(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



{NA=1.2,\[Lambda]=1.064,w0DL=(0.61\[Lambda])/NA} (*Beam waist corresponding to Diffraction Limited Spot given by Microscope NA*)
nParticle=0.2574-6.9663 I;(*particles complex refractive index*)
R=50;(*Particles radius*)
nmed=1.33;(*mediums' real refractive index*)
dndT=-3.4*10^-4;(*mediums' thermorefractive coefficient dn/dT*)
\[Lambda]=1064;(*probing beam wavelength in vacuum, used for scatteruing calculations*)
Mn=nParticle/nmed;

(*Parameer Setup for GAUSSIAN Beam Scatter, all in nm*)
w0=500;(*beam waist*)
zp=0;(*axial particle position*)
\[Gamma]=2 zp/w0;(*position parameter for BSCs*)
k=nmed*2\[Pi]/\[Lambda];(*wave-vector in the medium*)
l=k w0^2;(*spreading length, determined by beam-waist and wave-vector k*)
zR=l/2; (*Rayleigh range*)
s=w0/l;(*confinement factor, determined by spreading length and beam-waist*)
nmax=50;(*maximum multipole order for non-multilayer Mie-coefficients. Multilayer coefs use computed nmax*)
npmax=50;
jmax=10;(*maximum order for BSC generation (Gaussian Off-Axis only)*)
w0G=N[w0*10^-9];(*w0G in [m]*)
\[Theta]div=2/(k w0);
{"nMax suggested:",nMaxP[k R]}
{\[Alpha]=4\[Pi] R^3 (Mn^2-1)/(Mn^2+2),\[Alpha]a1=6\[Pi] aMie[1,k R,Mn]/(I k^3)}

(*Parameer Setup for GAUSSIAN Heating Beam illumination, needed for PT signal, all in nm*)
nParticleh=0.5163+2.2304 I; (*"+" sign convention, since only used for PT signal*)
\[Lambda]h=532; (*heating laser wavelength in vacuum, used for PT signal*)
w0h=233;(*heating laser beam waist, used for PT signal*)
Ph0=97*10^-6;(*heating Power, used for PT signal*)
dzf=-250; (*heating laser offset relative to detection laser*)
\[Kappa]med=0.15*10^-9; (*medum thermal conductivity [W/nm]*)
cabber=0.3; (*Aberration, compute from exact scattering, e.g. PSF Lab*)
kh=nmed*2\[Pi]/\[Lambda]h;
lh=kh w0h^2; (*heating laser spreading length*)
zRh=lh/2; (*heating laser Rayleigh-range, used for PT signal*)
sh=w0h/lh;
Nn=Table[N[(2n+1)/(n(n+1))],{n,1,10000}];

(*parameter Setup for EXACT Scatter only, all in nm*)
NA=1.4;f=1.8*10^6;wa=1.8*10^6;n1=1.525;n2=nmed;d=0;ds=0; (*OIL IMMERSION, 100x, NA=1.4*)
NA=1.2;f=1.8*10^6/0.6;wa=1.8*10^6/(0.5*0.6);n1=1.33;n2=nmed;d=0;ds=0; (*WATER IMMERSION, 60x, NA=1.2*)
dobj=0.01; (*Microscope Back-pupil diameter*)
w0E=dobj n1/(2 NA);(*w0E in [m]*)
A=1-Exp[-2 (f/wa)^2 Sin[NA/n1]^2];(*Ratio of power transmitted through aperture for given total P0,"THEORY OF OPTICAL TWEEZERS"
P.A. Maia Neto and H.M.Nussenzveig, 2008*)

{"s:",s,"l:",l,"zR:",zR,"w0G:",w0G,"w0E:",w0E}


(*prepares units for later*)
\[Mu]m=10^-6;c=299792458;nm=10^-9;

(*Bessel related functions needed for Mie coeff.*)
psi[n_,x_]:=x SphericalBesselJ[n,x](*Riccarti \.06Bessel \.06Functions*)
xi[n_,x_]:=x SphericalHankelH2[n,x]
psidev[n_,x_]:= Derivative[0,1][psi][n,x];
xidev[n_,x_]:= Derivative[0,1][xi][n,x];

(*Mie Coeff. {Subscript[a, n],Subscript[b, n],Subscript[c, n],Subscript[d, n]}*)
aMie[n_,x_,m_]:=(m psi[n,m x]psidev[n,x]-psi[n,x]psidev[n,m x])/(m psi[n,m x]xidev[n,x]-xi[n,x]psidev[n,m x]);
bMie[n_,x_,m_]:=(psi[n,m x]psidev[n,x]-m psi[n,x]psidev[n,m x])/(psi[n,m x]xidev[n,x]-m xi[n,x]psidev[n,m x]);
cMie[n_,x_,m_]:=(m (xi[n,x]psidev[n,x]-psi[n,x]xidev[n,x]))/(psidev[n,m x]xi[n,x]-m xidev[n,x]psi[n,m x]);
dMie[n_,x_,m_]:=(m^2 (xi[n,x]psidev[n,x]-psi[n,x]xidev[n,x]))/(m psidev[n,m x]xi[n,x]-xidev[n,x]psi[n,m x]);

kk[\[Lambda]_,nmed_]:=2 \[Pi] nmed/\[Lambda]; XMieSF[\[Lambda]_,r_,nmed_]:=kk[\[Lambda],nmed] r; M[\[Lambda]_,nmed_,\[CapitalDelta]T_]:=nParticle/nmed; (*wave vector etc.*)



(*This function gives the total fluxes, i.e. the total cross-sections {Extinction, Scattering, Absorption}*)
Clear[CrossSections];
CrossSections[w00_,\[Lambda]\[Lambda]_,RR_,nParticlee_,nmaxx_]:=
Module[{w0=w00,\[Lambda]=\[Lambda]\[Lambda],R=RR,nParticle=nParticlee,Nmax=nmaxx,k,s,an,bn,gnT,n,Nn,Cext,Csca,Cabs,Cinc},
k=nmed 2\[Pi]/\[Lambda];s=1/(k w0);
(*Get Gaussian BSC for z0=0, \[Gamma]=2z0/w0=0*)
gnT=Table[N[gnMLA[n,s,0]],{n,1,Nmax+1}]; (*Subscript[g, n]*)
an=Table[aMie[n,k R,nParticle/nmed],{n,1,Nmax}]; (*Subscript[a, n]*)
bn=Table[bMie[n,k R,nParticle/nmed],{n,1,Nmax}]; (*Subscript[b, n]*)
Csca=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(\((2  n + 1)\)\ 
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] \((
\*SuperscriptBox[\(Abs[an[[n]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bn[[n]]]\), \(2\)])\)\)\);Cext=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] \((2  n + 1)\) Re[an[[n]] + bn[[n]]]\)\);Cabs=Cext-Csca;Cinc=\[Pi] w0^2/2;
{Cext,Csca,Cabs,Cinc}2\[Pi]/k^2
];


Clear[Dn1,Dn3,\[Psi]\[Zeta],L,Nmax,a,b,z1,m,li,D1lmlx,D3lmlx,D1lmlxM1,D3lmlxM1,Ha,Hb,Ql,PsiZetalmlx,PsiZetalmlxM1,an,bn,PsiXL,L,xL,Nmaxf,D1XL,D3XL,PsiXL,ZetaXL,PsiZetaXL,z1,z2,a1,a2,b1,b2,G1,G2,Temp];

abL[xx_,mm_,fixNmaxx_]:=
Module[{x=xx,m=mm,fixNmax=fixNmaxx,D1lmlx,D3lmlx,D1lmlxM1,D3lmlxM1,PsiZetalmlx,PsiZetalmlxM1,Ql,D1XL,D3XL,ZetaXL,PsiZetaXL,G1,G2,Temp,Nn,an,bn,Nmax,Nmaxf,Nstop,Ha,Hb,PsiXL,n,z1,z2,a1,a2,b1,b2,i,L,li,a,b},Nstop[xL_]:=Piecewise[{{4 xL^(1/3)+xL+1,0.02<=xL<8},{4.05 xL^(1/3)+xL+2,8<=xL<4200},{4 xL^(1/3)+xL+2,4200<=xL<20000}}];
L=Length[x];Nmaxf=Nstop[x[[L]]];
For[i=1,i<=L,i++,If[Nmaxf<Abs[x[[i]] m[[i]]],Nmaxf=Round[Abs[x[[i]] m[[i]]]],0];If[Nmaxf<Abs[x[[i-1]] m[[i]]],Nmaxf=Round[Abs[x[[i-1]] m[[i]]]],0]];Nmax=If[fixNmax==0,Round[Nmaxf+15],fixNmax];

an=Table[0,{Nmax+3}];bn=Table[0,{Nmax+3}];Nn=Table[0,{Nmax+3}];
D1lmlx=Table[Table[0,{L+2}],{Nmax+3}];D1lmlxM1=Table[Table[0,{L+2}],{Nmax+3}];
D3lmlx=Table[Table[0,{L+2}],{Nmax+2}];D3lmlxM1=Table[Table[0,{L+2}],{Nmax+2}];
PsiZetalmlx=Table[Table[0,{L+2}],{Nmax+2}];PsiZetalmlxM1=Table[Table[0,{L+2}],{Nmax+2}];
Ql=Table[Table[0,{L+2}],{Nmax+2}];Ha=Table[Table[0,{L+2}],{Nmax+2}];Hb=Table[Table[0,{L+2}],{Nmax+2}];
D1XL=Table[0,{Nmax+3}];D3XL=Table[0,{Nmax+2}];PsiXL=Table[0,{Nmax+2}];ZetaXL=Table[0,{Nmax+2}];PsiZetaXL=Table[0,{Nmax+2}];

z1=m[[1]] x[[1]];D1lmlx[[Nmax+2]][[1]]=0+0 I;
For[n=Nmax+2,n>=2,n--,D1lmlx[[n-1]][[1]]=(n-1)/z1-1/(D1lmlx[[n]][[1]]+(n-1)/z1)];
a=Re[z1];b=Im[z1];PsiZetalmlx[[1]][[1]]=N[(1-E^(-2 b) (Cos[2 a]+I Sin[2 a]))/2];D3lmlx[[1]][[1]]=I;For[n=2,n<=Nmax+1,n++,PsiZetalmlx[[n]][[1]]=PsiZetalmlx[[n-1]][[1]] ((n-1)/z1-D1lmlx[[n-1]][[1]]) ((n-1)/z1-D3lmlx[[n-1]][[1]]);D3lmlx[[n]][[1]]=D1lmlx[[n]][[1]]+I/PsiZetalmlx[[n]][[1]]];
For[n=1,n<=Nmax+1,n++,Ha[[n]][[1]]=D1lmlx[[n]][[1]];Hb[[n]][[1]]=D1lmlx[[n]][[1]]];

For[li=2,li<=L,li++,
z1=m[[li]] x[[li]];z2=m[[li]] x[[li-1]];D1lmlx[[Nmax+2]][[li]]=0+0 I;D1lmlxM1[[Nmax+2]][[li]]=0+0 I;
For[n=Nmax+2,n>=2,n--,D1lmlx[[n-1]][[li]]=(n-1)/z1-1/(D1lmlx[[n]][[li]]+(n-1)/z1);D1lmlxM1[[n-1]][[li]]=(n-1)/z2-1/(D1lmlxM1[[n]][[li]]+(n-1)/z2)];
a1=Re[z1];b1=Im[z1];a2=Re[z2];b2=Im[z2];D3lmlx[[1]][[li]]=I;D3lmlxM1[[1]][[li]]=I;
PsiZetalmlx[[1]][[li]]=N[(1-E^(-2 b1) (Cos[2 a1]+I Sin[2 a1]))/2];PsiZetalmlxM1[[1]][[li]]=N[(1-E^(-2 b2) (Cos[2 a2]+I Sin[2 a2]))/2];
For[n=2,n<=Nmax+1,n++,
PsiZetalmlx[[n]][[li]]=PsiZetalmlx[[n-1]][[li]] ((n-1)/z1-D1lmlx[[n-1]][[li]]) ((n-1)/z1-D3lmlx[[n-1]][[li]]);PsiZetalmlxM1[[n]][[li]]=PsiZetalmlxM1[[n-1]][[li]] ((n-1)/z2-D1lmlxM1[[n-1]][[li]]) ((n-1)/z2-D3lmlxM1[[n-1]][[li]]);
D3lmlx[[n]][[li]]=D1lmlx[[n]][[li]]+I/PsiZetalmlx[[n]][[li]];D3lmlxM1[[n]][[li]]=D1lmlxM1[[n]][[li]]+I/PsiZetalmlxM1[[n]][[li]]];
Ql[[1]][[li]]=(-E^(-2 b2)+E^(-2 I a2)) E^(-2 (b1-b2))/(-E^(-2 b1)+E^(-2 I a1));
For[n=2,n<=Nmax+1,n++,Ql[[n]][[li]]=(Abs[x[[li-1]]/x[[li]]]^2 Ql[[n-1]][[li]] ((z1 D1lmlx[[n]][[li]]+(n-1)) ((n-1)-z1 D3lmlx[[n-1]][[li]])))/((z2 D1lmlxM1[[n]][[li]]+(n-1)) ((n-1)-z2 D3lmlxM1[[n-1]][[li]]))];
For[n=2,n<=Nmax+1,n++,
G1=m[[li]] Ha[[n]][[li-1]]-m[[li-1]] D1lmlxM1[[n]][[li]];G2=m[[li]] Ha[[n]][[li-1]]-m[[li-1]] D3lmlxM1[[n]][[li]];Temp=G1 Ql[[n]][[li]];Ha[[n]][[li]]=(G2 D1lmlx[[n]][[li]]-Temp D3lmlx[[n]][[li]])/(G2-Temp);
G1=m[[li-1]] Hb[[n]][[li-1]]-m[[li]] D1lmlxM1[[n]][[li]];G2=m[[li-1]] Hb[[n]][[li-1]]-m[[li]] D3lmlxM1[[n]][[li]];Temp=G1 Ql[[n]][[li]];Hb[[n]][[li]]=(G2 D1lmlx[[n]][[li]]-Temp D3lmlx[[n]][[li]])/(G2-Temp);
];
];

z1=x[[L]];a=Re[z1];b=Im[z1];D1XL[[Nmax+2]]=0+0 I;
For[n=Nmax+2,n>=2,n--,D1XL[[n-1]]=(n-1)/z1-1/(D1XL[[n]]+(n-1)/z1)];
PsiXL[[1]]=Sin[a];ZetaXL[[1]]=Sin[a]-I Cos[a];PsiZetaXL[[1]]=N[1/2 (1-E^(-2 b) (Cos[2 a]+I Sin[2 a]))];D3XL[[1]]=I;
For[n=2,n<=Nmax+1,n++,PsiXL[[n]]=PsiXL[[n-1]] ((n-1)/z1-D1XL[[n-1]]);ZetaXL[[n]]=ZetaXL[[n-1]] ((n-1)/z1-D3XL[[n-1]]);PsiZetaXL[[n]]=PsiZetaXL[[n-1]] ((n-1)/z1-D1XL[[n-1]]) ((n-1)/z1-D3XL[[n-1]]);D3XL[[n]]=D1XL[[n]]+I/PsiZetaXL[[n]]];
For[n=1,n<=Nmax,n++,Nn[[n]]=(2 n+1)/(n (n+1));an[[n]]=(PsiXL[[n+1]] (Ha[[n+1]][[L]]/m[[L]]+n/x[[L]])-PsiXL[[n]])/(ZetaXL[[n+1]] (Ha[[n+1]][[L]]/m[[L]]+n/x[[L]])-ZetaXL[[n]]);bn[[n]]=(PsiXL[[n+1]] (m[[L]] Hb[[n+1]][[L]]+n/x[[L]])-PsiXL[[n]])/(ZetaXL[[n+1]] (m[[L]] Hb[[n+1]][[L]]+n/x[[L]])-ZetaXL[[n]])];
{Conjugate[an],Conjugate[bn],Nn,Nmax}
];
(*Recursively determine the angular functions \[Pi]n and \[Tau]n for an arbitrary angle \[Theta][radians], Subscript[\[Pi], n]=\[Pi][[n+1]] (since theres no 0-index!)*)
\[Pi]n\[Tau]n\[Theta][\[Theta]\[Theta]_,NNmax_]:=Module[{\[Theta]=N[\[Theta]\[Theta]],Nmax=NNmax,\[Pi]n,\[Tau]n,n},
\[Pi]n=Table[0,{n,1,Nmax+2}];\[Tau]n=\[Pi]n;\[Pi]n[[1]]=0;\[Pi]n[[2]]=1;
For[n=3,n<=Nmax+1,n++,\[Pi]n[[n]]=((2 (n-1)-1) Cos[\[Theta]] \[Pi]n[[n-1]])/(n-2)-((n-1) \[Pi]n[[n-2]])/(n-2)];
For[n=2,n<=Nmax+1,n++,\[Tau]n[[n]]=(n-1) Cos[\[Theta]] \[Pi]n[[n]]-n \[Pi]n[[n-1]]];{\[Pi]n,\[Tau]n}];


nMaxP[q_]:=q+4.3q^(1/3)+1;

FieldPM[r0_,kk_]:=Module[{r=r0,k=kk,n,FieldP,gn},
FieldP=Table[Table[0,{i,1,7}],{n,1,nmax}];
For[n=1,n<=nmax,n++,
FieldP[[n]][[1]]=r SphericalBesselJ[n,k r]; (* r*Subscript[j, n][kr] *)
FieldP[[n]][[2]]=((1+n) SphericalBesselJ[n,k r]-k r SphericalBesselJ[1+n,k r])/k; (* D[r*Subscript[j, n][kr],r]/k *)
FieldP[[n]][[3]]=Sqrt[\[Pi]/2] (n+n^2-k^2 r^2) BesselJ[1/2+n,k r]/((k r)^(3/2));(* D[r*Subscript[j, n][kr],{r,2}]/k *)
FieldP[[n]][[4]]=r SphericalHankelH2[n,k r];(* k*kr*\!\(
\(\*SubsuperscriptBox[\(h\), \(n\), \(2\)]\)[kr]\)/k^2 *)
FieldP[[n]][[5]]=k^-1 ((1+n) SphericalHankelH2[n,k r]-k r SphericalHankelH2[1+n,k r]);(* D[kr*\!\(
\(\*SubsuperscriptBox[\(h\), \(n\), \(2\)]\)[kr]\),r]/k^2 *)
FieldP[[n]][[6]]=(r k)^-1 (n+n^2-k^2 r^2) SphericalHankelH2[n,k r];(* D[kr*\!\(
\(\*SubsuperscriptBox[\(h\), \(n\), \(2\)]\)[kr]\),{r,2}]/k^2 *)
If[Exact==1,gn=(-1)^n gnET[[n]],gn=gnMLA[n,s,\[Gamma]]];
FieldP[[n]][[7]]=I^(n+1) (-1)^n ((2n+1)/(n(n+1)))gn]; (* k Subsuperscript[c, n, pw] Subscript[g, n] *)
FieldP (*Output the Table*)
];
(*Components of EM-Fields: Scattered (s), Incidence (i), Total (tot), Interior (sp)*)
EHVi[r0_,\[Theta]0_,\[Phi]0_]:=Module[{r=r0,\[Theta]=\[Theta]0,\[Phi]=\[Phi]0,FieldP,E\[Theta]i,E\[Phi]i,H\[Theta]i,H\[Phi]i,Et,Eri,Hri,Ei2,Hi2,\[Pi]n,\[Tau]n,\[Pi]n\[Tau]nT,E\[Theta]s,E\[Phi]s,H\[Theta]s,H\[Phi]s,Ers,Hrs,Eis,His,Es2,Hs2,E\[Theta]sp,E\[Phi]sp,H\[Theta]sp,H\[Phi]sp,Ersp,Hrsp,Esp2,Hsp2,EiV,EspV,EsV,ETotV,Etot2,Htot2,Poynting,PoyntingSP,PoyntingS,PoyntingI,STot2,SS2,SI2,SSP2},
(*create angular functions at Subscript[\[CapitalPi], n][\[Theta]] and Subscript[\[Tau], n][\[Theta]] for all n*)
\[Pi]n\[Tau]nT=\[Pi]n\[Tau]n\[Theta][\[Theta],nmax];\[Pi]n=\[Pi]n\[Tau]nT[[1]];\[Tau]n=\[Pi]n\[Tau]nT[[2]];
(*Get generating functions of the field components, i.e. {kr*\!\(
\(\*SubsuperscriptBox[\(h\), \(n\), \(2\)]\)[kr]\),r*Subscript[j, n][kr] and derivatives}*)
FieldP=If[r>=R,FieldPM[r,k],FieldPM[r,k*nParticle/nmed]];

(*Incidence Field Components: EiV={\!\(
\*SubsuperscriptBox[\(E\), \(\[Theta]\), \(inc\)], 
\*SubsuperscriptBox[\(E\), \(\[Phi]\), \(inc\)], 
\*SubsuperscriptBox[\(E\), \(r\), \(inc\)], 
\*SubsuperscriptBox[\(H\), \(\[Theta]\), \(inc\)], 
\*SubsuperscriptBox[\(H\), \(\[Phi]\), \(inc\)], 
\*SubsuperscriptBox[\(H\), \(r\), \(inc\)], \(\(|\)
\*SuperscriptBox[\(E\), \(inc\)]
\*SuperscriptBox[\(|\), \(2\)]\), \(\(|\)
\*SuperscriptBox[\(H\), \(inc\)]
\*SuperscriptBox[\(|\), \(2\)]\), \(\(|\)
\*SuperscriptBox[\(E\), \(inc\)]
\*SuperscriptBox[\(|\), \(2\)]\(+\(\(|\)
\*SuperscriptBox[\(H\), \(inc\)]
\*SuperscriptBox[\(|\), \(2\)]\)\)\)\)}*)
Eri=-Cos[\[Phi]]Sum[FieldP[[n]][[7]](FieldP[[n]][[3]]+k FieldP[[n]][[1]])\[Pi]n[[n+1]]Sin[\[Theta]],{n,1,nmax}];
E\[Theta]i=(Cos[\[Phi]]/r)Sum[FieldP[[n]][[7]](-FieldP[[n]][[2]]\[Tau]n[[n+1]]+I FieldP[[n]][[1]]\[Pi]n[[n+1]]),{n,1,nmax}];
E\[Phi]i=(Sin[\[Phi]]/r)Sum[FieldP[[n]][[7]](FieldP[[n]][[2]]\[Pi]n[[n+1]]-I FieldP[[n]][[1]]\[Tau]n[[n+1]]),{n,1,nmax}];
Hri=-Sin[\[Phi]]Sum[FieldP[[n]][[7]](FieldP[[n]][[3]]+k FieldP[[n]][[1]])\[Pi]n[[n+1]]Sin[\[Theta]],{n,1,nmax}];
H\[Theta]i=(Sin[\[Phi]]/r)Sum[FieldP[[n]][[7]](I FieldP[[n]][[1]]\[Pi]n[[n+1]]-FieldP[[n]][[2]]\[Tau]n[[n+1]]),{n,1,nmax}];
H\[Phi]i=(Cos[\[Phi]]/r)Sum[FieldP[[n]][[7]](I FieldP[[n]][[1]]\[Tau]n[[n+1]]-FieldP[[n]][[2]]\[Pi]n[[n+1]]),{n,1,nmax}];
Ei2=Abs[E\[Theta]i]^2+Abs[E\[Phi]i]^2+Abs[Eri]^2;Hi2=Abs[H\[Theta]i]^2+Abs[H\[Phi]i]^2+Abs[Hri]^2;
EiV={E\[Theta]i,E\[Phi]i,Eri,H\[Theta]i,H\[Phi]i,Hri,Ei2,Hi2,Ei2+Hi2};

(*Scattered Field Components: EsV={\!\(
\*SubsuperscriptBox[\(E\), \(\[Theta]\), \(sca\)], 
\*SubsuperscriptBox[\(E\), \(\[Phi]\), \(sca\)], 
\*SubsuperscriptBox[\(E\), \(r\), \(sca\)], 
\*SubsuperscriptBox[\(H\), \(\[Theta]\), \(sca\)], 
\*SubsuperscriptBox[\(H\), \(\[Phi]\), \(sca\)], 
\*SubsuperscriptBox[\(H\), \(r\), \(sca\)], \(\(|\)
\*SuperscriptBox[\(E\), \(sca\)]
\*SuperscriptBox[\(|\), \(2\)]\), \(\(|\)
\*SuperscriptBox[\(H\), \(sca\)]
\*SuperscriptBox[\(|\), \(2\)]\), \(\(|\)
\*SuperscriptBox[\(E\), \(sca\)]
\*SuperscriptBox[\(|\), \(2\)]\(+\(\(|\)
\*SuperscriptBox[\(H\), \(sca\)]
\*SuperscriptBox[\(|\), \(2\)]\)\)\)\)}*)
Ers=Cos[\[Phi]]Sum[FieldP[[n]][[7]]anL[[n]](FieldP[[n]][[6]]+k FieldP[[n]][[4]])\[Pi]n[[n+1]]Sin[\[Theta]],{n,1,nmax}];
E\[Theta]s=-(Cos[\[Phi]]/r)Sum[FieldP[[n]][[7]](-anL[[n]]FieldP[[n]][[5]]\[Tau]n[[n+1]]+I bnL[[n]]FieldP[[n]][[4]]\[Pi]n[[n+1]]),{n,1,nmax}];
E\[Phi]s=-(Sin[\[Phi]]/r)Sum[FieldP[[n]][[7]](anL[[n]]FieldP[[n]][[5]]\[Pi]n[[n+1]]-I bnL[[n]]FieldP[[n]][[4]]\[Tau]n[[n+1]]),{n,1,nmax}];
Hrs=Sin[\[Phi]]Sum[FieldP[[n]][[7]]bnL[[n]](FieldP[[n]][[6]]+k FieldP[[n]][[4]])\[Pi]n[[n+1]]Sin[\[Theta]],{n,1,nmax}];
H\[Theta]s=-(Sin[\[Phi]]/r)Sum[FieldP[[n]][[7]](I anL[[n]]FieldP[[n]][[4]]\[Pi]n[[n+1]]-bnL[[n]]FieldP[[n]][[5]]\[Tau]n[[n+1]]),{n,1,nmax}];
H\[Phi]s=-(Cos[\[Phi]]/r)Sum[FieldP[[n]][[7]](I anL[[n]]FieldP[[n]][[4]]\[Tau]n[[n+1]]-bnL[[n]]FieldP[[n]][[5]]\[Pi]n[[n+1]]),{n,1,nmax}];
Es2=Abs[E\[Theta]s]^2+Abs[E\[Phi]s]^2+Abs[Ers]^2;Hs2=Abs[H\[Theta]s]^2+Abs[H\[Phi]s]^2+Abs[Hrs]^2;
EsV={E\[Theta]s,E\[Phi]s,Ers,H\[Theta]s,H\[Phi]s,Hrs,Es2,Hs2,Es2+Hs2};

(*Interior Field Components: EspV={\!\(
\*SubsuperscriptBox[\(E\), \(\[Theta]\), \(sp\)], 
\*SubsuperscriptBox[\(E\), \(\[Phi]\), \(sp\)], 
\*SubsuperscriptBox[\(E\), \(r\), \(sp\)], 
\*SubsuperscriptBox[\(H\), \(\[Theta]\), \(sp\)], 
\*SubsuperscriptBox[\(H\), \(\[Phi]\), \(sp\)], 
\*SubsuperscriptBox[\(H\), \(r\), \(sp\)], \(\(|\)
\*SuperscriptBox[\(E\), \(sp\)]
\*SuperscriptBox[\(|\), \(2\)]\), \(\(|\)
\*SuperscriptBox[\(H\), \(sp\)]
\*SuperscriptBox[\(|\), \(2\)]\), \(\(|\)
\*SuperscriptBox[\(E\), \(sp\)]
\*SuperscriptBox[\(|\), \(2\)]\(+\(\(|\)
\*SuperscriptBox[\(H\), \(sp\)]
\*SuperscriptBox[\(|\), \(2\)]\)\)\)\)}*)
Ersp=-Cos[\[Phi]]Sum[FieldP[[n]][[7]]cnL[[n]](FieldP[[n]][[3]]+(k*nParticle/nmed) FieldP[[n]][[1]])\[Pi]n[[n+1]]Sin[\[Theta]],{n,1,nmax}];
E\[Theta]sp=(Cos[\[Phi]]/r)Sum[FieldP[[n]][[7]](-cnL[[n]]FieldP[[n]][[2]]\[Tau]n[[n+1]]+I dnL[[n]]FieldP[[n]][[1]]\[Pi]n[[n+1]]),{n,1,nmax}];
E\[Phi]sp=(Sin[\[Phi]]/r)Sum[FieldP[[n]][[7]](cnL[[n]]FieldP[[n]][[2]]\[Pi]n[[n+1]]-I dnL[[n]]FieldP[[n]][[1]]\[Tau]n[[n+1]]),{n,1,nmax}];
Hrsp=-Sin[\[Phi]]Sum[FieldP[[n]][[7]]dnL[[n]](FieldP[[n]][[3]]+(k*nParticle/nmed) FieldP[[n]][[1]])\[Pi]n[[n+1]]Sin[\[Theta]],{n,1,nmax}];
H\[Theta]sp=(Sin[\[Phi]]/r)Sum[FieldP[[n]][[7]](I cnL[[n]]FieldP[[n]][[1]]\[Pi]n[[n+1]]-dnL[[n]]FieldP[[n]][[2]]\[Tau]n[[n+1]]),{n,1,nmax}];
H\[Phi]sp=(Cos[\[Phi]]/r)Sum[FieldP[[n]][[7]](I cnL[[n]] FieldP[[n]][[1]]\[Tau]n[[n+1]]-dnL[[n]]FieldP[[n]][[2]]\[Pi]n[[n+1]]),{n,1,nmax}];
Esp2=Abs[E\[Theta]sp]^2+Abs[E\[Phi]sp]^2+Abs[Ersp]^2;Hsp2=Abs[H\[Theta]sp]^2+Abs[H\[Phi]sp]^2+Abs[Hrsp]^2;
EspV={E\[Theta]sp,E\[Phi]sp,Ersp,H\[Theta]sp,H\[Phi]sp,Hrsp,Esp2,Hsp2,Esp2+Hsp2};

(*Total Field Components: ETotV={\!\(
\*SubsuperscriptBox[\(E\), \(\[Theta]\), \(sca\)] + 
\*SubsuperscriptBox[\(E\), \(\[Theta]\), \(inc\)]\), etc.}*)
Etot2=Abs[E\[Theta]s+E\[Theta]i]^2+Abs[E\[Phi]s+E\[Phi]i]^2+Abs[Ers+Eri]^2;Htot2=Abs[H\[Theta]s+H\[Theta]i]^2+Abs[H\[Phi]s+H\[Phi]i]^2+Abs[Hrs+Hri]^2;
ETotV={E\[Theta]s+E\[Theta]i,E\[Phi]s+E\[Phi]i,Ers+Eri,H\[Theta]s+H\[Theta]i,H\[Phi]s+H\[Phi]i,Hrs+Hri,Etot2,Htot2,Etot2+Htot2};

(*Poynting Vectors: Poynting={\!\(
\*SubsuperscriptBox[\(S\), \(r\), \(tot\)], 
\*SubsuperscriptBox[\(S\), \(\[Theta]\), \(tot\)], 
\*SubsuperscriptBox[\(S\), \(\[Phi]\), \(tot\)]\)}, PoyntingS={\!\(
\*SubsuperscriptBox[\(S\), \(r\), \(sca\)], 
\*SubsuperscriptBox[\(S\), \(\[Theta]\), \(sca\)], 
\*SubsuperscriptBox[\(S\), \(\[Phi]\), \(sca\)]\)}, PoyntingI={\!\(
\*SubsuperscriptBox[\(S\), \(r\), \(inc\)], 
\*SubsuperscriptBox[\(S\), \(\[Theta]\), \(inc\)], 
\*SubsuperscriptBox[\(S\), \(\[Phi]\), \(inc\)]\)} and PoyntingSP={\!\(
\*SubsuperscriptBox[\(S\), \(r\), \(sp\)], 
\*SubsuperscriptBox[\(S\), \(\[Theta]\), \(sp\)], 
\*SubsuperscriptBox[\(S\), \(\[Phi]\), \(sp\)]\)}, and {Subscript[S, r],Subscript[S, \[Theta]],Subscript[S, \[Phi]]}=Re({Subscript[E, \[Theta]] Subsuperscript[H, \[Phi], *]-Subscript[E, \[Phi]] Subsuperscript[H, \[Theta], *],-(Subscript[E, r] Subsuperscript[H, \[Phi], *]-Subscript[E, \[Phi]] Subsuperscript[H, r, *]),Subscript[E, r] Subsuperscript[H, \[Theta], *]-Subscript[E, \[Theta]] Subsuperscript[H, r, *]})*)
Poynting=Re[{ETotV[[1]]*Conjugate[ETotV[[5]]]-ETotV[[2]]*Conjugate[ETotV[[4]]],ETotV[[2]]*Conjugate[ETotV[[6]]]-ETotV[[3]]*Conjugate[ETotV[[5]]],
ETotV[[3]]*Conjugate[ETotV[[4]]]-ETotV[[1]]*Conjugate[ETotV[[6]]]}];
STot2=Sqrt[Poynting[[1]]^2+Poynting[[2]]^2+Poynting[[3]]^2];
PoyntingS=Re[{EsV[[1]]*Conjugate[EsV[[5]]]-EsV[[2]]*Conjugate[EsV[[4]]],EsV[[2]]*Conjugate[EsV[[6]]]-EsV[[3]]*Conjugate[EsV[[5]]],
EsV[[3]]*Conjugate[EsV[[4]]]-EsV[[1]]*Conjugate[EsV[[6]]]}];
SS2=Sqrt[PoyntingS[[1]]^2+PoyntingS[[2]]^2+PoyntingS[[3]]^2];
PoyntingI=Re[{EiV[[1]]*Conjugate[EiV[[5]]]-EiV[[2]]*Conjugate[EiV[[4]]],EiV[[2]]*Conjugate[EiV[[6]]]-EiV[[3]]*Conjugate[EiV[[5]]],
EiV[[3]]*Conjugate[EiV[[4]]]-EiV[[1]]*Conjugate[EiV[[6]]]}];
SI2=Sqrt[PoyntingI[[1]]^2+PoyntingI[[2]]^2+PoyntingI[[3]]^2];
PoyntingSP=Re[{EspV[[1]]*Conjugate[EspV[[5]]]-EspV[[2]]*Conjugate[EspV[[4]]],EspV[[2]]*Conjugate[EspV[[6]]]-EspV[[3]]*Conjugate[EspV[[5]]],
EspV[[3]]*Conjugate[EspV[[4]]]-EspV[[1]]*Conjugate[EspV[[6]]]}];
SSP2=Sqrt[PoyntingSP[[1]]^2+PoyntingSP[[2]]^2+PoyntingSP[[3]]^2];

(*Output List: Fields and Poynting Vectors*)
Et={EiV,EsV,EspV,ETotV,If[r>R,Poynting,{0,0,0}],If[r<R,PoyntingSP,{0,0,0}],If[r>R,PoyntingS,{0,0,0}],If[r>R,PoyntingI,{0,0,0}],{STot2,SS2,SI2,SSP2}}
];


(*Maximum needed n for gnT[[n]]<gnT[[0]]/10^10, This function is not needed, jsut for fun*)
Clear[PTSignal,Signal];
gnMaxN[z00_,ss_]:=Module[{s=ss,z0=z00,Nmaxgn=1,T,n=1},T=10^-12 Abs[gnMLA[1,s,(2 z0)/w0]];If[s<0.001,Nmaxgn=100,While[Abs[gnMLA[n,s,(2 z0)/w0]]>T,Nmaxgn=Nmaxgn+1;n++]];Nmaxgn];

(*Total Detected Signal, (z0: position of beam rel to particle, \[Theta]T={\[Theta]min,..,\[Theta]max} angles for numerical integration, {an,bn}: Tables of scatter coeff.)*)
Signal[z00_,\[Theta]TT_,ss_,w00_,anT_,bnT_]:=
Module[{z0=z00,\[Theta]T=\[Theta]TT,s=ss,w0=w00,an=anT,bn=bnT,gnT,SignalV,\[CapitalDelta]T0z0,n,m,Nmax,\[Theta]i,N\[Theta],CincI=0,CsI=0,CisI=0,S1,S2,Cs,Cinc,Cis,M,Nn,\[Theta],\[Pi]n\[Tau]n,\[Pi]n,\[Tau]n,Cext,Csca,Cabs,d\[Theta]},
N\[Theta]=Length[\[Theta]T];S1=Table[0,{\[Theta]i,1,N\[Theta]}];S2=S1;M=S1;Cs=S1;Cis=S1;Cinc=S1;d\[Theta]=\[Theta]T[[2]]-\[Theta]T[[1]];
Nmax=Min[gnMaxN[z0,s],Length[an]];(*Nmax=Length[an];*)
(*Get Gaussian BSC for z0 value, \[Gamma]=2z0/w0*)
gnT=Table[N[gnMLA[n,s,2 z0/w0]],{n,1,Nmax+1}];Nn=Table[(2n+1)/(n(n+1)),{n,1,Nmax+1}];
(*Get Signal*)
For[\[Theta]i=1,\[Theta]i<=N\[Theta],\[Theta]i++,
\[Theta]=\[Theta]T[[\[Theta]i]];\[Pi]n\[Tau]n=\[Pi]n\[Tau]n\[Theta][\[Theta],Nmax+2];\[Pi]n=\[Pi]n\[Tau]n[[1]];\[Tau]n=\[Pi]n\[Tau]n[[2]];
S1[[\[Theta]i]]=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(gnT[[n]]\ Nn[[n]]\ \((an[[n]]\ \[Pi]n[[n + 1]] + bn[[n]]\ \[Tau]n[[n + 1]])\)\)\);S2[[\[Theta]i]]=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(gnT[[n]]\ Nn[[n]]\ \((an[[n]]\ \[Tau]n[[n + 1]] + bn[[n]]\ \[Pi]n[[n + 1]])\)\)\);
M[[\[Theta]i]]=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(gnT[[n]]\ Nn[[n]]\ \((\[Pi]n[[n + 1]] + \[Tau]n[[n + 1]])\)\)\);
Cs[[\[Theta]i]]=Abs[S1[[\[Theta]i]]]^2+Abs[S2[[\[Theta]i]]]^2;CsI=CsI+d\[Theta] Sin[\[Theta]]Cs[[\[Theta]i]];(*Scatter Term*)
(*Cis[[\[Theta]i]]=(Im[M[[\[Theta]i]]] Im[S1[[\[Theta]i]]+S2[[\[Theta]i]]]+Re[M[[\[Theta]i]]] Re[S1[[\[Theta]i]]+S2[[\[Theta]i]]]);CisI=CisI+Sin[\[Theta]]Cis[[\[Theta]i]];(*Interference Term*)*)
Cis[[\[Theta]i]]=Re[Conjugate[M[[\[Theta]i]]] (S1[[\[Theta]i]]+S2[[\[Theta]i]])];CisI=CisI+d\[Theta] Sin[\[Theta]]Cis[[\[Theta]i]];(*Interference Term*)
Cinc[[\[Theta]i]]=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\((
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(n\)]gnT[[m]]\ Nn[[m]]\ Nn[[\(-m\) + n + 1]]\ Conjugate[gnT[[\(-m\) + n + 1]]]\ \((\((\[Pi]n[[m + 1]] + \[Tau]n[[m + 1]])\)\ \((\[Pi]n[[\(-m\) + n + 2]] + \[Tau]n[[\(-m\) + n + 2]])\) - 
\*SuperscriptBox[\((\(-1\))\), \(n + 1\)]\ \((\[Pi]n[[m + 1]] - \[Tau]n[[m + 1]])\)\ \((\[Pi]n[[\(-m\) + n + 2]] - \[Tau]n[[\(-m\) + n + 2]])\))\))\)\);(*Incidence Term*)
CincI=CincI+d\[Theta] Cinc[[\[Theta]i]]Sin[\[Theta]];
];
Csca=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(\((2  n + 1)\)\ 
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] \((
\*SuperscriptBox[\(Abs[an[[n]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bn[[n]]]\), \(2\)])\)\)\);Cext=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] \((2  n + 1)\) Re[an[[n]] + bn[[n]]]\)\);Cabs=Cext-Csca;
SignalV=CsI-CisI;(*Total Scatterer Dependent Signal*)
{(\[Lambda]^2) /(4\[Pi] nmed^2) SignalV,(\[Lambda]^2) /(8\[Pi] nmed^2) Re[CincI],(\[Lambda]^2) /(4\[Pi] nmed^2) Cs,-((\[Lambda]^2) /(4\[Pi] nmed^2))Cis,(\[Lambda]^2) /(8\[Pi] nmed^2) Re[Cinc],(\[Lambda]^2) /(4\[Pi] nmed^2) CsI,-((\[Lambda]^2) /(4\[Pi] nmed^2))CisI,(\[Lambda]^2) /(2\[Pi] nmed^2) Csca,(\[Lambda]^2) /(2\[Pi] nmed^2) Cext,(\[Lambda]^2) /(2\[Pi] nmed^2) Cabs}
];

SignalExact[z00_,\[Theta]End_,ss_,w00_,anT_,bnT_]:=
Module[{z0=z00,\[Theta]f=\[Theta]End,s=ss,w0=w00,an=anT,bn=bnT,gnT,Nmax,SignalV,IncI,IncIE,n,m,ExtI,ScaI,ExtIR,ScaIR,\[Pi]n\[Tau]n,\[Pi]n,\[Tau]n,Cext,Csca,Cabs,Hnf,Hn0,a1Mult},
Nmax=Min[gnMaxN[z0,s],Length[an]];
(*Get Gaussian BSC for z0 value, \[Gamma]=2z0/w0*)
gnT=Table[N[gnMLA[n,s,2 z0/w0]],{n,1,Nmax+1}];
(*Get Signal*)
\[Pi]n\[Tau]n=\[Pi]n\[Tau]n\[Theta][\[Theta]f,Nmax+2];\[Pi]n=\[Pi]n\[Tau]n[[1]];\[Tau]n=\[Pi]n\[Tau]n[[2]];
Hnf=Table[0,{n,1,Nmax+1}];Hnf[[1]]=Cos[\[Theta]f](3-Cos[\[Theta]f]^2)-2;
For[n=1,n<=Nmax,n++,Hnf[[n+1]]=1/n ((n+2)Hnf[[n]]+Sin[\[Theta]f]^2 (Cos[\[Theta]f]((n+2)\[Pi]n[[n+1]]^2+n*\[Pi]n[[n+2]]^2)-2(n+1)\[Pi]n[[n+1]]\[Pi]n[[n+2]]))];
ExtI=Re[-\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 2\), \(Nmax\)]\(
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(n - 1\)]
\*FractionBox[\(1\), \(n \((n + 1)\) - m \((m + 1)\)\)] Nn[[n]] Nn[[m]] \((Conjugate[gnT[[n]]] gnT[[m]]\ \((an[[m]] + bn[[m]])\) + Conjugate[gnT[[m]]] gnT[[n]] \((an[[n]] + bn[[n]])\))\) 
\*SuperscriptBox[\(Sin[\[Theta]f]\), \(2\)] \((m \((m + 1)\) \[Tau]n[[n + 1]] \[Pi]n[[m + 1]] - n \((n + 1)\) \[Tau]n[[m + 1]] \[Pi]n[[n + 1]])\)\)\)+
\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\((
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Nn[[n]]\), \(2\)] \((an[[n]] + bn[[n]])\) \((
\*SuperscriptBox[\(Sin[\[Theta]f]\), \(2\)] \[Tau]n[[n + 1]] \[Pi]n[[n + 1]] - 
\*FractionBox[\(n \((n + 1)\)\), \(2  n + 1\)] Hnf[[n]])\))\)\)+\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(Nmax\)]\((Nn[[n]] Nn[[m]]\ Conjugate[gnT[[n]]] gnT[[m]] \((an[[m]] + bn[[m]])\) \[Pi]n[[n + 1]] \[Pi]n[[m + 1]] 
\*SuperscriptBox[\(Sin[\[Theta]f]\), \(2\)])\)\)\)];
ScaI=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 2\), \(Nmax\)]\(
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(n - 1\)]\((
\*FractionBox[\((m \((m + 1)\) \[Tau]n[[n + 1]] \[Pi]n[[m + 1]] - n \((n + 1)\) \[Tau]n[[m + 1]] \[Pi]n[[n + 1]])\), \(n \((n + 1)\) - m \((m + 1)\)\)] Nn[[n]] Nn[[m]]\ Re[Conjugate[gnT[[n]]] gnT[[m]] \((Conjugate[an[[n]]] an[[m]] + Conjugate[bn[[n]]] bn[[m]])\)] 
\*SuperscriptBox[\(Sin[\[Theta]f]\), \(2\)] \((\(-2\))\))\)\)\)+
\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Nn[[n]]\), \(2\)] \((
\*SuperscriptBox[\(Abs[an[[n]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bn[[n]]]\), \(2\)])\) \((
\*SuperscriptBox[\(Sin[\[Theta]f]\), \(2\)] \[Tau]n[[n + 1]] \[Pi]n[[n + 1]] - 
\*FractionBox[\(n \((n + 1)\)\), \(2  n + 1\)] Hnf[[n]])\)\)\)+\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(Nmax\)]Nn[[n]] Nn[[m]] Conjugate[gnT[[n]]] gnT[[m]] \((Conjugate[an[[n]]] bn[[m]] + Conjugate[bn[[n]]] an[[m]])\) \[Pi]n[[n + 1]] \[Pi]n[[m + 1]] 
\*SuperscriptBox[\(Sin[\[Theta]f]\), \(2\)]\)\);
IncI=\[Pi]/2 w0^2 (1-Exp[-Tan[\[Theta]f]^2 k^2 w0^2/2]);
IncIE=\[Pi]/k^2 Sin[\[Theta]f]^2 (\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*SuperscriptBox[\(Nn[[n]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] 
\*SuperscriptBox[\(\[Pi]n[[n + 1]]\), \(2\)]\)\)+\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 2\), \(Nmax\)]\(
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(n - 1\)]Nn[[n]] Nn[[m]] Conjugate[gnT[[n]]] gnT[[m]] \((\[Pi]n[[n + 1]] \[Pi]n[[m + 1]] \((1 + 
\*SuperscriptBox[\((\(-1\))\), \(n + m\)])\) - \((1 - 
\*SuperscriptBox[\((\(-1\))\), \(n + m\)])\) 
\*FractionBox[\(m \((m + 1)\) \[Tau]n[[n + 1]] \[Pi]n[[m + 1]] - n \((n + 1)\) \[Pi]n[[n + 1]] \[Tau]n[[m + 1]]\), \(n \((n + 1)\) - m \((m + 1)\)\)])\)\)\));
Csca=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(\((2  n + 1)\)\ 
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] \((
\*SuperscriptBox[\(Abs[an[[n]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bn[[n]]]\), \(2\)])\)\)\);Cext=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] \((2  n + 1)\) Re[an[[n]] + bn[[n]]]\)\);Cabs=Cext-Csca;
SignalV=Re[-ExtI+ScaI];(*Total Scatterer Dependent Signal*)
{(\[Lambda]^2) /(4\[Pi] nmed^2) SignalV,Re[IncIE],(\[Lambda]^2) /(4\[Pi] nmed^2) Re[ScaI],-((\[Lambda]^2) /(4\[Pi] nmed^2))ExtI,(\[Lambda]^2) /(2\[Pi] nmed^2) Csca,(\[Lambda]^2) /(2\[Pi] nmed^2) Cext,(\[Lambda]^2) /(2\[Pi] nmed^2) Cabs,IncI,Nmax}
];

SignalRayleigh[z00_,\[Theta]TT_,zRR_,w00_,alphaa_]:=
Module[{z0=z00,\[Theta]T=\[Theta]TT,zR=zRR,w0=w00,\[Alpha]=alphaa,gnT,SignalV,\[CapitalDelta]T0z0,n,m,Nmax,\[Theta]i,N\[Theta],CincI=0,CsI=0,CisI=0,S1pS2,Cs,Cinc,Cis,M,\[Theta],\[Pi]n\[Tau]n,\[Pi]n,\[Tau]n,Cext,Csca,Cabs,a1,a1Mult,ExtIR,ScaIR,\[Theta]f,IncIE,IncI,d\[Theta]},
N\[Theta]=Length[\[Theta]T];S1pS2=Table[0,{\[Theta]i,1,N\[Theta]}];M=S1pS2;Cs=M;Cis=M;Cinc=M;
Nmax=Min[gnMaxN[z0,s],100];(*Nmax=Length[an];*)
(*Nmax=10;*)
(*Get Gaussian BSC for z0 value, \[Gamma]=2z0/w0*)
gnT=Table[N[gnMLA[n,w0/(2zR),2 z0/w0]],{n,1,Nmax+1}];
(*Get Signal*)
a1=I \[Alpha] k^3/(6\[Pi]);
(*a1=(k R)^3 (2I)/3 (Mn^2-1)/(Mn^2+2) (1+3/5 (Mn^2-2)/(Mn^2+2) (k R)^2-(2I)/3 (Mn^2-1)/(Mn^2+2) (k R)^3);*)
\[Theta]f=Last[\[Theta]T];\[Pi]n\[Tau]n=\[Pi]n\[Tau]n\[Theta][\[Theta]f,Nmax+2];\[Pi]n=\[Pi]n\[Tau]n[[1]];\[Tau]n=\[Pi]n\[Tau]n[[2]];
a1Mult=(3/4 Abs[gnT[[1]]]^2 Sin[\[Theta]f/2]^2 (15+8Cos[\[Theta]f]+Cos[2\[Theta]f])+3/2 gnT[[1]]Sin[\[Theta]f]^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 2\), \(Nmax\)]\(Conjugate[gnT[[n]]]\ Nn[[n]] 
\*FractionBox[\(n \((n + 1)\) \[Pi]n[[n + 1]] \((Cos[\[Theta]f] + 1)\) - 2 \((\[Pi]n[[n + 1]] + \[Tau]n[[n + 1]])\)\), \(n \((n + 1)\) - 2\)]\)\));
ExtIR=Re[a1 a1Mult];
ScaIR=3/4 Abs[a1]^2 Abs[gnT[[1]]]^2 (4-3 Cos[\[Theta]f]-Cos[\[Theta]f]^3);
SignalV=ScaIR-ExtIR;(*Total Scatterer Dependent Signal*)
IncI=\[Pi]/2 w0^2 (1-Exp[-Tan[\[Theta]f]^2 k^2 w0^2/2]);
IncIE=\[Pi]/k^2 Sin[\[Theta]f]^2 (\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(
\*SuperscriptBox[\(Nn[[n]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnT[[n]]]\), \(2\)] 
\*SuperscriptBox[\(\[Pi]n[[n + 1]]\), \(2\)]\)\)+\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 2\), \(Nmax\)]\(
\*UnderoverscriptBox[\(\[Sum]\), \(m = 1\), \(n - 1\)]Nn[[n]] Nn[[m]] Conjugate[gnT[[n]]] gnT[[m]] \((\[Pi]n[[n + 1]] \[Pi]n[[m + 1]] \((1 + 
\*SuperscriptBox[\((\(-1\))\), \(n + m\)])\) - \((1 - 
\*SuperscriptBox[\((\(-1\))\), \(n + m\)])\) 
\*FractionBox[\(m \((m + 1)\) \[Tau]n[[n + 1]] \[Pi]n[[m + 1]] - n \((n + 1)\) \[Pi]n[[n + 1]] \[Tau]n[[m + 1]]\), \(n \((n + 1)\) - m \((m + 1)\)\)])\)\)\));
If[N\[Theta]>1;For[\[Theta]i=1,\[Theta]i<=N\[Theta],\[Theta]i++,
\[Theta]=\[Theta]T[[\[Theta]i]];\[Pi]n\[Tau]n=\[Pi]n\[Tau]n\[Theta][\[Theta],Nmax+2];\[Pi]n=\[Pi]n\[Tau]n[[1]];\[Tau]n=\[Pi]n\[Tau]n[[2]];
S1pS2[[\[Theta]i]]=(3/2)gnT[[1]]a1(1+Cos[\[Theta]]);
M[[\[Theta]i]]=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(Nmax\)]\(gnT[[n]]\ Nn[[n]]\ \((\[Pi]n[[n + 1]] + \[Tau]n[[n + 1]])\)\)\);
Cs[[\[Theta]i]]=(9/4)Abs[gnT[[1]]a1]^2 (1+Cos[\[Theta]]^2);CsI=CsI+Sin[\[Theta]]Cs[[\[Theta]i]];(*Scatter Term*)
Cis[[\[Theta]i]]=Re[Conjugate[M[[\[Theta]i]]]S1pS2[[\[Theta]i]]];CisI=CisI+Sin[\[Theta]]Cis[[\[Theta]i]];(*Interference Term*)
Cinc[[\[Theta]i]]=\[Pi]/2 w0^2 (Exp[-Tan[\[Theta]]^2 k^2 w0^2/2]);(*Incidence Term*)
CincI=CincI+Cinc[[\[Theta]i]]Sin[\[Theta]];
],0];
If[N\[Theta]>1,d\[Theta]=\[Theta]T[[2]]-\[Theta]T[[1]],d\[Theta]=0];
Csca=3 Abs[gnT[[1]]]^2 Abs[a1]^2;Cext=Abs[gnT[[1]]]^2 3Re[a1];Cabs=Cext-Csca;
{(\[Lambda]^2) /(4\[Pi] nmed^2) SignalV,Re[IncIE],(\[Lambda]^2) /(4\[Pi] nmed^2) Cs,-((\[Lambda]^2) /(4\[Pi] nmed^2))Cis,(\[Lambda]^2) /(8\[Pi] nmed^2) Re[Cinc],(\[Lambda]^2) /(2\[Pi] nmed^2) Csca,(\[Lambda]^2) /(2\[Pi] nmed^2) Cext,(\[Lambda]^2) /(2\[Pi] nmed^2) Cabs,(\[Lambda]^2) /(4\[Pi] nmed^2) ScaIR,-((\[Lambda]^2) /(4\[Pi] nmed^2))ExtIR,a1Mult,(\[Lambda]^2) /(4\[Pi] nmed^2) (CsI-CisI) d\[Theta],(\[Lambda]^2) /(4\[Pi] nmed^2) CsI d\[Theta],-((\[Lambda]^2) /(4\[Pi] nmed^2))CisI d\[Theta]}
];

(*Get Temperature Increase from Heating laser, uses above function*)
dTh[z00_,\[Theta]\[Theta]_,Ph00_]:=Module[{z0=z00,\[Theta]=\[Theta]\[Theta],Ph0=Ph00,m,AA,anCh,bnCh,cabsh,Ih0,dT},
x={kh R};m={nParticleh/nmed};
AA=abL[x,m,0];anCh=AA[[1]];bnCh=AA[[2]];
cabsh=SignalExact[z0,\[Theta],sh,w0h,anCh,bnCh][[7]];
Ih0=cabber*2Ph0/(\[Pi] w0h^2);
dT=Ih0 cabsh/(4\[Pi] \[Kappa]med R)
];

(*Photothermal Signal, i.e. Hot - Cold Total Signal*)
(*{PT Signal, Scatter Signal Cold, Scatter Signal Hot, PT(Ext), Ext(COld), Ext(Hot), PT(Sca), Sca(Cold), Sca(Hot)}*)
PTSignal[z00_,\[Theta]\[Theta]_,ddzf_,Ph00_]:=Module[{z0=z00,\[Theta]=\[Theta]\[Theta],dzf=ddzf,Ph0=Ph00,x,\[CapitalDelta]T0z0,m,i,AA,anC,bnC,anH,bnH,Nn,HotSignal,HotSignalT,ColdSignal,Inc},
(*Get Cold Scatterer {an,bn} with Cold*)
x={k R};m={nParticle/nmed};
AA=abL[x,m,70];anC=AA[[1]];bnC=AA[[2]];
(*Get Thermal Lens {an,bn} with Hot \[CapitalDelta]T0(z0)*)
\[CapitalDelta]T0z0=dTh[z0+dzf,\[Theta],Ph0];
x=k*rT;m=Join[{nParticle},Table[nmed+dndT*\[CapitalDelta]T0z0*R/rT[[i]],{i,1,L}]]/nmed;
AA=abL[x,m,70];anH=AA[[1]];bnH=AA[[2]];
(*Get Signals and compute difference*)
HotSignal=SignalExact[z0,\[Theta],s,w0,anH,bnH];
ColdSignal=SignalExact[z0,\[Theta],s,w0,anC,bnC];
{HotSignal[[1]]-ColdSignal[[1]],ColdSignal[[1]],HotSignal[[1]],HotSignal[[3]]-ColdSignal[[3]],ColdSignal[[3]],HotSignal[[3]],HotSignal[[4]]-ColdSignal[[4]],ColdSignal[[4]],HotSignal[[4]]}
];


Clear[M11,M12,M21,M22,X1,X2,Y1,Y2,SumX1,SumX2,InmS1S1,InmS2S2,InmM1S1,InmM2S2,Cs,Cis,SignalOffAxis];
\[Pi]nm[\[Theta]_,n_,m_]:=LegendreP[n,m,Cos[\[Theta]]]/Sin[\[Theta]];\[Tau]nm[\[Theta]_,n_,m_]:=n Cos[\[Theta]]\[Pi]nm[\[Theta],n,m]-(n+m)\[Pi]nm[\[Theta],n-1,m];
N\[Theta]=100;

OffAxis\[Theta]i[gnmTETo_,gnmTMTo_,anLL_,bnLL_,\[Theta]i_]:=Module[{gnmTET=gnmTETo,gnmTMT=gnmTMTo,anL=anLL,bnL=bnLL,\[Theta]=\[Theta]i,M11,M12,M21,M22,X1,X2,Y1,Y2,SumX1,SumX2,Cs,Cis,\[Pi]nmT,\[Tau]nmT},\[Pi]nmT=Table[Table[\[Pi]nm[\[Theta],n,m],{m,0,n}],{n,1,nmax}];\[Tau]nmT=Table[Table[\[Tau]nm[\[Theta],n,m],{m,0,n}],{n,1,nmax}];
M11=Table[Table[I gnmTET[[n]][[n+1+m]] Nn[[n]] \[Tau]nmT[[n]][[Abs[m]+1]],{m,-n,n}],{n,1,nmax}];
M12=Table[Table[m gnmTMT[[n]][[n+1+m]] Nn[[n]] \[Pi]nmT[[n]][[Abs[m]+1]],{m,-n,n}],{n,1,nmax}];M21=Table[Table[gnmTMT[[n]][[n+1+m]] Nn[[n]] \[Tau]nmT[[n]][[Abs[m]+1]],{m,-n,n}],{n,1,nmax}];
M22=Table[Table[I m gnmTET[[n]][[n+1+m]] Nn[[n]] \[Pi]nmT[[n]][[Abs[m]+1]],{m,-n,n}],{n,1,nmax}];Y1=Table[Table[M11[[n]][[n+1+m]]+M12[[n]][[n+1+m]],{m,-n,n}],{n,1,nmax}];
Y2=Table[Table[M21[[n]][[n+1+m]]+M22[[n]][[n+1+m]],{m,-n,n}],{n,1,nmax}];X1=Table[Table[anL[[n]] M12[[n]][[n+1+m]]+bnL[[n]] M11[[n]][[n+1+m]],{m,-n,n}],{n,1,nmax}];X2=Table[Table[anL[[n]] M21[[n]][[n+1+m]]+bnL[[n]] M22[[n]][[n+1+m]],{m,-n,n}],{n,1,nmax}];SumX1=Table[\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(np = Max[Abs[m], 1]\), \(npmax\)]\(Conjugate[\(X1[[np]]\)[[np + 1 + m]]]\)\),{m,-nmax,nmax}];
SumX2=Table[\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(np = Max[Abs[m], 1]\), \(npmax\)]\(Conjugate[\(X2[[np]]\)[[np + 1 + m]]]\)\),{m,-nmax,nmax}];
Cs=Re[\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\((
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]\((\(X1[[n]]\)[[n + 1 + m]]\ SumX1[[nmax + 1 + m]] + \(X2[[n]]\)[[n + 1 + m]]\ SumX2[[nmax + 1 + m]])\))\)\)];
Cis=Re[\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\((
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]\((\(Y1[[n]]\)[[n + 1 + m]]\ SumX1[[nmax + 1 + m]] + \(Y2[[n]]\)[[n + 1 + m]]\ SumX2[[nmax + 1 + m]])\))\)\)];
{Cs,Cis}
];

ScatterOA[x00_,y00_,z00_,ss_,anLL_,bnLL_,\[Theta]tmin_,\[Theta]tmax_]:=Module[{x0=x00,y0=y00,z0=-z00,s=ss,anL=anLL,bnL=bnLL,\[Theta]min=\[Theta]tmin,\[Theta]max=\[Theta]tmax,CextG,CscaG,CabsG,CsOA,CisOA,SignalOA,gnmTET,gnmTMT},gnmTET=Table[Table[gnmTEAddT[n,m,s,2z0/s,z0,x0,y0],{m,-n,n}],{n,1,nmax}];gnmTMT=Table[Table[gnmTMAddT[n,m,s,2z0/s,z0,x0,y0],{m,-n,n}],{n,1,nmax}];
CscaG=(4 \[Pi] )/k^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\(Nn[[n]]\ \(
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]
\*FractionBox[\(\(\((n + Abs[m])\)!\)\ \((
\*SuperscriptBox[\(Abs[anL[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnmTMT[[n, \((n + 1)\) + m]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bnL[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnmTET[[n, \((n + 1)\) + m]]]\), \(2\)])\)\), \(\((n - Abs[m])\)!\)]\)\)\);CextG=(4 \[Pi] )/k^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\(Nn[[n]]\ \(
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]
\*FractionBox[\(\(\((n + Abs[m])\)!\)\ Re[anL[[n]]\ 
\*SuperscriptBox[\(Abs[gnmTMT[[n, \((n + 1)\) + m]]]\), \(2\)] + bnL[[n]]\ 
\*SuperscriptBox[\(Abs[gnmTET[[n, \((n + 1)\) + m]]]\), \(2\)]]\), \(\((n - Abs[m])\)!\)]\)\)\);
CabsG=CextG-CscaG;
CsOA=(\[Theta]max-\[Theta]min)/N\[Theta] (2\[Pi])/k^2 Sum[OffAxis\[Theta]i[gnmTET,gnmTMT,anL,bnL,\[Theta]][[1]] Sin[\[Theta]],{\[Theta],\[Theta]min,\[Theta]max,(\[Theta]max-\[Theta]min)/N\[Theta]}];CisOA=(\[Theta]max-\[Theta]min)/N\[Theta] (2\[Pi])/k^2 Sum[OffAxis\[Theta]i[gnmTET,gnmTMT,anL,bnL,\[Theta]][[2]] Sin[\[Theta]],{\[Theta],\[Theta]min,\[Theta]max,(\[Theta]max-\[Theta]min)/N\[Theta]}];
SignalOA=CsOA-CisOA;
{CextG,CscaG,CabsG,CsOA,CisOA,SignalOA}
];


Clear[n,HmmtT,HnmT,\[Pi]nmT,\[Tau]nmT,\[Theta]max,Hnmt,I1N,I2N,I1T,I2T,ScatterOAE,Integrals\[Theta]f]

I1N[n_,np_,m_,\[Theta]f_]:=NIntegrate[(m^2 \[Pi]nm[\[Theta],n,m]\[Pi]nm[\[Theta],np,m]+\[Tau]nm[\[Theta],n,m]\[Tau]nm[\[Theta],np,m])Sin[\[Theta]],{\[Theta],0,\[Theta]f}];
I2N[n_,np_,m_,\[Theta]f_]:=NIntegrate[(\[Pi]nm[\[Theta],n,m]\[Tau]nm[\[Theta],np,m]+\[Tau]nm[\[Theta],n,m]\[Pi]nm[\[Theta],np,m])Sin[\[Theta]],{\[Theta],0,\[Theta]f}];

Integrals\[Theta]f[\[Theta]ff_]:=Module[{\[Theta]f=0.99999\[Theta]ff,\[Pi]nmT,\[Tau]nmT,HmmtT,HnmT,I1Tt,I2Tt,n},
\[Pi]nmT=Table[Table[\[Pi]nm[\[Theta]f,n,m],{m,0,n}],{n,0,nmax+3}];
\[Tau]nmT=Table[Table[\[Tau]nm[\[Theta]f,n,m],{m,0,n}],{n,0,nmax+3}];
HmmtT=RecurrenceTable[{Hmmt[n]==((2n-1)!!)^2 (Cos[\[Theta]f]Sin[\[Theta]f]^(2n)+(2n Hmmt[n-1])/((2n-1)((2n-3)!!)^2)),Hmmt[0]==Cos[\[Theta]f]-1},Hmmt,{n,0,nmax+2}];
HnmT=Table[Table[0,{m,0,nmax+3}],{n,1,nmax+3}];
For[m=0,m<=nmax,m++,
HnmT[[m+1,m+1]]=HmmtT[[m+1]];
For[n=m,n<=nmax,n++,HnmT[[n+2,m+1]]=(1/(n-m+1) ((n+m+1)HnmT[[n+1,m+1]]+Sin[\[Theta]f]^2 (Cos[\[Theta]f]((n+m+1)(\[Pi]nmT[[n+1]][[m+1]])^2+(n-m+1)(\[Pi]nmT[[n+2]][[m+1]])^2)-2(n+1)\[Pi]nmT[[n+1]][[m+1]]\[Pi]nmT[[n+2]][[m+1]])))
]];
I1Tt=Table[Table[Table[If[np==n,-((n(n+1))/(2n+1))HnmT[[n+1,m+1]]+Sin[\[Theta]f]^2 \[Pi]nmT[[n+1]][[m+1]]\[Tau]nmT[[n+1]][[m+1]],(-Sin[\[Theta]f]^2(np(np+1)\[Tau]nmT[[n+1]][[m+1]]\[Pi]nmT[[np+1]][[m+1]]-n(n+1)\[Pi]nmT[[n+1]][[m+1]]\[Tau]nmT[[np+1]][[m+1]]))/(n(n+1)-np(np+1))],{m,0,Min[np,n]}],{np,1,npmax}],{n,1,nmax}];
I2Tt=Table[Table[Table[Sin[\[Theta]f]^2 \[Pi]nmT[[n+1]][[m+1]]\[Pi]nmT[[np+1]][[m+1]],{m,0,Min[np,n]}],{np,1,npmax}],{n,1,nmax}];
{I1Tt,I2Tt,HmmtT,HnmT,\[Pi]nmT,\[Tau]nmT}
];

ScatterOAE[x00_,y00_,z00_,ss_,anLL_,bnLL_]:=Module[{x0=x00,y0=y00,z0=-z00,s=ss,anL=anLL,bnL=bnLL,CextG,CscaG,CabsG,CscaOA,CextOA,SignalOA,gnmTET,gnmTMT},
gnmTET=Table[Table[gnmTEAddT[n,m,s,2z0/s,z0,x0,y0],{m,-n,n}],{n,1,nmax+2}];gnmTMT=Table[Table[gnmTMAddT[n,m,s,2z0/s,z0,x0,y0],{m,-n,n}],{n,1,nmax+2}];
CscaG=(4 \[Pi] )/k^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\(Nn[[n]]\ \(
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]
\*FractionBox[\(\(\((n + Abs[m])\)!\)\ \((
\*SuperscriptBox[\(Abs[anL[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnmTMT[[n, \((n + 1)\) + m]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bnL[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnmTET[[n, \((n + 1)\) + m]]]\), \(2\)])\)\), \(\((n - Abs[m])\)!\)]\)\)\);CextG=(4 \[Pi] )/k^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\(Nn[[n]]\ \(
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]
\*FractionBox[\(\(\((n + Abs[m])\)!\)\ Re[anL[[n]]\ 
\*SuperscriptBox[\(Abs[gnmTMT[[n, \((n + 1)\) + m]]]\), \(2\)] + bnL[[n]]\ 
\*SuperscriptBox[\(Abs[gnmTET[[n, \((n + 1)\) + m]]]\), \(2\)]]\), \(\((n - Abs[m])\)!\)]\)\)\);
CabsG=CextG-CscaG;
CscaOA=Re[Sum[Nn[[n]]Nn[[np]]((anL[[n]]Conjugate[anL[[np]]]gnmTMT[[n,(n+1)+m]]Conjugate[gnmTMT[[np,(np+1)+m]]]+bnL[[n]]Conjugate[bnL[[np]]]gnmTET[[n,(n+1)+m]]Conjugate[gnmTET[[np,(np+1)+m]]])*I1T[[n,np,Abs[m]+1]]+I m(-anL[[n]]Conjugate[bnL[[np]]]gnmTMT[[n,(n+1)+m]]Conjugate[gnmTET[[np,(np+1)+m]]]+bnL[[n]]Conjugate[anL[[np]]]gnmTET[[n,(n+1)+m]]Conjugate[gnmTMT[[np,(np+1)+m]]])*I2T[[n,np,Abs[m]+1]]),{n,1,nmax},{m,-n,n},{np,Max[Abs[m],1],1}]];
CextOA=Re[Sum[Nn[[n]]Nn[[np]]((Conjugate[anL[[np]]]gnmTMT[[n,(n+1)+m]]Conjugate[gnmTMT[[np,(np+1)+m]]]+Conjugate[bnL[[np]]]gnmTET[[n,(n+1)+m]]Conjugate[gnmTET[[np,(np+1)+m]]])*I1T[[n,np,Abs[m]+1]]+I m(-Conjugate[bnL[[np]]]gnmTMT[[n,(n+1)+m]]Conjugate[gnmTET[[np,(np+1)+m]]]+Conjugate[anL[[np]]]gnmTET[[n,(n+1)+m]]Conjugate[gnmTMT[[np,(np+1)+m]]])*I2T[[n,np,Abs[m]+1]]),{n,1,nmax},{m,-n,n},{np,Max[Abs[m],1],1}]];
SignalOA=CscaOA-CextOA;
{CextG,CscaG,CabsG,(2\[Pi])/k^2 CscaOA,(2\[Pi])/k^2 CextOA,(2\[Pi])/k^2 SignalOA}
];

(*\[Theta]f=0.5;Test=Integrals\[Theta]f[\[Theta]f];I1T=Test[[1]];I2T=Test[[2]];
{{I1N[3,2,1,\[Theta]f],I1T[[3,2,2]]},{I1N[4,4,2,\[Theta]f],I1T[[4,4,3]]},{I1N[1,2,1,\[Theta]f],I1T[[1,2,2]]}}
{{I2N[3,2,1,\[Theta]f],I2T[[3,2,2]]},{I2N[4,4,2,\[Theta]f],I2T[[4,4,3]]},{I2N[1,2,1,\[Theta]f],I2T[[1,2,2]]}}*)


Clear[Ax,P0,PR,PI,PSx];
ScatterOARayleigh[x00_,y00_,z00_,ss_,\[Alpha]\[Alpha]_]:=Module[{x0=x00,y0=y00,z0=-z00,s=ss,\[Alpha]=\[Alpha]\[Alpha],Ax,CextOA,CscaOA,SignalOA,gnmTET,gnmTMT,Cabs},
(*gnmTET=Table[Table[gnmTE[n,m,jmax,s,z0,x0,y0],{m,-n,n}],{n,1,nmax+2}];
gnmTMT=Table[Table[gnmTM[n,m,jmax,s,z0,x0,y0],{m,-n,n}],{n,1,nmax+2}];*)
gnmTET=Table[Table[gnmTEAddT[n,m,s,2z0/s,z0,x0,0],{m,-n,n}],{n,1,nmax+2}];
gnmTMT=Table[Table[gnmTMAddT[n,m,s,2z0/s,z0,x0,0],{m,-n,n}],{n,1,nmax+2}];
Ax=Sum[(Nn[[n]]/2)(gnmTMT[[n,(n+1)+m]]Conjugate[gnmTMT[[1,2+m]]]I1T[[n,1,Abs[m]+1]]+I m gnmTET[[n,(n+1)+m]]Conjugate[gnmTMT[[1,2+m]]]I2T[[n,1,Abs[m]+1]]),{n,1,nmax},{m,-1,1}];
CextOA=-k (Re[Ax]Im[\[Alpha]]-Im[Ax]Re[\[Alpha]]);
CscaOA=(k^4 Abs[\[Alpha]]^2/(8\[Pi]))Sum[Abs[gnmTMT[[1,2+m]]]^2 I1T[[1,1,Abs[m]+1]],{m,-1,1}];
Cabs=-k Im[\[Alpha]](2Abs[gnmTMT[[1,1]]]^2+2Abs[gnmTMT[[1,3]]]^2+Abs[gnmTMT[[1,2]]]^2);
SignalOA=CscaOA-CextOA;
{SignalOA,CscaOA,CextOA,Re[Ax],Im[Ax],Cabs}
];


Q[n_,s_,\[Gamma]_]:=1/(1-I s \[Gamma]);
gnMLA[n_,s_,\[Gamma]_]:=E^(-((I \[Gamma])/(2 s))) Q[n,s,\[Gamma]] E^((n-1) (n+2) s^2 (-Q[n,s,\[Gamma]])); (*MLA: modified local approximation, more accurate than LA, rigorously justified*)
gnLA[n_,s_,\[Gamma]_]:=E^(-((I \[Gamma])/(2 s))) Q[n,s,\[Gamma]] E^((n+1/2) (n+1/2) s^2 (-Q[n,s,\[Gamma]])); (*LA: local approximation, less accurate, motivated via Barton et al.'s work*)



Clear[x0,z0,y0,Xm,Xp,a,Rnm];eps=0.000000001;(*test parameters for table check*)

(*functions for gaussian off-axis BSCs*)
Xm[x0_,y0_]:=x0-I y0+eps;Xp[x0_,y0_]:=x0+I y0+eps;
a[n_,z0_,s_]:=((n+1/2)s)/(1+2 I z0);(*a[n_,z0_,s_]:=((n-1)(n+2)s)/(1+2 I z0);*)
Rnm[n_,m_]:=If[m==0,(2n(n+1))/(2n+1),(2/(2n+1))^(Abs[m]-1)];
F0nTM[n_,m_,jmax_,s_,z0_,x0_,y0_]:=If[m==0,2 x0 Sum[a[n,z0,s]^(2j+1) (Xm[x0,y0]^j Xp[x0,y0]^j)/(j!(j+1)!),{j,0,jmax}],If[m>0,a[n,z0,s]^(m-1) Xm[x0,y0]^(m-1)/(m-1)!+Sum[a[n,z0,s]^(2j-m+1) (Xp[x0,y0]^(j-m) Xm[x0,y0]^j)/((j-m)!j!) (Xp[x0,y0]/(j-m+1)+Xm[x0,y0]/(j+1)),{j,m,jmax}],a[n,z0,s]^(Abs[m]-1) Xp[x0,y0]^(Abs[m]-1)/(Abs[m]-1)!+Sum[a[n,z0,s]^(2j-Abs[m]+1) (Xp[x0,y0]^j Xm[x0,y0]^(j-Abs[m]))/(j!(j-Abs[m])!) (Xm[x0,y0]/(j-Abs[m]+1)+Xp[x0,y0]/(j+1)),{j,Abs[m],jmax}]]];
gnmTM[n_,m_,jmax_,s_,z0_,x0_,y0_]:=1/(2(1+2 I z0)) Exp[(I z0)/s^2-(x0^2+y0^2)/(1+2 I z0)]Exp[-(n+1/2)^2/(1+2 I z0) s^2]Rnm[n,m] (-I)^Abs[m] I F0nTM[n,m,jmax,s,z0,x0,y0];
F0nTE[n_,m_,jmax_,s_,z0_,x0_,y0_]:=If[m==0,2 I y0 Sum[a[n,z0,s]^(2j+1) (Xm[x0,y0]^j Xp[x0,y0]^j)/(j!(j+1)!),{j,0,jmax}],If[m>0,a[n,z0,s]^(m-1) Xm[x0,y0]^(m-1)/(m-1)!+Sum[a[n,z0,s]^(2j-m+1) (Xp[x0,y0]^(j-m) Xm[x0,y0]^j)/((j-m)!j!) (Xp[x0,y0]/(j-m+1)-Xm[x0,y0]/(j+1)),{j,m,jmax}],-(a[n,z0,s]^(Abs[m]-1) Xp[x0,y0]^(Abs[m]-1)/(Abs[m]-1)!+Sum[a[n,z0,s]^(2j-Abs[m]+1) (Xp[x0,y0]^j Xm[x0,y0]^(j-Abs[m]))/(j!(j-Abs[m])!) (Xm[x0,y0]/(j-Abs[m]+1)-Xp[x0,y0]/(j+1)),{j,Abs[m],jmax}])]];
gnmTE[n_,m_,jmax_,s_,z0_,x0_,y0_]:=1/(2(1+2 I z0)) Exp[(I z0)/s^2-(x0^2+y0^2)/(1+2 I z0)]Exp[-(n+1/2)^2/(1+2 I z0) s^2]Rnm[n,m] (-I)^Abs[m] F0nTE[n,m,jmax,s,z0,x0,y0];


Qb[n_,s_,\[Gamma]_]:=1/(I-s \[Gamma]);\[Rho]n[n_,s_]:=(n+0.5)s;\[Rho]0[x0_,y0_]:=Sqrt[x0^2+y0^2];eps=0.000000001;
Knm[n_,m_]:=If[m==0,n (n+1)/(n+0.5),(-I)^Abs[m] I/(n+0.5)^(Abs[m]-1)];
gnmTMAddT[n_,m_,s_,\[Gamma]_,z0_,x0_,y0_]:=Knm[n,m](I Qb[n,s,\[Gamma]]Exp[-I Qb[n,s,\[Gamma]](\[Rho]0[x0,y0]^2+\[Rho]n[n,s]^2)]) Exp[I \[Gamma]/(2s)]/2 ((Exp[I(m-1)\[Phi]]BesselJ[m-1,2Qb[n,s,\[Gamma]]\[Rho]0[x0,y0]\[Rho]n[n,s]]+Exp[I(m+1)\[Phi]]BesselJ[m+1,2Qb[n,s,\[Gamma]]\[Rho]0[x0,y0]\[Rho]n[n,s]])/.{\[Phi]->ArcTan[y0+eps,x0+eps]});
gnmTEAddT[n_,m_,s_,\[Gamma]_,z0_,x0_,y0_]:=I^-1 Knm[n,m](I Qb[n,s,\[Gamma]]Exp[-I Qb[n,s,\[Gamma]](\[Rho]0[x0,y0]^2+\[Rho]n[n,s]^2)]) Exp[I \[Gamma]/(2s)]/2 ((Exp[I(m-1)\[Phi]]BesselJ[m-1,2Qb[n,s,\[Gamma]]\[Rho]0[x0,y0]\[Rho]n[n,s]]-Exp[I(m+1)\[Phi]]BesselJ[m+1,2Qb[n,s,\[Gamma]]\[Rho]0[x0,y0]\[Rho]n[n,s]])/.{\[Phi]->ArcTan[y0+eps,x0+eps]});


(*Correct Pnm*)
PnmCos[n_,m_,Cos\[Theta]_]:=-Sqrt[(4\[Pi])/(2n+1) (n+m)!/(n-m)!]SphericalHarmonicY[n,m,ArcCos[Cos\[Theta]],0]; (*\!\(
\*SubsuperscriptBox[\(P\), \(n\), \(m\)] \((cos \((\[Alpha])\))\)\):  \!\(
\*SubsuperscriptBox[\(P\), \(n\), \(1\)] \((cos \((\[Alpha])\))\)\)= Sin[\[Alpha]]Subscript[\[CapitalPi], n](\[Alpha])*)
(*Derivative Relations*)
PnmpCos[Cos\[Alpha]_,n_,m_]:=-((1+n) Cos\[Alpha] PnmCos[n,m,Cos\[Alpha]]+(-1+m-n) PnmCos[1+n,m,Cos\[Alpha]])/Sqrt[1-Cos\[Alpha]^2]; (*-sin(\[Alpha])*\!\(
\*SubsuperscriptBox[\(P\), \(n\), \(m\)]'\)(cos(\[Alpha])) = Subscript[\[Tau], n](\[Alpha])*)
BesselJPrime[m_,x_]:=(BesselJ[m-1,x]-BesselJ[m+1,x])/2;
ep=10^-10;N\[Alpha]=5000;

(*Normalization Factor and Precision Goal for numerical Integraion*)
PrecGoal=12;WorkingP=20;

(*Fresnel Coefficients, for aberration*)
c\[Alpha]2[\[Alpha]1_,n1_,n2_]:=Sqrt[1-(n1/n2)^2 Sin[\[Alpha]1]^2];ts[\[Alpha]1_,n1_,n2_]:=2(1+n2/n1 c\[Alpha]2[\[Alpha]1,n1,n2]/Cos[\[Alpha]1])^-1;tp[\[Alpha]1_,n1_,n2_]:=2(n2/n1+c\[Alpha]2[\[Alpha]1,n1,n2]/Cos[\[Alpha]1])^-1;

(*Define Integrals InmTM and InmTE*)
IntTM[n_,m_,\[Alpha]Max_,f_,\[Omega]a_,k0_,n1_,n2_,d_,ds_,\[Rho]0_,x0_,y0_,z0_]:=NIntegrate[Sqrt[Cos[\[Alpha]1]]Exp[-f^2Sin[\[Alpha]1]^2/\[Omega]a^2]Exp[-I k0 (n2 z0 c\[Alpha]2[\[Alpha]1,n1,n2]+d(n1 Cos[\[Alpha]1]-n2 c\[Alpha]2[\[Alpha]1,n1,n2]))]Exp[I k0 ds n1 Cos[\[Alpha]1]](m^2 ts[\[Alpha]1,n1,n2] BesselJ[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]/(k0 n1 \[Rho]0 Sin[\[Alpha]1]) PnmCos[n,m,c\[Alpha]2[\[Alpha]1,n1,n2]]+tp[\[Alpha]1,n1,n2]Sqrt[1-c\[Alpha]2[\[Alpha]1,n1,n2]^2]BesselJPrime[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]PnmpCos[c\[Alpha]2[\[Alpha]1,n1,n2],n,m]) x0/\[Rho]0+I m y0/\[Rho]0 (ts[\[Alpha]1,n1,n2] BesselJPrime[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]PnmCos[n,m,c\[Alpha]2[\[Alpha]1,n1,n2]]+tp[\[Alpha]1,n1,n2]Sqrt[1-c\[Alpha]2[\[Alpha]1,n1,n2]^2] BesselJ[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]/(k0 n1 \[Rho]0 Sin[\[Alpha]1]) PnmpCos[c\[Alpha]2[\[Alpha]1,n1,n2],n,m]),{\[Alpha]1,0,\[Alpha]Max},PrecisionGoal->PrecGoal];

IntTE[n_,m_,\[Alpha]Max_,f_,\[Omega]a_,k0_,n1_,n2_,d_,ds_,\[Rho]0_,x0_,y0_,z0_]:=NIntegrate[Sqrt[Cos[\[Alpha]1]]Exp[-f^2Sin[\[Alpha]1]^2/\[Omega]a^2]Exp[-I k0 (n2 z0 c\[Alpha]2[\[Alpha]1,n1,n2]+d(n1 Cos[\[Alpha]1]-n2 c\[Alpha]2[\[Alpha]1,n1,n2]))]Exp[I k0 ds n1 Cos[\[Alpha]1]](m^2 tp[\[Alpha]1,n1,n2] BesselJ[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]/(k0 n1 \[Rho]0 Sin[\[Alpha]1]) PnmCos[n,m,c\[Alpha]2[\[Alpha]1,n1,n2]]+ts[\[Alpha]1,n1,n2]Sqrt[1-c\[Alpha]2[\[Alpha]1,n1,n2]^2]BesselJPrime[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]PnmpCos[c\[Alpha]2[\[Alpha]1,n1,n2],n,m]) y0/\[Rho]0-I m x0/\[Rho]0 (tp[\[Alpha]1,n1,n2] BesselJPrime[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]PnmCos[n,m,c\[Alpha]2[\[Alpha]1,n1,n2]]+ts[\[Alpha]1,n1,n2]Sqrt[1-c\[Alpha]2[\[Alpha]1,n1,n2]^2] BesselJ[m,k0 n1 \[Rho]0 Sin[\[Alpha]1]]/(k0 n1 \[Rho]0 Sin[\[Alpha]1]) PnmpCos[c\[Alpha]2[\[Alpha]1,n1,n2],n,m]),{\[Alpha]1,0,\[Alpha]Max},PrecisionGoal->PrecGoal];

(*Gousebet's Coefficients gn from Neves Coefficients GnTM, eqn .5*)
gnTME[n_,\[Alpha]Max_,f_,\[Omega]a_,k0_,n1_,n2_,d_,ds_,z0_]:=(-1)^n/(n(n+1)) Sqrt[n2]/n1 n2  k0 f Exp[-I n1 k0 f ](\[Alpha]Max/N\[Alpha])Sum[Sqrt[Cos[\[Alpha]1]]Exp[-f^2Sin[\[Alpha]1]^2/\[Omega]a^2]Exp[-I k0 (n2 z0 c\[Alpha]2[\[Alpha]1,n1,n2]+d(n1 Cos[\[Alpha]1]-n2 c\[Alpha]2[\[Alpha]1,n1,n2]))]Exp[I k0 ds n1 Cos[\[Alpha]1]](ts[\[Alpha]1,n1,n2]PnmCos[n,1,c\[Alpha]2[\[Alpha]1,n1,n2]]+tp[\[Alpha]1,n1,n2]Sqrt[1-c\[Alpha]2[\[Alpha]1,n1,n2]^2]PnmpCos[c\[Alpha]2[\[Alpha]1,n1,n2],n,1]),{\[Alpha]1,0.01,\[Alpha]Max,\[Alpha]Max/N\[Alpha]}];

(*Gousebet's Coefficients gnm from Neves Coefficients Gnm*)
gnmExTMpm[n_,m_,NA_,n1_,n2_,d_,ds_,f_,\[Omega]0_,\[Lambda]_,x0_,y0_,z0_] :=IntTM[n,m,ArcSin[NA/n1],f,\[Omega]0,(2\[Pi])/\[Lambda],n1,n2,d,ds,Sqrt[(x0+ep)^2+(y0+ep)^2],x0+ep,y0+ep,z0+ep](-1)^n (n-m)!/(n+m)! Sqrt[n2]/n1 n2 (2\[Pi])/\[Lambda] f Exp[-I n1 (2\[Pi])/\[Lambda] f] I^-m Exp[-I m ArcTan[x0+ep,y0+ep]];
gnmExTEpm[n_,m_,NA_,n1_,n2_,d_,ds_,f_,\[Omega]0_,\[Lambda]_,x0_,y0_,z0_] :=IntTE[n,m,ArcSin[NA/n1],f,\[Omega]0,(2\[Pi])/\[Lambda],n1,n2,d,ds,Sqrt[(x0+ep)^2+(y0+ep)^2],x0+ep,y0+ep,z0+ep](-1)^n (n-m)!/(n+m)! Sqrt[n2]/n1 n2 (2\[Pi])/\[Lambda] f Exp[-I n1 (2\[Pi])/\[Lambda] f] I^-m Exp[-I m ArcTan[x0+ep,y0+ep]];

(*use general property of gnms*)
gnmExTM[n_,m_,NA_,n1_,n2_,d_,ds_,f_,\[Omega]0_,\[Lambda]_,x0_,y0_,z0_]:=If[m>=0,gnmExTMpm[n,m,NA,n1,n2,d,ds,f,\[Omega]0,\[Lambda],x0,y0,z0],(-1)^(n+1) Conjugate[gnmExTMpm[n,-m,NA,n1,n2,d,ds,f,\[Omega]0,\[Lambda],x0,y0,z0]]];
gnmExTE[n_,m_,NA_,n1_,n2_,d_,ds_,f_,\[Omega]0_,\[Lambda]_,x0_,y0_,z0_]:=If[m>=0,gnmExTEpm[n,m,NA,n1,n2,d,ds,f,\[Omega]0,\[Lambda],x0,y0,z0],(-1)^(n+1) Conjugate[gnmExTEpm[n,-m,NA,n1,n2,d,ds,f,\[Omega]0,\[Lambda],x0,y0,z0]]];

(*Test Calculation...*)
n=3; m=1;NA=1.4;f=1.8*10^6;wa=1.8*10^6;n1=1.525;n2=1.46;d=0;ds=0;\[Lambda]=532;k0=2\[Pi]/\[Lambda];

{n,m,NA,n1,n2,d,ds,f,wa,\[Lambda],0.1,0.1,1}
gnmExTM[n,m,NA,n1,n2,d,ds,f,wa,\[Lambda],100,100,0]
gnmExTE[n,m,NA,n1,n2,d,ds,f,wa,\[Lambda],100,100,0]


CprG[x00_,y00_,z00_,ss_,\[Lambda]\[Lambda]_,DoXYY_,Exactt_,RR_]:=Module[{z0=z00,x0=x00,y0=y00,s=ss,\[Lambda]=\[Lambda]\[Lambda],DoXY=DoXYY,Exact=Exactt,R=RR,gnmTMT,gnmTET,Unmp,Vnmp,Snmp,Tnmp,Corr,Cxy,CprGx,CprGy,CprGz,CprGzMLA,CscaG,CextG,CabsG,unit,start,Timegnm,TimePressure,TimeTotalCS,k,gnMLAT},

(*Initialize*)
{CextG=0,CscaG=0,CabsG=0,CprGx=0,CprGy=0,CprGz=0,CprGzMLA=0};
If[Exact==1,unit=nm,unit=nm];
k=nmed 2\[Pi]/(\[Lambda] unit); (*wave vector*)

(*Generate Table of Mie Coeff. an and bn*)
start=SessionTime[];
anL=Table[aMie[n,k (R unit),nParticle/nmed],{n,1,nmax+2}];
bnL=Table[bMie[n,k (R unit),nParticle/nmed],{n,1,nmax+2}];
Timeanbn= SessionTime[]-start;

(*Get Gaussian or Exact BSCs (beam shape coefficients)*)
start=SessionTime[];
If[Exact==0,{gnmTMT=Table[Table[gnmTMAddT[n,m,s,2z0/s,z0,x0,y0],{m,-n,n}],{n,1,nmax+2}],gnmTET=Table[Table[gnmTEAddT[n,m,s,2z0/s,z0,x0,y0],{m,-n,n}],{n,1,nmax+2}]},{gnmTMT=Table[Table[gnmExTM[n,m,NA,n1,n2,d,ds,f,wa,\[Lambda],x0,y0,z0],{m,-n,n}],{n,1,nmax+2}],gnmTET=Table[Table[gnmExTE[n,m,NA,n1,n2,d,ds,f,wa,\[Lambda],x0,y0,z0],{m,-n,n}],{n,1,nmax+2}]}];
gnMLAT=Table[gnMLA[n,s,2 z0/s],{n,1,nmax+2}];
Timegnm= SessionTime[]-start;

(*Get auxillary Matrix-elements for Pressure Computations n>=Abs[p]&&m>=Abs[p+1]*)
start=SessionTime[];
If[DoXY==1,{Unmp=Table[Table[Table[If[n>=Abs[p]&&m>=Abs[p+1],Conjugate[bnL[[m]]] Conjugate[gnmTET[[m,(m+1)+p+1]]] bnL[[n]] gnmTET[[n,(n+1)+p]]+Conjugate[anL[[m]]] Conjugate[gnmTMT[[m,(m+1)+p+1]]] anL[[n]] gnmTMT[[n,(n+1)+p]],10^2000],{n,1,nmax}],{m,1,nmax}],{p,-nmax,nmax}],Vnmp=Table[Table[Table[If[n>=Abs[p]&&m>=Abs[p+1],I bnL[[n]] Conjugate[anL[[m]]] gnmTET[[n,(n+1)+p]] Conjugate[gnmTMT[[m,(m+1)+p+1]]]-I anL[[n]] Conjugate[bnL[[m]]] gnmTMT[[n,(n+1)+p]] Conjugate[gnmTET[[m,(m+1)+p+1]]],10^2000],{n,1,nmax}],{m,1,nmax}],{p,-nmax,nmax}],Snmp=Table[Table[Table[If[n>=Abs[p]&&m>=Abs[p+1],(Conjugate[bnL[[m]]]+bnL[[n]]) Conjugate[gnmTET[[m,(m+1)+p+1]]] gnmTET[[n,(n+1)+p]]+(Conjugate[anL[[m]]]+anL[[n]]) Conjugate[gnmTMT[[m,(m+1)+p+1]]] gnmTMT[[n,(n+1)+p]],10^2000],{n,1,nmax}],{m,1,nmax}],{p,-nmax,nmax}],Tnmp=Table[Table[Table[If[n>=Abs[p]&&m>=Abs[p+1],I (Conjugate[anL[[m]]]+bnL[[n]]) gnmTET[[n,(n+1)+p]] Conjugate[gnmTMT[[m,(m+1)+p+1]]]-I (Conjugate[bnL[[m]]]+anL[[n]]) gnmTMT[[n,(n+1)+p]] Conjugate[gnmTET[[m,(m+1)+p+1]]],10^2000],{n,1,nmax}],{m,1,nmax}],{p,-nmax,nmax}]}];

(*Get Radiation Pressure Cross-sections, F=Cpr/c*)
Corr=nmax+1;If[DoXY==0,CprGz=(\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\((
\*UnderoverscriptBox[\(\[Sum]\), \(p = \(-n\)\), \(n\)]\((
\*FractionBox[\(1\), \(
\*SuperscriptBox[\((n + 1)\), \(2\)]\ \(\((n - Abs[p])\)!\)\)] \(\(\((n + Abs[p] + 1)\)!\)\ Re[\((\(-2\)\ bnL[[n]]\ Conjugate[bnL[[n + 1]]] + Conjugate[bnL[[n + 1]]] + bnL[[n]])\)\ Conjugate[gnmTET[[n + 1, \((n + 1 + 1)\) + p]]]\ gnmTET[[n, \((n + 1)\) + p]] + \((\(-2\)\ anL[[n]]\ Conjugate[anL[[n + 1]]] + Conjugate[anL[[n + 1]]] + anL[[n]])\)\ Conjugate[gnmTMT[[n + 1, \((n + 1 + 1)\) + p]]]\ gnmTMT[[n, \((n + 1)\) + p]]]\) + 
\*FractionBox[\(1\), \(\((
\*SuperscriptBox[\(n\), \(2\)]\ 
\*SuperscriptBox[\((n + 1)\), \(2\)])\)\ \(\((n - Abs[p])\)!\)\)] \(\((2\ n + 1)\)\ p\ \(\((n + Abs[p])\)!\)\ Re[I\ \((2\ anL[[n]]\ Conjugate[bnL[[n]]] - Conjugate[bnL[[n]]] - anL[[n]])\)\ gnmTMT[[n, \((n + 1)\) + p]]\ Conjugate[gnmTET[[n, \((n + 1)\) + p]]]]\))\))\)\)) (4\[Pi])/k^2];
If[DoXY==0&&Exact==0,CprGzMLA=(\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\((
\*FractionBox[\(2  n + 1\), \(n \((n + 1)\)\)] 
\*SuperscriptBox[\(Abs[gnMLAT[[n]]]\), \(2\)] Re[anL[[n]] + bnL[[n]] - 2  anL[[n]] Conjugate[bnL[[n]]]] + 
\*FractionBox[\(n \((n + 2)\)\), \(n + 1\)] Re[gnMLAT[[n]] Conjugate[gnMLAT[[n + 1]]] \((anL[[n]] + bnL[[n]] + Conjugate[anL[[n + 1]]] + Conjugate[bnL[[n + 1]]] - 2  Conjugate[anL[[n + 1]]] anL[[n]] - 2  Conjugate[bnL[[n + 1]]] bnL[[n]])\)])\)\)) (2\[Pi])/k^2];
If[DoXY==1,{Cxy=\!\(
\*UnderoverscriptBox[\(\[Sum]\), \(p = 1\), \(nmax\)]\((
\*UnderoverscriptBox[\(\[Sum]\), \(n = p\), \(nmax\)]\((
\*UnderoverscriptBox[\(\[Sum]\), \(m = Max[p - 1, 1]\), \(nmax\)]
\*FractionBox[\(\((n + p)\)!\), \(\((n - p)\)!\)] \((\((
\*FractionBox[\(KroneckerDelta[m, n + 1]\), 
SuperscriptBox[\(m\), \(2\)]] - 
\*FractionBox[\(KroneckerDelta[n, m + 1]\), 
SuperscriptBox[\(n\), \(2\)]])\)\ \((Snmp[[Corr + p - 1, n, m]] + Snmp[[Corr - p, m, n]] - 2\ Unmp[[Corr + p - 1, n, m]] - 2\ Unmp[[Corr - p, m, n]])\) + 
\*FractionBox[\((2\ n + 1)\), \(
\*SuperscriptBox[\(n\), \(2\)] 
\*SuperscriptBox[\((n + 1)\), \(2\)]\)]\ KroneckerDelta[m, n]\ \((Tnmp[[Corr + p - 1, n, m]] - Tnmp[[Corr - p, m, n]] - 2\ Vnmp[[Corr + p - 1, n, m]] + 2\ Vnmp[[Corr - p, m, n]])\))\))\))\)\),CprGx=(2\[Pi])/k^2 Re[Cxy],CprGy=(2\[Pi])/k^2 Im[Cxy]}];
TimePressure= SessionTime[]-start;

(*Get Total Cross-Sections: Scattering, Extinction, Absorption*)
start=SessionTime[];
CscaG=(4 \[Pi] )/k^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\(
\*FractionBox[\(2\ n + 1\), \(n\ \((n + 1)\)\)]\ \(
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]
\*FractionBox[\(\(\((n + Abs[m])\)!\)\ \((
\*SuperscriptBox[\(Abs[anL[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnmTMT[[n, \((n + 1)\) + m]]]\), \(2\)] + 
\*SuperscriptBox[\(Abs[bnL[[n]]]\), \(2\)]\ 
\*SuperscriptBox[\(Abs[gnmTET[[n, \((n + 1)\) + m]]]\), \(2\)])\)\), \(\((n - Abs[m])\)!\)]\)\)\);CextG=(4 \[Pi] )/k^2 \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(nmax\)]\(
\*FractionBox[\(2\ n + 1\), \(n\ \((n + 1)\)\)]\ \(
\*UnderoverscriptBox[\(\[Sum]\), \(m = \(-n\)\), \(n\)]
\*FractionBox[\(\(\((n + Abs[m])\)!\)\ Re[anL[[n]]\ 
\*SuperscriptBox[\(Abs[gnmTMT[[n, \((n + 1)\) + m]]]\), \(2\)] + bnL[[n]]\ 
\*SuperscriptBox[\(Abs[gnmTET[[n, \((n + 1)\) + m]]]\), \(2\)]]\), \(\((n - Abs[m])\)!\)]\)\)\);
CabsG=CextG-CscaG;

TimeTotalCS= SessionTime[]-start;
(*OUTPUT*)
{CextG,CscaG,CabsG,CprGx,CprGy,CprGz,Timegnm,TimePressure,TimeTotalCS,CprGzMLA,anL[[1]]}
(*{CextG unit^2,CscaG unit^2,CabsG unit^2,CprGx unit^2,CprGy unit^2,CprGz unit^2,Timegnm,TimePressure,TimeTotalCS,Timeanbn,CprGz unit^2 (MLA)}*)
];



