(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1047960,      21519]
NotebookOptionsPosition[   1043096,      21368]
NotebookOutlinePosition[   1043565,      21386]
CellTagsIndexPosition[   1043522,      21383]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Generalized Mie Theory Mathematica Scripts, \n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Multilayer Scatter-Coefficients, GLMT Cross-sectons, Fields, \
Radiation Pressure, Integrated Signals, Photothermal Signal, Angular \
Intensity Distributions, BSCs (Gauss (On/Off-axis), Exact)",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Implemented by ",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Markus Selmke (selmke@zr.uni-leipzig.de, markus.selmke@gmx.de)\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["If any of this code shall be used, please ",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["cite the appropriate Journal Article",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" reference:",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Nano-lens diffraction around a single heated nano particle\", \
Optics Express, Vol. 20, No. 7, pp. 8055-8070, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", M. Selmke, M. Braun, F. Cichos, (early version: \
arXiv:1109.2772v1)",
  FontSize->12],
 StyleBox["\n",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Photothermal Single Particle Microscopy: Detection of a Nanolens\
\", ACS Nano, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1) ",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.532369726316798*^9, 3.5323698534171743`*^9}, {
  3.532369907370092*^9, 3.532369928118697*^9}, {3.5542022160578613`*^9, 
  3.554202221813991*^9}, {3.554361510430574*^9, 3.5543615517729263`*^9}, {
  3.554361589354903*^9, 3.554361590611668*^9}, {3.554438544205818*^9, 
  3.554438553770154*^9}, {3.554449940391983*^9, 3.554450039986801*^9}, {
  3.5545247185423107`*^9, 3.5545247239240103`*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "PARAMETERS (sphere, beams),",
 StyleBox[" define n/\[Epsilon] of Particle, \[Mu]p=1",
  FontSize->18],
 StyleBox["\nGold : n = (532 nm: 0.5163+2.2304 I, 635 nm:  0.1748+3.4618 I, \
650 nm: 0.1507+3.6077 I, 1064 nm: 0.2574+6.9663 I), Polystyrene : n = \
1.59+0.0002 I\nuse \"+\"-Sign for anything that uses the Multilayer \
coefficients, i.e. the PT signal\nuse \"-\"-Sign convention for all other \
computations, i.e. Near-fields",
  FontSize->12]
}], "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQ3RAXZ+zN/8oxIYzdDERbsD951gakOSLkn4PoOWey
07uAtJZlN5jO8vzX1A2kH5WzNYPotFdpvgpCrxxNvKL8QPSyv581piu+csx7
9VAXRFuw3f4fb/zKUePNWYYEIL1CvJwTRC9f/AFMz9pjlujs88rx+cdaML1t
3vfZXwNeObbMrpoDohNS1u6Sy3/lWHWdaw+Inr5r6mEQLRJ7F0wnCV9ic6h+
5eh09iQHiF71pk0cRBdlxUuB6BsflZRBtGWNJpg+N3WKK4iOSH7oBqJlT+2p
zgDS/xiE6kF0wZJFIZOB9Ifz3aEg+vxt9VgQ7bHDPg5EX9xrdmg7kE47KXMY
RAfcizl0teGV40n+K0dAdMx/3VKZnleO+eHlVSD60uruAPO5rxwPFysHgWgA
hDq0mw==
  "],
 Background->RGBColor[1, 0.85, 0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"NA", "=", "1.2"}], ",", 
    RowBox[{"\[Lambda]", "=", "1.064"}], ",", 
    RowBox[{"w0DL", "=", 
     FractionBox[
      RowBox[{"0.61", "\[Lambda]"}], "NA"]}]}], "}"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Beam", " ", "waist", " ", "corresponding", " ", "to", " ", "Diffraction", 
    " ", "Limited", " ", "Spot", " ", "given", " ", "by", " ", "Microscope", 
    " ", "NA"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["nParticle",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["=",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"0.2574", "-", 
      RowBox[{"6.9663", " ", "I"}]}],
     FontSize->12]}], 
   StyleBox[";",
    FontColor->RGBColor[1, 0, 0]]}], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"particles", " ", "complex", " ", "refractive", " ", "index"}], 
    "*)"}],
   FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"R", "=", "50"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Particles", " ", "radius"}], "*)"}]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"nmed", "=", "1.33"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"mediums", "'"}], " ", "real", " ", "refractive", " ", "index"}],
     "*)"}]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"dndT", "=", 
     RowBox[{
      RowBox[{"-", "3.4"}], "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "4"}]]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"mediums", "'"}], " ", "thermorefractive", " ", "coefficient", 
     " ", 
     RowBox[{"dn", "/", "dT"}]}], "*)"}]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]", "=", "1064"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "probing", " ", "beam", " ", "wavelength", " ", "in", " ", "vacuum"}], 
     ",", " ", 
     RowBox[{"used", " ", "for", " ", "scatteruing", " ", "calculations"}]}], 
    "*)"}]}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Mn", "=", 
    RowBox[{"nParticle", "/", "nmed"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Parameer", " ", "Setup", " ", "for", " ", "GAUSSIAN", " ", "Beam", " ", 
     "Scatter"}], ",", " ", 
    RowBox[{"all", " ", "in", " ", "nm"}]}], "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"w0", "=", "500"}], ";"}],
   FontColor->RGBColor[1, 0, 0]], 
  RowBox[{"(*", 
   RowBox[{"beam", " ", "waist"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"zp", "=", "0"}], ";"}],
   FontColor->RGBColor[1, 0, 0]], 
  RowBox[{"(*", 
   RowBox[{"axial", " ", "particle", " ", "position"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "=", 
    RowBox[{"2", " ", 
     RowBox[{"zp", "/", "w0"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"position", " ", "parameter", " ", "for", " ", "BSCs"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"k", "=", 
    RowBox[{"nmed", "*", "2", 
     RowBox[{"\[Pi]", "/", "\[Lambda]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"wave", "-", 
    RowBox[{"vector", " ", "in", " ", "the", " ", "medium"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"l", "=", 
    RowBox[{"k", " ", 
     SuperscriptBox["w0", "2"]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"spreading", " ", "length"}], ",", " ", 
    RowBox[{
     RowBox[{"determined", " ", "by", " ", "beam"}], "-", 
     RowBox[{"waist", " ", "and", " ", "wave"}], "-", 
     RowBox[{"vector", " ", "k"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"zR", "=", 
    RowBox[{"l", "/", "2"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Rayleigh", " ", "range"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"s", "=", 
    RowBox[{"w0", "/", "l"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"confinement", " ", "factor"}], ",", " ", 
    RowBox[{
     RowBox[{
     "determined", " ", "by", " ", "spreading", " ", "length", " ", "and", 
      " ", "beam"}], "-", "waist"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nmax", "=", "50"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "maximum", " ", "multipole", " ", "order", " ", "for", " ", "non"}], "-", 
    
    RowBox[{"multilayer", " ", "Mie"}], "-", 
    RowBox[{
     RowBox[{"coefficients", ".", " ", "Multilayer"}], " ", "coefs", " ", 
     "use", " ", "computed", " ", "nmax"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"npmax", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"jmax", "=", "10"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "maximum", " ", "order", " ", "for", " ", "BSC", " ", "generation", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Gaussian", " ", "Off"}], "-", 
      RowBox[{"Axis", " ", "only"}]}], ")"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w0G", "=", 
    RowBox[{"N", "[", 
     RowBox[{"w0", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "9"}]]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"w0G", " ", 
    RowBox[{"in", " ", "[", "m", "]"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]div", "=", 
   RowBox[{"2", "/", 
    RowBox[{"(", 
     RowBox[{"k", " ", "w0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"\"\<nMax suggested:\>\"", ",", 
   RowBox[{"nMaxP", "[", 
    RowBox[{"k", " ", "R"}], "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Alpha]", "=", 
     RowBox[{"4", "\[Pi]", " ", 
      SuperscriptBox["R", "3"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Mn", "2"], "-", "1"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Mn", "2"], "+", "2"}], ")"}]}]}]}], ",", 
    RowBox[{"\[Alpha]a1", "=", 
     RowBox[{"6", "\[Pi]", " ", 
      RowBox[{
       RowBox[{"aMie", "[", 
        RowBox[{"1", ",", 
         RowBox[{"k", " ", "R"}], ",", "Mn"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"I", " ", 
         SuperscriptBox["k", "3"]}], ")"}]}]}]}]}], "}"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Parameer", " ", "Setup", " ", "for", " ", "GAUSSIAN", " ", "Heating", 
     " ", "Beam", " ", "illumination"}], ",", " ", 
    RowBox[{"needed", " ", "for", " ", "PT", " ", "signal"}], ",", " ", 
    RowBox[{"all", " ", "in", " ", "nm"}]}], "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["nParticleh",
     FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
    StyleBox["=",
     FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
    StyleBox[
     RowBox[{"0.5163", "+", 
      RowBox[{"2.2304", " ", "I"}]}],
     FontColor->GrayLevel[0]]}], 
   StyleBox[";",
    FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]]}], 
  StyleBox[" ",
   FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"\"\<+\>\"", " ", "sign", " ", "convention"}], ",", " ", 
     RowBox[{
     "since", " ", "only", " ", "used", " ", "for", " ", "PT", " ", 
      "signal"}]}], "*)"}],
   FontColor->RGBColor[
    0., 0.7239795529106584, 0.00006103608758678569]]}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]h", "=", "532"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "heating", " ", "laser", " ", "wavelength", " ", "in", " ", "vacuum"}], 
     ",", " ", 
     RowBox[{"used", " ", "for", " ", "PT", " ", "signal"}]}], "*)"}]}],
  FontColor->RGBColor[
   0., 0.7239795529106584, 0.00006103608758678569]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"w0h", "=", "233"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"heating", " ", "laser", " ", "beam", " ", "waist"}], ",", " ", 
     RowBox[{"used", " ", "for", " ", "PT", " ", "signal"}]}], "*)"}]}],
  FontColor->RGBColor[
   0., 0.7239795529106584, 0.00006103608758678569]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"Ph0", "=", 
     RowBox[{"97", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"heating", " ", "Power"}], ",", " ", 
     RowBox[{"used", " ", "for", " ", "PT", " ", "signal"}]}], "*)"}]}],
  FontColor->RGBColor[
   0., 0.7239795529106584, 0.00006103608758678569]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"dzf", "=", 
     RowBox[{"-", "250"}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "heating", " ", "laser", " ", "offset", " ", "relative", " ", "to", " ", 
     "detection", " ", "laser"}], "*)"}]}],
  FontColor->RGBColor[
   0., 0.7239795529106584, 0.00006103608758678569]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["\[Kappa]med",
     FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
    StyleBox["=",
     FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
    RowBox[{
     StyleBox["0.15",
      FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
     StyleBox["*",
      FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
     SuperscriptBox[
      StyleBox["10",
       FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
      RowBox[{"-", "9"}]]}]}], 
   StyleBox[";",
    FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]]}], 
  StyleBox[" ",
   FontColor->RGBColor[0., 0.7239795529106584, 0.00006103608758678569]], 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"medum", " ", "thermal", " ", 
     RowBox[{"conductivity", " ", "[", 
      RowBox[{"W", "/", "nm"}], "]"}]}], "*)"}],
   FontColor->RGBColor[
    0., 0.7375600823987183, 0.00006103608758678569]]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"cabber", "=", "0.3"}], ";"}],
   FontColor->RGBColor[0., 0.7647058823529411, 0.00006103608758678569]], " ", 
  
  RowBox[{"(*", 
   RowBox[{"Aberration", ",", " ", 
    RowBox[{"compute", " ", "from", " ", "exact", " ", "scattering"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"e", ".", "g", ".", " ", "PSF"}], " ", "Lab"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kh", "=", 
   RowBox[{"nmed", "*", "2", 
    RowBox[{"\[Pi]", "/", "\[Lambda]h"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lh", "=", 
    RowBox[{"kh", " ", 
     SuperscriptBox["w0h", "2"]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"heating", " ", "laser", " ", "spreading", " ", "length"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"zRh", "=", 
    RowBox[{"lh", "/", "2"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"heating", " ", "laser", " ", "Rayleigh"}], "-", "range"}], ",", 
    " ", 
    RowBox[{"used", " ", "for", " ", "PT", " ", "signal"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sh", "=", 
   RowBox[{"w0h", "/", "lh"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nn", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "+", "1"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"n", 
          RowBox[{"(", 
           RowBox[{"n", "+", "1"}], ")"}]}], ")"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "10000"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "parameter", " ", "Setup", " ", "for", " ", "EXACT", " ", "Scatter", " ", 
     "only"}], ",", " ", 
    RowBox[{"all", " ", "in", " ", "nm"}]}], "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"NA", "=", "1.4"}], ";", 
   RowBox[{"f", "=", 
    RowBox[{"1.8", "*", 
     SuperscriptBox["10", "6"]}]}], ";", 
   RowBox[{"wa", "=", 
    RowBox[{"1.8", "*", 
     SuperscriptBox["10", "6"]}]}], ";", 
   RowBox[{"n1", "=", "1.525"}], ";", 
   RowBox[{"n2", "=", "nmed"}], ";", 
   RowBox[{"d", "=", "0"}], ";", 
   RowBox[{"ds", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"OIL", " ", "IMMERSION"}], ",", " ", 
    RowBox[{"100", "x"}], ",", " ", 
    RowBox[{"NA", "=", "1.4"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NA", "=", "1.2"}], ";", 
   RowBox[{"f", "=", 
    RowBox[{"1.8", "*", 
     RowBox[{
      SuperscriptBox["10", "6"], "/", "0.6"}]}]}], ";", 
   RowBox[{"wa", "=", 
    RowBox[{"1.8", "*", 
     RowBox[{
      SuperscriptBox["10", "6"], "/", 
      RowBox[{"(", 
       RowBox[{"0.5", "*", "0.6"}], ")"}]}]}]}], ";", 
   RowBox[{"n1", "=", "1.33"}], ";", 
   RowBox[{"n2", "=", "nmed"}], ";", 
   RowBox[{"d", "=", "0"}], ";", 
   RowBox[{"ds", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"WATER", " ", "IMMERSION"}], ",", " ", 
    RowBox[{"60", "x"}], ",", " ", 
    RowBox[{"NA", "=", "1.2"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dobj", "=", "0.01"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Microscope", " ", "Back"}], "-", 
    RowBox[{"pupil", " ", "diameter"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w0E", "=", 
    RowBox[{"dobj", " ", 
     RowBox[{"n1", "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", "NA"}], ")"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"w0E", " ", 
    RowBox[{"in", " ", "[", "m", "]"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"A", "=", 
    RowBox[{"1", "-", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "2"}], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["f", "wa"], ")"}], "2"], 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"NA", "/", "n1"}], "]"}], "2"]}], "]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Ratio", " ", "of", " ", "power", " ", "transmitted", " ", "through", " ",
      "aperture", " ", "for", " ", "given", " ", "total", " ", "P0"}], ",", 
    RowBox[{"\"\<THEORY OF OPTICAL TWEEZERS\>\"", "\n", 
     RowBox[{"P", ".", "A", ".", " ", "Maia"}], " ", "Neto", " ", "and", " ", 
     
     RowBox[{"H", ".", "M", ".", "Nussenzveig"}]}], ",", " ", "2008"}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "\"\<s:\>\"", ",", "s", ",", "\"\<l:\>\"", ",", "l", ",", "\"\<zR:\>\"", 
   ",", "zR", ",", "\"\<w0G:\>\"", ",", "w0G", ",", "\"\<w0E:\>\"", ",", 
   "w0E"}], "}"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5296454856658278`*^9, 3.529645512704988*^9}, {
   3.529646449981284*^9, 3.529646452489663*^9}, {3.529646482780155*^9, 
   3.529646500728793*^9}, {3.554279646975918*^9, 3.554279689898466*^9}, {
   3.5542797299282*^9, 3.5542798435588827`*^9}, {3.554279902566409*^9, 
   3.55427993277774*^9}, {3.554284062472389*^9, 3.554284062656704*^9}, {
   3.554284118521447*^9, 3.55428413214151*^9}, {3.554284628440864*^9, 
   3.554284628964007*^9}, {3.554284666673428*^9, 3.554284667626693*^9}, {
   3.554284749449007*^9, 3.5542847501537123`*^9}, {3.554284841656938*^9, 
   3.5542848419209433`*^9}, {3.554286283624777*^9, 3.5542862845979548`*^9}, {
   3.554286320621085*^9, 3.5542863247957897`*^9}, {3.554303239357542*^9, 
   3.554303239942223*^9}, {3.55430327873071*^9, 3.554303312386231*^9}, 
   3.554303355634923*^9, {3.554304009860181*^9, 3.554304010073255*^9}, {
   3.5543514856484118`*^9, 3.554351485843555*^9}, {3.5543516919327307`*^9, 
   3.554351727420788*^9}, {3.554351777145666*^9, 3.554351853604267*^9}, 
   3.554351885573118*^9, {3.554352064114031*^9, 3.5543521184569807`*^9}, {
   3.5543522732755013`*^9, 3.554352293646678*^9}, {3.554352430055222*^9, 
   3.554352431926641*^9}, {3.554352581291423*^9, 3.5543526306548862`*^9}, {
   3.55435340327789*^9, 3.554353415816558*^9}, {3.5543534471056957`*^9, 
   3.554353447703061*^9}, {3.5543535534086533`*^9, 3.554353603843014*^9}, {
   3.554355874343204*^9, 3.554355954305307*^9}, {3.554358766659314*^9, 
   3.554358792499885*^9}, {3.554358822505918*^9, 3.554358893870623*^9}, {
   3.55435893987328*^9, 3.554358956834903*^9}, {3.554358993310802*^9, 
   3.554359009927129*^9}, 3.554359494138619*^9, {3.554359606338663*^9, 
   3.554359629177536*^9}, {3.554359936507471*^9, 3.5543599940171013`*^9}, {
   3.5543603745176373`*^9, 3.554360429995254*^9}, {3.554360484667049*^9, 
   3.5543605184893703`*^9}, {3.554361983536346*^9, 3.554362014926927*^9}, {
   3.5544340449238253`*^9, 3.554434045061632*^9}, 3.554435043435918*^9, 
   3.554435095164233*^9, 3.55443518837678*^9, {3.554436492944821*^9, 
   3.554436508458939*^9}, 3.554437020726201*^9, 3.554437832414855*^9, {
   3.554438356702704*^9, 3.554438414383421*^9}, {3.554438447174452*^9, 
   3.5544384932793417`*^9}, 3.554439155363065*^9, {3.554439209463625*^9, 
   3.554439212713313*^9}, 3.554439252605138*^9, 3.5544408188874283`*^9, {
   3.5544411346363907`*^9, 3.5544411395807467`*^9}, {3.554441208089693*^9, 
   3.554441221919217*^9}, {3.554448458888956*^9, 3.554448461472561*^9}, {
   3.5544488718643303`*^9, 3.554448875069447*^9}, {3.554449325003834*^9, 
   3.554449337446822*^9}, {3.5544496262703133`*^9, 3.554449629936014*^9}, 
   3.554450565879469*^9, {3.554450600801302*^9, 3.554450695169188*^9}, {
   3.554451614582117*^9, 3.5544516196615477`*^9}, {3.5544542810857887`*^9, 
   3.5544542936598063`*^9}, {3.554454947541799*^9, 3.55445494946205*^9}, 
   3.55445498016508*^9, {3.5544553635171432`*^9, 3.554455363727631*^9}, {
   3.5544554204589443`*^9, 3.55445542055781*^9}, {3.5544557590687103`*^9, 
   3.554455787335911*^9}, {3.554455878649125*^9, 3.554455878859782*^9}, {
   3.554456077572403*^9, 3.554456077677335*^9}, {3.554456171271215*^9, 
   3.554456196579955*^9}, {3.554505699887403*^9, 3.554505739888062*^9}, {
   3.5545058072133703`*^9, 3.554505810489818*^9}, {3.5545247420124702`*^9, 
   3.554524744257966*^9}, {3.554525560652047*^9, 3.554525572736244*^9}, {
   3.554525607487936*^9, 3.554525722372181*^9}, {3.554525770309565*^9, 
   3.554525770961176*^9}, 3.554525819860455*^9, {3.554525867943954*^9, 
   3.554525896128377*^9}, {3.554657674780677*^9, 3.554657732862335*^9}, {
   3.554657782829817*^9, 3.5546578253461514`*^9}, {3.555064380459509*^9, 
   3.555064405129178*^9}, {3.55517082837355*^9, 3.555170867013522*^9}, {
   3.5552637007664957`*^9, 3.555263710446628*^9}, 3.5566029516431103`*^9, {
   3.5566029934394083`*^9, 3.556602993711307*^9}, {3.556603143032545*^9, 
   3.556603175757465*^9}, {3.55660348213433*^9, 3.5566034954952087`*^9}, {
   3.557043853498581*^9, 3.5570438714881763`*^9}, {3.557043938358293*^9, 
   3.557043979787245*^9}, {3.5572072406647863`*^9, 3.5572072637555227`*^9}, {
   3.5572073673067417`*^9, 3.557207367477507*^9}, 3.557207468504328*^9, 
   3.557207509872075*^9, {3.5572075459632063`*^9, 3.557207549420402*^9}, 
   3.557207766608699*^9, {3.557208676892267*^9, 3.5572086771519337`*^9}, 
   3.557208729508016*^9, {3.557209137218464*^9, 3.5572091375264482`*^9}, {
   3.557209295521617*^9, 3.557209295774086*^9}, {3.557209427881258*^9, 
   3.557209428643345*^9}, {3.5572158953655653`*^9, 3.557215895510167*^9}, 
   3.557391177188794*^9, 3.557394468116074*^9, {3.557394814731659*^9, 
   3.557394815872624*^9}, {3.5573948479693413`*^9, 3.557394915803104*^9}, {
   3.55739828039564*^9, 3.557398299300064*^9}, {3.557555181438892*^9, 
   3.557555216289926*^9}, {3.557589090944612*^9, 3.5575891021888723`*^9}, {
   3.557739455205262*^9, 3.557739474574383*^9}, {3.562753152361466*^9, 
   3.562753164196979*^9}, {3.5627534754293613`*^9, 3.562753476404714*^9}, {
   3.563290938686989*^9, 3.563290966477151*^9}, {3.563291163925726*^9, 
   3.563291164277029*^9}, {3.563292871931758*^9, 3.563292872793358*^9}, {
   3.5632931099554577`*^9, 3.5632931104895973`*^9}, {3.5632933229468946`*^9, 
   3.563293323589686*^9}, {3.563293551414258*^9, 3.563293551771769*^9}, {
   3.563293592323585*^9, 3.5632935924792223`*^9}, {3.563293650690497*^9, 
   3.563293650867436*^9}, {3.5632938334886217`*^9, 3.563293833849929*^9}, 
   3.563620807441983*^9, {3.563620852505664*^9, 3.563620859761146*^9}, {
   3.563621300962695*^9, 3.5636213425001297`*^9}, {3.5636333278964033`*^9, 
   3.5636333388649473`*^9}, {3.564210707494141*^9, 3.564210724510137*^9}, {
   3.5642107567946777`*^9, 3.564210775518321*^9}, {3.5642108277134132`*^9, 
   3.564210842812031*^9}, 3.5642204627464123`*^9, {3.564239913498405*^9, 
   3.564239922232431*^9}, {3.564242639062614*^9, 3.564242639609703*^9}, {
   3.564336399563924*^9, 3.564336424918923*^9}, {3.564336470492753*^9, 
   3.564336475962359*^9}, {3.5643752653158484`*^9, 3.5643752723116283`*^9}, 
   3.5643837594749928`*^9, {3.564420766769711*^9, 3.564420864297297*^9}, {
   3.5644208987559233`*^9, 3.564420901522739*^9}, {3.564459089848997*^9, 
   3.564459094490623*^9}, {3.5644607985762568`*^9, 3.564460798823885*^9}, 
   3.564467418786786*^9, {3.564478331350266*^9, 3.564478331634124*^9}, {
   3.5660347023493443`*^9, 3.5660347322904167`*^9}, {3.56864895888021*^9, 
   3.568649036715929*^9}, 3.5686942441841927`*^9, {3.572012258129704*^9, 
   3.572012280782063*^9}, {3.572014697803028*^9, 3.572014723267932*^9}, {
   3.5720147949959393`*^9, 3.572014795418076*^9}, {3.5720148718418427`*^9, 
   3.572014878762885*^9}, {3.572015919089264*^9, 3.572015919327074*^9}, {
   3.572019010824759*^9, 3.5720190109806957`*^9}, {3.572019522170062*^9, 
   3.572019522382502*^9}, {3.572019667089643*^9, 3.5720196679073257`*^9}, {
   3.572019793826044*^9, 3.5720197969836807`*^9}, 3.572020303593202*^9, {
   3.572020872723712*^9, 3.5720208735940866`*^9}, 3.572067195694106*^9, {
   3.572067328676449*^9, 3.5720673563918447`*^9}, {3.572086254796645*^9, 
   3.572086280251453*^9}, {3.572087423151669*^9, 3.5720874513966303`*^9}, 
   3.5720875128792963`*^9, {3.572087659710589*^9, 3.5720876600229483`*^9}, {
   3.572171653625708*^9, 3.572171653807616*^9}, 3.572171965173826*^9, {
   3.572172020038994*^9, 3.572172020320854*^9}, {3.572172277930676*^9, 
   3.572172278094468*^9}, {3.5721948827697287`*^9, 3.5721948836939993`*^9}, {
   3.572254683428856*^9, 3.5722546916024933`*^9}, 3.572255063411875*^9, {
   3.5722552994168453`*^9, 3.5722552995215597`*^9}, 3.572284251282051*^9, 
   3.572284368812565*^9, 3.5723476362455997`*^9, {3.572347763301929*^9, 
   3.5723477634163733`*^9}, {3.572353433568321*^9, 3.572353449735292*^9}, {
   3.572353834965226*^9, 3.5723538413424263`*^9}, {3.572360387461441*^9, 
   3.572360387646555*^9}, {3.572360499773314*^9, 3.5723605010974827`*^9}, 
   3.572360618666533*^9, {3.5724555674531937`*^9, 3.572455578203644*^9}, {
   3.572784736669827*^9, 3.572784736828024*^9}, {3.5733576184215813`*^9, 
   3.5733576346495132`*^9}, 3.5733605302079163`*^9, {3.576511795505365*^9, 
   3.57651183867328*^9}, 3.5765123283056602`*^9, {3.576512368475257*^9, 
   3.576512369171515*^9}, {3.576512959788766*^9, 3.576512971571611*^9}, {
   3.576513170125449*^9, 3.57651319469925*^9}, {3.576514325102206*^9, 
   3.57651432534776*^9}, 3.576514471709771*^9, {3.576519646309277*^9, 
   3.576519646705707*^9}, 3.576519826145172*^9, {3.576519861280614*^9, 
   3.576519861391665*^9}, 3.5765199887119007`*^9, {3.576524924047323*^9, 
   3.5765249296709747`*^9}, {3.5769906956621523`*^9, 3.57699069841562*^9}, {
   3.5769907770421333`*^9, 3.576990777233392*^9}, 3.5769908229105883`*^9, {
   3.577197997002471*^9, 3.5771980248408422`*^9}, 3.577198416620522*^9, {
   3.5771986054539747`*^9, 3.577198629384385*^9}, {3.5771988147494907`*^9, 
   3.577198818779663*^9}, {3.577199402948633*^9, 3.5771994032177896`*^9}, {
   3.577199621088377*^9, 3.577199622816412*^9}, {3.57720445441348*^9, 
   3.577204455638891*^9}, {3.5772618786903276`*^9, 3.577261884979994*^9}, {
   3.577262012550407*^9, 3.577262017141376*^9}, {3.577342436673818*^9, 
   3.577342440631898*^9}, {3.5773424787637987`*^9, 3.577342494445302*^9}, {
   3.577342836933536*^9, 3.577342837802257*^9}, {3.577716002420075*^9, 
   3.5777160056986856`*^9}, 3.5885800859759073`*^9, {3.588660000525936*^9, 
   3.588660003024253*^9}, {3.590468641187838*^9, 3.5904686413176947`*^9}, {
   3.590469027008505*^9, 3.590469027142658*^9}, {3.590672807390629*^9, 
   3.590672807661147*^9}, {3.590673320624641*^9, 3.5906733216612062`*^9}, 
   3.5906733794833403`*^9, 3.590673458491736*^9, {3.5908128939083*^9, 
   3.590812895242291*^9}, {3.590813081720299*^9, 3.590813141371386*^9}, {
   3.590813189722253*^9, 3.590813204317664*^9}, {3.590901960719121*^9, 
   3.590901985418818*^9}, {3.590902032028593*^9, 3.5909020861274147`*^9}, {
   3.590938825073625*^9, 3.590938834862365*^9}, {3.5909388731345367`*^9, 
   3.5909388754075737`*^9}, {3.590989075661504*^9, 3.590989102837648*^9}, {
   3.5909907173673553`*^9, 3.59099073078082*^9}, {3.591001798437056*^9, 
   3.59100183035296*^9}, {3.591252440102881*^9, 3.591252449115556*^9}, 
   3.591253190419235*^9, 3.591254250383768*^9, {3.59125917285791*^9, 
   3.591259182584313*^9}, {3.591267818780397*^9, 3.5912678190509977`*^9}, {
   3.591329105069935*^9, 3.5913291265606318`*^9}, {3.591329408555616*^9, 
   3.591329412742889*^9}, 3.591352017061092*^9, {3.591352607131988*^9, 
   3.591352608351325*^9}, {3.591411325512383*^9, 3.591411325975376*^9}, {
   3.591508319188511*^9, 3.591508348517243*^9}, {3.591877055059937*^9, 
   3.5918770679112577`*^9}, {3.591953049847546*^9, 3.5919530499900303`*^9}, {
   3.591953170590621*^9, 3.591953171196948*^9}, {3.591953598515942*^9, 
   3.591953598899691*^9}, {3.591953661216752*^9, 3.59195366135603*^9}, {
   3.591953740037198*^9, 3.591953740482635*^9}, {3.5919557786550503`*^9, 
   3.591955790575383*^9}, {3.591958037302422*^9, 3.591958049550064*^9}, {
   3.592052711358171*^9, 3.5920527278568983`*^9}, {3.59211044411473*^9, 
   3.592110445223135*^9}, {3.592110535246703*^9, 3.592110535415738*^9}, {
   3.592651968421295*^9, 3.5926519699515142`*^9}, {3.592655063882073*^9, 
   3.5926551094639072`*^9}, {3.592655174924719*^9, 3.592655175096725*^9}, 
   3.592656034253265*^9, 3.5926572758502703`*^9, {3.592661423054204*^9, 
   3.592661423509076*^9}, {3.592662265911148*^9, 3.5926622667568703`*^9}, {
   3.592675558689036*^9, 3.5926755826215363`*^9}, {3.5926756230718813`*^9, 
   3.592675643462441*^9}, {3.5926759022423553`*^9, 3.5926759371471977`*^9}, {
   3.592714681343424*^9, 3.592714692935279*^9}, {3.592714728527231*^9, 
   3.59271472878467*^9}, {3.592717938437071*^9, 3.5927179406066427`*^9}, {
   3.592718011608807*^9, 3.592718019748331*^9}, {3.5927183695540257`*^9, 
   3.592718390435588*^9}, {3.59272553103372*^9, 3.592725531263481*^9}, {
   3.592730204831888*^9, 3.592730204960243*^9}, {3.592733912820204*^9, 
   3.592733912944914*^9}, {3.592733978438511*^9, 3.592734001378038*^9}, {
   3.592748585244712*^9, 3.592748585384967*^9}, {3.592793793292241*^9, 
   3.592793793716313*^9}, {3.5927938942975073`*^9, 3.592793894814842*^9}, {
   3.5927940081818123`*^9, 3.592794042652364*^9}, {3.592794271184732*^9, 
   3.59279427151346*^9}, {3.592819543326004*^9, 3.5928195437082863`*^9}, {
   3.592820121774054*^9, 3.592820122129673*^9}, {3.592821394862158*^9, 
   3.592821396054227*^9}, {3.592822243502253*^9, 3.5928222439185047`*^9}, {
   3.592892067416306*^9, 3.592892082562652*^9}, {3.5928921419290733`*^9, 
   3.592892169669146*^9}, {3.5928922037668247`*^9, 3.592892210370002*^9}, {
   3.592892460207048*^9, 3.59289249282347*^9}, 3.592892550124242*^9, {
   3.59289269807721*^9, 3.592892698531495*^9}, {3.5929029173952847`*^9, 
   3.5929029219968557`*^9}, 3.592904449889039*^9, {3.592904939336296*^9, 
   3.5929049681357327`*^9}, 3.5929050240950823`*^9, {3.592906989745564*^9, 
   3.592906991173003*^9}, 3.592981897161344*^9, {3.5929830500414124`*^9, 
   3.5929830516351557`*^9}, {3.592984941256364*^9, 3.592984967723587*^9}, {
   3.5929850594191313`*^9, 3.5929850600507812`*^9}, {3.593078684767445*^9, 
   3.5930786853638487`*^9}, {3.593078810699258*^9, 3.593078813970704*^9}, {
   3.593078846291098*^9, 3.593078846558674*^9}, {3.593081023110002*^9, 
   3.5930810234763947`*^9}, 3.5931647964536457`*^9, {3.593165449503705*^9, 
   3.5931654496380377`*^9}, {3.5931657355405493`*^9, 3.593165735667757*^9}, {
   3.593584604493428*^9, 3.593584604631136*^9}, {3.593944861311764*^9, 
   3.593944862050008*^9}, {3.594003534311858*^9, 3.5940035373227463`*^9}, {
   3.594031272314372*^9, 3.594031272492519*^9}, {3.5940313419701977`*^9, 
   3.594031343233996*^9}, {3.595309229405323*^9, 3.595309241548027*^9}, {
   3.595309328409335*^9, 3.595309328710758*^9}, {3.595310659305798*^9, 
   3.5953106597242527`*^9}, {3.5953111337292633`*^9, 3.595311134040028*^9}, {
   3.595311229895891*^9, 3.595311251159194*^9}, {3.595311299468927*^9, 
   3.5953112996130657`*^9}, {3.595311330842163*^9, 3.595311331212494*^9}, 
   3.5953113980124807`*^9, 3.59531159429991*^9, {3.595311632193425*^9, 
   3.595311632773787*^9}, {3.595311663906864*^9, 3.595311672137052*^9}, {
   3.596346818754038*^9, 3.596346841189405*^9}, {3.59637681559759*^9, 
   3.5963768581655827`*^9}, {3.5963770643027697`*^9, 3.596377064992869*^9}, {
   3.596377121020591*^9, 3.596377123935335*^9}, {3.596377186356237*^9, 
   3.59637718660562*^9}, {3.596377284578375*^9, 3.5963772894550533`*^9}, {
   3.596435104828185*^9, 3.59643512067708*^9}, {3.596538623515623*^9, 
   3.596538624347699*^9}, {3.596538743464314*^9, 3.596538743587708*^9}, {
   3.596538791297941*^9, 3.5965388093985558`*^9}, 3.596539247292573*^9, {
   3.596541335368175*^9, 3.596541360893368*^9}, {3.597406851718199*^9, 
   3.5974068673709717`*^9}, {3.5974070871175222`*^9, 3.597407087248165*^9}, {
   3.5974071842342863`*^9, 3.597407211357211*^9}, {3.5974072456484423`*^9, 
   3.597407284392157*^9}, {3.597409630945505*^9, 3.597409631269079*^9}, {
   3.5981211019451714`*^9, 3.598121102246313*^9}, {3.598122043797679*^9, 
   3.598122074570026*^9}, {3.5981224840402946`*^9, 3.5981224841999903`*^9}, 
   3.598165472257122*^9, {3.5981655769415283`*^9, 3.5981655771385117`*^9}, 
   3.598165718582014*^9, 3.598165785285037*^9, {3.598175305888509*^9, 
   3.598175306158023*^9}, {3.59828698935181*^9, 3.598286989873645*^9}, {
   3.598291484163912*^9, 3.598291486736638*^9}, {3.598879375525124*^9, 
   3.59887937567593*^9}, {3.59887945587922*^9, 3.598879456095172*^9}, {
   3.598881918414682*^9, 3.59888191855888*^9}, {3.598886361576386*^9, 
   3.598886361847537*^9}, {3.5989609652334642`*^9, 3.598960965492725*^9}, {
   3.5989750777582283`*^9, 3.598975081771798*^9}, {3.598975114596648*^9, 
   3.5989751149919558`*^9}, 3.60041917544998*^9, {3.601362212701621*^9, 
   3.601362214339457*^9}, {3.601362274993197*^9, 3.601362278564246*^9}, {
   3.6013683081164637`*^9, 3.6013683082405863`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.2`", ",", "1.064`", ",", "0.5408666666666667`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.554358830091385*^9, 3.554358865255776*^9, 3.554358913540926*^9, 
   3.554358962647942*^9, 3.554359030737906*^9, 3.554359495724883*^9, 
   3.554359631374332*^9, 3.554359943785555*^9, {3.554359979572698*^9, 
   3.55435999493254*^9}, 3.554360418614574*^9, 3.554360450789584*^9, 
   3.554360544343137*^9, {3.554362000337831*^9, 3.554362015515444*^9}, 
   3.55443359498532*^9, {3.5544340397374907`*^9, 3.554434045413167*^9}, 
   3.554435043797122*^9, 3.554435095751279*^9, {3.5544351886863623`*^9, 
   3.554435202588085*^9}, 3.554435260749197*^9, 3.5544357930771713`*^9, 
   3.5544364955884733`*^9, 3.554437021091709*^9, 3.554437832709882*^9, 
   3.554438305537958*^9, {3.554438343796096*^9, 3.5544383710765657`*^9}, {
   3.554438401330866*^9, 3.554438414763813*^9}, 3.554438493786646*^9, 
   3.5544385864387302`*^9, 3.554438651499035*^9, 3.5544390341301403`*^9, 
   3.554439071140037*^9, 3.554439120109458*^9, 3.554439155760347*^9, 
   3.554439213110135*^9, {3.5544392528949757`*^9, 3.554439264667676*^9}, 
   3.554440819194005*^9, 3.554440896251329*^9, 3.554441140044351*^9, {
   3.554441208550644*^9, 3.554441222399757*^9}, 3.5544412680265493`*^9, 
   3.554447990243992*^9, 3.554448461799959*^9, 3.554448875821843*^9, {
   3.554449325786501*^9, 3.5544493377578363`*^9}, {3.554449630597097*^9, 
   3.554449633969433*^9}, 3.554450567264997*^9, {3.554450628417693*^9, 
   3.55445064472488*^9}, {3.5544506753624077`*^9, 3.554450695784709*^9}, 
   3.554450727485261*^9, 3.554450801081851*^9, 3.554451481315361*^9, {
   3.554451620163546*^9, 3.554451647015533*^9}, 3.554453488648727*^9, 
   3.554453721445019*^9, 3.554453784972129*^9, 3.554453910321103*^9, 
   3.554454009798358*^9, {3.5544542778796463`*^9, 3.554454294036075*^9}, 
   3.55445433176127*^9, {3.554454949901557*^9, 3.554454980570551*^9}, 
   3.554455094598118*^9, {3.554455364653942*^9, 3.554455374069084*^9}, {
   3.554455421156849*^9, 3.554455426603117*^9}, {3.55445576007701*^9, 
   3.554455787937069*^9}, 3.5544558813582582`*^9, 3.554456078067572*^9, {
   3.554456171672131*^9, 3.5544561969906197`*^9}, {3.5544623979261436`*^9, 
   3.554462422899478*^9}, 3.5544624818101482`*^9, 3.554505707721221*^9, 
   3.55450574080121*^9, 3.554505811084465*^9, 3.554524572382772*^9, {
   3.554524729761052*^9, 3.554524744669938*^9}, {3.554525688052936*^9, 
   3.554525723137784*^9}, 3.55452577904255*^9, {3.554525811822513*^9, 
   3.5545258202728443`*^9}, {3.554525869214766*^9, 3.554525896476812*^9}, 
   3.5546576524176607`*^9, {3.554657708490981*^9, 3.5546577414516697`*^9}, {
   3.5546578006159687`*^9, 3.554657828983831*^9}, {3.555064370844635*^9, 
   3.555064385250565*^9}, {3.5551708390283737`*^9, 3.555170867739654*^9}, {
   3.5552637021785393`*^9, 3.5552637112970333`*^9}, 3.556603182851181*^9, 
   3.556603331742765*^9, {3.55660348289674*^9, 3.556603495897681*^9}, 
   3.557043882677291*^9, 3.557043983701639*^9, {3.5572072484857397`*^9, 
   3.5572072642279787`*^9}, 3.5572073680447187`*^9, 3.557207469048953*^9, {
   3.557207532809003*^9, 3.557207549744128*^9}, 3.557207767117255*^9, 
   3.557207929945424*^9, 3.5572086775767193`*^9, 3.5572087298118143`*^9, {
   3.5572091382367353`*^9, 3.55720915633365*^9}, 3.5572092963953333`*^9, 
   3.557209429814142*^9, 3.5572158962887783`*^9, 3.5573912002891083`*^9, 
   3.557391574587595*^9, 3.5573923712918663`*^9, {3.5573936526822357`*^9, 
   3.557393654207271*^9}, 3.5573944687423553`*^9, {3.557394816313151*^9, 
   3.557394845834958*^9}, {3.557394893448653*^9, 3.55739491627186*^9}, 
   3.5573949741895514`*^9, {3.557398277723606*^9, 3.557398301671763*^9}, 
   3.5574050742440147`*^9, 3.557504365200822*^9, 3.557555218341572*^9, 
   3.557589113482197*^9, 3.557739295876608*^9, {3.557739471039256*^9, 
   3.5577394753818293`*^9}, 3.562753104432859*^9, 3.56275318610849*^9, 
   3.562753477759244*^9, 3.562753566229475*^9, 3.562753955921987*^9, 
   3.563119641344646*^9, {3.563290865843299*^9, 3.563290867891015*^9}, {
   3.563291165247303*^9, 3.563291191224442*^9}, 3.56329287368295*^9, 
   3.563293111353644*^9, 3.563293339343655*^9, 3.5632935523182383`*^9, 
   3.563293593246901*^9, 3.563293651576387*^9, 3.563293834323365*^9, 
   3.563620887417611*^9, 3.56362126592406*^9, {3.563621301569706*^9, 
   3.563621343128489*^9}, 3.563633340668043*^9, {3.564210726877474*^9, 
   3.564210775892873*^9}, {3.564210844162661*^9, 3.564210873130417*^9}, 
   3.564220463462222*^9, {3.564239914633416*^9, 3.5642399232142067`*^9}, {
   3.564242640272049*^9, 3.564242661899024*^9}, {3.5643364165423937`*^9, 
   3.564336425445558*^9}, {3.5643364766181107`*^9, 3.564336482301577*^9}, {
   3.564375266265726*^9, 3.5643752733756*^9}, 3.564383760218378*^9, {
   3.564420789541357*^9, 3.564420864737459*^9}, {3.56442090227496*^9, 
   3.5644209058946333`*^9}, 3.564459118848886*^9, {3.564460799866702*^9, 
   3.564460817696002*^9}, 3.5644674218137608`*^9, 3.564477577828431*^9, 
   3.5644783861753407`*^9, 3.564478531208749*^9, {3.566034706567474*^9, 
   3.5660347328949757`*^9}, {3.566034777554575*^9, 3.566034784801989*^9}, 
   3.5661367388821383`*^9, 3.56613680558248*^9, {3.568648971476862*^9, 
   3.568648973543665*^9}, {3.568649004062286*^9, 3.568649047078418*^9}, 
   3.568657074422123*^9, 3.5686942451948757`*^9, 3.5687386859305687`*^9, {
   3.5720122628825207`*^9, 3.57201228199881*^9}, {3.572014719757648*^9, 
   3.572014724204927*^9}, 3.572014795986285*^9, 3.572014879273035*^9, 
   3.572015919776548*^9, {3.5720190069837437`*^9, 3.572019035377275*^9}, 
   3.572019522941901*^9, 3.572019668449237*^9, 3.572019797816325*^9, 
   3.5720203040113363`*^9, 3.5720208741177473`*^9, 3.57206719787799*^9, 
   3.572086281560055*^9, 3.5720863487147512`*^9, 3.572086452791595*^9, 
   3.572087452746438*^9, 3.572087513243477*^9, 3.572087660847622*^9, 
   3.572087894163962*^9, 3.572114585846671*^9, {3.572171654246595*^9, 
   3.572171656438197*^9}, 3.572171734796905*^9, {3.5721719623815937`*^9, 
   3.572171965469729*^9}, 3.57217202091262*^9, {3.572194873948105*^9, 
   3.572194884300334*^9}, {3.572252534703174*^9, 3.572252537046191*^9}, 
   3.572253300414853*^9, 3.572254253988761*^9, 3.572254692223521*^9, 
   3.572254851263934*^9, 3.572255063835442*^9, 3.5722552998871717`*^9, {
   3.5722842437750998`*^9, 3.572284251711459*^9}, 3.572284372910212*^9, 
   3.5723476390340567`*^9, 3.572347763884533*^9, 3.5723534586151657`*^9, {
   3.5723538434079237`*^9, 3.572353849456871*^9}, 3.572360388403021*^9, {
   3.572360490541038*^9, 3.572360502396728*^9}, 3.572360621718238*^9, {
   3.572455571344574*^9, 3.5724555784672613`*^9}, {3.572784732204767*^9, 
   3.572784760166497*^9}, {3.573357637876379*^9, 3.573357639816347*^9}, {
   3.573360530972642*^9, 3.5733605423144827`*^9}, 3.574760591311388*^9, 
   3.576504313593033*^9, 3.576511596876048*^9, {3.576511810645399*^9, 
   3.576511852338032*^9}, 3.576512289422798*^9, 3.5765123287410727`*^9, 
   3.576512370073312*^9, {3.576512961480832*^9, 3.576512972836647*^9}, 
   3.5765130538802023`*^9, {3.5765131706823483`*^9, 3.576513195686442*^9}, 
   3.5765143260465097`*^9, 3.576514397251598*^9, 3.576514472231398*^9, 
   3.5765196477414293`*^9, 3.576519828894815*^9, 3.576519862002242*^9, {
   3.576519974283821*^9, 3.57651999094121*^9}, 3.576524930442914*^9, 
   3.5766501583290052`*^9, {3.5767730719109507`*^9, 3.576773074158781*^9}, 
   3.5769906323560133`*^9, 3.576990699001289*^9, 3.5769907786538887`*^9, 
   3.576990823439889*^9, {3.577198000349237*^9, 3.577198025638427*^9}, 
   3.577198416893095*^9, {3.577198508033203*^9, 3.577198510184787*^9}, {
   3.577198605984647*^9, 3.5771986298961554`*^9}, 3.577198819984651*^9, 
   3.577199403889228*^9, 3.577199623445868*^9, 3.5772044565778*^9, {
   3.577261879791589*^9, 3.5772618857654753`*^9}, {3.577262025427031*^9, 
   3.577262048429865*^9}, {3.577342480722699*^9, 3.57734249541504*^9}, {
   3.577342838320467*^9, 3.5773428401299553`*^9}, {3.577360869686008*^9, 
   3.577360871948517*^9}, {3.5777160124718723`*^9, 3.577716014108659*^9}, {
   3.5885800880613327`*^9, 3.588580090189948*^9}, 3.5886497316226797`*^9, 
   3.588660003760792*^9, 3.5886609764780293`*^9, {3.59046864850095*^9, 
   3.590468650953718*^9}, {3.590469028049*^9, 3.590469035612535*^9}, 
   3.590469085261346*^9, 3.5904700780153027`*^9, {3.590656928664796*^9, 
   3.590656930593405*^9}, 3.590672808526771*^9, 3.590673322600754*^9, 
   3.5906733799097958`*^9, 3.590673458870077*^9, {3.590813082231382*^9, 
   3.590813141841138*^9}, {3.590813191966158*^9, 3.590813204673149*^9}, 
   3.5909019857756777`*^9, {3.5909020243445053`*^9, 3.5909020867147284`*^9}, 
   3.590915691937216*^9, {3.5909388295564823`*^9, 3.590938835338437*^9}, 
   3.590938875846842*^9, 3.5909891057944307`*^9, {3.590990718272015*^9, 
   3.590990731314279*^9}, {3.5910018219440117`*^9, 3.5910018310153103`*^9}, {
   3.591001990104844*^9, 3.591002000456848*^9}, {3.591252451453383*^9, 
   3.591252453152643*^9}, 3.591253112237088*^9, 3.5912531913133507`*^9, 
   3.5912541770238447`*^9, 3.5912542511202707`*^9, {3.591259138739263*^9, 
   3.591259183063888*^9}, 3.591259322521822*^9, 3.591267819711091*^9, {
   3.5913294038539743`*^9, 3.591329413063984*^9}, {3.591352018122363*^9, 
   3.591352019839457*^9}, 3.591352608813388*^9, {3.5913714579800262`*^9, 
   3.5913714602849483`*^9}, {3.5914113273149357`*^9, 3.591411331768703*^9}, {
   3.591508342044304*^9, 3.591508348971589*^9}, {3.591877064418826*^9, 
   3.5918771116034403`*^9}, 3.591952362849964*^9, 3.591953050414577*^9, 
   3.591953171672431*^9, 3.591953599173996*^9, 3.591953661891192*^9, 
   3.5919537408198223`*^9, {3.5919557814761477`*^9, 3.5919557910435677`*^9}, 
   3.591958050054686*^9, {3.592052722515538*^9, 3.5920527314550257`*^9}, 
   3.592052925531954*^9, 3.592110412279928*^9, 3.5921104458035593`*^9, 
   3.592110536116387*^9, 3.592642138148017*^9, 3.592651970374612*^9, 
   3.592655068451647*^9, {3.592655105085884*^9, 3.592655110071813*^9}, 
   3.5926551755446873`*^9, 3.592656034586945*^9, 3.592657276323567*^9, 
   3.592660057226182*^9, {3.592661424073071*^9, 3.592661431151182*^9}, 
   3.5926622673329153`*^9, {3.592675559548773*^9, 3.592675583207724*^9}, {
   3.592675624339472*^9, 3.592675643929874*^9}, {3.592675902732546*^9, 
   3.592675937635586*^9}, {3.592714682566625*^9, 3.59271469351265*^9}, 
   3.592714729297509*^9, 3.592718023403544*^9, 3.592718391590888*^9, 
   3.592725531834351*^9, 3.59272762239614*^9, 3.592730205778401*^9, 
   3.5927339135319138`*^9, {3.592733981647545*^9, 3.5927340030956697`*^9}, {
   3.592748576763071*^9, 3.592748585734343*^9}, 3.592793794532374*^9, 
   3.592793895513976*^9, {3.59279400914883*^9, 3.5927940430513353`*^9}, 
   3.5927942720849657`*^9, 3.592819544412829*^9, 3.592820078911571*^9, 
   3.5928201224891033`*^9, 3.592820320850068*^9, 3.5928208609534082`*^9, 
   3.59282139671628*^9, 3.5928221082684517`*^9, 3.592822244297883*^9, 
   3.5928250632244883`*^9, 3.5928898337954187`*^9, {3.592892071085148*^9, 
   3.592892087084156*^9}, 3.592892170965399*^9, 3.5928922110518503`*^9, {
   3.592892462264078*^9, 3.59289249351376*^9}, {3.5928925506969852`*^9, 
   3.592892556311309*^9}, {3.592892689535013*^9, 3.5928926993028316`*^9}, {
   3.592902918561487*^9, 3.5929029223163557`*^9}, 3.592904450449782*^9, 
   3.592904667551869*^9, 3.592904942903068*^9, 3.592904974105523*^9, 
   3.59290502474058*^9, 3.592905572165553*^9, 3.592906991514659*^9, 
   3.592981897667472*^9, 3.592983052365939*^9, {3.59298494195683*^9, 
   3.592984968410165*^9}, 3.592985060726647*^9, 3.593003868422555*^9, 
   3.5930786859464207`*^9, {3.5930788114171047`*^9, 3.593078814354246*^9}, 
   3.593078847084687*^9, 3.593081023929908*^9, 3.593164797237619*^9, 
   3.593165450008368*^9, 3.593165736142538*^9, 3.593505407622682*^9, {
   3.5935846085772057`*^9, 3.593584611249666*^9}, 3.593587781586492*^9, 
   3.593852656497983*^9, 3.59394472846449*^9, 3.593944862433148*^9, {
   3.594003530164383*^9, 3.594003540635169*^9}, 3.594003909978203*^9, 
   3.594031272928074*^9, 3.59403134397078*^9, {3.595309212567952*^9, 
   3.595309241976465*^9}, 3.595309329260269*^9, 3.595310660224545*^9, 
   3.59531113455013*^9, {3.595311233402629*^9, 3.595311253141189*^9}, 
   3.595311299995288*^9, 3.595311331676423*^9, 3.595311398418603*^9, {
   3.595311595161642*^9, 3.5953115979302464`*^9}, 3.595311633210622*^9, {
   3.595311668577585*^9, 3.595311672770331*^9}, {3.596346831506013*^9, 
   3.596346841486903*^9}, 3.596375868299177*^9, 3.5963763064444027`*^9, 
   3.5963768586931973`*^9, {3.596377065386838*^9, 3.59637707323591*^9}, {
   3.596377124269498*^9, 3.596377131073278*^9}, {3.596377187116062*^9, 
   3.596377215704887*^9}, 3.596377289881617*^9, 3.596435070428555*^9, 
   3.596435121158387*^9, 3.596538273080311*^9, {3.596538312156002*^9, 
   3.5965383152140493`*^9}, 3.596538396588505*^9, 3.596538624870192*^9, 
   3.596538743977462*^9, {3.596538791951955*^9, 3.5965388097480707`*^9}, 
   3.596538997381865*^9, 3.596539247731288*^9, {3.596541335882121*^9, 
   3.596541361320952*^9}, {3.597406869840568*^9, 3.597406872082171*^9}, 
   3.597407087926366*^9, {3.597407186408332*^9, 3.5974072128570147`*^9}, {
   3.597407246710915*^9, 3.597407258357163*^9}, 3.5974073173560543`*^9, 
   3.5974096324007607`*^9, {3.598119709737059*^9, 3.598119711477497*^9}, 
   3.598120433168222*^9, 3.598121021605102*^9, 3.598121103583084*^9, {
   3.59812204433881*^9, 3.598122075168559*^9}, 3.598122193392796*^9, 
   3.598122484849489*^9, 3.598122676267119*^9, 3.5981540240916767`*^9, 
   3.5981580423853817`*^9, 3.598165472699972*^9, 3.598165577560161*^9, 
   3.598165719125223*^9, 3.5981657856211243`*^9, 3.598166321277677*^9, 
   3.598167026822118*^9, {3.598167903978546*^9, 3.598167904961591*^9}, 
   3.598175315410966*^9, 3.5982831317377768`*^9, 3.5982836390429792`*^9, 
   3.598286992287978*^9, 3.5982909027203913`*^9, {3.598291198832191*^9, 
   3.5982912002432203`*^9}, {3.598291341646543*^9, 3.5982913453762083`*^9}, {
   3.598291475656177*^9, 3.598291487294619*^9}, {3.59853172687361*^9, 
   3.598531728658023*^9}, 3.598679786021976*^9, {3.598680069951858*^9, 
   3.5986800970585012`*^9}, 3.5986988344604816`*^9, 3.598698891176594*^9, {
   3.598728477050509*^9, 3.5987284780532703`*^9}, 3.5987816636759663`*^9, {
   3.5988100423180733`*^9, 3.5988100440352697`*^9}, {3.59887242675905*^9, 
   3.598872428725548*^9}, 3.59887937614281*^9, 3.598879456725876*^9, 
   3.5988819190314617`*^9, {3.598886135776182*^9, 3.59888613763615*^9}, 
   3.598886187506497*^9, 3.598886362448572*^9, {3.598938182942268*^9, 
   3.598938184659197*^9}, {3.598947658947979*^9, 3.5989476607539577`*^9}, {
   3.598960943848035*^9, 3.598960966247753*^9}, {3.598975066815968*^9, 
   3.598975082258492*^9}, 3.598975115583551*^9, 3.599203217375414*^9, 
   3.5992033732890043`*^9, {3.599203481328031*^9, 3.599203483411399*^9}, {
   3.599329697026661*^9, 3.5993296990275927`*^9}, 3.599384364791898*^9, {
   3.599415828653736*^9, 3.599415830674304*^9}, {3.600419179999693*^9, 
   3.600419182203286*^9}, {3.600494711335067*^9, 3.600494712433138*^9}, {
   3.6013622044103003`*^9, 3.601362219221046*^9}, {3.601362279322267*^9, 
   3.60136228063945*^9}, {3.601368295807447*^9, 3.601368308802229*^9}, {
   3.601445116296341*^9, 3.601445118161009*^9}, {3.601470066944476*^9, 
   3.601470070517827*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"nMax suggested:\"\>", ",", "4.541571639955999`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.554358830091385*^9, 3.554358865255776*^9, 3.554358913540926*^9, 
   3.554358962647942*^9, 3.554359030737906*^9, 3.554359495724883*^9, 
   3.554359631374332*^9, 3.554359943785555*^9, {3.554359979572698*^9, 
   3.55435999493254*^9}, 3.554360418614574*^9, 3.554360450789584*^9, 
   3.554360544343137*^9, {3.554362000337831*^9, 3.554362015515444*^9}, 
   3.55443359498532*^9, {3.5544340397374907`*^9, 3.554434045413167*^9}, 
   3.554435043797122*^9, 3.554435095751279*^9, {3.5544351886863623`*^9, 
   3.554435202588085*^9}, 3.554435260749197*^9, 3.5544357930771713`*^9, 
   3.5544364955884733`*^9, 3.554437021091709*^9, 3.554437832709882*^9, 
   3.554438305537958*^9, {3.554438343796096*^9, 3.5544383710765657`*^9}, {
   3.554438401330866*^9, 3.554438414763813*^9}, 3.554438493786646*^9, 
   3.5544385864387302`*^9, 3.554438651499035*^9, 3.5544390341301403`*^9, 
   3.554439071140037*^9, 3.554439120109458*^9, 3.554439155760347*^9, 
   3.554439213110135*^9, {3.5544392528949757`*^9, 3.554439264667676*^9}, 
   3.554440819194005*^9, 3.554440896251329*^9, 3.554441140044351*^9, {
   3.554441208550644*^9, 3.554441222399757*^9}, 3.5544412680265493`*^9, 
   3.554447990243992*^9, 3.554448461799959*^9, 3.554448875821843*^9, {
   3.554449325786501*^9, 3.5544493377578363`*^9}, {3.554449630597097*^9, 
   3.554449633969433*^9}, 3.554450567264997*^9, {3.554450628417693*^9, 
   3.55445064472488*^9}, {3.5544506753624077`*^9, 3.554450695784709*^9}, 
   3.554450727485261*^9, 3.554450801081851*^9, 3.554451481315361*^9, {
   3.554451620163546*^9, 3.554451647015533*^9}, 3.554453488648727*^9, 
   3.554453721445019*^9, 3.554453784972129*^9, 3.554453910321103*^9, 
   3.554454009798358*^9, {3.5544542778796463`*^9, 3.554454294036075*^9}, 
   3.55445433176127*^9, {3.554454949901557*^9, 3.554454980570551*^9}, 
   3.554455094598118*^9, {3.554455364653942*^9, 3.554455374069084*^9}, {
   3.554455421156849*^9, 3.554455426603117*^9}, {3.55445576007701*^9, 
   3.554455787937069*^9}, 3.5544558813582582`*^9, 3.554456078067572*^9, {
   3.554456171672131*^9, 3.5544561969906197`*^9}, {3.5544623979261436`*^9, 
   3.554462422899478*^9}, 3.5544624818101482`*^9, 3.554505707721221*^9, 
   3.55450574080121*^9, 3.554505811084465*^9, 3.554524572382772*^9, {
   3.554524729761052*^9, 3.554524744669938*^9}, {3.554525688052936*^9, 
   3.554525723137784*^9}, 3.55452577904255*^9, {3.554525811822513*^9, 
   3.5545258202728443`*^9}, {3.554525869214766*^9, 3.554525896476812*^9}, 
   3.5546576524176607`*^9, {3.554657708490981*^9, 3.5546577414516697`*^9}, {
   3.5546578006159687`*^9, 3.554657828983831*^9}, {3.555064370844635*^9, 
   3.555064385250565*^9}, {3.5551708390283737`*^9, 3.555170867739654*^9}, {
   3.5552637021785393`*^9, 3.5552637112970333`*^9}, 3.556603182851181*^9, 
   3.556603331742765*^9, {3.55660348289674*^9, 3.556603495897681*^9}, 
   3.557043882677291*^9, 3.557043983701639*^9, {3.5572072484857397`*^9, 
   3.5572072642279787`*^9}, 3.5572073680447187`*^9, 3.557207469048953*^9, {
   3.557207532809003*^9, 3.557207549744128*^9}, 3.557207767117255*^9, 
   3.557207929945424*^9, 3.5572086775767193`*^9, 3.5572087298118143`*^9, {
   3.5572091382367353`*^9, 3.55720915633365*^9}, 3.5572092963953333`*^9, 
   3.557209429814142*^9, 3.5572158962887783`*^9, 3.5573912002891083`*^9, 
   3.557391574587595*^9, 3.5573923712918663`*^9, {3.5573936526822357`*^9, 
   3.557393654207271*^9}, 3.5573944687423553`*^9, {3.557394816313151*^9, 
   3.557394845834958*^9}, {3.557394893448653*^9, 3.55739491627186*^9}, 
   3.5573949741895514`*^9, {3.557398277723606*^9, 3.557398301671763*^9}, 
   3.5574050742440147`*^9, 3.557504365200822*^9, 3.557555218341572*^9, 
   3.557589113482197*^9, 3.557739295876608*^9, {3.557739471039256*^9, 
   3.5577394753818293`*^9}, 3.562753104432859*^9, 3.56275318610849*^9, 
   3.562753477759244*^9, 3.562753566229475*^9, 3.562753955921987*^9, 
   3.563119641344646*^9, {3.563290865843299*^9, 3.563290867891015*^9}, {
   3.563291165247303*^9, 3.563291191224442*^9}, 3.56329287368295*^9, 
   3.563293111353644*^9, 3.563293339343655*^9, 3.5632935523182383`*^9, 
   3.563293593246901*^9, 3.563293651576387*^9, 3.563293834323365*^9, 
   3.563620887417611*^9, 3.56362126592406*^9, {3.563621301569706*^9, 
   3.563621343128489*^9}, 3.563633340668043*^9, {3.564210726877474*^9, 
   3.564210775892873*^9}, {3.564210844162661*^9, 3.564210873130417*^9}, 
   3.564220463462222*^9, {3.564239914633416*^9, 3.5642399232142067`*^9}, {
   3.564242640272049*^9, 3.564242661899024*^9}, {3.5643364165423937`*^9, 
   3.564336425445558*^9}, {3.5643364766181107`*^9, 3.564336482301577*^9}, {
   3.564375266265726*^9, 3.5643752733756*^9}, 3.564383760218378*^9, {
   3.564420789541357*^9, 3.564420864737459*^9}, {3.56442090227496*^9, 
   3.5644209058946333`*^9}, 3.564459118848886*^9, {3.564460799866702*^9, 
   3.564460817696002*^9}, 3.5644674218137608`*^9, 3.564477577828431*^9, 
   3.5644783861753407`*^9, 3.564478531208749*^9, {3.566034706567474*^9, 
   3.5660347328949757`*^9}, {3.566034777554575*^9, 3.566034784801989*^9}, 
   3.5661367388821383`*^9, 3.56613680558248*^9, {3.568648971476862*^9, 
   3.568648973543665*^9}, {3.568649004062286*^9, 3.568649047078418*^9}, 
   3.568657074422123*^9, 3.5686942451948757`*^9, 3.5687386859305687`*^9, {
   3.5720122628825207`*^9, 3.57201228199881*^9}, {3.572014719757648*^9, 
   3.572014724204927*^9}, 3.572014795986285*^9, 3.572014879273035*^9, 
   3.572015919776548*^9, {3.5720190069837437`*^9, 3.572019035377275*^9}, 
   3.572019522941901*^9, 3.572019668449237*^9, 3.572019797816325*^9, 
   3.5720203040113363`*^9, 3.5720208741177473`*^9, 3.57206719787799*^9, 
   3.572086281560055*^9, 3.5720863487147512`*^9, 3.572086452791595*^9, 
   3.572087452746438*^9, 3.572087513243477*^9, 3.572087660847622*^9, 
   3.572087894163962*^9, 3.572114585846671*^9, {3.572171654246595*^9, 
   3.572171656438197*^9}, 3.572171734796905*^9, {3.5721719623815937`*^9, 
   3.572171965469729*^9}, 3.57217202091262*^9, {3.572194873948105*^9, 
   3.572194884300334*^9}, {3.572252534703174*^9, 3.572252537046191*^9}, 
   3.572253300414853*^9, 3.572254253988761*^9, 3.572254692223521*^9, 
   3.572254851263934*^9, 3.572255063835442*^9, 3.5722552998871717`*^9, {
   3.5722842437750998`*^9, 3.572284251711459*^9}, 3.572284372910212*^9, 
   3.5723476390340567`*^9, 3.572347763884533*^9, 3.5723534586151657`*^9, {
   3.5723538434079237`*^9, 3.572353849456871*^9}, 3.572360388403021*^9, {
   3.572360490541038*^9, 3.572360502396728*^9}, 3.572360621718238*^9, {
   3.572455571344574*^9, 3.5724555784672613`*^9}, {3.572784732204767*^9, 
   3.572784760166497*^9}, {3.573357637876379*^9, 3.573357639816347*^9}, {
   3.573360530972642*^9, 3.5733605423144827`*^9}, 3.574760591311388*^9, 
   3.576504313593033*^9, 3.576511596876048*^9, {3.576511810645399*^9, 
   3.576511852338032*^9}, 3.576512289422798*^9, 3.5765123287410727`*^9, 
   3.576512370073312*^9, {3.576512961480832*^9, 3.576512972836647*^9}, 
   3.5765130538802023`*^9, {3.5765131706823483`*^9, 3.576513195686442*^9}, 
   3.5765143260465097`*^9, 3.576514397251598*^9, 3.576514472231398*^9, 
   3.5765196477414293`*^9, 3.576519828894815*^9, 3.576519862002242*^9, {
   3.576519974283821*^9, 3.57651999094121*^9}, 3.576524930442914*^9, 
   3.5766501583290052`*^9, {3.5767730719109507`*^9, 3.576773074158781*^9}, 
   3.5769906323560133`*^9, 3.576990699001289*^9, 3.5769907786538887`*^9, 
   3.576990823439889*^9, {3.577198000349237*^9, 3.577198025638427*^9}, 
   3.577198416893095*^9, {3.577198508033203*^9, 3.577198510184787*^9}, {
   3.577198605984647*^9, 3.5771986298961554`*^9}, 3.577198819984651*^9, 
   3.577199403889228*^9, 3.577199623445868*^9, 3.5772044565778*^9, {
   3.577261879791589*^9, 3.5772618857654753`*^9}, {3.577262025427031*^9, 
   3.577262048429865*^9}, {3.577342480722699*^9, 3.57734249541504*^9}, {
   3.577342838320467*^9, 3.5773428401299553`*^9}, {3.577360869686008*^9, 
   3.577360871948517*^9}, {3.5777160124718723`*^9, 3.577716014108659*^9}, {
   3.5885800880613327`*^9, 3.588580090189948*^9}, 3.5886497316226797`*^9, 
   3.588660003760792*^9, 3.5886609764780293`*^9, {3.59046864850095*^9, 
   3.590468650953718*^9}, {3.590469028049*^9, 3.590469035612535*^9}, 
   3.590469085261346*^9, 3.5904700780153027`*^9, {3.590656928664796*^9, 
   3.590656930593405*^9}, 3.590672808526771*^9, 3.590673322600754*^9, 
   3.5906733799097958`*^9, 3.590673458870077*^9, {3.590813082231382*^9, 
   3.590813141841138*^9}, {3.590813191966158*^9, 3.590813204673149*^9}, 
   3.5909019857756777`*^9, {3.5909020243445053`*^9, 3.5909020867147284`*^9}, 
   3.590915691937216*^9, {3.5909388295564823`*^9, 3.590938835338437*^9}, 
   3.590938875846842*^9, 3.5909891057944307`*^9, {3.590990718272015*^9, 
   3.590990731314279*^9}, {3.5910018219440117`*^9, 3.5910018310153103`*^9}, {
   3.591001990104844*^9, 3.591002000456848*^9}, {3.591252451453383*^9, 
   3.591252453152643*^9}, 3.591253112237088*^9, 3.5912531913133507`*^9, 
   3.5912541770238447`*^9, 3.5912542511202707`*^9, {3.591259138739263*^9, 
   3.591259183063888*^9}, 3.591259322521822*^9, 3.591267819711091*^9, {
   3.5913294038539743`*^9, 3.591329413063984*^9}, {3.591352018122363*^9, 
   3.591352019839457*^9}, 3.591352608813388*^9, {3.5913714579800262`*^9, 
   3.5913714602849483`*^9}, {3.5914113273149357`*^9, 3.591411331768703*^9}, {
   3.591508342044304*^9, 3.591508348971589*^9}, {3.591877064418826*^9, 
   3.5918771116034403`*^9}, 3.591952362849964*^9, 3.591953050414577*^9, 
   3.591953171672431*^9, 3.591953599173996*^9, 3.591953661891192*^9, 
   3.5919537408198223`*^9, {3.5919557814761477`*^9, 3.5919557910435677`*^9}, 
   3.591958050054686*^9, {3.592052722515538*^9, 3.5920527314550257`*^9}, 
   3.592052925531954*^9, 3.592110412279928*^9, 3.5921104458035593`*^9, 
   3.592110536116387*^9, 3.592642138148017*^9, 3.592651970374612*^9, 
   3.592655068451647*^9, {3.592655105085884*^9, 3.592655110071813*^9}, 
   3.5926551755446873`*^9, 3.592656034586945*^9, 3.592657276323567*^9, 
   3.592660057226182*^9, {3.592661424073071*^9, 3.592661431151182*^9}, 
   3.5926622673329153`*^9, {3.592675559548773*^9, 3.592675583207724*^9}, {
   3.592675624339472*^9, 3.592675643929874*^9}, {3.592675902732546*^9, 
   3.592675937635586*^9}, {3.592714682566625*^9, 3.59271469351265*^9}, 
   3.592714729297509*^9, 3.592718023403544*^9, 3.592718391590888*^9, 
   3.592725531834351*^9, 3.59272762239614*^9, 3.592730205778401*^9, 
   3.5927339135319138`*^9, {3.592733981647545*^9, 3.5927340030956697`*^9}, {
   3.592748576763071*^9, 3.592748585734343*^9}, 3.592793794532374*^9, 
   3.592793895513976*^9, {3.59279400914883*^9, 3.5927940430513353`*^9}, 
   3.5927942720849657`*^9, 3.592819544412829*^9, 3.592820078911571*^9, 
   3.5928201224891033`*^9, 3.592820320850068*^9, 3.5928208609534082`*^9, 
   3.59282139671628*^9, 3.5928221082684517`*^9, 3.592822244297883*^9, 
   3.5928250632244883`*^9, 3.5928898337954187`*^9, {3.592892071085148*^9, 
   3.592892087084156*^9}, 3.592892170965399*^9, 3.5928922110518503`*^9, {
   3.592892462264078*^9, 3.59289249351376*^9}, {3.5928925506969852`*^9, 
   3.592892556311309*^9}, {3.592892689535013*^9, 3.5928926993028316`*^9}, {
   3.592902918561487*^9, 3.5929029223163557`*^9}, 3.592904450449782*^9, 
   3.592904667551869*^9, 3.592904942903068*^9, 3.592904974105523*^9, 
   3.59290502474058*^9, 3.592905572165553*^9, 3.592906991514659*^9, 
   3.592981897667472*^9, 3.592983052365939*^9, {3.59298494195683*^9, 
   3.592984968410165*^9}, 3.592985060726647*^9, 3.593003868422555*^9, 
   3.5930786859464207`*^9, {3.5930788114171047`*^9, 3.593078814354246*^9}, 
   3.593078847084687*^9, 3.593081023929908*^9, 3.593164797237619*^9, 
   3.593165450008368*^9, 3.593165736142538*^9, 3.593505407622682*^9, {
   3.5935846085772057`*^9, 3.593584611249666*^9}, 3.593587781586492*^9, 
   3.593852656497983*^9, 3.59394472846449*^9, 3.593944862433148*^9, {
   3.594003530164383*^9, 3.594003540635169*^9}, 3.594003909978203*^9, 
   3.594031272928074*^9, 3.59403134397078*^9, {3.595309212567952*^9, 
   3.595309241976465*^9}, 3.595309329260269*^9, 3.595310660224545*^9, 
   3.59531113455013*^9, {3.595311233402629*^9, 3.595311253141189*^9}, 
   3.595311299995288*^9, 3.595311331676423*^9, 3.595311398418603*^9, {
   3.595311595161642*^9, 3.5953115979302464`*^9}, 3.595311633210622*^9, {
   3.595311668577585*^9, 3.595311672770331*^9}, {3.596346831506013*^9, 
   3.596346841486903*^9}, 3.596375868299177*^9, 3.5963763064444027`*^9, 
   3.5963768586931973`*^9, {3.596377065386838*^9, 3.59637707323591*^9}, {
   3.596377124269498*^9, 3.596377131073278*^9}, {3.596377187116062*^9, 
   3.596377215704887*^9}, 3.596377289881617*^9, 3.596435070428555*^9, 
   3.596435121158387*^9, 3.596538273080311*^9, {3.596538312156002*^9, 
   3.5965383152140493`*^9}, 3.596538396588505*^9, 3.596538624870192*^9, 
   3.596538743977462*^9, {3.596538791951955*^9, 3.5965388097480707`*^9}, 
   3.596538997381865*^9, 3.596539247731288*^9, {3.596541335882121*^9, 
   3.596541361320952*^9}, {3.597406869840568*^9, 3.597406872082171*^9}, 
   3.597407087926366*^9, {3.597407186408332*^9, 3.5974072128570147`*^9}, {
   3.597407246710915*^9, 3.597407258357163*^9}, 3.5974073173560543`*^9, 
   3.5974096324007607`*^9, {3.598119709737059*^9, 3.598119711477497*^9}, 
   3.598120433168222*^9, 3.598121021605102*^9, 3.598121103583084*^9, {
   3.59812204433881*^9, 3.598122075168559*^9}, 3.598122193392796*^9, 
   3.598122484849489*^9, 3.598122676267119*^9, 3.5981540240916767`*^9, 
   3.5981580423853817`*^9, 3.598165472699972*^9, 3.598165577560161*^9, 
   3.598165719125223*^9, 3.5981657856211243`*^9, 3.598166321277677*^9, 
   3.598167026822118*^9, {3.598167903978546*^9, 3.598167904961591*^9}, 
   3.598175315410966*^9, 3.5982831317377768`*^9, 3.5982836390429792`*^9, 
   3.598286992287978*^9, 3.5982909027203913`*^9, {3.598291198832191*^9, 
   3.5982912002432203`*^9}, {3.598291341646543*^9, 3.5982913453762083`*^9}, {
   3.598291475656177*^9, 3.598291487294619*^9}, {3.59853172687361*^9, 
   3.598531728658023*^9}, 3.598679786021976*^9, {3.598680069951858*^9, 
   3.5986800970585012`*^9}, 3.5986988344604816`*^9, 3.598698891176594*^9, {
   3.598728477050509*^9, 3.5987284780532703`*^9}, 3.5987816636759663`*^9, {
   3.5988100423180733`*^9, 3.5988100440352697`*^9}, {3.59887242675905*^9, 
   3.598872428725548*^9}, 3.59887937614281*^9, 3.598879456725876*^9, 
   3.5988819190314617`*^9, {3.598886135776182*^9, 3.59888613763615*^9}, 
   3.598886187506497*^9, 3.598886362448572*^9, {3.598938182942268*^9, 
   3.598938184659197*^9}, {3.598947658947979*^9, 3.5989476607539577`*^9}, {
   3.598960943848035*^9, 3.598960966247753*^9}, {3.598975066815968*^9, 
   3.598975082258492*^9}, 3.598975115583551*^9, 3.599203217375414*^9, 
   3.5992033732890043`*^9, {3.599203481328031*^9, 3.599203483411399*^9}, {
   3.599329697026661*^9, 3.5993296990275927`*^9}, 3.599384364791898*^9, {
   3.599415828653736*^9, 3.599415830674304*^9}, {3.600419179999693*^9, 
   3.600419182203286*^9}, {3.600494711335067*^9, 3.600494712433138*^9}, {
   3.6013622044103003`*^9, 3.601362219221046*^9}, {3.601362279322267*^9, 
   3.60136228063945*^9}, {3.601368295807447*^9, 3.601368308802229*^9}, {
   3.601445116296341*^9, 3.601445118161009*^9}, {3.601470066944476*^9, 
   3.601470070519677*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.7551683047359772`*^6", "-", 
    RowBox[{"14717.865327157391`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"1.935372502127473`*^6", "-", 
    RowBox[{"115877.23653051721`", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.554358830091385*^9, 3.554358865255776*^9, 3.554358913540926*^9, 
   3.554358962647942*^9, 3.554359030737906*^9, 3.554359495724883*^9, 
   3.554359631374332*^9, 3.554359943785555*^9, {3.554359979572698*^9, 
   3.55435999493254*^9}, 3.554360418614574*^9, 3.554360450789584*^9, 
   3.554360544343137*^9, {3.554362000337831*^9, 3.554362015515444*^9}, 
   3.55443359498532*^9, {3.5544340397374907`*^9, 3.554434045413167*^9}, 
   3.554435043797122*^9, 3.554435095751279*^9, {3.5544351886863623`*^9, 
   3.554435202588085*^9}, 3.554435260749197*^9, 3.5544357930771713`*^9, 
   3.5544364955884733`*^9, 3.554437021091709*^9, 3.554437832709882*^9, 
   3.554438305537958*^9, {3.554438343796096*^9, 3.5544383710765657`*^9}, {
   3.554438401330866*^9, 3.554438414763813*^9}, 3.554438493786646*^9, 
   3.5544385864387302`*^9, 3.554438651499035*^9, 3.5544390341301403`*^9, 
   3.554439071140037*^9, 3.554439120109458*^9, 3.554439155760347*^9, 
   3.554439213110135*^9, {3.5544392528949757`*^9, 3.554439264667676*^9}, 
   3.554440819194005*^9, 3.554440896251329*^9, 3.554441140044351*^9, {
   3.554441208550644*^9, 3.554441222399757*^9}, 3.5544412680265493`*^9, 
   3.554447990243992*^9, 3.554448461799959*^9, 3.554448875821843*^9, {
   3.554449325786501*^9, 3.5544493377578363`*^9}, {3.554449630597097*^9, 
   3.554449633969433*^9}, 3.554450567264997*^9, {3.554450628417693*^9, 
   3.55445064472488*^9}, {3.5544506753624077`*^9, 3.554450695784709*^9}, 
   3.554450727485261*^9, 3.554450801081851*^9, 3.554451481315361*^9, {
   3.554451620163546*^9, 3.554451647015533*^9}, 3.554453488648727*^9, 
   3.554453721445019*^9, 3.554453784972129*^9, 3.554453910321103*^9, 
   3.554454009798358*^9, {3.5544542778796463`*^9, 3.554454294036075*^9}, 
   3.55445433176127*^9, {3.554454949901557*^9, 3.554454980570551*^9}, 
   3.554455094598118*^9, {3.554455364653942*^9, 3.554455374069084*^9}, {
   3.554455421156849*^9, 3.554455426603117*^9}, {3.55445576007701*^9, 
   3.554455787937069*^9}, 3.5544558813582582`*^9, 3.554456078067572*^9, {
   3.554456171672131*^9, 3.5544561969906197`*^9}, {3.5544623979261436`*^9, 
   3.554462422899478*^9}, 3.5544624818101482`*^9, 3.554505707721221*^9, 
   3.55450574080121*^9, 3.554505811084465*^9, 3.554524572382772*^9, {
   3.554524729761052*^9, 3.554524744669938*^9}, {3.554525688052936*^9, 
   3.554525723137784*^9}, 3.55452577904255*^9, {3.554525811822513*^9, 
   3.5545258202728443`*^9}, {3.554525869214766*^9, 3.554525896476812*^9}, 
   3.5546576524176607`*^9, {3.554657708490981*^9, 3.5546577414516697`*^9}, {
   3.5546578006159687`*^9, 3.554657828983831*^9}, {3.555064370844635*^9, 
   3.555064385250565*^9}, {3.5551708390283737`*^9, 3.555170867739654*^9}, {
   3.5552637021785393`*^9, 3.5552637112970333`*^9}, 3.556603182851181*^9, 
   3.556603331742765*^9, {3.55660348289674*^9, 3.556603495897681*^9}, 
   3.557043882677291*^9, 3.557043983701639*^9, {3.5572072484857397`*^9, 
   3.5572072642279787`*^9}, 3.5572073680447187`*^9, 3.557207469048953*^9, {
   3.557207532809003*^9, 3.557207549744128*^9}, 3.557207767117255*^9, 
   3.557207929945424*^9, 3.5572086775767193`*^9, 3.5572087298118143`*^9, {
   3.5572091382367353`*^9, 3.55720915633365*^9}, 3.5572092963953333`*^9, 
   3.557209429814142*^9, 3.5572158962887783`*^9, 3.5573912002891083`*^9, 
   3.557391574587595*^9, 3.5573923712918663`*^9, {3.5573936526822357`*^9, 
   3.557393654207271*^9}, 3.5573944687423553`*^9, {3.557394816313151*^9, 
   3.557394845834958*^9}, {3.557394893448653*^9, 3.55739491627186*^9}, 
   3.5573949741895514`*^9, {3.557398277723606*^9, 3.557398301671763*^9}, 
   3.5574050742440147`*^9, 3.557504365200822*^9, 3.557555218341572*^9, 
   3.557589113482197*^9, 3.557739295876608*^9, {3.557739471039256*^9, 
   3.5577394753818293`*^9}, 3.562753104432859*^9, 3.56275318610849*^9, 
   3.562753477759244*^9, 3.562753566229475*^9, 3.562753955921987*^9, 
   3.563119641344646*^9, {3.563290865843299*^9, 3.563290867891015*^9}, {
   3.563291165247303*^9, 3.563291191224442*^9}, 3.56329287368295*^9, 
   3.563293111353644*^9, 3.563293339343655*^9, 3.5632935523182383`*^9, 
   3.563293593246901*^9, 3.563293651576387*^9, 3.563293834323365*^9, 
   3.563620887417611*^9, 3.56362126592406*^9, {3.563621301569706*^9, 
   3.563621343128489*^9}, 3.563633340668043*^9, {3.564210726877474*^9, 
   3.564210775892873*^9}, {3.564210844162661*^9, 3.564210873130417*^9}, 
   3.564220463462222*^9, {3.564239914633416*^9, 3.5642399232142067`*^9}, {
   3.564242640272049*^9, 3.564242661899024*^9}, {3.5643364165423937`*^9, 
   3.564336425445558*^9}, {3.5643364766181107`*^9, 3.564336482301577*^9}, {
   3.564375266265726*^9, 3.5643752733756*^9}, 3.564383760218378*^9, {
   3.564420789541357*^9, 3.564420864737459*^9}, {3.56442090227496*^9, 
   3.5644209058946333`*^9}, 3.564459118848886*^9, {3.564460799866702*^9, 
   3.564460817696002*^9}, 3.5644674218137608`*^9, 3.564477577828431*^9, 
   3.5644783861753407`*^9, 3.564478531208749*^9, {3.566034706567474*^9, 
   3.5660347328949757`*^9}, {3.566034777554575*^9, 3.566034784801989*^9}, 
   3.5661367388821383`*^9, 3.56613680558248*^9, {3.568648971476862*^9, 
   3.568648973543665*^9}, {3.568649004062286*^9, 3.568649047078418*^9}, 
   3.568657074422123*^9, 3.5686942451948757`*^9, 3.5687386859305687`*^9, {
   3.5720122628825207`*^9, 3.57201228199881*^9}, {3.572014719757648*^9, 
   3.572014724204927*^9}, 3.572014795986285*^9, 3.572014879273035*^9, 
   3.572015919776548*^9, {3.5720190069837437`*^9, 3.572019035377275*^9}, 
   3.572019522941901*^9, 3.572019668449237*^9, 3.572019797816325*^9, 
   3.5720203040113363`*^9, 3.5720208741177473`*^9, 3.57206719787799*^9, 
   3.572086281560055*^9, 3.5720863487147512`*^9, 3.572086452791595*^9, 
   3.572087452746438*^9, 3.572087513243477*^9, 3.572087660847622*^9, 
   3.572087894163962*^9, 3.572114585846671*^9, {3.572171654246595*^9, 
   3.572171656438197*^9}, 3.572171734796905*^9, {3.5721719623815937`*^9, 
   3.572171965469729*^9}, 3.57217202091262*^9, {3.572194873948105*^9, 
   3.572194884300334*^9}, {3.572252534703174*^9, 3.572252537046191*^9}, 
   3.572253300414853*^9, 3.572254253988761*^9, 3.572254692223521*^9, 
   3.572254851263934*^9, 3.572255063835442*^9, 3.5722552998871717`*^9, {
   3.5722842437750998`*^9, 3.572284251711459*^9}, 3.572284372910212*^9, 
   3.5723476390340567`*^9, 3.572347763884533*^9, 3.5723534586151657`*^9, {
   3.5723538434079237`*^9, 3.572353849456871*^9}, 3.572360388403021*^9, {
   3.572360490541038*^9, 3.572360502396728*^9}, 3.572360621718238*^9, {
   3.572455571344574*^9, 3.5724555784672613`*^9}, {3.572784732204767*^9, 
   3.572784760166497*^9}, {3.573357637876379*^9, 3.573357639816347*^9}, {
   3.573360530972642*^9, 3.5733605423144827`*^9}, 3.574760591311388*^9, 
   3.576504313593033*^9, 3.576511596876048*^9, {3.576511810645399*^9, 
   3.576511852338032*^9}, 3.576512289422798*^9, 3.5765123287410727`*^9, 
   3.576512370073312*^9, {3.576512961480832*^9, 3.576512972836647*^9}, 
   3.5765130538802023`*^9, {3.5765131706823483`*^9, 3.576513195686442*^9}, 
   3.5765143260465097`*^9, 3.576514397251598*^9, 3.576514472231398*^9, 
   3.5765196477414293`*^9, 3.576519828894815*^9, 3.576519862002242*^9, {
   3.576519974283821*^9, 3.57651999094121*^9}, 3.576524930442914*^9, 
   3.5766501583290052`*^9, {3.5767730719109507`*^9, 3.576773074158781*^9}, 
   3.5769906323560133`*^9, 3.576990699001289*^9, 3.5769907786538887`*^9, 
   3.576990823439889*^9, {3.577198000349237*^9, 3.577198025638427*^9}, 
   3.577198416893095*^9, {3.577198508033203*^9, 3.577198510184787*^9}, {
   3.577198605984647*^9, 3.5771986298961554`*^9}, 3.577198819984651*^9, 
   3.577199403889228*^9, 3.577199623445868*^9, 3.5772044565778*^9, {
   3.577261879791589*^9, 3.5772618857654753`*^9}, {3.577262025427031*^9, 
   3.577262048429865*^9}, {3.577342480722699*^9, 3.57734249541504*^9}, {
   3.577342838320467*^9, 3.5773428401299553`*^9}, {3.577360869686008*^9, 
   3.577360871948517*^9}, {3.5777160124718723`*^9, 3.577716014108659*^9}, {
   3.5885800880613327`*^9, 3.588580090189948*^9}, 3.5886497316226797`*^9, 
   3.588660003760792*^9, 3.5886609764780293`*^9, {3.59046864850095*^9, 
   3.590468650953718*^9}, {3.590469028049*^9, 3.590469035612535*^9}, 
   3.590469085261346*^9, 3.5904700780153027`*^9, {3.590656928664796*^9, 
   3.590656930593405*^9}, 3.590672808526771*^9, 3.590673322600754*^9, 
   3.5906733799097958`*^9, 3.590673458870077*^9, {3.590813082231382*^9, 
   3.590813141841138*^9}, {3.590813191966158*^9, 3.590813204673149*^9}, 
   3.5909019857756777`*^9, {3.5909020243445053`*^9, 3.5909020867147284`*^9}, 
   3.590915691937216*^9, {3.5909388295564823`*^9, 3.590938835338437*^9}, 
   3.590938875846842*^9, 3.5909891057944307`*^9, {3.590990718272015*^9, 
   3.590990731314279*^9}, {3.5910018219440117`*^9, 3.5910018310153103`*^9}, {
   3.591001990104844*^9, 3.591002000456848*^9}, {3.591252451453383*^9, 
   3.591252453152643*^9}, 3.591253112237088*^9, 3.5912531913133507`*^9, 
   3.5912541770238447`*^9, 3.5912542511202707`*^9, {3.591259138739263*^9, 
   3.591259183063888*^9}, 3.591259322521822*^9, 3.591267819711091*^9, {
   3.5913294038539743`*^9, 3.591329413063984*^9}, {3.591352018122363*^9, 
   3.591352019839457*^9}, 3.591352608813388*^9, {3.5913714579800262`*^9, 
   3.5913714602849483`*^9}, {3.5914113273149357`*^9, 3.591411331768703*^9}, {
   3.591508342044304*^9, 3.591508348971589*^9}, {3.591877064418826*^9, 
   3.5918771116034403`*^9}, 3.591952362849964*^9, 3.591953050414577*^9, 
   3.591953171672431*^9, 3.591953599173996*^9, 3.591953661891192*^9, 
   3.5919537408198223`*^9, {3.5919557814761477`*^9, 3.5919557910435677`*^9}, 
   3.591958050054686*^9, {3.592052722515538*^9, 3.5920527314550257`*^9}, 
   3.592052925531954*^9, 3.592110412279928*^9, 3.5921104458035593`*^9, 
   3.592110536116387*^9, 3.592642138148017*^9, 3.592651970374612*^9, 
   3.592655068451647*^9, {3.592655105085884*^9, 3.592655110071813*^9}, 
   3.5926551755446873`*^9, 3.592656034586945*^9, 3.592657276323567*^9, 
   3.592660057226182*^9, {3.592661424073071*^9, 3.592661431151182*^9}, 
   3.5926622673329153`*^9, {3.592675559548773*^9, 3.592675583207724*^9}, {
   3.592675624339472*^9, 3.592675643929874*^9}, {3.592675902732546*^9, 
   3.592675937635586*^9}, {3.592714682566625*^9, 3.59271469351265*^9}, 
   3.592714729297509*^9, 3.592718023403544*^9, 3.592718391590888*^9, 
   3.592725531834351*^9, 3.59272762239614*^9, 3.592730205778401*^9, 
   3.5927339135319138`*^9, {3.592733981647545*^9, 3.5927340030956697`*^9}, {
   3.592748576763071*^9, 3.592748585734343*^9}, 3.592793794532374*^9, 
   3.592793895513976*^9, {3.59279400914883*^9, 3.5927940430513353`*^9}, 
   3.5927942720849657`*^9, 3.592819544412829*^9, 3.592820078911571*^9, 
   3.5928201224891033`*^9, 3.592820320850068*^9, 3.5928208609534082`*^9, 
   3.59282139671628*^9, 3.5928221082684517`*^9, 3.592822244297883*^9, 
   3.5928250632244883`*^9, 3.5928898337954187`*^9, {3.592892071085148*^9, 
   3.592892087084156*^9}, 3.592892170965399*^9, 3.5928922110518503`*^9, {
   3.592892462264078*^9, 3.59289249351376*^9}, {3.5928925506969852`*^9, 
   3.592892556311309*^9}, {3.592892689535013*^9, 3.5928926993028316`*^9}, {
   3.592902918561487*^9, 3.5929029223163557`*^9}, 3.592904450449782*^9, 
   3.592904667551869*^9, 3.592904942903068*^9, 3.592904974105523*^9, 
   3.59290502474058*^9, 3.592905572165553*^9, 3.592906991514659*^9, 
   3.592981897667472*^9, 3.592983052365939*^9, {3.59298494195683*^9, 
   3.592984968410165*^9}, 3.592985060726647*^9, 3.593003868422555*^9, 
   3.5930786859464207`*^9, {3.5930788114171047`*^9, 3.593078814354246*^9}, 
   3.593078847084687*^9, 3.593081023929908*^9, 3.593164797237619*^9, 
   3.593165450008368*^9, 3.593165736142538*^9, 3.593505407622682*^9, {
   3.5935846085772057`*^9, 3.593584611249666*^9}, 3.593587781586492*^9, 
   3.593852656497983*^9, 3.59394472846449*^9, 3.593944862433148*^9, {
   3.594003530164383*^9, 3.594003540635169*^9}, 3.594003909978203*^9, 
   3.594031272928074*^9, 3.59403134397078*^9, {3.595309212567952*^9, 
   3.595309241976465*^9}, 3.595309329260269*^9, 3.595310660224545*^9, 
   3.59531113455013*^9, {3.595311233402629*^9, 3.595311253141189*^9}, 
   3.595311299995288*^9, 3.595311331676423*^9, 3.595311398418603*^9, {
   3.595311595161642*^9, 3.5953115979302464`*^9}, 3.595311633210622*^9, {
   3.595311668577585*^9, 3.595311672770331*^9}, {3.596346831506013*^9, 
   3.596346841486903*^9}, 3.596375868299177*^9, 3.5963763064444027`*^9, 
   3.5963768586931973`*^9, {3.596377065386838*^9, 3.59637707323591*^9}, {
   3.596377124269498*^9, 3.596377131073278*^9}, {3.596377187116062*^9, 
   3.596377215704887*^9}, 3.596377289881617*^9, 3.596435070428555*^9, 
   3.596435121158387*^9, 3.596538273080311*^9, {3.596538312156002*^9, 
   3.5965383152140493`*^9}, 3.596538396588505*^9, 3.596538624870192*^9, 
   3.596538743977462*^9, {3.596538791951955*^9, 3.5965388097480707`*^9}, 
   3.596538997381865*^9, 3.596539247731288*^9, {3.596541335882121*^9, 
   3.596541361320952*^9}, {3.597406869840568*^9, 3.597406872082171*^9}, 
   3.597407087926366*^9, {3.597407186408332*^9, 3.5974072128570147`*^9}, {
   3.597407246710915*^9, 3.597407258357163*^9}, 3.5974073173560543`*^9, 
   3.5974096324007607`*^9, {3.598119709737059*^9, 3.598119711477497*^9}, 
   3.598120433168222*^9, 3.598121021605102*^9, 3.598121103583084*^9, {
   3.59812204433881*^9, 3.598122075168559*^9}, 3.598122193392796*^9, 
   3.598122484849489*^9, 3.598122676267119*^9, 3.5981540240916767`*^9, 
   3.5981580423853817`*^9, 3.598165472699972*^9, 3.598165577560161*^9, 
   3.598165719125223*^9, 3.5981657856211243`*^9, 3.598166321277677*^9, 
   3.598167026822118*^9, {3.598167903978546*^9, 3.598167904961591*^9}, 
   3.598175315410966*^9, 3.5982831317377768`*^9, 3.5982836390429792`*^9, 
   3.598286992287978*^9, 3.5982909027203913`*^9, {3.598291198832191*^9, 
   3.5982912002432203`*^9}, {3.598291341646543*^9, 3.5982913453762083`*^9}, {
   3.598291475656177*^9, 3.598291487294619*^9}, {3.59853172687361*^9, 
   3.598531728658023*^9}, 3.598679786021976*^9, {3.598680069951858*^9, 
   3.5986800970585012`*^9}, 3.5986988344604816`*^9, 3.598698891176594*^9, {
   3.598728477050509*^9, 3.5987284780532703`*^9}, 3.5987816636759663`*^9, {
   3.5988100423180733`*^9, 3.5988100440352697`*^9}, {3.59887242675905*^9, 
   3.598872428725548*^9}, 3.59887937614281*^9, 3.598879456725876*^9, 
   3.5988819190314617`*^9, {3.598886135776182*^9, 3.59888613763615*^9}, 
   3.598886187506497*^9, 3.598886362448572*^9, {3.598938182942268*^9, 
   3.598938184659197*^9}, {3.598947658947979*^9, 3.5989476607539577`*^9}, {
   3.598960943848035*^9, 3.598960966247753*^9}, {3.598975066815968*^9, 
   3.598975082258492*^9}, 3.598975115583551*^9, 3.599203217375414*^9, 
   3.5992033732890043`*^9, {3.599203481328031*^9, 3.599203483411399*^9}, {
   3.599329697026661*^9, 3.5993296990275927`*^9}, 3.599384364791898*^9, {
   3.599415828653736*^9, 3.599415830674304*^9}, {3.600419179999693*^9, 
   3.600419182203286*^9}, {3.600494711335067*^9, 3.600494712433138*^9}, {
   3.6013622044103003`*^9, 3.601362219221046*^9}, {3.601362279322267*^9, 
   3.60136228063945*^9}, {3.601368295807447*^9, 3.601368308802229*^9}, {
   3.601445116296341*^9, 3.601445118161009*^9}, {3.601470066944476*^9, 
   3.601470070520792*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"s:\"\>", ",", "0.2546479089470325`", ",", "\<\"l:\"\>", ",", 
   "1963.495408493621`", ",", "\<\"zR:\"\>", ",", "981.7477042468105`", 
   ",", "\<\"w0G:\"\>", ",", "5.`*^-7", ",", "\<\"w0E:\"\>", ",", 
   "0.005541666666666667`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.554358830091385*^9, 3.554358865255776*^9, 3.554358913540926*^9, 
   3.554358962647942*^9, 3.554359030737906*^9, 3.554359495724883*^9, 
   3.554359631374332*^9, 3.554359943785555*^9, {3.554359979572698*^9, 
   3.55435999493254*^9}, 3.554360418614574*^9, 3.554360450789584*^9, 
   3.554360544343137*^9, {3.554362000337831*^9, 3.554362015515444*^9}, 
   3.55443359498532*^9, {3.5544340397374907`*^9, 3.554434045413167*^9}, 
   3.554435043797122*^9, 3.554435095751279*^9, {3.5544351886863623`*^9, 
   3.554435202588085*^9}, 3.554435260749197*^9, 3.5544357930771713`*^9, 
   3.5544364955884733`*^9, 3.554437021091709*^9, 3.554437832709882*^9, 
   3.554438305537958*^9, {3.554438343796096*^9, 3.5544383710765657`*^9}, {
   3.554438401330866*^9, 3.554438414763813*^9}, 3.554438493786646*^9, 
   3.5544385864387302`*^9, 3.554438651499035*^9, 3.5544390341301403`*^9, 
   3.554439071140037*^9, 3.554439120109458*^9, 3.554439155760347*^9, 
   3.554439213110135*^9, {3.5544392528949757`*^9, 3.554439264667676*^9}, 
   3.554440819194005*^9, 3.554440896251329*^9, 3.554441140044351*^9, {
   3.554441208550644*^9, 3.554441222399757*^9}, 3.5544412680265493`*^9, 
   3.554447990243992*^9, 3.554448461799959*^9, 3.554448875821843*^9, {
   3.554449325786501*^9, 3.5544493377578363`*^9}, {3.554449630597097*^9, 
   3.554449633969433*^9}, 3.554450567264997*^9, {3.554450628417693*^9, 
   3.55445064472488*^9}, {3.5544506753624077`*^9, 3.554450695784709*^9}, 
   3.554450727485261*^9, 3.554450801081851*^9, 3.554451481315361*^9, {
   3.554451620163546*^9, 3.554451647015533*^9}, 3.554453488648727*^9, 
   3.554453721445019*^9, 3.554453784972129*^9, 3.554453910321103*^9, 
   3.554454009798358*^9, {3.5544542778796463`*^9, 3.554454294036075*^9}, 
   3.55445433176127*^9, {3.554454949901557*^9, 3.554454980570551*^9}, 
   3.554455094598118*^9, {3.554455364653942*^9, 3.554455374069084*^9}, {
   3.554455421156849*^9, 3.554455426603117*^9}, {3.55445576007701*^9, 
   3.554455787937069*^9}, 3.5544558813582582`*^9, 3.554456078067572*^9, {
   3.554456171672131*^9, 3.5544561969906197`*^9}, {3.5544623979261436`*^9, 
   3.554462422899478*^9}, 3.5544624818101482`*^9, 3.554505707721221*^9, 
   3.55450574080121*^9, 3.554505811084465*^9, 3.554524572382772*^9, {
   3.554524729761052*^9, 3.554524744669938*^9}, {3.554525688052936*^9, 
   3.554525723137784*^9}, 3.55452577904255*^9, {3.554525811822513*^9, 
   3.5545258202728443`*^9}, {3.554525869214766*^9, 3.554525896476812*^9}, 
   3.5546576524176607`*^9, {3.554657708490981*^9, 3.5546577414516697`*^9}, {
   3.5546578006159687`*^9, 3.554657828983831*^9}, {3.555064370844635*^9, 
   3.555064385250565*^9}, {3.5551708390283737`*^9, 3.555170867739654*^9}, {
   3.5552637021785393`*^9, 3.5552637112970333`*^9}, 3.556603182851181*^9, 
   3.556603331742765*^9, {3.55660348289674*^9, 3.556603495897681*^9}, 
   3.557043882677291*^9, 3.557043983701639*^9, {3.5572072484857397`*^9, 
   3.5572072642279787`*^9}, 3.5572073680447187`*^9, 3.557207469048953*^9, {
   3.557207532809003*^9, 3.557207549744128*^9}, 3.557207767117255*^9, 
   3.557207929945424*^9, 3.5572086775767193`*^9, 3.5572087298118143`*^9, {
   3.5572091382367353`*^9, 3.55720915633365*^9}, 3.5572092963953333`*^9, 
   3.557209429814142*^9, 3.5572158962887783`*^9, 3.5573912002891083`*^9, 
   3.557391574587595*^9, 3.5573923712918663`*^9, {3.5573936526822357`*^9, 
   3.557393654207271*^9}, 3.5573944687423553`*^9, {3.557394816313151*^9, 
   3.557394845834958*^9}, {3.557394893448653*^9, 3.55739491627186*^9}, 
   3.5573949741895514`*^9, {3.557398277723606*^9, 3.557398301671763*^9}, 
   3.5574050742440147`*^9, 3.557504365200822*^9, 3.557555218341572*^9, 
   3.557589113482197*^9, 3.557739295876608*^9, {3.557739471039256*^9, 
   3.5577394753818293`*^9}, 3.562753104432859*^9, 3.56275318610849*^9, 
   3.562753477759244*^9, 3.562753566229475*^9, 3.562753955921987*^9, 
   3.563119641344646*^9, {3.563290865843299*^9, 3.563290867891015*^9}, {
   3.563291165247303*^9, 3.563291191224442*^9}, 3.56329287368295*^9, 
   3.563293111353644*^9, 3.563293339343655*^9, 3.5632935523182383`*^9, 
   3.563293593246901*^9, 3.563293651576387*^9, 3.563293834323365*^9, 
   3.563620887417611*^9, 3.56362126592406*^9, {3.563621301569706*^9, 
   3.563621343128489*^9}, 3.563633340668043*^9, {3.564210726877474*^9, 
   3.564210775892873*^9}, {3.564210844162661*^9, 3.564210873130417*^9}, 
   3.564220463462222*^9, {3.564239914633416*^9, 3.5642399232142067`*^9}, {
   3.564242640272049*^9, 3.564242661899024*^9}, {3.5643364165423937`*^9, 
   3.564336425445558*^9}, {3.5643364766181107`*^9, 3.564336482301577*^9}, {
   3.564375266265726*^9, 3.5643752733756*^9}, 3.564383760218378*^9, {
   3.564420789541357*^9, 3.564420864737459*^9}, {3.56442090227496*^9, 
   3.5644209058946333`*^9}, 3.564459118848886*^9, {3.564460799866702*^9, 
   3.564460817696002*^9}, 3.5644674218137608`*^9, 3.564477577828431*^9, 
   3.5644783861753407`*^9, 3.564478531208749*^9, {3.566034706567474*^9, 
   3.5660347328949757`*^9}, {3.566034777554575*^9, 3.566034784801989*^9}, 
   3.5661367388821383`*^9, 3.56613680558248*^9, {3.568648971476862*^9, 
   3.568648973543665*^9}, {3.568649004062286*^9, 3.568649047078418*^9}, 
   3.568657074422123*^9, 3.5686942451948757`*^9, 3.5687386859305687`*^9, {
   3.5720122628825207`*^9, 3.57201228199881*^9}, {3.572014719757648*^9, 
   3.572014724204927*^9}, 3.572014795986285*^9, 3.572014879273035*^9, 
   3.572015919776548*^9, {3.5720190069837437`*^9, 3.572019035377275*^9}, 
   3.572019522941901*^9, 3.572019668449237*^9, 3.572019797816325*^9, 
   3.5720203040113363`*^9, 3.5720208741177473`*^9, 3.57206719787799*^9, 
   3.572086281560055*^9, 3.5720863487147512`*^9, 3.572086452791595*^9, 
   3.572087452746438*^9, 3.572087513243477*^9, 3.572087660847622*^9, 
   3.572087894163962*^9, 3.572114585846671*^9, {3.572171654246595*^9, 
   3.572171656438197*^9}, 3.572171734796905*^9, {3.5721719623815937`*^9, 
   3.572171965469729*^9}, 3.57217202091262*^9, {3.572194873948105*^9, 
   3.572194884300334*^9}, {3.572252534703174*^9, 3.572252537046191*^9}, 
   3.572253300414853*^9, 3.572254253988761*^9, 3.572254692223521*^9, 
   3.572254851263934*^9, 3.572255063835442*^9, 3.5722552998871717`*^9, {
   3.5722842437750998`*^9, 3.572284251711459*^9}, 3.572284372910212*^9, 
   3.5723476390340567`*^9, 3.572347763884533*^9, 3.5723534586151657`*^9, {
   3.5723538434079237`*^9, 3.572353849456871*^9}, 3.572360388403021*^9, {
   3.572360490541038*^9, 3.572360502396728*^9}, 3.572360621718238*^9, {
   3.572455571344574*^9, 3.5724555784672613`*^9}, {3.572784732204767*^9, 
   3.572784760166497*^9}, {3.573357637876379*^9, 3.573357639816347*^9}, {
   3.573360530972642*^9, 3.5733605423144827`*^9}, 3.574760591311388*^9, 
   3.576504313593033*^9, 3.576511596876048*^9, {3.576511810645399*^9, 
   3.576511852338032*^9}, 3.576512289422798*^9, 3.5765123287410727`*^9, 
   3.576512370073312*^9, {3.576512961480832*^9, 3.576512972836647*^9}, 
   3.5765130538802023`*^9, {3.5765131706823483`*^9, 3.576513195686442*^9}, 
   3.5765143260465097`*^9, 3.576514397251598*^9, 3.576514472231398*^9, 
   3.5765196477414293`*^9, 3.576519828894815*^9, 3.576519862002242*^9, {
   3.576519974283821*^9, 3.57651999094121*^9}, 3.576524930442914*^9, 
   3.5766501583290052`*^9, {3.5767730719109507`*^9, 3.576773074158781*^9}, 
   3.5769906323560133`*^9, 3.576990699001289*^9, 3.5769907786538887`*^9, 
   3.576990823439889*^9, {3.577198000349237*^9, 3.577198025638427*^9}, 
   3.577198416893095*^9, {3.577198508033203*^9, 3.577198510184787*^9}, {
   3.577198605984647*^9, 3.5771986298961554`*^9}, 3.577198819984651*^9, 
   3.577199403889228*^9, 3.577199623445868*^9, 3.5772044565778*^9, {
   3.577261879791589*^9, 3.5772618857654753`*^9}, {3.577262025427031*^9, 
   3.577262048429865*^9}, {3.577342480722699*^9, 3.57734249541504*^9}, {
   3.577342838320467*^9, 3.5773428401299553`*^9}, {3.577360869686008*^9, 
   3.577360871948517*^9}, {3.5777160124718723`*^9, 3.577716014108659*^9}, {
   3.5885800880613327`*^9, 3.588580090189948*^9}, 3.5886497316226797`*^9, 
   3.588660003760792*^9, 3.5886609764780293`*^9, {3.59046864850095*^9, 
   3.590468650953718*^9}, {3.590469028049*^9, 3.590469035612535*^9}, 
   3.590469085261346*^9, 3.5904700780153027`*^9, {3.590656928664796*^9, 
   3.590656930593405*^9}, 3.590672808526771*^9, 3.590673322600754*^9, 
   3.5906733799097958`*^9, 3.590673458870077*^9, {3.590813082231382*^9, 
   3.590813141841138*^9}, {3.590813191966158*^9, 3.590813204673149*^9}, 
   3.5909019857756777`*^9, {3.5909020243445053`*^9, 3.5909020867147284`*^9}, 
   3.590915691937216*^9, {3.5909388295564823`*^9, 3.590938835338437*^9}, 
   3.590938875846842*^9, 3.5909891057944307`*^9, {3.590990718272015*^9, 
   3.590990731314279*^9}, {3.5910018219440117`*^9, 3.5910018310153103`*^9}, {
   3.591001990104844*^9, 3.591002000456848*^9}, {3.591252451453383*^9, 
   3.591252453152643*^9}, 3.591253112237088*^9, 3.5912531913133507`*^9, 
   3.5912541770238447`*^9, 3.5912542511202707`*^9, {3.591259138739263*^9, 
   3.591259183063888*^9}, 3.591259322521822*^9, 3.591267819711091*^9, {
   3.5913294038539743`*^9, 3.591329413063984*^9}, {3.591352018122363*^9, 
   3.591352019839457*^9}, 3.591352608813388*^9, {3.5913714579800262`*^9, 
   3.5913714602849483`*^9}, {3.5914113273149357`*^9, 3.591411331768703*^9}, {
   3.591508342044304*^9, 3.591508348971589*^9}, {3.591877064418826*^9, 
   3.5918771116034403`*^9}, 3.591952362849964*^9, 3.591953050414577*^9, 
   3.591953171672431*^9, 3.591953599173996*^9, 3.591953661891192*^9, 
   3.5919537408198223`*^9, {3.5919557814761477`*^9, 3.5919557910435677`*^9}, 
   3.591958050054686*^9, {3.592052722515538*^9, 3.5920527314550257`*^9}, 
   3.592052925531954*^9, 3.592110412279928*^9, 3.5921104458035593`*^9, 
   3.592110536116387*^9, 3.592642138148017*^9, 3.592651970374612*^9, 
   3.592655068451647*^9, {3.592655105085884*^9, 3.592655110071813*^9}, 
   3.5926551755446873`*^9, 3.592656034586945*^9, 3.592657276323567*^9, 
   3.592660057226182*^9, {3.592661424073071*^9, 3.592661431151182*^9}, 
   3.5926622673329153`*^9, {3.592675559548773*^9, 3.592675583207724*^9}, {
   3.592675624339472*^9, 3.592675643929874*^9}, {3.592675902732546*^9, 
   3.592675937635586*^9}, {3.592714682566625*^9, 3.59271469351265*^9}, 
   3.592714729297509*^9, 3.592718023403544*^9, 3.592718391590888*^9, 
   3.592725531834351*^9, 3.59272762239614*^9, 3.592730205778401*^9, 
   3.5927339135319138`*^9, {3.592733981647545*^9, 3.5927340030956697`*^9}, {
   3.592748576763071*^9, 3.592748585734343*^9}, 3.592793794532374*^9, 
   3.592793895513976*^9, {3.59279400914883*^9, 3.5927940430513353`*^9}, 
   3.5927942720849657`*^9, 3.592819544412829*^9, 3.592820078911571*^9, 
   3.5928201224891033`*^9, 3.592820320850068*^9, 3.5928208609534082`*^9, 
   3.59282139671628*^9, 3.5928221082684517`*^9, 3.592822244297883*^9, 
   3.5928250632244883`*^9, 3.5928898337954187`*^9, {3.592892071085148*^9, 
   3.592892087084156*^9}, 3.592892170965399*^9, 3.5928922110518503`*^9, {
   3.592892462264078*^9, 3.59289249351376*^9}, {3.5928925506969852`*^9, 
   3.592892556311309*^9}, {3.592892689535013*^9, 3.5928926993028316`*^9}, {
   3.592902918561487*^9, 3.5929029223163557`*^9}, 3.592904450449782*^9, 
   3.592904667551869*^9, 3.592904942903068*^9, 3.592904974105523*^9, 
   3.59290502474058*^9, 3.592905572165553*^9, 3.592906991514659*^9, 
   3.592981897667472*^9, 3.592983052365939*^9, {3.59298494195683*^9, 
   3.592984968410165*^9}, 3.592985060726647*^9, 3.593003868422555*^9, 
   3.5930786859464207`*^9, {3.5930788114171047`*^9, 3.593078814354246*^9}, 
   3.593078847084687*^9, 3.593081023929908*^9, 3.593164797237619*^9, 
   3.593165450008368*^9, 3.593165736142538*^9, 3.593505407622682*^9, {
   3.5935846085772057`*^9, 3.593584611249666*^9}, 3.593587781586492*^9, 
   3.593852656497983*^9, 3.59394472846449*^9, 3.593944862433148*^9, {
   3.594003530164383*^9, 3.594003540635169*^9}, 3.594003909978203*^9, 
   3.594031272928074*^9, 3.59403134397078*^9, {3.595309212567952*^9, 
   3.595309241976465*^9}, 3.595309329260269*^9, 3.595310660224545*^9, 
   3.59531113455013*^9, {3.595311233402629*^9, 3.595311253141189*^9}, 
   3.595311299995288*^9, 3.595311331676423*^9, 3.595311398418603*^9, {
   3.595311595161642*^9, 3.5953115979302464`*^9}, 3.595311633210622*^9, {
   3.595311668577585*^9, 3.595311672770331*^9}, {3.596346831506013*^9, 
   3.596346841486903*^9}, 3.596375868299177*^9, 3.5963763064444027`*^9, 
   3.5963768586931973`*^9, {3.596377065386838*^9, 3.59637707323591*^9}, {
   3.596377124269498*^9, 3.596377131073278*^9}, {3.596377187116062*^9, 
   3.596377215704887*^9}, 3.596377289881617*^9, 3.596435070428555*^9, 
   3.596435121158387*^9, 3.596538273080311*^9, {3.596538312156002*^9, 
   3.5965383152140493`*^9}, 3.596538396588505*^9, 3.596538624870192*^9, 
   3.596538743977462*^9, {3.596538791951955*^9, 3.5965388097480707`*^9}, 
   3.596538997381865*^9, 3.596539247731288*^9, {3.596541335882121*^9, 
   3.596541361320952*^9}, {3.597406869840568*^9, 3.597406872082171*^9}, 
   3.597407087926366*^9, {3.597407186408332*^9, 3.5974072128570147`*^9}, {
   3.597407246710915*^9, 3.597407258357163*^9}, 3.5974073173560543`*^9, 
   3.5974096324007607`*^9, {3.598119709737059*^9, 3.598119711477497*^9}, 
   3.598120433168222*^9, 3.598121021605102*^9, 3.598121103583084*^9, {
   3.59812204433881*^9, 3.598122075168559*^9}, 3.598122193392796*^9, 
   3.598122484849489*^9, 3.598122676267119*^9, 3.5981540240916767`*^9, 
   3.5981580423853817`*^9, 3.598165472699972*^9, 3.598165577560161*^9, 
   3.598165719125223*^9, 3.5981657856211243`*^9, 3.598166321277677*^9, 
   3.598167026822118*^9, {3.598167903978546*^9, 3.598167904961591*^9}, 
   3.598175315410966*^9, 3.5982831317377768`*^9, 3.5982836390429792`*^9, 
   3.598286992287978*^9, 3.5982909027203913`*^9, {3.598291198832191*^9, 
   3.5982912002432203`*^9}, {3.598291341646543*^9, 3.5982913453762083`*^9}, {
   3.598291475656177*^9, 3.598291487294619*^9}, {3.59853172687361*^9, 
   3.598531728658023*^9}, 3.598679786021976*^9, {3.598680069951858*^9, 
   3.5986800970585012`*^9}, 3.5986988344604816`*^9, 3.598698891176594*^9, {
   3.598728477050509*^9, 3.5987284780532703`*^9}, 3.5987816636759663`*^9, {
   3.5988100423180733`*^9, 3.5988100440352697`*^9}, {3.59887242675905*^9, 
   3.598872428725548*^9}, 3.59887937614281*^9, 3.598879456725876*^9, 
   3.5988819190314617`*^9, {3.598886135776182*^9, 3.59888613763615*^9}, 
   3.598886187506497*^9, 3.598886362448572*^9, {3.598938182942268*^9, 
   3.598938184659197*^9}, {3.598947658947979*^9, 3.5989476607539577`*^9}, {
   3.598960943848035*^9, 3.598960966247753*^9}, {3.598975066815968*^9, 
   3.598975082258492*^9}, 3.598975115583551*^9, 3.599203217375414*^9, 
   3.5992033732890043`*^9, {3.599203481328031*^9, 3.599203483411399*^9}, {
   3.599329697026661*^9, 3.5993296990275927`*^9}, 3.599384364791898*^9, {
   3.599415828653736*^9, 3.599415830674304*^9}, {3.600419179999693*^9, 
   3.600419182203286*^9}, {3.600494711335067*^9, 3.600494712433138*^9}, {
   3.6013622044103003`*^9, 3.601362219221046*^9}, {3.601362279322267*^9, 
   3.60136228063945*^9}, {3.601368295807447*^9, 3.601368308802229*^9}, {
   3.601445116296341*^9, 3.601445118161009*^9}, {3.601470066944476*^9, 
   3.601470070521974*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "MIE-COEFFICIENTS ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "n"], TraditionalForm]], "None"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", 
    RowBox[{"n", " "}]], TraditionalForm]], "None"],
 StyleBox["(Please read information concerning ",
  FontSize->12],
 StyleBox["SIGN CONVENTION",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[" below!)",
  FontSize->12],
 "\n",
 StyleBox["Riccarti - Bessel \.06function xi : ",
  FontSize->12],
 "\n",
 Cell[BoxData[
  StyleBox[
   RowBox[{"   ", "  ", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Photothermal", " ", "and", " ", "Multilayer"}], "-", 
        RowBox[{"Coefs", "."}]}], ":", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"corresponds", " ", "to", " ", "H1", " ", "and"}], ")"}], 
        " ", "plus", " ", "\"\<+\>\"", " ", "sign"}]}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"i", ".", "e", ".", " ", 
         SubscriptBox["n", "Au"]}], 
        RowBox[{"(", 
         RowBox[{"532", "nm"}], ")"}]}], "=", 
       RowBox[{"0.5163", "+", 
        RowBox[{"2.2304", " ", "I"}]}]}]}], " ", "\[IndentingNewLine]", 
     "      ", 
     RowBox[{"Gouesbet", ",", " ", "Nearfields", ",", " ", 
      RowBox[{
       RowBox[{"RadPressures", "  ", 
        RowBox[{"etc", "."}]}], ":", " ", 
       RowBox[{
       "H2", " ", "and", " ", "minus", " ", "\"\<-\>\"", " ", "sign"}]}], ",",
       " ", 
      RowBox[{
       RowBox[{
        RowBox[{"i", ".", "e", ".", "  ", 
         SubscriptBox["n", "Au"]}], 
        RowBox[{"(", 
         RowBox[{"532", "nm"}], ")"}]}], "=", 
       RowBox[{"0.5163", "-", 
        RowBox[{"2.2304", " ", "I", "  "}]}]}]}]}]}],
   FontSize->12,
   FontColor->RGBColor[1, 0, 0],
   Background->RGBColor[1, 0.85, 0.85]]], "Text",
  InitializationCell->True,
  CellChangeTimes->{{3.497679293332241*^9, 3.497679311135788*^9}, 
    3.4976910585174065`*^9, {3.497691089835766*^9, 3.497691127150219*^9}, {
    3.4976911798367424`*^9, 3.4976911799968987`*^9}, {3.4976914407937737`*^9, 
    3.4976914413533435`*^9}, {3.4976914896785393`*^9, 
    3.4976914900261955`*^9}, {3.49772132537926*^9, 3.497721339464965*^9}, {
    3.497721570260353*^9, 3.497721598022975*^9}, {3.497721749402769*^9, 
    3.497721762310053*^9}, {3.4977217972727537`*^9, 3.4977218026468554`*^9}, 
    3.4977218349709177`*^9, {3.497721891211123*^9, 3.497721903768449*^9}, 
    3.49772196643891*^9, {3.4977221601291847`*^9, 3.497722185887884*^9}, {
    3.497722242014049*^9, 3.497722243310285*^9}, {3.497722275862769*^9, 
    3.497722275970105*^9}, 3.4977224348748493`*^9, {3.4977229731364822`*^9, 
    3.497723000014002*^9}, {3.4977238550572367`*^9, 3.4977238554144363`*^9}, {
    3.497723910366666*^9, 3.497723977430134*^9}, {3.497726965139494*^9, 
    3.497726986421715*^9}, {3.497776478969555*^9, 3.4977764811267815`*^9}, {
    3.497777430895336*^9, 3.497777433495922*^9}, 3.4977775617029533`*^9, {
    3.49779038878318*^9, 3.497790415014697*^9}, {3.497794082126857*^9, 
    3.4977940969297132`*^9}, {3.497801845201638*^9, 3.497801940001289*^9}, 
    3.497801975350624*^9, {3.497802014252404*^9, 3.497802020197878*^9}, {
    3.497802052282159*^9, 3.497802052396743*^9}, 3.497802310840019*^9, {
    3.497802653906659*^9, 3.497802682161769*^9}, {3.497808600540502*^9, 
    3.497808607650961*^9}, 3.497808668699174*^9, {3.497808706986237*^9, 
    3.497808721164303*^9}, {3.4978088072476482`*^9, 3.4978088141990757`*^9}, {
    3.497809053490217*^9, 3.4978090605601673`*^9}, {3.4978103014510717`*^9, 
    3.4978103770193453`*^9}, {3.497812709771573*^9, 3.497812714534457*^9}, {
    3.49786188195744*^9, 3.497861885312722*^9}, 3.4978671955675383`*^9, {
    3.498283607300857*^9, 3.498283618488854*^9}, {3.498286561151466*^9, 
    3.498286602612596*^9}, {3.498305987823595*^9, 3.498305999290082*^9}, 
    3.4984587480803432`*^9, {3.4984654932136803`*^9, 
    3.4984654937634706`*^9}, {3.4984655289584017`*^9, 3.4984655293138227`*^9},
     3.498471095479938*^9, {3.4984772889311857`*^9, 3.498477314656807*^9}, 
    3.498907445117175*^9, {3.498908229192465*^9, 3.498908229379212*^9}, {
    3.498909133123087*^9, 3.498909137412986*^9}, {3.498910465415127*^9, 
    3.498910472713295*^9}, {3.498913997988604*^9, 3.4989139981235943`*^9}, {
    3.498914044248953*^9, 3.4989140444040003`*^9}, {3.4989242481077633`*^9, 
    3.498924258711973*^9}, {3.498924495285656*^9, 3.498924503175386*^9}, {
    3.4989248362605257`*^9, 3.498924844196879*^9}, {3.498926513767701*^9, 
    3.498926516569848*^9}, {3.498926648318211*^9, 3.498926654989155*^9}, {
    3.4989896674195127`*^9, 3.4989896684066477`*^9}, {3.498990506010316*^9, 
    3.498990513117537*^9}, {3.498990961287756*^9, 3.49899096745578*^9}, {
    3.4990624977519073`*^9, 3.49906251192861*^9}, {3.499063058123124*^9, 
    3.4990630592149067`*^9}, 3.499063347322259*^9, {3.4990636296587954`*^9, 
    3.49906363253699*^9}, {3.4990637398070602`*^9, 3.499063745369041*^9}, 
    3.4990642800514517`*^9, 3.4990801117228603`*^9, {3.499080305501318*^9, 
    3.499080308325286*^9}, {3.499160548274925*^9, 3.4991605521064043`*^9}, {
    3.499161023996531*^9, 3.499161026555059*^9}, {3.499161440224216*^9, 
    3.499161444143832*^9}, {3.499163325826466*^9, 3.4991633288822613`*^9}, {
    3.499172034004579*^9, 3.499172037384995*^9}, {3.499172834333021*^9, 
    3.499172838850675*^9}, {3.499173043551001*^9, 3.499173046009667*^9}, {
    3.499173157549073*^9, 3.499173160513274*^9}, {3.49942808085717*^9, 
    3.499428087390359*^9}, {3.500206447540786*^9, 3.500206456023302*^9}, {
    3.508589187074369*^9, 3.508589190231892*^9}, {3.508589476850644*^9, 
    3.508589477348749*^9}, {3.509170498779584*^9, 3.509170505949778*^9}, {
    3.509170589295842*^9, 3.509170598956603*^9}, {3.5091706523625507`*^9, 
    3.509170658059001*^9}, {3.515318592297471*^9, 3.515318595836187*^9}, {
    3.515387946050088*^9, 3.515387950131812*^9}, {3.5165588160855722`*^9, 
    3.5165588188258343`*^9}, {3.51659636067799*^9, 3.516596361320985*^9}, {
    3.516596438546509*^9, 3.516596439519425*^9}, {3.516597085231395*^9, 
    3.516597086470118*^9}, {3.51659787660032*^9, 3.5165978936755457`*^9}, {
    3.517039463911162*^9, 3.517039474548794*^9}, {3.5237776182622347`*^9, 
    3.523777684667384*^9}, {3.528442316587049*^9, 3.528442318165063*^9}, {
    3.5284424733858147`*^9, 3.528442475209852*^9}, {3.528442685207932*^9, 
    3.5284426857944717`*^9}, {3.528442953987035*^9, 3.5284429846481256`*^9}, {
    3.5284507666223927`*^9, 3.5284507667840652`*^9}, {3.52845097245695*^9, 
    3.5284509856091967`*^9}, {3.528451312452523*^9, 3.528451312669868*^9}, {
    3.529644872179673*^9, 3.5296449006552877`*^9}, {3.529645362971634*^9, 
    3.52964539217627*^9}, {3.5296464753971043`*^9, 3.529646475591346*^9}, {
    3.529647169063978*^9, 3.529647169396578*^9}, {3.529649905201055*^9, 
    3.529649906343062*^9}, {3.529655641621482*^9, 3.529655662949066*^9}, {
    3.529656954436404*^9, 3.529656955149273*^9}, 3.529686467808062*^9, {
    3.52969186833315*^9, 3.529691869421298*^9}, {3.529734606679757*^9, 
    3.5297346265927267`*^9}, {3.529762118479937*^9, 3.529762119219027*^9}, {
    3.529780246934883*^9, 3.529780247266218*^9}, {3.529815738091066*^9, 
    3.529815747640449*^9}, {3.5298162916389847`*^9, 3.5298163049870253`*^9}, {
    3.52981641462272*^9, 3.529816431643127*^9}, {3.529817467083869*^9, 
    3.529817468394849*^9}, {3.529828554087121*^9, 3.529828557632923*^9}, {
    3.5298377116949368`*^9, 3.52983774266153*^9}, {3.529837784012268*^9, 
    3.5298377873534822`*^9}, {3.530514165820072*^9, 3.5305141660926123`*^9}, {
    3.530519836088729*^9, 3.5305198363613567`*^9}, {3.531025988709428*^9, 
    3.531026013224771*^9}, {3.531026163231715*^9, 3.531026170141305*^9}, {
    3.531026321071066*^9, 3.5310263375185328`*^9}, {3.531473128740703*^9, 
    3.531473157027091*^9}, 3.5315889720604343`*^9, {3.531632664894644*^9, 
    3.531632665486025*^9}, {3.532106877147643*^9, 3.5321068809947853`*^9}, {
    3.5321069981023417`*^9, 3.532107109692912*^9}, {3.53210716548494*^9, 
    3.532107250402657*^9}, {3.532107325394965*^9, 3.532107344065818*^9}, 
    3.532107391450946*^9, {3.532108064517661*^9, 3.5321080783195753`*^9}, 
    3.532118597138898*^9, {3.532275337607031*^9, 3.532275338893052*^9}, {
    3.532276030704335*^9, 3.5322760746648617`*^9}, {3.532276121560622*^9, 
    3.5322761225254917`*^9}, {3.532276278969397*^9, 3.532276288388688*^9}, {
    3.532277454290394*^9, 3.532277455257657*^9}, {3.532281652034698*^9, 
    3.532281655600101*^9}, 3.532368085348022*^9, 3.532368344027742*^9, 
    3.532368376204671*^9, {3.5323684466232157`*^9, 3.532368494004251*^9}, {
    3.532368634586609*^9, 3.532368644638282*^9}, {3.5323687247489643`*^9, 
    3.532368727968088*^9}, {3.5323688393619337`*^9, 3.532368954385887*^9}, {
    3.532427670113476*^9, 3.532427671015189*^9}, {3.532427826514886*^9, 
    3.532427827176198*^9}, {3.534743131478382*^9, 3.534743131981379*^9}, {
    3.534743163085504*^9, 3.534743163467737*^9}, {3.5347437584336777`*^9, 
    3.534743774984112*^9}, {3.534743970576194*^9, 3.534743998366474*^9}, {
    3.534745813770913*^9, 3.5347458214501953`*^9}, {3.535178367294001*^9, 
    3.5351784018195887`*^9}, {3.535178560434997*^9, 3.5351785605938587`*^9}, {
    3.535178654971407*^9, 3.535178699302227*^9}, {3.535179478708027*^9, 
    3.535179488178892*^9}, {3.536678694995782*^9, 3.536678718167942*^9}, {
    3.538457139791945*^9, 3.538457141192031*^9}, {3.538457431973028*^9, 
    3.538457447216082*^9}, {3.5389985087457438`*^9, 3.53899852265202*^9}, {
    3.540577983837792*^9, 3.540577985381318*^9}, {3.540578066338348*^9, 
    3.540578066586337*^9}, {3.542353416707424*^9, 3.5423534249436626`*^9}, {
    3.542353567332198*^9, 3.5423535778438873`*^9}, {3.542354860256979*^9, 
    3.5423548701430817`*^9}, {3.5423552085091867`*^9, 3.542355215120421*^9}, {
    3.5423569751576023`*^9, 3.542356989967235*^9}, {3.543900544366967*^9, 
    3.543900562480075*^9}, {3.543900808527608*^9, 3.543900821669887*^9}, {
    3.5478310177935743`*^9, 3.547831018327734*^9}, {3.547831412738585*^9, 
    3.547831417078899*^9}, {3.547832115820421*^9, 3.547832159728569*^9}, {
    3.547834492495185*^9, 3.547834495966104*^9}, {3.547882838738327*^9, 
    3.54788284384301*^9}, 3.5478899420787277`*^9, {3.547893203971627*^9, 
    3.5478932167280207`*^9}, {3.547893471548398*^9, 3.547893474056078*^9}, {
    3.547893622810422*^9, 3.547893638827704*^9}, {3.547915057194215*^9, 
    3.5479150911172256`*^9}, {3.5479154008001833`*^9, 3.547915442347324*^9}, {
    3.547915986969235*^9, 3.5479160016286697`*^9}, {3.547918165005031*^9, 
    3.547918175075529*^9}, {3.547918557011546*^9, 3.5479185610698223`*^9}, {
    3.547919912481065*^9, 3.547919950553218*^9}, {3.54792005825746*^9, 
    3.547920059115597*^9}, {3.547920251150463*^9, 3.5479202544878817`*^9}, {
    3.5479209990464687`*^9, 3.5479209991657877`*^9}, {3.547921351940798*^9, 
    3.5479213583834057`*^9}, {3.547921401615552*^9, 3.547921413543582*^9}, {
    3.554279521975708*^9, 3.554279528053816*^9}, {3.554279685109273*^9, 
    3.5542797268268538`*^9}},
  FontSize->12],
 StyleBox["\nit is sometimes useful to check if the absorption cross-section \
> 0. However, only Re[an,bn] and Abs[an,bn] will be checked this way.",
  FontSize->12]
}], "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGBQAGIQ3RAXZ+zN/8oxIYzdDERbsD951gakOSLkn4PoOWey
07uAtJZlN5jO8vzX1A2kH5WzNYPotFdpvgpCrxxNvKL8QPSyv581piu+csx7
9VAXRFuw3f4fb/zKUePNWYYEIL1CvJwTRC9f/AFMz9pjlujs88rx+cdaML1t
3vfZXwNeObbMrpoDohNS1u6Sy3/lWHWdaw+Inr5r6mEQLRJ7F0wnCV9ic6h+
5eh09iQHiFYR/60Eojv2piqD6DCBE04g+uG2AFcQLXTQ2sgRSAe9cQbTp15X
mIHojn+BFiC6RS7fDkSvEvzqA1bH2xgBordNnBkFov+5bFroBKSX8DMvAtFH
PR5lOQNpHv6b2SA6Lnv9lmQgnba5fCuI3sixwTQFSDM9v2wGonX+R1VnAOma
NUlg2uj5M/tiIM23vtUJRLP+DvHuBdK3ZP8HgWgzh5dVIPrFxfhOEL0p3Kof
RKs4s08G0WpH/yVNBtJSJjlpIPrSntT524G0zVrXdSD6YVzRz6sNrxx39+z6
BaK9PC72rzrwyvHX8VkTQDQAr6r8Ug==
  "],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzVV1kobl0YJhdSx4Vy40L5USTcKOpXEsmQKT8JRb6IEBmSzpGcyI0phUwp
04WxfkMKHYUMmcfInDiZ53k6z/l2326dtfde3+DvL099X2uvtfb7rme94/5L
lhQg09HS0vqCXwF+v8fvmmJgYGBqaoqc6e3tXVhY0FigqExRPD4+CjXu7+97
enoODw97eXn9J3oZdJ6enmJiYtTV8hG0trZqa2s3NjZivLi4aGZm1t/fz35l
Y2MjKiqKmnx5eQkMDDw/P9fsGKIyKezu7sbHxycmJgo14nVfX9/Ly0t/f3/y
FaXspPQy6AwODtbV1alDTgne3t6+K5CVlWVoaOjs7Ozt7T0yMsLvsbOz41iA
viqx4ObmdnJyIpyfmJiIjY3V7JxSMikUFBTATEKNpaWl9fX1Ozs7qamp1Cts
dgy9UnTS09OPjo6UHlUU19fXPxWAGwg3ZGdnGxgYTE9PZ2RkUPPBwcGFhYXd
3d1KtSDSLSws+EcnJyc7OXp6eh4eHiwtLTU4OSWTgaKiItJGvEac//b2tqOj
IzMzk3J+BjsGF1I4hcjISPzb2NiMj4+T84eHhxEREfn5+TiGtbX10tISuYqA
RTaOi4vLVuD09JSSjMDR0dFpa2uDp8Ga5BKspqenV1JSouSC5JiZmXF3d+fG
e3t7o6OjKBC1tbUIWMyYmppeXV3xmysrK/9WALeEF/nHtbU1UZlsUDaiNL6+
vgqdk8GOzUVIB9je3kZGwgB2pK4RCAgIQESvrq4GBQWRSRUCPTw8zs7OGNQu
Li5MTEyio6OrqqpwMGoV/qCvr//8/MyQwKOhoYHKAPBPPl24uLggRagiR0rm
+vr6P38iPDyc3ym0kVKNDHZsLqLCy8rKJicnpXQZGxt3dXVhYG5uThoXpEJD
Q8cJCIWEhIQgbMfGxioqKoSS8/LyUKEYNEm0tLRwwc5heXmZVOfo6Dg/P88/
bm5u/lAAgTM0NMQ/kk5IysRlnvwJMicIbURpVIsdm4uocJlMxkcZhZWVFSMj
I0TiwcEBEia5NDs7izgqJIBwIzegCdHV1UUgU2WIh6urK2qxFEeqrYVf+fj4
cEs3Nzft7e3kZisrK/JK+/r6virQ2dmZk5PDP4IIv42UyQbYUTaiNLLZqcVF
KPzu7g4FhRujS7y/vyc3l5eXp6SkvMubyeTkZMQOv4TShpCUMi5KFSK9uLg4
Nzf3+PiYWkX2rq6uRneakJCAkvcuz945BHCTVFuLnG9ra8upg1M5ODiAOPag
1YHPo+wyrksKpEwGwBrlw97eHh7LzbA1CtmpzkVUOGoQ7p8bI2TS0tLIVXQm
+NR6lwd7WFjY1tYWuYry5OfnV1NT868C8ApuCaRgI/geBt8IUF0HA8K2Fn0L
6hoGcCRkLQiHeyOVITqExU5F8DLVgroaVeciKjwpKQn25cYo8U1NTaJakK75
D20SeBffVl0KoBFV/eRsiLa1zc3Nc3Nz5DakNXD8iCKhTDY00KgiFynhZJpF
n6xil/W/QbSt/aT4XFx+AdPHQc0=
    "], {{0, 12}, {140, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{140, 12},
  PlotRange->{{0, 140}, {0, 12}}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"prepares", " ", "units", " ", "for", " ", "later"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]m", "=", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]]}], ";", 
    RowBox[{"c", "=", "299792458"}], ";", 
    RowBox[{"nm", "=", 
     SuperscriptBox["10", 
      RowBox[{"-", "9"}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Bessel", " ", "related", " ", "functions", " ", "needed", " ", "for", 
     " ", "Mie", " ", 
     RowBox[{"coeff", "."}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"psi", "[", 
     RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
    RowBox[{"x", " ", 
     RowBox[{"SphericalBesselJ", "[", 
      RowBox[{"n", ",", "x"}], "]"}]}]}], 
   RowBox[{"(*", 
    RowBox[{"Riccarti", " ", "\.06Bessel", " ", "\.06Functions"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xi", "[", 
     RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
    RowBox[{"x", " ", 
     RowBox[{"SphericalHankelH2", "[", 
      RowBox[{"n", ",", "x"}], "]"}]}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"psidev", "[", 
      RowBox[{"n_", ",", "x_"}], "]"}], ":=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"0", ",", "1"}], "]"}], "[", "psi", "]"}], "[", 
      RowBox[{"n", ",", "x"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xidev", "[", 
      RowBox[{"n_", ",", "x_"}], "]"}], ":=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"0", ",", "1"}], "]"}], "[", "xi", "]"}], "[", 
      RowBox[{"n", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Mie", " ", 
     RowBox[{"Coeff", ".", " ", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["a", "n"], ",", 
        SubscriptBox["b", "n"], ",", 
        SubscriptBox["c", "n"], ",", 
        SubscriptBox["d", "n"]}], "}"}]}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"aMie", "[", 
      RowBox[{"n_", ",", "x_", ",", "m_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m", " ", 
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}], 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", "x"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m", " ", 
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}], 
         RowBox[{"xidev", "[", 
          RowBox[{"n", ",", "x"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"xi", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}]}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"bMie", "[", 
      RowBox[{"n_", ",", "x_", ",", "m_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}], 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", "x"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}], 
         RowBox[{"xidev", "[", 
          RowBox[{"n", ",", "x"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
         RowBox[{"xi", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cMie", "[", 
      RowBox[{"n_", ",", "x_", ",", "m_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"m", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"xi", "[", 
            RowBox[{"n", ",", "x"}], "]"}], 
           RowBox[{"psidev", "[", 
            RowBox[{"n", ",", "x"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"psi", "[", 
            RowBox[{"n", ",", "x"}], "]"}], 
           RowBox[{"xidev", "[", 
            RowBox[{"n", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}], 
         RowBox[{"xi", "[", 
          RowBox[{"n", ",", "x"}], "]"}]}], "-", 
        RowBox[{"m", " ", 
         RowBox[{"xidev", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}]}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"dMie", "[", 
      RowBox[{"n_", ",", "x_", ",", "m_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"xi", "[", 
            RowBox[{"n", ",", "x"}], "]"}], 
           RowBox[{"psidev", "[", 
            RowBox[{"n", ",", "x"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"psi", "[", 
            RowBox[{"n", ",", "x"}], "]"}], 
           RowBox[{"xidev", "[", 
            RowBox[{"n", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m", " ", 
         RowBox[{"psidev", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}], 
         RowBox[{"xi", "[", 
          RowBox[{"n", ",", "x"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"xidev", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"psi", "[", 
          RowBox[{"n", ",", 
           RowBox[{"m", " ", "x"}]}], "]"}]}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"kk", "[", 
      RowBox[{"\[Lambda]_", ",", "nmed_"}], "]"}], ":=", 
     RowBox[{"2", " ", "\[Pi]", " ", 
      RowBox[{"nmed", "/", "\[Lambda]"}]}]}], ";", " ", 
    RowBox[{
     RowBox[{"XMieSF", "[", 
      RowBox[{"\[Lambda]_", ",", "r_", ",", "nmed_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"kk", "[", 
       RowBox[{"\[Lambda]", ",", "nmed"}], "]"}], " ", "r"}]}], ";", " ", 
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"\[Lambda]_", ",", "nmed_", ",", "\[CapitalDelta]T_"}], "]"}], ":=", 
     RowBox[{"nParticle", "/", "nmed"}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"wave", " ", "vector", " ", 
     RowBox[{"etc", "."}]}], "*)"}], "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.497679293332241*^9, 3.497679311135788*^9}, 
   3.4976910585174065`*^9, {3.497691089835766*^9, 3.497691127150219*^9}, {
   3.4976911798367424`*^9, 3.4976911799968987`*^9}, {3.4976914407937737`*^9, 
   3.4976914413533435`*^9}, {3.4976914896785393`*^9, 
   3.4976914900261955`*^9}, {3.49772132537926*^9, 3.497721339464965*^9}, {
   3.497721570260353*^9, 3.497721598022975*^9}, {3.497721749402769*^9, 
   3.497721762310053*^9}, {3.4977217972727537`*^9, 3.4977218026468554`*^9}, 
   3.4977218349709177`*^9, {3.497721891211123*^9, 3.497721903768449*^9}, 
   3.49772196643891*^9, {3.4977221601291847`*^9, 3.497722185887884*^9}, {
   3.497722242014049*^9, 3.497722243310285*^9}, {3.497722275862769*^9, 
   3.497722275970105*^9}, 3.4977224348748493`*^9, {3.4977229731364822`*^9, 
   3.497723000014002*^9}, {3.4977238550572367`*^9, 3.4977238554144363`*^9}, {
   3.497723910366666*^9, 3.497723977430134*^9}, {3.497726965139494*^9, 
   3.497726986421715*^9}, {3.497776478969555*^9, 3.4977764811267815`*^9}, {
   3.497777430895336*^9, 3.497777433495922*^9}, 3.4977775617029533`*^9, {
   3.49779038878318*^9, 3.497790415014697*^9}, {3.497794082126857*^9, 
   3.4977940969297132`*^9}, {3.497801845201638*^9, 3.497801940001289*^9}, 
   3.497801975350624*^9, {3.497802014252404*^9, 3.497802020197878*^9}, {
   3.497802052282159*^9, 3.497802052396743*^9}, 3.497802310840019*^9, {
   3.497802653906659*^9, 3.497802682161769*^9}, {3.497808600540502*^9, 
   3.497808607650961*^9}, 3.497808668699174*^9, {3.497808706986237*^9, 
   3.497808721164303*^9}, {3.4978088072476482`*^9, 3.4978088141990757`*^9}, {
   3.497809053490217*^9, 3.4978090605601673`*^9}, {3.4978103014510717`*^9, 
   3.4978103770193453`*^9}, {3.497812709771573*^9, 3.497812714534457*^9}, {
   3.49786188195744*^9, 3.497861885312722*^9}, 3.4978671955675383`*^9, {
   3.498283607300857*^9, 3.498283618488854*^9}, {3.498286561151466*^9, 
   3.498286602612596*^9}, {3.498305987823595*^9, 3.498305999290082*^9}, 
   3.4984587480803432`*^9, {3.4984654932136803`*^9, 3.4984654937634706`*^9}, {
   3.4984655289584017`*^9, 3.4984655293138227`*^9}, 3.498471095479938*^9, {
   3.4984772889311857`*^9, 3.498477314656807*^9}, 3.498907445117175*^9, {
   3.498908229192465*^9, 3.498908229379212*^9}, {3.498909133123087*^9, 
   3.498909137412986*^9}, {3.498910465415127*^9, 3.498910472713295*^9}, {
   3.498913997988604*^9, 3.4989139981235943`*^9}, {3.498914044248953*^9, 
   3.4989140444040003`*^9}, {3.4989242481077633`*^9, 3.498924258711973*^9}, {
   3.498924495285656*^9, 3.498924503175386*^9}, {3.4989248362605257`*^9, 
   3.498924844196879*^9}, {3.498926513767701*^9, 3.498926516569848*^9}, {
   3.498926648318211*^9, 3.498926654989155*^9}, {3.4989896674195127`*^9, 
   3.4989896684066477`*^9}, {3.498990506010316*^9, 3.498990513117537*^9}, {
   3.498990961287756*^9, 3.49899096745578*^9}, {3.4990624977519073`*^9, 
   3.49906251192861*^9}, {3.499063058123124*^9, 3.4990630592149067`*^9}, 
   3.499063347322259*^9, {3.4990636296587954`*^9, 3.49906363253699*^9}, {
   3.4990637398070602`*^9, 3.499063745369041*^9}, 3.4990642800514517`*^9, 
   3.4990801117228603`*^9, {3.499080305501318*^9, 3.499080308325286*^9}, {
   3.499160548274925*^9, 3.4991605521064043`*^9}, {3.499161023996531*^9, 
   3.499161026555059*^9}, {3.499161440224216*^9, 3.499161444143832*^9}, {
   3.499163325826466*^9, 3.4991633288822613`*^9}, {3.499172034004579*^9, 
   3.499172037384995*^9}, {3.499172834333021*^9, 3.499172838850675*^9}, {
   3.499173043551001*^9, 3.499173046009667*^9}, {3.499173157549073*^9, 
   3.499173160513274*^9}, {3.49942808085717*^9, 3.499428087390359*^9}, {
   3.500206447540786*^9, 3.500206456023302*^9}, {3.508589187074369*^9, 
   3.508589190231892*^9}, {3.508589476850644*^9, 3.508589477348749*^9}, {
   3.509170498779584*^9, 3.509170505949778*^9}, {3.509170589295842*^9, 
   3.509170598956603*^9}, {3.5091706523625507`*^9, 3.509170658059001*^9}, {
   3.515318592297471*^9, 3.515318595836187*^9}, {3.515387946050088*^9, 
   3.515387950131812*^9}, {3.5165588160855722`*^9, 3.5165588188258343`*^9}, {
   3.51659636067799*^9, 3.516596361320985*^9}, {3.516596438546509*^9, 
   3.516596439519425*^9}, {3.516597085231395*^9, 3.516597086470118*^9}, {
   3.51659787660032*^9, 3.5165978936755457`*^9}, {3.517039463911162*^9, 
   3.517039474548794*^9}, {3.5237776182622347`*^9, 3.523777684667384*^9}, {
   3.528442316587049*^9, 3.528442318165063*^9}, {3.5284424733858147`*^9, 
   3.528442475209852*^9}, {3.528442685207932*^9, 3.5284426857944717`*^9}, {
   3.528442953987035*^9, 3.5284429846481256`*^9}, {3.5284507666223927`*^9, 
   3.5284507667840652`*^9}, {3.52845097245695*^9, 3.5284509856091967`*^9}, {
   3.528451312452523*^9, 3.528451312669868*^9}, {3.529644872179673*^9, 
   3.5296449006552877`*^9}, {3.529645362971634*^9, 3.52964539217627*^9}, {
   3.5296464753971043`*^9, 3.529646475591346*^9}, {3.529647169063978*^9, 
   3.529647169396578*^9}, {3.529649905201055*^9, 3.529649906343062*^9}, {
   3.529655641621482*^9, 3.529655662949066*^9}, {3.529656954436404*^9, 
   3.529656955149273*^9}, 3.529686467808062*^9, {3.52969186833315*^9, 
   3.529691869421298*^9}, {3.529734606679757*^9, 3.5297346265927267`*^9}, {
   3.529762118479937*^9, 3.529762119219027*^9}, {3.529780246934883*^9, 
   3.529780247266218*^9}, {3.529815738091066*^9, 3.529815747640449*^9}, {
   3.5298162916389847`*^9, 3.5298163049870253`*^9}, {3.52981641462272*^9, 
   3.529816431643127*^9}, {3.529817467083869*^9, 3.529817468394849*^9}, {
   3.529828554087121*^9, 3.529828557632923*^9}, {3.5298377116949368`*^9, 
   3.52983774266153*^9}, {3.529837784012268*^9, 3.5298377873534822`*^9}, {
   3.530514165820072*^9, 3.5305141660926123`*^9}, {3.530519836088729*^9, 
   3.5305198363613567`*^9}, {3.531025988709428*^9, 3.531026013224771*^9}, {
   3.531026163231715*^9, 3.531026170141305*^9}, {3.531026321071066*^9, 
   3.5310263375185328`*^9}, {3.531473128740703*^9, 3.531473157027091*^9}, 
   3.5315889720604343`*^9, {3.531632664894644*^9, 3.531632665486025*^9}, {
   3.532106877147643*^9, 3.5321068809947853`*^9}, {3.5321069981023417`*^9, 
   3.532107109692912*^9}, {3.53210716548494*^9, 3.532107250402657*^9}, {
   3.532107325394965*^9, 3.532107344065818*^9}, 3.532107391450946*^9, {
   3.532108064517661*^9, 3.5321080783195753`*^9}, 3.532118597138898*^9, {
   3.532275337607031*^9, 3.532275338893052*^9}, {3.532276030704335*^9, 
   3.5322760746648617`*^9}, {3.532276121560622*^9, 3.5322761225254917`*^9}, {
   3.532276278969397*^9, 3.532276288388688*^9}, {3.532277454290394*^9, 
   3.532277455257657*^9}, {3.532281652034698*^9, 3.532281655600101*^9}, 
   3.532368085348022*^9, 3.532368344027742*^9, 3.532368376204671*^9, {
   3.5323684466232157`*^9, 3.532368494004251*^9}, {3.532368634586609*^9, 
   3.532368644638282*^9}, {3.5323687247489643`*^9, 3.532368727968088*^9}, {
   3.5323688393619337`*^9, 3.532368954385887*^9}, {3.532427670113476*^9, 
   3.532427671015189*^9}, {3.532427826514886*^9, 3.532427827176198*^9}, {
   3.534743131478382*^9, 3.534743131981379*^9}, {3.534743163085504*^9, 
   3.534743163467737*^9}, {3.5347437584336777`*^9, 3.534743774984112*^9}, {
   3.534743970576194*^9, 3.534743998366474*^9}, {3.534745813770913*^9, 
   3.5347458214501953`*^9}, {3.535178367294001*^9, 3.5351784018195887`*^9}, {
   3.535178560434997*^9, 3.5351785605938587`*^9}, {3.535178654971407*^9, 
   3.535178699302227*^9}, {3.535179478708027*^9, 3.535179488178892*^9}, {
   3.536678694995782*^9, 3.536678718167942*^9}, {3.538457139791945*^9, 
   3.538457141192031*^9}, {3.538457431973028*^9, 3.538457447216082*^9}, {
   3.5389985087457438`*^9, 3.53899852265202*^9}, {3.540577983837792*^9, 
   3.540577985381318*^9}, {3.540578066338348*^9, 3.540578066586337*^9}, {
   3.542353416707424*^9, 3.5423534249436626`*^9}, {3.542353567332198*^9, 
   3.5423535778438873`*^9}, {3.542354860256979*^9, 3.5423548701430817`*^9}, {
   3.5423552085091867`*^9, 3.542355215120421*^9}, {3.5423569751576023`*^9, 
   3.542356989967235*^9}, {3.543900544366967*^9, 3.543900562480075*^9}, {
   3.543900808527608*^9, 3.543900821669887*^9}, {3.5478310177935743`*^9, 
   3.547831018327734*^9}, {3.547831412738585*^9, 3.547831417078899*^9}, {
   3.547832115820421*^9, 3.547832159728569*^9}, {3.547834492495185*^9, 
   3.547834495966104*^9}, {3.547882838738327*^9, 3.54788284384301*^9}, 
   3.5478899420787277`*^9, {3.547893203971627*^9, 3.5478932167280207`*^9}, {
   3.547893471548398*^9, 3.547893474056078*^9}, {3.547893622810422*^9, 
   3.547893638827704*^9}, {3.547915057194215*^9, 3.5479150911172256`*^9}, {
   3.5479154008001833`*^9, 3.547915442347324*^9}, {3.547915986969235*^9, 
   3.5479160016286697`*^9}, {3.547918165005031*^9, 3.547918175075529*^9}, {
   3.547918557011546*^9, 3.5479185610698223`*^9}, {3.547919912481065*^9, 
   3.547919950553218*^9}, {3.54792005825746*^9, 3.547920059115597*^9}, {
   3.547920251150463*^9, 3.5479202544878817`*^9}, {3.5479209990464687`*^9, 
   3.5479209991657877`*^9}, {3.547921351940798*^9, 3.5479213583834057`*^9}, {
   3.547921401615552*^9, 3.547921413543582*^9}, {3.554279521975708*^9, 
   3.554279528053816*^9}, {3.554279685109273*^9, 3.5542797268268538`*^9}, {
   3.554282214311639*^9, 3.5542822401436768`*^9}, {3.5542829294297047`*^9, 
   3.55428293812042*^9}, {3.5542848313677053`*^9, 3.5542848323264017`*^9}, {
   3.554303300350402*^9, 3.554303307136869*^9}, 3.554433616137577*^9, 
   3.5544336930858603`*^9, {3.554435225628139*^9, 3.554435238852293*^9}, 
   3.554436484438078*^9, 3.5544375725780153`*^9, 3.554439097742404*^9, 
   3.554439881037758*^9, 3.554440811267008*^9, 3.554449306103919*^9, 
   3.55444964496318*^9, 3.554450556844346*^9, 3.554452281522999*^9, 
   3.5544542247641773`*^9, 3.55445454856222*^9, 3.5544553137896013`*^9, 
   3.5544554161466503`*^9, {3.554455672060656*^9, 3.554455677652313*^9}, 
   3.554455909811925*^9, 3.554456063023418*^9, 3.554456228139711*^9, {
   3.554462456142919*^9, 3.5544624745308247`*^9}, 3.554472477794661*^9, {
   3.554505674614406*^9, 3.554505675320919*^9}, {3.55450581476824*^9, 
   3.554505815429551*^9}, 3.554524526045466*^9, {3.592657697874805*^9, 
   3.592657698974822*^9}, {3.592675619277109*^9, 3.5926756197966223`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "This", " ", "function", " ", "gives", " ", "the", " ", "total", " ", 
     "fluxes"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"i", ".", "e", ".", " ", "the"}], " ", "total", " ", "cross"}], 
     "-", 
     RowBox[{"sections", " ", 
      RowBox[{"{", 
       RowBox[{"Extinction", ",", " ", "Scattering", ",", " ", "Absorption"}],
        "}"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "CrossSections", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CrossSections", "[", 
      RowBox[{
      "w00_", ",", "\[Lambda]\[Lambda]_", ",", "RR_", ",", "nParticlee_", ",",
        "nmaxx_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"w0", "=", "w00"}], ",", 
         RowBox[{"\[Lambda]", "=", "\[Lambda]\[Lambda]"}], ",", 
         RowBox[{"R", "=", "RR"}], ",", 
         RowBox[{"nParticle", "=", "nParticlee"}], ",", 
         RowBox[{"Nmax", "=", "nmaxx"}], ",", "k", ",", "s", ",", "an", ",", 
         "bn", ",", "gnT", ",", "n", ",", "Nn", ",", "Cext", ",", "Csca", ",",
          "Cabs", ",", "Cinc"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"k", "=", 
         RowBox[{"nmed", " ", "2", 
          RowBox[{"\[Pi]", "/", "\[Lambda]"}]}]}], ";", 
        RowBox[{"s", "=", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"k", " ", "w0"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
           RowBox[{
           "Get", " ", "Gaussian", " ", "BSC", " ", "for", " ", "z0"}], "=", 
           "0"}], ",", " ", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"z0", "/", "w0"}]}], "=", "0"}]}]}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"gnT", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"gnMLA", "[", 
             RowBox[{"n", ",", "s", ",", "0"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Nmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", " ", 
        RowBox[{"(*", 
         SubscriptBox["g", "n"], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"an", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"aMie", "[", 
            RowBox[{"n", ",", 
             RowBox[{"k", " ", "R"}], ",", 
             RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}]}], ";", " ", 
        
        RowBox[{"(*", 
         SubscriptBox["a", "n"], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"bn", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"bMie", "[", 
            RowBox[{"n", ",", 
             RowBox[{"k", " ", "R"}], ",", 
             RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}]}], ";", " ", 
        
        RowBox[{"(*", 
         SubscriptBox["b", "n"], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Csca", "=", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "Nmax"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], "2"]}], ")"}]}]}]}], ";", 
        RowBox[{"Cext", "=", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "Nmax"], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], 
           RowBox[{"Re", "[", 
            RowBox[{
             RowBox[{
             "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{
             "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
            "]"}]}]}]}], ";", 
        RowBox[{"Cabs", "=", 
         RowBox[{"Cext", "-", "Csca"}]}], ";", 
        RowBox[{"Cinc", "=", 
         RowBox[{"\[Pi]", " ", 
          RowBox[{
           SuperscriptBox["w0", "2"], "/", "2"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Cext", ",", "Csca", ",", "Cabs", ",", "Cinc"}], "}"}], "2", 
         RowBox[{"\[Pi]", "/", 
          SuperscriptBox["k", "2"]}]}]}]}], "\[IndentingNewLine]", "]"}]}], 
    ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.554449360865066*^9, {3.554449410531507*^9, 3.554449435407113*^9}, {
   3.554450262693079*^9, 3.554450338450767*^9}, {3.554454995529337*^9, 
   3.554455013537751*^9}, {3.554455052162401*^9, 3.5544551074171543`*^9}, {
   3.554455174190716*^9, 3.5544551983019867`*^9}, {3.554455245655748*^9, 
   3.55445526745128*^9}, {3.554455306777684*^9, 3.554455306972919*^9}, {
   3.554455864140065*^9, 3.554455864793784*^9}, {3.590672843914139*^9, 
   3.590672875898054*^9}, {3.59081269997474*^9, 3.5908127250617237`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Mie (p.w.) Scattering Coefficients of a Multilayered Sphere \nand Angular \
Functions \[Pi]n(",
 "\[Theta]",
 ") and \[Tau]n(\[Theta])\n",
 StyleBox["(O.Pena, U.Pal, Comp.Phys.Comm. 180, (2009), 2348-2354)\n",
  FontSize->14],
 StyleBox["Must Define: L (number of Layers), x = k*{r(1),..,r(L)}, m = \
{n(l)/n(L+1), .. , n(L)/n(L+1)}. if fixNmax=0 then nmax=automatic, otherwise \
Nmax is fixed to fixNmax\nFunction abL[x,m,fixNmax] delivers List with set of \
coefficients: {{",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["a", "1", 
     RowBox[{"L", "+", "1"}]], ",", 
    SubsuperscriptBox["a", "2", 
     RowBox[{"L", "+", "1"}]], ",", "..", ",", 
    SubsuperscriptBox["a", "Nmax", 
     RowBox[{"L", "+", "1"}]]}], TraditionalForm]], "None",
  FontSize->16],
 StyleBox["},{",
  FontSize->16,
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["b", "1", 
     RowBox[{"L", "+", "1"}]], ",", 
    SubsuperscriptBox["b", "2", 
     RowBox[{"L", "+", "1"}]], ",", "..", ",", 
    SubsuperscriptBox["b", "Nmax", 
     RowBox[{"L", "+", "1"}]]}], TraditionalForm]], "None",
  FontSize->16],
 StyleBox["},..}\n",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["corresponds to H1 and \"+\"-sign in refractive index nParticle",
  FontSize->14,
  FontColor->GrayLevel[0]]
}], "Title",
 CellChangeTimes->{{3.521554417193355*^9, 3.521554523923253*^9}, {
   3.52155457513398*^9, 3.521554708669533*^9}, {3.5215547461511707`*^9, 
   3.521554747988824*^9}, {3.521620249346819*^9, 3.5216202863685627`*^9}, {
   3.5216212234402113`*^9, 3.5216212366223593`*^9}, {3.521633808755925*^9, 
   3.5216339606355743`*^9}, 3.554283107215863*^9, {3.5544392367287483`*^9, 
   3.554439244986895*^9}, 3.554524564532893*^9, {3.5545245960559263`*^9, 
   3.554524622709956*^9}, {3.554524661945993*^9, 3.554524677968278*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "Dn1", ",", "Dn3", ",", "\[Psi]\[Zeta]", ",", "L", ",", "Nmax", ",", "a", 
     ",", "b", ",", "z1", ",", "m", ",", "li", ",", "D1lmlx", ",", "D3lmlx", 
     ",", "D1lmlxM1", ",", "D3lmlxM1", ",", "Ha", ",", "Hb", ",", "Ql", ",", 
     "PsiZetalmlx", ",", "PsiZetalmlxM1", ",", "an", ",", "bn", ",", "PsiXL", 
     ",", "L", ",", "xL", ",", "Nmaxf", ",", "D1XL", ",", "D3XL", ",", 
     "PsiXL", ",", "ZetaXL", ",", "PsiZetaXL", ",", "z1", ",", "z2", ",", 
     "a1", ",", "a2", ",", "b1", ",", "b2", ",", "G1", ",", "G2", ",", 
     "Temp"}], "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"abL", "[", 
     RowBox[{"xx_", ",", "mm_", ",", "fixNmaxx_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x", "=", "xx"}], ",", 
        RowBox[{"m", "=", "mm"}], ",", 
        RowBox[{"fixNmax", "=", "fixNmaxx"}], ",", "D1lmlx", ",", "D3lmlx", 
        ",", "D1lmlxM1", ",", "D3lmlxM1", ",", "PsiZetalmlx", ",", 
        "PsiZetalmlxM1", ",", "Ql", ",", "D1XL", ",", "D3XL", ",", "ZetaXL", 
        ",", "PsiZetaXL", ",", "G1", ",", "G2", ",", "Temp", ",", "Nn", ",", 
        "an", ",", "bn", ",", "Nmax", ",", "Nmaxf", ",", "Nstop", ",", "Ha", 
        ",", "Hb", ",", "PsiXL", ",", "n", ",", "z1", ",", "z2", ",", "a1", 
        ",", "a2", ",", "b1", ",", "b2", ",", "i", ",", "L", ",", "li", ",", 
        "a", ",", "b"}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Nstop", "[", "xL_", "]"}], ":=", 
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["xL", 
                RowBox[{"1", "/", "3"}]]}], "+", "xL", "+", "1"}], ",", 
             RowBox[{"0.02", "\[LessEqual]", "xL", "<", "8"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"4.05", " ", 
               SuperscriptBox["xL", 
                RowBox[{"1", "/", "3"}]]}], "+", "xL", "+", "2"}], ",", 
             RowBox[{"8", "\[LessEqual]", "xL", "<", "4200"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["xL", 
                RowBox[{"1", "/", "3"}]]}], "+", "xL", "+", "2"}], ",", 
             RowBox[{"4200", "\[LessEqual]", "xL", "<", "20000"}]}], "}"}]}], 
          "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "x", "]"}]}], ";", 
       RowBox[{"Nmaxf", "=", 
        RowBox[{"Nstop", "[", 
         RowBox[{"x", "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"Nmaxf", "<", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{
               "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
               " ", 
               RowBox[{
               "m", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
              "]"}]}], ",", 
            RowBox[{"Nmaxf", "=", 
             RowBox[{"Round", "[", 
              RowBox[{"Abs", "[", 
               RowBox[{
                RowBox[{
                "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                " ", 
                RowBox[{
                "m", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}],
                "]"}], "]"}]}], ",", "0"}], "]"}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"Nmaxf", "<", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"x", "\[LeftDoubleBracket]", 
                RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
               RowBox[{
               "m", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
              "]"}]}], ",", 
            RowBox[{"Nmaxf", "=", 
             RowBox[{"Round", "[", 
              RowBox[{"Abs", "[", 
               RowBox[{
                RowBox[{"x", "\[LeftDoubleBracket]", 
                 RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
                RowBox[{
                "m", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}],
                "]"}], "]"}]}], ",", "0"}], "]"}]}]}], "]"}], ";", 
       RowBox[{"Nmax", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"fixNmax", "\[Equal]", "0"}], ",", 
          RowBox[{"Round", "[", 
           RowBox[{"Nmaxf", "+", "15"}], "]"}], ",", "fixNmax"}], "]"}]}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"an", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "3"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"bn", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "3"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"Nn", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "3"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"D1lmlx", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "3"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"D1lmlxM1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "3"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"D3lmlx", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"D3lmlxM1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"PsiZetalmlx", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"PsiZetalmlxM1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Ql", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"Ha", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"Hb", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"L", "+", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"D1XL", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "3"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"D3XL", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"PsiXL", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"ZetaXL", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"PsiZetaXL", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Nmax", "+", "2"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"z1", "=", 
        RowBox[{
         RowBox[{"m", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         " ", 
         RowBox[{
         "x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{"D1lmlx", "\[LeftDoubleBracket]", 
          RowBox[{"Nmax", "+", "2"}], "\[RightDoubleBracket]"}], 
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
        RowBox[{"0", "+", 
         RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", 
          RowBox[{"Nmax", "+", "2"}]}], ",", 
         RowBox[{"n", "\[GreaterEqual]", "2"}], ",", 
         RowBox[{"n", "--"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"D1lmlx", "\[LeftDoubleBracket]", 
            RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
           "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
          RowBox[{
           FractionBox[
            RowBox[{"n", "-", "1"}], "z1"], "-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{
              RowBox[{
              "D1lmlx", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "-", "1"}], ")"}], "/", "z1"}]}]]}]}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"a", "=", 
        RowBox[{"Re", "[", "z1", "]"}]}], ";", 
       RowBox[{"b", "=", 
        RowBox[{"Im", "[", "z1", "]"}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{
         "PsiZetalmlx", "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], "=", 
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "2"}], " ", "b"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "a"}], "]"}], "+", 
               RowBox[{"\[ImaginaryI]", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "a"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
          "2"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{
         "D3lmlx", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
        "\[ImaginaryI]"}], ";", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", "2"}], ",", 
         RowBox[{"n", "\[LessEqual]", 
          RowBox[{"Nmax", "+", "1"}]}], ",", 
         RowBox[{"n", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "PsiZetalmlx", "\[LeftDoubleBracket]", "n", 
             "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{"PsiZetalmlx", "\[LeftDoubleBracket]", 
              RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "-", "1"}], "z1"], "-", 
              RowBox[{
               RowBox[{"D1lmlx", "\[LeftDoubleBracket]", 
                RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "-", "1"}], "z1"], "-", 
              RowBox[{
               RowBox[{"D3lmlx", "\[LeftDoubleBracket]", 
                RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
             ")"}]}]}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{
            "D3lmlx", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{
             "D1lmlx", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
              "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
            FractionBox["\[ImaginaryI]", 
             RowBox[{
              RowBox[{
              "PsiZetalmlx", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", "1"}], ",", 
         RowBox[{"n", "\[LessEqual]", 
          RowBox[{"Nmax", "+", "1"}]}], ",", 
         RowBox[{"n", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "Ha", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{
            "D1lmlx", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Hb", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{
            "D1lmlx", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}]}], 
        "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"li", "=", "2"}], ",", 
         RowBox[{"li", "\[LessEqual]", "L"}], ",", 
         RowBox[{"li", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"z1", "=", 
           RowBox[{
            RowBox[{
            "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], " ", 
            RowBox[{
            "x", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}]}], 
          ";", 
          RowBox[{"z2", "=", 
           RowBox[{
            RowBox[{
            "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], " ", 
            RowBox[{"x", "\[LeftDoubleBracket]", 
             RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}]}]}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{"D1lmlx", "\[LeftDoubleBracket]", 
             RowBox[{"Nmax", "+", "2"}], "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
           RowBox[{"0", "+", 
            RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{"D1lmlxM1", "\[LeftDoubleBracket]", 
             RowBox[{"Nmax", "+", "2"}], "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
           RowBox[{"0", "+", 
            RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"n", "=", 
             RowBox[{"Nmax", "+", "2"}]}], ",", 
            RowBox[{"n", "\[GreaterEqual]", "2"}], ",", 
            RowBox[{"n", "--"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"D1lmlx", "\[LeftDoubleBracket]", 
                RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
              RowBox[{
               FractionBox[
                RowBox[{"n", "-", "1"}], "z1"], "-", 
               FractionBox["1", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "D1lmlx", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                  "\[RightDoubleBracket]"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "1"}], ")"}], "/", "z1"}]}]]}]}], ";", 
             RowBox[{
              RowBox[{
               RowBox[{"D1lmlxM1", "\[LeftDoubleBracket]", 
                RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
              RowBox[{
               FractionBox[
                RowBox[{"n", "-", "1"}], "z2"], "-", 
               FractionBox["1", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "D1lmlxM1", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                  "\[RightDoubleBracket]"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "1"}], ")"}], "/", "z2"}]}]]}]}]}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"a1", "=", 
           RowBox[{"Re", "[", "z1", "]"}]}], ";", 
          RowBox[{"b1", "=", 
           RowBox[{"Im", "[", "z1", "]"}]}], ";", 
          RowBox[{"a2", "=", 
           RowBox[{"Re", "[", "z2", "]"}]}], ";", 
          RowBox[{"b2", "=", 
           RowBox[{"Im", "[", "z2", "]"}]}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{
            "D3lmlx", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
           "\[ImaginaryI]"}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{
            "D3lmlxM1", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
            "\[RightDoubleBracket]"}], "=", "\[ImaginaryI]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "PsiZetalmlx", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
            "\[RightDoubleBracket]"}], "=", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "b1"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "a1"}], "]"}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "a1"}], "]"}]}]}], ")"}]}]}], ")"}], 
             "/", "2"}], "]"}]}], ";", 
          RowBox[{
           RowBox[{
            RowBox[{
            "PsiZetalmlxM1", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
            "\[RightDoubleBracket]"}], "=", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "b2"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "a2"}], "]"}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "a2"}], "]"}]}]}], ")"}]}]}], ")"}], 
             "/", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"n", "=", "2"}], ",", 
            RowBox[{"n", "\[LessEqual]", 
             RowBox[{"Nmax", "+", "1"}]}], ",", 
            RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "PsiZetalmlx", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
               "\[RightDoubleBracket]"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"PsiZetalmlx", "\[LeftDoubleBracket]", 
                 RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], " ", 
               
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"n", "-", "1"}], "z1"], "-", 
                 RowBox[{
                  RowBox[{"D1lmlx", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}], 
                ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"n", "-", "1"}], "z1"], "-", 
                 RowBox[{
                  RowBox[{"D3lmlx", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}], 
                ")"}]}]}], ";", 
             RowBox[{
              RowBox[{
               RowBox[{
               "PsiZetalmlxM1", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
               "\[RightDoubleBracket]"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"PsiZetalmlxM1", "\[LeftDoubleBracket]", 
                 RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], " ", 
               
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"n", "-", "1"}], "z2"], "-", 
                 RowBox[{
                  RowBox[{"D1lmlxM1", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}], 
                ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"n", "-", "1"}], "z2"], "-", 
                 RowBox[{
                  RowBox[{"D3lmlxM1", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}], 
                ")"}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
               "D3lmlx", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
               "\[RightDoubleBracket]"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                "D1lmlx", "\[LeftDoubleBracket]", "n", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                "\[RightDoubleBracket]"}], "+", 
               FractionBox["\[ImaginaryI]", 
                RowBox[{
                 RowBox[{
                 "PsiZetalmlx", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                 "\[RightDoubleBracket]"}]]}]}], ";", 
             RowBox[{
              RowBox[{
               RowBox[{
               "D3lmlxM1", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
               "\[RightDoubleBracket]"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                "D1lmlxM1", "\[LeftDoubleBracket]", "n", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                "\[RightDoubleBracket]"}], "+", 
               FractionBox["\[ImaginaryI]", 
                RowBox[{
                 RowBox[{
                 "PsiZetalmlxM1", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                 "\[RightDoubleBracket]"}]]}]}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Ql", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 RowBox[{"-", "2"}], " ", "b2"}]]}], "+", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "a2"}]]}], 
             ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               RowBox[{"(", 
                RowBox[{"b1", "-", "b2"}], ")"}]}]], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "b1"}]]}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "a1"}]]}], 
              ")"}]}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"n", "=", "2"}], ",", 
            RowBox[{"n", "\[LessEqual]", 
             RowBox[{"Nmax", "+", "1"}]}], ",", 
            RowBox[{"n", "++"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
              "Ql", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
             FractionBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                 FractionBox[
                  RowBox[{"x", "\[LeftDoubleBracket]", 
                   RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{
                  "x", "\[LeftDoubleBracket]", "li", 
                   "\[RightDoubleBracket]"}]], "]"}], "2"], " ", 
               RowBox[{
                RowBox[{"Ql", "\[LeftDoubleBracket]", 
                 RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], " ", 
               
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"z1", " ", 
                    RowBox[{
                    RowBox[{
                    "D1lmlx", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                    "\[RightDoubleBracket]"}]}], "+", 
                   RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", "1"}], ")"}], "-", 
                   RowBox[{"z1", " ", 
                    RowBox[{
                    RowBox[{"D3lmlx", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", "li", 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}], ")"}]}], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"z2", " ", 
                  RowBox[{
                   RowBox[{
                   "D1lmlxM1", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                   "\[RightDoubleBracket]"}]}], "+", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "1"}], ")"}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "1"}], ")"}], "-", 
                 RowBox[{"z2", " ", 
                  RowBox[{
                   RowBox[{"D3lmlxM1", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], 
                   "\[LeftDoubleBracket]", "li", 
                   "\[RightDoubleBracket]"}]}]}], ")"}]}]]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"n", "=", "2"}], ",", 
            RowBox[{"n", "\[LessEqual]", 
             RowBox[{"Nmax", "+", "1"}]}], ",", 
            RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"G1", "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], 
                " ", 
                RowBox[{
                 RowBox[{
                 "Ha", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}]}], "-", 
               RowBox[{
                RowBox[{"m", "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
                RowBox[{
                 RowBox[{
                 "D1lmlxM1", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                 "\[RightDoubleBracket]"}]}]}]}], ";", 
             RowBox[{"G2", "=", 
              RowBox[{
               RowBox[{
                RowBox[{
                "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], 
                " ", 
                RowBox[{
                 RowBox[{
                 "Ha", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}]}], "-", 
               RowBox[{
                RowBox[{"m", "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
                RowBox[{
                 RowBox[{
                 "D3lmlxM1", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                 "\[RightDoubleBracket]"}]}]}]}], ";", 
             RowBox[{"Temp", "=", 
              RowBox[{"G1", " ", 
               RowBox[{
                RowBox[{
                "Ql", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}]}], 
             ";", 
             RowBox[{
              RowBox[{
               RowBox[{
               "Ha", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
              FractionBox[
               RowBox[{
                RowBox[{"G2", " ", 
                 RowBox[{
                  RowBox[{
                  "D1lmlx", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                  "\[RightDoubleBracket]"}]}], "-", 
                RowBox[{"Temp", " ", 
                 RowBox[{
                  RowBox[{
                  "D3lmlx", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                  "\[RightDoubleBracket]"}]}]}], 
               RowBox[{"G2", "-", "Temp"}]]}], ";", "\[IndentingNewLine]", 
             RowBox[{"G1", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"m", "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
                RowBox[{
                 RowBox[{
                 "Hb", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}]}], "-", 
               RowBox[{
                RowBox[{
                "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], 
                " ", 
                RowBox[{
                 RowBox[{
                 "D1lmlxM1", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                 "\[RightDoubleBracket]"}]}]}]}], ";", 
             RowBox[{"G2", "=", 
              RowBox[{
               RowBox[{
                RowBox[{"m", "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
                RowBox[{
                 RowBox[{
                 "Hb", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  "\[LeftDoubleBracket]", 
                 RowBox[{"li", "-", "1"}], "\[RightDoubleBracket]"}]}], "-", 
               RowBox[{
                RowBox[{
                "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], 
                " ", 
                RowBox[{
                 RowBox[{
                 "D3lmlxM1", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                 "\[RightDoubleBracket]"}]}]}]}], ";", 
             RowBox[{"Temp", "=", 
              RowBox[{"G1", " ", 
               RowBox[{
                RowBox[{
                "Ql", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}]}], 
             ";", 
             RowBox[{
              RowBox[{
               RowBox[{
               "Hb", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}], "=", 
              FractionBox[
               RowBox[{
                RowBox[{"G2", " ", 
                 RowBox[{
                  RowBox[{
                  "D1lmlx", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                  "\[RightDoubleBracket]"}]}], "-", 
                RowBox[{"Temp", " ", 
                 RowBox[{
                  RowBox[{
                  "D3lmlx", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "li", 
                  "\[RightDoubleBracket]"}]}]}], 
               RowBox[{"G2", "-", "Temp"}]]}], ";"}]}], "\[IndentingNewLine]",
            "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       "\[IndentingNewLine]", 
       RowBox[{"z1", "=", 
        RowBox[{"x", "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}]}],
        ";", 
       RowBox[{"a", "=", 
        RowBox[{"Re", "[", "z1", "]"}]}], ";", 
       RowBox[{"b", "=", 
        RowBox[{"Im", "[", "z1", "]"}]}], ";", 
       RowBox[{
        RowBox[{"D1XL", "\[LeftDoubleBracket]", 
         RowBox[{"Nmax", "+", "2"}], "\[RightDoubleBracket]"}], "=", 
        RowBox[{"0", "+", 
         RowBox[{"0", " ", "\[ImaginaryI]"}]}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", 
          RowBox[{"Nmax", "+", "2"}]}], ",", 
         RowBox[{"n", "\[GreaterEqual]", "2"}], ",", 
         RowBox[{"n", "--"}], ",", 
         RowBox[{
          RowBox[{"D1XL", "\[LeftDoubleBracket]", 
           RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], "=", 
          RowBox[{
           FractionBox[
            RowBox[{"n", "-", "1"}], "z1"], "-", 
           FractionBox["1", 
            RowBox[{
             RowBox[{
             "D1XL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "-", "1"}], ")"}], "/", "z1"}]}]]}]}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
        "PsiXL", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
        
        RowBox[{"Sin", "[", "a", "]"}]}], ";", 
       RowBox[{
        RowBox[{
        "ZetaXL", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
        RowBox[{
         RowBox[{"Sin", "[", "a", "]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"Cos", "[", "a", "]"}]}]}]}], ";", 
       RowBox[{
        RowBox[{
        "PsiZetaXL", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "=", 
        RowBox[{"N", "[", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "2"}], " ", "b"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "a"}], "]"}], "+", 
               RowBox[{"\[ImaginaryI]", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", "a"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
         "]"}]}], ";", 
       RowBox[{
        RowBox[{
        "D3XL", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
        "\[ImaginaryI]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", "2"}], ",", 
         RowBox[{"n", "\[LessEqual]", 
          RowBox[{"Nmax", "+", "1"}]}], ",", 
         RowBox[{"n", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "PsiXL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           "=", 
           RowBox[{
            RowBox[{"PsiXL", "\[LeftDoubleBracket]", 
             RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "-", "1"}], "z1"], "-", 
              RowBox[{"D1XL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}]}], 
             ")"}]}]}], ";", 
          RowBox[{
           RowBox[{
           "ZetaXL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           "=", 
           RowBox[{
            RowBox[{"ZetaXL", "\[LeftDoubleBracket]", 
             RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "-", "1"}], "z1"], "-", 
              RowBox[{"D3XL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}]}], 
             ")"}]}]}], ";", 
          RowBox[{
           RowBox[{
           "PsiZetaXL", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{"PsiZetaXL", "\[LeftDoubleBracket]", 
             RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "-", "1"}], "z1"], "-", 
              RowBox[{"D1XL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "-", "1"}], "z1"], "-", 
              RowBox[{"D3XL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}]}], 
             ")"}]}]}], ";", 
          RowBox[{
           RowBox[{
           "D3XL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           "=", 
           RowBox[{
            RowBox[{
            "D1XL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "+", 
            FractionBox["\[ImaginaryI]", 
             RowBox[{
             "PsiZetaXL", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", "1"}], ",", 
         RowBox[{"n", "\[LessEqual]", "Nmax"}], ",", 
         RowBox[{"n", "++"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "=", 
           
           FractionBox[
            RowBox[{
             RowBox[{"2", " ", "n"}], "+", "1"}], 
            RowBox[{"n", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", "1"}], ")"}]}]]}], ";", 
          RowBox[{
           RowBox[{
           "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "=", 
           
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"PsiXL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{
                  RowBox[{"Ha", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}], 
                 RowBox[{
                 "m", "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}]],
                 "+", 
                FractionBox["n", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "L", 
                  "\[RightDoubleBracket]"}]]}], ")"}]}], "-", 
             RowBox[{
             "PsiXL", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], 
            RowBox[{
             RowBox[{
              RowBox[{"ZetaXL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{
                  RowBox[{"Ha", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}], 
                 RowBox[{
                 "m", "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}]],
                 "+", 
                FractionBox["n", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "L", 
                  "\[RightDoubleBracket]"}]]}], ")"}]}], "-", 
             RowBox[{
             "ZetaXL", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}]]}], ";", 
          RowBox[{
           RowBox[{
           "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "=", 
           
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"PsiXL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "m", "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                  RowBox[{"Hb", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}]}], 
                "+", 
                FractionBox["n", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "L", 
                  "\[RightDoubleBracket]"}]]}], ")"}]}], "-", 
             RowBox[{
             "PsiXL", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], 
            RowBox[{
             RowBox[{
              RowBox[{"ZetaXL", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "m", "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                  RowBox[{"Hb", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  "\[LeftDoubleBracket]", "L", "\[RightDoubleBracket]"}]}], 
                "+", 
                FractionBox["n", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "L", 
                  "\[RightDoubleBracket]"}]]}], ")"}]}], "-", 
             RowBox[{
             "ZetaXL", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}]]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Conjugate", "[", "an", "]"}], ",", 
         RowBox[{"Conjugate", "[", "bn", "]"}], ",", "Nn", ",", "Nmax"}], 
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Recursively", " ", "determine", " ", "the", " ", "angular", " ", 
     "functions", " ", "\[Pi]n", " ", "and", " ", "\[Tau]n", " ", "for", " ", 
     "an", " ", "arbitrary", " ", "angle", " ", 
     RowBox[{"\[Theta]", "[", "radians", "]"}]}], ",", " ", 
    RowBox[{
     SubscriptBox["\[Pi]", "n"], "=", 
     RowBox[{
      RowBox[{"\[Pi]", "\[LeftDoubleBracket]", 
       RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"since", " ", "theres", " ", "no", " ", "0"}], "-", 
        RowBox[{"index", "!"}]}], ")"}]}]}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
    RowBox[{"\[Theta]\[Theta]_", ",", "NNmax_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"N", "[", "\[Theta]\[Theta]", "]"}]}], ",", 
       RowBox[{"Nmax", "=", "NNmax"}], ",", "\[Pi]n", ",", "\[Tau]n", ",", 
       "n"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Pi]n", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"Nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"\[Tau]n", "=", "\[Pi]n"}], ";", 
      RowBox[{
       RowBox[{
       "\[Pi]n", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
       "0"}], ";", 
      RowBox[{
       RowBox[{
       "\[Pi]n", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "=", 
       "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"n", "=", "3"}], ",", 
        RowBox[{"n", "\[LessEqual]", 
         RowBox[{"Nmax", "+", "1"}]}], ",", 
        RowBox[{"n", "++"}], ",", 
        RowBox[{
         RowBox[{
         "\[Pi]n", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"n", "-", "1"}], ")"}]}], "-", "1"}], ")"}], " ", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
             RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}]}], 
           RowBox[{"n", "-", "2"}]], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "-", "1"}], ")"}], " ", 
            RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
             RowBox[{"n", "-", "2"}], "\[RightDoubleBracket]"}]}], 
           RowBox[{"n", "-", "2"}]]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"n", "=", "2"}], ",", 
        RowBox[{"n", "\[LessEqual]", 
         RowBox[{"Nmax", "+", "1"}]}], ",", 
        RowBox[{"n", "++"}], ",", 
        RowBox[{
         RowBox[{
         "\[Tau]n", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "-", "1"}], ")"}], " ", 
           RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
           RowBox[{
           "\[Pi]n", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}],
           "-", 
          RowBox[{"n", " ", 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "-", "1"}], "\[RightDoubleBracket]"}]}]}]}]}], "]"}],
       ";", 
      RowBox[{"{", 
       RowBox[{"\[Pi]n", ",", "\[Tau]n"}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.521534322330295*^9, 3.52153436317723*^9}, {
   3.521534506221447*^9, 3.521534648106056*^9}, {3.521534848722228*^9, 
   3.521534872884055*^9}, {3.5215349114830027`*^9, 3.521534952489663*^9}, {
   3.52153499290456*^9, 3.521535008163014*^9}, {3.521535045527358*^9, 
   3.521535056308837*^9}, {3.521535108037712*^9, 3.5215352842848577`*^9}, {
   3.521535319302402*^9, 3.521535338762188*^9}, {3.5215354480887737`*^9, 
   3.52153547252658*^9}, {3.521535513366314*^9, 3.521535807433427*^9}, {
   3.521535839746499*^9, 3.521535840454218*^9}, {3.5215358769342813`*^9, 
   3.521535942976795*^9}, 3.5215365145110197`*^9, {3.521536607056617*^9, 
   3.521536647337723*^9}, {3.521536861465458*^9, 3.521536865688775*^9}, {
   3.521536916088032*^9, 3.521537044300496*^9}, {3.5215371616177473`*^9, 
   3.521537409745084*^9}, {3.521537499962538*^9, 3.5215375186011047`*^9}, {
   3.5215375647371407`*^9, 3.521537607224371*^9}, {3.521537751698242*^9, 
   3.52153775250753*^9}, {3.5215378037801247`*^9, 3.5215378452985687`*^9}, {
   3.521538083915058*^9, 3.5215380902447777`*^9}, {3.521538181827333*^9, 
   3.521538282169488*^9}, {3.5215383643786697`*^9, 3.5215386994144697`*^9}, {
   3.521538745551753*^9, 3.521538750185522*^9}, {3.521538823252015*^9, 
   3.521538826352261*^9}, {3.521538879569322*^9, 3.521538882418618*^9}, {
   3.521538924445704*^9, 3.521538952102107*^9}, {3.521539020558321*^9, 
   3.5215390419151773`*^9}, {3.521539085089164*^9, 3.521539188509488*^9}, {
   3.521539219528584*^9, 3.5215393089412317`*^9}, {3.5215393494530497`*^9, 
   3.521539360662807*^9}, {3.521539412802761*^9, 3.521539769269554*^9}, {
   3.521539817245327*^9, 3.521539824902268*^9}, 3.521539859273569*^9, {
   3.521539919928483*^9, 3.521539935405127*^9}, {3.5215400120425262`*^9, 
   3.521540012432982*^9}, {3.521540063793915*^9, 3.52154016995436*^9}, {
   3.5215402525911493`*^9, 3.521540342854937*^9}, {3.521540383988516*^9, 
   3.521540535148766*^9}, {3.5215410376078777`*^9, 3.521541085352622*^9}, {
   3.5215411383934507`*^9, 3.521541271234234*^9}, {3.521541313596575*^9, 
   3.5215413666794643`*^9}, {3.521541414631886*^9, 3.521541589455687*^9}, {
   3.521541625931041*^9, 3.521541795583839*^9}, {3.521542047065968*^9, 
   3.521542097106003*^9}, {3.521542132694421*^9, 3.521542204899811*^9}, {
   3.521542243888275*^9, 3.521542389847869*^9}, {3.5215424509055634`*^9, 
   3.521542876676146*^9}, {3.521542936760395*^9, 3.521542958048605*^9}, {
   3.5215430717091837`*^9, 3.521543081938632*^9}, {3.5215431136892443`*^9, 
   3.521543148094103*^9}, {3.521543374503545*^9, 3.521543453919882*^9}, {
   3.521543507617931*^9, 3.521543723662498*^9}, {3.521543811014106*^9, 
   3.5215438256740522`*^9}, {3.521543866939245*^9, 3.521543990652722*^9}, {
   3.521544060294969*^9, 3.5215441516254387`*^9}, {3.521544190451445*^9, 
   3.521544207363023*^9}, {3.5215442621887617`*^9, 3.521544280841077*^9}, {
   3.521544376294694*^9, 3.52154449522431*^9}, {3.521544611944132*^9, 
   3.521544741355007*^9}, {3.521544855481885*^9, 3.521545078512643*^9}, {
   3.521545215221284*^9, 3.521545401583041*^9}, {3.521545443622323*^9, 
   3.521545448944066*^9}, 3.521545569830324*^9, 3.521545619424539*^9, {
   3.5215456659753304`*^9, 3.521545683060895*^9}, {3.521546610111526*^9, 
   3.5215466823689747`*^9}, 3.5215489357942753`*^9, {3.521548974189479*^9, 
   3.521548975516169*^9}, {3.5215490271995497`*^9, 3.521549034362608*^9}, {
   3.521549106627297*^9, 3.521549107699218*^9}, {3.521549305386297*^9, 
   3.521549347128086*^9}, {3.5215497278434134`*^9, 3.521549772670308*^9}, {
   3.521549851867859*^9, 3.521549870323007*^9}, {3.521549911349058*^9, 
   3.521549911450736*^9}, {3.5215503692477083`*^9, 3.521550425787966*^9}, {
   3.521550679390503*^9, 3.521550683411437*^9}, {3.52155089585647*^9, 
   3.5215508984163647`*^9}, {3.52155109346483*^9, 3.521551099432691*^9}, {
   3.521551320670635*^9, 3.5215513268893213`*^9}, {3.52155187118818*^9, 
   3.52155187752782*^9}, {3.5215523725093727`*^9, 3.521552414713863*^9}, {
   3.521552499175124*^9, 3.521552526604784*^9}, {3.521553136069693*^9, 
   3.521553139928108*^9}, {3.5215539451551037`*^9, 3.521553960559821*^9}, 
   3.5215541111674843`*^9, {3.521554150832654*^9, 3.5215541825746393`*^9}, {
   3.521554219085803*^9, 3.521554232403232*^9}, {3.521554285815116*^9, 
   3.521554294020564*^9}, {3.521554357353936*^9, 3.5215544107421303`*^9}, {
   3.521554445984418*^9, 3.521554451678317*^9}, 3.521554566466552*^9, {
   3.5215549339484386`*^9, 3.5215550606754303`*^9}, {3.5215552278706217`*^9, 
   3.5215552525442543`*^9}, {3.521555405589664*^9, 3.521555433937323*^9}, {
   3.521555479108057*^9, 3.5215554817971363`*^9}, {3.521557269296372*^9, 
   3.521557276084564*^9}, {3.521557482925807*^9, 3.521557490365937*^9}, {
   3.521558012353036*^9, 3.521558140588443*^9}, {3.5215644019556026`*^9, 
   3.521564434961144*^9}, {3.521564532845624*^9, 3.521564785018571*^9}, {
   3.521564853817423*^9, 3.521565027447647*^9}, {3.5215650694232817`*^9, 
   3.5215650731745*^9}, {3.521565111783354*^9, 3.521565243930827*^9}, {
   3.521565281346352*^9, 3.5215653247529783`*^9}, {3.521565375995953*^9, 
   3.5215655200182867`*^9}, {3.5215656667368603`*^9, 3.521565847558886*^9}, {
   3.521565891133149*^9, 3.5215658922276173`*^9}, 3.521566045038134*^9, {
   3.521572594968721*^9, 3.52157262387815*^9}, {3.521573513161874*^9, 
   3.521573513809115*^9}, {3.521574925484437*^9, 3.521574973246975*^9}, {
   3.521614993037924*^9, 3.521614993414803*^9}, {3.521615026701838*^9, 
   3.521615027155704*^9}, {3.521615066990088*^9, 3.521615067298945*^9}, {
   3.52162021158351*^9, 3.5216202117079563`*^9}, {3.5216202966151133`*^9, 
   3.521620340484447*^9}, 3.521620670818223*^9, {3.521620908917638*^9, 
   3.521620920294325*^9}, {3.52162096429708*^9, 3.521621005135746*^9}, {
   3.521632857972938*^9, 3.5216328871398993`*^9}, {3.521632924752551*^9, 
   3.521632948023098*^9}, {3.5216330241062107`*^9, 3.521633047882238*^9}, {
   3.52187512925098*^9, 3.521875180549686*^9}, {3.53208795792192*^9, 
   3.532087980928131*^9}, {3.533152064539463*^9, 3.533152089298633*^9}, {
   3.5545246390704603`*^9, 3.554524647396661*^9}, {3.5721721571872187`*^9, 
   3.5721721643364277`*^9}, {3.576512046312505*^9, 3.5765120562034063`*^9}, {
   3.576514305124001*^9, 3.576514307300332*^9}, {3.5992034603607483`*^9, 
   3.5992034608885736`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "EM-FIELDS (near/far-fields) and Poynting Vectors\n",
 StyleBox["these functions take the Mie-coefs lists {an,bn,cn,dn} and compute \
the EM-fields (",
  FontSize->12],
 StyleBox["spherical coordinates",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[") in space. Reference: \"Light Scattering from a sphere \
arbitrarily located in a Gaussian beam, using a Bromwich formulation\", J. \
Opt. Soc. Am. A, Vol. 5, No. 9, 1988. ",
  FontSize->12],
 StyleBox["Use \"-\" sign convention for \[Epsilon] and n!",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\nComparable to:\"Energy flow around a small particle investigated \
by classical Mie theory\", Phys. Rev. B 70, 035418, 2004, Z. B. Wang et al. \
(to check results, i.e. Fig. 6)",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.5215555775512342`*^9, 3.521555594875887*^9}, {
  3.521557503283558*^9, 3.5215575314578533`*^9}, {3.532076727719061*^9, 
  3.532076729051992*^9}, {3.53211414098179*^9, 3.532114150162614*^9}, {
  3.5323692225660763`*^9, 3.5323692484039*^9}, {3.532431102089347*^9, 
  3.532431299376902*^9}, {3.55445874621679*^9, 3.554458940551188*^9}, {
  3.557740267047749*^9, 3.557740286671011*^9}, {3.557740317537147*^9, 
  3.5577403375977077`*^9}},
 FontWeight->"Bold",
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 StyleBox["Analytical sum Expressions for the spherical components of the \
EM-Fields", "Title",
  FontSize->24,
  FontWeight->"Bold"],
 ", n=Sqrt[\[Epsilon]]"
}], "Text",
 CellChangeTimes->{{3.532092134203248*^9, 3.532092150415887*^9}, {
  3.5321141229964933`*^9, 3.532114136163643*^9}, {3.532268689185893*^9, 
  3.532268708486507*^9}, {3.532430364966741*^9, 3.53243036906418*^9}, {
  3.532945455065666*^9, 3.5329454608860283`*^9}, {3.533237117017902*^9, 
  3.5332371212110367`*^9}, {3.554280103465692*^9, 3.554280105247449*^9}, {
  3.554458231275963*^9, 3.554458237747423*^9}, {3.5544582723969297`*^9, 
  3.5544582800099163`*^9}, {3.5545254675291233`*^9, 3.554525467990773*^9}, {
  3.557740354987903*^9, 3.557740355325057*^9}},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "Plot Field Intensities for the example defined above, {{",
 Cell[BoxData[
  SubscriptBox["z", "n"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 
    3.5322868540730333`*^9}}],
 ", ",
 Cell[BoxData[
  SubscriptBox["x", "i"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 
    3.5322868540730333`*^9}}],
 " or ",
 Cell[BoxData[
  SubscriptBox["y", "i"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 
    3.5322868540730333`*^9}}],
 ", {Fields[r,\[Theta],\[Phi]]}},{},..}, coordinate transform to cartesian: {",
 Cell[BoxData[
  SubscriptBox["S", "z"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}, {
    3.53228811956033*^9, 3.53228814463232*^9}, 3.5322885694137793`*^9, {
    3.532288633051366*^9, 3.532288640729644*^9}, 3.532288693436808*^9, {
    3.532326560676771*^9, 3.532326561467997*^9}, 3.5323267539092283`*^9, {
    3.532326855841176*^9, 3.5323268626361923`*^9}, {3.532327648154467*^9, 
    3.532327648472391*^9}, {3.532328314440467*^9, 3.5323283774651546`*^9}, {
    3.532328422377253*^9, 3.532328424681246*^9}, {3.532328560525572*^9, 
    3.532328568167946*^9}, {3.532328656757094*^9, 3.532328674806654*^9}},
  FontColor->RGBColor[1, 0, 0]],
 " = ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      StyleBox[
       SubscriptBox["S", "r"],
       FontColor->RGBColor[0, 0, 1]]}], "-", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      StyleBox[
       SubscriptBox["S", "\[Theta]"],
       FontColor->RGBColor[0, 0, 1]]}]}], ",", 
    RowBox[{
     StyleBox[
      SubscriptBox["S", 
       RowBox[{"x", "/", "y"}]],
      FontColor->RGBColor[1, 0, 0]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       StyleBox[
        SubscriptBox["S", "r"],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], 
       StyleBox[
        SubscriptBox["S", "\[Theta]"],
        FontColor->RGBColor[0, 0, 1]]}]}]}]}], "}"}]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}, {
    3.53228811956033*^9, 3.53228814463232*^9}, 3.5322885694137793`*^9, {
    3.532288633051366*^9, 3.532288640729644*^9}, 3.532288693436808*^9, {
    3.532326560676771*^9, 3.532326561467997*^9}, 3.5323267539092283`*^9, {
    3.532326855841176*^9, 3.5323268626361923`*^9}, {3.532327648154467*^9, 
    3.532327648472391*^9}, {3.532328314440467*^9, 3.5323283774651546`*^9}, {
    3.532328422377253*^9, 3.532328424681246*^9}, {3.532328560525572*^9, 
    3.532328568167946*^9}, {3.532328656757094*^9, 3.532328674806654*^9}}]
}], "Text",
 CellChangeTimes->{{3.532092134203248*^9, 3.532092150415887*^9}, {
  3.5321141229964933`*^9, 3.532114136163643*^9}, {3.532195780162475*^9, 
  3.5321957995108*^9}, {3.532286988684536*^9, 3.532287098671701*^9}, {
  3.5323694900629387`*^9, 3.532369583549016*^9}, {3.532509295787271*^9, 
  3.532509311123616*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  GraphicsBox[
   {Thickness[0.005317938980894221], 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     LineBox[{{97.1992, 84.51120000000002}, {97.1992, 46.11120000000002}}]}, 
    {RGBColor[0.925756, 0., 0.], Opacity[1.], JoinForm[{"Miter", 4.}], 
     LineBox[{{110., 46.1108}, {161.373, 46.1108}}]}, 
    {FaceForm[{RGBColor[0.925756, 0., 0.], Opacity[1.]}], 
     PolygonBox[{{158.56449999999998`, 42.4077}, {160.13649999999998`, 
      46.1107}, {158.56449999999998`, 49.8147}, {167.34149999999997`, 
      46.1107}, {158.56449999999998`, 42.4077}}]}, 
    {RGBColor[0.118, 0.239, 1.], Opacity[1.], 
     Dashing[{0.015953816942682664`}], JoinForm[{"Miter", 4.}], 
     LineBox[{{180.1328, 69.91160000000002}, {169.33180000000002`, 
      102.31160000000003`}}]}, 
    {FaceForm[{RGBColor[0.118, 0.239, 1.], Opacity[1.]}], 
     PolygonBox[{{173.7334, 100.8188}, {169.7224, 101.1398}, {166.7064, 
      98.47579999999999}, {167.4444, 107.9748}, {173.7334, 100.8188}}]}, 
    {JoinForm[{"Miter", 4.}], 
     LineBox[{{16.5, 7.5}, {16.5, 120.76400000000001`}}]}, 
    {Thickness[0.005317938980894221], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQ3fnl9vXGz3oOFS/VDDlOxDm4ZuZ/aJ2i53DU27zz
78I4B1NBM5u9ZnoOgTvkWk/XxTnkHf23qfqmrsNFpds/L8XGOXDEz/ARrdF1
+FmXtafELs7hy4aA7FnftR1A3MlHYh1SVyWEBLEbw/k2fhcn9rw2cmBbIxMl
cSXWoaM16rLNUSOHT3+vVHC+jnX4khNWuy7JyCF2lycPk1acw4y7k9tZPxs6
TMsTalYoj3PIZMhvDNlj6OC67fPfA/PjHBJDgtQXdBrC3b8gTvO0Q4Shg/A6
94ffPsY5TNvEU6ijbehQY28aN0sq3sFK2at6MpOhg1/v9LxljvEONc36Psvu
GThotYvdPJcW7+C3jMtt6n4DB6DzUo53xjvMB5o3YamBQ4Et13XnVfEOyfU3
bU9OMHAAqv7+/Xi8w50MhvzsDgOHe/694uuvxjv03AYKNBo4WN/3753+KN5B
rZRpVlEVQp4xv5FFtAih/4bQJ0f/WIT5p57aL/F3Rtjfx/ZBzEMF4b57k9tb
sxgM4O5/EiG+/eJ6fbj/mO4xcb4K1Yf7Hz1+Ad4Z2co=
      "]]}, 
    {JoinForm[{"Miter", 4.}], 
     LineBox[{{7., 15.}, {238.69899999999998`, 15.}}]}, 
    {Thickness[0.005317938980894221], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQzae7ae57xTyHPaxCIvZsBg52XNcXv+HLc4jzPsG+
19TA4Vdd1p6Qv7kOad+fJC5MMXAIebx09o03uQ6ecxvUnCYbOMT0H/qqcTfX
oebC5sivBw0cJr6tsTddkOvQvjz8lFGLIZxvttouPPqjhsOnS75Jv5bnOnQk
x955pqHpMF9K/27J5lyHj1+8IttKNR1mH1HY8OlSroOEWjDrYistsPqGn7kO
F11ufPgiqe0gEGG55RxvnoPef8W/Ye3aDjD324dHb9z/Rtvh/fJj3s/N8hwO
O63NrPPXcXh6Qem2pXeew5VZz2SXr9Rx6HRMeHogLs+hZ2c2581fOg4lkyVY
wgrzHLh+Lkjf7KTrAJS+cKkpzyFj86viqw26Dh1AAYHJeQ5HgObd26Lr8ARo
3suFeQ7WjL4tufd0HW79rMs6siLPwQvoIM33umD7zdfnObz0ALkQIb9N9Pdp
KW49uH6g5Ler0npw8wNvSdckuurB7c8zadieUKkHd9+TT/KX8rfrwd3vCgwO
rf96cP/JLX/hoRegD/c/yHzRVfoO6PELAPvE6Uc=
      "]]}, 
    {JoinForm[{"Miter", 4.}], 
     LineBox[{{16.5166, 14.9502}, {109.9996, 46.111200000000004`}}]}, 
    {RGBColor[0.118, 0.239, 1.], Opacity[1.], JoinForm[{"Miter", 4.}], 
     LineBox[{{110., 46.1108}, {174.801, 67.7108}}]}, 
    {FaceForm[{RGBColor[0.118, 0.239, 1.], Opacity[1.]}], 
     PolygonBox[{{173.3076, 63.3091}, {173.6276, 67.3201}, {
      170.96460000000002`, 70.3361}, {180.4636, 69.5981}, {173.3076, 
      63.3091}}]}, 
    {RGBColor[0.118, 0.239, 1.], Opacity[1.], JoinForm[{"Miter", 4.}], 
     LineBox[{{110., 46.1108}, {99.199, 78.51079999999999}}]}, 
    {FaceForm[{RGBColor[0.118, 0.239, 1.], Opacity[1.]}], 
     PolygonBox[{{103.6006, 77.0181}, {99.5896, 77.3391}, {96.5736, 
      74.6751}, {97.3116, 84.17410000000001}, {103.6006, 77.0181}}]}, 
    {RGBColor[0.21200000000000008`, 0.30600000000000005`, 1.], Opacity[1.], 
     Dashing[{0.015953816942682664`}], JoinForm[{"Miter", 4.}], 
     LineBox[{{97.1992, 84.51120000000002}, {162.0002, 
      106.11120000000003`}}]}, 
    {FaceForm[{RGBColor[0.21200000000000008`, 0.30600000000000005`, 1.], 
     Opacity[1.]}], 
     PolygonBox[{{160.5068, 101.7095}, {160.8268, 105.7205}, {158.1638, 
      108.7365}, {167.6628, 107.9985}, {160.5068, 101.7095}}]}, 
    {Thickness[0.007976908471341332], JoinForm[{"Miter", 4.}], 
     LineBox[{{110., 46.1108}, {161.373, 102.3118}}]}, 
    {Thickness[0.005317938980894221], 
     PolygonBox[{{162.6309, 95.45460000000001}, {160.1219, 
      100.94360000000002`}, {154.4299, 102.95160000000001`}, {
      167.41389999999998`, 108.92060000000001`}, {162.6309, 
      95.45460000000001}}], PolygonBox[CompressedData["
1:eJw9V3lcj+kWL0JulibERDTpJjKWYmTt21DN70PyPu9mD41BlyhpRBI1CiFa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      "]], PolygonBox[CompressedData["
1:eJxdVntUTfsW3hLlkai8SkUizi4k5RGaKBGF1vxtIZXy2LouyaPQ8UpIRKIO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      "]], 
     PolygonBox[{{92.97460000000001, 99.0117}, {90.1496, 96.75970000000001}, {
      90.65360000000001, 96.0617}, {92.97460000000001, 97.56070000000001}, {
      95.29660000000001, 96.0617}, {95.8006, 96.72670000000001}}], 
     PolygonBox[CompressedData["
1:eJxlV3lYj9sWbpAGkkopkuFEKbNESi1JypGkb++dcJKjOpo4OUjD7yRKMpQp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      "]], PolygonBox[CompressedData["
1:eJxFV3lcTt0WTpMxGiiVlDQhQ1R85WMRyVDtcw5RIqL2MVeGikLS9yJCylBk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      "]], 
     PolygonBox[CompressedData["
1:eJxFVH1UzXcYr5BC3k3eRh0sRnlptjlmHw2niXu/paIU5YrnokjCSN5aOne5
w5KYJUMoSbUrRXXuSeWt5N2apdOM2J0lnU7y0p7f/d5z/HHPPb/zfJ/v83ze
vk6LV/mE2VhZWWn4p/zHhE7wG5dGiEutzLjRSWBBTokpNYNgXWtjr5snsKHr
cJePswh70lrHPwkVSN7dY+PBbMIR/py6XODNtRdXSnMJ73Y2/3E/SsCnZlDM
5nOEwrc7m7vGCsx40NicUUh43tG916QEgR31FSluJYR0Ffrk7BEw9OMbSi39
BwRseOCGy4S28U/OjEgTOPhkyAm6QXDp0dWQfkIgpHPVAOMDQhfdUM2LLIHl
tZE631rC3ztSK2uyBdy35mP7Y8Jgh7qxu88KqLOTwuxeELrzZ9oZAQXe7GbC
LatamysZsl/fRlCjT2jpUYGeGydldm8ifJQ46/njnwUueWRpF5oI17d4lmze
LeuuzwjO+ujICzsEzPw1EC6Pmrz32nqBvOdRhjCub+XjRSsEevD5Yu4/znhD
Fws4v2uJrn5JSHbSR3sHWfpbCYb07ypGBQpUT3/QmNQu+4cECyxN0AQ/tNXK
+lKB2MSCFdpuWiS12C5KiZbn7bprUaHM32LRj7+Dw8ve5/4g8LYluu5XBy3+
C/SYGnJQIP6Le2V/dtGa9b2aLmBKnTImme9X6LLLERg5t9PR3tZaMPyO7gUC
LjzwAPOjjFtSItDg6doe+YpQ/j53U26pwMKHMzvU/0NYM8ih7rNyCx7mf+1M
3rBCYPSpPtXxDwlBHlMblDrL2eB4l3CY7WYolXgeVRJ4ec8ovr/Y2H/k7XKC
Im8gz1+j0z82sV9qTrcFBfB+xASPKCDc8ze5LWA/rLR/nRadK/Wcw3p5BTDC
TKnPoF3SX0tOSn0e/SKg0HnuKOH8Tata50wBu6oB3mNS5f3fGgTW1R3qNSKF
MLB+fv/8iwKOTIj1XkJIyux+1UaBcQxoWCJhHxPSekngjmLQ7R/wdhvuEuuz
mfAmKLzMtVz6JWIDQSj+YrxXSz2ynq0i3Pk0bEB9ocAhbm8lQuP3V3yN7Oe3
nCeHpYRtUTOTbFmfgd4cKI3kp4T37328yDg+RO6n5vxYsaFmBBMafj/dNjhO
4F5ZuHtxoMzz/XUCTF/T4flSn7HLpR8b/QmfTynyqVoooNBl8CPMN7ldWOYn
wHQuy/MlGE8eU8HLgm+e5MvGQ+CnydZz4hYQ2nM3NZ1lVIs4j95LCPlKPUDu
e5r3v+iT7NTG8yKUQGoJN+76m37cJMDrDHVeyfvzOmt1AhzPBA3zUZXBJ/bL
/DtGkcLW7adHBIrYD3PXS7z3Twn0YvyfxMg83+E8s9tGn9r2Ie/K+zQyQe63
mvlkORK/ZL3sFUMdE2hqnhXgryd4sb29UwT6KgHSW/RIkHny1Uv/vNkocB7b
6yu4n1+vKUVaAWVcno4Qz3J5zrO8NwkWfWZI/xzfQjgXF1Od91pt9kv1GsK/
DsXjDoxWm9+b2Ej2y/D97T0d1Zgd56B2W83vZY3uXVgHNfKVeRGEJs31YK8G
ldn/Nly/OuFSjutNlVmficxPZbDX5c5Glfl9TGF+zmd3eJqYr8I3WdraSOZH
9Uo/d+1vKpzhz8nMT0tBje4rrheusH89LJ7gNO2l5nqJCtP5/DbGc8jvcGZ4
lcrMV8EuwkQeF/GXCq+G3lq1aB/Btnffr8uD1PgfxBnYYA==
      "]], 
     PolygonBox[{{206.17969999999997`, 76.71000000000001}, {
      203.35369999999998`, 74.45800000000001}, {203.85769999999997`, 73.76}, {
      206.17969999999997`, 75.25900000000001}, {208.50169999999997`, 73.76}, {
      209.00569999999996`, 74.42500000000001}}], PolygonBox[CompressedData["
1:eJxlVGtMlFcQxZVQQXkIvjEqtYioFAmIERQOxAihinu3SK0iKir2XuuDAC4i
tLVIsaB1W19IFYmBLSVgkEpVXhUVgSpFBIJKFURYBFHptiUIFjv7fRqS9sdm
czL3OzNz5szYhe1UbVEYGRmto5/h37c2vLGzh8O81UmTYaXEWxy57GifiZ8S
aaNs00OL/4/bE9JrciwZglQOM1IIr4TNxnXTGVZnL6iZWMLh/eRe7pz5DB3e
mestSzlCfL2eVPoweAbWfRtXxrFi/MGA7g+ZgW+auMJR7GA52i+cwTuzpazt
qsx3JIbh0+D49/+o4Mi3b0/Yn8ywgRJmVHPsp/S13zOsqS/ZNFDDER1haz4n
l+Ek1WdWzzFvy+Q2/2KGUMebmua7HIHE96iKoVPM7VO3cHxVHVSe3cAQpUg7
0K3jiK109Ah6yLDMPlrh9YLjjtFDxckOub74fg73xaWqed0MkyObwmL+4SjP
zrQIecpw/lHXsQKFkPivET7levbCQopT+wMhDxg+Jj2KX3LsqBgqGLzFoHFR
O50kvtU9zsUnrjJsbaSKCOcNhGyv+Fnq5/FQv6yPu5Zh6cCzp8pBjijSX3eC
4fIhk972IQ5bGlhDCgPJGfLZSAEvQ8J9Ur3praMEGoJ7nD+KZaB0drUWAs1N
+yJ1UQw5JKD5eIGAbmO3rAj5faitkPg0u2RcYCewnPKfo/irSZFNegcBF905
e+NoBhu9T22bk4DBDinEP3+51myZq4Cx21j3xV8yZLWUWbQuFOikcqwOMlzb
nLMhylNApKlPKVIZHhxJSryxRMA0efomM62sd5qXAMl73I7613lnnvEibGhn
djlDZdGlQ270XuzsTfz6JsP24PjnScT3DQ3cp5FhLem1dJHALDLkCprfOL3P
YbW7wOuCvfpcHcOUyCbrea4yX8hzht4J/podzgIFym1pa/9mmJoe6vjBXIHZ
lqMLtYMM06o7XtfMEphKeiweoUIsGXrkuwJryb+TTVT4aUxET99UgQvaPZVL
zFQwtF84UaCfBMoyV+HXDu/NAdYCf5HgK61UOJfS/MnVMQLqU2dnLrKW+KId
3xGg9OoNNhJfbsqIN/4hTO42dRng0GT0n7clfInm7fEnh4IEcx6rQtnjcae1
PZK/w8wtVHCv8QyM0EnvXW6YqjD47ClSWzkKtXv8uLEKbWTPSc0cMzY9X2My
JM2j9UUjx6ry7Pfy+hh2K2jidRz3SZ7tpM/t8MatJ25x0DhLgsn/Py6o8Qyr
4ugi/WKaGe5a68tjrnPE6fNvP77N4EZ2v3tF9qe2guFoUuL9eNr3YOK/c1ni
6wwv4siiBqPzmFS/5qK0H7FnMuTv+y/I8Y1HhrFBjnrq33COxCqO9ankSLNh
LMXrmdSfciPHF/6/xJcSpnHYHxNc9lO97OfkCA59vnJbbB2Dx8yAvQm7OaaT
Hr6/MZD6zVV75X03Jb8Z5CiK42A0n1eFb+oh7PHdzc/9fxjGdF5WT6R7+Lae
/2KD//Lpnu4zrjjsouaSf+5ZK5Gc/6hrfDLHBDp/122UOF5ABjjN8dKwYOOU
0v24SPduCtFdpDhV6/z7fY6tS/nOfPq+ivZhV7s8j4axSlTTgW3pGc73L4Ac
pmQ=
      "]], PolygonBox[CompressedData["
1:eJxFWHlcTukXfyWhqKSVCAkJEcranIyyJeskvfde0vuEkLGGmkwqjSyJikiE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      "]], PolygonBox[CompressedData["
1:eJxlV2dUVccWviIP7CBRAY0hiEgMWO65vRzcsSCyCJk5QSQGu4jBQogKQSWI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      "]], 
     PolygonBox[CompressedData["
1:eJw9VQtUjVkY1VOGSamGLEpJc5NCelBy9zkXJSUqavKcyNsUoeQVpkHJ1SCv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      "]], 
     PolygonBox[CompressedData["
1:eJxNVnlcTekbL5HC2IY0jWZs9bNH55xb51zLN8WgLFmG0EKiad5bUgqFqKZU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      "]], PolygonBox[CompressedData["
1:eJw9V3lcjdkbT3YlNCH0S0hC2d333vve9/bFGESWCMV5rxKaRBiSMRq7LDPW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      "]], 
     PolygonBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQrfmWd5/BzWiHPaxCIvZ87g5/rArOJVyPdthnMFPL
45Wbg8mRjXp6l6IdJq1sCjx5ws0ht6Jq6ZeT0Q5l/nJiVavcHNzci37y7492
WMwINGGCm0OMguPH2xujHcLmr17rUeXm4Pe5L3jLomiHE+y2s69mujnsXM/8
/MvEaAdzqQPRBfFuDpauQAPqox3ubm2puRDtBrafIw8hzzMZaHEsQv8v/pfb
9f0Q5oeUqEz/74Cwf1VToKesGcJ93X9Tvz/RRbi/Y3n4qU0aCP/pOsu8fqSG
8D9MfpaWxFQTI3e4fpC964Pd4ea31VzY/LPQHW7/EzOgg3vc4e7bCzRPfpE7
3P07gP7u2eQO91/db6uCd3vc4f4Hyx9wh4cPTB4WfjD9sPCFmQ8Lf5j9sPiB
uQ8WfzD3w+IX5j/0+AcABEPoPQ==
      "]]}, 
    {JoinForm[{"Miter", 4.}], 
     BezierCurveBox[{{111.3936, 46.1113}, {111.3936, 45.3413}, {
      110.76960000000001`, 44.7173}, {109.9996, 44.7173}, {109.2316, 
      44.7173}, {108.6076, 45.3413}, {108.6076, 46.1113}, {108.6076, 
      46.8813}, {109.2316, 47.5043}, {109.9996, 47.5043}, {
      110.76960000000001`, 47.5043}, {111.3936, 46.8813}, {111.3936, 46.1113}},
      SplineClosed->True,
      SplineDegree->3]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     LineBox[{{167., 46.1108}, {85.916, 46.1108}}]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     LineBox[{{167., 108.5}, {167., 46.111000000000004`}}]}, 
    {JoinForm[{"Miter", 4.}], 
     BezierCurveBox[{{82.66799999999999, 15.}, {82.66799999999999, 20.008}, {
      80.74399999999999, 26.098}, {78.72999999999999, 29.1}},
      SplineDegree->3]}, 
    {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQ/WTp7CMKKsEOp+s99tfW2jk0ZO0pKdYPdsj70Hpy
yRNbhy7HhKcBlsEOKZKPIqaH2jpsPVG2779jsMOJkIMrRM7ZOGye+375Mc9g
hx1/2r/c9rZxuOKbJBCRGuyg+qR53lkvKwc7ruuLCwpDHLYsqzyuKWXr0Dc9
T4g7OcRhkfLOP+F2tg5KG4oyAv1CHNb8isl1LbV1EIyw3HJCLMSh4rim1SR+
OwfONTJRS64EO9zXnbCg4qKdwzKgc1dsCnZ4yWIi+MzS3oE1jE9308RghyV+
DsKJi+0dTpXtmy9WEOywjMtNdS6ng8OH5ce8xQOCHQ6lrEqY4uDg4Lbt898X
hsEOuoryX1TKHBxm5Ak1HxANdsjS/jb97koHhy1A/1z6HeTAkN/I4nvbwSFF
IMIy5EmQQ/F1oU+MXI4OZZMlWKrOBzl4BPyR6DZ1dFC5/fOf1LEgh4I13bd/
ezo6bP/890rF3iAHlqP9huWxjg4lGRPfmh6G8MXdHB1+1WXtkTkZ5NDWGnX5
j46jg819/97wq0EOJ57aL7n/1cFBERgenI+CwO5bs8PBIaAXGGDvgxwkQQ4o
dXDIBzo36E+QwwcxjwAbPQcH5ds/61ZxBjvoTVjww/CIvQNQ+tRPsWAHUPBr
qdg7oMcvAP0Z3HM=
      "]]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     LineBox[{{180.4639, 69.5981}, {180.4639, 46.11110000000001}}]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     LineBox[{{180.4639, 46.1108}, {166.9999, 46.1108}}]}, 
    {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxdVntQlWUaP+IlEpeLYaXIAjGMiRGgCIQBvyjp/d5DRMSyLBHyckmui8ga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      "]], 
     PolygonBox[CompressedData["
1:eJxFVH1MlVUYh9CMzAhREBSBVYjEHBkRXcF+EZxz0Z1zA4YXZAy1kZUiDLM/
GqMrIwZITEALRD4EjZEpkUOGAvKpCYYMEYQRI7uKKJqAInYze977Ovzj3bvn
fDzP8/t4jtu2hLC4FywsLAR9yj+xO6N3xI/D5mvf4+sHJEwaWjnzPH66P8Wk
KefoO3TTeWyHRHO064e5hRwUVo4GSqy0/0JM53Gseer2ZMZFYuqTSzFv5XDs
GT1sG28p8dp4XbXVPo7IdL/+b28IhIUUG1gmR9NEiX9ap8B3HncXNWVw7FcK
nhTIehL3yEj7XkrBfQKfPjJuPZLNEXji85HJJIHknlNRD3Of9acXWL3sYJ91
EUfo0PLkP/0EZuh4/1GO/o54H8MqYe538ixHFNXvcBZQrtcPc1wOunb/geez
/TscHinZ9TtCBF5cvOSD80YOU9e9i23bBG5me9yNGeRodXAPj9grMEn4uno4
dvkY6ppLBIJW3Ln+YyeHc+UtbckZgX8V/s5z3H+wISq9T0ATzJOs2znmV+Rp
bCcEnKhgSyuHmV4LiY/ovi/FCn17XCUiSo+fKGhV+Yh+T4K6Ga5t48gxTrmE
SQltscE9tYOD0NV9HKfqMXmBozxPYymSJQIp30ynGgfkSxw2uLemd3Ncv1Bw
1v4niULPZQcP9Kr89DRLWDbMX7xkgGPKpTchlvQ+5kUdbdbOxesUgyRr1fzD
EqML86tas7WYR3gsb0m88QM5JF+L3bVLTV3/SVXPNC0SYxd0OzroEFBEiOK0
cA8nBpx0qLYay/a4webiV5u8C293MxD71vWOOih2GfuVqXrZ6cCTHtuszmPm
fkqtdJi1Ga/TG9TzbjMSa3ZVWDbEM5wjP3kZpZnf92MZZPWBOIsrEtM54V8a
Q5nZn6dbJE6nkYPWMey0fly2/YgEpR+vW8Xwu6PiIInND+uHst5lqh6Jqh7X
OMPFNnJgisRLBEgfw6DAPV8k8ZVupb3nbgbbY40tAzUSPn/7BVdnqP1WUr1+
ZaGYmfXCJQnFXitaGFJJENNVifYaQjDI5vjO7B0ZXbj8uR7llGDQjiPC27Mq
uFFCT/24vsKxZW2Et6ZCYqeYzrlnxfEP+TUkU+IoCRpmYmZ99iZIFJA8duMM
s2XbTx3yl9ik4LnKsCm65tzEyxLzSI6lrQykbtofQwLktjT/kwyNLQ7uV34W
UOzpRHgW6YjQSKHO8zcM6/WUwF/AU5m/LIYERe831fnYWMbm5m0LEdRfy9Dw
PTn6dQF959r2mnYGJfR9RyCXnpdfLqv93d4g5vgwz89nApF0/u2/GKrseoIi
MwQ2/rYgoIjwmN+HUoGq1NCQ4lmGrcSH56DA/xBCL34=
      "]], 
     PolygonBox[{{53.422900000000006`, 64.71390000000001}, {53.46790000000001,
       64.87590000000002}, {53.288900000000005`, 65.05690000000001}, {
      53.13790000000001, 64.97390000000001}, {50.0369, 56.42290000000001}, {
      49.99190000000001, 56.26190000000001}, {50.1709, 56.08190000000001}, {
      50.36690000000001, 56.29690000000001}}], PolygonBox[CompressedData["
1:eJxFVGtQVVUY5TmkoEQMmdMokAh3HEMCQ/M1i0Syu/c5+4APBvABGmIqiQOi
+SxR0kC8oZEigybZVVTMTJBBMjUfjAZhSKCNA6RIiA+QvEYy9J19Rvpx5843
e5/1fetba23fBcujEh3s7Ozi6af/R958fV2Cg4L1CcGzgroUbB4kju+6y/vr
T8qwqaWJYx3VKfUKhlvbpgfe4nBQ6Ga5gife15fPr+OYc+Jsx7x9Cr5M3Lpw
7jWOWwQbvF1BRMPj7s8rOI5OiY7r/EyB7FfA8fKa0CNTtiiIci7K7fmYo+Fi
8lhsVnCnSwfkqBlKN6k+7PlreIOF9ddTj314e8VAjqwcutmjIJzwN03n+GDu
HxET31JxP/WUV8U6Yz73BBUjTRuy+U4OD+pXla7K+fOsHOGEE5OlotTr36vW
co7dFvc1tkIVV3ZX5FmqOF6qpoYnVNAWRsX/zpHrviZ0ws8qaDgX/z85gvp8
e9V6FZm0r84OjtsRjqu1NhUBM5yLrncbeOk9KvJoHw09HLGZ4+ufuQmU0Piv
9HG8QUDuPgIqrdFir6BtmLWtM0TghR7FOu/pAtceVl0YQ+ehJERzvJA8j/Ry
1BLxjlUCv9E8D2wcn5JO97Yb9eDHHObAPt/KAwLexDeglWMMzRtTKpAy36U6
8ibH24RXfEWQuJd3f0t6xbtUD81vFIYulRw/tNMi/xKSb8hRjrF0f4BNSH8U
7OF4kjMj7Tt7DU0FHgd3beFoyzYlO7lo2J90sj0khePZnYSv0101bKS5dsZw
mM5nBvQO1jC+/mLytTCOVWL4qzkemsSzmTjay45neHtqhr/ciY//+Uwr1TRW
ZJKNYVJK9VY3qjsKJ40+08TwcNCPQe/T971PVzZNvMowxyescwXhLz7Znvp3
KQO/4jJ570ANceRLWxGTeI3OmtQ1KpfhXJxPWJidhoLWYVbPTQyFHgcrf3ki
MI38ZE5laCZelXeF5O2yiKEuv3XY2noB3R7RsUz6a8wlIfmaNYaubnOMwykh
c/L4PYY39Q+KhNR9dhjD5NF1+cUWIefbPonJPNSuF6B1jC16x8CrWCJkH+t4
hirZSEBfx1n6vocaLQkWWEj6O85mWEsyRXsLkMy0AuN7MUTAzY8Mv5fBabWr
n8lPyHzuO2Lwsx8n8JFO6Hsm81o4U0idZ5UwdOi5edH/AJN+dt0gZB60HQzz
qO3pLIFMXcA0JvfWRnx0uwYn/l/r+pWkMJgoB+3FAqN1wI0MK8h3jecE0skw
Iy3GvF/dEFg24J/9SaSP7mvHVoEN2eVLt51m8CHj9XUZeIE1DD+R8MueC5zJ
s7j3tDIsst1J8CL/ybz2MdzLNj0Y5KDhUdWFd3tHkN8I6H6fkP6JncpBMT7s
2S1QSo4vm8tB7PwONQt8U3luiH8qN/SuElhJ853K4JLP4mMCNZSztB0cLfo5
5SuGFrAyjyOBgGuXCpTJBHFcTqbFUl5f85/hHELniI47Ee0voMt0K4fL3Jud
BL6gdyQuw3j/LrWoKMqdYK+kGe+X43kVeuzYAo5DRHvcAVW+h48Ujptkyz0Z
KgbT83xjHMdTc0xm/CIV1Lwiz4fj+VV6KMyqocc0hhF6MGYq/X6K0g9GKYb+
Lby//g8DK6hQ
      "]], 
     PolygonBox[{{64.3965, 60.407199999999996`}, {64.591875, 60.429075}, {
      64.6935, 60.58219999999999}, {64.591875, 60.735324999999996`}, {64.3965,
       60.7572}, {59.511500000000005`, 60.7572}, {59.317125000000004`, 
      60.735324999999996`}, {59.2165, 60.58219999999999}, {
      59.317125000000004`, 60.429075}, {59.511500000000005`, 
      60.407199999999996`}}], PolygonBox[CompressedData["
1:eJxdVX04l2cblpLJqyZfxdSrYmVNpZLMxxlek3qe576FEElei7dMJUUqsT7k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      "]]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     BezierCurveBox[{{71.333, 61.0386}, {78.041, 60.3106}, {92.55199999999999,
       60.7626}, {100.5, 51.4326}},
      SplineDegree->3]}, 
    {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQneaSmf8hM9LhhtAnx/N5ng53mTi75JMiHQoaWY6W
T/Z0EEo8fFk7OtJh6f19fHe2ejp4i/Z4vQqJdNjMU7im+Zqnw/mrYW/0/SMd
rj3P0v721dNBd8KCH4ZWkQ6XJsb8cy7ycthU/WlDwP4IB97CNd23F3g6FEjz
PuC9FOGwwvSstV+fp0OUk92Lm+8jHGz8Lk6MAdovtv0iQ51wpEO85mmB466e
Djv+tH+5rxrpUMY0i2O3vqeDr4Nw4mHzSIeVIP2Sng6n6j32c3pFOqzfllSf
yOjpUOexv7YW6F6FLzlhe196OBgJmtkw5kQ6dLRGXZ5yycNhQ0D2rPLqSIdS
oHnSezwc9tXKWhzujHQoAfKbl3k4qPFzbz02LdJBRPbk0/8TPcDuT1kU6fDo
5dRNR+o8HDStJp2uXxPpkMmQ38iS6+HQD/Ru0NJIhxO7dvTua/ZwyMj/0Lpy
bqRDha6i/Ja5Hg5B0xT7Zk6NdNACemfRLg+HFywmgma9kQ59bB/EPG55OJxZ
df7qpJZIh5Ag9QWJfzwcZpTPWXQY6D6g9i9rFDwd3gAD6E5RpMPJp/ZLnrt5
OqDHFwD6fMZJ
      "]]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     BezierCurveBox[{{100.667, 46.1108}, {100.517, 51.1098}, {103.5, 
      52.2018}, {104.6, 52.8328}},
      SplineDegree->3]}, 
    {Thickness[0.005317938980894221], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQzWE7O3R+eJTDl5yw2nXvvBwKz3VcUnOJcpjS3hrF
/czLQcT+2J2vhlEOksXXhTbd83K4/4B78kGFKAe/ixNj0m54OexhFRKxF4hy
+Of86+3rS14OAXJiWb7nIx2S62/aVh7wcvjF/3L7evkoh8I13bczVng69Gm8
5bXTiXJ49/qA5eOTng5l/kANjlEObqqlTLP+QfivoqMcYoEG6tp6OVgVnOtQ
yopyWM7lpmob6+Xg97kvuKQiykFU9uRT+xoIf0J7lMObA5bKp2Z7OWzWy1uc
OC3KgSG/keXoTi+HRKCBp5ZEOdSu25b0/6qXgx3Qu6s3RTn0sX0Q8/jg5aCf
t5jxxX6Ifbkc3g5SB6IVEs9AzZfzdniauPDaj+tRDo9eTt3UY+jtUKoy/f+E
RxD3Kzt5O4TPX71W4FqUg8aCzg2WFt4ORzfq5T0+HuXwYB/fnM+63g5A4/fo
7ohykAMal6Ps7cAECrDlUQ7P7Jfc3yfh7aDjLPN615QoBwcgl43P22Feg9oh
t8YoB8NyXcV4Zoj6OzlRDgctlb0e//ByQI8vAFf1xTo=
      "]]}, 
    {RGBColor[0.925756, 0., 0.], Opacity[1.], JoinForm[{"Miter", 4.}], 
     LineBox[{{167., 46.1108}, {167., 102.36179999999999`}}]}, 
    {FaceForm[{RGBColor[0.925756, 0., 0.], Opacity[1.]}], 
     PolygonBox[{{170.70309999999998`, 99.5532}, {167.00009999999997`, 
      101.1262}, {163.29609999999997`, 99.5532}, {167.00009999999997`, 
      108.3312}, {170.70309999999998`, 99.5532}}]}, 
    {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxFWHtcTdkXT0LyaCaPKBKTJnkV8qjuuevecw6R0aSmodLZk1eRGIzJe0jy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      "]], PolygonBox[CompressedData["
1:eJxFVm1UFeUaRbTID0IkKEMkNEUSUMhQmPec2R0RuYDIxY/ARHkEBEI9KeEX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      "]], 
     PolygonBox[{{148.32230000000004`, 42.4604}, {145.49630000000005`, 
      40.2084}, {146.00030000000004`, 39.5104}, {148.32230000000004`, 
      41.0094}, {150.64330000000004`, 39.5104}, {151.14830000000003`, 
      40.175399999999996`}}], PolygonBox[CompressedData["
1:eJxFUn1MzGEcT2EtrXJojZiMK+m0M2q6+t3nnjSa0rwLq3xjWk3sKmOrvAvL
kkOmFWnVH/qjNRoJycvsNLV2Q96uoVazq6yXU5N8f78z92y//fbZ8zzf5/MW
QAc37XN1cXHR8Sf/f3bEk884wUVe1wVC6ssGav4Qlu4uahmpF8hUnWo2TxKe
jQTtLjILrA8/b0jh/cu2XH1Oj4AxrdiWy/d9dqy++2pYoDHW0/XOMGHnXp3V
e1xgLD+9KdtG4Fvd7Yw9XZcV+M5zYr6tXzWbUF36fGFdugETliN96lAnfv/G
fuoM40hrgib6uAGXbLlPxhkP1rxcP3zFALdtXprlWkKOyW/q44cGBBf4Jr5e
QWgYmrAEWg34wAQ+rSSEJTXGxk0a0KvWnssIJ2Qz7xh/IZ/vPBnhmBcaJpBt
8jsdIhE07MOieIEbTMMoCLX+rGiPQBbvJ68l9DNtk1FApjsRR8jieWtOCIXf
1s2EJh6UcVFAlp+1kxDHvi0sUfw6kEKE2zENQ/nlArIN6gwCViU1VlQKNJsr
XrRnO/RXVgvw8+LPUQI/X5pco2Bj2jECy64vY3xzbujnxXVOrPjpQ5DjC2qV
wLZs85pBKB9ggfslZX+fJ2EWxxqgkZS8A/n8kuknrkZ7S7Lfm4fmEEY5bjFV
grssfP6/PFwlHH7ML9qd+MfG+wvOTEl19KUdil5TD/3HqTpr24VugoVrllgN
qLXukaPfCZ/G8s3WYih5b2LszfTtecBZ384Nlq+Emdynb9uBCGvCRXsXQZYX
uhLY4qVZUfWFIHm8q7SpALmeLz46+KT06uWcvhvek8JbVadHklxICzl6l6cH
17Kt/43ip644QY9xJjz4ilB5KMqjJlAv9zZ58KnjfO40vZxHzNsHpPzD+iTs
L7b9vsB+87TOXx0SrmWqTBl3lPe7gswSCksyVfYqR/96WyRo3WsLg28R+tTa
dVGPJLA9s9xuEFp5BT+QEFBnvJ9nInAsI/caJOhYb0khoZNz+HZPQiITTtjl
xH8BeL+pPA==
      "]], PolygonBox[CompressedData["
1:eJxFWHtciFcfT1rUktyqIYViJKR5c2t+UUITNc/znE9IpcU5yH2S2KolpJsk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      "]], 
     PolygonBox[CompressedData["
1:eJxFVglYj9ka/99IWVIx2cO0SpO9UaJekrIV+Z8jdO2a+o4lo1GRkoYsc0lT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      "]], 
     PolygonBox[{{228.06640000000002`, 98.96190000000001}, {
      225.24140000000003`, 96.70990000000002}, {225.74540000000002`, 
      96.01190000000001}, {228.06640000000002`, 97.51090000000002}, {
      230.38840000000002`, 96.01190000000001}, {230.8924, 
      96.67690000000002}}], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQfeqp/ZL7c3Ic/loVnOvYFebwV6L4utCDHAfmPaxC
Iv7hDid27ehd9jTH4eeTxIXTIsMdSq4LfXJ8l+NQs1THWSYx3OFllvY36a85
DmbvLVz3J4c7hAWpL8j8l+PwP/X7k4Wp4Q7ZDPmMmiy5DrEKjh+90sIdVL2q
m3dz5To8NZM6cBjIP8A3x3iRVK7D177gEpV0BD/6685bXXPDHRZvMf9x6GeO
g7xYlu/nWeEOVRErTM8C3ZNY5i8nBuRvfPhy6qZVOXD1MD7MvDsZDPmNG3Ic
0s7Eeq8A2re2+3YGw7Ych+9A5X9Twh1k5sVpeu/OcehYHn7qEtA/Cl9ywmoP
QPx7LSbcQWNB54aHQPlnQK4JMDxu2VZGrOjOAfsn+UmYg8gnx/NpwQj7fh5K
WZWQhcmHuQ8c3ioI93e0Rl3e8zQbLg/jo7ifD2EeOH4yoO6bEgYxTybH4fX2
9czP34Q61K3blrRZAuLfHU9DHUDe6RPOcbAFRm/Qg1Cwe2p4IeaV3Al1CAXG
VydbjoOIiP2xOzdDHa7seSxy8F+2g9zrR2ZeN0IdHJfc36f3Ldthxv8JddXX
Qx34Ctd0334EdR8Sv0/jLe++BaEOWqcFju9iznE4yW47O3RxqEMw0PgN4pDw
NVoS6rBhW1J9pFmOwyuQexeFOkxtB3o4KAeuH8aHma/zbfpdZe8cB3YhEXs1
oHtuAJOfv0uOw4WOS/ce3Ap12MwDdIBtjsPbR8AE9RiifrIjVP/7UIe0VQkh
QZVQ9dlhDnqK8l9ydiDMB/mPbxEmH+ae/86/3r5+luMw/QpnhhLQ/SrA9Kuv
lguXh/Fh+u9NBnrgL8I8AMlInf4=
      "]]}, 
    {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
     BezierCurveBox[{{198.40040000000002`, 90.73100000000001}, {
      192.02640000000002`, 90.275}, {178.2364, 90.558}, {170.68240000000003`, 
      84.70800000000001}},
      SplineDegree->3]}, 
    {Thickness[0.007976908471341332], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQZOqQ7mUgeiFZ6GOJRMlmCJ8E51YHneoyH6JsRh
xTFvc8mQVAcrV/ciy08hDrZc1xenxaQ6fNt5q2vr9xCHm+e+ByenpDpEnDI6
svFPiEPQDrnW182pDofaloef4gt16J2eJ9QclOrAlaGUU9EX6uCXJBCR6Zvq
MK9B7ZBaTajDGpmolN0uqQ7TrnBmKMWHOiQLRFgesUx1WNUU6FlrE+pwqmzf
/CvGqQ4SU69wLtEKddBuF7t5TjfVYfJKoALJUAcQN1091YEHKDCVPdQhaw/Q
B4qpDosZ97Bu+hbi8LbG3vSdVKrDmhvxZbufhThoxvQf+iqS6lD326rg3PUQ
B9O4XZ42/KkOWb6f+9hPhUDM50x1OLJRL695b4iD8u2fdbtYUh0eck9eGbcJ
op6HIdVBxP7Yna0rQhw6HROePmNNdTB7b+EavD7EYdXHS76TeFIdMoHejdoW
4hAIDI+/wqkOzxIXXtsBNM/6vn+vuEyqwxMzYIAfDXFQ3FCUcV4l1WGWlsRU
g7MhDiDni+ilOjgAjVe5GuJwAuR/c4j/VO+GOKDHFwD1qrwA
      "]]}},
   AspectRatio->Automatic,
   ImageSize->{352., 191.},
   PlotRange->{{0., 255.}, {0., 138.667}}], 
  GraphicsBox[InsetBox[
    GraphicsBox[{
      {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
      {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -2.6678041342529504`}, \
{-5.628231475275794, -2.6678115445620056`}, {-5.421788280513543, \
-2.667160690753425}, {-5.212399735329252, -2.6653073051928438`}, \
{-5.00325118175986, -2.661938371970305}, {-4.794342619805368, \
-2.6570538910858095`}, {-4.712506466827043, -2.6545439121544314`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.688905571864801, -2.6538200542143766`}, \
{-4.585674049465776, -2.650653862539357}, {-4.445905536559083, \
-2.645345021281961}, {-4.3067648732861805`, -2.6390343139498875`}, \
{-4.1682520596470685`, -2.631721740543136}, {-4.030367095641745, \
-2.623407301061706}, {-3.893109981270213, -2.614090995505599}, \
{-3.7564807165324705`, -2.6037728238748135`}, {-3.745903008894787, \
-2.6028923914969266`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7223723854773336`, -2.6009338269914393`}, \
{-3.620479301428518, -2.5924527861693503`}, {-3.485105735958356, \
-2.580130882389209}, {-3.350546997480164, -2.5667518257028115`}, \
{-3.2167903057628604`, -2.5522244502136493`}, {-3.0328115232337622`, \
-2.530333572005533}, {-2.850780545401912, -2.506574172855656}, \
{-2.783771696835819, -2.4970380380430997`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7603952341837066`, -2.493711296813225}, \
{-2.670697372267309, -2.4809462527640176`}, {-2.492562003829954, \
-2.4534498117306183`}, {-2.4692272151538517`, -2.4497050673109517`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.3378161183196577`, \
-2.4274791142736163`}, {-2.230593088152367, -2.408391585011152}, \
{-2.034117496260978, -2.3726840783687524`}, {-1.840998526072801, \
-2.3361111112974533`}, {-1.8296499289650492`, -2.3338721337898516`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8064844757926708`, -2.329301795437552}, \
{-1.6512361775878368`, -2.298672683797255}, {-1.464830450806085, \
-2.260368795868157}, {-1.3300014963870224`, -2.23247414497471}, \
{-1.1968791013530922`, -2.2056942621659803`}, {-1.0654632657042946`, \
-2.1800291474419686`}, {-0.9357539894406304, -2.1554788008026744`}, \
{-0.8800504161911398, -2.1457078803789327`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8567935015558512, -2.14162840308606}, \
{-0.8071077280314303, -2.132913060227806}, {-0.6788809369460265, \
-2.113201763697072}, {-0.5510736161844187, -2.096344911210472}, \
{-0.4236857657466071, -2.082342502768006}, {-0.26892460907294624`, \
-2.0691242080265813`}, {-0.11129360081258652`, -2.059790671658014}, {
           0.05010740445437556, -2.052949247576246}, {
           0.08254347039483564, -2.051827761231128}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.10614136254870497`, -2.051011857296517}, {
           0.2161785521478434, -2.0472072896952205`}, {
           0.3867793620144847, -2.040542029170647}, {
           0.5617693538009683, -2.0309306971582357`}, {
           0.7399035334868286, -2.017056156908257}, {
           0.9199369070516001, -1.997601271670982}, {
           1.0473699978610307`, -1.9800441002433486`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.0707610288576488`, -1.976821386751365}, {
           1.1004801138290303`, -1.9727268217824023`}, {
           1.2801437931528636`, -1.9425935875785107`}, {
           1.4582746747369393`, -1.9083054250647902`}, {
           1.634219488295096, -1.8709661902467234`}, {
           1.8637155649102648`, -1.8196476135002202`}, {
           1.9962414441263054`, -1.7896489890824354`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.0192708056604864`, -1.784436051267331}, {
           2.0896582631649174`, -1.7685031111209308`}, {
           2.31335637067389, -1.719731522750578}, {
           2.536118675052017, -1.6755316880308846`}, {
           2.7591250494440507`, -1.6359395893189919`}, {
           2.9466251210642107`, -1.6067420018915188`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{2.969955935758747, -1.603108917936341}, {
           2.9835553669947408`, -1.6009912089720413`}, {
           3.1389523352175877`, -1.5795386768322233`}, {
           3.295494460151299, -1.560053869548085}, {
           3.4531817417958757`, -1.5425367871196265`}, {
           3.6120141801513177`, -1.5269874295468477`}, {
           3.7719791856707205`, -1.5130754719454231`}, {
           3.9088385478001872`, -1.502366241655622}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.9323785824286612`, -1.500524236491023}, {
           3.9330641688071792`, -1.5004705894310275`}, {
           4.095269129560693, -1.4891727820036609`}, {
           4.258594067931265, -1.4791820496633228`}, {
           4.42284465269925, -1.4703066329796788`}, {
           4.587826552645005, -1.462354772522394}, {
           4.753539767768531, -1.4553264682914682`}, {
           4.875495821308352, -1.4508534407119837`}}]}, 
         {Arrowheads[{{0.016051864801428565`, 1.}}], 
          ArrowBox[{{4.899091948535454, -1.449987996768921}, {
           4.91998429806983, -1.4492217202869015`}, {
           5.11203446196108, -1.4431133706696224`}, {
           5.30437624107148, -1.4377720672139171`}, {
           5.497009635401031, -1.4331978099197857`}, {
           5.656854249492381, -1.430043412282737}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           2.6687014448852087`}, {-5.628575646685763, 
           2.6687089483243502`}, {-5.4217519770536144`, 
           2.6680575308658114`}, {-5.211955500909859, 
           2.66619867593964}, {-5.002399935865031, 
           2.662817349966801}, {-4.793085281919133, 
           2.657913552947295}, {-4.712506558938833, 2.655436816905503}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.6889057118049955`, 
           2.654711401230605}, {-4.584011539072163, 
           2.6514872848811213`}, {-4.444246255419217, 
           2.646167793788346}, {-4.305109829003859, 
           2.6398461484134423`}, {-4.166602259826089, 
           2.632522348756411}, {-4.028723547885906, 
           2.624196394817252}, {-3.891473693183311, 
           2.614868286595965}, {-3.754852695718305, 
           2.60453802409255}, {-3.7459025499368046`, 2.603792195825433}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-3.722372114725495, 
           2.6018313714828363`}, {-3.618860555490886, 
           2.593205607307007}, {-3.483497272501055, 
           2.5808710362393366`}, {-3.3489864093726798`, 
           2.5674828725548484`}, {-3.215277562492505, 
           2.552946731399905}, {-3.031326541585109, 
           2.531041045409627}, {-2.849324803778895, 
           2.507269961447205}, {-2.7837711143518495`, 2.4979362038070008`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7603948859764293`, 
           2.494607816768754}, {-2.6692723490738626`, 
           2.481633479512639}, {-2.4911691774700118`, 
           2.4541315996059296`}, {-2.467838968079956, 
           2.4503863831843447`}, {-2.444546998600464, 
           2.446612201231679}, {-2.3364763340739008`, 
           2.4281623379317}, {-2.229297341425842, 
           2.409077958286527}, {-2.0330390421392837`, 
           2.37340528563872}, {-1.8401311954067112`, 
           2.336875680639547}, {-1.829642873147605, 2.334807061509263}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8064771541841416`, 
           2.330238070565741}, {-1.6505738012281246`, 
           2.299489143289007}, {-1.4643668596035238`, 
           2.2612456735871005`}, {-1.329537202027628, 
           2.233370449933564}, {-1.196412321023544, 
           2.206613999176361}, {-1.0649922165912717`, 
           2.1809763213154922`}, {-0.9352768887308112, 
           2.1564574163509573`}, {-0.8800165048145531, 
           2.1467794927133936`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8567584982472705, 
           2.142706245378355}, {-0.8066218776608529, 
           2.133925662416497}, {-0.6783827236000886, 
           2.1142494376458516`}, {-0.5505594265485172, 
           2.0974287420390216`}, {-0.4231519865061391, 
           2.0834635755960065`}, {-0.26836191761590505`, 
           2.070286971147605}, {-0.11069605175971695`, 2.060987427768457}, {
           0.05074210849906302, 2.054171279965361}, {0.08259576032314508, 
           2.0530731482258036`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.10619373467151866`, 2.052259625030274}, {
           0.216849060597073, 2.0484448622451144`}, {0.3874817057271532, 
           2.04178887092594}, {0.5624969450821427, 2.0321840023260616`}, {
           0.7406509469954623, 2.018317726974506}, {0.9206998798005332, 
           1.9988775154003002`}, {1.0474344642031608`, 
           1.9814336915792419`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.070825921996213, 1.9782140773706733`}, {
           1.1012577860206438`, 1.9740254174473324`}, {1.2809387081790824`, 
           1.9439234829594898`}, {1.4590914701873967`, 1.9096731049324485`}, {
           1.635064895957135, 1.8723756763618842`}, {1.8648116687216236`, 
           1.8210704099158144`}, {1.9963653426804302`, 
           1.7913344844821872`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.0193963101535357`, 1.7861286463566857`}, {
           2.0910075282029177`, 1.7699419008554202`}, {2.3149621321418308`, 
           1.7211877590865}, {2.5379851382791756`, 1.6770055945148508`}, {
           2.7612555214872487`, 1.6374311913274282`}, {2.946781225583616, 
           1.6085897755872967`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.9701129710728913`, 1.6049626740227092`}, {
           2.9859522566383445`, 1.6025003337111876`}, {3.141600425034927, 
           1.581050898793921}, {3.2983948131616057`, 1.5615706809295884`}, {
           3.4563354210183794`, 1.5440596801181903`}, {3.615422248605249, 
           1.5285178963597266`}, {3.7756422199086415`, 1.5146145270583973`}, {
           3.9089929619322255`, 1.5042038837282177`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.9325333262067783`, 1.5023660961568404`}, {
           3.9369822589149877`, 1.5020187696184029`}, {4.099442365624287, 
           1.4907306240397429`}, {4.2630225400365385`, 1.4807500903224178`}, {
           4.427527697637862, 1.471885185612149}, {4.592762753914376, 
           1.4639439270546588`}, {4.758727708866082, 1.4569263146499467`}, {
           4.875647821067172, 1.4526519942229916`}}]}, 
         {Arrowheads[{{0.016048651079750714`, 1.}}], 
          ArrowBox[{{4.8992440516301174`, 1.4517893723147874`}, {
           4.925422562492979, 1.450832348398013}, {5.114897846820877, 
           1.4448231410286185`}, {5.304687778590475, 1.439560598741194}, {
           5.494792357801774, 1.435044721535739}, {5.656854249492381, 
           1.431836822534929}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           0.0005099147223225828}, {-5.614045035798889, 
           0.000509896862148913}, {-5.45709150477684, 
           0.0005095813923242737}, {-5.300343688847845, 
           0.0005090160201355309}, {-5.143801588011904, 
           0.0005082007455826845}, {-4.987465202269018, 
           0.0005071355686657344}, {-4.831334531619185, 
           0.000505820489384681}, {-4.712374529592222, 
           0.0005046265161748425}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.6887625365954415`, 
           0.0005043895282243661}, {-4.675409576062407, 
           0.0005042555077395239}, {-4.519690335598682, 
           0.0005024406237302634}, {-4.355177838705192, 
           0.0005001573306367508}, {-4.190915266673364, 
           0.0004973861552711381}, {-3.975236786638663, 
           0.0004928659914194406}, {-3.759611063008718, 
           0.0004872641051227555}, {-3.7442828168550295`, 
           0.00048677617913503077`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7206708238690225`, 
           0.00048602456640097543`}, {-3.5435591478130366`, 
           0.00048038677923271526`}, {-3.3266020930811284`, 
           0.00047204029660095236`}, {-3.297960377561696, 
           0.00047084395045735397`}, {-3.2692889803835756`, 
           0.000469617214133102}, {-3.133411154277462, 
           0.0004629636962161674}, {-2.99635650847591, 
           0.00045547727483312504`}, {-2.8617377425701314`, 
           0.00044761545835505796`}, {-2.776191105033683, 
           0.00044198944757104425`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7525791120867753`, 
           0.0004404365948724825}, {-2.7248339068671323`, 
           0.00043861191972141203`}, {-2.585645001366914, 
           0.0004284666589321872}, {-2.4441710260694762`, 
           0.0004171796759873836}, {-2.2436595012159026`, 
           0.00039903793289275164`}, {-2.0328174867132467`, 
           0.00037709682085157686`}, {-1.8743718848497946`, 
           0.0003586295651219406}, {-1.8080993966273688`, 
           0.0003501628404401174}}]}, 
         {Arrowheads[{{0.01741466619689049, 1.}}], 
          ArrowBox[{{-1.7844874038220928`, 
           0.00034714626074568226`}, {-1.7053453899817113`, 
           0.00033703537371058815`}, {-1.573867230599304, 
           0.0003191269604781896}, {-1.4319187946164633`, 
           0.00029894398973325816`}, {-1.3140861622861484`, 
           0.00028227273233066976`}, {-1.1855324500353122`, 
           0.00026484320850703104`}, {-1.1167660999288185`, 
           0.0002561457395440388}, {-1.0442669515087548`, 
           0.00024835553938238453`}, {-1.0255393911934936`, 
           0.00024665463321237567`}, {-1.0071137056967354`, 
           0.00024513419778693504`}, {-0.9919168843703915, 
           0.00024393123675677835`}, {-0.9782430573772536, 
           0.0002428298979663486}, {-0.9707104627168346, 
           0.00024221899499535652`}, {-0.9663584063558541, 
           0.00024186667726030817`}, {-0.9620974581308767, 
           0.00024152257823604402`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -4.160207907142072}, \
{-5.527815661385164, -4.160159059238797}, {-5.316686659844921, \
-4.159288877275903}, {-5.1008667366339004`, -4.157274818689604}, \
{-4.881507025929927, -4.15394274571651}, {-4.7124510373758, \
-4.150264864480127}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.688844630144675, -4.149751297566844}, \
{-4.6597586619108196`, -4.149118520593227}, {-4.437557173469616, \
-4.142386508447086}, {-4.216210573727183, -4.133524272092839}, \
{-3.9959287232030785`, -4.12264747029823}, {-3.776921482416859, \
-4.109871761831003}, {-3.745364092641306, -4.107734094582059}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7218060866499294`, -4.106138297901271}, \
{-3.5594875477178505`, -4.095142996102255}, {-3.343854546791564, \
-4.078542870008401}, {-3.1301257371618374`, -4.060390813545161}, \
{-2.9184043763525085`, -4.0410062567082505`}, {-2.780650774554544, \
-4.027511466712207}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.757151272296593, -4.025209379188952}, \
{-2.7090850784669662`, -4.02050065881305}, {-2.502329372344959, \
-3.9991518557192087`}, {-2.2978908876148627`, -3.977528842238853}, \
{-2.0955232539050543`, -3.9562006131841088`}, {-1.9360605428152595`, \
-3.9399768771122177`}, {-1.8176295502159854`, -3.9286093481933078`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7941255801041012`, -3.926353333495702}, \
{-1.7777213428419893`, -3.9247787824649536`}, {-1.6203195344901449`, \
-3.9107639002809305`}, {-1.4656542728790187`, -3.8964090438535433`}, \
{-1.3110888651613712`, -3.883946469563162}, {-1.157088610074951, \
-3.8729822498132513`}, {-1.0036535076197577`, -3.8635163846038103`}, \
{-0.8523971189261402, -3.855632971990317}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8288074373230931, -3.8546082457761948`}, \
{-0.6980930552560486, -3.8490133716188164`}, {-0.5451962946535203, \
-3.8438435314682167`}, {-0.39209327598820826`, -3.840039353483041}, \
{-0.23878399926011218`, -3.8376008376632895`}, {-0.01351067103638609, \
-3.8354988154975125`}, {0.11538705935908289`, -3.83483481443924}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.13899873907103721`, -3.8347131817288096`}, {
           0.21343998125378133`, -3.8343297066789632`}, {
           0.44206795761038986`, -3.8340935112076417`}, {
           0.6723732580334396, -3.834790229083548}, {
           0.9039873256792408, -3.834993593986498}, {
           1.083471318446813, -3.8336689991728816`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.1070826684616704`, -3.8334947470220913`}, {
           1.1365416037041038`, -3.8332773395963087`}, {
           1.3700360921080283`, -3.8296414659129794`}, {
           1.6044707908910145`, -3.8240859729365106`}, {
           1.7455873936243556`, -3.8198914281744063`}, {
           1.8866137730429315`, -3.8151382960531333`}, {
           2.0275499291467423`, -3.8098265765726906`}, {
           2.05120446408939, -3.8088406810234763`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.0747959751863116`, -3.8078574122402986`}, {
           2.168395861935787, -3.8039562697330793`}, {
           2.3091515714100668`, -3.7975273755342993`}, {
           2.4498170575695815`, -3.7905398939763497`}, {
           2.590392320414331, -3.7829938250592314`}, {
           2.7308773599443152`, -3.774889168782944}, {
           2.8569561366892304`, -3.7672475354739245`}, {
           2.9829464253583793`, -3.7593965984145314`}, {
           3.0178935369320112`, -3.757199548112184}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.041459006145507, -3.7557180373684025`}, {
           3.131344125449809, -3.750067151797274}, {
           3.2796050580980776`, -3.7408171050616166`}, {
           3.427729223303184, -3.73164645820756}, {
           3.575716621065129, -3.722555211235104}, {
           3.59549381767455, -3.721344993424866}, {
           3.6152694423899274`, -3.720138709992095}, {
           3.761153873284244, -3.711487979262924}, {
           3.907005894831119, -3.703070990954086}, {
           3.9842157888693417`, -3.6987301762584073`}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{4.00779055374075, -3.6974047802443897`}, {
           4.067032913623697, -3.694074117644862}, {
           4.227081896735976, -3.6855522593466783`}, {
           4.387152844167959, -3.6775054160595353`}, {
           4.5472457559196435`, -3.669933587783434}, {
           4.70736063199103, -3.662836774518373}, {
           4.867497472382119, -3.6562149762643528`}, {
           4.951213232400989, -3.6530020237714416`}}]}, 
         {Arrowheads[{{0.014450046412662306`, 1.}}], 
          ArrowBox[{{4.974807854697524, -3.6520964786206855`}, {
           5.02765627709291, -3.650068193021374}, {
           5.187837046123404, -3.644396424789436}, {
           5.348060945567226, -3.6392165770714446`}, {
           5.508349141518001, -3.6345455553703068`}, {
           5.656854249492381, -3.6306398700041296`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           4.161002370340662}, {-5.529270190333502, 
           4.160956138816243}, {-5.318206205754528, 
           4.160091730773391}, {-5.1024040014541505`, 
           4.158085893511722}, {-4.883023954241249, 
           4.154763910310908}, {-4.7124509331938045`, 4.151062598939335}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.688844497189158, 
           4.150550356326232}, {-4.661226440924707, 
           4.14995106445062}, {-4.438963786662454, 
           4.14323092347957}, {-4.2175547579331845`, 
           4.134380427531238}, {-3.9972093935269215`, 
           4.123514918762445}, {-3.7781377322336906`, 
           4.11074973933001}, {-3.7453639659547697`, 4.10853172077536}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-3.7218058608958877`, 
           4.106937387256036}, {-3.5606385764112565`, 
           4.096030126114699}, {-3.3449397175631925`, 
           4.079437400218122}, {-3.1311446781982397`, 
           4.061291030128364}, {-2.9193569808251407`, 
           4.041910484333509}, {-2.7806491247589467`, 4.028327877475719}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.757149529393738, 
           4.026026740581133}, {-2.7099716271282555`, 
           4.021406966928648}, {-2.5031504354514493`, 
           4.000058293523268}, {-2.2986471532927184`, 
           3.9784338498770473`}, {-2.0962155281500605`, 
           3.9571030217496643`}, {-1.9367053330075616`, 
           3.9408769989181356`}, {-1.817625544920393, 3.9294486961001485`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7941215466450027`, 
           3.927192974839308}, {-1.7783192868515059`, 
           3.9256764033620697`}, {-1.6208713189952553`, 
           3.9116589161792614`}, {-1.4661601127429864`, 
           3.8973002867576962`}, {-1.3115496667006479`, 
           3.884834330649464}, {-1.157505157584837, 
           3.873866845110078}, {-1.0040265853955528`, 
           3.8643978301395383`}, {-0.8523914146357849, 
           3.856493873351911}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8288015909597171, 
           3.855472127833778}, {-0.6983814707700763, 
           3.849889042348186}, {-0.5454433662808991, 
           3.8447169304137483`}, {-0.39229963666526635`, 
           3.8409109499345324`}, {-0.23895028192317735`, 
           3.8384711009105383`}, {-0.013450392610105166`, 
           3.8363665031984344`}, {0.11539302715941399`, 3.835703064705152}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.1390047071382684, 3.835581483817148}, {
           0.21372868773401704`, 3.835196716281583}, {0.4425869591091892, 
           3.8349617401599843`}, {0.6731244215154111, 3.835661574833638}, {
           0.9049710572246861, 3.8358666916092594`}, {1.0834772951730018`, 
           3.8345484178681883`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.10708864431416, 3.8343740473704298`}, {
           1.1377568485090161`, 3.834147561793564}, {1.3714817953684015`, 
           3.830504185386551}, {1.606145897802843, 3.8249365623882206`}, {
           1.7473545038089722`, 3.8207347665316536`}, {1.8884725198194738`, 
           3.8159747215408735`}, {2.0294999458343477`, 3.810656427415881}, {
           2.0512112265965157`, 3.8097511475457257`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.074802720642943, 3.8087674697562357`}, {
           2.170436781853594, 3.8047798841566762`}, {2.311283027877212, 
           3.7983450917632586`}, {2.452038683905203, 3.7913520502356284`}, {
           2.5927037499375665`, 3.783800759573785}, {2.7332782259743014`, 
           3.77569121977773}, {2.8594377454196036`, 3.7680454710053475`}, {
           2.98550897279605, 3.7601907160680064`}, {3.0179027161766574`, 
           3.758154719125131}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.0414682094649432`, 3.7566735913737452`}, {
           3.133886962431293, 3.7508649296117196`}, {3.282128251237743, 
           3.7416199613297794`}, {3.430232839215401, 3.7324558112221857`}, {
           3.578200726364267, 3.7233724792889387`}, {3.5979755770055557`, 
           3.722163398769891}, {3.617748864111301, 3.7209582542607995`}, {
           3.763711982018968, 3.712310467806193}, {3.9096429299118807`, 
           3.703896751479012}, {3.9842263188474543`, 
           3.6997077796124196`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{4.007801157697394, 3.6983837001074353`}, {
           4.069857208218475, 3.694898325501983}, {4.230093520488616, 
           3.686376233895503}, {4.390351866722304, 3.6783304766595726`}, {
           4.550632246919538, 3.670761053794192}, {4.710934661080319, 
           3.6636679652993607`}, {4.871259109204647, 3.657051211175079}, {
           4.951224190527707, 3.653988972711401}}]}, 
         {Arrowheads[{{0.014449806819168017`, 1.}}], 
          ArrowBox[{{4.974818889242955, 3.6530854209016703`}, {
           5.0316055912925215`, 3.650910791421347}, {5.191974107343943, 
           3.645246706038164}, {5.35238577158149, 3.640075546125334}, {
           5.512861698227745, 3.635413902782658}, {5.656854249492381, 
           3.631638933940879}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.5528757474394965`, 0.005106538878232603}, {
           1.5640468229079372`, 0.0038422771759907856`}, {1.580621121496495, 
           0.0029111469488959166`}, {1.6051518708295276`, 
           0.00222765788593847}, {1.6212413566771064`, 
           0.001959695430393163}, {1.640449364040145, 
           0.0017306183768011271`}, {1.7075931363896313`, 
           0.0012831476724842875`}, {1.807187240597266, 
           0.0009882003256990069}, {1.815100669876582, 
           0.0009724985898194364}, {1.8231897984254282`, 
           0.0009572371227985556}, {1.8625168719551581`, 
           0.0009004504919594494}, {1.9055431883485785`, 
           0.0008502188520797856}, {1.9988533077692079`, 
           0.0007608090333896519}, {2.1066582529566587`, 
           0.0006910320940681456}, {2.228659722421737, 
           0.0006364674741222112}, {2.4635745812447953`, 
           0.0005665504507415668}, {2.4972427864992244`, 
           0.000559670288912732}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.520854779004179, 0.0005548451333005554}, {
           2.593526967006472, 0.0005399944333558201}, {2.7318093236682475`, 
           0.0005190400788397904}, {2.9752596923100856`, 
           0.0004923922010507634}, {3.1028275567968624`, 
           0.00048160679083015124`}, {3.2342905413942113`, 
           0.0004725137330588067}, {3.3689793781169657`, 
           0.0004647049232802992}, {3.4653344932398076`, 
           0.00045983774556562166`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.4889464862076536`, 0.00045864503497806535`}, {
           3.5062247989799586`, 0.000457772257038198}, {3.6460268039831902`, 
           0.0004517157343325032}, {3.788385393126661, 
           0.00044653535516321483`}, {3.9338913487936202`, 
           0.00044247778214339225`}, {4.07919690414565, 
           0.00043814526046569873`}, {4.226586417731318, 
           0.000434491552233964}, {4.375823576597324, 
           0.0004314179924029644}, {4.433426205673158, 
           0.00043047714704216227`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.457038198667978, 0.00043009148349824276`}, {
           4.599033283903243, 0.0004277722244758044}, {4.82491219103328, 
           0.0004249638944539197}, {5.052671721600156, 
           0.0004227104413039453}, {5.281523299216587, 
           0.00042072930399251606`}, {5.401517918527193, 
           0.0004198201179270643}}]}, 
         {Arrowheads[{{0.00490692035172399, 1.}}], 
          ArrowBox[{{5.425129911524484, 0.0004196412124466851}, {
           5.511140998837307, 0.00041898951587471836`}, {5.656854249492381, 
           0.00041811289320531765`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -1.337968254850927}, \
{-5.536661966040593, -1.3378112712515295`}, {-5.336192282091987, \
-1.336922938090504}, {-5.124767122022398, -1.3351050191241636`}, \
{-4.913741418494116, -1.3322643622217796`}, {-4.7124405883608445`, \
-1.3284017931686394`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-4.688835074976716, -1.3278539193541181`}, \
{-4.493261106096414, -1.322809543603114}, {-4.465350971222034, \
-1.3219971121932141`}, {-4.43745243063786, -1.3211567393470625`}, \
{-4.265953107294687, -1.314658997413662}, {-4.09490388091568, \
-1.3069035639345585`}, {-3.9058544352669204`, -1.2973180492072838`}, \
{-3.7452895438778473`, -1.2874485613312203`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7217220306142202`, -1.285999930286089}, \
{-3.717236051012016, -1.2857241893011626`}, {-3.5290487281509666`, \
-1.272121984216195}, {-3.3412924666837727`, -1.2565114339523813`}, \
{-3.1536114238000374`, -1.2383685487563476`}, {-2.965649756689366, \
-1.2171693388747207`}, {-2.7819746410978077`, -1.1935022974053888`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7585967822066606`, -1.190188646312942}, \
{-2.5888845497872124`, -1.1656019450546864`}, {-2.4652988878527586`, \
-1.1456491289160402`}, {-2.3407294518621398`, -1.1234241628726567`}, \
{-2.215176241815355, -1.0989270469245362`}, {-2.088639257712405, \
-1.0721577810716785`}, {-1.8899720304641883`, -1.0245025471463542`}, \
{-1.8324480809778227`, -1.008486294892768}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8097013184897435`, -1.0021529695697589`}, \
{-1.6850755555112513`, -0.9674537238645892}, {-1.5231358606663252`, \
-0.9165857094462798}, {-1.3531195367927586`, -0.8577239555330751}, \
{-1.1250461369718572`, -0.771905415321205}, {-0.9492806696432257, \
-0.7051193598463978}, {-0.9175556002077166, -0.6936224945700644}}]}, 
         {Arrowheads[{{0.004801605898669028, 1.}}], 
          ArrowBox[{{-0.8953185077854755, -0.6856854673067024}, \
{-0.8488794521810501, -0.6699120084525728}, {-0.7932651945026091, \
-0.6528565675054385}, {-0.7660814057556473, -0.6451957950092684}, \
{-0.745956777575587, -0.639640862922115}, {-0.7341304671479313, \
-0.6363355269582184}, {-0.7259379958350395, -0.6340261675699765}, \
{-0.7195812366663366, -0.632224779471824}, {-0.7144664724064312, \
-0.630769296115475}, {-0.7058582733158641, -0.6283082349604278}, \
{-0.6999521474833869, -0.6266098912560265}, {-0.695564408069681, \
-0.6253431701690406}, {-0.6903593620579962, -0.623835272678256}, \
{-0.6839590902926407, -0.6219725266040489}, {-0.678249060058338, \
-0.6203029697298934}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           1.3388854641625225`}, {-5.536588985737063, 
           1.3387280990506931`}, {-5.336121692016142, 
           1.3378390680860057`}, {-5.124704923385183, 
           1.3360200508867979`}, {-4.913687297481391, 
           1.3331778502933274`}, {-4.712440654014933, 1.329314194698738}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-4.688835140708294, 
           1.3287663320415661`}, {-4.493222457022795, 
           1.3237182681141177`}, {-4.465313304572845, 
           1.3229054370464626`}, {-4.437415744980164, 
           1.3220646518426573`}, {-4.265917602422963, 
           1.31556355221222}, {-4.094869657578914, 
           1.3078041158309555`}, {-3.905830746975133, 
           1.2982145689502487`}, {-3.745290446242154, 1.2883425599484193`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7217229692373612`, 
           1.2868933391354553`}, {-3.7172244394316345`, 
           1.2866167137240516`}, {-3.5290507349484175`, 
           1.273010550152364}, {-3.3413096335254826`, 
           1.257396078235186}, {-3.1536457420602573`, 
           1.2392492922989944`}, {-2.9657036674501684`, 
           1.2180461866702654`}, {-2.7819785762771643`, 
           1.1943661365942686`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7586009981671262`, 
           1.1910504674248434`}, {-2.588984968795402, 
           1.1664710163351961`}, {-2.4653759829408126`, 
           1.1465087437624046`}, {-2.340785283179095, 
           1.1242730503990817`}, {-2.21521286951025, 
           1.099763936245227}, {-2.0886587419342773`, 
           1.0729814013008403`}, {-1.8898334999584088`, 
           1.0252655831268187`}, {-1.832465886038801, 1.009282698473896}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8097201648209906`, 
           1.0029456345151049`}, {-1.6847776279147189`, 
           0.9681360613225558}, {-1.5227881736297353`, 
           0.9172195802105144}, {-1.3527281720816688`, 
           0.8583093839551}, {-1.1247208224740652`, 
           0.7724637144544764}, {-0.9489924122720088, 
           0.7056399764606698}, {-0.917628342384755, 0.6942633807266755}}]}, 
         {Arrowheads[{{0.004819022767131045, 1.}}], 
          ArrowBox[{{-0.895396175189926, 
           0.6863124379773847}, {-0.8486135593422783, 
           0.6704051579252911}, {-0.7929256733539225, 
           0.6533157886912929}, {-0.7661869135669157, 
           0.6457773048890236}, {-0.7462193339790338, 
           0.6402620026842698}, {-0.7343346831470924, 
           0.6369385822243968}, {-0.7258412261812086, 
           0.6345429436233204}, {-0.7192941575210638, 
           0.6326861264830537}, {-0.714047273382854, 
           0.6311916638220243}, {-0.7054055866273625, 
           0.6287185677551077}, {-0.6994655104412575, 
           0.6270087151455638}, {-0.6950471732175456, 
           0.6257318234689455}, {-0.6897745555211059, 
           0.6242026953690296}, {-0.6833032613406346, 
           0.6223171233011239}, {-0.6775570873108753, 0.6206349987790521}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, -2.1709206751896004`}, \
{-5.459128173784755, -2.1705900757169845`}, {-5.224155797246894, \
-2.1688960054360407`}, {-4.989693816381473, -2.1656293351964555`}, \
{-4.755890829735595, -2.1604706681785975`}, {-4.712482063238238, \
-2.1591045551822057`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688881754428707, -2.1583618321982314`}, \
{-4.522909654376422, -2.153138540655643}, {-4.290937989781208, \
-2.1434178718131838`}, {-4.060163535427208, -2.13109358083681}, \
{-3.830831225680758, -2.1159485692493205`}, {-3.7457868703726356`, \
-2.109157744346461}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          
          ArrowBox[{{-3.7222497953358045`, -2.107278299735217}, \
{-3.6031402069969296`, -2.097767352703748}, {-3.377209496986084, \
-2.0763372715810333`}, {-3.1531581132585815`, -2.0514456662621168`}, \
{-3.0262935839730183`, -2.035645859047458}, {-2.9001123664805637`, \
-2.0186516917122828`}, {-2.7838831001179174`, -2.0017529276623027`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7605403083345896`, -1.9981998978363313`}, \
{-2.6498698213873233`, -1.9808591702830192`}, {-2.5258253376749322`, \
-1.9599027693428202`}, {-2.4025123602266616`, -1.9374739095078264`}, \
{-2.2799701377119237`, -1.9135743065556128`}, {-2.158237918800132, \
-1.8882056762637542`}, {-2.0373419542889883`, -1.8613954718198915`}, \
{-1.9173188932735632`, -1.833150556483613}, {-1.8350021654543336`, \
-1.812013141278747}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8121321252909381`, -1.8061405374047539`}, \
{-1.6801108661917472`, -1.772239916675793}, {-1.4473197124609856`, \
-1.704472190903664}, {-1.2191170950224963`, -1.6303822392717982`}, \
{-1.0804258255593506`, -1.582216148190906}, {-0.9440448691340064, \
-1.5319133791764983`}, {-0.9126429611847815, -1.519923212420417}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8905842845045083, -1.5115005645914183`}, \
{-0.8093327934920411, -1.4804763692465057`}, {-0.6759332473809978, \
-1.4284620278553342`}, {-0.5432282248608912, -1.3768272021276948`}, \
{-0.4105997199917358, -1.3265287391882983`}, {-0.29337119498617514`, \
-1.2842475170502323`}, {-0.1738749392831721, -1.244613656215065}, \
{-0.050854673412367137`, -1.2078198987624662`}, {-0.019133338320953656`, \
-1.1990520857577325`}, {-0.0015066239097834, -1.1943254399761662`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.021335257295126066`, -1.1883470711768764`}, {
           0.20067206248176775`, -1.1433388823206982`}, {
           0.3982000011215499, -1.087480044650594}, {
           0.5211485369328108, -1.0379242495791405`}, {
           0.6376213722631303, -0.9724949207305076}, {
           0.7421046589695489, -0.8889142267865713}, {
           0.7611048461523897, -0.8706454367028166}, {
           0.779156599827807, -0.8517374629970862}, {
           0.8030351592310093, -0.8199319512853668}, {
           0.824367638474274, -0.7862875622455455}, {
           0.8346082607455242, -0.7665387707665048}}]}, 
         {Arrowheads[{{0.008464175641731679, 1.}}], 
          ArrowBox[{{0.8454776914925896, -0.7455773374049498}, {
           0.8613278675350493, -0.7150106576390718}, {
           0.8847700432429749, -0.6368422097006022}, {
           0.8906766733180613, -0.5516284962428912}, {
           0.8874491765260504, -0.5167357198840971}, {
           0.8819280836562643, -0.48445267195529373`}, {
           0.8761767511999374, -0.4600831185128589}, {
           0.869766343754036, -0.43825869395886524`}, {
           0.8641500516017503, -0.42191000608884127`}, {
           0.8594149779670315, -0.40949962253508737`}, {
           0.8522662506460289, -0.3923259562376581}, {
           0.8477609090610425, -0.38241685584565555`}, {
           0.8447759033545766, -0.3761539164889849}, {
           0.8418530823275069, -0.37020771548531317`}, {
           0.840040449894641, -0.36661933718414735`}, {
           0.8377326954370184, -0.3621447560621785}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           2.176969463928433}, {-5.53771457136697, 
           2.176914023737852}, {-5.344568854728093, 
           2.1760283662334374`}, {-5.151706309354532, 
           2.174173185940033}, {-4.959213191389103, 
           2.171099270752088}, {-4.7671781916421105`, 
           2.1666272310127312`}, {-4.712488761940574, 2.1649193854152755`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688888273649834, 
           2.1641823876033564`}, {-4.575692435591353, 
           2.1606474995137654`}, {-4.384847048714633, 
           2.1530505090469965`}, {-4.194733156489746, 
           2.143726692404228}, {-4.005441884394493, 
           2.132566482377266}, {-3.817064357906671, 
           2.1194603117579134`}, {-3.7458601872129793`, 2.113698659077164}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-3.722325117817131, 
           2.111794263669491}, {-3.62969170250408, 
           2.1042986133379755`}, {-3.5019822348624614`, 
           2.0926966938460456`}, {-3.374920567840675, 
           2.0800974115421305`}, {-3.2485145546471923`, 
           2.0664542391330176`}, {-3.122772048490488, 
           2.051720649325496}, {-2.9976923407320064`, 
           2.035851086962893}, {-2.8732815722108156`, 
           2.0187992191793045`}, {-2.784026578935661, 2.005610574666364}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.760668213417775, 
           2.0021590570771015`}, {-2.7495578703518238`, 
           2.0005173521176722`}, {-2.626539362579938, 
           1.980957791920938}, {-2.504226053665042, 
           1.9600352444436486`}, {-2.3826324465010384`, 
           1.9376944957710664`}, {-2.141763835869459, 
           1.888748100796089}, {-1.9041993821775622`, 
           1.8341717881223474`}, {-1.8350390732179114`, 
           1.8163410121966461`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8121747529724697`, 
           1.8104461777587637`}, {-1.6703112277079768`, 
           1.7738712004477601`}, {-1.5318292113316552`, 
           1.7344443120571684`}, {-1.3950776369363123`, 
           1.692481690526316}, {-1.2598203373907784`, 
           1.6485922943026774`}, {-1.1261226110144034`, 
           1.603050190443685}, {-0.9947423001064528, 
           1.555460683221665}, {-0.9127604188599169, 
           1.5241102311440424`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8907059918239822, 
           1.5156764620309593`}, {-0.8656550899073978, 
           1.5060968196990716`}, {-0.7381230244944323, 
           1.4557872134801482`}, {-0.6112711161537117, 
           1.4055848306658123`}, {-0.4300054397289081, 
           1.3358831281014085`}, {-0.24680042679266603`, 
           1.270847958846958}, {-0.05654223170234459, 
           1.2124398389928361`}, {-0.024977242939628094`, 
           1.2036985488380822`}, {-0.0020312884723438507`, 
           1.1975607886480137`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.020804031682686894`, 1.1915551069919759`}, {
           0.15212061385612297`, 1.1573882716543884`}, {0.2651944034744492, 
           1.1268886689036894`}, {0.38050044577275177`, 
           1.0915524465003754`}, {0.4953776594470465, 1.0470707825981675`}, {
           0.5813297725584337, 1.0044592443896414`}, {0.6624857582257693, 
           0.9532081203468123}, {0.7361744792306802, 0.8921175677584995}, {
           0.7553397638414338, 0.8739702828323447}, {0.7736497868867926, 
           0.855142320059366}, {0.7978535619730209, 0.8235429160631577}, {
           0.8195216536067988, 0.7901176094161259}, {0.8326458990022271, 
           0.7654339104022072}}]}, 
         {Arrowheads[{{0.008366803021994109, 1.}}], 
          ArrowBox[{{0.8437308540147402, 0.7445856494266073}, {
           0.8572591387898427, 0.719142044899102}, {0.8816342025432817, 
           0.6411710789876403}, {0.8886978427472954, 0.5565727717319504}, {
           0.8859146225348901, 0.521247460131489}, {0.8805574373829583, 
           0.48790179036473585`}, {0.8747783444579968, 0.4624646621076541}, {
           0.8676970553533434, 0.4379099622782869}, {0.8616383081398736, 
           0.42029886906477365`}, {0.8566845290111496, 0.4073977090294713}, {
           0.8500356080131297, 0.3914947141544282}, {0.8458718014943765, 
           0.3823133147057709}, {0.8430932373942774, 0.3764481097236884}, {
           0.8403659352361393, 0.3708558945904046}, {0.8374922644165059, 
           0.3651489707902756}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -5.095918607427803}, \
{-5.594313962370117, -5.095730374971032}, {-5.452421514472959, \
-5.0951337983397185`}, {-5.310205053647296, -5.0943667348112704`}, \
{-5.167664579893132, -5.093429184385687}, {-5.024988178188807, \
-5.092098923030768}, {-4.882363933512666, -5.0901537267143135`}, \
{-4.73979184586471, -5.0875935954363225`}, {-4.712430457461105, \
-5.086984037038356}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.6888243217352885`, -5.086458138349921}, \
{-4.597271915244942, -5.084418529196794}, {-4.454804141653359, \
-5.080628527995731}, {-4.312388525089958, -5.07622359183313}, \
{-4.170025065554745, -5.0712037207089935`}, {-4.027713763047715, \
-5.06556891462332}, {-3.8857153837126344`, -5.0593249797067275`}, \
{-3.7449878720714733`, -5.052511476874518}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-3.7214086862319036`, -5.05126733498887}, \
{-3.6034396929896078`, -5.045027141772638}, {-3.463162381601661, \
-5.036973238755141}, {-3.323458759529426, -5.028316013037342}, \
{-3.1843288267729024`, -5.019055464619242}, {-3.0457725833320897`, \
-5.009191593500839}, {-2.907790029206989, -4.998724399682135}, \
{-2.779042009128607, -4.988642234845816}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7555020832692887`, -4.9867988401854255`}, \
{-2.702959459808567, -4.9826842651392145`}, {-2.4998246515580687`, \
-4.966735109949158}, {-2.2983856044554947`, -4.950876934111965}, \
{-2.0986423185008456`, -4.935109737627635}, {-1.9004371918863607`, \
-4.9199700941572075`}, {-1.8138483504819833`, -4.91382185863462}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7902956556661476`, -4.912149500943134}, \
{-1.7036126228042823`, -4.905994577361722}, {-1.50816861125461, \
-4.893183187241178}, {-1.3141051572373437`, -4.881535923795575}, \
{-1.1210713284218028`, -4.871326202184142}, {-0.9287161924773055, \
-4.862827437566111}, {-0.8473113248611386, -4.859944659838044}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8237141234911534, -4.859109015870477}, \
{-0.7370397494038523, -4.856039629941479}, {-0.5460419992014429, \
-4.850962779310249}, {-0.408044736978442, -4.848189797424937}, \
{-0.2699639113235003, -4.845979802748474}, {-0.13179952223661845`, \
-4.844332795280858}, {0.006448430282205209, -4.843248775022089}, {
           0.12058338616794262`, -4.842818879609182}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.14419521167690785`, -4.842729944406134}, {
           0.14477994623296986`, -4.842727741972169}, {
           0.283195025615675, -4.842769696131097}, {
           0.42169366843032086`, -4.843374637498873}, {
           0.5602758746769083, -4.844542566075496}, {
           0.7547628952286346, -4.8463450265209325`}, {
           0.9493601367877367, -4.847686532574483}, {
           1.0886542779546062`, -4.848316481143725}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{1.1122660294952, -4.848423263733256}, {
           1.144067599354214, -4.848567084236147}, {
           1.3388852829280673`, -4.848986681505926}, {
           1.5338131875092962`, -4.84894532438382}, {
           1.7288513130979004`, -4.8484430128698275`}, {
           1.9239996596938802`, -4.847479746963949}, {
           2.0567384127711836`, -4.846511547571969}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{2.080349777682644, -4.846339325755648}, {
           2.1192582272972356`, -4.846055526666185}, {
           2.3143855378767184`, -4.844137925509233}, {
           2.509140113401081, -4.841694517025787}, {
           2.7035219538703217`, -4.838725301215851}, {
           2.897531059284442, -4.835230278079421}, {
           3.024722140429165, -4.832589174175591}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.048329044574315, -4.832098980318176}, {
           3.0911674296434413`, -4.8312094476165}, {
           3.28443106494732, -4.826662809827085}, {
           3.4773219651960776`, -4.821590364711179}, {
           3.6698401303897143`, -4.8159921122687805`}, {
           3.8278341310944715`, -4.811106922941066}, {
           3.985602629298346, -4.806101666408921}, {
           3.9924396877360797`, -4.805885312859677}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{4.01603986757365, -4.805138502997342}, {
           4.110990254222568, -4.802133869741581}, {
           4.236255022918136, -4.798280439428565}, {
           4.36139693538505, -4.794541375469869}, {
           4.4864159916233115`, -4.790916677865497}, {
           4.503205723908306, -4.790437334482824}, {
           4.519993551039305, -4.789960528186641}, {
           4.694349806988296, -4.785309234381192}, {
           4.868514764938093, -4.780946445578545}, {
           4.96014703503642, -4.778717252265233}}]}, 
         {Arrowheads[{{0.014256387238985325`, 1.}}], 
          ArrowBox[{{4.983752043965705, -4.778142999024433}, {
           5.016142834296257, -4.777355008798497}, {
           5.163638917334435, -4.773980097393212}, {
           5.311003014052623, -4.770821711362687}, {
           5.458235124450824, -4.767879850706924}, {
           5.605258447628027, -4.765269473508371}, {
           5.656854249492381, -4.764442037750297}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           5.096521395341231}, {-5.593877418492312, 
           5.096331475417876}, {-5.451944368418021, 
           5.095733688963498}, {-5.309689082073207, 
           5.094965173346711}, {-5.1671115594578705`, 
           5.0940259285675165`}, {-5.02439916931863, 
           5.09269370122707}, {-4.8817392804020985`, 
           5.090746237926525}, {-4.739131892708279, 
           5.0881835386658825`}, {-4.712430412716418, 5.087588290226403}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.688824284700379, 
           5.087062045581239}, {-4.596577006237172, 
           5.0850056034451425`}, {-4.454074620988776, 
           5.081212432264305}, {-4.311624736963093, 
           5.07680402512337}, {-4.169227354160122, 
           5.071780382022338}, {-4.026882472579862, 
           5.066141502961207}, {-3.8848508497169916`, 
           5.059893235159256}, {-3.7449877345696976`, 5.0531186585276515`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.721408372304079, 
           5.051878019052162}, {-3.6025096526274516`, 
           5.045586074990723}, {-3.462200078400783, 
           5.037527182624141}, {-3.3224645203861813`, 
           5.028864748736014}, {-3.183302978583646, 
           5.0195987733263445`}, {-3.044715452993179, 
           5.009729256395131}, {-2.9067019436147787`, 
           4.9992561979423735`}, {-2.7790414663963974`, 4.989256592815597}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7555015779281815`, 
           4.98741272073757}, {-2.701864397533143, 
           4.983211337226003}, {-2.4987228073655947`, 
           4.967259760856287}, {-2.297277173112133, 
           4.951401468833223}, {-2.09752749477276, 
           4.935636461156812}, {-1.8993155782219528`, 
           4.920501054600868}, {-1.8138478796723434`, 4.914435283133049}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-1.7902951292392808`, 
           4.912763708912729}, {-1.702483229334189, 
           4.906531565939205}, {-1.5070304481094703`, 
           4.893727995171823}, {-1.3129572345477958`, 
           4.882090342298723}, {-1.1199125091603404`, 
           4.871891082303496}, {-0.9275451924582789, 
           4.863402690169734}, {-0.847310380034465, 4.860565851265109}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8237131318527813, 
           4.859731530230865}, {-0.7358552844416106, 
           4.856625165897436}, {-0.5448427851103377, 
           4.851558509486604}, {-0.40681931567133145`, 
           4.848792317172442}, {-0.26871217095268857`, 
           4.846588666380751}, {-0.13052135095440992`, 4.844947557111531}, {
           0.0077531443235044906`, 4.843868989364782}, {0.12058447272870844`, 
           4.843448169082593}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.1441963015044109, 4.843360105451784}, {
           0.14611131488105455`, 4.843352963140505}, {0.2845531607182399, 
           4.843399478438697}, {0.4230786818350609, 4.844008535259362}, {
           0.5616878782315184, 4.845180133602497}, {0.7562851386699976, 
           4.8469873645167505`}, {0.950991652178395, 4.848331987308379}, {
           1.088655264514029, 4.848955249622311}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1122670155209027`, 4.849062150162831}, {
           1.1458074187567102`, 4.849214001977383}, {1.3407324384049437`, 
           4.849633408523761}, {1.5357667111230953`, 4.849590206947515}, {
           1.7309102369111646`, 4.849084397248644}, {1.9261630157691523`, 
           4.848115979427147}, {2.056739375580129, 4.847159508219644}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.0803507351463, 4.846986555124399}, {2.121525047697058, 
           4.8466849534830265`}, {2.3167550335789575`, 4.844760027266189}, {
           2.5116116742989267`, 4.842309908626547}, {2.7060949698569656`, 
           4.839334597564097}, {2.900204920253074, 4.835834094078842}, {
           3.0247232602378866`, 4.833246699863125}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0483301573393318`, 4.8327561669101575`}, {
           3.0939415254872524`, 4.83180839817078}, {3.287304785559501, 
           4.827257509839912}, {3.480294700469818, 4.822181429086237}, {
           3.6729112702182047`, 4.816580155909757}, {3.8310093041344384`, 
           4.811692199119561}, {3.988881613010765, 4.806684540420146}, {
           3.9924415909452575`, 4.806571927817606}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.016041779208083, 4.805825384251993}, {
           4.114251176399461, 4.802718731341458}, {4.239498082222317, 
           4.7988683307775934`}, {4.364622330479335, 4.7951333387285535`}, {
           4.489623921170515, 4.791513755194337}, {4.506411439019984, 
           4.791035165578598}, {4.523197053832422, 4.790559113871192}, {
           4.697654482087485, 4.785912618669589}, {4.871920400834489, 
           4.7815550742289625`}, {4.9601491658374846`, 
           4.779412858531364}}]}, 
         {Arrowheads[{{0.01425634097131411, 1.}}], 
          ArrowBox[{{4.9837542019208225`, 4.778839722561044}, {
           5.020060448822769, 4.77795819812815}, {5.168067449034741, 
           4.774579423250502}, {5.315941401470404, 4.771418749596017}, {
           5.463682306129759, 4.768476177164696}, {5.611212555286534, 
           4.765867490231065}, {5.656854249492381, 4.765139835405076}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, -3.3292514758385434`}, \
{-5.584969482358292, -3.329358989164769}, {-5.372174936669185, \
-3.328825449974255}, {-5.159552567280787, -3.3270567082949265`}, \
{-4.947244390687819, -3.3238785940693276`}, {-4.735392423385001, \
-3.3191169372400022`}, {-4.71247145415646, -3.3183899125491956`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688871329976332, -3.317641345906399}, \
{-4.524030561604496, -3.31241280136001}, {-4.313279197788514, \
-3.303555063093998}, {-4.103410092746836, -3.292591272051892}, \
{-3.8946950072892412`, -3.279568977843617}, {-3.7457506594847736`, \
-3.268672507094168}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.722201600769138, -3.2669497050324954`}, \
{-3.6875377010078076`, -3.2644137634182018`}, {-3.4822363344687766`, \
-3.2471487850533927`}, {-3.2789042699431734`, -3.227967952352191}, \
{-3.0776548697020227`, -3.2070651749175996`}, {-2.8787381811300445`, \
-3.184275559013306}, {-2.7825740378705417`, -3.17225558167125}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7591443633840864`, -3.1693270040651567`}, \
{-2.682294903521003, -3.1597212535744488`}, {-2.488274377009497, \
-3.134026732211208}, {-2.2966259417301282`, -3.1078164685337635`}, \
{-2.1547918621636, -3.088241112908714}, {-2.014379086435917, \
-3.068998597378104}, {-1.8752815248978987`, -3.050344841753408}, \
{-1.8232265032360937`, -3.042526933542409}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.799876380719168, -3.0390200842755144`}, \
{-1.738524710824967, -3.0298059545237193`}, {-1.602605707520383, \
-3.0110074663515722`}, {-1.4677897391071002`, -2.9933095777082848`}, \
{-1.3340768055851189`, -2.976712288593856}, {-1.2014669069544395`, \
-2.9612155990082862`}, {-1.0695800193830454`, -2.9471144966132465`}, \
{-0.938036119038922, -2.934703969070408}, {-0.8620527888043927, \
-2.928495645621731}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8385192194122576, -2.9265728026739777`}, \
{-0.80683520592207, -2.923984016379771}, {-0.6759772800324882, \
-2.9149546385413343`}, {-0.544908624573928, -2.907534979681037}, \
{-0.4130755227501409, -2.9016441839248164`}, {-0.2804779745611265, \
-2.8972822512726726`}, {-0.14711598000688375`, -2.894449181724606}, \
{-0.012619762630565495`, -2.892528276550191}, {
           0.1050784419838968, -2.8911215779490025`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.1286888795591909, -2.8908514926489475`}, {
           0.26088466995884246`, -2.8895728631310407`}, {
           0.39989288517193367`, -2.8885383548863057`}, {
           0.5402620274533486, -2.8870745833553286`}, {
           0.6818490245924873, -2.8844568196086415`}, {
           0.8246538765893499, -2.880685063646244}, {
           0.9686765834439355, -2.875759315468137}, {
           1.0728867427943514`, -2.871058186576415}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.0964747461047248`, -2.869994084529631}, {
           1.1689553816892182`, -2.866724337969789}, {
           1.3695163891078463`, -2.8548485295269197`}, {
           1.5703596056998208`, -2.840131890139529}, {
           1.7714850314651422`, -2.8225744198076166`}, {
           1.972431088855965, -2.8031652635385815`}, {
           2.037956222709012, -2.7965338517756013`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.061448216535838, -2.794156365839465}, {
           2.1727362003244455`, -2.7828935663398218`}, {
           2.372400365870583, -2.761759328211338}, {
           2.5714235854943777`, -2.7397625491531303`}, {
           2.714208785379881, -2.723906750518427}, {
           2.856996139587242, -2.7085721186738096`}, {
           2.99978564811646, -2.693758653619279}, {
           3.0005632059850056`, -2.6936808263235306`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{3.0240578031244443`, -2.691329205905257}, {
           3.142577310967536, -2.679466355354835}, {
           3.285371128140469, -2.6656952238804776`}, {
           3.4281670996352602`, -2.6524452591962064`}, {
           3.5709652254519084`, -2.639716461302022}, {
           3.713765505590415, -2.6275088301979235`}, {
           3.872390769595047, -2.6146871234369167`}, {
           3.964803359941805, -2.607728163841558}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{3.9883486896481135`, -2.6059551262341194`}, {
           4.03132748006166, -2.602718687726953}, {
           4.197229576377041, -2.5911238416178546`}, {
           4.363500000759215, -2.58040424540353}, {
           4.530138753208181, -2.570559899083979}, {
           4.6971458337239405`, -2.561590802659202}, {
           4.7195378505868, -2.5604481779140973`}, {
           4.741934655199243, -2.5593218659102495`}, {
           4.923814136539027, -2.5513356648469534`}, {
           4.931187435134219, -2.551050134404395}}]}, 
         {Arrowheads[{{0.014875259160795476`, 1.}}], 
          ArrowBox[{{4.954781743512635, -2.5501364465581533`}, {
           5.105989066988617, -2.5442809541441784`}, {
           5.237492088079505, -2.5394112031016616`}, {
           5.369143915609334, -2.5349810769797876`}, {
           5.500513457501977, -2.5309721832066456`}, {
           5.631169621681305, -2.5273661292103244`}, {
           5.656854249492381, -2.5267400127764907`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           3.3301806617884475`}, {-5.584159632534824, 
           3.330288235064471}, {-5.371462974246593, 
           3.3297506271537247`}, {-5.158937849184568, 
           3.3279784095257723`}, {-4.946726312330985, 
           3.3247977666608453`}, {-4.734970418668077, 
           3.320034883039177}, {-4.712471392001056, 3.3193210080171225`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688871275594003, 
           3.3185721963520707`}, {-4.523704516229084, 
           3.313331595248328}, {-4.313049118606441, 
           3.304477218189998}, {-4.103275529121174, 
           3.293519153815623}, {-3.8946550510943134`, 
           3.2805048040766422`}, {-3.7457500159816135`, 
           3.2696134868379514`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-3.7222009310590365`, 
           3.2678910430375887`}, {-3.687590691432879, 
           3.2653595564482316`}, {-3.482380094175097, 
           3.248106409986577}, {-3.2791365183388024`, 
           3.2289391840146306`}, {-3.0779732229418286`, 
           3.2080516978553457`}, {-2.879139921913617, 
           3.1852797205688526`}, {-2.782571579291185, 3.173214129398477}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.759141758256008, 
           3.1702867244733373`}, {-2.6827771652543224`, 
           3.16074546142554}, {-2.4888344660878516`, 
           3.135072400063746}, {-2.2972613375381092`, 
           3.1088840161218094`}, {-2.155354555409636, 
           3.089307329420676}, {-2.014869907373657, 
           3.070063784058167}, {-1.8757013254418102`, 
           3.0514094496416253`}, {-1.8232179433964584`, 
           3.0435306577716585`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7998675954973047`, 
           3.0400253095258125`}, {-1.7388741335015911`, 
           3.030868986633403}, {-1.6028857017178766`, 
           3.012070047804191}, {-1.4680012000615694`, 
           2.994372459135632}, {-1.3342206285326705`, 
           2.977776220627726}, {-1.2015439871311822`, 
           2.9622813322804733`}, {-1.069590667342194, 
           2.9481829271704982`}, {-0.9379800606507999, 
           2.935776138374426}, {-0.862034953797545, 2.929576869864583}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8385012352838017, 
           2.9276558528807812`}, {-0.8067121670569997, 
           2.925060965892256}, {-0.675786986560792, 
           2.9160374097239887`}, {-0.5446505349292018, 
           2.908624101285012}, {-0.4127488279292519, 
           2.902739671990714}, {-0.2800818655609411, 
           2.898384121841095}, {-0.1466496478242702, 
           2.895557450836155}, {-0.01208265198996053, 2.8936423535201072`}, {
           0.10509823876138304`, 2.89224653970518}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.12870867223922858`, 2.8919760119778624`}, {
           0.2615642421594139, 2.8906949635873294`}, {0.40064414047447766`, 
           2.8896626709705995`}, {0.5410847627676385, 2.888199921842035}, {
           0.6827425321900765, 2.8855819914566947`}, {0.8256174487417912, 
           2.8818088798145793`}, {0.969709512422782, 2.8768805869156884`}, {
           1.07290755041402, 2.87222498390329}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.0964955523563664`, 2.8711608515318146`}, {
           1.1702073457697648`, 2.8678354700212294`}, {1.370984475330726, 
           2.855947444472928}, {1.5720409011056655`, 2.841216510270784}, {
           1.7733766230945835`, 2.823642667414798}, {1.974531639870612, 
           2.8042178501752386`}, {2.037984660482435, 
           2.7977989964893157`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.061476760053278, 2.795422555644319}, {
           2.175045950006883, 2.7839339928223756`}, {2.3749195535033967`, 
           2.7627910953562083`}, {2.5741524503601525`, 2.740789157776737}, {
           2.7170411070151967`, 2.7249368856547456`}, {2.859932880291752, 
           2.709606954896559}, {3.000600661308657, 2.6950301513187473`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.0240947257070467`, 2.692673347499419}, {
           3.145725776709396, 2.6805141174715996`}, {3.288626899850485, 
           2.666751210804827}, {3.4315311396130848`, 2.653510645501859}, {
           3.5744384959971955`, 2.6407924215626957`}, {3.7173489690028174`, 
           2.6285965389873374`}, {3.8760940994863855`, 2.6157887895517966`}, {
           3.9648444607855944`, 2.609118443552392}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.988390045244235, 2.6073487922202943`}, {
           4.035151409805293, 2.603834277164125}, {4.2010425501892685`, 
           2.592263317639652}, {4.367301089070986, 2.5815666452911015`}, {
           4.533927026450444, 2.571744260118474}, {4.700920362327642, 
           2.562796162121769}, {4.723310745756602, 2.5616562715117075`}, {
           4.745705901817621, 2.560532661818205}, {4.927704080100177, 
           2.5525611057665816`}, {4.931227976496646, 2.552425007077692}}]}, 
         {Arrowheads[{{0.014874391356216007`, 1.}}], 
          ArrowBox[{{4.954822378971856, 2.5515137523526046`}, {
           5.1099970635057685`, 2.5455206501901713`}, {5.241631279214413, 
           2.5406594657481256`}, {5.373414028813697, 2.536238036685896}, {
           5.50487032055542, 2.5322384100770106`}, {5.635525162691382, 
           2.5286426329949974`}, {5.656854249492381, 2.52812387996534}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.5303689881843494, -1.6136893036119007`}, \
{-0.40936641187347117`, -1.583826484833065}, {-0.2882708723393188, \
-1.5582580159498618`}, {-0.1656240500067656, -1.5368440659549907`}, \
{-0.0399676253006839, -1.519444803841151}, {
           0.08965012534825756, -1.504466620459715}, {
           0.22418092550938953`, -1.4903159066620546`}, {
           0.36323360785398573`, -1.474080516702874}, {
           0.4017851888604247, -1.4683638250213775`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.4251417843110731, -1.4649003495572066`}, {
           0.5064170050533194, -1.4528483048368777`}, {
           0.6712194513168517, -1.4199600517359423`}, {
           0.8347094420726964, -1.375256491840056}, {
           0.9931978358330144, -1.3193336791438346`}, {
           1.0636111535195596`, -1.2901295597744173`}, {
           1.1321787301279176`, -1.2593020229052863`}, {
           1.3153675638152882`, -1.166622758814568}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{1.3361079344746114`, -1.1553475938238087`}, {
           1.4955695393396078`, -1.0657044476791044`}, {
           1.697479616080465, -0.9514858949777288}, {
           1.7141566571215838`, -0.9422345682463548}, {
           1.7307834490327787`, -0.9331550628806047}, {
           1.7990807611641222`, -0.8989686383184416}, {
           1.8673840007448372`, -0.8672901850900229}, {
           2.0048252059099205`, -0.8083879418535096}, {
           2.145053698079252, -0.758023292831609}, {
           2.184780163880133, -0.7465215077824735}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.207460692723681, -0.7399549390656203}, {
           2.2902886653287133`, -0.7159742119167775}, {
           2.453274670808212, -0.6788346653156926}, {
           2.6236585822858767`, -0.6486583926344298}, {
           2.8011407491958984`, -0.6241534521669568}, {
           2.9854215209724675`, -0.6040279022072417}, {
           3.1383663339824572`, -0.5908871668501919}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{3.1618916555165977`, -0.5888659147502633}, {
           3.1760383878945913`, -0.5876504536784708}, {
           3.372158832464483, -0.5738847862423799}, {
           3.4962918375738345`, -0.5668455796122407}, {
           3.6222535510299707`, -0.5607099255614323}, {
           3.7498401527070326`, -0.5552939794168321}, {
           3.8788478224791634`, -0.5504138965053175}, {
           4.0091510029542805`, -0.5460156764596322}, {
           4.10516447485, -0.5431713179915876}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.12876611353671, -0.5424721294346818}, {
           4.140668858302459, -0.5421195156587296}, {
           4.273264650741077, -0.5386528645488013}, {
           4.406801642487514, -0.5355431735760386}, {
           4.541186822517367, -0.5327559053061149}, {
           4.676352166525218, -0.5302782435158361}, {
           4.81219841680692, -0.5280702204680923}, {
           4.948626315658326, -0.5260918684257736}, {
           5.073064823806313, -0.5244845326018435}}]}, 
         {Arrowheads[{{0.011862717510706042`, 1.}}], 
          ArrowBox[{{5.09667505050417, -0.5241962714632652}, {
           5.222976208034549, -0.5227548461071215}, {
           5.3607773441596684`, -0.52136433957121}, {
           5.498900141582486, -0.5201285140592989}, {
           5.637570510103716, -0.5190282211508016}, {
           5.656854249492381, -0.5188932107082624}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.657398108075013, 
           1.6498547011540499`}, {-0.4915593360396402, 
           1.6042324291887908`}, {-0.2828183756218638, 
           1.557617177890294}, {-0.06904272398905029, 1.5239048979813774`}, {
           0.15654614769940894`, 1.4988280455308096`}, {0.27101218763468904`, 
           1.4858313148468205`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.29447343558909883`, 1.4831674721791948`}, {
           0.39679589697309614`, 1.4715495506167595`}, {0.5903711976001648, 
           1.4392537361176252`}, {0.7855250541639653, 1.3921268803490445`}, {
           0.9750022089789917, 1.328880958681573}, {1.044324218864717, 
           1.3009550098839535`}, {1.1120367930863173`, 1.2713075009284618`}, {
           1.198168056051509, 1.228736910357506}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.2193357049178228`, 1.21827474734938}, {
           1.301321507634277, 1.1777530607988902`}, {1.4741071388361535`, 
           1.082024062859681}, {1.6831170336382515`, 0.963617430329785}, {
           1.6998880846933806`, 0.9542170798623715}, {1.7166025201467523`, 
           0.9449920375436932}, {1.7847194803749091`, 0.9104599181788603}, {
           1.8527569718603618`, 0.878450646841184}, {1.9895140159407465`, 
           0.8189140423785923}, {2.0610733105940025`, 
           0.7926046269552606}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.083234935445632, 0.7844567071427079}, {
           2.128641203290456, 0.7677626862004796}, {2.2724183118036345`, 
           0.7248197774297768}, {2.425610295343474, 0.68859050429741}, {
           2.5853828261665943`, 0.6588437990731614}, {2.751528956633326, 
           0.6344258925705893}, {2.923841739103998, 0.6141830156032525}, {
           3.0081577572442084`, 0.6062942744286429}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.031667076834145, 0.6040947049811415}, {
           3.1019417654069126`, 0.5975196930023385}, {3.285146100833015, 
           0.5833640694639854}, {3.4071511179878335`, 0.5756763985805792}, {
           3.53106305552565, 0.5689677740758353}, {3.656691848773527, 
           0.563045578583479}, {3.783847433058527, 0.5577171947372352}, {
           3.912396729972408, 0.5529219602581694}, {3.974496656476712, 
           0.5508905776906913}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.998096026678913, 0.550118606580083}, {
           4.042239224686755, 0.548674615774399}, {4.173233697898368, 
           0.5448956482802267}, {4.305238930304051, 0.5415055447699552}, {
           4.438157674774106, 0.5384661410495337}, {4.571917811135128, 
           0.5357629008172817}, {4.706415810518348, 0.533351752906056}, {
           4.841548144055, 0.5311886261487139}, {4.942342861932188, 
           0.5297496934616717}}]}, 
         {Arrowheads[{{0.014631093647853264`, 1.}}], 
          ArrowBox[{{4.965952449228966, 0.5294126459694578}, {
           4.977244523252519, 0.5292514417440857}, {5.113453654119028, 
           0.5275306879572724}, {5.2501004995367895`, 0.526001144220537}, {
           5.387110022388067, 0.5246375899661421}, {5.521519125734948, 
           0.5234479129639904}, {5.65618326263806, 0.5223950975524166}, {
           5.656854249492381, 0.5223904251984839}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.01999999999999999, 1.}}], 
          ArrowBox[{{-5.656854249492381, -0.6723608580137553}, \
{-5.517454281731932, -0.6722407564083698}, {-5.301438663986418, \
-0.6716484466600885}, {-5.085690349139244, -0.6705490507203332}, \
{-5.056934707810731, -0.6703651349203779}, {-5.028185964472404, \
-0.6701701868066009}, {-4.8379021704188405`, -0.6682618187526582}, \
{-4.712400145254443, -0.6665901758239335}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.688790246515668, -0.6662757002589148}, \
{-4.648001407072503, -0.6657324072328721}, {-4.435006440450529, \
-0.6623326811359015}, {-4.2223665520918825`, -0.657812268767289}, \
{-4.010081741996561, -0.6521711701270346}, {-3.798152010164566, \
-0.6454093852151385}, {-3.7446130736475998`, -0.6433143577188866}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-3.721019137592368, -0.6423911054468723}, \
{-3.5859133814916593`, -0.6371042937851727}, {-3.3727018808736036`, \
-0.6268332755907099}, {-3.158517508310399, -0.6145963306317498}, \
{-2.9433602638020453`, -0.6003934589082927}, {-2.803442236665754, \
-0.5898552141551399}, {-2.778194736464126, -0.5877117130813184}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7546673829954456`, -0.5857142516684438}, \
{-2.6614912173059793`, -0.577803638355643}, {-2.51750720572272, \
-0.5642387315098021}, {-2.371490201915977, -0.5491604936176171}, \
{-2.1658483399211224`, -0.524997749961658}, {-1.9505777813644247`, \
-0.4957661140495938}, {-1.816877504735393, -0.4753465638941476}}]}, 
         {Arrowheads[{{0.01934675925401892, 1.}}], 
          ArrowBox[{{-1.793536164753917, -0.47178172712294547`}, \
{-1.792654016873379, -0.4716469999305617}, {-1.6249027785763792`, \
-0.44345923884247307`}, {-1.4979538784113915`, -0.42064455497148456`}, \
{-1.3614203038158081`, -0.39496338531868413`}, {-1.1390960532350858`, \
-0.3536809453987747}, {-1.0771876019963993`, -0.3429522341399652}, \
{-1.011543991635311, -0.3328304422818669}, {-0.9510675038754307, \
-0.3248133639167005}, {-0.9409036062917946, -0.32360624617488476`}, \
{-0.93222171310853, -0.32259260384811267`}, {-0.9251430254147028, \
-0.3217748350818649}, {-0.9149783119960153, -0.32060038236736527`}, \
{-0.9085591720126943, -0.31985394116625054`}, {-0.9042311909484175, \
-0.319348605191202}, {-0.8978030665663126, -0.3185951283264076}, \
{-0.8931171260435125, -0.3180435629372244}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -1.7752181679128414`}, \
{-5.594225580410296, -1.7751625231391213`}, {-5.467518856853779, \
-1.7747815643702456`}, {-5.34022209154999, -1.7740828980742365`}, \
{-5.212959613757389, -1.7730182771381109`}, {-5.085761964699471, \
-1.771541232745564}, {-4.9586596855997325`, -1.7696052960802902`}, \
{-4.831768057058698, -1.767101147694359}, {-4.712467212121754, \
-1.764102096079073}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.688865146488172, -1.7634200316293793`}, \
{-4.578962593454311, -1.7600602574167332`}, {-4.453048758390959, \
-1.7555235155250388`}, {-4.327460854486834, -1.7503092424647564`}, \
{-4.2021988817419365`, -1.7444174382358861`}, {-4.0772628401562665`, \
-1.7378481028384283`}, {-3.9526527297298237`, -1.7306012362723824`}, \
{-3.8283854974956975`, -1.7224828571792772`}, {-3.745640178654118, \
-1.7163498703291502`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7220927770949257`, -1.7146045642968697`}, \
{-3.704478090486977, -1.713298984200641}, {-3.580930508703661, \
-1.7030496173364738`}, {-3.4577427521457507`, -1.6917347565867755`}, \
{-3.3349148208132453`, -1.679354401951546}, {-3.2124467147061457`, \
-1.6659085534307858`}, {-2.9685899781681617`, -1.635820374732672}, \
{-2.8501825948422757`, -1.61943250830217}, {-2.7836874200544193`, \
-1.6094377578169021`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.760337717570231, -1.605928112929446}, \
{-2.732034385622128, -1.601673898369886}, {-2.52495492760411, \
-1.5671239305685134`}, {-2.31859153620955, -1.5280157781023966`}, \
{-2.1319577343061096`, -1.487771611498269}, {-1.945412245791008, \
-1.4423268441936072`}, {-1.9200278237332464`, -1.4357875006766536`}, \
{-1.894639243578971, -1.429131124154446}, {-1.8364580135787745`, \
-1.4125580356260992`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8137493566625777`, -1.4060894102389991`}, \
{-1.8029784493706211`, -1.4030212867208196`}, {-1.7111251722515226`, \
-1.375028276005994}, {-1.5387677412536567`, -1.3190509058808941`}, \
{-1.3648720920734378`, -1.2557045845884365`}, {-1.1874288308316256`, \
-1.183106505108711}, {-1.0044285636489798`, -1.0993738604218086`}, \
{-0.9346231532555841, -1.064581384625917}}]}, 
         {Arrowheads[{{0.01181113877096596, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAT5K9qlA77b9agrjxYd3wv1B4D19S
Yeq/v6Ft63Un8L+kBPYKNZLlvxTQVgc45+2/wHHCSJY/5L/nKnh5ykTtv2Cl
nXcg2OK/Si1ZyI2e7L+uqIs5s2nhv4/xOm4a++u/3pxliC3u4L8yrrGIJ8Xr
v6rasyJzeuC/K06+HQ+T678BiEKCtBLgv+WQuupzZuu/MbdIMgn+3r9cDR6c
4Sbrv4O6MmswV96/SePnw6wC678kTb9OWOHdv/l7axUE6eq/+i77pxZ73b8p
K7aHs9Lqv8qrOn88JN2/1iaI7bW/6r+lkaoC/Nncv+Y7qHByr+q/vTUiya0S
3L+JCiQAroPqv4iD+Xjkkdu/PKhdPEln6r/LjiZxVzbbvwwr3eQMU+q/eFNM
fczY2r/SbLIHVT7qv3+irytfmNq/GO3j9Qgw6r9PJnJ/tTPav0Ea+zOnGeq/
BO2/Yw==
           "]]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -4.614874231139193}, \
{-5.4989338972552435`, -4.614948287106928}, {-5.311945376677376, \
-4.614581164978753}, {-5.124519506688714, -4.613410099270346}, \
{-4.937128779955456, -4.611309343600079}, {-4.712428188792252, \
-4.607184978595761}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.68882301918611, -4.606626666744441}, \
{-4.4690259002780595`, -4.60064799707365}, {-4.235632894422684, \
-4.5922934422356665`}, {-4.003081010399726, -4.582021088072156}, \
{-3.7718213404716203`, -4.569698473121094}, {-3.7451808128556903`, \
-4.568034803416281}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.721614727313382, -4.5665631290131685`}, \
{-3.5421854025969743`, -4.555357978124668}, {-3.314295459702698, \
-4.539320457682431}, {-3.088273774715705, -4.521906766393934}, \
{-2.8644994721258596`, -4.503219061549663}, {-2.779831070207826, \
-4.495689632289274}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.756311892054371, -4.493598108365858}, \
{-2.643146187172664, -4.483534458287358}, {-2.4240279489074816`, \
-4.4634362479774525`}, {-2.2069587863816746`, -4.443507721990381}, \
{-2.0257445856401097`, -4.427438524474129}, {-1.8458305950927634`, \
-4.412449182956087}, {-1.8155347293858923`, -4.410126781622435}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7919918083107393`, -4.408322043252124}, \
{-1.6670398438663023`, -4.398743554501351}, {-1.491083050402946, \
-4.384351020814013}, {-1.3154531273304761`, -4.3721595569829015`}, \
{-1.1405925018322258`, -4.361659520345282}, {-0.9665011739081952, \
-4.352850910901154}, {-0.8495252108979299, -4.3480474866278085`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8259331000104275, -4.347078715649736}, \
{-0.7931791435583843, -4.345733728650518}, {-0.6201648917218123, \
-4.340187776837167}, {-0.4469968993374994, -4.336092858704895}, \
{-0.27367516640544676`, -4.3334489742537}, {-0.10019969292565145`, \
-4.332256123483584}, {0.030515808250049847`, -4.331967643389422}, {
           0.11835709160885297`, -4.331858815684199}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.1419690664857562, -4.331829562502285}, {
           0.1615576641373067, -4.331805293934597}, {
           0.29292587473612025`, -4.331769075119108}, {
           0.42462044004649036`, -4.331858986942955}, {
           0.5566413600684172, -4.33207502940614}, {
           0.6889886348019011, -4.332417202508663}, {
           0.8216622642469418, -4.332885506250521}, {
           0.954662248403538, -4.333479940631716}, {
           1.0864455130531046`, -4.33382381680482}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1100574256643967`, -4.333885429894843}, {
           1.1309074261916054`, -4.333939836032144}, {
           1.3072636990517694`, -4.333579632193715}, {
           1.4837310669840298`, -4.332399329116428}, {
           1.6603095299883868`, -4.330398926800283}, {
           1.8369990880648401`, -4.3275784252452825`}, {
           2.0137997412133903`, -4.323937824451424}, {
           2.0544485202926643`, -4.322912895287632}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.07805301109611, -4.322317725357098}, {
           2.190711489434036, -4.319477124418708}, {
           2.367734332726779, -4.314196325147136}, {
           2.6091752371058092`, -4.306301986052653}, {
           2.850140970865015, -4.298152832145623}, {
           3.0220464632207804`, -4.292145576136812}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0456440523919355`, -4.29132095583295}, {
           3.090631534004397, -4.289748863426046}, {
           3.3306469265239547`, -4.281090079893921}, {
           3.5701871484236882`, -4.2721764815492485`}, {
           3.8092521997035975`, -4.26300806839203}, {
           3.989458148969487, -4.255890743312095}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{4.013051747370415, -4.254958902214124}, {
           4.047842080363683, -4.253584840422263}, {
           4.285956790403944, -4.24390679763995}, {
           4.4645453681872596`, -4.23670523496338}, {
           4.643037270832711, -4.229832743113419}, {
           4.779502477799142, -4.22483089573245}, {
           4.915923288182447, -4.220082891146742}, {
           4.956833902509886, -4.218734718727401}}]}, 
         {Arrowheads[{{0.014328984100183665`, 1.}}], 
          ArrowBox[{{4.980433084951942, -4.217957028941744}, {
           5.052299701982624, -4.215588729356296}, {
           5.188631719199674, -4.21134841036111}, {
           5.2069525659175095`, -4.210795545369663}, {
           5.22527263441071, -4.2102494006369655`}, {
           5.4178008822095265`, -4.205251682367633}, {
           5.559974493650302, -4.2018562971194235`}, {
           5.656854249492381, -4.199710166097871}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           4.615499704213702}, {-5.500211659430803, 
           4.615575538890458}, {-5.313227337238787, 
           4.615212778174337}, {-5.125781818754679, 
           4.614047523876281}, {-4.93837047808379, 
           4.611953367146369}, {-4.712428104126709, 4.607815732819243}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688823152807036, 
           4.607247763742984}, {-4.470211946238145, 
           4.601311803174614}, {-4.236789005719974, 
           4.5929682416058135`}, {-4.004205860630167, 
           4.582707015563944}, {-3.7729134800461184`, 
           4.570394990350317}, {-3.7451807208847163`, 4.568664523476492}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7216145607651323`, 
           4.567194043774389}, {-3.5432434048784667`, 
           4.556064052174522}, {-3.3153181767460254`, 
           4.540034873835633}, {-3.0892603372676097`, 
           4.522628128132724}, {-2.8654493355015016`, 
           4.503945401021793}, {-2.779829968825475, 4.4963337385147275`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7563107340987005`, 
           4.494242850855606}, {-2.6440590945544074`, 
           4.484263547933301}, {-2.424903867117789, 
           4.464166145878011}, {-2.207797905883109, 
           4.444236771866687}, {-2.0265798974586087`, 
           4.428168022947499}, {-1.846662498666949, 
           4.41317790355087}, {-1.8155318573614132`, 4.410791225824965}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7919889526952548`, 
           4.4089862734110925`}, {-1.6678687105201675`, 
           4.399470407212714}, {-1.4919095232352375`, 
           4.38507359641917}, {-1.3162774511493545`, 
           4.372877379595727}, {-1.141414991732424, 
           4.362371772902594}, {-0.9673221449844484, 
           4.3535567763397705`}, {-0.8495222122830476, 
           4.348714654354518}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8259301413388882, 
           4.347744911140098}, {-0.7939989109054268, 
           4.346432389907255}, {-0.6209842997414423, 
           4.340878930154414}, {-0.44781732173857886`, 
           4.33677671363061}, {-0.27449797689683675`, 
           4.334125740335844}, {-0.10102626521621516`, 4.332926010270116}, {
           0.029617024627054206`, 4.3326333019766645`}, {0.11836010717116395`,
            4.33252135320841}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.1419720813815142, 4.332491566870668}, {
           0.16058601866754119`, 4.332468085521003}, {0.29188071690524575`, 
           4.332430360903131}, {0.4235011193401679, 4.332520128123049}, {
           0.5554472259723076, 4.332737387180756}, {0.687719036801665, 
           4.333082138076253}, {0.8203165518282399, 4.333554380809539}, {
           0.9532397710520325, 4.334154115380616}, {1.086448457582934, 
           4.3345082890111515`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.1100603671229556`, 4.3345710680681595`}, {
           1.1294053432585418`, 4.334622502254691}, {1.305682283573588, 
           4.334271724427174}, {1.4820705919971708`, 4.3331017818980655`}, {
           1.65857026852929, 4.3311126746673665`}, {1.8351813131699453`, 
           4.328304402735076}, {2.011903725919138, 4.324676966101194}, {
           2.054451581853558, 4.323607072373299}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{2.0780561134110624`, 4.323013520954347}, {
           2.1887375067768673`, 4.32023036476572}, {2.365682655743132, 
           4.314964598728656}, {2.607952182489034, 4.307060798040006}, {
           2.849743705922978, 4.29890096555959}, {3.0220512160405493`, 
           4.292891701687868}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{3.045648862707801, 4.2920687283567664`}, {
           3.0910572260449642`, 4.290485101287407}, {3.3318927428549916`, 
           4.2818132052234565`}, {3.572250256353062, 4.27288527736774}, {
           3.812129766539173, 4.263701317720256}, {3.9894655911701182`, 
           4.256708677246741}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.013059248953208, 4.255778340882526}, {
           4.051531273413326, 4.254261326281005}, {4.290454776975522, 
           4.2445653030499875`}, {4.469195044336313, 4.237368871359817}, {
           4.647838756611102, 4.230502245306641}, {4.784284690234145, 
           4.225510788000343}, {4.9206861440553595`, 4.220774275657035}, {
           4.956842674269697, 4.219585939471377}}]}, 
         {Arrowheads[{{0.01432879599676117, 1.}}], 
          ArrowBox[{{4.980441924723998, 4.218810316282343}, {
           5.057043118074747, 4.216292708276717}, {5.193355612292304, 
           4.21206608585939}, {5.211673981733129, 4.211515131256697}, {
           5.229991574510874, 4.2109708882023416`}, {5.42239811181499, 
           4.205991252236693}, {5.563581282451002, 4.202627336280243}, {
           5.656854249492381, 4.200564878596105}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -2.9670878736294894`}, \
{-5.535479020474037, -2.9669619106070577`}, {-5.38831495068017, \
-2.9663951092456124`}, {-5.239134656193974, -2.965299106458516}, \
{-5.089915646460279, -2.9635629202316243`}, {-4.940852659311289, \
-2.961090996779844}, {-4.792140432579208, -2.9577877823180825`}, \
{-4.712479753944969, -2.955502758701499}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.688877468910411, -2.9548257398807465`}, \
{-4.643895430390051, -2.9535354543584122`}, {-4.496234116869835, \
-2.9482161904129067`}, {-4.34915649201856, -2.941829990481566}, \
{-4.20266255583623, -2.93437685456439}, {-4.0567523083228405`, \
-2.925856782661379}, {-3.911425749478392, -2.916269774772532}, \
{-3.766682879302886, -2.90561583089785}, {-3.745864767077934, \
-2.9039232117406004`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-3.7223304330764955`, -2.9020097498400443`}, \
{-3.622523697796323, -2.8938949510373333`}, {-3.45742525279263, \
-2.8790867819312562`}, {-3.293673278000727, -2.8629025113789455`}, \
{-3.131267773420616, -2.845342139380401}, {-2.9702087390522918`, \
-2.826405665935623}, {-2.810660935194621, -2.806208142681344}, \
{-2.783219665442596, -2.8024982129755323`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7598205458754586`, -2.7993347628306804`}, \
{-2.6527891221464635`, -2.784864621254298}, {-2.4965932999078193`, \
-2.762375101654484}, {-2.34207346847869, -2.738739583881903}, \
{-2.1893049729297798`, -2.714445434740156}, {-2.0383631583317943`, \
-2.6899800210328446`}, {-1.8892480246847345`, -2.665343342759969}, \
{-1.8265171273643053`, -2.654777514370558}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.803233097027098, -2.6508557616256523`}, \
{-1.7419595719886007`, -2.640535399921529}, {-1.526279924712034, \
-2.6043413614857283`}, {-1.3145104776570764`, -2.569784220108431}, \
{-1.1062460521003383`, -2.5381371281518654`}, {-0.9010814693184275, \
-2.510673237978259}, {-0.8698430863153507, -2.5072320588328623`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.846373067487178, -2.5046466324577}, \
{-0.6973375432835089, -2.4882290753209433`}, {-0.4933350879677484, \
-2.4716411659132493`}, {-0.2873454349630205, -2.4603299166237087`}, \
{-0.07763991586120042, -2.453715734320853}, {
           0.09608597444519035, -2.4504209960823777`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.11969372224218114`, -2.4499732715132083`}, {
           0.1368318530097796, -2.4496482442263923`}, {
           0.35712025532198666`, -2.4459770715620364`}, {
           0.5826123654886621, -2.440226230249755}, {
           0.8126952579230471, -2.4299197342115186`}, {
           0.9524336895531715, -2.4212452502630493`}, {
           1.0632314547054735`, -2.4126190466034685`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.0867722097912287`, -2.4107862718413524`}, {
           1.0925577200284406`, -2.410335838662378}, {
           1.2330673493488538`, -2.3971914994095065`}, {
           1.373962577514412, -2.3818122325044326`}, {
           1.5516359372834145`, -2.360183534355405}, {
           1.7282163748091899`, -2.3369741781326776`}, {
           1.903703890091738, -2.3121841638362497`}, {
           2.0238456095609028`, -2.294017213434348}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.0471921980708725`, -2.2904869134071117`}, {
           2.078098483131059, -2.2858134914661217`}, {
           2.2516963853534087`, -2.259008170201465}, {
           2.4247938281850443`, -2.232914209221451}, {
           2.5973908116259645`, -2.207531608526079}, {
           2.7694873356761702`, -2.1828603681153504`}, {
           2.896607783499733, -2.165346213268952}, {
           2.9817693411053803`, -2.154237390309798}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.0051829750834003`, -2.151183219836582}, {
           3.023792295599444, -2.148755743721594}, {
           3.1927386257046755`, -2.128084658689317}, {
           3.3622518684542353`, -2.1088562394687798`}, {
           3.5323320238481237`, -2.0910704860599814`}, {
           3.7029790918863403`, -2.074727398462922}, {
           3.7257741572193694`, -2.072644102222331}, {
           3.748580511414445, -2.070590323532437}, {
           3.899247269700907, -2.0584641800463515`}, {
           3.944654640219149, -2.055151003659007}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{3.968204028199126, -2.05343270825231}, {
           4.050432626968626, -2.0474328485665776`}, {
           4.242009854236882, -2.034165325022479}, {
           4.434408820476117, -2.0222598933538265`}, {
           4.62762952568633, -2.011716553560619}, {
           4.821671969867521, -2.002535305642857}, {
           4.911057775769609, -1.9988489806524916`}}]}, 
         {Arrowheads[{{0.015301163229078298`, 1.}}], 
          ArrowBox[{{4.934649714850257, -1.9978760347386915`}, {
           5.016421631501287, -1.994503711170999}, {
           5.211763989069226, -1.9874093317155017`}, {
           5.407699042571337, -1.9812521672763657`}, {
           5.604226792007619, -1.9760322178535907`}, {
           5.656854249492381, -1.974859640348612}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, -3.7258796660669766`}, \
{-5.569325494904021, -3.7258835177808}, {-5.425287170205636, \
-3.7255239349494493`}, {-5.2788941630206905`, -3.7247008535054587`}, \
{-5.132468485093759, -3.7233164902935676`}, {-4.98605164416711, \
-3.7212979857707964`}, {-4.839685147983007, -3.718572480394168}, \
{-4.712466094561025, -3.715265600818599}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688862074440334, -3.7146520476601776`}, \
{-4.606015005967356, -3.712498555150527}, {-4.3734103062959715`, \
-3.704131985812124}, {-4.141871048968856, -3.6934727723789598`}, \
{-3.9113972339860084`, -3.680520914851034}, {-3.7455368564316287`, \
-3.6694776397440108`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7219770275789834`, -3.6679089849795004`}, \
{-3.6825349665479505`, -3.665282863315145}, {-3.4558303518552083`, \
-3.647765067858092}, {-3.2312833899077797`, -3.627967528479875}, \
{-3.0088940807056646`, -3.6058902451804937`}, {-2.789032182253596, \
-3.582386670308045}, {-2.7815234532368547`, -3.5815534322540783`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.758055512293751, -3.578949212365674}, \
{-2.572067452556306, -3.5583102562106257`}, {-2.3579998916137925`, \
-3.5336610028882354`}, {-2.1468294994260586`, -3.508438910340874}, \
{-2.012328414146026, -3.492275394959744}, {-1.878886532253351, \
-3.476632476410106}, {-1.8198979377648923`, -3.469894098597937}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7964385088044441`, -3.467214284017439}, \
{-1.7465038537480349`, -3.4615101546919598`}, {-1.615180378630079, \
-3.446908429805306}, {-1.4847741851981477`, -3.4330848804467666`}, \
{-1.3551433517509064`, -3.4202970853129635`}, {-1.226287878288356, \
-3.408545044403897}, {-1.098207764810498, -3.397828757719567}, \
{-0.9706042120605648, -3.3883280379640723`}, {-0.8560197554478737, \
-3.381039513527344}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8324486216207116, -3.3796569010386737`}, \
{-0.7159303909741728, -3.373512737351883}, {-0.5888601226377166, \
-3.368198156495189}, {-0.41743775558147755`, -3.3627565341877643`}, \
{-0.24477406277277647`, -3.358851957712512}, {-0.07086904421161333, \
-3.3564844270694314`}, {0.10427730010201275`, -3.355653942258522}, {
           0.11160953911358873`, -3.355640444750984}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.13522149210460516`, -3.355596978831095}, {
           0.28084356182074943`, -3.3553289113307594`}, {
           0.45900833259724527`, -3.354477742337117}, {
           0.6387716124315009, -3.353100435277595}, {
           0.8201334013235169, -3.3511969901521934`}, {
           1.050170850867678, -3.3471006813783055`}, {
           1.0796343276002294`, -3.3462296947434926`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1032360102551164`, -3.345531991945615}, {
           1.2811593496378686`, -3.3402722986639843`}, {
           1.5130988976340891`, -3.33071184200923}, {
           1.7459894948563388`, -3.318419311414042}, {
           1.9791570634106934`, -3.3039963329239637`}, {
           2.046513227032907, -3.299380403288674}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.070069969062314, -3.2977660556507313`}, {
           2.211927525403228, -3.2880445325845367`}, {
           2.444300880833943, -3.270563910395762}, {
           2.676277129702837, -3.251554466357639}, {
           2.844809883942213, -3.2373699104464264`}, {
           3.0116288847126356`, -3.223713171124703}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.0351661911812613`, -3.22183667735893}, {
           3.18164576925801, -3.2101821542115117`}, {
           3.3499489003344305`, -3.197178953887809}, {
           3.5181754903565334`, -3.184569538759943}, {
           3.686325539324318, -3.172353908827914}, {
           3.854399047237785, -3.160532064091721}, {
           3.9770676527162276`, -3.1521874841070394`}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{4.000625202884912, -3.1505849725201585`}, {
           4.022396014096933, -3.149104004551365}, {
           4.191708118921372, -3.1381939819435907`}, {
           4.361161635628354, -3.1280811262321238`}, {
           4.518976771373969, -3.119339379554892}, {
           4.676983385018781, -3.111205585587793}, {
           4.83518147656279, -3.103679744330826}, {
           4.943668491921404, -3.0989414204394996`}}]}, 
         {Arrowheads[{{0.014611014452874837`, 1.}}], 
          ArrowBox[{{4.967257995626339, -3.0979111154889933`}, {
           4.993571046005996, -3.096761855783991}, {
           5.0148293460137765`, -3.095874703965166}, {
           5.036091466852837, -3.094997607748307}, {
           5.227269416829563, -3.0880016850145675`}, {
           5.4186377137825605`, -3.0818255921283053`}, {
           5.567134039735048, -3.0772532336827867`}, {
           5.656854249492381, -3.0747669676025735`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           3.726830002849124}, {-5.570919104560654, 
           3.726835578654739}, {-5.4269250179013095`, 
           3.7264806814458216`}, {-5.280536849470861, 
           3.7256636780171286`}, {-5.1341151986463025`, 
           3.7242863937506523`}, {-4.987701542660502, 
           3.722275939802869}, {-4.841337358746326, 
           3.719559427330256}, {-4.712466050010351, 3.7162178261066097`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688861990798402, 
           3.715605778677905}, {-4.607518747493927, 
           3.7134965684585963`}, {-4.374764732733585, 
           3.70513924251152}, {-4.1430753144653, 
           3.6944874494890265`}, {-3.9124504926890715`, 
           3.681541189391116}, {-3.745536331112711, 3.6704375800702342`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.7219764103391744`, 
           3.6688703064882344`}, {-3.6834375472696843`, 
           3.666306590652782}, {-3.4565837580719205`, 
           3.6487897817090187`}, {-3.2318891250957784`, 
           3.6289907625598254`}, {-3.0093536483412615`, 
           3.6069095332052026`}, {-2.7893478751785965`, 
           3.5834003085459205`}, {-2.7815211031816025`, 
           3.5825321031326203`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7580530552272795`, 
           3.5799288477571785`}, {-2.572242352978014, 
           3.5593173034827483`}, {-2.3580370817395133`, 
           3.534660518015686}, {-2.146732061463094, 
           3.5094299521447345`}, {-2.0121090305365117`, 
           3.493257094981218}, {-1.8785464917726922`, 
           3.4776066423165024`}, {-1.8198912872291046`, 
           3.47090984945723}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7964317004076544`, 
           3.4682314171726643`}, {-1.7460444451716364`, 
           3.4624785941505887`}, {-1.614602890733344, 
           3.447872950483476}, {-1.484079071414282, 
           3.434047557022839}, {-1.3543302301709168`, 
           3.4212602594763504`}, {-1.2253563670032483`, 
           3.4095110578440107`}, {-1.0971574819112782`, 
           3.3987999521258194`}, {-0.9694339618750227, 
           3.3893059686374993`}, {-0.8560085557244763, 
           3.3821047433105678`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.83243806516721, 
           3.3807110198259487`}, {-0.7145141779097088, 
           3.374506447297637}, {-0.5873179139806519, 
           3.369200909446095}, {-0.4158393859720323, 
           3.3637741575206763`}, {-0.24311837053312596`, 
           3.3598804755572447`}, {-0.06915486766393353, 
           3.3575198635558006`}, {0.10605112263554439`, 3.356692321516344}, {
           0.1116202278742737, 3.3566820492511744`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.1352321807058222, 3.3566384967898246`}, {
           0.2826765984096101, 3.3563665342228535`}, {0.4608985577025657, 
           3.355511186459308}, {0.6407170005144105, 3.3541262782257073`}, {
           0.8221319268451437, 3.3522118095220517`}, {1.0522868306943385`, 
           3.3480986423031296`}, {1.0796454120432288`, 
           3.347288243187545}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1032470529583709`, 3.346589129857067}, {
           1.2833896090269956`, 3.3412530575565538`}, {1.5154402618431153`, 
           3.331675055282324}, {1.7484387891426985`, 3.319364635480441}, {
           1.9817121384860918`, 3.3049253590986374`}, {2.0465266098397734`, 
           3.30048205360447}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.0700833132267284`, 3.2988671421904345`}, {
           2.214587257433643, 3.288960787084647}, {2.4470641459853537`, 
           3.2714709194384706`}, {2.679142804141223, 3.2524557561601073`}, {
           2.847779524996003, 3.2382669525404286`}, {3.011645670995702, 
           3.224858387104337}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0351825054146553`, 3.222976056558359}, {
           3.1848243316147293`, 3.211077692316684}, {3.353232417378676, 
           3.198077235712618}, {3.521564291445677, 3.185472894780423}, {
           3.689819953815734, 3.173264669520099}, {3.8579994044888464`, 
           3.1614525599316456`}, {3.977086745101142, 
           3.1533652656935813`}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{4.000644478205935, 3.1517654456100974`}, {
           4.0261026434650145`, 3.1500365660150638`}, {4.195538952606144, 
           3.13913886405988}, {4.365117287490145, 3.129038512008754}, {
           4.5229159173460705`, 3.1203156544818524`}, {4.680905895132144, 
           3.1121998983334094`}, {4.839087220848364, 3.1046912435634257`}, {
           4.943688330598819, 3.100132943655151}}]}, 
         {Arrowheads[{{0.014610594095856896`, 1.}}], 
          ArrowBox[{{4.967277935465796, 3.099104957489823}, {
           4.997459894494731, 3.097789690171901}, {5.018716130578717, 
           3.0969046635704585`}, {5.03997618116769, 3.0960296794216906`}, {
           5.231276814823839, 3.08904698032826}, {5.42276428493355, 
           3.0828861652438952`}, {5.5698864188505715`, 3.078368064637387}, {
           5.656854249492381, 3.075961841734026}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           5.577906130133575}, {-5.498260932203243, 
           5.57769944904581}, {-5.3241655121477915`, 
           5.577104416046672}, {-5.14890057502358, 
           5.576066967868315}, {-4.973228895518762, 
           5.57452805339869}, {-4.797913248321493, 
           5.572428621525744}, {-4.7124084687313985`, 5.571094551071252}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.688799349160087, 
           5.57072619471705}, {-4.625256910907877, 
           5.569734787103521}, {-4.456330758523658, 
           5.566392532213191}, {-4.2900489625114435`, 
           5.562312606583387}, {-4.125325694213844, 
           5.557405759942747}, {-3.9165295127252375`, 
           5.549621754556163}, {-3.7448077414001615`, 5.541775514719147}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7212203575018323`, 
           5.5406977697729705`}, {-3.7044825690002847`, 
           5.539932993694137}, {-3.4901327573895196`, 
           5.5286278146233965`}, {-3.2744279722434797`, 
           5.515994554610668}, {-3.0591049472149345`, 
           5.502330158802348}, {-2.845269344514868, 
           5.487924686041097}, {-2.778506927216765, 5.483249977669981}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7549526047856436`, 
           5.481600702633203}, {-2.6329224513311336`, 
           5.473056144138036}, {-2.4220655548515846`, 
           5.458002540904285}, {-2.2128542825381543`, 
           5.443067170776224}, {-2.0053207896335117`, 
           5.428533098890026}, {-1.8127857781944732`, 5.415558072139882}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7892246338534643`, 
           5.414009982194253}, {-1.5945514574864301`, 
           5.401659505286458}, {-1.4699554868048166`, 
           5.394327978987098}, {-1.3457654307048903`, 
           5.387577068105414}, {-1.2219273629392888`, 
           5.38142102639379}, {-1.098962570565841, 
           5.37572206757918}, {-0.8534957621009417, 
           5.366265548736367}, {-0.8460051906097219, 5.366052219423511}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8224027675628888, 
           5.365380029231319}, {-0.6090054969944498, 
           5.3593025365928675`}, {-0.3652894650807826, 
           5.354849876733004}, {-0.12214535619435682`, 
           5.352924414741102}, {-0.07357372671979584, 
           5.352792042129517}, {-0.025025961688239173`, 
           5.3527620782000955`}, {-0.0007642071348712871, 
           5.352798419942962}, {0.023491356264227777`, 5.352860464279441}, {
           0.04774681619737859, 5.35293613445521}, {0.0720039115086864, 
           5.353021944686875}, {0.09626262888667625, 5.353117901967788}, {
           0.12194107903416544`, 5.35324147425242}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.1455527986314215, 5.353355100819365}, {
           0.28821887308090927`, 5.354041652097108}, {0.48020133834735745`, 
           5.355153666233889}, {0.6722100246860203, 5.35645394437813}, {
           0.8642449320968975, 5.35794248652983}, {1.0563060605799892`, 
           5.359619292688992}, {1.090008566146654, 5.359946526823974}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1136194462225237`, 5.360175776423904}, {
           1.2483934101352965`, 5.361484362855612}, {1.4405069807628181`, 
           5.3635376970296935`}, {1.632646772462554, 5.365779295211234}, {
           1.8246215210533174`, 5.367847447795983}, {2.0162399623539216`, 
           5.369380445179688}, {2.058050924317667, 5.369598579008221}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.0816625959795436`, 5.3697217645101984`}, {
           2.2075020963643657`, 5.37037828736235}, {2.3984079230846502`, 
           5.370840974343967}, {2.5889574425147748`, 5.37076850612454}, {
           2.7791506546547398`, 5.370160882704069}, {2.968987559504545, 
           5.369018104082555}, {3.0261333780214676`, 
           5.3685120527878984`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.0497444452618634`, 5.368302966428558}, {
           3.15846815706419, 5.367340170259996}, {3.299301321481524, 
           5.365793724156272}, {3.4398437033154265`, 5.364063428767898}, {
           3.668691231592519, 5.360924495784694}, {3.8967454219608815`, 
           5.357440028114534}, {3.9120368526411613`, 5.357194376860206}, {
           3.927320201329396, 5.356947496299052}, {3.9941389294344947`, 
           5.355807718991459}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.01774748802759, 5.3554050100487345`}, {
           4.0822889348658595`, 5.354304078040723}, {4.2369643399115775`, 
           5.35157605964682}, {4.4260534526314, 5.348930000708207}, {
           4.615142565351224, 5.346283941769595}, {4.804231678071047, 
           5.343637882830983}, {4.962122765437749, 5.341428400132353}}]}, 
         {Arrowheads[{{0.014211984970100965`, 1.}}], 
          ArrowBox[{{4.98573244687742, 5.341098013005814}, {4.99332079079087, 
           5.340991823892371}, {5.179465968680583, 5.341200800453722}, {
           5.368035563489211, 5.33905857130922}, {5.556258813023708, 
           5.337252228694127}, {5.656854249492381, 5.336464898434827}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.01938641848684033, 1.}}], 
          ArrowBox[{{1.0121290138867345`, 1.0351878026376764`}, {
           1.0607592976180147`, 0.9976774942240741}, {1.1064457819553448`, 
           0.9586902948680535}, {1.2455301231486826`, 0.8145893780443881}, {
           1.3471316720238249`, 0.6760796479644097}, {1.3781226954524832`, 
           0.6258524463526071}, {1.4050270499271214`, 0.578028489529438}, {
           1.4280848640055945`, 0.5323535694231525}, {1.4337372113291882`, 
           0.5204365390319321}, {1.4391319230124857`, 0.5086658694254043}, {
           1.4535117958005956`, 0.4765274370252942}, {1.4667474042991657`, 
           0.44639968825908055`}, {1.491208140372942, 0.3898650850772547}, {
           1.5120274474342426`, 0.34022554660782295`}, {1.5298802135715202`, 
           0.29649113549222494`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019143633268722583`, 1.}}], 
          ArrowBox[{{1.0390559752919233`, -1.0200936987113314`}, {
           1.0872350255880827`, -0.9816731114819142}, {
           1.132436749097229, -0.9418553790238774}, {
           1.229314920682583, -0.8436188572470182}, {
           1.307813843036672, -0.74638061031764}, {
           1.3874052438271038`, -0.6273223109196715}, {
           1.445922581304625, -0.5214521030315399}, {
           1.451604654931329, -0.5098858771319622}, {
           1.457147312001684, -0.49859008961089657`}, {
           1.4724082671953207`, -0.46735029442867587`}, {
           1.486705155297976, -0.4381118721232146}, {
           1.513670414985739, -0.3833268888668338}, {
           1.5378154702901645`, -0.3353863255752971}, {
           1.5599438602114064`, -0.2933136656805766}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.07976321956970409, -1.7410778163408307`}, {
           0.22099991487800555`, -1.7323553797179978`}, {
           0.366555923437885, -1.7222222377555425`}, {
           0.5161705252678788, -1.7085588114096455`}, {
           0.6683897397635237, -1.6899246091369131`}, {
           0.8217595863203563, -1.6648791393939515`}, {
           1.0155654981882005`, -1.624348290631981}, {
           1.015635954956394, -1.6243298378446571`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.0384775550877925`, -1.618347570985559}, {
           1.2055712829770633`, -1.5745853448295604`}, {
           1.3905712827023402`, -1.5187352173686341`}, {
           1.569359839379427, -1.4599428236311471`}, {
           1.7430954830224097`, -1.4010816943364575`}, {
           1.9129367436453744`, -1.345025360203923}, {
           1.939621047253427, -1.3365169638748269`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.962117151002852, -1.3293439917271552`}, {
           2.0118437259879003`, -1.3134884755302239`}, {
           2.11032757764412, -1.2834415964713155`}, {
           2.2652355778839466`, -1.2398846045054723`}, {
           2.421045907148422, -1.2012793941391866`}, {
           2.578388603846719, -1.1672382992942552`}, {
           2.7378937063880113`, -1.1373736538924757`}, {
           2.7592044509989817`, -1.1336875599530405`}, {
           2.780559004163647, -1.1300642152858398`}, {
           2.880783050609313, -1.1150840390780277`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.9041411652075277`, -1.1116326311220592`}, {
           3.0240201291153324`, -1.0955584101586089`}, {
           3.2671159885966614`, -1.0662140220322205`}, {
           3.390731531195231, -1.053703308284134}, {
           3.5157254823657373`, -1.0426335814127863`}, {
           3.64195761776698, -1.032729790611602}, {
           3.769287713057759, -1.0237168850740064`}, {
           3.8438072555776968`, -1.0190041357116735`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{3.8673721713750537`, -1.0175138482227546`}, {
           3.897715768238074, -1.015594864799999}, {
           4.027241783307924, -1.0083637297895804`}, {
           4.157726540711401, -1.001865990222319}, {
           4.2890308228925935`, -0.9959441562777834}, {
           4.421154629851501, -0.990598227955974}, {
           4.554097961588124, -0.9858282052568904}, {
           4.7418588357266325`, -0.9798942921026832}, {
           4.810980661382394, -0.9779848812656186}}]}, 
         {Arrowheads[{{0.0174156963699339, 1.}}], 
          ArrowBox[{{4.834583650648508, -0.9773328758669724}, {
           4.930693473071844, -0.9746779526970116}, {
           5.120601873623757, -0.9701791870398756}, {
           5.311584037382372, -0.9663979951312752}, {
           5.5034554391909944`, -0.9632390952527491}, {
           5.656854249492381, -0.9611202859027713}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-0.20414212198056925`, 
           1.7656987656151437`}, {-0.05478500275678147, 
           1.7517136928791595`}, {0.09932444172013907, 1.7409120295414284`}, {
           0.25865865928309395`, 1.73051023613886}, {0.4236900977649838, 
           1.7177247732083636`}, {0.5928462246695824, 1.700035603420189}, {
           0.7360268952292639, 1.6790949487036557`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.7593903377606797, 1.6756779666408708`}, {
           0.7645545075006637, 1.6749226894445854`}, {0.9364454480077787, 
           1.6422083470154405`}, {1.1061495479404788`, 1.6017148918666415`}, {
           1.272423491312312, 1.5553103807868482`}, {1.434023962136826, 
           1.5048628705647207`}, {1.5912851676700583`, 1.4524360621524015`}, {
           1.6690038048585474`, 1.4258923932639016`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.6913485188306452`, 1.4182608815629805`}, {
           1.7445413151680462`, 1.4000936565020332`}, {1.8386259506327374`, 
           1.3680554561539007`}, {1.9317303864954032`, 1.3373922308926791`}, {
           2.0870287437048676`, 1.2891199628129983`}, {2.2419251640345106`, 
           1.2449077778478317`}, {2.397417706401396, 1.2052011504812958`}, {
           2.5545044297225874`, 1.1704455551975075`}, {2.5754325877840807`, 
           1.166166696051847}, {2.596398714383593, 1.1619617163528255`}, {
           2.599385480352002, 1.1614325445340807`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.6226353858505536`, 1.1573133082402283`}, {
           2.71135990026765, 1.1415937931667535`}, {2.827636311531389, 
           1.1230369549402042`}, {3.041030952530078, 1.0919650890766917`}, {
           3.2589966066413223`, 1.0661323426322729`}, {3.481276464368407, 
           1.044782509097954}, {3.5592272206097224`, 1.038713088018722}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{3.5827679632095917`, 1.036880152890882}, {
           3.70761371621462, 1.0271593819647409`}, {3.9376597588181674`, 
           1.0127352511369299`}, {4.1707871061278246`, 1.0005602384422532`}, {
           4.394491623859791, 0.9913601252906825}, {4.525840951990655, 
           0.987062229892131}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{4.5494403147937055`, 0.9862900326206008}, {
           4.6205429029813425`, 0.9839634772362269}, {4.8485232035887, 
           0.9778771324516101}, {5.078014785778082, 0.9726079291095563}, {
           5.308353767483302, 0.9680646840608061}, {5.493671842978919, 
           0.9651055005147554}}]}, 
         {Arrowheads[{{0.0029558279193960925`, 1.}}], 
          ArrowBox[{{5.517280826244712, 0.9647285091466318}, {
           5.538735613973939, 0.964385916257824}, {5.656854249492381, 
           0.9628629409838312}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           0.6723471043804703}, {-5.509769938569337, 
           0.6722117432815616}, {-5.2937719085544614`, 
           0.6716032144857397}, {-5.264953301556742, 
           0.6714913615323318}, {-5.236139739656857, 
           0.6713703000735873}, {-5.03923197384605, 
           0.6699878832901617}, {-4.842689021090407, 
           0.668032638279962}, {-4.712400399999548, 0.6664263314510366}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688790201310348, 
           0.6661352452220995}, {-4.62512728940056, 
           0.6653503557260425}, {-4.408016237812093, 
           0.6616366787970561}, {-4.191355866325002, 
           0.656891607493003}, {-3.9751461749392893`, 
           0.6511151418138832}, {-3.758887065527815, 
           0.6439166558350543}, {-3.744608284332359, 0.6433231924305537}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7210166592242793`, 
           0.642342662932784}, {-3.5420784399634377`, 
           0.634905523631874}, {-3.3247202982461577`, 
           0.6240817452043425}, {-3.106812640375976, 
           0.6114453205524595}, {-2.955299421673896, 
           0.6013149738183324}, {-2.8019419551132123`, 
           0.5896185401741628}, {-2.7781970547744845`, 0.5875894567327948}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.75467080329622, 
           0.5855790575889355}, {-2.646740240693926, 
           0.5763560196199506}, {-2.489694278416037, 
           0.561527412155696}, {-2.2690597743272507`, 
           0.537536870422361}, {-2.0389598084567027`, 
           0.5082394738839294}, {-1.8717357096504628`, 
           0.48400116256680303`}, {-1.8168968200596858`, 
           0.4751590119613694}}]}, 
         {Arrowheads[{{0.01936064939571231, 1.}}], 
          ArrowBox[{{-1.7935859004447054`, 
           0.47140038986808985`}, {-1.6946768359870346`, 
           0.45545242209004866`}, {-1.5615726885525336`, 
           0.4322194135602905}, {-1.418807942237445, 
           0.4058064126438229}, {-1.188290929567109, 
           0.36241853445256833`}, {-1.1242681643311876`, 
           0.35076028729664405`}, {-1.056451913109834, 
           0.33932848684494993`}, {-0.9852276717720276, 
           0.32897323235836456`}, {-0.9524277264897091, 
           0.3248251830617108}, {-0.9281668146674829, 
           0.3219469767145833}, {-0.9139309278126901, 
           0.32030161949219055`}, {-0.9065907611618643, 
           0.3194476706547454}, {-0.9021056200173936, 
           0.31892336546907885`}, {-0.8965742389421804, 
           0.3182745069320215}, {-0.8924899765207116, 0.3177936913408589}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, -5.580979433759249}, \
{-5.52940457366039, -5.580896013543733}, {-5.395668475899052, \
-5.580527112105299}, {-5.263088967578767, -5.579877601152004}, \
{-5.131666048699534, -5.578947480683848}, {-5.001399719261354, \
-5.577736750700829}, {-4.872289979264226, -5.57624541120295}, \
{-4.744336828708149, -5.574473462190209}, {-4.712411011347995, \
-5.573934119194303}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688802386998858, -5.573535283792783}, \
{-4.6171209204765145`, -5.572324323507287}, {-4.49022290745271, \
-5.569701414998864}, {-4.363642789636734, -5.56660473666494}, \
{-4.237380567028589, -5.563034288505515}, {-4.111436239628275, \
-5.558990070520589}, {-3.9858098074357895`, -5.554472082710162}, \
{-3.860501270451134, -5.549480325074234}, {-3.7448044204700026`, \
-5.544421191832069}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7212181414990155`, -5.543320929206156}, \
{-3.500625057001465, -5.532611626466829}, {-3.266633494365406, \
-5.519902476432788}, {-3.033535940766135, -5.505887347510685}, \
{-2.8013323962036503`, -5.490566239700517}, {-2.7783236856729117`, \
-5.488978596338675}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7547677040877874`, -5.487353190267121}, \
{-2.5705064541132723`, -5.474638824984638}, {-2.3415417079303174`, \
-5.458804775345399}, {-2.114438157654785, -5.443064090782802}, \
{-1.889195803286676, -5.427416771296845}, {-1.8125269573127714`, \
-5.422364316025436}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.788966068683601, -5.420811660126662}, \
{-1.6656165697901864`, -5.412682963026906}, {-1.4435023821295097`, \
-5.399682812112364}, {-1.222853240304647, -5.388416318553218}, \
{-1.0036691443155994`, -5.378883482349468}, {-0.8457351479791477, \
-5.373083152331141}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8221354906059409, -5.3723223222673395`}, \
{-0.6767075659420784, -5.36783909679681}, {-0.513525086930656, \
-5.363773410969598}, {-0.3505414813694596, -5.360678729775132}, \
{-0.18775674925848906`, -5.358555053213411}, {-0.025170890597744244`, \
-5.357402381284436}, {0.12217709334938334`, -5.357237538579745}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.1457889754092813, -5.357262436496845}, {
           0.29940420637306686`, -5.3580100513247215`}, {
           0.4614949109035791, -5.359332458928432}, {
           0.623589674424758, -5.360750002433791}, {
           0.7856884969366025, -5.362262681840796}, {
           0.9477913784391127, -5.363870497149448}, {
           1.0902323928672117`, -5.365366855646985}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1138430581105045`, -5.365617202236406}, {
           1.2720093184161296`, -5.367371535471694}, {
           1.4341243768906362`, -5.369264758485287}, {
           1.5962434943558093`, -5.371253117400528}, {
           1.7582461503798963`, -5.3730942489456925`}, {
           1.9200118245311453`, -5.374545789849059}, {
           2.0582698397898613`, -5.3754547499439935`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.081881326924725, -5.375609160809552}, {
           2.2428322272151315`, -5.376280099730399}, {
           2.403886955747869, -5.376562868708373}, {
           2.564704702407768, -5.376456047044548}, {
           2.7252854671948294`, -5.3759596347389245`}, {
           2.885629250109054, -5.375073631791503}, {
           3.0263520528762893`, -5.373999848482909}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0499633585082835`, -5.373819682757219}, {
           3.059871033984878, -5.373744082382975}, {
           3.2337076153374333`, -5.372108860224494}, {
           3.40713899416672, -5.370167965316058}, {
           3.580165170472738, -5.367921397657668}, {
           3.752988745517122, -5.3655219936243}, {
           3.925812320561506, -5.363122589590933}, {
           3.9943697373955755`, -5.362170769548866}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.017979455083042, -5.361842982950126}, {
           4.09863589560589, -5.360723185557566}, {
           4.266602254660507, -5.357132970321076}, {
           4.444465120946964, -5.353977566590171}, {
           4.6224232344298555`, -5.350870156181566}, {
           4.847757857635602, -5.347248198929244}, {
           4.9623172950033085`, -5.345623571797334}}]}, 
         {Arrowheads[{{0.014208167424509163`, 1.}}], 
          ArrowBox[{{4.985926913989833, -5.345288751476451}, {
           5.072650982103145, -5.34405887223399}, {
           5.087770144081472, -5.3438588056207585`}, {
           5.102887334836447, -5.343660773888913}, {
           5.295545684182794, -5.3414982901339165`}, {
           5.487861148605987, -5.339687857533916}, {
           5.6469120207947245`, -5.338238369213423}, {
           5.656854249492381, -5.338153657536217}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.6261705817166885`, 
           5.656854249492381}, {-1.5623285327530831`, 
           5.653146083978946}, {-1.3654962519645402`, 
           5.642630329516407}, {-1.1753926527303578`, 
           5.63358675795777}, {-0.9862498001366231, 
           5.625923989699787}, {-0.7980676941833341, 
           5.619642024742458}, {-0.6825951060080113, 5.61656567596305}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.658991488011361, 
           5.6159368430723955`}, {-0.6097849357052837, 
           5.61462591275103}, {-0.4224912756798396, 
           5.611122701601299}, {-0.23563514990769913`, 
           5.60909846187573}, {-0.049142733745575984`, 5.608390365887517}, {
           0.13705979744981572`, 5.60883558594985}, {0.28542056080810474`, 
           5.6100053138172346`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.30903181994482204`, 5.610191473197728}, {
           0.32315180057023435`, 5.6103028000367825`}, {0.50922820670866, 
           5.612635481593677}, {0.695236201810213, 5.615632996140699}, {
           0.8811229718200172, 5.619094709198015}, {1.0667911582113265`, 
           5.622686922449431}, {1.2521790380348896`, 5.626182388647842}, {
           1.253372205303907, 5.626204032046522}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{1.2769803146191143`, 5.626632270178145}, {
           1.437287250602067, 5.629540149917043}, {1.622116435224219, 
           5.632719248380828}, {1.7514615517666785`, 5.634841541609208}, {
           1.8808691928927848`, 5.63687932028012}, {2.010211743270957, 
           5.6388133974397565`}, {2.1394032776016165`, 5.640594872490903}, {
           2.2213404355590045`, 5.641560842204941}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{2.2449507878817827`, 5.6418391882673395`}, {
           2.268680324381735, 5.64211893941027}, {2.397717884579183, 
           5.6433331757399054`}, {2.525076499410841, 5.644223515842474}, {
           2.6504225745373624`, 5.644803947570071}, {2.6753118041825656`, 
           5.6448863740690784`}, {2.700144772879996, 5.644958048088109}, {
           2.724929826696341, 5.645019351148483}, {2.73731141859625, 
           5.645047457556772}, {2.749683636841889, 5.645073089440062}, {
           2.7620475448841466`, 5.64509629427788}, {2.77440419194265, 
           5.645117119005608}, {2.7867546123791187`, 5.645135609976898}, {
           2.9504676597381465`, 5.6451989243515746`}, {3.1154539535144874`, 
           5.644960850768225}, {3.1894177347097608`, 5.644735265764894}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{3.213029617887624, 5.644663250967121}, {
           3.281545695513516, 5.644454281126077}, {3.4485750875406076`, 
           5.643712107324357}, {3.6139919104451055`, 5.6427318808146065`}, {
           3.775245945076352, 5.641511153048368}, {3.94316447955368, 
           5.6399433332225355`}, {4.10622578316494, 5.638159005636286}, {
           4.157479057303208, 5.637542581009933}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.181089342755732, 5.637258619416594}, {
           4.300925364158667, 5.635817348084002}, {4.497769684240274, 
           5.633370847951588}, {4.511165171754853, 5.633204522888802}, {
           4.52459225265028, 5.6330382511096655`}, {4.708790214235558, 
           5.630961462665957}, {4.8947447945226585`, 5.629154767213388}, {
           5.091504881055733, 5.627909624158604}, {5.125518026582742, 
           5.627694381155459}}]}, 
         {Arrowheads[{{0.010751539872707768`, 1.}}], 
          ArrowBox[{{5.149129546806153, 5.62754496202815}, {5.288264967588807,
            5.62666448110382}, {5.479390358358244, 5.625799304271432}, {
           5.6022633925459315`, 5.625750594099958}, {5.617489842670879, 
           5.625744557926102}, {5.635791991327913, 5.625598553883228}, {
           5.656854249492381, 5.6254493651111845`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           2.9680577375090733`}, {-5.537900620786775, 
           2.9679394186196726`}, {-5.390791521436865, 
           2.967381209716819}, {-5.241631097275321, 
           2.9662958450119956`}, {-5.092429913608952, 
           2.9645720937000606`}, {-4.9433831230886005`, 
           2.9621141523595895`}, {-4.794685878365107, 
           2.958826217569157}, {-4.71247972304672, 2.956477084017111}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.688877364866603, 
           2.955802620027236}, {-4.64645461348257, 
           2.9545903420869726`}, {-4.498805762485089, 
           2.949288578671245}, {-4.351739325372664, 
           2.942920927321974}, {-4.205255302145295, 
           2.9354873880391597`}, {-4.059353692802979, 
           2.926987960822802}, {-3.91403449734572, 
           2.9174226456729015`}, {-3.769297715773516, 
           2.906791442589458}, {-3.7458651534853757`, 2.9048900585506447`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7223305112545786`, 
           2.9029803914580508`}, {-3.625143348086367, 
           2.895094351572471}, {-3.459994993102521, 
           2.880309000855316}, {-3.2961920734136343`, 
           2.8641463723548912`}, {-3.133734589019707, 
           2.846606466071198}, {-2.9726225399207387`, 
           2.8276892820042354`}, {-2.813020948364825, 
           2.8075101738183554`}, {-2.7832182112605923`, 
           2.8034857374095288`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7598185965646587`, 
           2.8003259517493904`}, {-2.655094836600062, 
           2.78618449517791}, {-2.498844204626449, 
           2.763712246082899}, {-2.3442690524439866`, 
           2.740093426533322}, {-2.1914449950159436`, 
           2.715814444518382}, {-2.040447647305589, 
           2.691361708027282}, {-1.8912770093129236`, 
           2.666735217060021}, {-1.826505061609182, 2.6558331037547256`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8032205903492997`, 
           2.6519139697325373`}, {-1.7439330810379468`, 
           2.641934971616601}, {-1.5280508422518895`, 
           2.6057268343249236`}, {-1.316086702670539, 
           2.5711503858326705`}, {-1.1076359775731732`, 
           2.5394814445738136`}, {-0.9022939822390713, 
           2.511995828982325}, {-0.8698116206266996, 
           2.5084172757153573`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8463416284648215, 
           2.5058316072800118`}, {-0.6983778035535017, 
           2.4895305625669395`}, {-0.49420452840173384`, 
           2.4729226688363917`}, {-0.2880469010970844, 
           2.4615952328648927`}, {-0.07817766595286887, 2.454971339726655}, {
           0.09612170155322158, 2.451665461615768}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.11972944867283128`, 2.4512177013308816`}, {
           0.13645610527039, 2.4509004524004614`}, {0.35690734081217074`, 
           2.447232033865096}, {0.5825644157142534, 2.441488120003897}, {
           0.8128157050184173, 2.431190746700202}, {0.9526793363626976, 
           2.4225206872825287`}, {1.063270081304265, 2.413921059866232}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{1.0868110085691083`, 2.4120904979722986`}, {
           1.0929296261814803`, 2.411614709227074}, {1.2335665744747655`, 
           2.398472812533838}, {1.374590181242553, 2.38309499720282}, {
           1.5526269412234945`, 2.361443165095575}, {1.7295686959217236`, 
           2.338209091650943}, {1.9054154453372398`, 2.3133927768689238`}, {
           2.023906132109581, 2.2954931956091826`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.047253236296984, 2.291966307547634}, {
           2.0801671894700426`, 2.2869942207495177`}, {2.2541221058107315`, 
           2.260163261153105}, {2.427578371849904, 2.234049735940066}, {
           2.6005359875875618`, 2.2086536451104006`}, {2.7729949530237032`, 
           2.1839749886641093`}, {2.9002306745457167`, 2.1664793452140008`}, {
           2.981850521147467, 2.1558540901627494`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.005264948090616, 2.1528060048194413`}, {
           3.0275325105390154`, 2.1499072180630985`}, {3.196478809217161, 
           2.129279148895742}, {3.365992402722901, 2.1100916322490906`}, {
           3.536073291056235, 2.0923446681231446`}, {3.7067214742171624`, 
           2.076038256517904}, {3.72951715171924, 2.0739596704895957`}, {
           3.752324105147531, 2.071910531517031}, {3.903109130310809, 
           2.059803208447987}, {3.944737052440938, 2.056773076021401}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.968286738739913, 2.0550588740041253`}, {
           4.054412454609748, 2.0487897087163573`}, {4.246228194578173, 
           2.0355382371489372`}, {4.4388654843557775`, 2.0236488880839416`}, {
           4.632324323942562, 2.01312166152137}, {4.826604713338527, 
           2.0039565574612235`}, {4.911141183621914, 2.000481481005225}}]}, 
         {Arrowheads[{{0.01529940275889379, 1.}}], 
          ArrowBox[{{4.934733251856462, 1.999511671873198}, {5.0215912667607, 
           1.9959411627000967`}, {5.21716859842611, 1.9888630640345852`}, {
           5.413336708334756, 1.982722261464689}, {5.61009559648664, 
           1.9775187549904083`}, {5.656854249492381, 1.9764815248963117`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.7577127650736306`, 0.49673197998424057`}, {
           1.8999919421946265`, 0.4214792743053581}, {1.9121268306242032`, 
           0.41631480238387}, {1.9243788977881833`, 0.41127713514019093`}, {
           1.978963247769119, 0.3925801896452308}, {2.0360423633602465`, 
           0.3757313620839135}, {2.155809549875576, 0.34549494135570674`}, {
           2.286908953902008, 0.32153961904545214`}, {2.4291137681470873`, 
           0.302588693874438}, {2.595864204926353, 0.2866247280812693}, {
           2.667795742006976, 0.28157953897261456`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.6913498694525737`, 0.2799274815847792}, {
           2.773645434564275, 0.274155372359214}, {2.961164524139596, 
           0.26414465222487915`}, {3.1571500986218646`, 0.2561880590264252}, {
           3.3604255325452987`, 0.24977476343034916`}, {3.5699197289541886`, 
           0.24460334833726083`}, {3.6350214158381324`, 
           0.24332399799280513`}}]}, 
         {Arrowheads[{{0.01999999999999999, 1.}}], 
          ArrowBox[{{3.6586288508669558`, 0.24286007483533484`}, {
           3.784666029792575, 0.24038324641520237`}, {4.003854980159286, 
           0.23693944621670474`}, {4.2038348607855465`, 
           0.23439093189425417`}, {4.406480274664259, 0.23230001258019117`}, {
           4.603023074746668, 0.23063123729841062`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{4.62663436871719, 0.2304501060324932}, {
           4.817789972514166, 0.2290681583543014}, {5.025699377605151, 
           0.2277895142796949}, {5.234898264446576, 0.2267351561157359}, {
           5.4450927600098415`, 0.2258625475484215}, {5.571099931407548, 
           0.22542435543475778`}}]}, 
         {Arrowheads[{{0.0012975944078844042`, 1.}}], 
          ArrowBox[{{5.5947117816354055`, 0.22534224481800408`}, {
           5.65598899126635, 0.22512915226374897`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.0079662100114303, 1.}}], 
          ArrowBox[{{1.2465475373954231`, 0.23451346588845512`}, {
           1.1969844215276775`, 0.19337482154848873`}, {1.1831382636584906`, 
           0.18380448669024405`}, {1.1681704329125082`, 
           0.17434909675843036`}, {1.1506116751629523`, 
           0.16510299431074194`}, {1.1313412020538707`, 0.1558608639736281}, {
           1.088674447334063, 0.13732422242643816`}, {1.038389697248501, 
           0.11910469206653297`}, {0.9909837589584973, 
           0.10414131909640267`}, {0.9588017448862555, 0.09495236942351498}, {
           0.9409274428966194, 0.09019726195034565}, {0.9308336826879344, 
           0.08760761614452484}, {0.9239348402749168, 0.08586634556801093}, {
           0.9191469418242394, 0.08467099911090714}, {0.9120236421935589, 
           0.0829129330971012}, {0.9076078819553174, 0.08183564422159398}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.005497814140738653, 1.}}], 
          ArrowBox[{{1.2543222313111086`, -0.28709111923755}, {
           1.2118505455264483`, -0.23683740546451082`}, {
           1.2004930651121308`, -0.22607289311821718`}, {
           1.1880202280810217`, -0.2153649698212542}, {
           1.1745471482101313`, -0.2057533689721752}, {
           1.1599834677686707`, -0.19619878143900965`}, {
           1.1283107963327643`, -0.17716417140176977`}, {
           1.0908129473680797`, -0.1581690560556317}, {
           1.0459284547119014`, -0.13904355247366276`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           1.76182679283215}, {-5.581802186393281, 
           1.7617870994063092`}, {-5.3859346810288535`, 
           1.761033147554613}, {-5.19012744784314, 
           1.7594543240292349`}, {-4.982819058783855, 
           1.7565417107629449`}, {-4.776127092975173, 
           1.7521140203249694`}, {-4.712476695619203, 1.750278482176902}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688874514597044, 
           1.7495978469343365`}, {-4.570051550417092, 
           1.746171252715309}, {-4.364592431109612, 
           1.7387134079339635`}, {-4.33728301794071, 
           1.737619787139153}, {-4.3099908436742895`, 
           1.7364927368121144`}, {-4.142736358054244, 
           1.7280144498405792`}, {-3.9761615764927183`, 
           1.7181090784402797`}, {-3.768656374882312, 
           1.7043394214326837`}, {-3.7456639272697645`, 
           1.7024943301885267`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7221275960523634`, 
           1.7006055935311424`}, {-3.562183024422319, 
           1.6877704080981655`}, {-3.356741525112739, 
           1.6684020384367244`}, {-3.1523318769535726`, 
           1.6462343124483612`}, {-2.9487847286077815`, 
           1.6206188950271967`}, {-2.7836389865006894`, 
           1.5964304715059472`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7602762596101185`, 
           1.5930085998583332`}, {-2.7459307287383306`, 
           1.5909074510673522`}, {-2.5437698773452184`, 
           1.5570999805688277`}, {-2.3423021744284456`, 
           1.5191964835316234`}, {-2.2073015872306967`, 
           1.490920108818532}, {-2.072227040198864, 
           1.4597104127593392`}, {-1.9370785333329468`, 
           1.4255673953540446`}, {-1.8367295042481278`, 
           1.3980529246708795`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8139579707066795`, 
           1.3918092499911046`}, {-1.801856066632946, 
           1.3884910566026487`}, {-1.5801061525677933`, 
           1.31952875942248}, {-1.3557761273650302`, 
           1.2382846146425197`}, {-1.1956495862982779`, 
           1.1726682544431735`}, {-1.030790822607171, 
           1.098023774837622}, {-0.9348144660964062, 
           1.0505014970874305`}}]}, 
         {Arrowheads[{{0.011211446363170943`, 1.}}], 
          ArrowBox[{{-0.9136543301182264, 
           1.0400241472927017`}, {-0.8371297720763254, 
           1.0021333434094557`}, {-0.6891710438062552, 
           0.9282028460800987}, {-0.6485176002221841, 
           0.9087603903778948}, {-0.6054111548407679, 
           0.8889149227016621}, {-0.561694598413751, 
           0.8695151627679686}, {-0.5123544173079908, 
           0.848187709770835}, {-0.5032573026902777, 
           0.8443143312593712}, {-0.49607893521470936`, 
           0.8412529602998012}, {-0.49086077823740243`, 
           0.8390177258656805}, {-0.48492318644182547`, 
           0.8364643265613076}, {-0.47987539748661084`, 
           0.8342835136241603}, {-0.46977921721618393`, 
           0.8299066174828997}, {-0.4629473833789586, 
           0.8269367037752509}, {-0.4568703900660728, 
           0.8242892457565866}, {-0.4456485691200619, 
           0.8193876414194625}, {-0.43901345180496687`, 
           0.8164793307594125}, {-0.43475117431346316`, 
           0.8146070852343086}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           0.3429233473206922}, {-5.460679344666343, 
           0.3427690665419659}, {-5.431686763522379, 
           0.34273266338218805`}, {-5.40269841826247, 
           0.3426921162780327}, {-5.200502491892003, 
           0.34214661455735135`}, {-4.998663160124363, 
           0.3413243687483502}, {-4.87011350268417, 
           0.34071171536185785`}, {-4.741712267998219, 
           0.3399217217819998}, {-4.712381776493987, 0.33970049953673315`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688770455084178, 
           0.3395224135494855}, {-4.6134594560665105`, 
           0.33895438800877603`}, {-4.485355066889044, 
           0.3378097140421865}, {-4.35739910046582, 
           0.33648769988223126`}, {-4.229591556796837, 
           0.33498834552891027`}, {-4.101932435882096, 
           0.3333116509822235}, {-3.974421737721598, 
           0.331457616242171}, {-3.8467723615921567`, 
           0.32933246439163855`}, {-3.7443751435898123`, 
           0.3273416507090504}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.7207676119230837`, 
           0.3268826714714194}, {-3.7186972067705875`, 
           0.3268424185135119}, {-3.5901962732568897`, 
           0.32398747860779115`}, {-3.4612695610510644`, 
           0.32076764467447616`}, {-3.331917070153111, 
           0.317182916713567}, {-3.20213880056303, 
           0.3132332947250637}, {-3.0719347522808205`, 
           0.3089187787089663}, {-2.9413049253064827`, 
           0.3042393686652746}, {-2.8096433546051722`, 
           0.29906147558556867`}, {-2.776758191495476, 
           0.29762814712694147`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7531685947757434`, 
           0.29659997402063376`}, {-2.676344075142044, 
           0.2932515104614283}, {-2.5408608195560616`, 
           0.2867003793414317}, {-2.402647320486191, 
           0.2792989882741573}, {-2.2609142084658274`, 
           0.2708986296993342}, {-2.1142406184550864`, 
           0.2612316300084754}, {-1.9924533815313608`, 
           0.2524982840026641}, {-1.8650818439234, 
           0.2426025289365651}, {-1.810572916042526, 0.23803215252205814`}}]}, 
         {Arrowheads[{{0.00421417877154381, 1.}}], 
          ArrowBox[{{-1.7870434866723375`, 
           0.23605929498805317`}, {-1.7309306452640543`, 
           0.2313544362264966}, {-1.588804425186176, 
           0.21856407728877703`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -0.3429844633262989}, \
{-5.468333520938055, -0.3428423927624183}, {-5.439339217417055, \
-0.3428070557037541}, {-5.4103490684448134`, -0.3427676066057647}, \
{-5.207908407513919, -0.34223068764477466`}, {-5.005822598018904, \
-0.341417981072502}, {-4.877190531772433, -0.34081199228000486`}, \
{-4.748707783368345, -0.34002923764450393`}, {-4.712381804781997, \
-0.3397576363929613}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-4.688770471737519, -0.33958109971439043`}, \
{-4.620374352806638, -0.3390697171659993}, {-4.492190240087313, \
-0.3379334308444909}, {-4.36415544521037, -0.3366203786799788}, \
{-4.236269968175809, -0.3351305606724629}, {-4.10853380898363, \
-0.33346397682194323`}, {-3.9809469676338325`, -0.33162062712841983`}, \
{-3.853225548842016, -0.32950712800177673`}, {-3.744375118256316, \
-0.3274029743858002}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.7207677828122714`, -0.3269346901267913}, \
{-3.596527293079126, -0.32418953067878326`}, {-3.467550456108052, \
-0.32098543248243294`}, {-3.3381551464105588`, -0.31741780126284685`}, \
{-3.2083413639866456`, -0.31348663702002505`}, {-3.0781091088363133`, \
-0.3091919397539675}, {-2.947458380959562, -0.3045337094646743}, \
{-2.81578850428958, -0.2993792857845907}, {-2.7767582456689444`, \
-0.29768581050851395`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7531684471443194`, -0.2966622779473445}, \
{-2.6824988027595555`, -0.29359600834616223`}, {-2.5470482974882893`, \
-0.2870756946723538}, {-2.4088960095945784`, -0.2797101622861302}, \
{-2.2672616444730878`, -0.2713521011318058}, {-2.1207406718342123`, \
-0.26173635310914606`}, {-1.998627297137852, -0.25301399331962565`}, \
{-1.8709469997445516`, -0.24312745258402982`}, {-1.8105738438480017`, \
-0.23807937195363876`}}]}, 
         {Arrowheads[{{0.0010738857526330478`, 1.}}], 
          ArrowBox[{{-1.787043961119242, -0.236111928915843}, \
{-1.7365071494721587`, -0.23188631082103112`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, -1.0000294034236679`}, \
{-5.465958664868487, -0.9997648178342348}, {-5.437250067640607, \
-0.9996872695340837}, {-5.4085480546495415`, -0.9995981056526981}, \
{-5.206283246765347, -0.9982252809353738}, {-5.004492132091208, \
-0.9960791702206541}, {-4.790812506438952, -0.9931844030506859}, \
{-4.712425380066083, -0.9916638733872546}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-4.688817828064488, -0.9912059412654841}, \
{-4.577782057815465, -0.9890521031267764}, {-4.365400786220748, \
-0.9836822704489255}, {-4.153668691654799, -0.9770749050171335}, \
{-3.942372475148983, -0.9688277255742404}, {-3.744925286683211, \
-0.9592027037668913}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.721346480118926, -0.9579563992248196}, \
{-3.520447779411844, -0.9462070808836718}, {-3.3098193001805205`, \
-0.9318336156359964}, {-3.148884596412832, -0.91907590600167}, \
{-2.9870314293916396`, -0.904272990878167}, {-2.824259799116944, \
-0.8874248702654878}, {-2.780043478751247, -0.8823213643557101}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.756587211955071, -0.8796140111606559}, \
{-2.660569705588744, -0.868531544163632}, {-2.537492504642166, \
-0.8526962755026989}, {-2.4126406765614075`, -0.8348406078985702}, \
{-2.286014221346467, -0.8149645413512461}, {-2.157613138997347, \
-0.7930680758607265}, {-1.955906646400593, -0.7543492475750723}, \
{-1.8252282023748356`, -0.7256619235915254}}]}, 
         {Arrowheads[{{0.012972044931321395`, 1.}}], 
          ArrowBox[{{-1.8021653887516813`, -0.7205990349773238}, \
{-1.7447085942893483`, -0.7079857712513482}, {-1.5998374076864261`, \
-0.6727030281141038}, {-1.4462554734538517`, -0.6321671390879803}, \
{-1.2096265311162981`, -0.5655787636557476}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           0.9997273144154485}, {-5.458255183096332, 
           0.9994336074891882}, {-5.429548597515654, 
           0.9993530157331736}, {-5.400848674983862, 
           0.9992607239685257}, {-5.198829858896242, 
           0.9978634546687941}, {-4.9972864537424435`, 
           0.9956906192854315}, {-4.783693564975746, 
           0.9927635326120847}, {-4.712425263843086, 0.9913683197201587}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688817794255453, 
           0.9909061584873112}, {-4.570749761979473, 
           0.9885947516186507}, {-4.358455044753624, 
           0.9831842763051293}, {-4.1468094132982, 
           0.9765321066715204}, {-3.9355952086777624`, 
           0.9682345784984112}, {-3.744926161266092, 0.9588849911664449}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-3.7213442126396115`, 
           0.9576968743602629}, {-3.5138081031355286`, 
           0.9454924538754538}, {-3.303235202213733, 
           0.9310478574256056}, {-3.1427646242374627`, 
           0.9182661552942932}, {-2.9813670619208223`, 
           0.9034418709256636}, {-2.8190425152638108`, 
           0.8865750043197168}, {-2.7800402010106695`, 0.8820573605240791}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7565850283693383`, 
           0.8793405444277064}, {-2.655790984266429, 
           0.8676655554764527}, {-2.532955333866675, 
           0.8518101346978719}, {-2.408338668716762, 
           0.833935184597496}, {-2.28194098881669, 
           0.8140407051753252}, {-2.153762294166459, 
           0.7921266964313594}, {-1.9526487060114424`, 
           0.7534392466975955}, {-1.8252210784048235`, 0.7254195764253294}}]}, 
         {Arrowheads[{{0.004454551944054401, 1.}}], 
          ArrowBox[{{-1.8021600090760437`, 
           0.7203487486083583}, {-1.7420462121398739`, 
           0.7071305101415382}, {-1.5974704113007354`, 
           0.6718773019327381}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.7753052586586193`, -0.48671792094081234`}, {
           1.9256807024794291`, -0.4118650562743317}, {
           1.9380732780262042`, -0.4069555979586599}, {
           1.9505874475821208`, -0.4021663146085092}, {
           2.007641717516292, -0.3840411783657249}, {
           2.06735290912148, -0.36774176629545885`}, {
           2.1928474694875026`, -0.3386553489658713}, {
           2.3302952769248426`, -0.3158125300757575}, {
           2.4790962255838473`, -0.2978047789536775}, {
           2.66100130859448, -0.28214089439538564`}, {
           2.6883447704071393`, -0.2804395953839267}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.71191119139023, -0.2789733023082052}, {
           2.8548902004821097`, -0.2700772068359495}, {
           3.059184442607729, -0.2604857595614404}, {
           3.2724055402532617`, -0.2529498846329599}, {
           3.493190312592236, -0.24693181576046647`}, {
           3.6556379411642927`, -0.2434965857237611}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{3.6792446564960404`, -0.24299738177545846`}, {
           3.7203408746502493`, -0.24212833269028997`}, {
           3.952778478408784, -0.2382432204240955}, {
           4.189626160731242, -0.2351045422370689}, {
           4.401363011183024, -0.23284318115102537`}, {
           4.6155890604453305`, -0.23100369056165362`}, {
           4.623641755208768, -0.23094721742573596`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{4.64725316759212, -0.23078163180006597`}, {
           4.831800197444658, -0.22948741293219266`}, {
           5.049492311107506, -0.22819569072588153`}, {
           5.267692805657298, -0.22709866805226062`}, {
           5.485161379772844, -0.22620580424732822`}, {
           5.591719319702273, -0.22584619091818867`}}]}, 
         {Arrowheads[{{0.0008792842628268401, 1.}}], 
          ArrowBox[{{5.615331178238458, -0.22576650526490938`}, {
           5.656854249492381, -0.2256263725831063}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-5.516267442448932, -2.4284388025599157`}, \
{-5.375751238948935, -2.4276439293465666`}, {-5.23542282460658, \
-2.4261575117330447`}, {-5.095282199421865, -2.42397954971935}, \
{-4.955329363394792, -2.4211100433054824`}, {-4.815564316525361, \
-2.417548992491442}, {-4.675987058813569, -2.4132963972772288`}, \
{-4.572019687971175, -2.4096086782399344`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.548422534314325, -2.408771688018279}, \
{-4.5365975902594196`, -2.4083522576628424`}, {-4.397395910862912, \
-2.402716573648284}, {-4.25860752686448, -2.3962055043035004`}, \
{-4.120457944504558, -2.38863520869844}, {-3.9829471637831473`, \
-2.3800056868331034`}, {-3.846075184700248, -2.3703169387074907`}, \
{-3.709842007255858, -2.359568964321601}, {-3.6058540071949925`, \
-2.3505139635207573`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.582331026893823, -2.348465644432587}, \
{-3.5742476314499805`, -2.347761763675435}, {-3.4392920572826133`, \
-2.3348953367689926`}, {-3.304975284753757, -2.3209696836022737`}, \
{-3.1583281788576416`, -2.304327408291144}, {-3.0127140320904355`, \
-2.286151784487944}, {-2.868132844452138, -2.266442812192674}, \
{-2.7245846159427503`, -2.245200491405334}, {-2.645184462790011, \
-2.2325654542051088`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.6218658691075767`, -2.2288547397173457`}, \
{-2.582192276421911, -2.222541435529057}, {-2.4410787557492597`, \
-2.1985822579669776`}, {-2.3012440539247976`, -2.173322958719095}, \
{-2.1626881709485244`, -2.1467635377854095`}, {-2.025569711124279, \
-2.118929337158975}, {-1.8900472787559015`, -2.089845698832846}, \
{-1.7561208738433918`, -2.059512622807022}, {-1.6956628186829728`, \
-2.0450834539825946`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.6726958724450776`, -2.039602067858466}, \
{-1.6237904963867504`, -2.0279301090815034`}, {-1.5449020810943805`, \
-2.008448292495101}, {-1.4665991465298864`, -1.9887843736210746`}, \
{-1.3009825038172373`, -1.946171076643459}, {-1.1388079905076827`, \
-1.9030843284848844`}, {-0.9796847692897149, -1.8606651093703952`}, \
{-0.8232220028518268, -1.8200543995250358`}, {-0.803644465478632, \
-1.8150434932663129`}, {-0.784112713551054, -1.8100813479578641`}, \
{-0.7581746733719208, -1.8037137724659555`}}]}, 
         {Arrowheads[{{0.001364150224392406, 1.}}], 
          ArrowBox[{{-0.7352435576983871, -1.798084372204544}, \
{-0.728115759182763, -1.7963345563038091`}, {-0.6725833227271818, \
-1.7831281681094604`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.328257874466412, 
           2.1821949574248136`}, {-2.1323477214123447`, 
           2.1446216023080154`}, {-1.9393825143502759`, 
           2.1044002554064707`}, {-1.749645834209808, 
           2.061400763486396}, {-1.666998635684499, 
           2.041648821477996}, {-1.584959536272738, 
           2.021613971030483}, {-1.417345232770964, 
           1.9796121558697692`}, {-1.4065838017226215`, 
           1.9768230228898669`}}]}, 
         {Arrowheads[{{0.01332921109253634, 1.}}], 
          ArrowBox[{{-1.3837270181156753`, 
           1.970899032977536}, {-1.2527780591188755`, 
           1.9369598608933445`}, {-1.0912826326763192`, 
           1.8944004896548223`}, {-0.9328835708031411, 
           1.8526774457078163`}, {-0.9129752516461808, 
           1.8474348181756362`}, {-0.8931059932206425, 
           1.8422293792138094`}, {-0.8336298558400463, 
           1.8270328011011612`}, {-0.774581618745538, 
           1.8123018837551028`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.805429801688043, 
           4.2781446290895895`}, {-2.68092640632109, 
           4.265985469833054}, {-2.5571170213059546`, 
           4.253705265693085}, {-2.433978033446467, 
           4.241418538084642}, {-2.2618228607785342`, 
           4.224514128978667}, {-2.090987181297308, 
           4.20840680760675}, {-1.9213486701670672`, 
           4.19327265586802}, {-1.8652724057725723`, 4.187954290432871}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8417658959079852`, 
           4.1857248942540295`}, {-1.7540898007997705`, 
           4.1774095487375735`}, {-1.5874776380227225`, 
           4.163311979786389}, {-1.4218179939252222`, 
           4.150539744266648}, {-1.2571108685072698`, 
           4.139092842178349}, {-1.0933562617688646`, 
           4.128971273521492}, {-0.9301776436766701, 
           4.120280492550601}, {-0.8997369880770748, 4.118944193729979}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8761477133190185, 
           4.1179086601838835`}, {-0.7671984841973468, 
           4.1131259535202025`}, {-0.6044187833308967, 
           4.107507656430294}, {-0.4418385410773193, 
           4.103425601280877}, {-0.19821971089372797`, 4.099280851349234}, {
           0.046702915886282004`, 4.09675765372147}, {0.06803036101724004, 
           4.096644292072993}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.09164202047508503, 4.0965187891530235`}, {
           0.1696531529999437, 4.096104137021544}, {0.29292933926271075`, 
           4.095856008397586}, {0.41653147467458235`, 4.096013267849599}, {
           0.5404595592355578, 4.096575915377581}, {0.6646895577041692, 
           4.0971743272262495`}, {0.7891974348389474, 4.09743887964032}, {
           0.9139831906398923, 4.097369572619793}, {1.0361166352353535`, 
           4.096975852190031}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{1.0597282554696363`, 4.0968447964183605`}, {
           1.1643883382402804`, 4.096229380274943}, {1.2900077300397244`, 
           4.0951584949506215`}, {1.4159050005053346`, 4.093753750191701}, {
           1.5420801496371122`, 4.092015145998184}, {1.6751749893105614`, 
           4.0896992483723125`}, {1.8082398328119256`, 4.086767660313989}, {
           1.941274680141204, 4.083220381823215}, {2.0040513239516122`, 
           4.081255512008216}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.027651759684481, 4.08051683308278}, {2.074279531298397,
            4.079057412899988}, {2.2072693843695474`, 4.074586598760535}, {
           2.3402592374406974`, 4.070115784621083}, {2.473249090511848, 
           4.065644970481631}, {2.605414640086875, 4.057873178465848}, {
           2.770514209463292, 4.050250293983379}, {2.9356137788397088`, 
           4.04262740950091}, {2.9712652018345675`, 4.040981332045034}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{2.99485206695821, 4.039892292571338}, {
           3.1007133482161255`, 4.035004525018442}, {3.2641890937168636`, 
           4.02470600172812}, {3.4083717323553846`, 4.016795221145927}, {
           3.5524156177214037`, 4.008927478115479}, {3.6949107405972046`, 
           4.0013214857970825`}, {3.837315751502251, 3.993912100207571}, {
           3.9379387516051105`, 3.988812342884412}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.9615204774573085`, 3.9876171779719716`}, {
           3.9796306504365435`, 3.9866993213469444`}, {4.1218554374000815`, 
           3.979683149215203}, {4.140913950880302, 3.9787558419664912`}, {
           4.159971693590173, 3.9778323687386767`}, {4.323100385781881, 
           3.9702461592808618`}, {4.486204715174063, 3.962955711159343}, {
           4.702178507414788, 3.953682410978416}, {4.905063415462625, 
           3.945685826507315}}]}, 
         {Arrowheads[{{0.01542726877591519, 1.}}], 
          ArrowBox[{{4.9286586526231915`, 3.944797663001997}, {
           5.1339551415186095`, 3.9375203703303026`}, {5.349647697437144, 
           3.9308266682305995`}, {5.557258143110527, 3.925112451032942}, {
           5.656854249492381, 3.9226627024490917`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.805199345428574, -4.277430804550784}, \
{-2.68075407628618, -4.265274466992066}, {-2.5570024121486346`, \
-4.252997183460846}, {-2.4339207564331082`, -4.240713369391828}, \
{-2.2617963381272035`, -4.223808061197469}, {-2.090991154566093, \
-4.2076997599918196`}, {-1.9213829787752204`, -4.192564440443383}, \
{-1.865043901449429, -4.187220107938854}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.8415374324328817`, -4.184990281104713}, \
{-1.7541533381753007`, -4.176701014089938}, {-1.587570683960113, \
-4.1626024554019825`}, {-1.42194058356605, -4.149828827708253}, \
{-1.257263036993111, -4.13838013100875}, {-1.0935380442412959`, \
-4.128256365303471}, {-0.9303891167164656, -4.119563172210465}, \
{-0.8995087624544157, -4.118206860930204}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8759195114774981, -4.117170785795788}, \
{-0.7674397658244809, -4.112406193347774}, {-0.6046899915653419, \
-4.1067854287154}, {-0.4421397939390477, -4.102700878313343}, \
{-0.1985865370829684, -4.098552871750305}, {
           0.04627069917274629, -4.096026565168367}, {
           0.06825861907399217, -4.09590939371625}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.0918702768220033, -4.095783569525619}, {
           0.1691883095754667, -4.095371549370312}, {
           0.2924319148280957, -4.095121958567533}, {
           0.41600151493063353`, -4.095277792760028}, {
           0.5398971098830795, -4.095839051947799}, {
           0.6640948165647699, -4.096436257689014}, {
           0.788570751855041, -4.096699931541844}, {
           0.9133249157538923, -4.096630073506286}, {
           1.0363449017721151`, -4.096233176175857}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.059956510813479, -4.096099663834552}, {
           1.1636679293773355`, -4.095489761770012}, {
           1.2892567791019274`, -4.094419308069296}, {
           1.4151238574350997`, -4.093015322480193}, {
           1.5412691643768512`, -4.091277805002704}, {
           1.6744685078988333`, -4.088960519215549}, {
           1.8076378848520487`, -4.086026225248916}, {
           1.9407772952364977`, -4.082474923102805}, {
           2.0042791179453214`, -4.080486369205327}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.027879542211972, -4.0797473240306275`}, {
           2.0738867390521807`, -4.078306612777218}, {
           2.2069811995834803`, -4.073829798361891}, {
           2.3400756601147794`, -4.0693529839465645`}, {
           2.4731701206460786`, -4.064876169531238}, {
           2.60543870994372, -4.05709257102667}, {
           2.7695470641231488`, -4.049510369257656}, {
           2.9336554183025774`, -4.041928167488641}, {
           2.9714915840559897`, -4.040180045375402}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.9950784155080954`, -4.039090276874244}, {
           3.097763772482006, -4.034345965719627}, {
           3.260265610918574, -4.024115059660336}, {
           3.4043151568351617`, -4.016208147188081}, {
           3.5482268963617267`, -4.0083399929144115`}, {
           3.6907418473414673`, -4.000725004404608}, {
           3.833166072261309, -3.993306462570715}, {
           3.938163624681827, -3.9879788178418907`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.961745280361057, -3.986782269154039}, {
           3.9754995711212517`, -3.9860843674127318`}, {
           4.117742343921297, -3.979058718930659}, {
           4.136802971847735, -3.9781301431332956`}, {
           4.155862822856086, -3.977205400066517}, {
           4.318861291682557, -3.969614848986718}, {
           4.481835198864498, -3.9623194719814956`}, {
           4.697247411538412, -3.953052969245333}, {
           4.905287387349439, -3.944830495798853}}]}, 
         {Arrowheads[{{0.0154225183547181, 1.}}], 
          ArrowBox[{{4.928883369134511, -3.9439621659178994`}, {
           5.127925425032827, -3.9368819392117573`}, {
           5.343126193721378, -3.9301764447107947`}, {
           5.5504948083454675`, -3.924445513924053}, {
           5.656854249492381, -3.9218199058707612`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           5.334588510328588}, {-5.566502491562625, 
           5.334377236897617}, {-5.427420872622804, 
           5.333783736503849}, {-5.288751237301512, 
           5.33292291965215}, {-5.150493585598749, 
           5.331794786342517}, {-5.012647917514517, 
           5.330399336574952}, {-4.875214233048812, 
           5.328736570349454}, {-4.738063802767328, 
           5.326654170806306}, {-4.712421059300064, 5.326157332534451}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688813497095527, 
           5.325699926702528}, {-4.601067897235761, 
           5.323999821085793}, {-4.464226516454106, 
           5.320773521187913}, {-4.327539660422366, 
           5.316975271112668}, {-4.1910073291405405`, 
           5.312605070860055}, {-4.0546295226086295`, 
           5.307662920430077}, {-3.918406240826634, 
           5.302148819822732}, {-3.782337483794553, 
           5.296062769038022}, {-3.744892156595687, 5.294245272000567}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.721307927997137, 
           5.29310055598885}, {-3.6466110268236718`, 
           5.289474966182442}, {-3.511414645225277, 
           5.28245560936249}, {-3.3767483389993687`, 
           5.275004698578167}, {-3.2426121081459462`, 
           5.267122233829473}, {-3.1090059526650102`, 
           5.258808215116406}, {-2.97592987255656, 
           5.2500626424389685`}, {-2.8433838678205965`, 
           5.240885515797158}, {-2.7785698819989677`, 5.236168078351721}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-2.7550201844247604`, 
           5.234454031240484}, {-2.711367938457121, 
           5.231276835190978}, {-2.5005137814057297`, 
           5.215577270424165}, {-2.2914229489477904`, 
           5.200056192800811}, {-2.0840954410833032`, 
           5.184713602320913}, {-1.8785312578122682`, 
           5.169549498984472}, {-1.8131005839382102`, 5.1649676056262965`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7895462723872921`, 
           5.163318175209925}, {-1.6744525247955655`, 
           5.155258541303766}, {-1.4715813676940752`, 
           5.142535387791071}, {-1.2699177865077975`, 
           5.131380038446387}, {-1.0694617812367326`, 
           5.121792493269713}, {-0.8698394241107239, 
           5.113851253936922}, {-0.846453713845665, 5.113121319469124}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.822853214341733, 
           5.112384680818857}, {-0.6706767873596153, 
           5.107634822123883}, {-0.4719738709834068, 
           5.103143197830596}, {-0.27373067498209824`, 
           5.100376381057061}, {-0.12641825541341958`, 5.099205550995677}, {
           0.02095924731983345, 5.098526018653828}, {0.12147602772611445`, 
           5.0983976925119565`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.14508800148186046`, 5.098367547958163}, {
           0.1684018332176599, 5.098337784031515}, {0.3159095022800599, 
           5.0986408471287366`}, {0.4634822545070333, 5.099435207945494}, {
           0.6111200898985792, 5.100720866481787}, {0.7588230084546987, 
           5.1024978227376145`}, {0.9065910101753918, 5.104766076712979}, {
           1.0895102979250693`, 5.10755507729385}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1131195467901305`, 5.1079150514092575`}, {
           1.1270955106802862`, 5.108128145238166}, {1.3474096501295039`, 
           5.110710100136647}, {1.5675334285230431`, 5.112511941408419}, {
           1.7874668458609042`, 5.113533669053485}, {2.007209902143088, 
           5.113775283071844}, {2.0575724812515537`, 5.11365175815179}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.0811844032273545`, 5.113593844899015}, {
           2.2267625973695933`, 5.1132367834634955`}, {2.44612493154042, 
           5.1119181702284395`}, {2.6652969046555706`, 5.109819443366677}, {
           2.884096064976714, 5.1071655068231925`}, {3.025620348870783, 
           5.105230319815336}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{3.0492301347499993`, 5.104907482280782}, {
           3.1023399607655224`, 5.104181264542972}, {3.320028592021996, 
           5.100866716526015}, {3.537161958746135, 5.097221862772323}, {
           3.7537400609379388`, 5.0932467032818955`}, {3.9697628985974083`, 
           5.088941238054731}, {3.9935641810684785`, 
           5.0884291549947065`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.017170711056265, 5.087921262021822}, {
           4.185230471724543, 5.084305467090831}, {4.400142780319341, 
           5.079339390390196}, {4.582855144994554, 5.075108371283874}, {
           4.7653000001203445`, 5.071163280717921}, {4.961424233511398, 
           5.067286814234335}}]}, 
         {Arrowheads[{{0.014227976344979914`, 1.}}], 
          ArrowBox[{{4.98503161561713, 5.066820205779501}, {5.002256254791619,
            5.0664797545497}, {5.238789457269202, 5.062314474655148}, {
           5.2546900510620045`, 5.062051654025035}, {5.270588725508067, 
           5.061791249551395}, {5.468570821768851, 5.058954239122002}, {
           5.656854249492381, 5.056621052750075}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, -4.847796740102592}, \
{-5.54025445255888, -4.847885594666024}, {-5.400633793870968, \
-4.847703483263112}, {-5.260886113351466, -4.847155017062304}, \
{-5.121046305028505, -4.846187129127026}, {-4.981149262930212, \
-4.844746752520706}, {-4.841306668635496, -4.842734841871164}, \
{-4.712424760504179, -4.84025966154404}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688818457899753, -4.839744427137075}, \
{-4.562119868193516, -4.83669928232588}, {-4.42277566204625, \
-4.832675633430138}, {-4.283597585281469, -4.827981405118995}, \
{-4.144585637899173, -4.822616597392452}, {-4.005739819899359, \
-4.816581210250509}, {-3.867060131282029, -4.809875243693165}, \
{-3.745079514203624, -4.803426767248633}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.721502103242367, -4.802150104994724}, \
{-3.5911697414624006`, -4.794719120653057}, {-3.4542016900769967`, \
-4.786335851250486}, {-3.317885067707865, -4.777415776592906}, \
{-3.182219874355007, -4.767958896680315}, {-3.047206110018423, \
-4.757965211512713}, {-2.9128437746981124`, -4.747434721090101}, \
{-2.7793489980198034`, -4.73638531453266}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.755821275991388, -4.734392203835716}, \
{-2.586081174614762, -4.720009904038724}, {-2.3946513204586903`, \
-4.7038880456250824`}, {-2.204843305925857, -4.688001850171553}, \
{-2.0166571310162635`, -4.672351317678134}, {-1.8299162760469545`, \
-4.657408856804252}, {-1.8145798054483144`, -4.656270894478332}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.791032544414572, -4.6545236935325445`}, \
{-1.6444442213349726`, -4.6436468762093295`}, {-1.4602409668803191`, \
-4.631065375893367}, {-1.2773065126829946`, -4.619664355856363}, \
{-1.095286194401933, -4.609679549876133}, {-0.9138253476960703, \
-4.60134669173049}, {-0.8482494854126796, -4.598924894471243}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8246535783463392, -4.5980534685978665`}, \
{-0.7329239725654073, -4.594665781419434}, {-0.5525820690099428, \
-4.589636818942965}, {-0.42372157758733264`, -4.586885695420012}, \
{-0.29471456562552817`, -4.58464459567755}, {-0.16556103312452913`, \
-4.582913519715579}, {-0.03626098008433565, -4.581692467534097}, {
           0.09318559349505229, -4.580981439133106}, {
           0.11962532319280256`, -4.580940429942993}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.14323728778868663`, -4.580903806741617}, {
           0.22277868761363462`, -4.580780434512605}, {
           0.35251830227141157`, -4.581089453672595}, {
           0.48240443746838346`, -4.581908496613075}, {
           0.6591753253732249, -4.583153453529944}, {
           0.8361908324143579, -4.583968485230479}, {
           1.0134509585917826`, -4.584353591714684}, {
           1.0877072807256307`, -4.5843348425020665`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.1113192729709351`, -4.584328880635788}, {
           1.1909557039054999`, -4.584308772982556}, {
           1.3687050683555082`, -4.583834029034096}, {
           1.546699051941809, -4.582929359869304}, {
           1.7249376546644015`, -4.58159476548818}, {
           1.9034208765232854`, -4.579830245890725}, {
           2.055770116454363, -4.57790039612458}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.0793802152916907`, -4.577601320502407}, {
           2.0818965777418446`, -4.577569445046461}, {
           2.260112618543462, -4.574746006924912}, {
           2.438068998928138, -4.571359931526079}, {
           2.615765718895872, -4.567411218849961}, {
           2.793202778446664, -4.562899868896558}, {
           2.9703801775805143`, -4.557825881665871}, {
           3.023604302781764, -4.5561301534099}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.047204320997497, -4.555378253447646}, {
           3.147297916297422, -4.552189257157899}, {
           3.3239559945973887`, -4.545989995372643}, {
           3.470187863124243, -4.540534956140119}, {
           3.616248231784011, -4.534926622540975}, {
           3.7479878300994134`, -4.5298309334993965`}, {
           3.8795981048578723`, -4.524797755886039}, {
           3.9910408382618976`, -4.520584638917772}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.0146360343526934`, -4.519694177758782}, {
           4.1424306837039575`, -4.514918934943981}, {
           4.160048738636474, -4.51426447945657}, {
           4.1776648095544875`, -4.513612797487696}, {
           4.341236878849189, -4.507827567736034}, {
           4.504667077245217, -4.502297616300419}, {
           4.726571533536334, -4.495032184921509}, {
           4.948258350963945, -4.488260318887523}, {
           4.9585801480739, -4.487969368670547}}]}, 
         {Arrowheads[{{0.01429105049027691, 1.}}], 
          ArrowBox[{{4.982182766084872, -4.487304059445967}, {
           5.169716036438878, -4.482017882521693}, {
           5.390933096871961, -4.476340740147251}, {
           5.498175565626508, -4.473911873959115}, {
           5.60028245708503, -4.471751667929087}, {
           5.656854249492381, -4.47062532339398}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-5.656854249492381, 
           4.848323351313337}, {-5.539728563578836, 
           4.848411774453421}, {-5.400046151362289, 
           4.848227983527988}, {-5.260236598451636, 
           4.847677417792239}, {-5.1203348407889795`, 
           4.846706935050809}, {-4.9803758143164245`, 
           4.845263393108333}, {-4.840471539058731, 
           4.843247771831743}, {-4.71242476263808, 4.840785827682965}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-4.688818378193893, 
           4.840274381865922}, {-4.561163302262209, 
           4.837203230877025}, {-4.421759340723382, 
           4.833174311198897}, {-4.2825221504241755`, 
           4.828474292053589}, {-4.14345173136459, 
           4.823103173441103}, {-4.004548083544627, 
           4.817060955361437}, {-3.8658112069642843`, 
           4.810347637814591}, {-3.7450792775801887`, 4.8039610347247175`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{-3.7215016135115953`, 
           4.802688964812966}, {-3.589808533940321, 
           4.795175823135624}, {-3.452785429101163, 
           4.786784355707569}, {-3.3164144787105547`, 
           4.777855848220466}, {-3.180695682768496, 
           4.768390300674315}, {-3.045629041274987, 
           4.758387713069116}, {-2.9112145542300265`, 
           4.747848085404869}, {-2.7793481997155043`, 4.736928420918705}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7558202641662093`, 
           4.734937866514648}, {-2.584401256631065, 
           4.720408181821388}, {-2.3929721362094893`, 
           4.704284020273597}, {-2.203164860368889, 
           4.688398933038204}, {-2.0149794291092658`, 
           4.672752920115207}, {-1.828238482692215, 
           4.6578178761289}, {-1.8145797188968624`, 4.656805130595481}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.791032364853999, 
           4.655059183598518}, {-1.642764661379332, 
           4.644065695703573}, {-1.4585579651706189`, 
           4.631496378839229}, {-1.2756183940660721`, 
           4.620109925535866}, {-1.0935910769050234`, 
           4.61014069647612}, {-0.9121211425268029, 
           4.601823052342624}, {-0.8482486523590952, 4.59946955172911}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8246526719529129, 
           4.598600113975602}, {-0.7312085909314083, 
           4.5951569931353795`}, {-0.5508534221188408, 
           4.590142518854386}, {-0.42196547400988216`, 
           4.587400843651327}, {-0.292930704181572, 
           4.585168417606292}, {-0.16374911263390984`, 
           4.58344524071928}, {-0.03442069936689529, 4.5822313129902925`}, {
           0.09505453561947075, 4.581526634419329}, {0.11962633734917007`, 
           4.581489587847866}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.14323830351075864`, 4.581453988407442}, {
           0.22467659232518866`, 4.581331205006389}, {0.3544454707502591, 
           4.581645024751473}, {0.48436117089468067`, 4.58246809365458}, {
           0.6612592256537724, 4.583717540718137}, {0.8384008088262138, 
           4.584534703217762}, {1.0157859204120059`, 4.584919581153455}, {
           1.0877082268832272`, 4.584900386084209}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{1.1113202190402764`, 4.584894084369947}, {
           1.1934145604111484`, 4.584872174525217}, {1.37128672882364, 
           4.584392483333047}, {1.5494024256494827`, 4.583480507576945}, {
           1.7277616508886755`, 4.58213624725691}, {1.906364404541218, 
           4.580359702372944}, {2.055770947090066, 4.578457675614715}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.0793810269606925`, 4.578157106423355}, {
           2.084958782771883, 4.578086098550321}, {2.263292881745443, 
           4.575250661414314}, {2.4413667014618983`, 4.571853390964924}, {
           2.6191802419212475`, 4.567894287202151}, {2.796733503123492, 
           4.563373350125994}, {2.974026485068631, 4.558290579736455}, {
           3.0236056952177157`, 4.556709770151863}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0472056951121638`, 4.55595729535613}, {
           3.151059187756665, 4.552645976033532}, {3.327831611187594, 
           4.546439539017227}, {3.474194305763928, 4.540977766702279}, {
           3.620385508611777, 4.535363139263957}, {3.7521086459312216`, 
           4.530268094367506}, {3.8837025894602815`, 4.525237328497472}, {
           3.9910428708038204`, 4.521182217936332}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{4.014638032487446, 4.520290837849215}, {
           4.015167339198956, 4.520270841653853}, {4.146502895147246, 
           4.515368633836651}, {4.164118998974106, 4.514715087694337}, {
           4.181733124984249, 4.514064317375972}, {4.345433994937941, 
           4.508282778386896}, {4.508993057888045, 4.502757098994598}, {
           4.731478768303324, 4.495485165892284}, {4.953745906034622, 
           4.488709665352345}, {4.958582437451648, 4.488573721810367}}]}, 
         {Arrowheads[{{0.01429099362321073, 1.}}], 
          ArrowBox[{{4.982185108761966, 4.4879103061388035`}, {
           5.175750202076346, 4.482469645855737}, {5.397447387422901, 
           4.476804155883419}, {5.504694837120452, 4.474386309635053}, {
           5.6067221001573495`, 4.472237672715991}, {5.656854249492381, 
           4.471244216252182}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.3064481891657578`, -2.162405321769212}, {
           1.4475687987417285`, -2.1417393889187024`}, {
           1.5881615208184994`, -2.1188338053208207`}, {
           1.7280302464383988`, -2.094631219266402}, {
           1.8669788666437568`, -2.0700742790462816`}, {
           2.005007381434574, -2.0451629846604593`}, {
           2.14211579081085, -2.019897336108935}, {
           2.2372391320124865`, -2.0026015667279453`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.260470234944066, -1.9983775792849587`}, {
           2.3079001034441293`, -1.98975365946691}, {
           2.473408325031422, -1.9611094483554936`}, {
           2.6386404555727268`, -1.9339647027746858`}, {
           2.803596495068045, -1.9083194227244866`}, {
           2.968765981903912, -1.8843482810917134`}, {
           3.134638454466864, -1.8622259507631833`}, {
           3.193879163182587, -1.8550158992496568`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.2173181958455737`, -1.8521631880550908`}, {
           3.3012139127569013`, -1.8419524317388962`}, {
           3.468492356774023, -1.823527724018852}, {
           3.6181785509356845`, -1.8086608067654866`}, {
           3.7686009303679677`, -1.795170615021606}, {
           3.9421866648234163`, -1.7811054595028801`}, {
           4.1167487887212335`, -1.7683784556557323`}, {
           4.157708673174756, -1.7657209985524835`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.181271126937814, -1.7641922781725798`}, {
           4.292287302061418, -1.7569896034801626`}, {
           4.46880220484397, -1.7469389029761708`}, {
           4.492466759132184, -1.745684620031955}, {
           4.516147746511204, -1.7444495795645032`}, {
           4.691442410395185, -1.7364765741572}, {
           4.867388982888936, -1.7294522388218845`}, {
           5.084153209932846, -1.7213364490627092`}, {
           5.1246715389139466`, -1.7200216875215126`}}]}, 
         {Arrowheads[{{0.010773747599522786`, 1.}}], 
          ArrowBox[{{5.148271111076932, -1.7192559153228848`}, {
           5.30013142261366, -1.7143282664720219`}, {
           5.515323620931377, -1.7084276910498222`}, {
           5.656854249492381, -1.705263827969435}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{1.1657668865276334`, 2.1821323090047264`}, {
           1.3075979787343583`, 2.1636973781707005`}, {1.4489008452885999`, 
           2.143021778371916}, {1.5896754861903581`, 2.120105509608373}, {
           1.7297262822958033`, 2.0958929295446316`}, {1.8688576144611062`, 
           2.071328395845252}, {2.007069482686267, 2.0464119085102337`}, {
           2.0977159719575535`, 2.029728571400092}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.120937932437571, 2.0254546078063447`}, {
           2.1443618869712857`, 2.0211434675395767`}, {2.3103915372947004`, 
           1.9909963159600204`}, {2.4761482506060295`, 1.9623529694985127`}, {
           2.641632026905273, 1.9352134281550537`}, {2.806842866192432, 
           1.9095776919296432`}, {2.972270017197045, 1.885619408282892}, {
           3.053225458976192, 1.8748467145743588`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{3.076631133661741, 1.8717321350119762`}, {
           3.1384027286486536`, 1.8635122246754112`}, {3.305241000547256, 
           1.8432561411072006`}, {3.472784832892853, 1.8248511575782602`}, {
           3.6226160178333697`, 1.8100115385188036`}, {3.7731833873628617`, 
           1.7965468658745987`}, {3.94678268237826, 1.7825210224035652`}, {
           4.016250355180139, 1.7774707347989618`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{4.039800196621877, 1.7757586654647437`}, {
           4.121355812127204, 1.7698295865499074`}, {4.296902776609694, 
           1.7584725583136254`}, {4.4734235758257315`, 1.7484499376947187`}, {
           4.497089127097619, 1.747199138574396}, {4.520771062088781, 
           1.7459675334179956`}, {4.696210653438223, 1.738011473747052}, {
           4.872299443229115, 1.7310034422444889`}, {4.9829515718730395`, 
           1.726872838720554}}]}, 
         {Arrowheads[{{0.013776725882650895`, 1.}}], 
          ArrowBox[{{5.0065471303699525`, 1.7259920251449725`}, {
           5.088769793930972, 1.7229226831629005`}, {5.304395167699339, 
           1.7159443311388032`}, {5.519175564534217, 1.7100683861721968`}, {
           5.656854249492381, 1.7069963636794845`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.671767500991714, -3.9318143271105344`}, \
{-4.464898526998454, -3.925423315193715}, {-4.258705775941813, \
-3.9173703954522123`}, {-4.053438783309414, -3.9073971095064337`}, \
{-3.8493147784404576`, -3.8954070436126083`}, {-3.7284179770741415`, \
-3.8871694308480924`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-3.704860605969487, -3.8855642891179802`}, \
{-3.6464944549144103`, -3.881587362139655}, {-3.4451385063107343`, \
-3.8661252294564905`}, {-3.2455084888273418`, -3.849114860408691}, \
{-3.047785268567388, -3.830724829460505}, {-2.8520085039682, \
-3.8112538404088636`}, {-2.764130288094867, -3.80206960532135}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7406461996959797`, -3.7996152611300404`}, \
{-2.658217853467104, -3.791000597050695}, {-2.466714345790579, \
-3.77011894998313}, {-2.277589913433782, -3.7488786323631382`}, \
{-2.0905705704870625`, -3.7277521718274094`}, {-1.9053823310407743`, \
-3.707212096012633}, {-1.8018385356353679`, -3.696295182259365}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.7783566949315568`, -3.6938194257089334`}, \
{-1.7404288573533737`, -3.689820587052616}, {-1.576589947457169, \
-3.6738436862576447`}, {-1.4136206759039038`, -3.6594461039749815`}, \
{-1.2538886553600395`, -3.6450356401810935`}, {-1.0939241086419698`, \
-3.6329456914621927`}, {-0.9343393493703307, -3.622764481950124}, \
{-0.8370597123458888, -3.61770972204305}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.813479530652864, -3.6164844691466653`}, \
{-0.775134377545121, -3.614492011644887}, {-0.6163091931663424, \
-3.6081282805464827`}, {-0.4573008704225585, -3.603412518602461}, \
{-0.29754648350233115`, -3.6000839557603723`}, {-0.13704603240566204`, \
-3.5981425920202175`}, {0.02420048286744919, -3.597588427381996}, {
           0.13070372080661158`, -3.5975207612669657`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.1543157090389614, -3.5975057595492457`}, {
           0.25235375831567225`, -3.597443471734828}, {
           0.4826384488259211, -3.596616771803626}, {
           0.715054554398195, -3.595108327588391}, {
           0.9496020750324956, -3.592918139089122}, {
           1.0987600891156268`, -3.5905552041398523`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.1223691197984287`, -3.590181194040149}, {
           1.1855585610274413`, -3.589180158058122}, {
           1.4222015626816509`, -3.583028336247691}, {
           1.659531079995126, -3.57446267365783}, {
           1.8975471129678656`, -3.5634831702885386`}, {
           2.066108480967561, -3.554394415877022}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.08968622483287, -3.553123114355728}, {
           2.1357059387362183`, -3.550641751735578}, {
           2.373463834436532, -3.5364903435947097`}, {
           2.610820800068807, -3.521028945865934}, {
           2.847776835633044, -3.5042575585492504`}, {
           3.0320963308852202`, -3.49086149858517}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0556462086796925`, -3.489149929363206}, {
           3.0844081689864837`, -3.487059553928816}, {
           3.320791027986367, -3.470318304288788}, {
           3.556925412632694, -3.4540338096291667`}, {
           3.792811322925465, -3.4382060699499517`}, {
           3.954505995165633, -3.4276728135272867`}, {
           3.997938447496055, -3.424945484900025}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.021504024588295, -3.423465691115123}, {
           4.1162629220839975`, -3.417515332800984}, {
           4.269135655964888, -3.408415285050252}, {
           4.422068909872039, -3.3999056003111745`}, {
           4.5750626838054504`, -3.391986278583752}, {
           4.728116977765121, -3.384657319867984}, {
           4.748648003274136, -3.3837139806768355`}, {
           4.769180872528934, -3.3827804530447976`}, {
           4.951767391729577, -3.3753270396134574`}, {
           4.964706015630236, -3.3748504363610174`}}]}, 
         {Arrowheads[{{0.01416466266216318, 1.}}], 
          ArrowBox[{{4.988302005724582, -3.3739812615778377`}, {
           5.134515893447989, -3.3685953708543823`}, {
           5.327336997621014, -3.361871977626261}, {
           5.520353708648127, -3.3558999928444906`}, {
           5.656854249492381, -3.3521727725246206`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.4990820880991955`, 
           3.662749171150437}, {-1.3554084723045579`, 
           3.649058262257683}, {-1.2116566417511234`, 
           3.6371656746655905`}, {-1.0683080099397801`, 
           3.6267389674084223`}, {-0.9253625768705298, 
           3.6177781404861786`}, {-0.7828203425433712, 
           3.610283193898859}, {-0.6403053828673844, 
           3.6041610258525494`}, {-0.5567799122750147, 
           3.6013298544499093`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.5331814718913599, 
           3.6005299639603705`}, {-0.49744177375165144`, 
           3.5993185345533343`}, {-0.35422951519617146`, 
           3.5957557200012134`}, {-0.21066860720094388`, 
           3.5934725821961875`}, {-0.024397955203604355`, 
           3.591667934790794}, {0.1633412431457067, 3.590496401621811}, {
           0.35254898784699035`, 3.5899579826892385`}, {0.4112020876330271, 
           3.5899871114974116`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.43481407771916636`, 3.589998837887531}, {
           0.5432252789002464, 3.590052677993076}, {0.7352002118278983, 
           3.5898152526208027`}, {0.9283038821523704, 3.588280471659898}, {
           1.1225362898736626`, 3.5854483351103608`}, {1.3178974349917745`, 
           3.5813188429721916`}, {1.3792010394412848`, 3.57966840240174}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.4028044799132846`, 3.5790329409781085`}, {
           1.447797651149592, 3.577821616523886}, {1.5776645173156725`, 
           3.5736666819034335`}, {1.7074980334900163`, 3.5688540391108345`}, {
           1.8372981996726234`, 3.563383688146089}, {1.9670650158634935`, 
           3.5572556290091972`}, {2.096798482062627, 3.5504698617001584`}, {
           2.226498598270023, 3.5430263862189735`}, {2.3462282396774157`, 
           3.535546043783537}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.3697919267675625`, 3.534036783749598}, {
           2.5184370484839484`, 3.524345482281615}, {2.680544644751804, 
           3.5137192730695275`}, {2.8424881532892496`, 3.5030465749293795`}, {
           3.004267574096286, 3.492327387861171}, {3.1658829071729127`, 
           3.4815617118649027`}, {3.3122161822896485`, 
           3.4717619763404937`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.3357752041714512`, 3.4701812533492076`}, {
           3.4886213101349366`, 3.459890893088184}, {3.6497443800203344`, 
           3.448985750307734}, {3.806640917566315, 3.4384876342978727`}, {
           3.963574781314213, 3.4282922254165156`}, {4.1163649523330745`, 
           3.4187926787594174`}, {4.269205115844805, 3.4098392818641345`}, {
           4.27828786955743, 3.4093398320819515`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.301864244706441, 3.4080433953618328`}, {
           4.422095271849407, 3.4014320347306675`}, {4.575035420346877, 
           3.3935709373590157`}, {4.595543012996955, 3.3925536332240096`}, {
           4.6160521586717005`, 3.3915465008133365`}, {4.793771525991743, 
           3.3836558389480436`}, {4.971633606956407, 3.376476172970997}, {
           5.160930508743362, 3.3692152564969415`}, {5.245401556860285, 
           3.366314111973247}}]}, 
         {Arrowheads[{{0.008216858836522305, 1.}}], 
          ArrowBox[{{5.268999636191087, 3.365503639744638}, {
           5.350413573255958, 3.3627074912069617`}, {5.540081550628045, 
           3.356922434861343}, {5.656854249492381, 3.3537899952891594`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.3689891137082277`, -2.611833863286821}, {
           1.5503291842763507`, -2.5949177190257338`}, {
           1.7315684123945612`, -2.575289218111715}, {
           1.9124065716122776`, -2.5539885982165362`}, {
           2.0925434354789187`, -2.53205609701197}, {
           2.271979003994485, -2.5094917144980156`}, {
           2.3073316250166327`, -2.504903625657765}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.3307472463477485`, -2.5018647293097533`}, {
           2.450713277158976, -2.486295450674674}, {
           2.672825287411116, -2.4577939251574397`}, {
           2.8948700389065047`, -2.4308500341908608`}, {
           3.116847531645144, -2.405463777774937}, {
           3.2684524707365443`, -2.3891845070910493`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.291929502245745, -2.38666355392763}, {
           3.338757765627032, -2.3816351559096685`}, {
           3.561047517957124, -2.3595863773819636`}, {
           3.784163565740373, -2.3395396509787316`}, {
           4.00810590897678, -2.321494976699971}, {
           4.232852869396109, -2.3054539018091287`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{4.256417768541382, -2.303963362297288}, {
           4.408769153456306, -2.294327890907257}, {
           4.5851457018245565`, -2.2843675894462496`}, {
           4.756204238197136, -2.2756928166631236`}, {
           4.9276850684619635`, -2.267864124350086}, {
           5.099588192619037, -2.2608815125071366`}, {
           5.199708435623146, -2.2573162171536834`}}]}, 
         {Arrowheads[{{0.009184246282306808, 1.}}], 
          ArrowBox[{{5.2233054718762455`, -2.256475923510918}, {
           5.271913610668358, -2.2547449811342757`}, {
           5.2950440861369374`, -2.2539790231090495`}, {
           5.318181417194771, -2.25322593562653}, {
           5.518456272984706, -2.2477416674636577`}, {
           5.656854249492381, -2.2445359014209183`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.6277747081904091, -3.1407226229804417`}, \
{-0.4786378270669926, -3.1341712557812653`}, {-0.32885412736726705`, \
-3.129390067736865}, {-0.17842360909123245`, -3.1263790588472404`}, \
{-0.026906152478022916`, -3.124458113347053}, {
           0.12613836223322905`, -3.1229471154709634`}, {
           0.2807099350425229, -3.1218460652189717`}, {
           0.3164308573652354, -3.121687916341275}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.3400426189526487, -3.1215833789062737`}, {
           0.436808565949858, -3.1211549625910777`}, {
           0.5942879640829855, -3.1200679629855363`}, {
           0.7530018385696563, -3.1177792218006015`}, {
           0.9129501894098699, -3.114288739036274}, {
           1.0741330166036258`, -3.1095965146925533`}, {
           1.2842325932922531`, -3.101339763095632}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.3078263738543168`, -3.1004125456856606`}, {
           1.3100995515813612`, -3.1003232115512294`}, {
           1.5461896116199587`, -3.0879379856687157`}, {
           1.782403196719419, -3.0724408370450123`}, {
           2.0187403068797423`, -3.0538317656801195`}, {
           2.2498769980783737`, -3.0338351029241077`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{2.2733971839338643`, -3.031755072213162}, {
           2.4903644230872164`, -3.0124556971415446`}, {
           2.725296259310427, -2.9909831605715573`}, {
           2.9596412809466197`, -2.968987622467771}, {
           3.1222947790733433`, -2.953852887202024}, {
           3.2139464487608764`, -2.945699438156201}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.2374655587823646`, -2.9436071482304738`}, {
           3.2850439558247824`, -2.939374513546459}, {
           3.4478888112009365`, -2.925552501501075}, {
           3.6108293452018065`, -2.9123868510658726`}, {
           3.7738655578273916`, -2.899877562240852}, {
           3.9369974490776922`, -2.8880246350260124`}, {
           4.100225018952709, -2.8768280694213546`}, {
           4.179183751788431, -2.871732400807861}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.20274672734259, -2.870211744248926}, {
           4.26354826745244, -2.866287865426878}, {
           4.44068336503022, -2.8556586237699135`}, {
           4.618165351767802, -2.84587387810154}, {
           4.7809094774527, -2.8376432802861915`}, {
           4.9438627130720185`, -2.830112338059908}, {
           5.107025058625757, -2.8232810514226885`}, {
           5.145959542538379, -2.8218197686686777`}}]}, 
         {Arrowheads[{{0.010323837323733423`, 1.}}], 
          ArrowBox[{{5.169554922699659, -2.820934190676135}, {
           5.270396514113916, -2.8171494203745335`}, {
           5.292328305735906, -2.816373738953115}, {
           5.314262250626447, -2.8156103558730936`}, {
           5.513247177346133, -2.8097462427840436`}, {
           5.656854249492381, -2.805992916105022}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.6278596551935005, 
           3.1417834777612414`}, {-0.4786363221019322, 
           3.1352324859231673`}, {-0.3287661084249099, 
           3.1304526143772424`}, {-0.17824901416243238`, 
           3.1274438631234664`}, {-0.026644769161451698`, 
           3.1255255236624135`}, {0.12648689673108093`, 3.124016887494658}, {
           0.281145983515165, 3.1229179546201995`}, {0.31634625065263, 
           3.1227626206817116`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.33995801375159207`, 3.12265842521801}, {
           0.4373324911907997, 3.122228725039039}, {0.5948998269513007, 
           3.1211429982923744`}, {0.7537013979899833, 3.1188545739214057`}, {
           0.9137372043068468, 3.1153634519261324`}, {1.0750072459018907`, 
           3.1106696323065552`}, {1.284148803668764, 
           3.1024519022217354`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{1.3077425903040982`, 3.10152483936384}, {
           1.3112212440794155`, 3.101388153771128}, {1.5475564203147736`, 
           3.0889924057949822`}, {1.7840127746079641`, 3.0734823883781175`}, {
           2.0205903069589866`, 3.0548581015205345`}, {2.2497990063711453`, 
           3.0350341389608113`}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{2.273319730330345, 3.0329602346629936`}, {
           2.4926937571431425`, 3.0134562835369865`}, {2.727865887803429, 
           2.9919761434244654`}, {2.962451622175854, 2.9699765158981126`}, {
           3.125239207607495, 2.954843993474213}, {3.2138747486051367`, 
           2.9469672854218034`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.2373940557768295`, 2.9448772128154737`}, {
           3.288123209062854, 2.940369103250366}, {3.4511036265419315`, 
           2.9265518452265713`}, {3.614180460044728, 2.913392219402829}, {
           3.777353709571242, 2.9008902257791394`}, {3.9406233751214748`, 
           2.889045864355502}, {4.103989456695426, 2.877859135131917}, {
           4.1791135552523615`, 2.873020172469923}}]}, 
         {Arrowheads[{{0.020000000000000007`, 1.}}], 
          ArrowBox[{{4.202676716781938, 2.8715024003963756`}, {
           4.267451954293095, 2.867330038108385}, {4.444718285499189, 
           2.856714812963885}, {4.6223318792373025`, 2.8469441554503354`}, {
           4.785061491976132, 2.838733235791436}, {4.9479990601736485`, 
           2.8312213035208105`}, {5.111144583829854, 2.8244083586384585`}, {
           5.145889496514375, 2.8231079338146983`}}]}, 
         {Arrowheads[{{0.01032532464542967, 1.}}], 
          ArrowBox[{{5.169484968573882, 2.822224807761882}, {
           5.274498062944747, 2.8182944011443807`}, {5.296427580633019, 
           2.817521038378896}, {5.318359240555004, 2.816759951986755}, {
           5.517348592383383, 2.8109121734080174`}, {5.656854249492381, 
           2.807273812216783}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.59495692232418, -5.656854249492381}, \
{-1.5625539906720267`, -5.655022229519474}, {-1.4254795597517051`, \
-5.647792812618338}, {-1.2889749019681278`, -5.641116204624962}, \
{-1.1530400173212954`, -5.634992405539346}, {-1.0176749058112056`, \
-5.62942141536149}, {-0.882704072676459, -5.6244881266080835`}, \
{-0.7479520231556552, -5.620277431795814}, {-0.6513234726715162, \
-5.617772102509054}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.6277194120343292, -5.617160110048187}, \
{-0.6134187572487925, -5.616789330924682}, {-0.4791042749558716, \
-5.614023823994688}, {-0.34500857627689274`, -5.611980911005831}, \
{-0.21113166121185578`, -5.610660591958111}, {-0.0774735297607606, \
-5.610062866851529}, {0.05596581807639289, -5.610187735686084}, {
           0.18927881195730314`, -5.610814365176864}, {
           0.3166991414858368, -5.6116820272546075`}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{0.3403102924952151, -5.611880265222721}, {
           0.4558030268234918, -5.612910406272358}, {
           0.5890142478087702, -5.614379817877072}, {
           0.7221915444955047, -5.616130156853099}, {
           0.8553349168836952, -5.618161423200436}, {
           0.9884443649733419, -5.620473616919085}, {
           1.121519888764444, -5.623066738009046}, {
           1.2557225329637178`, -5.625758342025739}, {
           1.2846727185961222`, -5.626310646524983}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{1.3082804158482644`, -5.626761028348945}, {
           1.3896871994670945`, -5.628314086883098}, {
           1.5234138882745745`, -5.630733972581123}, {
           1.6572136581834636`, -5.632991958167604}, {
           1.7910435295800362`, -5.635148531953366}, {
           1.9251204241695956`, -5.637196911910223}, {
           2.059134311636743, -5.639094784672126}, {
           2.192775161666081, -5.640799836873028}, {
           2.252643657947491, -5.6414364762201}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{2.2762543160229036`, -5.641687551073733}, {
           2.3250309570866485`, -5.642206240047868}, {
           2.4554512702119355`, -5.6432589778107936`}, {
           2.5845684549532204`, -5.643991954914575}, {
           2.712914865221781, -5.644439076111978}, {
           2.842095975870022, -5.644656835664996}, {
           2.972858764997447, -5.64468365622824}, {
           3.1044478413859835`, -5.644526335143412}, {
           3.2207235141734403`, -5.6442307749757905`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{3.2443353859761244`, -5.644157370168494}, {
           3.398468183347247, -5.643514812353802}, {
           3.556771398358189, -5.64256699739579}, {
           3.712039922618965, -5.641389254938475}, {
           3.865296219898155, -5.640022615042157}, {
           4.101378659387384, -5.637538812272164}, {
           4.188780957958167, -5.636485583466472}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{4.212391236781348, -5.6362010712033666`}, {
           4.333487863725024, -5.634741813748416}, {
           4.569791906965733, -5.631823477270186}, {
           4.753030558971863, -5.629714428135846}, {
           4.941069924809593, -5.627813757979935}, {
           5.153672735114947, -5.626021600738777}, {
           5.156814780939027, -5.626000956664939}}]}, 
         {Arrowheads[{{0.010088821150451432`, 1.}}], 
          ArrowBox[{{5.180426264307721, -5.625845822961176}, {
           5.3658351807088875`, -5.624627637239298}, {
           5.3801065292345704`, -5.624547179675816}, {
           5.394375783858701, -5.624468645897662}, {
           5.444901032380904, -5.624221638041233}, {
           5.495399225565731, -5.623999308064223}, {
           5.592223542284686, -5.623758613167393}, {
           5.656854249492381, -5.6234977632765535`}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-5.656854249492381, -5.338055660114318}, \
{-5.544486282816296, -5.33774957644206}, {-5.3995044114018835`, \
-5.337052369305722}, {-5.254956210360861, -5.336054058338556}, \
{-5.110841679693226, -5.3347546435405615`}, {-4.9671608193989805`, \
-5.333154124911738}, {-4.823913629478128, -5.331252502452087}, \
{-4.712422737480245, -5.329406976207503}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-4.688813978743413, -5.329016176716441}, \
{-4.680985538856531, -5.328886591321558}, {-4.538261976460055, \
-5.3258932066801}, {-4.3957429422887015`, -5.322272348527716}, \
{-4.2534284363424675`, -5.318024016864403}, {-4.111318458621355, \
-5.313148211690163}, {-3.9694130091253665`, -5.307644933004995}, \
{-3.8277120878544997`, -5.3015141808088995`}, {-3.744893369474662, \
-5.297558549293992}}]}, 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{-3.7213082630229333`, -5.296432064941325}, \
{-3.6862156948087543`, -5.294755955101875}, {-3.545124414138939, \
-5.287484289939326}, {-3.404638829995861, -5.279813219376654}, \
{-3.2647589423795216`, -5.271742743413857}, {-3.1254847512899206`, \
-5.263272862050937}, {-2.986816256727057, -5.254403575287893}, \
{-2.8487534586909318`, -5.2451348831247255`}, {-2.778522647621557, \
-5.24019517229195}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-2.7549688438541526`, -5.238538506537258}, \
{-2.7112963571815456`, -5.235466785561434}, {-2.574444952198897, \
-5.225399282598018}, {-2.365865138208234, -5.209856991708233}, \
{-2.1589645292071986`, -5.194722977998964}, {-1.9537431251957915`, \
-5.17999724147021}, {-1.812973325908594, -5.170095285568975}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-1.78941953219499, -5.168438476879611}, \
{-1.7502009261740128`, -5.1656797821219715`}, {-1.5480907237916022`, \
-5.152373945293886}, {-1.3471653096983003`, -5.14068307632559}, \
{-1.1474246838941073`, -5.130607175217086}, {-0.948868846379024, \
-5.1221462419683705`}, {-0.8463089769375147, -5.118615854890593}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{-0.8227109607036942, -5.117803547581441}, \
{-0.7510648044042774, -5.115337293814258}, {-0.5535795652210943, \
-5.1102173479895585`}, {-0.35641312882947596`, -5.106786404494273}, \
{-0.15956549522942198`, -5.105044463328401}, {-0.013611112939107328`, \
-5.104562262870486}, {0.12162157141114091`, -5.104455715532982}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{0.14523354199116445`, -5.104469306666535}, {
           0.27853706345112056`, -5.104699290403635}, {
           0.4247308575510348, -5.105318518394697}, {
           0.5710044555874818, -5.106304889202086}, {
           0.7173578575604608, -5.107658402825801}, {
           0.8637910634699727, -5.109379059265842}, {
           1.0103040733160171`, -5.111466858522208}, {
           1.0896692888566728`, -5.112586358250081}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{1.113278933166085, -5.1129193881574455`}, {
           1.1879061147023429`, -5.113972054729981}, {
           1.3653950457764856`, -5.115980710471623}, {
           1.5427708665384459`, -5.117492825747134}, {
           1.720033576988223, -5.118508400556514}, {
           1.8971831771258176`, -5.119027434899762}, {
           2.0577297474073646`, -5.11904783360303}}]}, 
         {Arrowheads[{{0.020000000000000004`, 1.}}], 
          ArrowBox[{{2.0813417147072353`, -5.1190308460391725`}, {
           2.2511430464644584`, -5.118575882187866}, {
           2.4279533156655053`, -5.11760529513272}, {
           2.6392701107372774`, -5.115832272238057}, {
           2.8501047602604013`, -5.11343092271483}, {
           3.0257788280598525`, -5.110900714974757}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.0493883723772655`, -5.110560670183173}, {
           3.0604572642348793`, -5.11040124656304}, {
           3.2703276226607096`, -5.106743243782686}, {
           3.4799569083122166`, -5.10277107768805}, {
           3.6895861939637236`, -5.098798911593415}, {
           3.8992154796152305`, -5.0948267454987795`}, {
           3.9936800725677344`, -5.0920059926787395`}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.017281545843093, -5.091301242674343}, {
           4.104731823851753, -5.088689940274191}, {
           4.277491103733907, -5.08444158207362}, {
           4.4499627421288634`, -5.080276526384465}, {
           4.687420909490311, -5.074945803594612}, {
           4.9244373057207715`, -5.0701079072224084`}, {
           4.940363624978348, -5.069799094667135}, {
           4.956288037652773, -5.069492603366292}, {
           4.961503847834126, -5.069401985779137}}]}, 
         {Arrowheads[{{0.014226255703201858`, 1.}}], 
          ArrowBox[{{4.985112278078558, -5.06899182150726}, {
           5.144370760855245, -5.0662249226092015`}, {
           5.332179011339602, -5.063294756179733}, {
           5.513878913663469, -5.060620610648979}, {
           5.656854249492381, -5.058771169123271}}]}}, 
        {GrayLevel[0], 
         {Arrowheads[{{0.019999999999999997`, 1.}}], 
          ArrowBox[{{1.3703673140885948`, 2.6129050362814876`}, {
           1.55190934843634, 2.5959727950332905`}, {1.7333493750461408`, 
           2.576327170011745}, {1.914387925648287, 2.5550105781008288`}, {
           2.094725531973066, 2.533065436184516}, {2.274362194020479, 
           2.5104917442628083`}, {2.3087172506837517`, 
           2.5060369917625556`}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{2.332133208677714, 2.5030006906310565`}, {
           2.4532979117905254`, 2.4872895023357047`}, {2.675721509653105, 
           2.458777959055338}, {2.8980812936508107`, 2.4318302368408413`}, {
           3.120377263783643, 2.4064463356922157`}, {3.269850896153758, 
           2.390424919380963}}]}, 
         {Arrowheads[{{0.02, 1.}}], 
          ArrowBox[{{3.293328410693319, 2.387908468630235}, {
           3.342609420051602, 2.382626255609461}, {3.5652238353926964`, 
           2.360590784386264}, {3.7886665827449346`, 2.340560709816313}, {
           4.0129376621083175`, 2.322536031899607}, {4.234259047292825, 
           2.306785615240408}}]}, 
         {Arrowheads[{{0.019999999999999993`, 1.}}], 
          ArrowBox[{{4.25782220748756, 2.3052694406330922`}, {
           4.414106208172308, 2.2954168615540205`}, {4.590657161954411, 
           2.2854800954951444`}, {4.761710784960279, 2.276835650686693}, {
           4.933185291420885, 2.2690350155604637`}, {5.105080681336228, 
           2.2620781901164557`}, {5.20111549536893, 2.258671301606273}}]}, 
         {Arrowheads[{{0.009154442011897926, 1.}}], 
          ArrowBox[{{5.224712644351183, 2.2578341796047314`}, {
           5.277396954706311, 2.25596517435467}, {5.300526415971627, 
           2.255202206546919}, {5.323662707558905, 2.2544520787855835`}, {
           5.524109752841301, 2.248986770965738}, {5.656854249492381, 
           2.245926823641296}}]}}}}},
     Frame->True,
     FrameLabel->{{
        FormBox["\"y/R\"", TraditionalForm], 
        FormBox["\"\"", TraditionalForm]}, {
        FormBox["\"z/R\"", TraditionalForm], 
        FormBox[
        "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \\(tot\\)]\\),\\!\\(\
\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(tot\\)]\\)}\"", 
         TraditionalForm]}}], {194.4, -189.}, ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}],
   ImageSize->{211., Automatic},
   ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}]], "Input",
 CellChangeTimes->{3.532430063576189*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"nMaxP", "[", "q_", "]"}], ":=", 
    RowBox[{"q", "+", 
     RowBox[{"4.3", 
      SuperscriptBox["q", 
       RowBox[{"1", "/", "3"}]]}], "+", "1"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FieldPM", "[", 
     RowBox[{"r0_", ",", "kk_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "=", "r0"}], ",", 
        RowBox[{"k", "=", "kk"}], ",", "n", ",", "FieldP", ",", "gn"}], "}"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FieldP", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "7"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"n", "=", "1"}], ",", 
         RowBox[{"n", "\[LessEqual]", "nmax"}], ",", 
         RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
           RowBox[{"r", " ", 
            RowBox[{"SphericalBesselJ", "[", 
             RowBox[{"n", ",", 
              RowBox[{"k", " ", "r"}]}], "]"}]}]}], ";", " ", 
          RowBox[{"(*", " ", 
           RowBox[{"r", "*", 
            RowBox[{
             SubscriptBox["j", "n"], "[", "kr", "]"}]}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "n"}], ")"}], " ", 
               RowBox[{"SphericalBesselJ", "[", 
                RowBox[{"n", ",", 
                 RowBox[{"k", " ", "r"}]}], "]"}]}], "-", 
              RowBox[{"k", " ", "r", " ", 
               RowBox[{"SphericalBesselJ", "[", 
                RowBox[{
                 RowBox[{"1", "+", "n"}], ",", 
                 RowBox[{"k", " ", "r"}]}], "]"}]}]}], ")"}], "/", "k"}]}], 
          ";", " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"r", "*", 
               RowBox[{
                SubscriptBox["j", "n"], "[", "kr", "]"}]}], ",", "r"}], "]"}],
             "/", "k"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            SqrtBox[
             RowBox[{"\[Pi]", "/", "2"}]], " ", 
            RowBox[{"(", 
             RowBox[{"n", "+", 
              SuperscriptBox["n", "2"], "-", 
              RowBox[{
               SuperscriptBox["k", "2"], " ", 
               SuperscriptBox["r", "2"]}]}], ")"}], " ", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"1", "/", "2"}], "+", "n"}], ",", 
               RowBox[{"k", " ", "r"}]}], "]"}], "/", 
             RowBox[{"(", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"k", " ", "r"}], ")"}], 
               RowBox[{"3", "/", "2"}]], ")"}]}]}]}], ";", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"r", "*", 
               RowBox[{
                SubscriptBox["j", "n"], "[", "kr", "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "/", "k"}], " ", 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], "=", 
           RowBox[{"r", " ", 
            RowBox[{"SphericalHankelH2", "[", 
             RowBox[{"n", ",", 
              RowBox[{"k", " ", "r"}]}], "]"}]}]}], ";", 
          RowBox[{"(*", " ", 
           RowBox[{"k", "*", "kr", "*", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["h", "n", "2"], "[", "kr", "]"}], "/", 
             SuperscriptBox["k", "2"]}]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            SuperscriptBox["k", 
             RowBox[{"-", "1"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "n"}], ")"}], " ", 
               RowBox[{"SphericalHankelH2", "[", 
                RowBox[{"n", ",", 
                 RowBox[{"k", " ", "r"}]}], "]"}]}], "-", 
              RowBox[{"k", " ", "r", " ", 
               RowBox[{"SphericalHankelH2", "[", 
                RowBox[{
                 RowBox[{"1", "+", "n"}], ",", 
                 RowBox[{"k", " ", "r"}]}], "]"}]}]}], ")"}]}]}], ";", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"kr", "*", 
               RowBox[{
                SubsuperscriptBox["h", "n", "2"], "[", "kr", "]"}]}], ",", 
              "r"}], "]"}], "/", 
            SuperscriptBox["k", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"r", " ", "k"}], ")"}], 
             RowBox[{"-", "1"}]], " ", 
            RowBox[{"(", 
             RowBox[{"n", "+", 
              SuperscriptBox["n", "2"], "-", 
              RowBox[{
               SuperscriptBox["k", "2"], " ", 
               SuperscriptBox["r", "2"]}]}], ")"}], " ", 
            RowBox[{"SphericalHankelH2", "[", 
             RowBox[{"n", ",", 
              RowBox[{"k", " ", "r"}]}], "]"}]}]}], ";", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"kr", "*", 
               RowBox[{
                SubsuperscriptBox["h", "n", "2"], "[", "kr", "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "/", 
            SuperscriptBox["k", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"Exact", "\[Equal]", "1"}], ",", 
            RowBox[{"gn", "=", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"-", "1"}], ")"}], "n"], 
              RowBox[{
              "gnET", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"gn", "=", 
             RowBox[{"gnMLA", "[", 
              RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}]}]}], "]"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            SuperscriptBox["I", 
             RowBox[{"n", "+", "1"}]], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "n"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", "n"}], "+", "1"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"n", 
                RowBox[{"(", 
                 RowBox[{"n", "+", "1"}], ")"}]}], ")"}]}], ")"}], 
            "gn"}]}]}]}], "]"}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"k", 
         StyleBox[" ",
          FontSize->8], 
         SubsuperscriptBox["c", "n", "pw"], 
         SubscriptBox["g", "n"]}], " ", "*)"}], "\[IndentingNewLine]", 
       "FieldP"}]}], " ", 
     RowBox[{"(*", 
      RowBox[{"Output", " ", "the", " ", "Table"}], "*)"}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"Components", " ", "of", " ", "EM"}], "-", 
     RowBox[{"Fields", ":", " ", 
      RowBox[{"Scattered", " ", 
       RowBox[{"(", "s", ")"}]}]}]}], ",", " ", 
    RowBox[{"Incidence", " ", 
     RowBox[{"(", "i", ")"}]}], ",", " ", 
    RowBox[{"Total", " ", 
     RowBox[{"(", "tot", ")"}]}], ",", " ", 
    RowBox[{"Interior", " ", 
     RowBox[{"(", "sp", ")"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EHVi", "[", 
    RowBox[{"r0_", ",", "\[Theta]0_", ",", "\[Phi]0_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "=", "r0"}], ",", 
       RowBox[{"\[Theta]", "=", "\[Theta]0"}], ",", 
       RowBox[{"\[Phi]", "=", "\[Phi]0"}], ",", "FieldP", ",", "E\[Theta]i", 
       ",", "E\[Phi]i", ",", "H\[Theta]i", ",", "H\[Phi]i", ",", "Et", ",", 
       "Eri", ",", "Hri", ",", "Ei2", ",", "Hi2", ",", "\[Pi]n", ",", 
       "\[Tau]n", ",", "\[Pi]n\[Tau]nT", ",", "E\[Theta]s", ",", "E\[Phi]s", 
       ",", "H\[Theta]s", ",", "H\[Phi]s", ",", "Ers", ",", "Hrs", ",", "Eis",
        ",", "His", ",", "Es2", ",", "Hs2", ",", "E\[Theta]sp", ",", 
       "E\[Phi]sp", ",", "H\[Theta]sp", ",", "H\[Phi]sp", ",", "Ersp", ",", 
       "Hrsp", ",", "Esp2", ",", "Hsp2", ",", "EiV", ",", "EspV", ",", "EsV", 
       ",", "ETotV", ",", "Etot2", ",", "Htot2", ",", "Poynting", ",", 
       "PoyntingSP", ",", "PoyntingS", ",", "PoyntingI", ",", "STot2", ",", 
       "SS2", ",", "SI2", ",", "SSP2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"create", " ", "angular", " ", "functions", " ", "at", " ", 
       RowBox[{
        SubscriptBox["\[CapitalPi]", "n"], "[", "\[Theta]", "]"}], " ", "and",
        " ", 
       RowBox[{
        SubscriptBox["\[Tau]", "n"], "[", "\[Theta]", "]"}], " ", "for", " ", 
       "all", " ", "n"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Pi]n\[Tau]nT", "=", 
       RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "nmax"}], "]"}]}], ";", 
      RowBox[{"\[Pi]n", "=", 
       RowBox[{
       "\[Pi]n\[Tau]nT", "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}]}], ";", 
      RowBox[{"\[Tau]n", "=", 
       RowBox[{
       "\[Pi]n\[Tau]nT", "\[LeftDoubleBracket]", "2", 
        "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "Get", " ", "generating", " ", "functions", " ", "of", " ", "the", 
         " ", "field", " ", "components"}], ",", " ", 
        RowBox[{"i", ".", "e", ".", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"kr", "*", 
            RowBox[{
             SubsuperscriptBox["h", "n", "2"], "[", "kr", "]"}]}], ",", 
           RowBox[{"r", "*", 
            RowBox[{
             SubscriptBox["j", "n"], "[", "kr", "]"}], " ", "and", " ", 
            "derivatives"}]}], "}"}]}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"FieldP", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"r", "\[GreaterEqual]", "R"}], ",", 
         RowBox[{"FieldPM", "[", 
          RowBox[{"r", ",", "k"}], "]"}], ",", 
         RowBox[{"FieldPM", "[", 
          RowBox[{"r", ",", 
           RowBox[{"k", "*", 
            RowBox[{"nParticle", "/", "nmed"}]}]}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Incidence", " ", "Field", " ", 
         RowBox[{"Components", ":", " ", "EiV"}]}], "=", 
        RowBox[{"{", 
         RowBox[{
          SubsuperscriptBox["E", "\[Theta]", "inc"], ",", 
          SubsuperscriptBox["E", "\[Phi]", "inc"], ",", 
          SubsuperscriptBox["E", "r", "inc"], ",", 
          SubsuperscriptBox["H", "\[Theta]", "inc"], ",", 
          SubsuperscriptBox["H", "\[Phi]", "inc"], ",", 
          SubsuperscriptBox["H", "r", "inc"], ",", 
          RowBox[{"|", 
           SuperscriptBox["E", "inc"], 
           SuperscriptBox["|", "2"]}], ",", 
          RowBox[{"|", 
           SuperscriptBox["H", "inc"], 
           SuperscriptBox["|", "2"]}], ",", 
          RowBox[{"|", 
           SuperscriptBox["E", "inc"], 
           SuperscriptBox["|", "2"], 
           RowBox[{"+", 
            RowBox[{"|", 
             SuperscriptBox["H", "inc"], 
             SuperscriptBox["|", "2"]}]}]}]}], "}"}]}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Eri", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "FieldP", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"k", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}]}]}], ")"}], 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"E\[Theta]i", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{
                "FieldP", "\[LeftDoubleBracket]", "n", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"I", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"E\[Phi]i", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{"I", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Hri", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "FieldP", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"k", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}]}]}], ")"}], 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H\[Theta]i", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"I", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H\[Phi]i", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"I", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Ei2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "E\[Theta]i", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "E\[Phi]i", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "Eri", "]"}], "2"]}]}], ";", 
      RowBox[{"Hi2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "H\[Theta]i", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "H\[Phi]i", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "Hri", "]"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"EiV", "=", 
       RowBox[{"{", 
        RowBox[{
        "E\[Theta]i", ",", "E\[Phi]i", ",", "Eri", ",", "H\[Theta]i", ",", 
         "H\[Phi]i", ",", "Hri", ",", "Ei2", ",", "Hi2", ",", 
         RowBox[{"Ei2", "+", "Hi2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Scattered", " ", "Field", " ", 
         RowBox[{"Components", ":", " ", "EsV"}]}], "=", 
        RowBox[{"{", 
         RowBox[{
          SubsuperscriptBox["E", "\[Theta]", "sca"], ",", 
          SubsuperscriptBox["E", "\[Phi]", "sca"], ",", 
          SubsuperscriptBox["E", "r", "sca"], ",", 
          SubsuperscriptBox["H", "\[Theta]", "sca"], ",", 
          SubsuperscriptBox["H", "\[Phi]", "sca"], ",", 
          SubsuperscriptBox["H", "r", "sca"], ",", 
          RowBox[{"|", 
           SuperscriptBox["E", "sca"], 
           SuperscriptBox["|", "2"]}], ",", 
          RowBox[{"|", 
           SuperscriptBox["H", "sca"], 
           SuperscriptBox["|", "2"]}], ",", 
          RowBox[{"|", 
           SuperscriptBox["E", "sca"], 
           SuperscriptBox["|", "2"], 
           RowBox[{"+", 
            RowBox[{"|", 
             SuperscriptBox["H", "sca"], 
             SuperscriptBox["|", "2"]}]}]}]}], "}"}]}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Ers", "=", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Phi]", "]"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{
           "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "FieldP", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"k", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}]}]}], ")"}], 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"E\[Theta]s", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "/", "r"}], ")"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{
               "anL", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}]}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"I", " ", 
              RowBox[{
              "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"E\[Phi]s", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sin", "[", "\[Phi]", "]"}], "/", "r"}], ")"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{"I", " ", 
              RowBox[{
              "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Hrs", "=", 
       RowBox[{
        RowBox[{"Sin", "[", "\[Phi]", "]"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{
           "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "FieldP", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"k", " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}]}]}], ")"}], 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H\[Theta]s", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sin", "[", "\[Phi]", "]"}], "/", "r"}], ")"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"I", " ", 
              RowBox[{
              "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{
              RowBox[{
              "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H\[Phi]s", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "\[Phi]", "]"}], "/", "r"}], ")"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"I", " ", 
              RowBox[{
              "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{
              RowBox[{
              "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Es2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "E\[Theta]s", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "E\[Phi]s", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "Ers", "]"}], "2"]}]}], ";", 
      RowBox[{"Hs2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "H\[Theta]s", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "H\[Phi]s", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "Hrs", "]"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"EsV", "=", 
       RowBox[{"{", 
        RowBox[{
        "E\[Theta]s", ",", "E\[Phi]s", ",", "Ers", ",", "H\[Theta]s", ",", 
         "H\[Phi]s", ",", "Hrs", ",", "Es2", ",", "Hs2", ",", 
         RowBox[{"Es2", "+", "Hs2"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Interior", " ", "Field", " ", 
         RowBox[{"Components", ":", " ", "EspV"}]}], "=", 
        RowBox[{"{", 
         RowBox[{
          SubsuperscriptBox["E", "\[Theta]", "sp"], ",", 
          SubsuperscriptBox["E", "\[Phi]", "sp"], ",", 
          SubsuperscriptBox["E", "r", "sp"], ",", 
          SubsuperscriptBox["H", "\[Theta]", "sp"], ",", 
          SubsuperscriptBox["H", "\[Phi]", "sp"], ",", 
          SubsuperscriptBox["H", "r", "sp"], ",", 
          RowBox[{"|", 
           SuperscriptBox["E", "sp"], 
           SuperscriptBox["|", "2"]}], ",", 
          RowBox[{"|", 
           SuperscriptBox["H", "sp"], 
           SuperscriptBox["|", "2"]}], ",", 
          RowBox[{"|", 
           SuperscriptBox["E", "sp"], 
           SuperscriptBox["|", "2"], 
           RowBox[{"+", 
            RowBox[{"|", 
             SuperscriptBox["H", "sp"], 
             SuperscriptBox["|", "2"]}]}]}]}], "}"}]}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Ersp", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "\[Phi]", "]"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{
           "cnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "FieldP", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "*", 
                RowBox[{"nParticle", "/", "nmed"}]}], ")"}], " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}]}]}], ")"}], 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"E\[Theta]sp", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{
               "cnL", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}]}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"I", " ", 
              RowBox[{
              "dnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"E\[Phi]sp", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "cnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{"I", " ", 
              RowBox[{
              "dnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Hrsp", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", "\[Phi]", "]"}]}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{
           "dnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
              "FieldP", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"k", "*", 
                RowBox[{"nParticle", "/", "nmed"}]}], ")"}], " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}]}]}], ")"}], 
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H\[Theta]sp", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"I", " ", 
              RowBox[{
              "cnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{
              RowBox[{
              "dnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H\[Phi]sp", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Phi]", "]"}], "/", "r"}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "FieldP", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"I", " ", 
              RowBox[{
              "cnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{
              RowBox[{
              "dnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
               RowBox[{
               "FieldP", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Esp2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "E\[Theta]sp", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "E\[Phi]sp", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "Ersp", "]"}], "2"]}]}], ";", 
      RowBox[{"Hsp2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", "H\[Theta]sp", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "H\[Phi]sp", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "Hrsp", "]"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"EspV", "=", 
       RowBox[{"{", 
        RowBox[{
        "E\[Theta]sp", ",", "E\[Phi]sp", ",", "Ersp", ",", "H\[Theta]sp", ",",
          "H\[Phi]sp", ",", "Hrsp", ",", "Esp2", ",", "Hsp2", ",", 
         RowBox[{"Esp2", "+", "Hsp2"}]}], "}"}]}], ";", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Total", " ", "Field", " ", 
         RowBox[{"Components", ":", " ", "ETotV"}]}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["E", "\[Theta]", "sca"], "+", 
           SubsuperscriptBox["E", "\[Theta]", "inc"]}], ",", " ", 
          RowBox[{"etc", "."}]}], "}"}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Etot2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"E\[Theta]s", "+", "E\[Theta]i"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"E\[Phi]s", "+", "E\[Phi]i"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"Ers", "+", "Eri"}], "]"}], "2"]}]}], ";", 
      RowBox[{"Htot2", "=", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"H\[Theta]s", "+", "H\[Theta]i"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"H\[Phi]s", "+", "H\[Phi]i"}], "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"Hrs", "+", "Hri"}], "]"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ETotV", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"E\[Theta]s", "+", "E\[Theta]i"}], ",", 
         RowBox[{"E\[Phi]s", "+", "E\[Phi]i"}], ",", 
         RowBox[{"Ers", "+", "Eri"}], ",", 
         RowBox[{"H\[Theta]s", "+", "H\[Theta]i"}], ",", 
         RowBox[{"H\[Phi]s", "+", "H\[Phi]i"}], ",", 
         RowBox[{"Hrs", "+", "Hri"}], ",", "Etot2", ",", "Htot2", ",", 
         RowBox[{"Etot2", "+", "Htot2"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"Poynting", " ", 
          RowBox[{"Vectors", ":", " ", "Poynting"}]}], "=", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["S", "r", "tot"], ",", 
           SubsuperscriptBox["S", "\[Theta]", "tot"], ",", 
           SubsuperscriptBox["S", "\[Phi]", "tot"]}], "}"}]}], ",", " ", 
        RowBox[{"PoyntingS", "=", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["S", "r", "sca"], ",", 
           SubsuperscriptBox["S", "\[Theta]", "sca"], ",", 
           SubsuperscriptBox["S", "\[Phi]", "sca"]}], "}"}]}], ",", " ", 
        RowBox[{"PoyntingI", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             SubsuperscriptBox["S", "r", "inc"], ",", 
             SubsuperscriptBox["S", "\[Theta]", "inc"], ",", 
             SubsuperscriptBox["S", "\[Phi]", "inc"]}], "}"}], " ", "and", 
           " ", "PoyntingSP"}], "=", 
          RowBox[{"{", 
           RowBox[{
            SubsuperscriptBox["S", "r", "sp"], ",", 
            SubsuperscriptBox["S", "\[Theta]", "sp"], ",", 
            SubsuperscriptBox["S", "\[Phi]", "sp"]}], "}"}]}]}], ",", " ", 
        RowBox[{
         RowBox[{"and", " ", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["S", "r"], ",", 
            SubscriptBox["S", "\[Theta]"], ",", 
            SubscriptBox["S", "\[Phi]"]}], "}"}]}], "=", 
         RowBox[{"Re", 
          RowBox[{"(", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["E", "\[Theta]"], 
               SubsuperscriptBox["H", "\[Phi]", "*"]}], "-", 
              RowBox[{
               SubscriptBox["E", "\[Phi]"], 
               SubsuperscriptBox["H", "\[Theta]", "*"]}]}], ",", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["E", "r"], 
                 SubsuperscriptBox["H", "\[Phi]", "*"]}], "-", 
                RowBox[{
                 SubscriptBox["E", "\[Phi]"], 
                 SubsuperscriptBox["H", "r", "*"]}]}], ")"}]}], ",", 
             RowBox[{
              RowBox[{
               SubscriptBox["E", "r"], 
               SubsuperscriptBox["H", "\[Theta]", "*"]}], "-", 
              RowBox[{
               SubscriptBox["E", "\[Theta]"], 
               SubsuperscriptBox["H", "r", "*"]}]}]}], "}"}], ")"}]}]}]}], 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Poynting", "=", 
       RowBox[{"Re", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "ETotV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "ETotV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "ETotV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "ETotV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ETotV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "ETotV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "ETotV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "ETotV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ETotV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "ETotV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "ETotV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "ETotV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}]}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"STot2", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
          "Poynting", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "Poynting", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "Poynting", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          "2"]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"PoyntingS", "=", 
       RowBox[{"Re", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "EsV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EsV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EsV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EsV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "EsV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EsV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EsV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EsV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "EsV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EsV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EsV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EsV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}]}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SS2", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
          "PoyntingS", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "PoyntingS", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "PoyntingS", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
           "2"]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"PoyntingI", "=", 
       RowBox[{"Re", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "EiV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EiV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EiV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EiV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "EiV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EiV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EiV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EiV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "EiV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EiV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EiV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EiV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}]}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SI2", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
          "PoyntingI", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "PoyntingI", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "PoyntingI", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
           "2"]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"PoyntingSP", "=", 
       RowBox[{"Re", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
            "EspV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EspV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EspV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EspV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
            "EspV", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EspV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EspV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EspV", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], 
             "]"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
            "EspV", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EspV", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             "]"}]}], "-", 
           RowBox[{
            RowBox[{
            "EspV", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "*", 
            RowBox[{"Conjugate", "[", 
             RowBox[{
             "EspV", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], 
             "]"}]}]}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SSP2", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
          "PoyntingSP", "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "PoyntingSP", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
          "PoyntingSP", "\[LeftDoubleBracket]", "3", 
           "\[RightDoubleBracket]"}], "2"]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Output", " ", 
        RowBox[{"List", ":", " ", 
         RowBox[{"Fields", " ", "and", " ", "Poynting", " ", "Vectors"}]}]}], 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Et", "=", 
       RowBox[{"{", 
        RowBox[{"EiV", ",", "EsV", ",", "EspV", ",", "ETotV", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"r", ">", "R"}], ",", "Poynting", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"r", "<", "R"}], ",", "PoyntingSP", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"r", ">", "R"}], ",", "PoyntingS", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"r", ">", "R"}], ",", "PoyntingI", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"STot2", ",", "SS2", ",", "SI2", ",", "SSP2"}], "}"}]}], 
        "}"}]}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
   3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
   3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
   3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
   3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
   3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
   3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
   3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
   3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
   3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
   3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
   3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
   3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
   3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
   3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
   3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
   3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
   3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
   3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
   3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
   3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
   3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
   3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
   3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
   3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
   3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
   3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
   3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
   3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
   3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
   3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
   3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
   3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
   3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
   3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
   3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
   3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
   3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
   3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
   3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
   3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
   3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
   3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
   3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
   3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
   3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
   3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
   3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
   3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
   3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
   3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
   3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
   3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
   3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
   3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
   3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
   3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
   3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
   3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
   3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
   3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
   3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
   3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
   3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
   3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
   3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
   3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
   3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
   3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
   3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
   3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
   3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
   3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
   3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
   3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
   3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
   3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
   3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
   3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
   3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
   3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
   3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
   3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
   3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
   3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
   3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
   3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
   3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
   3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
   3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
   3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
   3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
   3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
   3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
   3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
   3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
   3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
   3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
   3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
   3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
   3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
   3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}, {
   3.53228811956033*^9, 3.53228814463232*^9}, 3.5322885694137793`*^9, {
   3.532288633051366*^9, 3.532288640729644*^9}, 3.532288693436808*^9, {
   3.532326560676771*^9, 3.532326561467997*^9}, 3.5323267539092283`*^9, {
   3.532326855841176*^9, 3.5323268626361923`*^9}, {3.532327648154467*^9, 
   3.532327648472391*^9}, {3.532328314440467*^9, 3.5323283774651546`*^9}, {
   3.532328422377253*^9, 3.532328424681246*^9}, {3.532328560525572*^9, 
   3.532328568167946*^9}, {3.532328656757094*^9, 3.532328674806654*^9}, {
   3.532369649877342*^9, 3.532369677362103*^9}, {3.532426139880467*^9, 
   3.532426146749992*^9}, {3.5324263708760233`*^9, 3.53242637135772*^9}, {
   3.5324265451015463`*^9, 3.53242664640594*^9}, {3.532426710153561*^9, 
   3.532426712455083*^9}, {3.532426808781193*^9, 3.532426811476164*^9}, {
   3.532426920081225*^9, 3.5324269243890877`*^9}, {3.532427247497072*^9, 
   3.532427247782962*^9}, {3.532427389799304*^9, 3.5324273902035933`*^9}, {
   3.53242773405241*^9, 3.532427734288618*^9}, {3.5324278776010933`*^9, 
   3.532427878162541*^9}, {3.532427978672858*^9, 3.5324279790374527`*^9}, 
   3.532428019187714*^9, 3.532428578606598*^9, {3.5324286292468357`*^9, 
   3.5324286294361553`*^9}, {3.5324287490920963`*^9, 3.532428786648559*^9}, {
   3.532428851541996*^9, 3.532428890715725*^9}, {3.5324291141513567`*^9, 
   3.532429120879005*^9}, {3.5324293995104322`*^9, 3.532429403438241*^9}, {
   3.532429574100875*^9, 3.532429594688299*^9}, {3.5324297964888983`*^9, 
   3.532429799526272*^9}, {3.532430379231759*^9, 3.532430385420787*^9}, {
   3.532461249879245*^9, 3.532461263820463*^9}, {3.532519017925084*^9, 
   3.532519032122608*^9}, {3.532526527088233*^9, 3.5325265440358753`*^9}, {
   3.5326845279221773`*^9, 3.532684538218657*^9}, {3.532684616403873*^9, 
   3.5326847193191137`*^9}, {3.5326847743446608`*^9, 
   3.5326847791223173`*^9}, {3.5326848262379723`*^9, 3.532684826623354*^9}, {
   3.532684993114265*^9, 3.532685016053644*^9}, {3.532685053981876*^9, 
   3.532685054276844*^9}, {3.5326930938293943`*^9, 3.532693094015086*^9}, {
   3.532719132200535*^9, 3.532719157902748*^9}, {3.5327558533588247`*^9, 
   3.5327558541164303`*^9}, 3.532766726445366*^9, {3.53279945619037*^9, 
   3.532799474541209*^9}, {3.5328547531806307`*^9, 3.5328547626942863`*^9}, {
   3.532889639366725*^9, 3.532889681754258*^9}, {3.532889752453826*^9, 
   3.532889826086711*^9}, {3.532889873275487*^9, 3.532889876801948*^9}, {
   3.532890057966181*^9, 3.532890058203142*^9}, {3.5328902298340693`*^9, 
   3.532890296151712*^9}, 3.5328903692293787`*^9, {3.5328904029992867`*^9, 
   3.532890411808332*^9}, {3.532892206439148*^9, 3.5328922075044518`*^9}, {
   3.5328922802358723`*^9, 3.532892280824774*^9}, {3.53292574814461*^9, 
   3.532925797752677*^9}, {3.532926124318124*^9, 3.5329261244685383`*^9}, 
   3.532926245852261*^9, {3.5329265689394712`*^9, 3.532926570000724*^9}, {
   3.532927806123478*^9, 3.532927906601138*^9}, {3.532928541923399*^9, 
   3.532928542184353*^9}, {3.532942425439447*^9, 3.532942425643545*^9}, {
   3.53294379960877*^9, 3.532943799729001*^9}, {3.532944561800413*^9, 
   3.532944562537307*^9}, {3.532945363163622*^9, 3.532945364969389*^9}, 
   3.532945453748047*^9, {3.532945507096512*^9, 3.532945529973261*^9}, {
   3.5329455638179398`*^9, 3.5329456100961733`*^9}, {3.5330199613331537`*^9, 
   3.53301996789213*^9}, {3.533025930245824*^9, 3.533025936728265*^9}, {
   3.533025989637192*^9, 3.533026067353613*^9}, 3.533027178074147*^9, {
   3.5331117027217407`*^9, 3.533111703037171*^9}, {3.533117076494013*^9, 
   3.533117079507195*^9}, 3.533123562826027*^9, {3.533126655128166*^9, 
   3.533126658767866*^9}, 3.533149740861843*^9, {3.533198581738796*^9, 
   3.533198585522266*^9}, {3.5332174893963213`*^9, 3.5332175238336163`*^9}, {
   3.533225989098296*^9, 3.533225989240814*^9}, {3.533232253786924*^9, 
   3.533232257138947*^9}, {3.533236075371122*^9, 3.533236146977006*^9}, {
   3.533238618388226*^9, 3.533238639565093*^9}, {3.533238674371769*^9, 
   3.533238674619027*^9}, {3.554282890723061*^9, 3.5542828915908947`*^9}, {
   3.554458317175798*^9, 3.554458460708013*^9}, {3.5544585374013767`*^9, 
   3.55445859192402*^9}, {3.554458688136119*^9, 3.554458734323386*^9}, {
   3.55452521277927*^9, 3.554525213952197*^9}, {3.554525244636451*^9, 
   3.554525256295351*^9}, 3.554525381167959*^9, {3.55774036903944*^9, 
   3.557740371839279*^9}, {3.557740476367394*^9, 3.557740508772482*^9}, {
   3.572086737301703*^9, 3.572086739871395*^9}, 3.572087068408938*^9, 
   3.572087407620016*^9, {3.572088098040041*^9, 3.5720880999690943`*^9}, {
   3.5772947386656713`*^9, 3.577294766580621*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Define Collected Scatter-Signal and PT-Signal function (On-Axis)", 
  "Title"],
 "\n",
 StyleBox["(Integration of Flux over a discrete angular domain \[Theta]T={\
\[Theta]min,...,\[Theta]max} in rad) and Photothermal function as Difference\n\
\"Nano-lens diffraction around a single heated nano particle\", Optics \
Express, Vol. 20, No. 7, pp. 8055-8070, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", M. Selmke, M. Braun, F. Cichos, (early version: \
arXiv:1109.2772v1)",
  FontSize->12],
 StyleBox["\n",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Photothermal Single Particle Microscopy: Detection of a Nanolens\
\", ACS Nano, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1) \nA radii-table which defines the \
specific discretization of the n(r) profile in the medium is required, i.e. \
rT={R(particle), r_2, r_3, ...}",
  FontSize->12]
}], "Title",
 CellChangeTimes->{
  3.52157698243744*^9, {3.521619109724292*^9, 3.521619121363326*^9}, {
   3.521619160891412*^9, 3.5216192265585127`*^9}, {3.521621422921493*^9, 
   3.521621424176527*^9}, 3.554213210484359*^9, {3.554213243463027*^9, 
   3.554213254880499*^9}, {3.5544498843928537`*^9, 3.5544498923109503`*^9}, {
   3.554449930432259*^9, 3.5544499306727657`*^9}, {3.557590110151206*^9, 
   3.557590112379148*^9}, {3.557740524669976*^9, 3.55774059599072*^9}, {
   3.5577406543321857`*^9, 3.5577406812825727`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"Maximum", " ", "needed", " ", "n", " ", "for", " ", 
      RowBox[{"gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}],
      "<", 
     RowBox[{
      RowBox[{"gnT", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}], 
      "/", 
      SuperscriptBox["10", "10"]}]}], ",", " ", 
    RowBox[{"This", " ", "function", " ", "is", " ", "not", " ", "needed"}], 
    ",", " ", 
    RowBox[{"jsut", " ", "for", " ", "fun"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"PTSignal", ",", "Signal"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gnMaxN", "[", 
      RowBox[{"z00_", ",", "ss_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"s", "=", "ss"}], ",", 
         RowBox[{"z0", "=", "z00"}], ",", 
         RowBox[{"Nmaxgn", "=", "1"}], ",", "T", ",", 
         RowBox[{"n", "=", "1"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"T", "=", 
         RowBox[{
          SuperscriptBox["10", 
           RowBox[{"-", "12"}]], 
          RowBox[{"Abs", "[", 
           RowBox[{"gnMLA", "[", 
            RowBox[{"1", ",", "s", ",", 
             FractionBox[
              RowBox[{"2", " ", "z0"}], "w0"]}], "]"}], "]"}]}]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"s", "<", "0.001"}], ",", 
          RowBox[{"Nmaxgn", "=", "100"}], ",", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"gnMLA", "[", 
               RowBox[{"n", ",", "s", ",", 
                FractionBox[
                 RowBox[{"2", " ", "z0"}], "w0"]}], "]"}], "]"}], ">", "T"}], 
            ",", 
            RowBox[{
             RowBox[{"Nmaxgn", "=", 
              RowBox[{"Nmaxgn", "+", "1"}]}], ";", 
             RowBox[{"n", "++"}]}]}], "]"}]}], "]"}], ";", "Nmaxgn"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Total", " ", "Detected", " ", "Signal"}], ",", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"z0", ":", " ", 
        RowBox[{
        "position", " ", "of", " ", "beam", " ", "rel", " ", "to", " ", 
         "particle"}]}], ",", " ", 
       RowBox[{"\[Theta]T", "=", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Theta]min", ",", "..", ",", "\[Theta]max"}], "}"}], " ", 
         "angles", " ", "for", " ", "numerical", " ", "integration"}]}], ",", 
       " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"an", ",", "bn"}], "}"}], ":", " ", 
        RowBox[{"Tables", " ", "of", " ", "scatter", " ", 
         RowBox[{"coeff", "."}]}]}]}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Signal", "[", 
      RowBox[{
      "z00_", ",", "\[Theta]TT_", ",", "ss_", ",", "w00_", ",", "anT_", ",", 
       "bnT_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"z0", "=", "z00"}], ",", 
         RowBox[{"\[Theta]T", "=", "\[Theta]TT"}], ",", 
         RowBox[{"s", "=", "ss"}], ",", 
         RowBox[{"w0", "=", "w00"}], ",", 
         RowBox[{"an", "=", "anT"}], ",", 
         RowBox[{"bn", "=", "bnT"}], ",", "gnT", ",", "SignalV", ",", 
         "\[CapitalDelta]T0z0", ",", "n", ",", "m", ",", "Nmax", ",", 
         "\[Theta]i", ",", "N\[Theta]", ",", 
         RowBox[{"CincI", "=", "0"}], ",", 
         RowBox[{"CsI", "=", "0"}], ",", 
         RowBox[{"CisI", "=", "0"}], ",", "S1", ",", "S2", ",", "Cs", ",", 
         "Cinc", ",", "Cis", ",", "M", ",", "Nn", ",", "\[Theta]", ",", 
         "\[Pi]n\[Tau]n", ",", "\[Pi]n", ",", "\[Tau]n", ",", "Cext", ",", 
         "Csca", ",", "Cabs", ",", "d\[Theta]"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"N\[Theta]", "=", 
         RowBox[{"Length", "[", "\[Theta]T", "]"}]}], ";", 
        RowBox[{"S1", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"\[Theta]i", ",", "1", ",", "N\[Theta]"}], "}"}]}], 
          "]"}]}], ";", 
        RowBox[{"S2", "=", "S1"}], ";", 
        RowBox[{"M", "=", "S1"}], ";", 
        RowBox[{"Cs", "=", "S1"}], ";", 
        RowBox[{"Cis", "=", "S1"}], ";", 
        RowBox[{"Cinc", "=", "S1"}], ";", 
        RowBox[{"d\[Theta]", "=", 
         RowBox[{
          RowBox[{
          "\[Theta]T", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "-", 
          RowBox[{
          "\[Theta]T", "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Nmax", "=", 
         RowBox[{"Min", "[", 
          RowBox[{
           RowBox[{"gnMaxN", "[", 
            RowBox[{"z0", ",", "s"}], "]"}], ",", 
           RowBox[{"Length", "[", "an", "]"}]}], "]"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Nmax", "=", 
           RowBox[{"Length", "[", "an", "]"}]}], ";"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "Get", " ", "Gaussian", " ", "BSC", " ", "for", " ", "z0", " ", 
           "value"}], ",", " ", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{"2", 
            RowBox[{"z0", "/", "w0"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"gnT", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"gnMLA", "[", 
             RowBox[{"n", ",", "s", ",", 
              RowBox[{"2", " ", 
               RowBox[{"z0", "/", "w0"}]}]}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Nmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
        RowBox[{"Nn", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"n", 
              RowBox[{"(", 
               RowBox[{"n", "+", "1"}], ")"}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Nmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Get", " ", "Signal"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"\[Theta]i", "=", "1"}], ",", 
          RowBox[{"\[Theta]i", "\[LessEqual]", "N\[Theta]"}], ",", 
          RowBox[{"\[Theta]i", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"\[Theta]", "=", 
            RowBox[{
            "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}]}], ";", 
           RowBox[{"\[Pi]n\[Tau]n", "=", 
            RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
             RowBox[{"\[Theta]", ",", 
              RowBox[{"Nmax", "+", "2"}]}], "]"}]}], ";", 
           RowBox[{"\[Pi]n", "=", 
            RowBox[{
            "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}], ";", 
           RowBox[{"\[Tau]n", "=", 
            RowBox[{
            "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "S1", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "1"}], "Nmax"], 
             RowBox[{
              RowBox[{
              "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
              "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  " ", 
                 RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
                RowBox[{
                 RowBox[{
                 "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  " ", 
                 RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
               ")"}]}]}]}], ";", 
           RowBox[{
            RowBox[{
            "S2", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "1"}], "Nmax"], 
             RowBox[{
              RowBox[{
              "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
              "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  " ", 
                 RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
                RowBox[{
                 RowBox[{
                 "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  " ", 
                 RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
               ")"}]}]}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "M", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "1"}], "Nmax"], 
             RowBox[{
              RowBox[{
              "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
              "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                 RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "+", 
                RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                 RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], 
               ")"}]}]}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "Cs", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "S1", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "S2", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "]"}], "2"]}]}], ";", 
           RowBox[{"CsI", "=", 
            RowBox[{"CsI", "+", 
             RowBox[{"d\[Theta]", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}], 
              RowBox[{
              "Cs", "\[LeftDoubleBracket]", "\[Theta]i", 
               "\[RightDoubleBracket]"}]}]}]}], ";", 
           RowBox[{"(*", 
            RowBox[{"Scatter", " ", "Term"}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{
              RowBox[{
              "Cis", "\[LeftDoubleBracket]", "\[Theta]i", 
               "\[RightDoubleBracket]"}], "=", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Im", "[", 
                  RowBox[{
                  "M", "\[LeftDoubleBracket]", "\[Theta]i", 
                   "\[RightDoubleBracket]"}], "]"}], " ", 
                 RowBox[{"Im", "[", 
                  RowBox[{
                   RowBox[{
                   "S1", "\[LeftDoubleBracket]", "\[Theta]i", 
                    "\[RightDoubleBracket]"}], "+", 
                   RowBox[{
                   "S2", "\[LeftDoubleBracket]", "\[Theta]i", 
                    "\[RightDoubleBracket]"}]}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Re", "[", 
                  RowBox[{
                  "M", "\[LeftDoubleBracket]", "\[Theta]i", 
                   "\[RightDoubleBracket]"}], "]"}], " ", 
                 RowBox[{"Re", "[", 
                  RowBox[{
                   RowBox[{
                   "S1", "\[LeftDoubleBracket]", "\[Theta]i", 
                    "\[RightDoubleBracket]"}], "+", 
                   RowBox[{
                   "S2", "\[LeftDoubleBracket]", "\[Theta]i", 
                    "\[RightDoubleBracket]"}]}], "]"}]}]}], ")"}]}], ";", 
             RowBox[{"CisI", "=", 
              RowBox[{"CisI", "+", 
               RowBox[{
                RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                RowBox[{
                "Cis", "\[LeftDoubleBracket]", "\[Theta]i", 
                 "\[RightDoubleBracket]"}]}]}]}], ";"}], 
            RowBox[{"(*", 
             RowBox[{"Interference", " ", "Term"}], "*)"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "Cis", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{"Re", "[", 
             RowBox[{
              RowBox[{"Conjugate", "[", 
               RowBox[{
               "M", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "S1", "\[LeftDoubleBracket]", "\[Theta]i", 
                 "\[RightDoubleBracket]"}], "+", 
                RowBox[{
                "S2", "\[LeftDoubleBracket]", "\[Theta]i", 
                 "\[RightDoubleBracket]"}]}], ")"}]}], "]"}]}], ";", 
           RowBox[{"CisI", "=", 
            RowBox[{"CisI", "+", 
             RowBox[{"d\[Theta]", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}], 
              RowBox[{
              "Cis", "\[LeftDoubleBracket]", "\[Theta]i", 
               "\[RightDoubleBracket]"}]}]}]}], ";", 
           RowBox[{"(*", 
            RowBox[{"Interference", " ", "Term"}], "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "Cinc", "\[LeftDoubleBracket]", "\[Theta]i", 
             "\[RightDoubleBracket]"}], "=", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "1"}], "Nmax"], 
             RowBox[{"(", 
              RowBox[{
               UnderoverscriptBox["\[Sum]", 
                RowBox[{"m", "=", "1"}], "n"], 
               RowBox[{
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}],
                 " ", 
                RowBox[{
                "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
                " ", 
                RowBox[{"Nn", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"-", "m"}], "+", "n", "+", "1"}], 
                 "\[RightDoubleBracket]"}], " ", 
                RowBox[{"Conjugate", "[", 
                 RowBox[{"gnT", "\[LeftDoubleBracket]", 
                  RowBox[{
                   RowBox[{"-", "m"}], "+", "n", "+", "1"}], 
                  "\[RightDoubleBracket]"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], "+", 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"-", "m"}], "+", "n", "+", "2"}], 
                    "\[RightDoubleBracket]"}], "+", 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"-", "m"}], "+", "n", "+", "2"}], 
                    "\[RightDoubleBracket]"}]}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "+", "1"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], "-", 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"-", "m"}], "+", "n", "+", "2"}], 
                    "\[RightDoubleBracket]"}], "-", 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"-", "m"}], "+", "n", "+", "2"}], 
                    "\[RightDoubleBracket]"}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ";", 
           RowBox[{"(*", 
            RowBox[{"Incidence", " ", "Term"}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{"CincI", "=", 
            RowBox[{"CincI", "+", 
             RowBox[{"d\[Theta]", " ", 
              RowBox[{
              "Cinc", "\[LeftDoubleBracket]", "\[Theta]i", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Csca", "=", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "Nmax"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], "2"]}], ")"}]}]}]}], ";", 
        RowBox[{"Cext", "=", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "Nmax"], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], 
           RowBox[{"Re", "[", 
            RowBox[{
             RowBox[{
             "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{
             "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
            "]"}]}]}]}], ";", 
        RowBox[{"Cabs", "=", 
         RowBox[{"Cext", "-", "Csca"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"SignalV", "=", 
         RowBox[{"CsI", "-", "CisI"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"Total", " ", "Scatterer", " ", "Dependent", " ", "Signal"}],
          "*)"}], "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "SignalV"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"8", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], 
           RowBox[{"Re", "[", "CincI", "]"}]}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cs"}], ",", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[Lambda]", "2"], " "}], 
             RowBox[{"4", "\[Pi]", " ", 
              SuperscriptBox["nmed", "2"]}]]}], "Cis"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"8", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], 
           RowBox[{"Re", "[", "Cinc", "]"}]}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "CsI"}], ",", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[Lambda]", "2"], " "}], 
             RowBox[{"4", "\[Pi]", " ", 
              SuperscriptBox["nmed", "2"]}]]}], "CisI"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Csca"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cext"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cabs"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SignalExact", "[", 
      RowBox[{
      "z00_", ",", "\[Theta]End_", ",", "ss_", ",", "w00_", ",", "anT_", ",", 
       "bnT_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"z0", "=", "z00"}], ",", 
         RowBox[{"\[Theta]f", "=", "\[Theta]End"}], ",", 
         RowBox[{"s", "=", "ss"}], ",", 
         RowBox[{"w0", "=", "w00"}], ",", 
         RowBox[{"an", "=", "anT"}], ",", 
         RowBox[{"bn", "=", "bnT"}], ",", "gnT", ",", "Nmax", ",", "SignalV", 
         ",", "IncI", ",", "IncIE", ",", "n", ",", "m", ",", "ExtI", ",", 
         "ScaI", ",", "ExtIR", ",", "ScaIR", ",", "\[Pi]n\[Tau]n", ",", 
         "\[Pi]n", ",", "\[Tau]n", ",", "Cext", ",", "Csca", ",", "Cabs", ",",
          "Hnf", ",", "Hn0", ",", "a1Mult"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Nmax", "=", 
         RowBox[{"Min", "[", 
          RowBox[{
           RowBox[{"gnMaxN", "[", 
            RowBox[{"z0", ",", "s"}], "]"}], ",", 
           RowBox[{"Length", "[", "an", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "Get", " ", "Gaussian", " ", "BSC", " ", "for", " ", "z0", " ", 
           "value"}], ",", " ", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{"2", 
            RowBox[{"z0", "/", "w0"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"gnT", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"gnMLA", "[", 
             RowBox[{"n", ",", "s", ",", 
              RowBox[{"2", " ", 
               RowBox[{"z0", "/", "w0"}]}]}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Nmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Get", " ", "Signal"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"\[Pi]n\[Tau]n", "=", 
         RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
          RowBox[{"\[Theta]f", ",", 
           RowBox[{"Nmax", "+", "2"}]}], "]"}]}], ";", 
        RowBox[{"\[Pi]n", "=", 
         RowBox[{
         "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}]}], ";", 
        RowBox[{"\[Tau]n", "=", 
         RowBox[{
         "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Hnf", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Nmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
        RowBox[{
         RowBox[{
         "Hnf", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Theta]f", "]"}], "2"]}], ")"}]}], "-", 
          "2"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"n", "=", "1"}], ",", 
          RowBox[{"n", "\[LessEqual]", "Nmax"}], ",", 
          RowBox[{"n", "++"}], ",", 
          RowBox[{
           RowBox[{"Hnf", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "=", 
           RowBox[{
            FractionBox["1", "n"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "+", "2"}], ")"}], 
               RowBox[{
               "Hnf", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "2"}], ")"}], 
                    SuperscriptBox[
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "2"]}], "+", 
                    RowBox[{"n", "*", 
                    SuperscriptBox[
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "2"}], "\[RightDoubleBracket]"}], 
                    "2"]}]}], ")"}]}], "-", 
                 RowBox[{"2", 
                  RowBox[{"(", 
                   RowBox[{"n", "+", "1"}], ")"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "2"}], "\[RightDoubleBracket]"}]}]}], 
                ")"}]}]}], ")"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"ExtI", "=", 
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "2"}], "Nmax"], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"m", "=", "1"}], 
               RowBox[{"n", "-", "1"}]], 
              RowBox[{
               FractionBox["1", 
                RowBox[{
                 RowBox[{"n", 
                  RowBox[{"(", 
                   RowBox[{"n", "+", "1"}], ")"}]}], "-", 
                 RowBox[{"m", 
                  RowBox[{"(", 
                   RowBox[{"m", "+", "1"}], ")"}]}]}]], 
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "gnT", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{
                  "gnT", "\[LeftDoubleBracket]", "m", 
                   "\[RightDoubleBracket]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    "an", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "+", 
                    RowBox[{
                    "bn", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "gnT", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{
                  "gnT", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    "an", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "+", 
                    RowBox[{
                    "bn", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}]}]}], ")"}], 
               SuperscriptBox[
                RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"m", 
                  RowBox[{"(", 
                   RowBox[{"m", "+", "1"}], ")"}], 
                  RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
                 
                 RowBox[{"n", 
                  RowBox[{"(", 
                   RowBox[{"n", "+", "1"}], ")"}], 
                  RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                ")"}]}]}]}]}], "+", "\[IndentingNewLine]", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"n", "=", "1"}], "Nmax"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "+", 
                RowBox[{
                "bn", "\[LeftDoubleBracket]", "n", 
                 "\[RightDoubleBracket]"}]}], ")"}], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
                 RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                 RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
                RowBox[{
                 FractionBox[
                  RowBox[{"n", 
                   RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], 
                  RowBox[{
                   RowBox[{"2", "n"}], "+", "1"}]], 
                 RowBox[{
                 "Hnf", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], ")"}]}], "+", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"n", "=", "1"}], "Nmax"], 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"m", "=", "1"}], "Nmax"], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               " ", 
               RowBox[{"Conjugate", "[", 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 "]"}], 
               RowBox[{
               "gnT", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                 "an", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}],
                  "+", 
                 RowBox[{
                 "bn", "\[LeftDoubleBracket]", "m", 
                  "\[RightDoubleBracket]"}]}], ")"}], 
               RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
               RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
               SuperscriptBox[
                RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"]}], ")"}]}]}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ScaI", "=", 
         RowBox[{
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n", "=", "2"}], "Nmax"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", "1"}], 
             RowBox[{"n", "-", "1"}]], 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"m", 
                  RowBox[{"(", 
                   RowBox[{"m", "+", "1"}], ")"}], 
                  RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
                 
                 RowBox[{"n", 
                  RowBox[{"(", 
                   RowBox[{"n", "+", "1"}], ")"}], 
                  RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                ")"}], 
               RowBox[{
                RowBox[{"n", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "1"}], ")"}]}], "-", 
                RowBox[{"m", 
                 RowBox[{"(", 
                  RowBox[{"m", "+", "1"}], ")"}]}]}]], 
              RowBox[{
              "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              RowBox[{
              "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{"Re", "[", 
               RowBox[{
                RowBox[{"Conjugate", "[", 
                 RowBox[{
                 "gnT", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "]"}], 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "an", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}], 
                   RowBox[{
                   "an", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bn", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}], 
                   RowBox[{
                   "bn", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}], "]"}], 
              SuperscriptBox[
               RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}]}], ")"}]}]}], "+", 
          "\[IndentingNewLine]", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n", "=", "1"}], "Nmax"], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Abs", "[", 
              RowBox[{
              "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "2"], 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "]"}], "2"]}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
               RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
               RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
              RowBox[{
               FractionBox[
                RowBox[{"n", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "1"}], ")"}]}], 
                RowBox[{
                 RowBox[{"2", "n"}], "+", "1"}]], 
               RowBox[{
               "Hnf", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}]}]}], ")"}]}]}], "+", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n", "=", "1"}], "Nmax"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", "1"}], "Nmax"], 
            RowBox[{
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
             RowBox[{"Conjugate", "[", 
              RowBox[{
              "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "]"}], 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Conjugate", "[", 
                 RowBox[{
                 "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  "]"}], 
                RowBox[{
                "bn", "\[LeftDoubleBracket]", "m", 
                 "\[RightDoubleBracket]"}]}], "+", 
               RowBox[{
                RowBox[{"Conjugate", "[", 
                 RowBox[{
                 "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  "]"}], 
                RowBox[{
                "an", "\[LeftDoubleBracket]", "m", 
                 "\[RightDoubleBracket]"}]}]}], ")"}], 
             RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
             RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
              RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"]}]}]}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"IncI", "=", 
         RowBox[{
          FractionBox["\[Pi]", "2"], 
          SuperscriptBox["w0", "2"], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                RowBox[{"Tan", "[", "\[Theta]f", "]"}], "2"]}], 
              SuperscriptBox["k", "2"], 
              RowBox[{
               SuperscriptBox["w0", "2"], "/", "2"}]}], "]"}]}], ")"}]}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"IncIE", "=", 
         RowBox[{
          FractionBox["\[Pi]", 
           SuperscriptBox["k", "2"]], 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "1"}], "Nmax"], 
             RowBox[{
              SuperscriptBox[
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "2"], " ", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 "]"}], "2"], 
              SuperscriptBox[
               RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "2"]}]}], 
            "+", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "2"}], "Nmax"], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"m", "=", "1"}], 
               RowBox[{"n", "-", "1"}]], 
              RowBox[{
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               RowBox[{"Conjugate", "[", 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 "]"}], 
               RowBox[{
               "gnT", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "+", "m"}]]}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "+", "m"}]]}], ")"}], 
                  FractionBox[
                   RowBox[{
                    RowBox[{"m", 
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], 
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                   RowBox[{
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], "-", 
                    RowBox[{"m", 
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]}]]}]}], ")"}]}]}]}]}], 
           ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Csca", "=", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "Nmax"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
               "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], "2"]}], ")"}]}]}]}], ";", 
        RowBox[{"Cext", "=", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "Nmax"], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "]"}], "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "n"}], "+", "1"}], ")"}], 
           RowBox[{"Re", "[", 
            RowBox[{
             RowBox[{
             "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{
             "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
            "]"}]}]}]}], ";", 
        RowBox[{"Cabs", "=", 
         RowBox[{"Cext", "-", "Csca"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"SignalV", "=", 
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"-", "ExtI"}], "+", "ScaI"}], "]"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"Total", " ", "Scatterer", " ", "Dependent", " ", "Signal"}],
          "*)"}], "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "SignalV"}], ",", 
          RowBox[{"Re", "[", "IncIE", "]"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], 
           RowBox[{"Re", "[", "ScaI", "]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[Lambda]", "2"], " "}], 
             RowBox[{"4", "\[Pi]", " ", 
              SuperscriptBox["nmed", "2"]}]]}], "ExtI"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Csca"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cext"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cabs"}], ",", "IncI", ",", 
          "Nmax"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SignalRayleigh", "[", 
      RowBox[{
      "z00_", ",", "\[Theta]TT_", ",", "zRR_", ",", "w00_", ",", "alphaa_"}], 
      "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"z0", "=", "z00"}], ",", 
         RowBox[{"\[Theta]T", "=", "\[Theta]TT"}], ",", 
         RowBox[{"zR", "=", "zRR"}], ",", 
         RowBox[{"w0", "=", "w00"}], ",", 
         RowBox[{"\[Alpha]", "=", "alphaa"}], ",", "gnT", ",", "SignalV", ",",
          "\[CapitalDelta]T0z0", ",", "n", ",", "m", ",", "Nmax", ",", 
         "\[Theta]i", ",", "N\[Theta]", ",", 
         RowBox[{"CincI", "=", "0"}], ",", 
         RowBox[{"CsI", "=", "0"}], ",", 
         RowBox[{"CisI", "=", "0"}], ",", "S1pS2", ",", "Cs", ",", "Cinc", 
         ",", "Cis", ",", "M", ",", "\[Theta]", ",", "\[Pi]n\[Tau]n", ",", 
         "\[Pi]n", ",", "\[Tau]n", ",", "Cext", ",", "Csca", ",", "Cabs", ",",
          "a1", ",", "a1Mult", ",", "ExtIR", ",", "ScaIR", ",", "\[Theta]f", 
         ",", "IncIE", ",", "IncI", ",", "d\[Theta]"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"N\[Theta]", "=", 
         RowBox[{"Length", "[", "\[Theta]T", "]"}]}], ";", 
        RowBox[{"S1pS2", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"\[Theta]i", ",", "1", ",", "N\[Theta]"}], "}"}]}], 
          "]"}]}], ";", 
        RowBox[{"M", "=", "S1pS2"}], ";", 
        RowBox[{"Cs", "=", "M"}], ";", 
        RowBox[{"Cis", "=", "M"}], ";", 
        RowBox[{"Cinc", "=", "M"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Nmax", "=", 
         RowBox[{"Min", "[", 
          RowBox[{
           RowBox[{"gnMaxN", "[", 
            RowBox[{"z0", ",", "s"}], "]"}], ",", "100"}], "]"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Nmax", "=", 
           RowBox[{"Length", "[", "an", "]"}]}], ";"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Nmax", "=", "10"}], ";"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "Get", " ", "Gaussian", " ", "BSC", " ", "for", " ", "z0", " ", 
           "value"}], ",", " ", 
          RowBox[{"\[Gamma]", "=", 
           RowBox[{"2", 
            RowBox[{"z0", "/", "w0"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"gnT", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{"gnMLA", "[", 
             RowBox[{"n", ",", 
              RowBox[{"w0", "/", 
               RowBox[{"(", 
                RowBox[{"2", "zR"}], ")"}]}], ",", 
              RowBox[{"2", " ", 
               RowBox[{"z0", "/", "w0"}]}]}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Nmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Get", " ", "Signal"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"a1", "=", 
         RowBox[{"I", " ", "\[Alpha]", " ", 
          RowBox[{
           SuperscriptBox["k", "3"], "/", 
           RowBox[{"(", 
            RowBox[{"6", "\[Pi]"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"a1", "=", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"k", " ", "R"}], ")"}], "3"], 
            FractionBox[
             RowBox[{"2", "I"}], "3"], 
            FractionBox[
             RowBox[{
              SuperscriptBox["Mn", "2"], "-", "1"}], 
             RowBox[{
              SuperscriptBox["Mn", "2"], "+", "2"}]], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{
               FractionBox["3", "5"], 
               FractionBox[
                RowBox[{
                 SuperscriptBox["Mn", "2"], "-", "2"}], 
                RowBox[{
                 SuperscriptBox["Mn", "2"], "+", "2"}]], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"k", " ", "R"}], ")"}], "2"]}], "-", 
              RowBox[{
               FractionBox[
                RowBox[{"2", "I"}], "3"], 
               FractionBox[
                RowBox[{
                 SuperscriptBox["Mn", "2"], "-", "1"}], 
                RowBox[{
                 SuperscriptBox["Mn", "2"], "+", "2"}]], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"k", " ", "R"}], ")"}], "3"]}]}], ")"}]}]}], ";"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"\[Theta]f", "=", 
         RowBox[{"Last", "[", "\[Theta]T", "]"}]}], ";", 
        RowBox[{"\[Pi]n\[Tau]n", "=", 
         RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
          RowBox[{"\[Theta]f", ",", 
           RowBox[{"Nmax", "+", "2"}]}], "]"}]}], ";", 
        RowBox[{"\[Pi]n", "=", 
         RowBox[{
         "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}]}], ";", 
        RowBox[{"\[Tau]n", "=", 
         RowBox[{
         "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"a1Mult", "=", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["3", "4"], 
            SuperscriptBox[
             RowBox[{"Abs", "[", 
              RowBox[{
              "gnT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "]"}], "2"], 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              FractionBox["\[Theta]f", "2"], "]"}], "2"], 
            RowBox[{"(", 
             RowBox[{"15", "+", 
              RowBox[{"8", 
               RowBox[{"Cos", "[", "\[Theta]f", "]"}]}], "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", "\[Theta]f"}], "]"}]}], ")"}]}], "+", 
           RowBox[{
            FractionBox["3", "2"], 
            RowBox[{
            "gnT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "2"}], "Nmax"], 
             RowBox[{
              RowBox[{"Conjugate", "[", 
               RowBox[{
               "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "]"}], " ", 
              RowBox[{
              "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              FractionBox[
               RowBox[{
                RowBox[{"n", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "1"}], ")"}], 
                 RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                  RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", "\[Theta]f", "]"}], "+", "1"}], 
                  ")"}]}], "-", 
                RowBox[{"2", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "+", 
                   RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], 
                  ")"}]}]}], 
               RowBox[{
                RowBox[{"n", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "1"}], ")"}]}], "-", "2"}]]}]}]}]}], 
          ")"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ExtIR", "=", 
         RowBox[{"Re", "[", 
          RowBox[{"a1", " ", "a1Mult"}], "]"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"ScaIR", "=", 
         RowBox[{
          FractionBox["3", "4"], " ", 
          SuperscriptBox[
           RowBox[{"Abs", "[", "a1", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{
            "gnT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{"4", "-", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", "\[Theta]f", "]"}]}], "-", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]f", "]"}], "3"]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"SignalV", "=", 
         RowBox[{"ScaIR", "-", "ExtIR"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"Total", " ", "Scatterer", " ", "Dependent", " ", "Signal"}],
          "*)"}], "\[IndentingNewLine]", 
        RowBox[{"IncI", "=", 
         RowBox[{
          FractionBox["\[Pi]", "2"], 
          SuperscriptBox["w0", "2"], 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                RowBox[{"Tan", "[", "\[Theta]f", "]"}], "2"]}], 
              SuperscriptBox["k", "2"], 
              RowBox[{
               SuperscriptBox["w0", "2"], "/", "2"}]}], "]"}]}], ")"}]}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"IncIE", "=", 
         RowBox[{
          FractionBox["\[Pi]", 
           SuperscriptBox["k", "2"]], 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "1"}], "Nmax"], 
             RowBox[{
              SuperscriptBox[
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "2"], " ", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 "]"}], "2"], 
              SuperscriptBox[
               RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "2"]}]}], 
            "+", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"n", "=", "2"}], "Nmax"], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"m", "=", "1"}], 
               RowBox[{"n", "-", "1"}]], 
              RowBox[{
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               RowBox[{
               "Nn", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               RowBox[{"Conjugate", "[", 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 "]"}], 
               RowBox[{
               "gnT", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
               
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "+", "m"}]]}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], 
                    RowBox[{"n", "+", "m"}]]}], ")"}], 
                  FractionBox[
                   RowBox[{
                    RowBox[{"m", 
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], 
                    RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                   RowBox[{
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], "-", 
                    RowBox[{"m", 
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}]}]}]]}]}], ")"}]}]}]}]}], 
           ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"N\[Theta]", ">", "1"}], ";", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"\[Theta]i", "=", "1"}], ",", 
             RowBox[{"\[Theta]i", "\[LessEqual]", "N\[Theta]"}], ",", 
             RowBox[{"\[Theta]i", "++"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[Theta]", "=", 
               RowBox[{
               "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}]}], ";", 
              RowBox[{"\[Pi]n\[Tau]n", "=", 
               RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
                RowBox[{"\[Theta]", ",", 
                 RowBox[{"Nmax", "+", "2"}]}], "]"}]}], ";", 
              RowBox[{"\[Pi]n", "=", 
               RowBox[{
               "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}]}], ";", 
              RowBox[{"\[Tau]n", "=", 
               RowBox[{
               "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
               "S1pS2", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "/", "2"}], ")"}], 
                RowBox[{
                "gnT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                 "a1", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}]}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
               "M", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "=", 
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"n", "=", "1"}], "Nmax"], 
                RowBox[{
                 RowBox[{
                 "gnT", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                 "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                  " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "+", 
                   RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], 
                  ")"}]}]}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
               "Cs", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"9", "/", "4"}], ")"}], 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{
                   "gnT", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "a1"}], "]"}], "2"], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], ")"}]}]}], 
              ";", 
              RowBox[{"CsI", "=", 
               RowBox[{"CsI", "+", 
                RowBox[{
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                 RowBox[{
                 "Cs", "\[LeftDoubleBracket]", "\[Theta]i", 
                  "\[RightDoubleBracket]"}]}]}]}], ";", 
              RowBox[{"(*", 
               RowBox[{"Scatter", " ", "Term"}], "*)"}], 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
               "Cis", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "=", 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{"Conjugate", "[", 
                  RowBox[{
                  "M", "\[LeftDoubleBracket]", "\[Theta]i", 
                   "\[RightDoubleBracket]"}], "]"}], 
                 RowBox[{
                 "S1pS2", "\[LeftDoubleBracket]", "\[Theta]i", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], ";", 
              RowBox[{"CisI", "=", 
               RowBox[{"CisI", "+", 
                RowBox[{
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                 RowBox[{
                 "Cis", "\[LeftDoubleBracket]", "\[Theta]i", 
                  "\[RightDoubleBracket]"}]}]}]}], ";", 
              RowBox[{"(*", 
               RowBox[{"Interference", " ", "Term"}], "*)"}], 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
               "Cinc", "\[LeftDoubleBracket]", "\[Theta]i", 
                "\[RightDoubleBracket]"}], "=", 
               RowBox[{
                FractionBox["\[Pi]", "2"], 
                SuperscriptBox["w0", "2"], 
                RowBox[{"(", 
                 RowBox[{"Exp", "[", 
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", "\[Theta]", "]"}], "2"]}], 
                   SuperscriptBox["k", "2"], 
                   RowBox[{
                    SuperscriptBox["w0", "2"], "/", "2"}]}], "]"}], ")"}]}]}],
               ";", 
              RowBox[{"(*", 
               RowBox[{"Incidence", " ", "Term"}], "*)"}], 
              "\[IndentingNewLine]", 
              RowBox[{"CincI", "=", 
               RowBox[{"CincI", "+", 
                RowBox[{
                 RowBox[{
                 "Cinc", "\[LeftDoubleBracket]", "\[Theta]i", 
                  "\[RightDoubleBracket]"}], 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], ";"}]}], 
            "\[IndentingNewLine]", "]"}]}], ",", "0"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"N\[Theta]", ">", "1"}], ",", 
          RowBox[{"d\[Theta]", "=", 
           RowBox[{
            RowBox[{
            "\[Theta]T", "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}], "-", 
            RowBox[{
            "\[Theta]T", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}]}], ",", 
          RowBox[{"d\[Theta]", "=", "0"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Csca", "=", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{
            "gnT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"Abs", "[", "a1", "]"}], "2"]}]}], ";", 
        RowBox[{"Cext", "=", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{
            "gnT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "]"}], "2"], "3", 
          RowBox[{"Re", "[", "a1", "]"}]}]}], ";", 
        RowBox[{"Cabs", "=", 
         RowBox[{"Cext", "-", "Csca"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "SignalV"}], ",", 
          RowBox[{"Re", "[", "IncIE", "]"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cs"}], ",", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[Lambda]", "2"], " "}], 
             RowBox[{"4", "\[Pi]", " ", 
              SuperscriptBox["nmed", "2"]}]]}], "Cis"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"8", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], 
           RowBox[{"Re", "[", "Cinc", "]"}]}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Csca"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cext"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"2", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "Cabs"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "ScaIR"}], ",", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[Lambda]", "2"], " "}], 
             RowBox[{"4", "\[Pi]", " ", 
              SuperscriptBox["nmed", "2"]}]]}], "ExtIR"}], ",", "a1Mult", ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], 
           RowBox[{"(", 
            RowBox[{"CsI", "-", "CisI"}], ")"}], " ", "d\[Theta]"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[Lambda]", "2"], " "}], 
            RowBox[{"4", "\[Pi]", " ", 
             SuperscriptBox["nmed", "2"]}]], "CsI", " ", "d\[Theta]"}], ",", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["\[Lambda]", "2"], " "}], 
             RowBox[{"4", "\[Pi]", " ", 
              SuperscriptBox["nmed", "2"]}]]}], "CisI", " ", "d\[Theta]"}]}], 
         "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Get", " ", "Temperature", " ", "Increase", " ", "from", " ", "Heating", 
      " ", "laser"}], ",", " ", 
     RowBox[{"uses", " ", "above", " ", "function"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dTh", "[", 
      RowBox[{"z00_", ",", "\[Theta]\[Theta]_", ",", "Ph00_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"z0", "=", "z00"}], ",", 
         RowBox[{"\[Theta]", "=", "\[Theta]\[Theta]"}], ",", 
         RowBox[{"Ph0", "=", "Ph00"}], ",", "m", ",", "AA", ",", "anCh", ",", 
         "bnCh", ",", "cabsh", ",", "Ih0", ",", "dT"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"x", "=", 
         RowBox[{"{", 
          RowBox[{"kh", " ", "R"}], "}"}]}], ";", 
        RowBox[{"m", "=", 
         RowBox[{"{", 
          RowBox[{"nParticleh", "/", "nmed"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AA", "=", 
         RowBox[{"abL", "[", 
          RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";", 
        RowBox[{"anCh", "=", 
         RowBox[{"AA", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", 
        RowBox[{"bnCh", "=", 
         RowBox[{"AA", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"cabsh", "=", 
         RowBox[{
          RowBox[{"SignalExact", "[", 
           RowBox[{
           "z0", ",", "\[Theta]", ",", "sh", ",", "w0h", ",", "anCh", ",", 
            "bnCh"}], "]"}], "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Ih0", "=", 
         RowBox[{"cabber", "*", "2", 
          RowBox[{"Ph0", "/", 
           RowBox[{"(", 
            RowBox[{"\[Pi]", " ", 
             SuperscriptBox["w0h", "2"]}], ")"}]}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dT", "=", 
         RowBox[{"Ih0", " ", 
          RowBox[{"cabsh", "/", 
           RowBox[{"(", 
            RowBox[{"4", "\[Pi]", " ", "\[Kappa]med", " ", "R"}], 
            ")"}]}]}]}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Photothermal", " ", "Signal"}], ",", " ", 
     RowBox[{
      RowBox[{"i", ".", "e", ".", " ", "Hot"}], " ", "-", " ", 
      RowBox[{"Cold", " ", "Total", " ", "Signal"}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PT", " ", "Signal"}], ",", " ", 
      RowBox[{"Scatter", " ", "Signal", " ", "Cold"}], ",", " ", 
      RowBox[{"Scatter", " ", "Signal", " ", "Hot"}], ",", " ", 
      RowBox[{"PT", 
       RowBox[{"(", "Ext", ")"}]}], ",", " ", 
      RowBox[{"Ext", 
       RowBox[{"(", "COld", ")"}]}], ",", " ", 
      RowBox[{"Ext", 
       RowBox[{"(", "Hot", ")"}]}], ",", " ", 
      RowBox[{"PT", 
       RowBox[{"(", "Sca", ")"}]}], ",", " ", 
      RowBox[{"Sca", 
       RowBox[{"(", "Cold", ")"}]}], ",", " ", 
      RowBox[{"Sca", 
       RowBox[{"(", "Hot", ")"}]}]}], "}"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PTSignal", "[", 
      RowBox[{"z00_", ",", "\[Theta]\[Theta]_", ",", "ddzf_", ",", "Ph00_"}], 
      "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"z0", "=", "z00"}], ",", 
         RowBox[{"\[Theta]", "=", "\[Theta]\[Theta]"}], ",", 
         RowBox[{"dzf", "=", "ddzf"}], ",", 
         RowBox[{"Ph0", "=", "Ph00"}], ",", "x", ",", "\[CapitalDelta]T0z0", 
         ",", "m", ",", "i", ",", "AA", ",", "anC", ",", "bnC", ",", "anH", 
         ",", "bnH", ",", "Nn", ",", "HotSignal", ",", "HotSignalT", ",", 
         "ColdSignal", ",", "Inc"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Get", " ", "Cold", " ", "Scatterer", " ", 
         RowBox[{"{", 
          RowBox[{"an", ",", "bn"}], "}"}], " ", "with", " ", "Cold"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"x", "=", 
         RowBox[{"{", 
          RowBox[{"k", " ", "R"}], "}"}]}], ";", 
        RowBox[{"m", "=", 
         RowBox[{"{", 
          RowBox[{"nParticle", "/", "nmed"}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AA", "=", 
         RowBox[{"abL", "[", 
          RowBox[{"x", ",", "m", ",", "70"}], "]"}]}], ";", 
        RowBox[{"anC", "=", 
         RowBox[{"AA", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", 
        RowBox[{"bnC", "=", 
         RowBox[{"AA", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"Get", " ", "Thermal", " ", "Lens", " ", 
          RowBox[{"{", 
           RowBox[{"an", ",", "bn"}], "}"}], " ", "with", " ", "Hot", " ", 
          "\[CapitalDelta]T0", 
          RowBox[{"(", "z0", ")"}]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"\[CapitalDelta]T0z0", "=", 
         RowBox[{"dTh", "[", 
          RowBox[{
           RowBox[{"z0", "+", "dzf"}], ",", "\[Theta]", ",", "Ph0"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"x", "=", 
         RowBox[{"k", "*", "rT"}]}], ";", 
        RowBox[{"m", "=", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "nParticle", "}"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"nmed", "+", 
               RowBox[{"dndT", "*", "\[CapitalDelta]T0z0", "*", 
                RowBox[{"R", "/", 
                 RowBox[{"rT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}]}]}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]}], "]"}], 
          "/", "nmed"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"AA", "=", 
         RowBox[{"abL", "[", 
          RowBox[{"x", ",", "m", ",", "70"}], "]"}]}], ";", 
        RowBox[{"anH", "=", 
         RowBox[{"AA", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", 
        RowBox[{"bnH", "=", 
         RowBox[{"AA", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
         "Get", " ", "Signals", " ", "and", " ", "compute", " ", 
          "difference"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"HotSignal", "=", 
         RowBox[{"SignalExact", "[", 
          RowBox[{
          "z0", ",", "\[Theta]", ",", "s", ",", "w0", ",", "anH", ",", 
           "bnH"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ColdSignal", "=", 
         RowBox[{"SignalExact", "[", 
          RowBox[{
          "z0", ",", "\[Theta]", ",", "s", ",", "w0", ",", "anC", ",", 
           "bnC"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"HotSignal", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", 
           RowBox[{"ColdSignal", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", 
          RowBox[{"ColdSignal", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"HotSignal", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"HotSignal", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "-", 
           RowBox[{"ColdSignal", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], ",", 
          RowBox[{"ColdSignal", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{"HotSignal", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"HotSignal", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "-", 
           RowBox[{"ColdSignal", "[", 
            RowBox[{"[", "4", "]"}], "]"}]}], ",", 
          RowBox[{"ColdSignal", "[", 
           RowBox[{"[", "4", "]"}], "]"}], ",", 
          RowBox[{"HotSignal", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]",
       "]"}]}], ";"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.521539921710382*^9, 3.521539922349125*^9}, 
   3.521540137383369*^9, {3.521543075368484*^9, 3.521543105137628*^9}, {
   3.521543200579979*^9, 3.521543233001226*^9}, {3.521543312319969*^9, 
   3.521543338918846*^9}, 3.521543372557125*^9, {3.5215457319380617`*^9, 
   3.521545841354154*^9}, {3.5215459395120277`*^9, 3.521546299983704*^9}, {
   3.521546436390168*^9, 3.521546438427196*^9}, {3.5215464745481358`*^9, 
   3.521546480833865*^9}, {3.521546528403769*^9, 3.521546532104628*^9}, {
   3.521546691740171*^9, 3.5215466923126802`*^9}, {3.521548318730534*^9, 
   3.5215486440267067`*^9}, {3.521548679988933*^9, 3.5215487503209553`*^9}, {
   3.5215487983073893`*^9, 3.5215488300140944`*^9}, {3.521549958485528*^9, 
   3.5215499642910347`*^9}, {3.521552000252885*^9, 3.5215520015459146`*^9}, {
   3.521552155551263*^9, 3.52155216223072*^9}, {3.5215522755083847`*^9, 
   3.521552310914034*^9}, {3.5215556504139643`*^9, 3.521555726217935*^9}, {
   3.521555768297613*^9, 3.521555787978026*^9}, {3.521555860932276*^9, 
   3.521556078047586*^9}, {3.521556116868821*^9, 3.521556166449415*^9}, {
   3.521556206827374*^9, 3.521556219913822*^9}, {3.521556263162629*^9, 
   3.5215564898443727`*^9}, {3.5215565337059193`*^9, 3.521556535840818*^9}, {
   3.521556657515935*^9, 3.521556682821827*^9}, {3.521556712940714*^9, 
   3.521556781199284*^9}, {3.521556841934454*^9, 3.5215568473112373`*^9}, {
   3.521556914083198*^9, 3.52155693175152*^9}, {3.521556971040709*^9, 
   3.5215570196597157`*^9}, {3.521557080087916*^9, 3.521557173157921*^9}, {
   3.521557209943611*^9, 3.5215572226447973`*^9}, {3.521557369956501*^9, 
   3.521557370128484*^9}, {3.521557788306583*^9, 3.521557808782606*^9}, {
   3.5215582005449247`*^9, 3.521558229944488*^9}, 3.521566031192984*^9, {
   3.521566077936925*^9, 3.521566104316391*^9}, {3.521566796100881*^9, 
   3.521566865860341*^9}, {3.521566920638398*^9, 3.52156696927713*^9}, {
   3.521567008180668*^9, 3.521567070715005*^9}, {3.521567121156026*^9, 
   3.521567123489386*^9}, 3.521567167714007*^9, {3.5215672043450336`*^9, 
   3.521567297111741*^9}, {3.521567384958536*^9, 3.52156739991855*^9}, {
   3.521567764273575*^9, 3.521567958564992*^9}, 3.521568029955658*^9, {
   3.521568124888043*^9, 3.521568131977282*^9}, {3.5215691399229403`*^9, 
   3.521569176591297*^9}, {3.5215692488777227`*^9, 3.521569322415523*^9}, {
   3.521569426026637*^9, 3.521569756361761*^9}, 3.521569807117062*^9, {
   3.521569970680183*^9, 3.521569986224421*^9}, {3.521570067544285*^9, 
   3.5215701486510153`*^9}, 3.52157019666776*^9, {3.5215702312841043`*^9, 
   3.521570250202752*^9}, 3.521570484637426*^9, {3.521570538069004*^9, 
   3.521570549064281*^9}, {3.521571479252922*^9, 3.521571507298904*^9}, 
   3.521571538277194*^9, {3.521571591757854*^9, 3.5215715941248713`*^9}, {
   3.521571743796525*^9, 3.521571802491433*^9}, {3.521571845692972*^9, 
   3.521571875226109*^9}, {3.5215719201394978`*^9, 3.521571957724434*^9}, {
   3.521572102319139*^9, 3.52157218042878*^9}, {3.5215725002304296`*^9, 
   3.521572501040793*^9}, {3.52157272770578*^9, 3.5215727478522167`*^9}, {
   3.521573034254608*^9, 3.5215730622934227`*^9}, {3.521573735953515*^9, 
   3.521573763735442*^9}, {3.521573798214425*^9, 3.5215738291453447`*^9}, {
   3.521573979011619*^9, 3.521574016097364*^9}, {3.521574046490527*^9, 
   3.521574046810958*^9}, {3.521574198789689*^9, 3.521574200641498*^9}, {
   3.521574230988451*^9, 3.521574351430047*^9}, {3.521574394621708*^9, 
   3.5215744662286663`*^9}, {3.521574496299326*^9, 3.5215745197756643`*^9}, {
   3.521574588728137*^9, 3.521574589413417*^9}, {3.521574629981784*^9, 
   3.5215746332254753`*^9}, {3.52157470377873*^9, 3.521574749518814*^9}, {
   3.5215747990419273`*^9, 3.5215747993807983`*^9}, {3.521574832948352*^9, 
   3.521574860218799*^9}, {3.521574908216262*^9, 3.5215749126353407`*^9}, {
   3.5215752331520767`*^9, 3.521575253238461*^9}, {3.521575303911285*^9, 
   3.521575318512807*^9}, {3.521575423553677*^9, 3.521575452866247*^9}, {
   3.521575487130869*^9, 3.5215756093420057`*^9}, {3.521576252689938*^9, 
   3.521576272979711*^9}, {3.521576639996014*^9, 3.521576700122484*^9}, {
   3.5215772009058533`*^9, 3.5215772047633877`*^9}, {3.521577244376631*^9, 
   3.521577244833097*^9}, {3.521577367956995*^9, 3.5215773798284397`*^9}, {
   3.521613586262292*^9, 3.5216135865096493`*^9}, {3.521613627528943*^9, 
   3.521613650190626*^9}, {3.5216137463290586`*^9, 3.521613802950284*^9}, {
   3.521613840366507*^9, 3.521613908949339*^9}, {3.52161394125104*^9, 
   3.521614152600874*^9}, {3.52161420243267*^9, 3.52161420453463*^9}, {
   3.521614237785763*^9, 3.521614285291009*^9}, {3.521614343561599*^9, 
   3.5216144297739563`*^9}, {3.521614476984214*^9, 3.521614480717712*^9}, {
   3.521614525028408*^9, 3.521614564892064*^9}, {3.521614632483923*^9, 
   3.521614634215494*^9}, {3.521614705819991*^9, 3.521614718319775*^9}, {
   3.5216147550383263`*^9, 3.521614755454384*^9}, {3.521614873079467*^9, 
   3.5216149015281878`*^9}, {3.5216152071289797`*^9, 
   3.5216152166981287`*^9}, {3.5216155464392443`*^9, 
   3.5216155765270844`*^9}, {3.521615638759782*^9, 3.521615652957055*^9}, 
   3.52161670731536*^9, {3.521616737382536*^9, 3.521616778692563*^9}, 
   3.521617747163459*^9, {3.52161923272758*^9, 3.5216192561812267`*^9}, {
   3.521619290939052*^9, 3.521619320268631*^9}, {3.521621266443159*^9, 
   3.521621342250135*^9}, {3.521621395542218*^9, 3.5216214046692142`*^9}, {
   3.5216214479525213`*^9, 3.5216214491760683`*^9}, {3.521624523835369*^9, 
   3.52162452440875*^9}, {3.521624609008278*^9, 3.521624673447432*^9}, {
   3.521624735268839*^9, 3.521624756219799*^9}, {3.521624938166098*^9, 
   3.521624940996278*^9}, {3.521624980911252*^9, 3.521624981261756*^9}, {
   3.5216250267688923`*^9, 3.5216250639300137`*^9}, {3.52162511664894*^9, 
   3.521625128362938*^9}, {3.521627811333799*^9, 3.5216278546983843`*^9}, {
   3.521634022519857*^9, 3.521634033485652*^9}, {3.5218757558362083`*^9, 
   3.521875776873104*^9}, {3.521879879123221*^9, 3.521879881816216*^9}, {
   3.521950911522537*^9, 3.521950943210288*^9}, {3.521951692341786*^9, 
   3.521951819233716*^9}, {3.521951970999457*^9, 3.5219519810156727`*^9}, {
   3.52196367523072*^9, 3.521963690753562*^9}, {3.521965632777637*^9, 
   3.5219656391618843`*^9}, {3.527405104388234*^9, 3.5274051416851063`*^9}, {
   3.527410279944854*^9, 3.527410309353045*^9}, {3.5341669490735397`*^9, 
   3.534166988936541*^9}, {3.53416703396203*^9, 3.5341670343334846`*^9}, {
   3.534167123155633*^9, 3.5341671354943333`*^9}, {3.534231575462715*^9, 
   3.534231584068177*^9}, {3.534231616491531*^9, 3.5342316516108294`*^9}, {
   3.534231685280518*^9, 3.534231722319127*^9}, {3.534231778414218*^9, 
   3.534231778676667*^9}, {3.534234007420342*^9, 3.534234010688233*^9}, {
   3.534234100861925*^9, 3.534234118540532*^9}, {3.534412566903373*^9, 
   3.534412588444292*^9}, {3.5542785819491034`*^9, 3.554278583525566*^9}, {
   3.554283002907897*^9, 3.5542830042181253`*^9}, {3.554302563465529*^9, 
   3.5543025894164333`*^9}, {3.554350927773059*^9, 3.554351014657928*^9}, {
   3.554359520171158*^9, 3.55435960091226*^9}, {3.554359645442162*^9, 
   3.554359786370907*^9}, {3.55435983105936*^9, 3.554359910703341*^9}, {
   3.554360132957446*^9, 3.554360141587286*^9}, {3.554360192600506*^9, 
   3.554360198972556*^9}, {3.554360327604395*^9, 3.554360368286531*^9}, {
   3.554360558043578*^9, 3.55436058773799*^9}, {3.554360625066368*^9, 
   3.5543606428474607`*^9}, {3.55436069026523*^9, 3.5543606924239187`*^9}, {
   3.554361040885507*^9, 3.554361046388942*^9}, {3.554361194988945*^9, 
   3.554361219021737*^9}, {3.554362820648522*^9, 3.554362829927236*^9}, {
   3.554434196921153*^9, 3.5544342381822157`*^9}, {3.554434311869961*^9, 
   3.554434389911913*^9}, {3.554434439588079*^9, 3.554434659452927*^9}, {
   3.554435142176127*^9, 3.5544351462734537`*^9}, {3.554435668438723*^9, 
   3.55443574137276*^9}, {3.554435956281588*^9, 3.554436056004719*^9}, {
   3.554436130533276*^9, 3.554436153372384*^9}, {3.554436213674032*^9, 
   3.554436305369451*^9}, {3.554436369151074*^9, 3.554436422870926*^9}, {
   3.554437036025982*^9, 3.554437043697545*^9}, {3.554437546292334*^9, 
   3.554437554159794*^9}, {3.554437625486649*^9, 3.5544376671794157`*^9}, {
   3.554438644459998*^9, 3.554438645930093*^9}, {3.554441916898652*^9, 
   3.554441934239637*^9}, {3.554441974391275*^9, 3.554442016988146*^9}, {
   3.554442067222929*^9, 3.554442105740343*^9}, {3.554442528306943*^9, 
   3.554442569030098*^9}, {3.554443620732234*^9, 3.554443645701728*^9}, {
   3.5544478074978533`*^9, 3.554447807870372*^9}, {3.554447843633369*^9, 
   3.554447843936692*^9}, {3.554448007146016*^9, 3.554448022251151*^9}, {
   3.5544492836465483`*^9, 3.5544492847451468`*^9}, {3.554449845335743*^9, 
   3.554449847183167*^9}, {3.554450245042077*^9, 3.554450245185563*^9}, {
   3.557395140748897*^9, 3.557395178550931*^9}, {3.5573961828566437`*^9, 
   3.557396270828265*^9}, {3.562753093020554*^9, 3.562753093695938*^9}, {
   3.5627535877266273`*^9, 3.562753597447105*^9}, {3.572014287975206*^9, 
   3.5720143284920063`*^9}, {3.572017555310008*^9, 3.572017602649775*^9}, {
   3.572017654055594*^9, 3.572017684948883*^9}, {3.572017727847254*^9, 
   3.572017791401997*^9}, {3.572017896955888*^9, 3.572018084187724*^9}, {
   3.572018130146696*^9, 3.572018222588181*^9}, {3.5720183978750267`*^9, 
   3.57201853920221*^9}, {3.572018569914918*^9, 3.572018641812923*^9}, {
   3.572018709187296*^9, 3.5720187119336243`*^9}, 3.572019334196747*^9, {
   3.5720196098921423`*^9, 3.572019610255148*^9}, {3.572019971508868*^9, 
   3.5720200591133003`*^9}, {3.572020157208823*^9, 3.5720201633011703`*^9}, 
   3.572020217758707*^9, {3.572020283979372*^9, 3.572020299569173*^9}, 
   3.572020754344838*^9, {3.572087471307423*^9, 3.572087482514852*^9}, {
   3.572087732446018*^9, 3.572087733854149*^9}, {3.572087869232122*^9, 
   3.5720878711783237`*^9}, {3.572088134680501*^9, 3.572088136184698*^9}, {
   3.572088887559638*^9, 3.572088889327149*^9}, 3.5720890441083517`*^9, {
   3.5721145122442417`*^9, 3.57211452322547*^9}, {3.572165669894168*^9, 
   3.5721657571624937`*^9}, 3.57216587118106*^9, {3.5721659178561*^9, 
   3.572165919389432*^9}, {3.572170171473349*^9, 3.572170226936977*^9}, {
   3.57217132838076*^9, 3.5721713549786463`*^9}, {3.572171945695012*^9, 
   3.572171945938591*^9}, {3.5722525981477413`*^9, 3.572252602585291*^9}, {
   3.572252663480957*^9, 3.572252773039959*^9}, {3.572252984116976*^9, 
   3.5722530255236197`*^9}, {3.572253277216*^9, 3.572253297490048*^9}, {
   3.5722534502958117`*^9, 3.572253452646689*^9}, {3.572254036799102*^9, 
   3.572254038634283*^9}, {3.5722541203069344`*^9, 3.572254127695943*^9}, {
   3.572254186644651*^9, 3.572254186950182*^9}, {3.572254245070229*^9, 
   3.5722542513587227`*^9}, {3.572254363637401*^9, 3.5722543818966227`*^9}, {
   3.572254459369401*^9, 3.572254459742483*^9}, {3.572254699808742*^9, 
   3.57225484344928*^9}, {3.5722549658401537`*^9, 3.572254967127759*^9}, {
   3.572255118333026*^9, 3.57225511920383*^9}, {3.57225516290156*^9, 
   3.572255166915111*^9}, {3.5722552203451147`*^9, 3.572255230013577*^9}, {
   3.572255281771171*^9, 3.5722552964292793`*^9}, 3.572256457869796*^9, {
   3.590657051865273*^9, 3.590657060605015*^9}, {3.590657096291256*^9, 
   3.5906570984860907`*^9}, {3.590657140657288*^9, 3.590657140980288*^9}, {
   3.59065724005809*^9, 3.5906572705469713`*^9}, {3.5906576998371563`*^9, 
   3.59065770057393*^9}, {3.591875103590816*^9, 3.591875165121923*^9}, {
   3.591875232627163*^9, 3.591875337919025*^9}, {3.591875393953032*^9, 
   3.59187574725718*^9}, {3.5918757990460157`*^9, 3.591875812655862*^9}, {
   3.5918759148326178`*^9, 3.591875916449108*^9}, {3.591875970397201*^9, 
   3.5918760981368513`*^9}, {3.591876130569522*^9, 3.5918761852867537`*^9}, {
   3.591876236875214*^9, 3.5918764673082743`*^9}, {3.5918766368036137`*^9, 
   3.591876704857895*^9}, {3.591876746715138*^9, 3.59187674717523*^9}, {
   3.591876801824349*^9, 3.59187680360341*^9}, 3.591876863083335*^9, {
   3.591876910130773*^9, 3.5918770232837057`*^9}, {3.591879539960863*^9, 
   3.591879544803939*^9}, {3.5918795823434143`*^9, 3.591879584099859*^9}, {
   3.591879625840187*^9, 3.59187963432428*^9}, {3.591879671947651*^9, 
   3.591879780325953*^9}, {3.59188013046052*^9, 3.591880151860606*^9}, {
   3.5918802895640593`*^9, 3.591880345396204*^9}, {3.5918810056523848`*^9, 
   3.591881011659429*^9}, {3.5918811385550632`*^9, 3.591881147166441*^9}, {
   3.591881275359378*^9, 3.591881289166202*^9}, {3.591881352136999*^9, 
   3.591881392121541*^9}, {3.591881423530877*^9, 3.591881423693246*^9}, 
   3.591881458771546*^9, {3.591881982042532*^9, 3.591881984621223*^9}, 
   3.591882075672678*^9, {3.5918824114130507`*^9, 3.591882428054475*^9}, 
   3.591882512041589*^9, {3.591883701543478*^9, 3.591883709146172*^9}, {
   3.5918839151913157`*^9, 3.5918840394368687`*^9}, {3.591884071565469*^9, 
   3.591884095370652*^9}, {3.591884142126789*^9, 3.5918841565507927`*^9}, {
   3.591936061618853*^9, 3.591936083341301*^9}, {3.591937125763397*^9, 
   3.591937150566016*^9}, {3.5919373903378057`*^9, 3.591937414549396*^9}, {
   3.5919448551247673`*^9, 3.591944922012726*^9}, {3.5919511703356247`*^9, 
   3.5919514001993*^9}, {3.591951459303842*^9, 3.591951460848341*^9}, {
   3.591952030360824*^9, 3.5919521218345213`*^9}, {3.5919521539038553`*^9, 
   3.591952156217224*^9}, {3.5919522600672283`*^9, 3.59195229736465*^9}, 
   3.591952352795822*^9, {3.591952383798064*^9, 3.5919524602833977`*^9}, {
   3.591952760916366*^9, 3.591952771904748*^9}, {3.591952809408581*^9, 
   3.591952838469836*^9}, {3.59195290459387*^9, 3.591952930198488*^9}, {
   3.591952964349264*^9, 3.591952965528474*^9}, 3.5919530777090197`*^9, 
   3.5919531185566463`*^9, {3.5919531489606247`*^9, 3.591953158351651*^9}, 
   3.591953238849821*^9, {3.591953414047181*^9, 3.591953487547801*^9}, {
   3.591953827309065*^9, 3.591953844357483*^9}, {3.5919543066049013`*^9, 
   3.59195435623847*^9}, {3.592729915846612*^9, 3.5927299162060833`*^9}, {
   3.592730013460249*^9, 3.592730014431039*^9}, {3.592747468481263*^9, 
   3.5927474841952047`*^9}, {3.5927475282674017`*^9, 3.592747568251892*^9}, {
   3.592747613402487*^9, 3.5927477445288353`*^9}, {3.59274780280355*^9, 
   3.592747830325038*^9}, {3.592748549118826*^9, 3.59274856933253*^9}, {
   3.592823776551907*^9, 3.592823935280862*^9}, {3.592824423251239*^9, 
   3.592824424963138*^9}, {3.5928246670873957`*^9, 3.592824675418646*^9}, {
   3.592889423194762*^9, 3.5928894366571417`*^9}, {3.59290264959258*^9, 
   3.592902655582387*^9}, {3.5929026947291307`*^9, 3.592902817824732*^9}, {
   3.59290285921868*^9, 3.592902869757494*^9}, {3.59290360231841*^9, 
   3.5929036113649187`*^9}, {3.5929041231584597`*^9, 3.592904128712586*^9}, {
   3.592904432272449*^9, 3.5929044386276073`*^9}, {3.592904486131199*^9, 
   3.592904489484015*^9}, 3.592904529012875*^9, {3.592904577420068*^9, 
   3.59290458221739*^9}, {3.592904618542474*^9, 3.592904618963818*^9}, {
   3.592905086289716*^9, 3.592905089920669*^9}, {3.592905730119453*^9, 
   3.592905748237864*^9}, 3.592906959138687*^9, {3.592907017318282*^9, 
   3.592907034843137*^9}, {3.592907099065126*^9, 3.592907105798004*^9}, 
   3.5929073294162607`*^9, {3.592907417934814*^9, 3.592907420034728*^9}, {
   3.592907627978722*^9, 3.5929077156261044`*^9}, {3.59290780461755*^9, 
   3.59290781697681*^9}, {3.592907874294293*^9, 3.592907886616661*^9}, {
   3.592982105823971*^9, 3.592982120074668*^9}, {3.592982443317314*^9, 
   3.592982445534526*^9}, {3.5929824907858667`*^9, 3.592982535636064*^9}, {
   3.592982571685213*^9, 3.592982618600762*^9}, {3.59298290625882*^9, 
   3.5929829533768177`*^9}, {3.5929996206861057`*^9, 3.592999653895678*^9}, {
   3.593166027681108*^9, 3.593166046301817*^9}, {3.5935054430998*^9, 
   3.593505482405244*^9}, {3.593505519251636*^9, 3.5935055204382277`*^9}, {
   3.5935056372855997`*^9, 3.593505661340022*^9}, {3.593944723547881*^9, 
   3.5939447251648693`*^9}, 3.593944944396605*^9, {3.5939449927126102`*^9, 
   3.593944993241571*^9}, {3.594003517456452*^9, 3.594003527605398*^9}, {
   3.594003624043076*^9, 3.594003652314537*^9}, {3.594003832761945*^9, 
   3.5940038468387413`*^9}, {3.594004346539361*^9, 3.5940043495567617`*^9}, {
   3.594006157059765*^9, 3.594006159282447*^9}, 3.5940069081684093`*^9, {
   3.594007104294353*^9, 3.594007157309567*^9}, 3.594007188548807*^9, {
   3.59400730793684*^9, 3.594007312335147*^9}, {3.59403117475869*^9, 
   3.5940311775415907`*^9}, {3.594031394416765*^9, 3.594031395818488*^9}, {
   3.5940314259898043`*^9, 3.59403142806297*^9}, {3.594031492625904*^9, 
   3.594031495810843*^9}, {3.594104471681658*^9, 3.594104481294262*^9}, {
   3.594104546528974*^9, 3.594104561919025*^9}, {3.594104593196905*^9, 
   3.594104598307151*^9}, {3.594104638279985*^9, 3.594104662460606*^9}, 
   3.5941047243151827`*^9, {3.5941050053755817`*^9, 3.5941050078470383`*^9}, {
   3.5941121865154943`*^9, 3.5941121888671627`*^9}, {3.594112994735076*^9, 
   3.5941130211597443`*^9}, {3.59812156856343*^9, 3.5981215699548597`*^9}, 
   3.598121745073241*^9, {3.5981218092004213`*^9, 3.5981218423949747`*^9}, {
   3.5981219266504793`*^9, 3.598121976497416*^9}, 3.598122027145727*^9, {
   3.598122113520479*^9, 3.598122122692883*^9}, 3.598153547506332*^9, 
   3.598153959671947*^9, 3.59816462422508*^9, 3.598164661549801*^9, 
   3.598165657990847*^9, 3.5981658419823103`*^9, {3.60041953467557*^9, 
   3.600419560781691*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "OFF-AXIS particle position: Scattering Signal\n",
 StyleBox["\"Photothermal Single Particle Microscopy: Detection of a Nanolens\
\", ACS Nano, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1), APPENDIX\nSyntax: ScatterOA[x/w0, \
y/w0, z/l, s, anL, bnL, \[Theta]min, \[Theta]max] = {\[Sigma]ext, \
\[Sigma]sca, \[Sigma]abs, d\[Sigma]sca, d\[Sigma]ext,  d\[Sigma]sca - d\
\[Sigma]ext} provides the differential scattering signals, last entry being \
the total scatter signal detected on a photo-diode. Set below is a reasonable \
value (for small AuNPs) for the # of \[Theta]-values (N\[Theta]) used in the \
angular integration discretization. change if necessary. anL and bnL are the \
Mie-scattering coefficient lists {a_1, a_2, ...} and {b_1, b_2, ...}, \
\[Theta]min, \[Theta]max define the angular collection domain (polar angle)",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.491071860105487*^9, 3.491071864637607*^9}, {
  3.5550644850429077`*^9, 3.5550644959625893`*^9}, {3.5575900203335457`*^9, 
  3.557590068691924*^9}, {3.5575902622569513`*^9, 3.5575904884719067`*^9}, {
  3.557740066878723*^9, 3.5577401586755238`*^9}, {3.557740190280815*^9, 
  3.5577402545028763`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "M11", ",", "M12", ",", "M21", ",", "M22", ",", "X1", ",", "X2", ",", "Y1",
     ",", "Y2", ",", "SumX1", ",", "SumX2", ",", "InmS1S1", ",", "InmS2S2", 
    ",", "InmM1S1", ",", "InmM2S2", ",", "Cs", ",", "Cis", ",", 
    "SignalOffAxis"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Pi]nm", "[", 
    RowBox[{"\[Theta]_", ",", "n_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"LegendreP", "[", 
     RowBox[{"n", ",", "m", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "/", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"\[Tau]nm", "[", 
    RowBox[{"\[Theta]_", ",", "n_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"n", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], 
     RowBox[{"\[Pi]nm", "[", 
      RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "+", "m"}], ")"}], 
     RowBox[{"\[Pi]nm", "[", 
      RowBox[{"\[Theta]", ",", 
       RowBox[{"n", "-", "1"}], ",", "m"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"N\[Theta]", "=", "100"}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OffAxis\[Theta]i", "[", 
     RowBox[{
     "gnmTETo_", ",", "gnmTMTo_", ",", "anLL_", ",", "bnLL_", ",", 
      "\[Theta]i_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"gnmTET", "=", "gnmTETo"}], ",", 
        RowBox[{"gnmTMT", "=", "gnmTMTo"}], ",", 
        RowBox[{"anL", "=", "anLL"}], ",", 
        RowBox[{"bnL", "=", "bnLL"}], ",", 
        RowBox[{"\[Theta]", "=", "\[Theta]i"}], ",", "M11", ",", "M12", ",", 
        "M21", ",", "M22", ",", "X1", ",", "X2", ",", "Y1", ",", "Y2", ",", 
        "SumX1", ",", "SumX2", ",", "Cs", ",", "Cis", ",", "\[Pi]nmT", ",", 
        "\[Tau]nmT"}], "}"}], ",", 
      RowBox[{
       RowBox[{"\[Pi]nmT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"\[Pi]nm", "[", 
             RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "0", ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"\[Tau]nmT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"\[Tau]nm", "[", 
             RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "0", ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"M11", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"I", " ", 
             RowBox[{
              RowBox[{
              "gnmTET", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
              RowBox[{
              "\[Tau]nmT", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], "+", "1"}], 
              "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"M12", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"m", " ", 
             RowBox[{
              RowBox[{
              "gnmTMT", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
              RowBox[{
              "\[Pi]nmT", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], "+", "1"}], 
              "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"M21", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "gnmTMT", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
              RowBox[{
              "\[Tau]nmT", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], "+", "1"}], 
              "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"M22", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"I", " ", "m", " ", 
             RowBox[{
              RowBox[{
              "gnmTET", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
             "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
             " ", 
             RowBox[{
              RowBox[{
              "\[Pi]nmT", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], "+", "1"}], 
              "\[RightDoubleBracket]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"Y1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "M11", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{
              RowBox[{
              "M12", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}]}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Y2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "M21", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
             "+", 
             RowBox[{
              RowBox[{
              "M22", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}]}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"X1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
               RowBox[{
               "M12", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}]}],
              "+", 
             RowBox[{
              RowBox[{
              "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
               RowBox[{
               "M11", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1", "+", "m"}], 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"X2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
               RowBox[{
               "M21", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}]}],
              "+", 
             RowBox[{
              RowBox[{
              "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
               RowBox[{
               "M22", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"n", "+", "1", "+", "m"}], 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"SumX1", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"np", "=", 
             RowBox[{"Max", "[", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], ",", "1"}], "]"}]}], "npmax"], 
           
           RowBox[{"Conjugate", "[", 
            RowBox[{
             RowBox[{
             "X1", "\[LeftDoubleBracket]", "np", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", 
             RowBox[{"np", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
            "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", 
            RowBox[{"-", "nmax"}], ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"SumX2", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"np", "=", 
             RowBox[{"Max", "[", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], ",", "1"}], "]"}]}], "npmax"], 
           
           RowBox[{"Conjugate", "[", 
            RowBox[{
             RowBox[{
             "X2", "\[LeftDoubleBracket]", "np", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", 
             RowBox[{"np", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
            "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", 
            RowBox[{"-", "nmax"}], ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Cs", "=", 
        RowBox[{"Re", "[", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "nmax"], 
          RowBox[{"(", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", 
              RowBox[{"-", "n"}]}], "n"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                "X1", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
               " ", 
               RowBox[{"SumX1", "\[LeftDoubleBracket]", 
                RowBox[{"nmax", "+", "1", "+", "m"}], 
                "\[RightDoubleBracket]"}]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{
                "X2", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
               " ", 
               RowBox[{"SumX2", "\[LeftDoubleBracket]", 
                RowBox[{"nmax", "+", "1", "+", "m"}], 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], ")"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"Cis", "=", 
        RowBox[{"Re", "[", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "nmax"], 
          RowBox[{"(", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", 
              RowBox[{"-", "n"}]}], "n"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                "Y1", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
               " ", 
               RowBox[{"SumX1", "\[LeftDoubleBracket]", 
                RowBox[{"nmax", "+", "1", "+", "m"}], 
                "\[RightDoubleBracket]"}]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{
                "Y2", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"n", "+", "1", "+", "m"}], "\[RightDoubleBracket]"}], 
               " ", 
               RowBox[{"SumX2", "\[LeftDoubleBracket]", 
                RowBox[{"nmax", "+", "1", "+", "m"}], 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], ")"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Cs", ",", "Cis"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}],
    ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScatterOA", "[", 
    RowBox[{
    "x00_", ",", "y00_", ",", "z00_", ",", "ss_", ",", "anLL_", ",", "bnLL_", 
     ",", "\[Theta]tmin_", ",", "\[Theta]tmax_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x0", "=", "x00"}], ",", 
       RowBox[{"y0", "=", "y00"}], ",", 
       RowBox[{"z0", "=", 
        RowBox[{"-", "z00"}]}], ",", 
       RowBox[{"s", "=", "ss"}], ",", 
       RowBox[{"anL", "=", "anLL"}], ",", 
       RowBox[{"bnL", "=", "bnLL"}], ",", 
       RowBox[{"\[Theta]min", "=", "\[Theta]tmin"}], ",", 
       RowBox[{"\[Theta]max", "=", "\[Theta]tmax"}], ",", "CextG", ",", 
       "CscaG", ",", "CabsG", ",", "CsOA", ",", "CisOA", ",", "SignalOA", ",",
        "gnmTET", ",", "gnmTMT"}], "}"}], ",", 
     RowBox[{
      RowBox[{"gnmTET", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"gnmTEAddT", "[", 
            RowBox[{"n", ",", "m", ",", "s", ",", 
             RowBox[{"2", 
              RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", "y0"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"gnmTMT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"gnmTMAddT", "[", 
            RowBox[{"n", ",", "m", ",", "s", ",", 
             RowBox[{"2", 
              RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", "y0"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CscaG", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]", " "}], 
         SuperscriptBox["k", "2"]], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "nmax"], 
         RowBox[{
          RowBox[{
          "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"m", "=", 
             RowBox[{"-", "n"}]}], "n"], 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "anL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "bnL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}]}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", 
               RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]]}]}]}]}]}], ";", 
      RowBox[{"CextG", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]", " "}], 
         SuperscriptBox["k", "2"]], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "nmax"], 
         RowBox[{
          RowBox[{
          "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"m", "=", 
             RowBox[{"-", "n"}]}], "n"], 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], " ", 
             RowBox[{"Re", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{
                "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}]}], "]"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", 
               RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]]}]}]}]}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"CabsG", "=", 
       RowBox[{"CextG", "-", "CscaG"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"CsOA", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Theta]max", "-", "\[Theta]min"}], "N\[Theta]"], 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], 
         SuperscriptBox["k", "2"]], " ", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"OffAxis\[Theta]i", "[", 
             RowBox[{
             "gnmTET", ",", "gnmTMT", ",", "anL", ",", "bnL", ",", 
              "\[Theta]"}], "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Theta]", ",", "\[Theta]min", ",", "\[Theta]max", ",", 
            FractionBox[
             RowBox[{"\[Theta]max", "-", "\[Theta]min"}], "N\[Theta]"]}], 
           "}"}]}], "]"}]}]}], ";", 
      RowBox[{"CisOA", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Theta]max", "-", "\[Theta]min"}], "N\[Theta]"], 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], 
         SuperscriptBox["k", "2"]], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"OffAxis\[Theta]i", "[", 
             RowBox[{
             "gnmTET", ",", "gnmTMT", ",", "anL", ",", "bnL", ",", 
              "\[Theta]"}], "]"}], "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Theta]", ",", "\[Theta]min", ",", "\[Theta]max", ",", 
            FractionBox[
             RowBox[{"\[Theta]max", "-", "\[Theta]min"}], "N\[Theta]"]}], 
           "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SignalOA", "=", 
       RowBox[{"CsOA", "-", "CisOA"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "CextG", ",", "CscaG", ",", "CabsG", ",", "CsOA", ",", "CisOA", ",", 
        "SignalOA"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4909453688862667`*^9, 3.4909453697569733`*^9}, {
   3.490945458451236*^9, 3.490945490175466*^9}, {3.490945525309311*^9, 
   3.490945575857732*^9}, {3.490945746078394*^9, 3.4909458001138268`*^9}, {
   3.4909459207687187`*^9, 3.490946252289543*^9}, {3.490946417387443*^9, 
   3.490946557848196*^9}, {3.490946604620192*^9, 3.490946775437936*^9}, {
   3.490946826139266*^9, 3.490946920051197*^9}, {3.4909469957185297`*^9, 
   3.490947014695559*^9}, {3.490947071454657*^9, 3.490947089615149*^9}, {
   3.490947144565303*^9, 3.490947148931162*^9}, {3.4909472425449123`*^9, 
   3.490947309894614*^9}, {3.4909475067260027`*^9, 3.490947560113865*^9}, {
   3.49094762005973*^9, 3.490947629505975*^9}, {3.4909476636008253`*^9, 
   3.49094767865119*^9}, {3.49094771040139*^9, 3.490947740333735*^9}, {
   3.49094805590348*^9, 3.4909482707103157`*^9}, 3.490948764345323*^9, {
   3.4909491549741983`*^9, 3.490949159327145*^9}, {3.490949493322565*^9, 
   3.490949619634519*^9}, {3.4909505851043873`*^9, 3.4909505985570583`*^9}, {
   3.490951546689272*^9, 3.490951557989132*^9}, {3.490953985326879*^9, 
   3.4909539867124434`*^9}, {3.490954032843851*^9, 3.4909540331261673`*^9}, {
   3.490954095500002*^9, 3.490954128047719*^9}, {3.4909542090930634`*^9, 
   3.490954213584547*^9}, {3.490954247387576*^9, 3.490954248833827*^9}, {
   3.490954336330393*^9, 3.490954340543138*^9}, {3.49095577068579*^9, 
   3.490955799235155*^9}, {3.4909583648371773`*^9, 3.49095838073057*^9}, {
   3.554280444151483*^9, 3.554280504188389*^9}, {3.554280568260068*^9, 
   3.554280575319149*^9}, {3.557208773612158*^9, 3.557208838377722*^9}, 
   3.557209633844925*^9, {3.557209678632279*^9, 3.557209760632246*^9}, {
   3.557215374051145*^9, 3.557215464287776*^9}, {3.5572155707881737`*^9, 
   3.557215576280979*^9}, {3.557215655073948*^9, 3.5572156690753393`*^9}, {
   3.557215706258432*^9, 3.557215715090034*^9}, {3.557215751705405*^9, 
   3.557215788230338*^9}, {3.557218046264564*^9, 3.557218136773677*^9}, {
   3.5572181942432337`*^9, 3.557218227583281*^9}, {3.55721829019595*^9, 
   3.557218348767399*^9}, {3.5573288717692947`*^9, 3.557328872264798*^9}, {
   3.557386708635531*^9, 3.557386753744059*^9}, {3.557388414240148*^9, 
   3.557388559022146*^9}, {3.557388678975111*^9, 3.5573887710221252`*^9}, {
   3.557388805793909*^9, 3.5573888243171453`*^9}, {3.557388860367383*^9, 
   3.557388891041003*^9}, {3.557389091095622*^9, 3.557389131667047*^9}, {
   3.55738916183379*^9, 3.557389449901166*^9}, {3.557389486872736*^9, 
   3.55738954468581*^9}, {3.557389598565716*^9, 3.557389677394401*^9}, {
   3.557389764377842*^9, 3.5573898354883547`*^9}, {3.557389908614995*^9, 
   3.557389942434581*^9}, {3.557389982654024*^9, 3.557390030888773*^9}, {
   3.557390078724305*^9, 3.5573900910077763`*^9}, {3.557390215286847*^9, 
   3.557390448386938*^9}, {3.5573905793612633`*^9, 3.557390661956753*^9}, {
   3.557390692389759*^9, 3.557390692746002*^9}, {3.557390728825891*^9, 
   3.557390850026161*^9}, {3.557390931742074*^9, 3.557390999586823*^9}, {
   3.557391035699122*^9, 3.5573911070148897`*^9}, {3.557391245943735*^9, 
   3.5573912620475187`*^9}, {3.5573914369724293`*^9, 3.557391478490144*^9}, {
   3.557391539716552*^9, 3.557391542493231*^9}, {3.5573916924075747`*^9, 
   3.557391696324327*^9}, {3.557392231752171*^9, 3.557392236361211*^9}, {
   3.557392333394143*^9, 3.557392336765808*^9}, {3.557392566978126*^9, 
   3.557392585043724*^9}, {3.557392857402131*^9, 3.557392857576866*^9}, {
   3.557392905221393*^9, 3.557392922913686*^9}, {3.557392964408615*^9, 
   3.557392964595834*^9}, 3.5573931117172537`*^9, {3.557393268857986*^9, 
   3.557393271613716*^9}, {3.557394025521769*^9, 3.557394042964089*^9}, {
   3.557394167872086*^9, 3.557394173166443*^9}, {3.557394244398687*^9, 
   3.557394251383607*^9}, {3.55739428178458*^9, 3.557394289428743*^9}, {
   3.557394343173264*^9, 3.5573943735650473`*^9}, {3.557398267238804*^9, 
   3.557398268536302*^9}, {3.557420768383552*^9, 3.5574207686193237`*^9}, 
   3.557420816495178*^9, {3.557420896666102*^9, 3.5574208995140877`*^9}, {
   3.557420982960802*^9, 3.557420985045141*^9}, 3.557421035398741*^9, {
   3.557421261232778*^9, 3.557421297143807*^9}, {3.557421329089753*^9, 
   3.557421332548128*^9}, {3.557473189359517*^9, 3.557473193338456*^9}, {
   3.557473244990506*^9, 3.557473274198813*^9}, {3.557473315208241*^9, 
   3.5574733540980167`*^9}, {3.5574733918670187`*^9, 3.557473392201157*^9}, {
   3.557473470148492*^9, 3.557473504126998*^9}, {3.557473575038397*^9, 
   3.557473604741192*^9}, {3.557473668987714*^9, 3.557473758978724*^9}, {
   3.557473800686817*^9, 3.557473802319824*^9}, {3.557473941282967*^9, 
   3.557474019368471*^9}, 3.5574740613150997`*^9, {3.557485608907538*^9, 
   3.5574856217423363`*^9}, 3.557485658491466*^9, 3.557485698171495*^9, {
   3.55748574992797*^9, 3.5574859411725082`*^9}, {3.557486274548502*^9, 
   3.557486274901066*^9}, {3.557589875783835*^9, 3.557589914864352*^9}, {
   3.557590193118559*^9, 3.557590203176846*^9}, {3.557739335024212*^9, 
   3.55773940556793*^9}, {3.55774002608989*^9, 3.5577400417562838`*^9}, {
   3.592655381404646*^9, 3.5926553815264997`*^9}, 3.592655486799161*^9, {
   3.592657662967502*^9, 3.592657688565185*^9}, {3.59265813227586*^9, 
   3.592658132442981*^9}, {3.592658190532997*^9, 3.592658190724688*^9}, {
   3.592658535677918*^9, 3.5926585359473753`*^9}, {3.592660182288412*^9, 
   3.5926601824023027`*^9}, {3.5974069944852753`*^9, 3.597407004463327*^9}, {
   3.597487299553822*^9, 3.597487301207479*^9}, 3.598157775375801*^9, {
   3.598781628045697*^9, 3.598781640643527*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "n", ",", "HmmtT", ",", "HnmT", ",", "\[Pi]nmT", ",", "\[Tau]nmT", ",", 
    "\[Theta]max", ",", "Hnmt", ",", "I1N", ",", "I2N", ",", "I1T", ",", 
    "I2T", ",", "ScatterOAE", ",", "Integrals\[Theta]f"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"I1N", "[", 
    RowBox[{"n_", ",", "np_", ",", "m_", ",", "\[Theta]f_"}], "]"}], ":=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], 
         RowBox[{"\[Pi]nm", "[", 
          RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}], 
         RowBox[{"\[Pi]nm", "[", 
          RowBox[{"\[Theta]", ",", "np", ",", "m"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"\[Tau]nm", "[", 
          RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}], 
         RowBox[{"\[Tau]nm", "[", 
          RowBox[{"\[Theta]", ",", "np", ",", "m"}], "]"}]}]}], ")"}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "\[Theta]f"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"I2N", "[", 
     RowBox[{"n_", ",", "np_", ",", "m_", ",", "\[Theta]f_"}], "]"}], ":=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Pi]nm", "[", 
           RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}], 
          RowBox[{"\[Tau]nm", "[", 
           RowBox[{"\[Theta]", ",", "np", ",", "m"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[Tau]nm", "[", 
           RowBox[{"\[Theta]", ",", "n", ",", "m"}], "]"}], 
          RowBox[{"\[Pi]nm", "[", 
           RowBox[{"\[Theta]", ",", "np", ",", "m"}], "]"}]}]}], ")"}], 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", "\[Theta]f"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Integrals\[Theta]f", "[", "\[Theta]ff_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Theta]f", "=", 
         RowBox[{"0.99999", "\[Theta]ff"}]}], ",", "\[Pi]nmT", ",", 
        "\[Tau]nmT", ",", "HmmtT", ",", "HnmT", ",", "I1Tt", ",", "I2Tt", ",",
         "n"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Pi]nmT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"\[Pi]nm", "[", 
             RowBox[{"\[Theta]f", ",", "n", ",", "m"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "0", ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", 
            RowBox[{"nmax", "+", "3"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Tau]nmT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"\[Tau]nm", "[", 
             RowBox[{"\[Theta]f", ",", "n", ",", "m"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "0", ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", 
            RowBox[{"nmax", "+", "3"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"HmmtT", "=", 
        RowBox[{"RecurrenceTable", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Hmmt", "[", "n", "]"}], "\[Equal]", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", "n"}], "-", "1"}], ")"}], "!!"}], ")"}], "2"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "\[Theta]f", "]"}], 
                  RowBox[{"2", "n"}]]}], "+", 
                FractionBox[
                 RowBox[{"2", "n", " ", 
                  RowBox[{"Hmmt", "[", 
                   RowBox[{"n", "-", "1"}], "]"}]}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "n"}], "-", "1"}], ")"}], 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "n"}], "-", "3"}], ")"}], "!!"}], ")"}], 
                   "2"]}]]}], ")"}]}]}], ",", 
            RowBox[{
             RowBox[{"Hmmt", "[", "0", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"Cos", "[", "\[Theta]f", "]"}], "-", "1"}]}]}], "}"}], 
          ",", "Hmmt", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", 
            RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"HnmT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", "0", ",", 
              RowBox[{"nmax", "+", "3"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"nmax", "+", "3"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"m", "=", "0"}], ",", 
         RowBox[{"m", "\[LessEqual]", "nmax"}], ",", 
         RowBox[{"m", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"HnmT", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"m", "+", "1"}], ",", 
             RowBox[{"m", "+", "1"}]}], "\[RightDoubleBracket]"}], "=", 
           RowBox[{"HmmtT", "\[LeftDoubleBracket]", 
            RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"n", "=", "m"}], ",", 
            RowBox[{"n", "\[LessEqual]", "nmax"}], ",", 
            RowBox[{"n", "++"}], ",", 
            RowBox[{
             RowBox[{"HnmT", "\[LeftDoubleBracket]", 
              RowBox[{
               RowBox[{"n", "+", "2"}], ",", 
               RowBox[{"m", "+", "1"}]}], "\[RightDoubleBracket]"}], "=", 
             RowBox[{"(", 
              RowBox[{
               FractionBox["1", 
                RowBox[{"n", "-", "m", "+", "1"}]], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "+", "m", "+", "1"}], ")"}], 
                  RowBox[{"HnmT", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"n", "+", "1"}], ",", 
                    RowBox[{"m", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "m", "+", "1"}], ")"}], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], ")"}],
                     "2"]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", "m", "+", "1"}], ")"}], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "2"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], ")"}],
                     "2"]}]}], ")"}]}], "-", 
                    RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], 
                    RowBox[{
                    RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{
                    RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "2"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                   ")"}]}]}], ")"}]}], ")"}]}]}], "\[IndentingNewLine]", 
           "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"I1Tt", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"np", "\[Equal]", "n"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], 
                    RowBox[{
                    RowBox[{"2", "n"}], "+", "1"}]]}], 
                  RowBox[{"HnmT", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"n", "+", "1"}], ",", 
                    RowBox[{"m", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
                 "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
                  RowBox[{
                   RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                   "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                  RowBox[{
                   RowBox[{"\[Tau]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                   "\[LeftDoubleBracket]", 
                   RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                ",", 
                FractionBox[
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"]}], 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"np", 
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], 
                    RowBox[{
                    RowBox[{"\[Tau]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{
                    RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"np", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], "-", 
                    RowBox[{"n", 
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], 
                    RowBox[{
                    RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
                    RowBox[{
                    RowBox[{"\[Tau]nmT", "\[LeftDoubleBracket]", 
                    RowBox[{"np", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
                   ")"}]}], 
                 RowBox[{
                  RowBox[{"n", 
                   RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}]}], "-", 
                  RowBox[{"np", 
                   RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}]}]}]]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "0", ",", 
                RowBox[{"Min", "[", 
                 RowBox[{"np", ",", "n"}], "]"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"np", ",", "1", ",", "npmax"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"I2Tt", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
               RowBox[{
                RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                 RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}], 
               RowBox[{
                RowBox[{"\[Pi]nmT", "\[LeftDoubleBracket]", 
                 RowBox[{"np", "+", "1"}], "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"m", "+", "1"}], "\[RightDoubleBracket]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "0", ",", 
                RowBox[{"Min", "[", 
                 RowBox[{"np", ",", "n"}], "]"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"np", ",", "1", ",", "npmax"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "I1Tt", ",", "I2Tt", ",", "HmmtT", ",", "HnmT", ",", "\[Pi]nmT", ",", 
         "\[Tau]nmT"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ScatterOAE", "[", 
     RowBox[{
     "x00_", ",", "y00_", ",", "z00_", ",", "ss_", ",", "anLL_", ",", 
      "bnLL_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0", "=", "x00"}], ",", 
        RowBox[{"y0", "=", "y00"}], ",", 
        RowBox[{"z0", "=", 
         RowBox[{"-", "z00"}]}], ",", 
        RowBox[{"s", "=", "ss"}], ",", 
        RowBox[{"anL", "=", "anLL"}], ",", 
        RowBox[{"bnL", "=", "bnLL"}], ",", "CextG", ",", "CscaG", ",", 
        "CabsG", ",", "CscaOA", ",", "CextOA", ",", "SignalOA", ",", "gnmTET",
         ",", "gnmTMT"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gnmTET", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"gnmTEAddT", "[", 
             RowBox[{"n", ",", "m", ",", "s", ",", 
              RowBox[{"2", 
               RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", "y0"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"gnmTMT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"gnmTMAddT", "[", 
             RowBox[{"n", ",", "m", ",", "s", ",", 
              RowBox[{"2", 
               RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", "y0"}], 
             "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"CscaG", "=", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "\[Pi]", " "}], 
          SuperscriptBox["k", "2"]], 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "nmax"], 
          RowBox[{
           RowBox[{
           "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
           
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", 
              RowBox[{"-", "n"}]}], "n"], 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "+", 
                 RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], "2"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{
                   "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], "2"]}]}], ")"}]}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "-", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]]}]}]}]}]}], 
       ";", 
       RowBox[{"CextG", "=", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "\[Pi]", " "}], 
          SuperscriptBox["k", "2"]], 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"n", "=", "1"}], "nmax"], 
          RowBox[{
           RowBox[{
           "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
           
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"m", "=", 
              RowBox[{"-", "n"}]}], "n"], 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "+", 
                 RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], " ", 
              RowBox[{"Re", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "anL", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{
                 "bnL", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", 
                   RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], "2"]}]}], "]"}]}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "-", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]]}]}]}]}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"CabsG", "=", 
        RowBox[{"CextG", "-", "CscaG"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"CscaOA", "=", 
        RowBox[{"Re", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            RowBox[{
            "Nn", "\[LeftDoubleBracket]", "np", "\[RightDoubleBracket]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "anL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                  "bnL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "bnL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}]}], ")"}], "*", 
               RowBox[{"I1T", "\[LeftDoubleBracket]", 
                RowBox[{"n", ",", "np", ",", 
                 RowBox[{
                  RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
                "\[RightDoubleBracket]"}]}], "+", 
              RowBox[{"I", " ", "m", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "bnL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                  "bnL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}]}], ")"}], "*", 
               RowBox[{"I2T", "\[LeftDoubleBracket]", 
                RowBox[{"n", ",", "np", ",", 
                 RowBox[{
                  RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", "nmax"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "n"}], ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"np", ",", 
             RowBox[{"Max", "[", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], ",", "1"}], "]"}], ",", "1"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"CextOA", "=", 
        RowBox[{"Re", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
            RowBox[{
            "Nn", "\[LeftDoubleBracket]", "np", "\[RightDoubleBracket]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "bnL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}]}], ")"}], "*", 
               RowBox[{"I1T", "\[LeftDoubleBracket]", 
                RowBox[{"n", ",", "np", ",", 
                 RowBox[{
                  RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
                "\[RightDoubleBracket]"}]}], "+", 
              RowBox[{"I", " ", "m", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}]}], 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "np", 
                    "\[RightDoubleBracket]"}], "]"}], 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"np", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"np", "+", "1"}], ")"}], "+", "m"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}]}], ")"}], "*", 
               RowBox[{"I2T", "\[LeftDoubleBracket]", 
                RowBox[{"n", ",", "np", ",", 
                 RowBox[{
                  RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", "nmax"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "n"}], ",", "n"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"np", ",", 
             RowBox[{"Max", "[", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], ",", "1"}], "]"}], ",", "1"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"SignalOA", "=", 
        RowBox[{"CscaOA", "-", "CextOA"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"CextG", ",", "CscaG", ",", "CabsG", ",", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           SuperscriptBox["k", "2"]], "CscaOA"}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           SuperscriptBox["k", "2"]], "CextOA"}], ",", 
         RowBox[{
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           SuperscriptBox["k", "2"]], "SignalOA"}]}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"\[Theta]f", "=", "0.5"}], ";", 
    RowBox[{"Test", "=", 
     RowBox[{"Integrals\[Theta]f", "[", "\[Theta]f", "]"}]}], ";", 
    RowBox[{"I1T", "=", 
     RowBox[{"Test", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
     ";", 
    RowBox[{"I2T", "=", 
     RowBox[{"Test", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"I1N", "[", 
          RowBox[{"3", ",", "2", ",", "1", ",", "\[Theta]f"}], "]"}], ",", 
         RowBox[{"I1T", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"I1N", "[", 
          RowBox[{"4", ",", "4", ",", "2", ",", "\[Theta]f"}], "]"}], ",", 
         RowBox[{"I1T", "\[LeftDoubleBracket]", 
          RowBox[{"4", ",", "4", ",", "3"}], "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"I1N", "[", 
          RowBox[{"1", ",", "2", ",", "1", ",", "\[Theta]f"}], "]"}], ",", 
         RowBox[{"I1T", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
        "}"}]}], "}"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"I2N", "[", 
          RowBox[{"3", ",", "2", ",", "1", ",", "\[Theta]f"}], "]"}], ",", 
         RowBox[{"I2T", "\[LeftDoubleBracket]", 
          RowBox[{"3", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"I2N", "[", 
          RowBox[{"4", ",", "4", ",", "2", ",", "\[Theta]f"}], "]"}], ",", 
         RowBox[{"I2T", "\[LeftDoubleBracket]", 
          RowBox[{"4", ",", "4", ",", "3"}], "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"I2N", "[", 
          RowBox[{"1", ",", "2", ",", "1", ",", "\[Theta]f"}], "]"}], ",", 
         RowBox[{"I2T", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
        "}"}]}], "}"}]}]}], "*)"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5926427792540216`*^9, 3.592642794568759*^9}, {
   3.592642830152213*^9, 3.592642862546418*^9}, {3.592643009379498*^9, 
   3.592643024011511*^9}, {3.592643056415991*^9, 3.592643199214016*^9}, {
   3.5926432342311*^9, 3.592643294596505*^9}, {3.592643333593403*^9, 
   3.592643348119581*^9}, {3.5926434709944353`*^9, 3.592643645452895*^9}, {
   3.592644094368346*^9, 3.5926441315715303`*^9}, {3.592644530922711*^9, 
   3.592644534744465*^9}, {3.592644633303133*^9, 3.5926446336823397`*^9}, {
   3.592645198622354*^9, 3.592645198947795*^9}, {3.5926452794559317`*^9, 
   3.592645364474959*^9}, {3.592645446726019*^9, 3.592645496670294*^9}, {
   3.592646305857114*^9, 3.592646364459711*^9}, {3.592646399839666*^9, 
   3.592646470780963*^9}, {3.592646521059557*^9, 3.592646745466783*^9}, {
   3.592646783963552*^9, 3.592646879382978*^9}, {3.592646912950347*^9, 
   3.59264691819639*^9}, {3.592647078043831*^9, 3.592647121508973*^9}, {
   3.5926471825845337`*^9, 3.592647182754076*^9}, {3.592647349944558*^9, 
   3.592647352952985*^9}, {3.592647545496751*^9, 3.592647584379525*^9}, {
   3.592647630771235*^9, 3.592647661298295*^9}, {3.592647802873008*^9, 
   3.5926478633326817`*^9}, {3.5926479201106243`*^9, 3.59264795627558*^9}, {
   3.592648019437244*^9, 3.5926481194789753`*^9}, {3.592648158831698*^9, 
   3.592648189370249*^9}, {3.5926482312409697`*^9, 3.5926483151896353`*^9}, {
   3.5926483668105097`*^9, 3.592648397466782*^9}, {3.592650257710258*^9, 
   3.5926503630527983`*^9}, {3.592650400737734*^9, 3.592650512787529*^9}, {
   3.592650747910375*^9, 3.592650748212998*^9}, {3.592650835436901*^9, 
   3.592650843028594*^9}, {3.592650874567988*^9, 3.5926509759466333`*^9}, {
   3.5926510620116158`*^9, 3.592651063379702*^9}, {3.592651227842004*^9, 
   3.592651260313429*^9}, {3.5926514778133793`*^9, 3.592651497455518*^9}, {
   3.592651543597643*^9, 3.592651546077271*^9}, {3.5926515928048553`*^9, 
   3.5926515929195423`*^9}, {3.5926516364521646`*^9, 3.5926516374428663`*^9},
    {3.592651794409423*^9, 3.5926518214644547`*^9}, {3.5926519279105186`*^9, 
   3.592651962284721*^9}, {3.5926520823809032`*^9, 3.5926520839768763`*^9}, {
   3.592652201494802*^9, 3.5926522443608913`*^9}, {3.592652310903236*^9, 
   3.592652402966281*^9}, {3.5926524840368567`*^9, 3.592652487317605*^9}, {
   3.59265270324225*^9, 3.592652764953279*^9}, {3.59265281117514*^9, 
   3.592653080414287*^9}, {3.592653119697412*^9, 3.592653294573493*^9}, {
   3.592653363242373*^9, 3.5926535235393047`*^9}, {3.592653559158606*^9, 
   3.592653617177002*^9}, {3.592653743207964*^9, 3.5926537833746634`*^9}, {
   3.59265383460118*^9, 3.5926538560246773`*^9}, {3.5926539075288687`*^9, 
   3.592654024852335*^9}, {3.59265406107618*^9, 3.5926541464246197`*^9}, {
   3.5926543252943287`*^9, 3.5926549817123003`*^9}, {3.592655197839485*^9, 
   3.5926551984100723`*^9}, {3.59265550011287*^9, 3.5926555035544443`*^9}, {
   3.592655565151979*^9, 3.592655593062307*^9}, {3.592655656659622*^9, 
   3.5926556593724546`*^9}, {3.5926557424711123`*^9, 3.592655827187357*^9}, {
   3.592655870541663*^9, 3.592655921296207*^9}, {3.5926559747943687`*^9, 
   3.592655996817231*^9}, {3.59265612143718*^9, 3.5926561301584377`*^9}, {
   3.592656166837747*^9, 3.592656476093549*^9}, {3.592656520799947*^9, 
   3.592656548496765*^9}, {3.592656796893553*^9, 3.592656852412436*^9}, {
   3.592656945682494*^9, 3.5926570376573257`*^9}, {3.592657087142173*^9, 
   3.592657108760231*^9}, {3.592657201365192*^9, 3.592657300394661*^9}, {
   3.592657335079443*^9, 3.592657385155903*^9}, {3.592657571636003*^9, 
   3.592657589082115*^9}, {3.592657719724681*^9, 3.5926577410174923`*^9}, {
   3.5926577893719473`*^9, 3.592657859516509*^9}, {3.592657894040359*^9, 
   3.592657894492758*^9}, {3.592658095970468*^9, 3.592658100634058*^9}, 
   3.592658174096962*^9, {3.5926583526315804`*^9, 3.592658364240327*^9}, {
   3.592658657363935*^9, 3.592658755184544*^9}, {3.592658791968504*^9, 
   3.5926588950187387`*^9}, {3.5926589479830437`*^9, 3.592659015936792*^9}, {
   3.5926591075273733`*^9, 3.592659113497985*^9}, {3.592659157955681*^9, 
   3.592659169513733*^9}, {3.592659230379725*^9, 3.592659257466988*^9}, {
   3.592659310855897*^9, 3.592659321985558*^9}, {3.592659400547645*^9, 
   3.592659429311173*^9}, {3.5926594814286337`*^9, 3.5926594815840387`*^9}, {
   3.5926595727868013`*^9, 3.592659573046012*^9}, {3.592733943106533*^9, 
   3.592733966880623*^9}, {3.59385786976322*^9, 3.593857881564617*^9}, {
   3.593860760665586*^9, 3.5938607631291103`*^9}, {3.593860912682075*^9, 
   3.5938609139556627`*^9}, {3.597407011613701*^9, 3.597407022203287*^9}, {
   3.597411063896636*^9, 3.597411086526745*^9}, {3.597411567361825*^9, 
   3.597411571641241*^9}, {3.597487268429966*^9, 3.5974872697733717`*^9}, {
   3.598119811636578*^9, 3.5981198704784403`*^9}, 3.598157766969006*^9, 
   3.5981586229992647`*^9, 3.598158668478476*^9, {3.598166957659184*^9, 
   3.598166960768156*^9}, {3.5981670974678097`*^9, 3.5981671016472683`*^9}, {
   3.598167148234441*^9, 3.598167151924514*^9}, {3.598167197607127*^9, 
   3.5981672211867743`*^9}, {3.5981672538738117`*^9, 3.59816727447323*^9}, {
   3.598781599588106*^9, 3.5987816165691643`*^9}, 3.598781646882066*^9}],

Cell[CellGroupData[{

Cell["\<\
Rayleigh Limit, Off-Axis for small particles\
\>", "Subsubsection",
 CellChangeTimes->{{3.598282981885829*^9, 3.598282991724918*^9}, {
  3.5987809966004333`*^9, 3.5987810356310663`*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Ax", ",", "P0", ",", "PR", ",", "PI", ",", "PSx"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScatterOARayleigh", "[", 
    RowBox[{
    "x00_", ",", "y00_", ",", "z00_", ",", "ss_", ",", "\[Alpha]\[Alpha]_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x0", "=", "x00"}], ",", 
       RowBox[{"y0", "=", "y00"}], ",", 
       RowBox[{"z0", "=", 
        RowBox[{"-", "z00"}]}], ",", 
       RowBox[{"s", "=", "ss"}], ",", 
       RowBox[{"\[Alpha]", "=", "\[Alpha]\[Alpha]"}], ",", "Ax", ",", 
       "CextOA", ",", "CscaOA", ",", "SignalOA", ",", "gnmTET", ",", "gnmTMT",
        ",", "Cabs"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"gnmTET", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"gnmTE", "[", 
             RowBox[{
             "n", ",", "m", ",", "jmax", ",", "s", ",", "z0", ",", "x0", ",", 
              "y0"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"gnmTMT", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"gnmTM", "[", 
             RowBox[{
             "n", ",", "m", ",", "jmax", ",", "s", ",", "z0", ",", "x0", ",", 
              "y0"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"m", ",", 
              RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", 
            RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gnmTET", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"gnmTEAddT", "[", 
            RowBox[{"n", ",", "m", ",", "s", ",", 
             RowBox[{"2", 
              RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", "0"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"gnmTMT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"gnmTMAddT", "[", 
            RowBox[{"n", ",", "m", ",", "s", ",", 
             RowBox[{"2", 
              RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", "0"}], 
            "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Ax", "=", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
            "Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], "/",
             "2"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
              RowBox[{"n", ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
              "\[RightDoubleBracket]"}], 
             RowBox[{"Conjugate", "[", 
              RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", 
                RowBox[{"2", "+", "m"}]}], "\[RightDoubleBracket]"}], "]"}], 
             RowBox[{"I1T", "\[LeftDoubleBracket]", 
              RowBox[{"n", ",", "1", ",", 
               RowBox[{
                RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
              "\[RightDoubleBracket]"}]}], "+", 
            RowBox[{"I", " ", "m", " ", 
             RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
              RowBox[{"n", ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
              "\[RightDoubleBracket]"}], 
             RowBox[{"Conjugate", "[", 
              RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", 
                RowBox[{"2", "+", "m"}]}], "\[RightDoubleBracket]"}], "]"}], 
             RowBox[{"I2T", "\[LeftDoubleBracket]", 
              RowBox[{"n", ",", "1", ",", 
               RowBox[{
                RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
              "\[RightDoubleBracket]"}]}]}], ")"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"m", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CextOA", "=", 
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Re", "[", "Ax", "]"}], 
           RowBox[{"Im", "[", "\[Alpha]", "]"}]}], "-", 
          RowBox[{
           RowBox[{"Im", "[", "Ax", "]"}], 
           RowBox[{"Re", "[", "\[Alpha]", "]"}]}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CscaOA", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["k", "4"], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Abs", "[", "\[Alpha]", "]"}], "2"], "/", 
           RowBox[{"(", 
            RowBox[{"8", "\[Pi]"}], ")"}]}]}], ")"}], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", 
               RowBox[{"2", "+", "m"}]}], "\[RightDoubleBracket]"}], "]"}], 
            "2"], 
           RowBox[{"I1T", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1", ",", 
             RowBox[{
              RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]}], 
            "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", 
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Cabs", "=", 
       RowBox[{
        RowBox[{"-", "k"}], " ", 
        RowBox[{"Im", "[", "\[Alpha]", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "]"}], 
            "2"]}], "+", 
          RowBox[{"2", 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}], "]"}], 
            "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"Abs", "[", 
            RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], 
           "2"]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"SignalOA", "=", 
       RowBox[{"CscaOA", "-", "CextOA"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"SignalOA", ",", "CscaOA", ",", "CextOA", ",", 
        RowBox[{"Re", "[", "Ax", "]"}], ",", 
        RowBox[{"Im", "[", "Ax", "]"}], ",", "Cabs"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.598119732952289*^9, 3.598119779336042*^9}, {
   3.598119875104335*^9, 3.598120358183223*^9}, {3.598120389848909*^9, 
   3.598120445546063*^9}, 3.59812051351495*^9, {3.5981205563538*^9, 
   3.598120783628867*^9}, 3.598120989205217*^9, {3.598122388383436*^9, 
   3.5981224168482227`*^9}, {3.598122518546247*^9, 3.5981225410021067`*^9}, {
   3.598122575740138*^9, 3.598122660325526*^9}, {3.598153607847043*^9, 
   3.5981536209567337`*^9}, {3.598158530887682*^9, 3.598158548624626*^9}, {
   3.598164313567749*^9, 3.598164344820345*^9}, {3.598166273652463*^9, 
   3.5981662780374517`*^9}, {3.598166312459262*^9, 3.598166312770945*^9}, {
   3.598166360858008*^9, 3.598166396597412*^9}, {3.598166839780921*^9, 
   3.598166861757255*^9}, {3.59816746594628*^9, 3.598167467634671*^9}, {
   3.5981677643404493`*^9, 3.598167789825882*^9}, {3.598171293768158*^9, 
   3.598171299800392*^9}, 3.5981721338858*^9, {3.598175297638476*^9, 
   3.5981752978762283`*^9}, 3.5981774522565937`*^9, {3.5981776644048347`*^9, 
   3.598177664878606*^9}, {3.5982831274388657`*^9, 3.598283128115844*^9}, {
   3.5982831736555758`*^9, 3.5982832110038347`*^9}, {3.5982832513466053`*^9, 
   3.598283356588526*^9}, {3.598283390797516*^9, 3.598283621824657*^9}, {
   3.598283698118145*^9, 3.598283701372795*^9}, {3.598283781659465*^9, 
   3.598283793318527*^9}, {3.598283973839408*^9, 3.598283975654297*^9}, {
   3.598284446888646*^9, 3.598284451064994*^9}, {3.598284925812202*^9, 
   3.598284979016953*^9}, {3.598285033661895*^9, 3.5982850339622383`*^9}, {
   3.598291355599978*^9, 3.598291362126896*^9}, 3.598349228439589*^9, {
   3.5986798564862127`*^9, 3.598679886669064*^9}, {3.5986799875890617`*^9, 
   3.598680049182706*^9}, {3.598680318131138*^9, 3.598680327258771*^9}, {
   3.598681915843541*^9, 3.5986819475403433`*^9}, {3.598697830765691*^9, 
   3.598697857830652*^9}, {3.5986989296961327`*^9, 3.598698934992402*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Radiation Forces, Gouesbet Formalism",
  FontSize->50],
 "\n",
 StyleBox["Help: Markus Selmke (selmke@rz.uni-leipzig.de, \
markus.selmke@gmx.de)",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.4977910729476*^9, 3.497791085493401*^9}, {
  3.4978102134039383`*^9, 3.497810253191922*^9}, {3.554286455849388*^9, 
  3.554286461334003*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "Gaussian on-axis BSCs (MLA), ",
 StyleBox["BSC: beam shape coefficients",
  FontSize->14],
 "\n",
 StyleBox["\"Partial-wave representations of laser beams for use in \
light-scattering calculations\", G\[EAcute]rard Gouesbet, James A. Lock, and \
G\[EAcute]rard Gr\[EAcute]han, 20 April 1995, Vol. 34, No. 12, APPLIED OPTICS\
\nNotation: \[Gamma] = 2 z/\[Omega]0, s = w0/l",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.497791064163142*^9, 3.497791066278159*^9}, {
   3.497811065890477*^9, 3.49781111728531*^9}, {3.499432530230111*^9, 
   3.499432550548489*^9}, 3.5296449292507057`*^9, {3.529644978218852*^9, 
   3.529644985192461*^9}, {3.529645034461788*^9, 3.52964510376457*^9}, {
   3.554278970931547*^9, 3.55427899270618*^9}, {3.5577408468066607`*^9, 
   3.5577408599914713`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Q", "[", 
    RowBox[{"n_", ",", "s_", ",", "\[Gamma]_"}], "]"}], ":=", 
   FractionBox["1", 
    RowBox[{"1", "-", 
     RowBox[{"\[ImaginaryI]", " ", "s", " ", "\[Gamma]"}]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"gnMLA", "[", 
     RowBox[{"n_", ",", "s_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Gamma]"}], 
        RowBox[{"2", " ", "s"}]]}]], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"n", "+", "2"}], ")"}], " ", 
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"Q", "[", 
          RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}]}], ")"}]}]]}]}], 
   ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"MLA", ":", " ", 
     RowBox[{"modified", " ", "local", " ", "approximation"}]}], ",", " ", 
    RowBox[{"more", " ", "accurate", " ", "than", " ", "LA"}], ",", " ", 
    RowBox[{"rigorously", " ", "justified"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"gnLA", "[", 
     RowBox[{"n_", ",", "s_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Gamma]"}], 
        RowBox[{"2", " ", "s"}]]}]], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", 
         RowBox[{"1", "/", "2"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"n", "+", 
         RowBox[{"1", "/", "2"}]}], ")"}], " ", 
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"Q", "[", 
          RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}]}], ")"}]}]]}]}], 
   ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"LA", ":", " ", 
     RowBox[{"local", " ", "approximation"}]}], ",", " ", 
    RowBox[{"less", " ", "accurate"}], ",", " ", 
    RowBox[{"motivated", " ", "via", " ", "Barton", " ", "et", " ", 
     RowBox[{"al", ".", "'"}], "s", " ", "work"}]}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.554278663975795*^9, 3.554278675634184*^9}, {
   3.554278705988607*^9, 3.554278711006757*^9}, 3.554278762372208*^9, {
   3.554278961383627*^9, 3.554278969070641*^9}, {3.557740781142058*^9, 
   3.557740838749205*^9}, {3.572088795329742*^9, 3.572088797542162*^9}, {
   3.5720906027701683`*^9, 3.5720906095366898`*^9}, {3.5987810498277693`*^9, 
   3.598781092412837*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Gaussian off-axis BSCs (LA, ",
 StyleBox["not MLA!, falsely sensitive to s for high focusing",
  FontSize->18],
 ")\n",
 StyleBox["\"Localized Approximation of Generalized Lorenz-Mie Theory: Faster \
Algorithm for Computations of Beam Shape Coefficients, gnm\", Kuan F. Ren, \
Gerard Grehan, Gerard Gouesbet, 1991\n",
  FontSize->12],
 StyleBox["coordinates of the beam waist center as viewed from the particle \
(r0=-",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "p"], TraditionalForm]],
  FontSize->12],
 StyleBox[")",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["!: x0 = x/",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox[", y0 = y/",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox[", ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox[" = z/l,  ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"k", " ", 
      SuperscriptBox["\[Omega]0", "2"]}]}], ","}], TraditionalForm]],
  FontSize->12],
 StyleBox[" s=",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox["/l=1/(k ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox["), ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", 
    RowBox[{
     SubscriptBox["n", "med"], "med", " ", "2", "\[Pi]", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["w", "0"], "2"], "/", "\[Lambda]"}]}]}], 
   TraditionalForm]], "None",
  FontSize->12],
 StyleBox[", \[Gamma]=2 z0/",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.497791064163142*^9, 3.497791066278159*^9}, {
   3.497811065890477*^9, 3.49781111728531*^9}, {3.499432530230111*^9, 
   3.499432550548489*^9}, 3.5296449292507057`*^9, {3.529644989584557*^9, 
   3.529644990968552*^9}, {3.5542787555294027`*^9, 3.554278758120583*^9}, {
   3.554279018474639*^9, 3.554279018710978*^9}, {3.554279052306334*^9, 
   3.5542790559954233`*^9}, {3.554523932717222*^9, 3.554524048136654*^9}, {
   3.597406931152341*^9, 3.597406939239506*^9}, {3.5981577145392723`*^9, 
   3.598157749465837*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "x0", ",", "z0", ",", "y0", ",", "Xm", ",", "Xp", ",", "a", ",", "Rnm"}], 
    "]"}], ";", 
   RowBox[{"eps", "=", "0.000000001"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "test", " ", "parameters", " ", "for", " ", "table", " ", "check"}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"functions", " ", "for", " ", "gaussian", " ", "off"}], "-", 
    RowBox[{"axis", " ", "BSCs"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Xm", "[", 
    RowBox[{"x0_", ",", "y0_"}], "]"}], ":=", 
   RowBox[{"x0", "-", 
    RowBox[{"I", " ", "y0"}], "+", "eps"}]}], ";", 
  RowBox[{
   RowBox[{"Xp", "[", 
    RowBox[{"x0_", ",", "y0_"}], "]"}], ":=", 
   RowBox[{"x0", "+", 
    RowBox[{"I", " ", "y0"}], "+", "eps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", 
     RowBox[{"n_", ",", "z0_", ",", "s_"}], "]"}], ":=", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "+", 
        RowBox[{"1", "/", "2"}]}], ")"}], "s"}], 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "I", " ", "z0"}]}]]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "[", 
      RowBox[{"n_", ",", "z0_", ",", "s_"}], "]"}], ":=", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"n", "+", "2"}], ")"}], "s"}], 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "I", " ", "z0"}]}]]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rnm", "[", 
    RowBox[{"n_", ",", "m_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"m", "\[Equal]", "0"}], ",", 
     FractionBox[
      RowBox[{"2", "n", 
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}]}], 
      RowBox[{
       RowBox[{"2", "n"}], "+", "1"}]], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", 
        RowBox[{
         RowBox[{"2", "n"}], "+", "1"}]], ")"}], 
      RowBox[{
       RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F0nTM", "[", 
    RowBox[{
    "n_", ",", "m_", ",", "jmax_", ",", "s_", ",", "z0_", ",", "x0_", ",", 
     "y0_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"m", "\[Equal]", "0"}], ",", 
     RowBox[{"2", " ", "x0", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", 
           RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
          RowBox[{
           RowBox[{"2", "j"}], "+", "1"}]], 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"Xm", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"Xp", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], "j"]}], 
          RowBox[{
           RowBox[{"j", "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"j", "+", "1"}], ")"}], "!"}]}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "jmax"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m", ">", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", 
           RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
          RowBox[{"m", "-", "1"}]], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Xm", "[", 
            RowBox[{"x0", ",", "y0"}], "]"}], 
           RowBox[{"m", "-", "1"}]], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "!"}]]}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", 
             RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
            RowBox[{
             RowBox[{"2", "j"}], "-", "m", "+", "1"}]], 
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"Xp", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "-", "m"}]], 
             SuperscriptBox[
              RowBox[{"Xm", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], "j"]}], 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"j", "-", "m"}], ")"}], "!"}], 
             RowBox[{"j", "!"}]}]], 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"Xp", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "-", "m", "+", "1"}]], "+", 
             FractionBox[
              RowBox[{"Xm", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "+", "1"}]]}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "m", ",", "jmax"}], "}"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", 
           RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
          RowBox[{
           RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Xp", "[", 
            RowBox[{"x0", ",", "y0"}], "]"}], 
           RowBox[{
            RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Abs", "[", "m", "]"}], "-", "1"}], ")"}], "!"}]]}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", 
             RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
            RowBox[{
             RowBox[{"2", "j"}], "-", 
             RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]], 
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"Xp", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], "j"], 
             SuperscriptBox[
              RowBox[{"Xm", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "-", 
               RowBox[{"Abs", "[", "m", "]"}]}]]}], 
            RowBox[{
             RowBox[{"j", "!"}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"j", "-", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]}]], 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"Xm", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "-", 
               RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]], "+", 
             FractionBox[
              RowBox[{"Xp", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "+", "1"}]]}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", 
            RowBox[{"Abs", "[", "m", "]"}], ",", "jmax"}], "}"}]}], "]"}]}]}],
       "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gnmTM", "[", 
    RowBox[{
    "n_", ",", "m_", ",", "jmax_", ",", "s_", ",", "z0_", ",", "x0_", ",", 
     "y0_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "I", " ", "z0"}]}], ")"}]}]], 
    RowBox[{"Exp", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"I", " ", "z0"}], 
       SuperscriptBox["s", "2"]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["x0", "2"], "+", 
        SuperscriptBox["y0", "2"]}], 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "I", " ", "z0"}]}]]}], "]"}], 
    RowBox[{"Exp", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"n", "+", 
           RowBox[{"1", "/", "2"}]}], ")"}], "2"]}], 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "I", " ", "z0"}]}]], 
      SuperscriptBox["s", "2"]}], "]"}], 
    RowBox[{"Rnm", "[", 
     RowBox[{"n", ",", "m"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "I"}], ")"}], 
     RowBox[{"Abs", "[", "m", "]"}]], "I", " ", 
    RowBox[{"F0nTM", "[", 
     RowBox[{
     "n", ",", "m", ",", "jmax", ",", "s", ",", "z0", ",", "x0", ",", "y0"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F0nTE", "[", 
    RowBox[{
    "n_", ",", "m_", ",", "jmax_", ",", "s_", ",", "z0_", ",", "x0_", ",", 
     "y0_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"m", "\[Equal]", "0"}], ",", 
     RowBox[{"2", " ", "I", " ", "y0", " ", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", 
           RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
          RowBox[{
           RowBox[{"2", "j"}], "+", "1"}]], 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"Xm", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"Xp", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], "j"]}], 
          RowBox[{
           RowBox[{"j", "!"}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"j", "+", "1"}], ")"}], "!"}]}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "jmax"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m", ">", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", 
           RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
          RowBox[{"m", "-", "1"}]], 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Xm", "[", 
            RowBox[{"x0", ",", "y0"}], "]"}], 
           RowBox[{"m", "-", "1"}]], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "!"}]]}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", 
             RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
            RowBox[{
             RowBox[{"2", "j"}], "-", "m", "+", "1"}]], 
           FractionBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"Xp", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "-", "m"}]], 
             SuperscriptBox[
              RowBox[{"Xm", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], "j"]}], 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"j", "-", "m"}], ")"}], "!"}], 
             RowBox[{"j", "!"}]}]], 
           RowBox[{"(", 
            RowBox[{
             FractionBox[
              RowBox[{"Xp", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "-", "m", "+", "1"}]], "-", 
             FractionBox[
              RowBox[{"Xm", "[", 
               RowBox[{"x0", ",", "y0"}], "]"}], 
              RowBox[{"j", "+", "1"}]]}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "m", ",", "jmax"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", 
             RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
            RowBox[{
             RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]], 
           FractionBox[
            SuperscriptBox[
             RowBox[{"Xp", "[", 
              RowBox[{"x0", ",", "y0"}], "]"}], 
             RowBox[{
              RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Abs", "[", "m", "]"}], "-", "1"}], ")"}], "!"}]]}], 
          "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"a", "[", 
               RowBox[{"n", ",", "z0", ",", "s"}], "]"}], 
              RowBox[{
               RowBox[{"2", "j"}], "-", 
               RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]], 
             FractionBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"Xp", "[", 
                 RowBox[{"x0", ",", "y0"}], "]"}], "j"], 
               SuperscriptBox[
                RowBox[{"Xm", "[", 
                 RowBox[{"x0", ",", "y0"}], "]"}], 
                RowBox[{"j", "-", 
                 RowBox[{"Abs", "[", "m", "]"}]}]]}], 
              RowBox[{
               RowBox[{"j", "!"}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"j", "-", 
                  RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]}]], 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"Xm", "[", 
                 RowBox[{"x0", ",", "y0"}], "]"}], 
                RowBox[{"j", "-", 
                 RowBox[{"Abs", "[", "m", "]"}], "+", "1"}]], "-", 
               FractionBox[
                RowBox[{"Xp", "[", 
                 RowBox[{"x0", ",", "y0"}], "]"}], 
                RowBox[{"j", "+", "1"}]]}], ")"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Abs", "[", "m", "]"}], ",", "jmax"}], "}"}]}], "]"}]}],
          ")"}]}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gnmTE", "[", 
    RowBox[{
    "n_", ",", "m_", ",", "jmax_", ",", "s_", ",", "z0_", ",", "x0_", ",", 
     "y0_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "I", " ", "z0"}]}], ")"}]}]], 
    RowBox[{"Exp", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"I", " ", "z0"}], 
       SuperscriptBox["s", "2"]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["x0", "2"], "+", 
        SuperscriptBox["y0", "2"]}], 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "I", " ", "z0"}]}]]}], "]"}], 
    RowBox[{"Exp", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"n", "+", 
           RowBox[{"1", "/", "2"}]}], ")"}], "2"]}], 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "I", " ", "z0"}]}]], 
      SuperscriptBox["s", "2"]}], "]"}], 
    RowBox[{"Rnm", "[", 
     RowBox[{"n", ",", "m"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "I"}], ")"}], 
     RowBox[{"Abs", "[", "m", "]"}]], 
    RowBox[{"F0nTE", "[", 
     RowBox[{
     "n", ",", "m", ",", "jmax", ",", "s", ",", "z0", ",", "x0", ",", "y0"}], 
     "]"}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.483717050703693*^9, 3.483717107683577*^9}, {
   3.483717144502136*^9, 3.483717163236207*^9}, {3.483717223074294*^9, 
   3.4837174169484863`*^9}, {3.483717452895051*^9, 3.483717638588603*^9}, {
   3.4837176741912737`*^9, 3.483717894961233*^9}, {3.4837179672535343`*^9, 
   3.483717995780615*^9}, {3.483718033116261*^9, 3.483718064441533*^9}, {
   3.48371809931857*^9, 3.48371815015926*^9}, {3.4837182479870663`*^9, 
   3.483718427054965*^9}, {3.483718514045143*^9, 3.4837186376550303`*^9}, {
   3.483718710961052*^9, 3.483718714067618*^9}, {3.4840727248182507`*^9, 
   3.48407275813513*^9}, {3.48407359952265*^9, 3.4840736291004*^9}, {
   3.484407853699766*^9, 3.484407864664379*^9}, {3.484407897046526*^9, 
   3.484407950475025*^9}, {3.484407987474275*^9, 3.484408059782446*^9}, {
   3.484932361993827*^9, 3.484932426518701*^9}, {3.484932481615362*^9, 
   3.484932626703463*^9}, {3.484932706064516*^9, 3.4849327089554853`*^9}, {
   3.48493505618857*^9, 3.484935059060972*^9}, {3.4849351747058897`*^9, 
   3.484935179311997*^9}, {3.4849352252642317`*^9, 3.4849352301109753`*^9}, {
   3.48532763771189*^9, 3.485327647510913*^9}, {3.485492776055834*^9, 
   3.485492900280405*^9}, {3.485492943462658*^9, 3.4854930574055147`*^9}, {
   3.489000556803177*^9, 3.489000611995698*^9}, 3.489000676631517*^9, {
   3.489000724933764*^9, 3.4890008276977*^9}, {3.4890008616975307`*^9, 
   3.4890009059998198`*^9}, {3.489000998092308*^9, 3.48900099982745*^9}, {
   3.4890011390505247`*^9, 3.489001139484733*^9}, {3.489001384392355*^9, 
   3.489001442982387*^9}, {3.489001563651598*^9, 3.4890015749079647`*^9}, 
   3.4890017153897448`*^9, {3.489001784489853*^9, 3.489001786617571*^9}, {
   3.489001867092228*^9, 3.4890018683475637`*^9}, {3.489002153059896*^9, 
   3.489002178949963*^9}, {3.4890039192324057`*^9, 3.489003946250203*^9}, {
   3.490882510088324*^9, 3.490882751776415*^9}, {3.490882943294983*^9, 
   3.490882947299107*^9}, {3.490883114154242*^9, 3.490883141535119*^9}, {
   3.49088322874979*^9, 3.490883298845488*^9}, {3.490883361180887*^9, 
   3.4908833769517*^9}, {3.490884082967482*^9, 3.490884088197378*^9}, {
   3.490884195913527*^9, 3.49088422011063*^9}, {3.490884480387226*^9, 
   3.490884480790697*^9}, {3.490884571908619*^9, 3.490884572201557*^9}, {
   3.4908920576668167`*^9, 3.490892082019659*^9}, {3.490894299220241*^9, 
   3.490894313230397*^9}, {3.490895326822937*^9, 3.4908953520843487`*^9}, {
   3.490895394969783*^9, 3.4908953964930353`*^9}, {3.4909515894818163`*^9, 
   3.490951590709942*^9}, {3.490952099639071*^9, 3.490952099837081*^9}, {
   3.490952335551187*^9, 3.490952335789167*^9}, {3.490952406420711*^9, 
   3.490952409128599*^9}, {3.490954728630557*^9, 3.490954731080351*^9}, {
   3.4976079817810783`*^9, 3.4976080020154533`*^9}, 3.4977228874500933`*^9, {
   3.4977237189423943`*^9, 3.497723719452932*^9}, {3.4977237643429317`*^9, 
   3.4977237644994926`*^9}, {3.497726914989373*^9, 3.497726947883778*^9}, {
   3.498989559301618*^9, 3.4989896003080797`*^9}, {3.516557321296527*^9, 
   3.516557340175724*^9}, {3.5165573981821127`*^9, 3.516557446065158*^9}, {
   3.5165574859994307`*^9, 3.516557603342722*^9}, 3.516558417701212*^9, {
   3.516558563418545*^9, 3.516558566937361*^9}, {3.516558611756752*^9, 
   3.51655862676783*^9}, {3.52155584601366*^9, 3.521555848198847*^9}, {
   3.529837952592029*^9, 3.529837988415908*^9}, {3.547916172720607*^9, 
   3.547916174026477*^9}, {3.554278636473021*^9, 3.554278660122048*^9}, {
   3.554278843153564*^9, 3.554278844086668*^9}, {3.554278890334189*^9, 
   3.554278897544313*^9}, {3.5542789561437387`*^9, 3.5542789582719183`*^9}, 
   3.55445374082266*^9, {3.5544538031775417`*^9, 3.554453821758067*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Gaussian off-axis BSCs (LA, ",
 StyleBox["artifact-free for large x0",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["\"Plane-wave spectrum of electromagnetic beams\", A. Doicu and T. \
Wriedt, Opt. Commun. 136, 114-124, 1997\n\[OpenCurlyDoubleQuote]Computation \
of the beam shape coefficients in the Generalized Lorenz-Mie Theory by using \
the translational addition theorem for spherical vector wave functions\
\[CloseCurlyDoubleQuote], A. Doicu and T. Wriedt, 1997\nx0 = x/",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox[", y0 = y/",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox[", ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox[" = z/l,  ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"k", " ", 
      SuperscriptBox["\[Omega]0", "2"]}]}], ","}], TraditionalForm]],
  FontSize->12],
 StyleBox[" s=",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox["/l=1/(k ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "0"], TraditionalForm]], "None",
  FontSize->12],
 StyleBox["), ",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   RowBox[{"l", "=", 
    RowBox[{
     SubscriptBox["n", "med"], "med", " ", "2", "\[Pi]", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["w", "0"], "2"], "/", "\[Lambda]"}]}]}], 
   TraditionalForm]], "None",
  FontSize->12],
 StyleBox[", \[Gamma]=2 zp/",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["w", "0"], "=", 
    RowBox[{"2", 
     RowBox[{"z0", "/", "s"}]}]}], TraditionalForm]], "None",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.497791064163142*^9, 3.497791066278159*^9}, {
   3.497811065890477*^9, 3.49781111728531*^9}, {3.499432530230111*^9, 
   3.499432550548489*^9}, 3.5296449292507057`*^9, {3.529644989584557*^9, 
   3.529644990968552*^9}, {3.533276698803783*^9, 3.5332767564645357`*^9}, {
   3.53327751170024*^9, 3.533277516200556*^9}, {3.5986792871668053`*^9, 
   3.598679300726358*^9}, {3.5986795197184153`*^9, 3.5986795212559834`*^9}, {
   3.598681004477622*^9, 3.5986810432180023`*^9}, {3.598698667741939*^9, 
   3.598698713206889*^9}, {3.598698998315094*^9, 3.5986990038256207`*^9}, {
   3.5987269836032553`*^9, 3.598726991089919*^9}, {3.598780974734763*^9, 
   3.59878097546194*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Qb", "[", 
    RowBox[{"n_", ",", "s_", ",", "\[Gamma]_"}], "]"}], ":=", 
   FractionBox["1", 
    RowBox[{"\[ImaginaryI]", "-", 
     RowBox[{"s", " ", "\[Gamma]"}]}]]}], ";", 
  RowBox[{
   RowBox[{"\[Rho]n", "[", 
    RowBox[{"n_", ",", "s_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", "0.5"}], ")"}], "s"}]}], ";", 
  RowBox[{
   RowBox[{"\[Rho]0", "[", 
    RowBox[{"x0_", ",", "y0_"}], "]"}], ":=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     SuperscriptBox["x0", "2"], "+", 
     SuperscriptBox["y0", "2"]}], "]"}]}], ";", 
  RowBox[{"eps", "=", "0.000000001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Knm", "[", 
    RowBox[{"n_", ",", "m_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"m", "\[Equal]", "0"}], ",", 
     RowBox[{"n", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "1"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"n", "+", "0.5"}], ")"}]}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "I"}], ")"}], 
       RowBox[{"Abs", "[", "m", "]"}]], 
      RowBox[{"I", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"n", "+", "0.5"}], ")"}], 
        RowBox[{
         RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gnmTMAddT", "[", 
    RowBox[{
    "n_", ",", "m_", ",", "s_", ",", "\[Gamma]_", ",", "z0_", ",", "x0_", ",",
      "y0_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Knm", "[", 
     RowBox[{"n", ",", "m"}], "]"}], 
    RowBox[{"(", 
     RowBox[{"I", " ", 
      RowBox[{"Qb", "[", 
       RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", 
        RowBox[{"Qb", "[", 
         RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[Rho]0", "[", 
            RowBox[{"x0", ",", "y0"}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[Rho]n", "[", 
            RowBox[{"n", ",", "s"}], "]"}], "2"]}], ")"}]}], "]"}]}], ")"}], 
    FractionBox[
     RowBox[{"Exp", "[", 
      RowBox[{"I", " ", 
       RowBox[{"\[Gamma]", "/", 
        RowBox[{"(", 
         RowBox[{"2", "s"}], ")"}]}]}], "]"}], "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"I", 
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"m", "-", "1"}], ",", 
           RowBox[{"2", 
            RowBox[{"Qb", "[", 
             RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
            RowBox[{"\[Rho]0", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], 
            RowBox[{"\[Rho]n", "[", 
             RowBox[{"n", ",", "s"}], "]"}]}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"I", 
           RowBox[{"(", 
            RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"2", 
            RowBox[{"Qb", "[", 
             RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
            RowBox[{"\[Rho]0", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], 
            RowBox[{"\[Rho]n", "[", 
             RowBox[{"n", ",", "s"}], "]"}]}]}], "]"}]}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Phi]", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"y0", "+", "eps"}], ",", 
          RowBox[{"x0", "+", "eps"}]}], "]"}]}], "}"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gnmTEAddT", "[", 
    RowBox[{
    "n_", ",", "m_", ",", "s_", ",", "\[Gamma]_", ",", "z0_", ",", "x0_", ",",
      "y0_"}], "]"}], ":=", 
   RowBox[{
    SuperscriptBox["I", 
     RowBox[{"-", "1"}]], 
    RowBox[{"Knm", "[", 
     RowBox[{"n", ",", "m"}], "]"}], 
    RowBox[{"(", 
     RowBox[{"I", " ", 
      RowBox[{"Qb", "[", 
       RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", 
        RowBox[{"Qb", "[", 
         RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[Rho]0", "[", 
            RowBox[{"x0", ",", "y0"}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[Rho]n", "[", 
            RowBox[{"n", ",", "s"}], "]"}], "2"]}], ")"}]}], "]"}]}], ")"}], 
    FractionBox[
     RowBox[{"Exp", "[", 
      RowBox[{"I", " ", 
       RowBox[{"\[Gamma]", "/", 
        RowBox[{"(", 
         RowBox[{"2", "s"}], ")"}]}]}], "]"}], "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"I", 
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"m", "-", "1"}], ",", 
           RowBox[{"2", 
            RowBox[{"Qb", "[", 
             RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
            RowBox[{"\[Rho]0", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], 
            RowBox[{"\[Rho]n", "[", 
             RowBox[{"n", ",", "s"}], "]"}]}]}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"I", 
           RowBox[{"(", 
            RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{"2", 
            RowBox[{"Qb", "[", 
             RowBox[{"n", ",", "s", ",", "\[Gamma]"}], "]"}], 
            RowBox[{"\[Rho]0", "[", 
             RowBox[{"x0", ",", "y0"}], "]"}], 
            RowBox[{"\[Rho]n", "[", 
             RowBox[{"n", ",", "s"}], "]"}]}]}], "]"}]}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Phi]", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"y0", "+", "eps"}], ",", 
          RowBox[{"x0", "+", "eps"}]}], "]"}]}], "}"}]}], ")"}]}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ/eRUZoB+8CvHhBenkkD0v9R3mSDaZyN7Hoiu6ZS+
B6LTXWrug+iwU7mvQHTo2eOvwep2iH4B0XPMZn0F0XEVoUEGQNpc42wIiD6+
KyMaRMdccYwD0fPTT6SBaAPrhmYQPcmXqQNEl8rf6QfRf9jZpoPoupDVs0C0
9s/2hSA6uD1+HYhWedO2GUSvmXRhD4g20jt0EUTL3PlzCUQvsux6BqIrPNa8
BdFipyKPvD//yvHYjAIw3aBoeg5Eix7LBdPPrveqfwDSHvabNED05R/rnUG0
rkOlJ4i+cy00FUTfsJ0MpvW8tJl+AuloiXww/UPnMweIvsO/nAtET5dREgbR
KdNSwDQAwNW26Q==
  "]],

Cell[CellGroupData[{

Cell["Check Both BSCs against each other :", "Subsubsection",
 CellChangeTimes->{{3.5986808981493196`*^9, 3.598680912306254*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTE", "[", 
     RowBox[{
     "4", ",", "2", ",", "10", ",", "s", ",", "2", ",", "1", ",", "1"}], 
     "]"}], "]"}], ",", 
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTEAddT", "[", 
     RowBox[{"4", ",", "2", ",", "s", ",", 
      RowBox[{"2", "*", 
       RowBox[{"2", "/", "s"}]}], ",", "2", ",", "1", ",", "1"}], "]"}], 
    "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTE", "[", 
     RowBox[{
     "5", ",", "3", ",", "10", ",", "s", ",", "2", ",", "1", ",", "1"}], 
     "]"}], "]"}], ",", 
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTEAddT", "[", 
     RowBox[{"5", ",", "3", ",", "s", ",", 
      RowBox[{"2", "*", 
       RowBox[{"2", "/", "s"}]}], ",", "2", ",", "1", ",", "1"}], "]"}], 
    "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTM", "[", 
     RowBox[{
     "4", ",", "2", ",", "10", ",", "s", ",", "2", ",", "1", ",", "1"}], 
     "]"}], "]"}], ",", 
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTMAddT", "[", 
     RowBox[{"4", ",", "2", ",", "s", ",", 
      RowBox[{"2", "*", 
       RowBox[{"2", "/", "s"}]}], ",", "2", ",", "1", ",", "1"}], "]"}], 
    "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTM", "[", 
     RowBox[{
     "5", ",", "3", ",", "10", ",", "s", ",", "2", ",", "1", ",", "1"}], 
     "]"}], "]"}], ",", 
   RowBox[{"Timing", "[", 
    RowBox[{"gnmTMAddT", "[", 
     RowBox[{"5", ",", "3", ",", "s", ",", 
      RowBox[{"2", "*", 
       RowBox[{"2", "/", "s"}]}], ",", "2", ",", "1", ",", "1"}], "]"}], 
    "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.5986803643960037`*^9, 3.598680364603713*^9}, {
   3.5986803967233553`*^9, 3.598680454453421*^9}, {3.598680711606391*^9, 
   3.598680844323543*^9}, 3.598680882996413*^9, {3.598680915581236*^9, 
   3.5986809248061533`*^9}, {3.598681055484765*^9, 3.59868107083497*^9}, {
   3.598698537851944*^9, 3.59869855221255*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.00053300000000000005359601651377943199`2.7473271223061966", ",", 
     RowBox[{
      RowBox[{"-", "0.004364511564040826`"}], "-", 
      RowBox[{"0.0059263924738842235`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.0002970000000000000092183205513407529`2.4933563625968365", ",", 
     RowBox[{
      RowBox[{"-", "0.004364511564717195`"}], "-", 
      RowBox[{"0.005926392469037732`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.598680423194419*^9, 3.598680454910914*^9}, {
   3.598680711924028*^9, 3.598680845515427*^9}, 3.598680883373966*^9, {
   3.598680925714802*^9, 3.598680958706614*^9}, {3.598681061883337*^9, 
   3.598681071214978*^9}, 3.598697957847282*^9, 3.598698517321045*^9, {
   3.598698552644746*^9, 3.598698582890436*^9}, 3.5986986529047937`*^9, 
   3.5986987179026003`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.00045199999999999998208724538706348994`2.675738348091006", ",", 
     RowBox[{"0.00023427685960590548`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.0001322139260203653`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.00028099999999999999977795539507496869`2.469306233184704", ",", 
     RowBox[{"0.0002342768595066819`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.0001322139256657796`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.598680423194419*^9, 3.598680454910914*^9}, {
   3.598680711924028*^9, 3.598680845515427*^9}, 3.598680883373966*^9, {
   3.598680925714802*^9, 3.598680958706614*^9}, {3.598681061883337*^9, 
   3.598681071214978*^9}, 3.598697957847282*^9, 3.598698517321045*^9, {
   3.598698552644746*^9, 3.598698582890436*^9}, 3.5986986529047937`*^9, 
   3.598698717904278*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.00046599999999999999712382847683045384`2.6889858299696243", ",", 
     RowBox[{"0.005958966833718567`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.004079556386320354`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00023299999999999999856191423841522692`2.387955834305643", ",", 
     RowBox[{"0.005958966829247578`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.004079556387465315`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.598680423194419*^9, 3.598680454910914*^9}, {
   3.598680711924028*^9, 3.598680845515427*^9}, 3.598680883373966*^9, {
   3.598680925714802*^9, 3.598680958706614*^9}, {3.598681061883337*^9, 
   3.598681071214978*^9}, 3.598697957847282*^9, 3.598698517321045*^9, {
   3.598698552644746*^9, 3.598698582890436*^9}, 3.5986986529047937`*^9, 
   3.598698717905237*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0.00042400000000000000622418783180478385`2.6479657698723567", ",", 
     RowBox[{
      RowBox[{"-", "0.00013625041681933047`"}], "+", 
      RowBox[{"0.00022759260933030264`", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
    "0.00020799999999999998719947547076714045`2.3386632482423857", ",", 
     RowBox[{
      RowBox[{"-", "0.00013625041647005384`"}], "+", 
      RowBox[{"0.00022759260925225107`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.598680423194419*^9, 3.598680454910914*^9}, {
   3.598680711924028*^9, 3.598680845515427*^9}, 3.598680883373966*^9, {
   3.598680925714802*^9, 3.598680958706614*^9}, {3.598681061883337*^9, 
   3.598681071214978*^9}, 3.598697957847282*^9, 3.598698517321045*^9, {
   3.598698552644746*^9, 3.598698582890436*^9}, 3.5986986529047937`*^9, 
   3.598698717906167*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Simplify BSCs analytically to find expressions for transmission for Rayleigh \
particles (off-axis)\
\>", "Subsubsection",
 CellChangeTimes->{{3.5986808981493196`*^9, 3.598680912306254*^9}, {
  3.601459915844288*^9, 3.601459949707993*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Phi]", ",", "zR", ",", "zp", ",", "s", ",", "\[Rho]0", ",", "m", ",", 
   "n", ",", "k", ",", "z0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gnmTMloc", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "I"}], ")"}], 
       RowBox[{"Abs", "[", "m", "]"}]], "I"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"n", "+", 
        FractionBox["1", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]]], 
    RowBox[{"(", 
     RowBox[{"I", " ", 
      FractionBox["1", 
       RowBox[{"I", "+", 
        RowBox[{"2", "z0"}]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", 
        FractionBox["1", 
         RowBox[{"I", "+", 
          RowBox[{"2", "z0"}]}]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Rho]0", "2"], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"n", "+", 
              FractionBox["1", "2"]}], ")"}], "2"], 
           SuperscriptBox["s", "2"]}]}], ")"}]}], "]"}]}], ")"}], 
    FractionBox[
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "I"}], " ", 
       RowBox[{"z0", "/", 
        SuperscriptBox["s", "2"]}]}], "]"}], "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"I", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
       RowBox[{"BesselJ", "[", 
        RowBox[{
         RowBox[{"m", "-", "1"}], ",", 
         RowBox[{
          FractionBox["2", 
           RowBox[{"I", "+", 
            RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
          RowBox[{"(", 
           RowBox[{"n", "+", 
            FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"I", 
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
       RowBox[{"BesselJ", "[", 
        RowBox[{
         RowBox[{"m", "+", "1"}], ",", 
         RowBox[{
          FractionBox["2", 
           RowBox[{"I", "+", 
            RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
          RowBox[{"(", 
           RowBox[{"n", "+", 
            FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gn0TMloc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"n", 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}]}], 
       RowBox[{"n", "+", 
        FractionBox["1", "2"]}]], 
      RowBox[{"(", 
       RowBox[{"I", " ", 
        FractionBox["1", 
         RowBox[{"I", "+", 
          RowBox[{"2", "z0"}]}]], 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "I"}], " ", 
          FractionBox["1", 
           RowBox[{"I", "+", 
            RowBox[{"2", "z0"}]}]], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Rho]0", "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"n", "+", 
                FractionBox["1", "2"]}], ")"}], "2"], 
             SuperscriptBox["s", "2"]}]}], ")"}]}], "]"}]}], ")"}], 
      FractionBox[
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "I"}], " ", 
         RowBox[{"z0", "/", 
          SuperscriptBox["s", "2"]}]}], "]"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"I", 
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"m", "-", "1"}], ",", 
           RowBox[{
            FractionBox["2", 
             RowBox[{"I", "+", 
              RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
            RowBox[{"(", 
             RowBox[{"n", "+", 
              FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"I", 
           RowBox[{"(", 
            RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ",", 
           RowBox[{
            FractionBox["2", 
             RowBox[{"I", "+", 
              RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
            RowBox[{"(", 
             RowBox[{"n", "+", 
              FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}]}], ")"}]}], 
     ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{"m", "\[Rule]", "0"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gnmTEloc", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "I"}], ")"}], 
       RowBox[{"Abs", "[", "m", "]"}]], "I"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"n", "+", 
        FractionBox["1", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]]], 
    FractionBox["1", "I"], 
    RowBox[{"(", 
     RowBox[{"I", " ", 
      FractionBox["1", 
       RowBox[{"I", "+", 
        RowBox[{"2", "z0"}]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", 
        FractionBox["1", 
         RowBox[{"I", "+", 
          RowBox[{"2", "z0"}]}]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Rho]0", "2"], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"n", "+", 
              FractionBox["1", "2"]}], ")"}], "2"], 
           SuperscriptBox["s", "2"]}]}], ")"}]}], "]"}]}], ")"}], 
    FractionBox[
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "I"}], " ", 
       RowBox[{"z0", "/", 
        SuperscriptBox["s", "2"]}]}], "]"}], "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"I", 
         RowBox[{"(", 
          RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
       RowBox[{"BesselJ", "[", 
        RowBox[{
         RowBox[{"m", "-", "1"}], ",", 
         RowBox[{
          FractionBox["2", 
           RowBox[{"I", "+", 
            RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
          RowBox[{"(", 
           RowBox[{"n", "+", 
            FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"I", 
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
       RowBox[{"BesselJ", "[", 
        RowBox[{
         RowBox[{"m", "+", "1"}], ",", 
         RowBox[{
          FractionBox["2", 
           RowBox[{"I", "+", 
            RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
          RowBox[{"(", 
           RowBox[{"n", "+", 
            FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gn0TEloc", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"n", 
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}]}], 
        RowBox[{"n", "+", 
         FractionBox["1", "2"]}]], 
       FractionBox["1", "I"], 
       RowBox[{"(", 
        RowBox[{"I", " ", 
         FractionBox["1", 
          RowBox[{"I", "+", 
           RowBox[{"2", "z0"}]}]], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", 
           FractionBox["1", 
            RowBox[{"I", "+", 
             RowBox[{"2", "z0"}]}]], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Rho]0", "2"], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"n", "+", 
                 FractionBox["1", "2"]}], ")"}], "2"], 
              SuperscriptBox["s", "2"]}]}], ")"}]}], "]"}]}], ")"}], 
       FractionBox[
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "I"}], " ", 
          RowBox[{"z0", "/", 
           SuperscriptBox["s", "2"]}]}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"I", 
            RowBox[{"(", 
             RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
          RowBox[{"BesselJ", "[", 
           RowBox[{
            RowBox[{"m", "-", "1"}], ",", 
            RowBox[{
             FractionBox["2", 
              RowBox[{"I", "+", 
               RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", 
               FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"I", 
            RowBox[{"(", 
             RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
          RowBox[{"BesselJ", "[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{
             FractionBox["2", 
              RowBox[{"I", "+", 
               RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", 
               FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}]}]}], ")"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"m", "\[Rule]", "0"}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1mTMlocConj", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", "I", ")"}], 
         RowBox[{"Abs", "[", "m", "]"}]], 
        RowBox[{"(", 
         RowBox[{"-", "I"}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"n", "+", 
          FractionBox["1", "2"]}], ")"}], 
        RowBox[{
         RowBox[{"Abs", "[", "m", "]"}], "-", "1"}]]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "I"}], " ", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"-", "I"}], "+", 
          RowBox[{"2", "z0"}]}]], 
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox["1", 
           RowBox[{
            RowBox[{"-", "I"}], "+", 
            RowBox[{"2", "z0"}]}]], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Rho]0", "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"n", "+", 
                FractionBox["1", "2"]}], ")"}], "2"], 
             SuperscriptBox["s", "2"]}]}], ")"}]}], "]"}]}], ")"}], 
      FractionBox[
       RowBox[{"Exp", "[", 
        RowBox[{"I", " ", 
         RowBox[{"z0", "/", 
          SuperscriptBox["s", "2"]}]}], "]"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], 
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"Conjugate", "[", 
          RowBox[{"BesselJ", "[", 
           RowBox[{
            RowBox[{"m", "-", "1"}], ",", 
            RowBox[{
             FractionBox["2", 
              RowBox[{"I", "+", 
               RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", 
               FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], 
           RowBox[{"(", 
            RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"Conjugate", "[", 
          RowBox[{"BesselJ", "[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{
             FractionBox["2", 
              RowBox[{"I", "+", 
               RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", 
               FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}], "]"}]}]}], 
       ")"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{"n", "\[Rule]", "1"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g10TMlocConj", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"n", 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}]}], 
       RowBox[{"n", "+", 
        FractionBox["1", "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "I"}], " ", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"-", "I"}], "+", 
          RowBox[{"2", "z0"}]}]], 
        RowBox[{"Exp", "[", 
         RowBox[{"I", " ", 
          FractionBox["1", 
           RowBox[{
            RowBox[{"-", "I"}], "+", 
            RowBox[{"2", "z0"}]}]], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Rho]0", "2"], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"n", "+", 
                FractionBox["1", "2"]}], ")"}], "2"], 
             SuperscriptBox["s", "2"]}]}], ")"}]}], "]"}]}], ")"}], 
      FractionBox[
       RowBox[{"Exp", "[", 
        RowBox[{"I", " ", 
         RowBox[{"z0", "/", 
          SuperscriptBox["s", "2"]}]}], "]"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], 
           RowBox[{"(", 
            RowBox[{"m", "-", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"Conjugate", "[", 
          RowBox[{"BesselJ", "[", 
           RowBox[{
            RowBox[{"m", "-", "1"}], ",", 
            RowBox[{
             FractionBox["2", 
              RowBox[{"I", "+", 
               RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", 
               FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], 
           RowBox[{"(", 
            RowBox[{"m", "+", "1"}], ")"}], "\[Phi]"}], "]"}], 
         RowBox[{"Conjugate", "[", 
          RowBox[{"BesselJ", "[", 
           RowBox[{
            RowBox[{"m", "+", "1"}], ",", 
            RowBox[{
             FractionBox["2", 
              RowBox[{"I", "+", 
               RowBox[{"2", "z0"}]}]], "\[Rho]0", " ", 
             RowBox[{"(", 
              RowBox[{"n", "+", 
               FractionBox["1", "2"]}], ")"}], "s"}]}], "]"}], "]"}]}]}], 
       ")"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[Rule]", "1"}], ",", 
      RowBox[{"m", "\[Rule]", "0"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.601402628270643*^9, 3.601402668630824*^9}, {
   3.601402745363055*^9, 3.601402747179166*^9}, {3.6014029721576567`*^9, 
   3.601402974189122*^9}, {3.6014031447087793`*^9, 3.601403151759736*^9}, {
   3.6014031915181627`*^9, 3.60140324819249*^9}, {3.60140328702102*^9, 
   3.601403291620674*^9}, {3.601403325934656*^9, 3.6014033309453707`*^9}, {
   3.6014033613236523`*^9, 3.601403396653215*^9}, {3.6014411911451607`*^9, 
   3.601441191431673*^9}, {3.60144124162741*^9, 3.601441377263213*^9}, {
   3.601441407590065*^9, 3.6014414248781137`*^9}, {3.601441475003636*^9, 
   3.601441528445558*^9}, {3.601441591358917*^9, 3.6014416435303717`*^9}, {
   3.60144167359291*^9, 3.601441705271545*^9}, {3.601443367438231*^9, 
   3.601443383764347*^9}, {3.601443683674192*^9, 3.60144376772752*^9}, {
   3.601444008354785*^9, 3.601444015310581*^9}, {3.601445249133094*^9, 
   3.601445259050507*^9}, {3.601445479409267*^9, 3.601445502370525*^9}, {
   3.601445535755691*^9, 3.6014455555112047`*^9}, {3.60144560735242*^9, 
   3.60144560981074*^9}, 3.601445985549354*^9, {3.601446894894451*^9, 
   3.60144689927245*^9}, {3.6014470693041983`*^9, 3.601447107860382*^9}, {
   3.601447206245882*^9, 3.601447212045032*^9}, {3.6014472547337637`*^9, 
   3.601447274398219*^9}, {3.6014473239958057`*^9, 3.6014474321346893`*^9}, {
   3.601447511478366*^9, 3.601447562726741*^9}, {3.6014476360646467`*^9, 
   3.601447640976712*^9}, 3.601448060235499*^9, {3.601455455360256*^9, 
   3.60145549766791*^9}, 3.601455576937407*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Sigma]extI1n1mm1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"gnmTMloc", "*", "g1mTMlocConj"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"m", "\[Rule]", 
       RowBox[{"-", "1"}]}], "}"}]}], ")"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]extI1n1mp1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"gnmTMloc", "*", "g1mTMlocConj"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"m", "\[Rule]", "1"}], "}"}]}], ")"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]extI1n1mm0", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"gn0TMloc", "*", "g10TMlocConj"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]extI2n1mm1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"I", " ", "m", "*", "gnmTEloc", "*", "g1mTMlocConj"}], ")"}], 
       "/.", 
       RowBox[{"{", 
        RowBox[{"m", "\[Rule]", 
         RowBox[{"-", "1"}]}], "}"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"I", " ", "m", "*", "gnmTEloc", "*", "g1mTMlocConj"}], ")"}], 
       "/.", 
       RowBox[{"{", 
        RowBox[{"m", "\[Rule]", "1"}], "}"}]}], ")"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]sca", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gnmTMloc", "*", "g1mTMlocConj"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n", "\[Rule]", "1"}], ",", 
           RowBox[{"m", "\[Rule]", 
            RowBox[{"-", "1"}]}]}], "}"}]}], ")"}], "+", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"gnmTMloc", "*", "g1mTMlocConj"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"n", "\[Rule]", "1"}], ",", 
           RowBox[{"m", "\[Rule]", "1"}]}], "}"}]}], ")"}]}], ")"}], 
     SuperscriptBox["I111", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"gn0TMloc", "*", "g10TMlocConj"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{"n", "\[Rule]", "1"}], "}"}]}], ")"}], "*", 
     SuperscriptBox["I110", "2"]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.601441658109185*^9, 3.6014416637486963`*^9}, {
  3.601441709920577*^9, 3.601441762089301*^9}, {3.601443389017581*^9, 
  3.601443395625204*^9}, {3.601443631020071*^9, 3.601443632546571*^9}, {
  3.60144377709949*^9, 3.601443881705017*^9}, {3.6014439163394814`*^9, 
  3.601443935761176*^9}, {3.601445143939818*^9, 3.601445169008575*^9}, {
  3.601445283284919*^9, 3.601445283553368*^9}, {3.601446057003263*^9, 
  3.601446093101506*^9}, {3.6014461338869133`*^9, 3.601446212313669*^9}, {
  3.60144624872816*^9, 3.601446348072816*^9}, {3.601446392375016*^9, 
  3.6014464357581043`*^9}, {3.601446478451438*^9, 3.6014465589671183`*^9}, {
  3.6014563581021748`*^9, 3.601456382029851*^9}, {3.601456416042015*^9, 
  3.601456420944297*^9}, {3.601457744430851*^9, 3.6014577546943293`*^9}, {
  3.601462842574978*^9, 3.6014628568489428`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", "n", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "-", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Rho]0", "2"]}], "+", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Phi]", "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Phi]"}]}], ")"}]}]}], 
      RowBox[{"2", "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["z0", "2"]}]}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
      RowBox[{"BesselJ", "[", 
       RowBox[{"0", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
         RowBox[{"\[ImaginaryI]", "+", 
          RowBox[{"2", " ", "z0"}]}]]}], "]"}]}], "+", 
     RowBox[{"BesselJ", "[", 
      RowBox[{"2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
        RowBox[{"\[ImaginaryI]", "+", 
         RowBox[{"2", " ", "z0"}]}]]}], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Conjugate", "[", 
      RowBox[{"BesselJ", "[", 
       RowBox[{"0", ",", 
        FractionBox[
         RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
         RowBox[{"\[ImaginaryI]", "+", 
          RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
      RowBox[{"Conjugate", "[", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"2", ",", 
         FractionBox[
          RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
          RowBox[{"\[ImaginaryI]", "+", 
           RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["z0", "2"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.601460140437172*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", "n", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "-", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Rho]0", "2"]}], "+", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Phi]", "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["z0", "2"], " ", "\[Phi]"}]}], ")"}]}]}], 
      RowBox[{"2", "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["z0", "2"]}]}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"BesselJ", "[", 
      RowBox[{"0", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
        RowBox[{"\[ImaginaryI]", "+", 
         RowBox[{"2", " ", "z0"}]}]]}], "]"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
      RowBox[{"BesselJ", "[", 
       RowBox[{"2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
         RowBox[{"\[ImaginaryI]", "+", 
          RowBox[{"2", " ", "z0"}]}]]}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]], " ", 
      RowBox[{"Conjugate", "[", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
          RowBox[{"\[ImaginaryI]", "+", 
           RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}]}], "+", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"BesselJ", "[", 
       RowBox[{"2", ",", 
        FractionBox[
         RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
         RowBox[{"\[ImaginaryI]", "+", 
          RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}]}], ")"}]}], 
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["z0", "2"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.601460143148945*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"2", " ", "n", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "-", 
           
           RowBox[{"8", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Rho]0", "2"]}], "+", 
        RowBox[{"4", " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"\[Phi]", "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["z0", "2"], " ", "\[Phi]"}]}], ")"}]}]}], 
       RowBox[{"2", "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["z0", "2"]}]}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Phi]"}]]}], ")"}], "2"], 
    " ", "n", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "n"}], ")"}], " ", 
    RowBox[{"BesselJ", "[", 
     RowBox[{"1", ",", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
       RowBox[{"\[ImaginaryI]", "+", 
        RowBox[{"2", " ", "z0"}]}]]}], "]"}], " ", 
    RowBox[{"Conjugate", "[", 
     RowBox[{"BesselJ", "[", 
      RowBox[{"1", ",", 
       FractionBox[
        RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
        RowBox[{"\[ImaginaryI]", "+", 
         RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}]}], 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "n"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["z0", "2"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{3.601460144047168*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", "n", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "-", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", "z0"}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Rho]0", "2"]}]}], 
      RowBox[{"2", "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["z0", "2"]}]}]]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Conjugate", "[", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"2", ",", 
         FractionBox[
          RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
          RowBox[{"\[ImaginaryI]", "+", 
           RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
            RowBox[{"\[ImaginaryI]", "+", 
             RowBox[{"2", " ", "z0"}]}]]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"BesselJ", "[", 
          RowBox[{"0", ",", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
            RowBox[{"\[ImaginaryI]", "+", 
             RowBox[{"2", " ", "z0"}]}]]}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Phi]"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"Conjugate", "[", 
       RowBox[{"BesselJ", "[", 
        RowBox[{"0", ",", 
         FractionBox[
          RowBox[{"3", " ", "s", " ", "\[Rho]0"}], 
          RowBox[{"\[ImaginaryI]", "+", 
           RowBox[{"2", " ", "z0"}]}]]}], "]"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"BesselJ", "[", 
         RowBox[{"0", ",", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
           RowBox[{"\[ImaginaryI]", "+", 
            RowBox[{"2", " ", "z0"}]}]]}], "]"}], "-", 
        RowBox[{
         RowBox[{"BesselJ", "[", 
          RowBox[{"2", ",", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", "s", " ", "\[Rho]0"}], 
            RowBox[{"\[ImaginaryI]", "+", 
             RowBox[{"2", " ", "z0"}]}]]}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "\[Phi]"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["z0", "2"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{3.601461869322791*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.601462680297104*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Exact: Tightly focussed beam, \n",
 StyleBox["i.e. gaussian illuminating Microscope Objective Back-Aperture \
fullfilling the sine-condition & having aberrations, including \
Design-parameter mismatch.\n",
  FontSize->14],
 StyleBox["\"Axial optical trapping efficiency through a dielectric interface\
\", A. A. R. Neves, A. Fontes, C. L. Cesar, A. Camposeo, R. Cingolani and D. \
Pisignano, ",
  FontSize->12],
 StyleBox["2007",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", Phys. Rev. E.",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.497784690517108*^9, 3.4977847007904787`*^9}, {
  3.497801450210753*^9, 3.49780145342161*^9}, {3.4978108069190683`*^9, 
  3.497810877941732*^9}, {3.497811141463005*^9, 3.497811231833858*^9}, {
  3.5986990174820013`*^9, 3.598699020898116*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Correct Legendre Polynomials for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 7 and older! activate Numerical Calculus"
}], "Subsubtitle",
 CellChangeTimes->{{3.487927751831504*^9, 3.487927756742806*^9}, {
  3.4908777119151497`*^9, 3.490877727656192*^9}, {3.497801459919368*^9, 
  3.497801462141357*^9}, {3.598699030354466*^9, 3.598699037426444*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Correct", " ", "Bug", " ", "in", " ", "Mathematica", " ", "7.0", ".0"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "LegendreP", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"LegendreP", "[", 
       RowBox[{"n_Integer", ",", "m_Integer", ",", "x_Real"}], "]"}], "/;", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"OddQ", "[", "n", "]"}], "&&", 
         RowBox[{"m", "\[Equal]", 
          RowBox[{"-", "n"}]}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"EvenQ", "[", "n", "]"}], "&&", 
         RowBox[{"m", "\[Equal]", 
          RowBox[{
           RowBox[{"-", "n"}], "+", "1"}]}]}], ")"}]}]}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "z", "}"}], ",", 
       RowBox[{
        RowBox[{"LegendreP", "[", 
         RowBox[{"n", ",", "m", ",", "z"}], "]"}], "/.", 
        RowBox[{"z", "\[Rule]", 
         RowBox[{"SetPrecision", "[", 
          RowBox[{"x", ",", "\[Infinity]"}], "]"}]}]}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Protect", "[", "LegendreP", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.488013024348962*^9, 3.488013024777615*^9}, {
   3.490624759256908*^9, 3.490624760742465*^9}, {3.490625081222411*^9, 
   3.490625082118411*^9}, {3.490625654017346*^9, 3.490625658383603*^9}, {
   3.490626009106105*^9, 3.4906261154041767`*^9}, {3.490626869399111*^9, 
   3.490626870005259*^9}, 3.4906271366196203`*^9, 3.490632518354581*^9, {
   3.490635295167171*^9, 3.490635296157364*^9}, {3.497788396944908*^9, 
   3.497788423427601*^9}, 3.497802726930249*^9, 3.533019920705615*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"m", ",", "n", ",", "x"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"-", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"LegendreP", "[", 
        RowBox[{"n", ",", "m", ",", "x"}], "]"}], ",", "x"}], "]"}], 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       SuperscriptBox["Cos\[Alpha]", "2"]}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", "Cos\[Alpha]"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.532940511960763*^9, 3.532940528902321*^9}, {
  3.5329407931640987`*^9, 3.532940838781736*^9}, {3.532940908261627*^9, 
  3.532940936899049*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"Cos\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "n"}], ")"}], " ", 
     RowBox[{"LegendreP", "[", 
      RowBox[{"n", ",", "m", ",", "Cos\[Alpha]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "m", "-", "n"}], ")"}], " ", 
     RowBox[{"LegendreP", "[", 
      RowBox[{
       RowBox[{"1", "+", "n"}], ",", "m", ",", "Cos\[Alpha]"}], "]"}]}]}], 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["Cos\[Alpha]", "2"]}]]]}]], "Output",
 CellChangeTimes->{
  3.5329405292142363`*^9, {3.532940804321396*^9, 3.532940839255526*^9}, {
   3.532940908957836*^9, 3.532940937186812*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define functions gnmExTM and gnmExTE ", "Subtitle",
 CellChangeTimes->{{3.490877741787043*^9, 3.490877744541041*^9}, {
  3.497810599317397*^9, 3.4978106194930143`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Correct", " ", "Pnm"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"PnmCos", "[", 
      RowBox[{"n_", ",", "m_", ",", "Cos\[Theta]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"4", "\[Pi]"}], 
          RowBox[{
           RowBox[{"2", "n"}], "+", "1"}]], 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "+", "m"}], ")"}], "!"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "-", "m"}], ")"}], "!"}]]}], "]"}]}], 
      RowBox[{"SphericalHarmonicY", "[", 
       RowBox[{"n", ",", "m", ",", 
        RowBox[{"ArcCos", "[", "Cos\[Theta]", "]"}], ",", "0"}], "]"}]}]}], 
    ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubsuperscriptBox["P", "n", "m"], 
       RowBox[{"(", 
        RowBox[{"cos", 
         RowBox[{"(", "\[Alpha]", ")"}]}], ")"}]}], ":", "  ", 
      RowBox[{
       SubsuperscriptBox["P", "n", "1"], 
       RowBox[{"(", 
        RowBox[{"cos", 
         RowBox[{"(", "\[Alpha]", ")"}]}], ")"}]}]}], "=", " ", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Alpha]", "]"}], 
      SubscriptBox["\[CapitalPi]", "n"], 
      RowBox[{"(", "\[Alpha]", ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Derivative", " ", "Relations"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PnmpCos", "[", 
      RowBox[{"Cos\[Alpha]_", ",", "n_", ",", "m_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "n"}], ")"}], " ", "Cos\[Alpha]", " ", 
          RowBox[{"PnmCos", "[", 
           RowBox[{"n", ",", "m", ",", "Cos\[Alpha]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "m", "-", "n"}], ")"}], " ", 
          RowBox[{"PnmCos", "[", 
           RowBox[{
            RowBox[{"1", "+", "n"}], ",", "m", ",", "Cos\[Alpha]"}], 
           "]"}]}]}], ")"}]}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        SuperscriptBox["Cos\[Alpha]", "2"]}], "]"}]}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "sin"}], 
      RowBox[{"(", "\[Alpha]", ")"}], "*", 
      RowBox[{
       SubsuperscriptBox["P", "n", "m"], "'"}], 
      RowBox[{"(", 
       RowBox[{"cos", 
        RowBox[{"(", "\[Alpha]", ")"}]}], ")"}]}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[Tau]", "n"], 
      RowBox[{"(", "\[Alpha]", ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"BesselJPrime", "[", 
      RowBox[{"m_", ",", "x_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"BesselJ", "[", 
         RowBox[{
          RowBox[{"m", "-", "1"}], ",", "x"}], "]"}], "-", 
        RowBox[{"BesselJ", "[", 
         RowBox[{
          RowBox[{"m", "+", "1"}], ",", "x"}], "]"}]}], ")"}], "/", "2"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ep", "=", 
     SuperscriptBox["10", 
      RowBox[{"-", "10"}]]}], ";", 
    RowBox[{"N\[Alpha]", "=", "5000"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Normalization", " ", "Factor", " ", "and", " ", "Precision", " ", "Goal",
      " ", "for", " ", "numerical", " ", "Integraion"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PrecGoal", "=", "12"}], ";", 
    RowBox[{"WorkingP", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Fresnel", " ", "Coefficients"}], ",", " ", 
     RowBox[{"for", " ", "aberration"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"c\[Alpha]2", "[", 
      RowBox[{"\[Alpha]1_", ",", "n1_", ",", "n2_"}], "]"}], ":=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["n1", "n2"], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Alpha]1", "]"}], "2"]}]}], "]"}]}], ";", 
    RowBox[{
     RowBox[{"ts", "[", 
      RowBox[{"\[Alpha]1_", ",", "n1_", ",", "n2_"}], "]"}], ":=", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          FractionBox["n2", "n1"], 
          FractionBox[
           RowBox[{"c\[Alpha]2", "[", 
            RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
           RowBox[{"Cos", "[", "\[Alpha]1", "]"}]]}]}], ")"}], 
       RowBox[{"-", "1"}]]}]}], ";", 
    RowBox[{
     RowBox[{"tp", "[", 
      RowBox[{"\[Alpha]1_", ",", "n1_", ",", "n2_"}], "]"}], ":=", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox["n2", "n1"], "+", 
         FractionBox[
          RowBox[{"c\[Alpha]2", "[", 
           RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
          RowBox[{"Cos", "[", "\[Alpha]1", "]"}]]}], ")"}], 
       RowBox[{"-", "1"}]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Define", " ", "Integrals", " ", "InmTM", " ", "and", " ", "InmTE"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"IntTM", "[", 
      RowBox[{
      "n_", ",", "m_", ",", "\[Alpha]Max_", ",", "f_", ",", "\[Omega]a_", ",",
        "k0_", ",", "n1_", ",", "n2_", ",", "d_", ",", "ds_", ",", "\[Rho]0_",
        ",", "x0_", ",", "y0_", ",", "z0_"}], "]"}], ":=", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"Cos", "[", "\[Alpha]1", "]"}]], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["f", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Alpha]1", "]"}], "2"], "/", 
            SuperscriptBox["\[Omega]a", "2"]}]}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", "k0", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"n2", " ", "z0", " ", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "+", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"n1", " ", 
                 RowBox[{"Cos", "[", "\[Alpha]1", "]"}]}], "-", 
                RowBox[{"n2", " ", 
                 RowBox[{"c\[Alpha]2", "[", 
                  RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}]}], 
               ")"}]}]}], ")"}]}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{"I", " ", "k0", " ", "ds", " ", "n1", " ", 
           RowBox[{"Cos", "[", "\[Alpha]1", "]"}]}], "]"}], 
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           RowBox[{
            SuperscriptBox["m", "2"], 
            RowBox[{"ts", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            FractionBox[
             RowBox[{"BesselJ", "[", 
              RowBox[{"m", ",", 
               RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
                RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
             RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
              RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]], 
            RowBox[{"PnmCos", "[", 
             RowBox[{"n", ",", "m", ",", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"tp", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"c\[Alpha]2", "[", 
                RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], "2"]}], 
             "]"}], 
            RowBox[{"BesselJPrime", "[", 
             RowBox[{"m", ",", 
              RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
               RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
            RowBox[{"PnmpCos", "[", 
             RowBox[{
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], ",", "n", 
              ",", "m"}], "]"}]}]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}], 
         FractionBox["x0", "\[Rho]0"]}], "+", 
        RowBox[{"I", " ", "m", " ", 
         FractionBox["y0", "\[Rho]0"], 
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           RowBox[{
            RowBox[{"ts", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], " ", 
            RowBox[{"BesselJPrime", "[", 
             RowBox[{"m", ",", 
              RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
               RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
            RowBox[{"PnmCos", "[", 
             RowBox[{"n", ",", "m", ",", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"tp", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"c\[Alpha]2", "[", 
                RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], "2"]}], 
             "]"}], 
            FractionBox[
             RowBox[{"BesselJ", "[", 
              RowBox[{"m", ",", 
               RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
                RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
             RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
              RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]], 
            RowBox[{"PnmpCos", "[", 
             RowBox[{
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], ",", "n", 
              ",", "m"}], "]"}]}]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Alpha]1", ",", "0", ",", "\[Alpha]Max"}], "}"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "PrecGoal"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"IntTE", "[", 
      RowBox[{
      "n_", ",", "m_", ",", "\[Alpha]Max_", ",", "f_", ",", "\[Omega]a_", ",",
        "k0_", ",", "n1_", ",", "n2_", ",", "d_", ",", "ds_", ",", "\[Rho]0_",
        ",", "x0_", ",", "y0_", ",", "z0_"}], "]"}], ":=", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"Cos", "[", "\[Alpha]1", "]"}]], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["f", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Alpha]1", "]"}], "2"], "/", 
            SuperscriptBox["\[Omega]a", "2"]}]}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", "k0", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"n2", " ", "z0", " ", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "+", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"n1", " ", 
                 RowBox[{"Cos", "[", "\[Alpha]1", "]"}]}], "-", 
                RowBox[{"n2", " ", 
                 RowBox[{"c\[Alpha]2", "[", 
                  RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}]}], 
               ")"}]}]}], ")"}]}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{"I", " ", "k0", " ", "ds", " ", "n1", " ", 
           RowBox[{"Cos", "[", "\[Alpha]1", "]"}]}], "]"}], 
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           RowBox[{
            SuperscriptBox["m", "2"], 
            RowBox[{"tp", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            FractionBox[
             RowBox[{"BesselJ", "[", 
              RowBox[{"m", ",", 
               RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
                RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
             RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
              RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]], 
            RowBox[{"PnmCos", "[", 
             RowBox[{"n", ",", "m", ",", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"ts", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"c\[Alpha]2", "[", 
                RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], "2"]}], 
             "]"}], 
            RowBox[{"BesselJPrime", "[", 
             RowBox[{"m", ",", 
              RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
               RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
            RowBox[{"PnmpCos", "[", 
             RowBox[{
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], ",", "n", 
              ",", "m"}], "]"}]}]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}], 
         FractionBox["y0", "\[Rho]0"]}], "-", 
        RowBox[{"I", " ", "m", " ", 
         FractionBox["x0", "\[Rho]0"], 
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           RowBox[{
            RowBox[{"tp", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], " ", 
            RowBox[{"BesselJPrime", "[", 
             RowBox[{"m", ",", 
              RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
               RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
            RowBox[{"PnmCos", "[", 
             RowBox[{"n", ",", "m", ",", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"ts", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"c\[Alpha]2", "[", 
                RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], "2"]}], 
             "]"}], 
            FractionBox[
             RowBox[{"BesselJ", "[", 
              RowBox[{"m", ",", 
               RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
                RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]}], "]"}], 
             RowBox[{"k0", " ", "n1", " ", "\[Rho]0", " ", 
              RowBox[{"Sin", "[", "\[Alpha]1", "]"}]}]], 
            RowBox[{"PnmpCos", "[", 
             RowBox[{
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], ",", "n", 
              ",", "m"}], "]"}]}]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Alpha]1", ",", "0", ",", "\[Alpha]Max"}], "}"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "PrecGoal"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"Gousebet", "'"}], "s", " ", "Coefficients", " ", "gn", " ", 
      "from", " ", "Neves", " ", "Coefficients", " ", "GnTM"}], ",", " ", 
     RowBox[{"eqn", ".5"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gnTME", "[", 
      RowBox[{
      "n_", ",", "\[Alpha]Max_", ",", "f_", ",", "\[Omega]a_", ",", "k0_", 
       ",", "n1_", ",", "n2_", ",", "d_", ",", "ds_", ",", "z0_"}], "]"}], ":=", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], 
       RowBox[{"n", 
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}]}]], 
      FractionBox[
       RowBox[{"Sqrt", "[", "n2", "]"}], "n1"], "n2", " ", " ", "k0", " ", 
      "f", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "n1", " ", "k0", " ", "f"}], " ", "]"}], 
      RowBox[{"(", 
       RowBox[{"\[Alpha]Max", "/", "N\[Alpha]"}], ")"}], 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"Cos", "[", "\[Alpha]1", "]"}]], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["f", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Alpha]1", "]"}], "2"], "/", 
            SuperscriptBox["\[Omega]a", "2"]}]}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", "k0", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"n2", " ", "z0", " ", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "+", 
             RowBox[{"d", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"n1", " ", 
                 RowBox[{"Cos", "[", "\[Alpha]1", "]"}]}], "-", 
                RowBox[{"n2", " ", 
                 RowBox[{"c\[Alpha]2", "[", 
                  RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}]}], 
               ")"}]}]}], ")"}]}], "]"}], 
         RowBox[{"Exp", "[", 
          RowBox[{"I", " ", "k0", " ", "ds", " ", "n1", " ", 
           RowBox[{"Cos", "[", "\[Alpha]1", "]"}]}], "]"}], 
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          RowBox[{
           RowBox[{
            RowBox[{"ts", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            RowBox[{"PnmCos", "[", 
             RowBox[{"n", ",", "1", ",", 
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}]}], "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{"tp", "[", 
             RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", "-", 
              SuperscriptBox[
               RowBox[{"c\[Alpha]2", "[", 
                RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], "2"]}], 
             "]"}], 
            RowBox[{"PnmpCos", "[", 
             RowBox[{
              RowBox[{"c\[Alpha]2", "[", 
               RowBox[{"\[Alpha]1", ",", "n1", ",", "n2"}], "]"}], ",", "n", 
              ",", "1"}], "]"}]}]}], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Alpha]1", ",", "0.01", ",", "\[Alpha]Max", ",", 
          RowBox[{"\[Alpha]Max", "/", "N\[Alpha]"}]}], "}"}]}], "]"}]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Gousebet", "'"}], "s", " ", "Coefficients", " ", "gnm", " ", 
     "from", " ", "Neves", " ", "Coefficients", " ", "Gnm"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gnmExTMpm", "[", 
      RowBox[{
      "n_", ",", "m_", ",", "NA_", ",", "n1_", ",", "n2_", ",", "d_", ",", 
       "ds_", ",", "f_", ",", "\[Omega]0_", ",", "\[Lambda]_", ",", "x0_", 
       ",", "y0_", ",", "z0_"}], "]"}], " ", ":=", 
     RowBox[{
      RowBox[{"IntTM", "[", 
       RowBox[{"n", ",", "m", ",", 
        RowBox[{"ArcSin", "[", 
         FractionBox["NA", "n1"], "]"}], ",", "f", ",", "\[Omega]0", ",", 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], "\[Lambda]"], ",", "n1", ",", "n2", ",", "d",
         ",", "ds", ",", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x0", "+", "ep"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y0", "+", "ep"}], ")"}], "2"]}]], ",", 
        RowBox[{"x0", "+", "ep"}], ",", 
        RowBox[{"y0", "+", "ep"}], ",", 
        RowBox[{"z0", "+", "ep"}]}], "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "m"}], ")"}], "!"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "m"}], ")"}], "!"}]], 
      FractionBox[
       RowBox[{"Sqrt", "[", "n2", "]"}], "n1"], "n2", " ", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "\[Lambda]"], "f", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "n1", 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], "\[Lambda]"], " ", "f"}], "]"}], " ", 
      SuperscriptBox["I", 
       RowBox[{"-", "m"}]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "m", " ", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"x0", "+", "ep"}], ",", 
          RowBox[{"y0", "+", "ep"}]}], "]"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gnmExTEpm", "[", 
      RowBox[{
      "n_", ",", "m_", ",", "NA_", ",", "n1_", ",", "n2_", ",", "d_", ",", 
       "ds_", ",", "f_", ",", "\[Omega]0_", ",", "\[Lambda]_", ",", "x0_", 
       ",", "y0_", ",", "z0_"}], "]"}], " ", ":=", 
     RowBox[{
      RowBox[{"IntTE", "[", 
       RowBox[{"n", ",", "m", ",", 
        RowBox[{"ArcSin", "[", 
         FractionBox["NA", "n1"], "]"}], ",", "f", ",", "\[Omega]0", ",", 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], "\[Lambda]"], ",", "n1", ",", "n2", ",", "d",
         ",", "ds", ",", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x0", "+", "ep"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"y0", "+", "ep"}], ")"}], "2"]}]], ",", 
        RowBox[{"x0", "+", "ep"}], ",", 
        RowBox[{"y0", "+", "ep"}], ",", 
        RowBox[{"z0", "+", "ep"}]}], "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "m"}], ")"}], "!"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "m"}], ")"}], "!"}]], 
      FractionBox[
       RowBox[{"Sqrt", "[", "n2", "]"}], "n1"], "n2", " ", 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "\[Lambda]"], "f", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "n1", 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], "\[Lambda]"], " ", "f"}], "]"}], " ", 
      SuperscriptBox["I", 
       RowBox[{"-", "m"}]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "m", " ", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"x0", "+", "ep"}], ",", 
          RowBox[{"y0", "+", "ep"}]}], "]"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"use", " ", "general", " ", "property", " ", "of", " ", "gnms"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gnmExTM", "[", 
      RowBox[{
      "n_", ",", "m_", ",", "NA_", ",", "n1_", ",", "n2_", ",", "d_", ",", 
       "ds_", ",", "f_", ",", "\[Omega]0_", ",", "\[Lambda]_", ",", "x0_", 
       ",", "y0_", ",", "z0_"}], "]"}], ":=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m", "\[GreaterEqual]", "0"}], ",", 
       RowBox[{"gnmExTMpm", "[", 
        RowBox[{
        "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", 
         ",", "f", ",", "\[Omega]0", ",", "\[Lambda]", ",", "x0", ",", "y0", 
         ",", "z0"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"n", "+", "1"}]], 
        RowBox[{"Conjugate", "[", 
         RowBox[{"gnmExTMpm", "[", 
          RowBox[{"n", ",", 
           RowBox[{"-", "m"}], ",", "NA", ",", "n1", ",", "n2", ",", "d", ",",
            "ds", ",", "f", ",", "\[Omega]0", ",", "\[Lambda]", ",", "x0", 
           ",", "y0", ",", "z0"}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"gnmExTE", "[", 
      RowBox[{
      "n_", ",", "m_", ",", "NA_", ",", "n1_", ",", "n2_", ",", "d_", ",", 
       "ds_", ",", "f_", ",", "\[Omega]0_", ",", "\[Lambda]_", ",", "x0_", 
       ",", "y0_", ",", "z0_"}], "]"}], ":=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m", "\[GreaterEqual]", "0"}], ",", 
       RowBox[{"gnmExTEpm", "[", 
        RowBox[{
        "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", 
         ",", "f", ",", "\[Omega]0", ",", "\[Lambda]", ",", "x0", ",", "y0", 
         ",", "z0"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"n", "+", "1"}]], 
        RowBox[{"Conjugate", "[", 
         RowBox[{"gnmExTEpm", "[", 
          RowBox[{"n", ",", 
           RowBox[{"-", "m"}], ",", "NA", ",", "n1", ",", "n2", ",", "d", ",",
            "ds", ",", "f", ",", "\[Omega]0", ",", "\[Lambda]", ",", "x0", 
           ",", "y0", ",", "z0"}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Test", " ", "Calculation"}], "..."}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", "3"}], ";", " ", 
    RowBox[{"m", "=", "1"}], ";", 
    RowBox[{"NA", "=", "1.4"}], ";", 
    RowBox[{"f", "=", 
     RowBox[{"1.8", "*", 
      SuperscriptBox["10", "6"]}]}], ";", 
    RowBox[{"wa", "=", 
     RowBox[{"1.8", "*", 
      SuperscriptBox["10", "6"]}]}], ";", 
    RowBox[{"n1", "=", "1.525"}], ";", 
    RowBox[{"n2", "=", "1.46"}], ";", 
    RowBox[{"d", "=", "0"}], ";", 
    RowBox[{"ds", "=", "0"}], ";", 
    RowBox[{"\[Lambda]", "=", "532"}], ";", 
    RowBox[{"k0", "=", 
     RowBox[{"2", 
      RowBox[{"\[Pi]", "/", "\[Lambda]"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
    "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", ",", 
     "f", ",", "wa", ",", "\[Lambda]", ",", "0.1", ",", "0.1", ",", "1"}], 
    "}"}], "\[IndentingNewLine]", 
   RowBox[{"gnmExTM", "[", 
    RowBox[{
    "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", ",", 
     "f", ",", "wa", ",", "\[Lambda]", ",", "100", ",", "100", ",", "0"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"gnmExTE", "[", 
    RowBox[{
    "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", ",", 
     "f", ",", "wa", ",", "\[Lambda]", ",", "100", ",", "100", ",", "0"}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.486742765293777*^9, 3.4867428233628674`*^9}, {
   3.486743340484301*^9, 3.486743944859694*^9}, {3.4867439750777884`*^9, 
   3.4867440192572823`*^9}, {3.486744112007468*^9, 3.486744242516706*^9}, {
   3.486744283878252*^9, 3.486744406094905*^9}, {3.4867444420718813`*^9, 
   3.48674444398459*^9}, {3.486744516314742*^9, 3.486744769348443*^9}, {
   3.4867448363613167`*^9, 3.48674483992794*^9}, {3.486750342608822*^9, 
   3.486750343703321*^9}, {3.4867507409509897`*^9, 3.486750819313694*^9}, {
   3.486750850057632*^9, 3.486750870674354*^9}, 3.4867510587721643`*^9, {
   3.48675111970055*^9, 3.486751129052855*^9}, {3.486751252073133*^9, 
   3.4867512933486557`*^9}, {3.4867513553662643`*^9, 3.486751622524592*^9}, {
   3.486751662463889*^9, 3.4867516902833233`*^9}, {3.487049434129261*^9, 
   3.4870495155561028`*^9}, {3.487049644721232*^9, 3.4870496478201227`*^9}, {
   3.487049698854294*^9, 3.48704975250594*^9}, {3.487049784439828*^9, 
   3.487049799648747*^9}, {3.487049840358837*^9, 3.4870498958406153`*^9}, {
   3.487050557395453*^9, 3.487050559563039*^9}, {3.487050871268783*^9, 
   3.487050882855795*^9}, {3.487073786727211*^9, 3.4870737882448187`*^9}, {
   3.487073834326881*^9, 3.487073865409276*^9}, {3.487075923179803*^9, 
   3.487075973997198*^9}, {3.487076063844157*^9, 3.48707609098779*^9}, {
   3.4870762144315357`*^9, 3.487076254843429*^9}, {3.487076360527166*^9, 
   3.487076360801342*^9}, {3.487076647068109*^9, 3.487076650541996*^9}, {
   3.4870767560770893`*^9, 3.487076756259322*^9}, {3.4870770160316973`*^9, 
   3.487077029414077*^9}, {3.4870773505998163`*^9, 3.48707746653459*^9}, {
   3.487077538082673*^9, 3.487077538382163*^9}, {3.487077612977417*^9, 
   3.487077619815812*^9}, {3.48707765055177*^9, 3.4870776653224173`*^9}, {
   3.487229215284894*^9, 3.4872292202047787`*^9}, {3.487565013863212*^9, 
   3.487565014211697*^9}, {3.487565140430107*^9, 3.487565140566167*^9}, {
   3.487909561631063*^9, 3.48790959109377*^9}, {3.487927936447029*^9, 
   3.4879279828860607`*^9}, 3.4879286404829617`*^9, {3.487928832135442*^9, 
   3.487928912185936*^9}, {3.487928979158091*^9, 3.487929038795286*^9}, {
   3.487929125387993*^9, 3.487929127690522*^9}, {3.4879291646447983`*^9, 
   3.4879291891395187`*^9}, {3.487930699520507*^9, 3.487930727621456*^9}, {
   3.487940600903154*^9, 3.487940617786531*^9}, {3.487941154850937*^9, 
   3.4879411626336117`*^9}, {3.487941236332271*^9, 3.4879412493815413`*^9}, {
   3.487941654812064*^9, 3.487941733207499*^9}, {3.48794222328228*^9, 
   3.4879422501222878`*^9}, {3.4879446436089993`*^9, 3.487944690827264*^9}, 
   3.487946097487686*^9, {3.487946128665578*^9, 3.487946228179138*^9}, 
   3.4879469098518457`*^9, {3.488013054963456*^9, 3.488013175619492*^9}, 
   3.490624828405798*^9, {3.49062513055624*^9, 3.4906251364571857`*^9}, {
   3.490625183374688*^9, 3.4906251845933847`*^9}, {3.49062569367701*^9, 
   3.4906256978436213`*^9}, {3.490626173987357*^9, 3.490626177269205*^9}, {
   3.490626322338139*^9, 3.490626327657207*^9}, {3.490626908607669*^9, 
   3.4906269153140287`*^9}, {3.490626966114452*^9, 3.490626966508765*^9}, {
   3.49063261577041*^9, 3.4906326320492983`*^9}, {3.4908607028272448`*^9, 
   3.490860714054933*^9}, {3.490861324700601*^9, 3.4908613248696737`*^9}, {
   3.490877185378819*^9, 3.4908772864490337`*^9}, {3.490877321087248*^9, 
   3.490877506651992*^9}, {3.490877557030113*^9, 3.490877562799583*^9}, {
   3.490877618172806*^9, 3.490877623034597*^9}, 3.490877945520557*^9, {
   3.4908801918722467`*^9, 3.49088022745669*^9}, {3.490881853510949*^9, 
   3.490881855187158*^9}, {3.490882001903434*^9, 3.490882003429962*^9}, {
   3.490899749256074*^9, 3.4908997521988707`*^9}, {3.490899783872882*^9, 
   3.490899808852377*^9}, {3.491007439390972*^9, 3.491007611923202*^9}, {
   3.491032265128914*^9, 3.491032278433556*^9}, {3.491032312328228*^9, 
   3.491032453666522*^9}, {3.491039207306946*^9, 3.4910392687020397`*^9}, {
   3.4910626407297363`*^9, 3.491062646853642*^9}, {3.4910634126008167`*^9, 
   3.491063419723361*^9}, {3.491075356881385*^9, 3.491075360184763*^9}, {
   3.491151339506402*^9, 3.4911513441780977`*^9}, {3.491837690779464*^9, 
   3.491837702815278*^9}, {3.497785018376951*^9, 3.497785071421894*^9}, {
   3.497785556523966*^9, 3.497785583081264*^9}, {3.4977856918849363`*^9, 
   3.497785703719891*^9}, {3.4977857600657797`*^9, 3.4977857908296003`*^9}, {
   3.4977858248964443`*^9, 3.497785834501132*^9}, {3.497785864833262*^9, 
   3.497786043527378*^9}, {3.4977862034237957`*^9, 3.4977863571130867`*^9}, {
   3.497786538314633*^9, 3.49778655365044*^9}, {3.497786605070751*^9, 
   3.497786735921789*^9}, {3.497786799914275*^9, 3.4977871072625647`*^9}, {
   3.4977871390338907`*^9, 3.497787326035877*^9}, {3.497787378886882*^9, 
   3.497787396890449*^9}, {3.497787427422441*^9, 3.497787436886325*^9}, {
   3.497787467154914*^9, 3.497787537280695*^9}, {3.497787573626061*^9, 
   3.49778763571437*^9}, {3.497787730666054*^9, 3.4977878057484703`*^9}, {
   3.497787859185995*^9, 3.4977880463103943`*^9}, {3.4977880850326967`*^9, 
   3.4977881003640337`*^9}, {3.497788150503389*^9, 3.497788156992878*^9}, {
   3.497788245177567*^9, 3.497788369789199*^9}, {3.497788447392098*^9, 
   3.497788624970831*^9}, {3.4977887059455*^9, 3.497788706732333*^9}, {
   3.4977901746857224`*^9, 3.497790186379509*^9}, {3.497791148319536*^9, 
   3.4977911496542473`*^9}, {3.497793951158166*^9, 3.4977940197512293`*^9}, {
   3.497799023334918*^9, 3.497799039629533*^9}, {3.497799153789764*^9, 
   3.4977991646459913`*^9}, {3.4978018383683357`*^9, 3.497801839166731*^9}, {
   3.497801947411071*^9, 3.497801959981938*^9}, {3.497802062364583*^9, 
   3.497802080892542*^9}, {3.49780215625084*^9, 3.4978021759673147`*^9}, 
   3.497802210297309*^9, {3.497802241491254*^9, 3.497802245242579*^9}, {
   3.4978023775584908`*^9, 3.4978024019616213`*^9}, {3.4978025025242*^9, 
   3.4978026404874563`*^9}, {3.497802739076326*^9, 3.4978027699044447`*^9}, {
   3.497808547289052*^9, 3.4978085581616*^9}, {3.497809418145328*^9, 
   3.497809426308836*^9}, {3.497809482769915*^9, 3.497809486629882*^9}, {
   3.497809518174903*^9, 3.497809518448291*^9}, {3.497810660524494*^9, 
   3.4978106611805687`*^9}, {3.4978106946033*^9, 3.497810773023279*^9}, {
   3.497862331104453*^9, 3.497862341184354*^9}, {3.497868593211958*^9, 
   3.497868593739272*^9}, {3.49787332011618*^9, 3.497873330401745*^9}, 
   3.497873925941929*^9, {3.4978742706694403`*^9, 3.497874275663578*^9}, {
   3.497875312429234*^9, 3.497875314723531*^9}, {3.4978759479856043`*^9, 
   3.497875953001924*^9}, {3.498066591380198*^9, 3.4980665986446953`*^9}, {
   3.4980666580531473`*^9, 3.4980666942580013`*^9}, {3.498067499523991*^9, 
   3.498067499966007*^9}, 3.498067623124542*^9, {3.498067689762838*^9, 
   3.4980676941605253`*^9}, {3.498067812943825*^9, 3.49806781498525*^9}, {
   3.498067922635738*^9, 3.498067922977601*^9}, 3.498068238187374*^9, {
   3.498068689528511*^9, 3.498068697656251*^9}, {3.498068778773999*^9, 
   3.498068788213595*^9}, {3.532889234617124*^9, 3.532889234977075*^9}, {
   3.532890083459423*^9, 3.532890084011858*^9}, {3.5329274247696953`*^9, 
   3.532927574669334*^9}, {3.532927622917787*^9, 3.53292765761866*^9}, 
   3.53292771345837*^9, {3.532927916723158*^9, 3.532927931632352*^9}, 
   3.5329323521364594`*^9, {3.532933307873007*^9, 3.5329333379509897`*^9}, {
   3.532933375064946*^9, 3.532933376278823*^9}, 3.532933694574749*^9, {
   3.532933768226659*^9, 3.532933795548148*^9}, {3.532933947723104*^9, 
   3.532933988653101*^9}, {3.532934349869569*^9, 3.5329343608207912`*^9}, {
   3.5329345523042393`*^9, 3.532934582983571*^9}, {3.5329405826377087`*^9, 
   3.5329406093441687`*^9}, {3.53294084862624*^9, 3.5329408532173653`*^9}, {
   3.532940893493758*^9, 3.5329408973613462`*^9}, {3.532942378230566*^9, 
   3.5329423784385633`*^9}, {3.5329424712433147`*^9, 3.532942517702652*^9}, {
   3.532942863780786*^9, 3.532942876440269*^9}, {3.532942924750773*^9, 
   3.532942924950292*^9}, {3.532943075788748*^9, 3.532943105485703*^9}, {
   3.5329431364628468`*^9, 3.532943156194749*^9}, 3.53294319186625*^9, 
   3.532943228169589*^9, {3.532943573166628*^9, 3.5329436671520863`*^9}, 
   3.5329444479226217`*^9, {3.533027165083399*^9, 3.533027165802915*^9}, {
   3.533111671036646*^9, 3.533111673774728*^9}, {3.533120816938157*^9, 
   3.533120864627206*^9}, {3.533122601227566*^9, 3.533122664138151*^9}, 
   3.5331227482470417`*^9, {3.5331228310774403`*^9, 3.533122944333268*^9}, {
   3.533123470857452*^9, 3.5331234718583117`*^9}, 3.533123697722143*^9, {
   3.533123852842906*^9, 3.53312389144219*^9}, 3.533124132013809*^9, 
   3.533124517168549*^9, 3.533124558920657*^9, {3.533124790508312*^9, 
   3.533124797196986*^9}, {3.5331265589177847`*^9, 3.5331265626341677`*^9}, {
   3.5331518752627983`*^9, 3.533151885821815*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "1", ",", "1.4`", ",", "1.525`", ",", "1.46`", ",", "0", ",", "0",
    ",", "1.8`*^6", ",", "1.8`*^6", ",", "532", ",", "0.1`", ",", "0.1`", ",",
    "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.49778808694867*^9, 3.497788102778743*^9}, 
   3.4977883764793253`*^9, {3.497788436658126*^9, 3.497788522385994*^9}, {
   3.497788588484562*^9, 3.49778862566147*^9}, 3.497788707633964*^9, {
   3.497790175552143*^9, 3.4977901869522753`*^9}, {3.497791150048369*^9, 
   3.497791152110139*^9}, 3.4977939648852453`*^9, {3.497794004935527*^9, 
   3.49779402038482*^9}, 3.497794109534172*^9, 3.497794148721624*^9, 
   3.4977990410073643`*^9, 3.497799364371366*^9, {3.49780194913387*^9, 
   3.497801985247517*^9}, {3.497802022986712*^9, 3.49780208134453*^9}, {
   3.4978021475225*^9, 3.4978022112746353`*^9}, 3.497802246209161*^9, 
   3.4978022908925734`*^9, 3.4978023375020123`*^9, {3.4978023841921253`*^9, 
   3.497802402439013*^9}, {3.497802545972575*^9, 3.497802635048225*^9}, {
   3.497808543238044*^9, 3.497808558880097*^9}, {3.4978086780013742`*^9, 
   3.497808689639659*^9}, 3.4978088955760813`*^9, 3.497809151336845*^9, {
   3.4978094150513163`*^9, 3.4978094266917458`*^9}, {3.497809483223208*^9, 
   3.4978094870085278`*^9}, 3.497809521089123*^9, 3.497810779949469*^9, 
   3.497812734048222*^9, 3.497850947630926*^9, 3.497851647988799*^9, 
   3.49786228509918*^9, {3.497862328324917*^9, 3.497862342106682*^9}, 
   3.4978626554371557`*^9, 3.4978670077696*^9, 3.4978685947201433`*^9, {
   3.497873321581752*^9, 3.497873331345127*^9}, {3.4978739167891283`*^9, 
   3.4978739268293753`*^9}, 3.4978742106895657`*^9, 3.497874281312565*^9, {
   3.497875317081156*^9, 3.497875319926126*^9}, 3.497875959814049*^9, 
   3.497899807115675*^9, 3.498066543883226*^9, 3.498066599661824*^9, {
   3.498066661993333*^9, 3.4980666950878*^9}, 3.49806750091835*^9, 
   3.498067623773161*^9, {3.4980676909446793`*^9, 3.498067694631583*^9}, 
   3.4980678153307447`*^9, 3.498067923566811*^9, 3.498068239127181*^9, {
   3.498068691406839*^9, 3.498068698677924*^9}, {3.4980687804759007`*^9, 
   3.498068788644911*^9}, 3.498078941650257*^9, 3.498195779802011*^9, 
   3.498207961398548*^9, 3.4984587019776*^9, 3.498902679431717*^9, 
   3.498906711539904*^9, 3.498913145579225*^9, 3.498916019237358*^9, 
   3.498989604222432*^9, 3.499062471773217*^9, 3.499160405463608*^9, 
   3.49917183370048*^9, 3.4994272649196997`*^9, 3.4994279079291553`*^9, 
   3.499591704294342*^9, 3.500206434530155*^9, {3.5017063184899683`*^9, 
   3.501706318707199*^9}, 3.50513306245088*^9, 3.507271642974251*^9, 
   3.508131271633486*^9, 3.508588898028097*^9, 3.5091704845982523`*^9, 
   3.509713285059709*^9, 3.509713761704234*^9, 3.515318377483224*^9, 
   3.5153878988948603`*^9, 3.515730202995268*^9, 3.51655755864706*^9, 
   3.5165580066230803`*^9, 3.516558482134858*^9, 3.5165958630546627`*^9, 
   3.5170394774817753`*^9, 3.517040236413026*^9, 3.517735332095834*^9, 
   3.521532037923718*^9, 3.521564336788484*^9, 3.521607830912923*^9, 
   3.523773487948409*^9, 3.5244647289779243`*^9, 3.5273028226556*^9, 
   3.5284422192757063`*^9, 3.528450748574067*^9, 3.529215427851077*^9, 
   3.529644920535008*^9, 3.5297565369896803`*^9, 3.529816597170436*^9, 
   3.5299327293205748`*^9, 3.530514128414894*^9, 3.5314725009183083`*^9, 
   3.532077000602714*^9, 3.532266170768096*^9, 3.532283912313136*^9, 
   3.532322675150783*^9, 3.532427126958035*^9, 3.532889021940721*^9, 
   3.532889235690151*^9, 3.532890141764629*^9, 3.532925711814538*^9, 
   3.532927782675466*^9, {3.532927919423258*^9, 3.5329279418393908`*^9}, 
   3.532928125942244*^9, 3.532932352656474*^9, 3.532933170399371*^9, {
   3.532933309799345*^9, 3.532933338668084*^9}, 3.53293337730739*^9, 
   3.532933697844202*^9, {3.5329337784962263`*^9, 3.5329337960604258`*^9}, 
   3.532933989025599*^9, {3.532934352067305*^9, 3.5329343611343307`*^9}, {
   3.532934552663474*^9, 3.532934583319515*^9}, 3.5329351748734303`*^9, 
   3.532939709493998*^9, 3.53294142229156*^9, {3.532942355549892*^9, 
   3.532942378900051*^9}, 3.5329425191205*^9, 3.532942616539049*^9, 
   3.532942877303363*^9, 3.532942925938252*^9, {3.532943081191265*^9, 
   3.532943106064693*^9}, {3.532943138592819*^9, 3.532943156775187*^9}, 
   3.532943192507442*^9, 3.532943229529348*^9, {3.532943591261445*^9, 
   3.532943612018865*^9}, {3.532943646244033*^9, 3.5329436674990587`*^9}, 
   3.5330199234413557`*^9, 3.533027167496533*^9, 3.533027344098218*^9, {
   3.533111679028908*^9, 3.533111686455987*^9}, 3.53311175814382*^9, 
   3.533111794872864*^9, 3.533121199784664*^9, 3.533121693279747*^9, 
   3.5331229478081083`*^9, 3.53312301100251*^9, 3.533123121057499*^9, 
   3.53312340670669*^9, {3.53312345445103*^9, 3.5331234770512257`*^9}, 
   3.533123698482017*^9, 3.533123729038705*^9, 3.5331239536675653`*^9, 
   3.5331241324664183`*^9, {3.533124559333254*^9, 3.5331245799113607`*^9}, 
   3.5331247750127087`*^9, 3.533125559876917*^9, 3.533125638664227*^9, 
   3.533126567743038*^9, 3.5331266432142057`*^9, 3.533149289303029*^9, 
   3.533149423153569*^9, 3.533149718959682*^9, 3.533150204895443*^9, 
   3.5331503224201*^9, 3.533150359149572*^9, 3.533151886193246*^9, 
   3.533197244923388*^9, 3.536678658131988*^9, 3.538457032004142*^9, 
   3.5389984968464403`*^9, 3.54057716433875*^9, 3.542353397408936*^9, 
   3.542450847761526*^9, 3.543900515293633*^9, 3.547831003982678*^9, 
   3.5478931375442266`*^9, 3.547915217475786*^9, 3.554438305258304*^9, 
   3.554657652000422*^9, 3.5551708387130136`*^9, 3.556603182523567*^9, 
   3.5570438822592773`*^9, 3.5572072481936007`*^9, 3.557393652388187*^9, 
   3.557739279544034*^9, 3.5627531049644337`*^9, 3.563290867506699*^9, {
   3.564210728536224*^9, 3.5642107500232487`*^9}, 3.56433641818926*^9, 
   3.5644207911772747`*^9, 3.566034708579587*^9, 3.5686489732067003`*^9, 
   3.572012264597687*^9, 3.572194876114561*^9, 3.5722842459770393`*^9, 
   3.572784805983583*^9, 3.573357639418788*^9, 3.574760592375152*^9, 
   3.576504315629074*^9, 3.576773073703105*^9, 3.577198509768732*^9, 
   3.5773608715158873`*^9, 3.577716013737269*^9, 3.588580089847589*^9, 
   3.590468650600512*^9, 3.590656930281331*^9, 3.590813112685357*^9, 
   3.591252452489347*^9, 3.591259159112191*^9, 3.5913714599081793`*^9, 
   3.5915083429137897`*^9, 3.591877111292407*^9, 3.59264213972554*^9, 
   3.592748577405774*^9, 3.592892072856583*^9, 3.593584610925168*^9, 
   3.5939447297811537`*^9, 3.5940035308562927`*^9, 3.595309214933586*^9, 
   3.596346833222027*^9, 3.596538314867134*^9, 3.597406871749854*^9, 
   3.598119711065611*^9, 3.5981679045767717`*^9, 3.598283132338032*^9, 
   3.598291199598708*^9, 3.598291344246974*^9, 3.598531728219623*^9, 
   3.598679786687833*^9, 3.5986988351126223`*^9, 3.598728477628564*^9, 
   3.59881004364816*^9, 3.598872427743895*^9, 3.5988861371248093`*^9, 
   3.598938184271391*^9, 3.598947660400714*^9, 3.5992032181898813`*^9, 
   3.599203483074044*^9, 3.599329698576442*^9, 3.599415830204872*^9, 
   3.600419181369101*^9, 3.600494711999051*^9, 3.601362205845376*^9, 
   3.601445117707456*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "379.563049343562`"}], "+", 
  RowBox[{"805.2315763046527`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.49778808694867*^9, 3.497788102778743*^9}, 
   3.4977883764793253`*^9, {3.497788436658126*^9, 3.497788522385994*^9}, {
   3.497788588484562*^9, 3.49778862566147*^9}, 3.497788707633964*^9, {
   3.497790175552143*^9, 3.4977901869522753`*^9}, {3.497791150048369*^9, 
   3.497791152110139*^9}, 3.4977939648852453`*^9, {3.497794004935527*^9, 
   3.49779402038482*^9}, 3.497794109534172*^9, 3.497794148721624*^9, 
   3.4977990410073643`*^9, 3.497799364371366*^9, {3.49780194913387*^9, 
   3.497801985247517*^9}, {3.497802022986712*^9, 3.49780208134453*^9}, {
   3.4978021475225*^9, 3.4978022112746353`*^9}, 3.497802246209161*^9, 
   3.4978022908925734`*^9, 3.4978023375020123`*^9, {3.4978023841921253`*^9, 
   3.497802402439013*^9}, {3.497802545972575*^9, 3.497802635048225*^9}, {
   3.497808543238044*^9, 3.497808558880097*^9}, {3.4978086780013742`*^9, 
   3.497808689639659*^9}, 3.4978088955760813`*^9, 3.497809151336845*^9, {
   3.4978094150513163`*^9, 3.4978094266917458`*^9}, {3.497809483223208*^9, 
   3.4978094870085278`*^9}, 3.497809521089123*^9, 3.497810779949469*^9, 
   3.497812734048222*^9, 3.497850947630926*^9, 3.497851647988799*^9, 
   3.49786228509918*^9, {3.497862328324917*^9, 3.497862342106682*^9}, 
   3.4978626554371557`*^9, 3.4978670077696*^9, 3.4978685947201433`*^9, {
   3.497873321581752*^9, 3.497873331345127*^9}, {3.4978739167891283`*^9, 
   3.4978739268293753`*^9}, 3.4978742106895657`*^9, 3.497874281312565*^9, {
   3.497875317081156*^9, 3.497875319926126*^9}, 3.497875959814049*^9, 
   3.497899807115675*^9, 3.498066543883226*^9, 3.498066599661824*^9, {
   3.498066661993333*^9, 3.4980666950878*^9}, 3.49806750091835*^9, 
   3.498067623773161*^9, {3.4980676909446793`*^9, 3.498067694631583*^9}, 
   3.4980678153307447`*^9, 3.498067923566811*^9, 3.498068239127181*^9, {
   3.498068691406839*^9, 3.498068698677924*^9}, {3.4980687804759007`*^9, 
   3.498068788644911*^9}, 3.498078941650257*^9, 3.498195779802011*^9, 
   3.498207961398548*^9, 3.4984587019776*^9, 3.498902679431717*^9, 
   3.498906711539904*^9, 3.498913145579225*^9, 3.498916019237358*^9, 
   3.498989604222432*^9, 3.499062471773217*^9, 3.499160405463608*^9, 
   3.49917183370048*^9, 3.4994272649196997`*^9, 3.4994279079291553`*^9, 
   3.499591704294342*^9, 3.500206434530155*^9, {3.5017063184899683`*^9, 
   3.501706318707199*^9}, 3.50513306245088*^9, 3.507271642974251*^9, 
   3.508131271633486*^9, 3.508588898028097*^9, 3.5091704845982523`*^9, 
   3.509713285059709*^9, 3.509713761704234*^9, 3.515318377483224*^9, 
   3.5153878988948603`*^9, 3.515730202995268*^9, 3.51655755864706*^9, 
   3.5165580066230803`*^9, 3.516558482134858*^9, 3.5165958630546627`*^9, 
   3.5170394774817753`*^9, 3.517040236413026*^9, 3.517735332095834*^9, 
   3.521532037923718*^9, 3.521564336788484*^9, 3.521607830912923*^9, 
   3.523773487948409*^9, 3.5244647289779243`*^9, 3.5273028226556*^9, 
   3.5284422192757063`*^9, 3.528450748574067*^9, 3.529215427851077*^9, 
   3.529644920535008*^9, 3.5297565369896803`*^9, 3.529816597170436*^9, 
   3.5299327293205748`*^9, 3.530514128414894*^9, 3.5314725009183083`*^9, 
   3.532077000602714*^9, 3.532266170768096*^9, 3.532283912313136*^9, 
   3.532322675150783*^9, 3.532427126958035*^9, 3.532889021940721*^9, 
   3.532889235690151*^9, 3.532890141764629*^9, 3.532925711814538*^9, 
   3.532927782675466*^9, {3.532927919423258*^9, 3.5329279418393908`*^9}, 
   3.532928125942244*^9, 3.532932352656474*^9, 3.532933170399371*^9, {
   3.532933309799345*^9, 3.532933338668084*^9}, 3.53293337730739*^9, 
   3.532933697844202*^9, {3.5329337784962263`*^9, 3.5329337960604258`*^9}, 
   3.532933989025599*^9, {3.532934352067305*^9, 3.5329343611343307`*^9}, {
   3.532934552663474*^9, 3.532934583319515*^9}, 3.5329351748734303`*^9, 
   3.532939709493998*^9, 3.53294142229156*^9, {3.532942355549892*^9, 
   3.532942378900051*^9}, 3.5329425191205*^9, 3.532942616539049*^9, 
   3.532942877303363*^9, 3.532942925938252*^9, {3.532943081191265*^9, 
   3.532943106064693*^9}, {3.532943138592819*^9, 3.532943156775187*^9}, 
   3.532943192507442*^9, 3.532943229529348*^9, {3.532943591261445*^9, 
   3.532943612018865*^9}, {3.532943646244033*^9, 3.5329436674990587`*^9}, 
   3.5330199234413557`*^9, 3.533027167496533*^9, 3.533027344098218*^9, {
   3.533111679028908*^9, 3.533111686455987*^9}, 3.53311175814382*^9, 
   3.533111794872864*^9, 3.533121199784664*^9, 3.533121693279747*^9, 
   3.5331229478081083`*^9, 3.53312301100251*^9, 3.533123121057499*^9, 
   3.53312340670669*^9, {3.53312345445103*^9, 3.5331234770512257`*^9}, 
   3.533123698482017*^9, 3.533123729038705*^9, 3.5331239536675653`*^9, 
   3.5331241324664183`*^9, {3.533124559333254*^9, 3.5331245799113607`*^9}, 
   3.5331247750127087`*^9, 3.533125559876917*^9, 3.533125638664227*^9, 
   3.533126567743038*^9, 3.5331266432142057`*^9, 3.533149289303029*^9, 
   3.533149423153569*^9, 3.533149718959682*^9, 3.533150204895443*^9, 
   3.5331503224201*^9, 3.533150359149572*^9, 3.533151886193246*^9, 
   3.533197244923388*^9, 3.536678658131988*^9, 3.538457032004142*^9, 
   3.5389984968464403`*^9, 3.54057716433875*^9, 3.542353397408936*^9, 
   3.542450847761526*^9, 3.543900515293633*^9, 3.547831003982678*^9, 
   3.5478931375442266`*^9, 3.547915217475786*^9, 3.554438305258304*^9, 
   3.554657652000422*^9, 3.5551708387130136`*^9, 3.556603182523567*^9, 
   3.5570438822592773`*^9, 3.5572072481936007`*^9, 3.557393652388187*^9, 
   3.557739279544034*^9, 3.5627531049644337`*^9, 3.563290867506699*^9, {
   3.564210728536224*^9, 3.5642107500232487`*^9}, 3.56433641818926*^9, 
   3.5644207911772747`*^9, 3.566034708579587*^9, 3.5686489732067003`*^9, 
   3.572012264597687*^9, 3.572194876114561*^9, 3.5722842459770393`*^9, 
   3.572784805983583*^9, 3.573357639418788*^9, 3.574760592375152*^9, 
   3.576504315629074*^9, 3.576773073703105*^9, 3.577198509768732*^9, 
   3.5773608715158873`*^9, 3.577716013737269*^9, 3.588580089847589*^9, 
   3.590468650600512*^9, 3.590656930281331*^9, 3.590813112685357*^9, 
   3.591252452489347*^9, 3.591259159112191*^9, 3.5913714599081793`*^9, 
   3.5915083429137897`*^9, 3.591877111292407*^9, 3.59264213972554*^9, 
   3.592748577405774*^9, 3.592892072856583*^9, 3.593584610925168*^9, 
   3.5939447297811537`*^9, 3.5940035308562927`*^9, 3.595309214933586*^9, 
   3.596346833222027*^9, 3.596538314867134*^9, 3.597406871749854*^9, 
   3.598119711065611*^9, 3.5981679045767717`*^9, 3.598283132338032*^9, 
   3.598291199598708*^9, 3.598291344246974*^9, 3.598531728219623*^9, 
   3.598679786687833*^9, 3.5986988351126223`*^9, 3.598728477628564*^9, 
   3.59881004364816*^9, 3.598872427743895*^9, 3.5988861371248093`*^9, 
   3.598938184271391*^9, 3.598947660400714*^9, 3.5992032181898813`*^9, 
   3.599203483074044*^9, 3.599329698576442*^9, 3.599415830204872*^9, 
   3.600419181369101*^9, 3.600494711999051*^9, 3.601362205845376*^9, 
   3.6014451178382797`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "650.8848957513678`"}], "+", 
  RowBox[{"606.4230662803631`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.49778808694867*^9, 3.497788102778743*^9}, 
   3.4977883764793253`*^9, {3.497788436658126*^9, 3.497788522385994*^9}, {
   3.497788588484562*^9, 3.49778862566147*^9}, 3.497788707633964*^9, {
   3.497790175552143*^9, 3.4977901869522753`*^9}, {3.497791150048369*^9, 
   3.497791152110139*^9}, 3.4977939648852453`*^9, {3.497794004935527*^9, 
   3.49779402038482*^9}, 3.497794109534172*^9, 3.497794148721624*^9, 
   3.4977990410073643`*^9, 3.497799364371366*^9, {3.49780194913387*^9, 
   3.497801985247517*^9}, {3.497802022986712*^9, 3.49780208134453*^9}, {
   3.4978021475225*^9, 3.4978022112746353`*^9}, 3.497802246209161*^9, 
   3.4978022908925734`*^9, 3.4978023375020123`*^9, {3.4978023841921253`*^9, 
   3.497802402439013*^9}, {3.497802545972575*^9, 3.497802635048225*^9}, {
   3.497808543238044*^9, 3.497808558880097*^9}, {3.4978086780013742`*^9, 
   3.497808689639659*^9}, 3.4978088955760813`*^9, 3.497809151336845*^9, {
   3.4978094150513163`*^9, 3.4978094266917458`*^9}, {3.497809483223208*^9, 
   3.4978094870085278`*^9}, 3.497809521089123*^9, 3.497810779949469*^9, 
   3.497812734048222*^9, 3.497850947630926*^9, 3.497851647988799*^9, 
   3.49786228509918*^9, {3.497862328324917*^9, 3.497862342106682*^9}, 
   3.4978626554371557`*^9, 3.4978670077696*^9, 3.4978685947201433`*^9, {
   3.497873321581752*^9, 3.497873331345127*^9}, {3.4978739167891283`*^9, 
   3.4978739268293753`*^9}, 3.4978742106895657`*^9, 3.497874281312565*^9, {
   3.497875317081156*^9, 3.497875319926126*^9}, 3.497875959814049*^9, 
   3.497899807115675*^9, 3.498066543883226*^9, 3.498066599661824*^9, {
   3.498066661993333*^9, 3.4980666950878*^9}, 3.49806750091835*^9, 
   3.498067623773161*^9, {3.4980676909446793`*^9, 3.498067694631583*^9}, 
   3.4980678153307447`*^9, 3.498067923566811*^9, 3.498068239127181*^9, {
   3.498068691406839*^9, 3.498068698677924*^9}, {3.4980687804759007`*^9, 
   3.498068788644911*^9}, 3.498078941650257*^9, 3.498195779802011*^9, 
   3.498207961398548*^9, 3.4984587019776*^9, 3.498902679431717*^9, 
   3.498906711539904*^9, 3.498913145579225*^9, 3.498916019237358*^9, 
   3.498989604222432*^9, 3.499062471773217*^9, 3.499160405463608*^9, 
   3.49917183370048*^9, 3.4994272649196997`*^9, 3.4994279079291553`*^9, 
   3.499591704294342*^9, 3.500206434530155*^9, {3.5017063184899683`*^9, 
   3.501706318707199*^9}, 3.50513306245088*^9, 3.507271642974251*^9, 
   3.508131271633486*^9, 3.508588898028097*^9, 3.5091704845982523`*^9, 
   3.509713285059709*^9, 3.509713761704234*^9, 3.515318377483224*^9, 
   3.5153878988948603`*^9, 3.515730202995268*^9, 3.51655755864706*^9, 
   3.5165580066230803`*^9, 3.516558482134858*^9, 3.5165958630546627`*^9, 
   3.5170394774817753`*^9, 3.517040236413026*^9, 3.517735332095834*^9, 
   3.521532037923718*^9, 3.521564336788484*^9, 3.521607830912923*^9, 
   3.523773487948409*^9, 3.5244647289779243`*^9, 3.5273028226556*^9, 
   3.5284422192757063`*^9, 3.528450748574067*^9, 3.529215427851077*^9, 
   3.529644920535008*^9, 3.5297565369896803`*^9, 3.529816597170436*^9, 
   3.5299327293205748`*^9, 3.530514128414894*^9, 3.5314725009183083`*^9, 
   3.532077000602714*^9, 3.532266170768096*^9, 3.532283912313136*^9, 
   3.532322675150783*^9, 3.532427126958035*^9, 3.532889021940721*^9, 
   3.532889235690151*^9, 3.532890141764629*^9, 3.532925711814538*^9, 
   3.532927782675466*^9, {3.532927919423258*^9, 3.5329279418393908`*^9}, 
   3.532928125942244*^9, 3.532932352656474*^9, 3.532933170399371*^9, {
   3.532933309799345*^9, 3.532933338668084*^9}, 3.53293337730739*^9, 
   3.532933697844202*^9, {3.5329337784962263`*^9, 3.5329337960604258`*^9}, 
   3.532933989025599*^9, {3.532934352067305*^9, 3.5329343611343307`*^9}, {
   3.532934552663474*^9, 3.532934583319515*^9}, 3.5329351748734303`*^9, 
   3.532939709493998*^9, 3.53294142229156*^9, {3.532942355549892*^9, 
   3.532942378900051*^9}, 3.5329425191205*^9, 3.532942616539049*^9, 
   3.532942877303363*^9, 3.532942925938252*^9, {3.532943081191265*^9, 
   3.532943106064693*^9}, {3.532943138592819*^9, 3.532943156775187*^9}, 
   3.532943192507442*^9, 3.532943229529348*^9, {3.532943591261445*^9, 
   3.532943612018865*^9}, {3.532943646244033*^9, 3.5329436674990587`*^9}, 
   3.5330199234413557`*^9, 3.533027167496533*^9, 3.533027344098218*^9, {
   3.533111679028908*^9, 3.533111686455987*^9}, 3.53311175814382*^9, 
   3.533111794872864*^9, 3.533121199784664*^9, 3.533121693279747*^9, 
   3.5331229478081083`*^9, 3.53312301100251*^9, 3.533123121057499*^9, 
   3.53312340670669*^9, {3.53312345445103*^9, 3.5331234770512257`*^9}, 
   3.533123698482017*^9, 3.533123729038705*^9, 3.5331239536675653`*^9, 
   3.5331241324664183`*^9, {3.533124559333254*^9, 3.5331245799113607`*^9}, 
   3.5331247750127087`*^9, 3.533125559876917*^9, 3.533125638664227*^9, 
   3.533126567743038*^9, 3.5331266432142057`*^9, 3.533149289303029*^9, 
   3.533149423153569*^9, 3.533149718959682*^9, 3.533150204895443*^9, 
   3.5331503224201*^9, 3.533150359149572*^9, 3.533151886193246*^9, 
   3.533197244923388*^9, 3.536678658131988*^9, 3.538457032004142*^9, 
   3.5389984968464403`*^9, 3.54057716433875*^9, 3.542353397408936*^9, 
   3.542450847761526*^9, 3.543900515293633*^9, 3.547831003982678*^9, 
   3.5478931375442266`*^9, 3.547915217475786*^9, 3.554438305258304*^9, 
   3.554657652000422*^9, 3.5551708387130136`*^9, 3.556603182523567*^9, 
   3.5570438822592773`*^9, 3.5572072481936007`*^9, 3.557393652388187*^9, 
   3.557739279544034*^9, 3.5627531049644337`*^9, 3.563290867506699*^9, {
   3.564210728536224*^9, 3.5642107500232487`*^9}, 3.56433641818926*^9, 
   3.5644207911772747`*^9, 3.566034708579587*^9, 3.5686489732067003`*^9, 
   3.572012264597687*^9, 3.572194876114561*^9, 3.5722842459770393`*^9, 
   3.572784805983583*^9, 3.573357639418788*^9, 3.574760592375152*^9, 
   3.576504315629074*^9, 3.576773073703105*^9, 3.577198509768732*^9, 
   3.5773608715158873`*^9, 3.577716013737269*^9, 3.588580089847589*^9, 
   3.590468650600512*^9, 3.590656930281331*^9, 3.590813112685357*^9, 
   3.591252452489347*^9, 3.591259159112191*^9, 3.5913714599081793`*^9, 
   3.5915083429137897`*^9, 3.591877111292407*^9, 3.59264213972554*^9, 
   3.592748577405774*^9, 3.592892072856583*^9, 3.593584610925168*^9, 
   3.5939447297811537`*^9, 3.5940035308562927`*^9, 3.595309214933586*^9, 
   3.596346833222027*^9, 3.596538314867134*^9, 3.597406871749854*^9, 
   3.598119711065611*^9, 3.5981679045767717`*^9, 3.598283132338032*^9, 
   3.598291199598708*^9, 3.598291344246974*^9, 3.598531728219623*^9, 
   3.598679786687833*^9, 3.5986988351126223`*^9, 3.598728477628564*^9, 
   3.59881004364816*^9, 3.598872427743895*^9, 3.5988861371248093`*^9, 
   3.598938184271391*^9, 3.598947660400714*^9, 3.5992032181898813`*^9, 
   3.599203483074044*^9, 3.599329698576442*^9, 3.599415830204872*^9, 
   3.600419181369101*^9, 3.600494711999051*^9, 3.601362205845376*^9, 
   3.6014451179248667`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g1", "=", 
   RowBox[{"gnmExTM", "[", 
    RowBox[{
    "n", ",", "1", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", ",", 
     "f", ",", "wa", ",", "\[Lambda]", ",", "ep", ",", "ep", ",", "0"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{"I", " ", 
    RowBox[{"gnmExTE", "[", 
     RowBox[{
     "n", ",", "1", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",", "ds", ",",
       "f", ",", "wa", ",", "\[Lambda]", ",", "0", ",", "ep", ",", "0"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g3", "=", 
   RowBox[{
    RowBox[{"gnTME", "[", 
     RowBox[{"n", ",", 
      RowBox[{"ArcSin", "[", 
       RowBox[{"NA", "/", "n1"}], "]"}], ",", "f", ",", "wa", ",", 
      RowBox[{"2", 
       RowBox[{"\[Pi]", "/", "\[Lambda]"}]}], ",", "n1", ",", "n2", ",", "d", 
      ",", "ds", ",", "0"}], "]"}], "/", "2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"g1", ",", "g2", ",", "g3", ",", 
   RowBox[{"Abs", "[", "g1", "]"}], ",", 
   RowBox[{"Abs", "[", "g2", "]"}], ",", 
   RowBox[{"Abs", "[", "g3", "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.5328890577813053`*^9, 3.5328890650025253`*^9}, {
   3.532889112809435*^9, 3.5328891564624023`*^9}, {3.5328892060853252`*^9, 
   3.53288926960439*^9}, {3.532890204721908*^9, 3.53289020680768*^9}, {
   3.5329331860277433`*^9, 3.5329332652562113`*^9}, 3.53293380764987*^9, {
   3.5329338723826237`*^9, 3.532933874204955*^9}, {3.532934596742332*^9, 
   3.532934596894144*^9}, {3.532934837745751*^9, 3.532934837982635*^9}, {
   3.532942010733572*^9, 3.532942088256966*^9}, {3.532942197837545*^9, 
   3.532942257188036*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"98.32724350608743`", "\[InvisibleSpace]", "+", 
    RowBox[{"457.36604521709893`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "309.9789007499923`"}], "-", 
    RowBox[{"328.55321843494346`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "67.13428207423246`"}], "-", 
    RowBox[{"433.8116968447775`", " ", "\[ImaginaryI]"}]}], ",", 
   "467.81614565236504`", ",", "451.7013795132059`", ",", 
   "438.9756259167105`"}], "}"}]], "Output",
 CellChangeTimes->{{3.532889051289291*^9, 3.5328890653699617`*^9}, {
   3.532889114255931*^9, 3.532889156779766*^9}, {3.532889207209607*^9, 
   3.5328892700045013`*^9}, 3.532890145034307*^9, {3.5328901752862463`*^9, 
   3.53289020717447*^9}, {3.532933228230398*^9, 3.532933265608173*^9}, {
   3.532933315296245*^9, 3.532933340709654*^9}, 3.53293369941142*^9, {
   3.53293378051647*^9, 3.532933808178845*^9}, 3.5329338745472717`*^9, 
   3.532933990861455*^9, 3.532934353967002*^9, {3.532934554259213*^9, 
   3.5329345972461853`*^9}, 3.532934838344171*^9, 3.53293517669212*^9, 
   3.532941424673376*^9, {3.5329420029518347`*^9, 3.532942088580434*^9}, {
   3.5329421981195908`*^9, 3.532942220270464*^9}, 3.532942257665741*^9, 
   3.532942382894845*^9, 3.532942523223742*^9, 3.5329428796431093`*^9, {
   3.532943594176799*^9, 3.532943614535019*^9}, 3.532943648589178*^9, 
   3.533019930142537*^9, 3.533123482252646*^9, 3.533151897492969*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cn", "=", 
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJztnC+PpEgUwEnuk9wXwJ7mE5CcRp1AnDksYk25kjgcCoXCHAqDwmA4QXaD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      "], {{0, 55}, {182, 
      0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
     Selectable->False],
    BaseStyle->"ImageGraphics",
    ImageSize->{174.5, Automatic},
    ImageSizeRaw->{182, 55},
    PlotRange->{{0, 182}, {0, 55}}]}], ",", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztXbHLvMx23pC/JP+Af0LAkF5IbXUL29gFWyEBq8ROksLKSrggBCT5sLGy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     "], {{0, 68}, {442, 0}}, {0, 
     255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{348., Automatic},
   ImageSizeRaw->{442, 68},
   PlotRange->{{0, 442}, {0, 68}}], ",", 
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztW62StLgaZuucG1mxlnvIFVC1GrUCe7CxuMg4ag1rUCgUCoPCYDAYBAaD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     "], {{0, 37}, {260, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{258., Automatic},
   ImageSizeRaw->{260, 37},
   PlotRange->{{0, 260}, {0, 37}}]}]], "Input",
 CellChangeTimes->{{3.5330262122819977`*^9, 3.533026212605165*^9}, {
  3.533026266173723*^9, 3.533026275428735*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nmax", "=", "40"}], ";", 
  RowBox[{"\[Theta]", "=", 
   RowBox[{"N", "[", 
    RowBox[{"22", "*", 
     RowBox[{"\[Pi]", "/", "180"}]}], "]"}]}], ";", 
  RowBox[{"\[Pi]n\[Tau]nT", "=", 
   RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
    RowBox[{"\[Theta]", ",", "Nmax"}], "]"}]}], ";", 
  RowBox[{"\[Pi]n", "=", 
   RowBox[{
   "\[Pi]n\[Tau]nT", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
   ";", 
  RowBox[{"\[Tau]n", "=", 
   RowBox[{
   "\[Pi]n\[Tau]nT", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", 
           RowBox[{
            RowBox[{"Sin", "[", "\[Theta]", "]"}], 
            RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
             RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", 
           RowBox[{"PnmCos", "[", 
            RowBox[{"n", ",", "1", ",", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}]}]}], "]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S2", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"n", ",", 
            RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
             RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}]}], "]"}], ",", 
      RowBox[{"ListPlot", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", 
           RowBox[{"N", "[", 
            RowBox[{"PnmpCos", "[", 
             RowBox[{
              RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "n", ",", "1"}], 
             "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}], "]"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S3", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", 
           RowBox[{
            RowBox[{"Sin", "[", "\[Theta]", "]"}], 
            RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
             RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", 
           RowBox[{"-", 
            RowBox[{"LegendreP", "[", 
             RowBox[{"n", ",", "1", ",", 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}]}]}], "}"}], ",", 
         
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}]}]}], "]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"S1", ",", "S2", ",", "S3"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5331197790888*^9, 3.533119781975996*^9}, {
   3.533119816607519*^9, 3.533119866246168*^9}, {3.53311991512527*^9, 
   3.53312005887339*^9}, {3.53312032633191*^9, 3.533120402337291*^9}, {
   3.533120443695978*^9, 3.533120502933949*^9}, {3.533120540847374*^9, 
   3.533120679645171*^9}, 3.53312078922305*^9, {3.533120941201181*^9, 
   3.533120951908692*^9}, {3.533120998095839*^9, 3.5331210879813347`*^9}, {
   3.5331211316548233`*^9, 3.533121146435467*^9}, {3.533121191071333*^9, 
   3.5331212059855957`*^9}, {3.53312124781697*^9, 3.533121366796829*^9}, {
   3.5331218803947287`*^9, 3.5331218805528727`*^9}, {3.533122223440564*^9, 
   3.5331222269452868`*^9}, {3.533122256992311*^9, 3.533122260639842*^9}, {
   3.5331223346157007`*^9, 3.533122395539394*^9}, {3.533122444236149*^9, 
   3.5331225895260687`*^9}, {3.5331229630551434`*^9, 3.533122990779024*^9}, {
   3.5331230569212427`*^9, 3.5331231255996323`*^9}, {3.5331231576812363`*^9, 
   3.533123162447092*^9}, {3.533123207135893*^9, 3.533123279271769*^9}, {
   3.5331233852253447`*^9, 3.533123438733021*^9}, {3.533123733125306*^9, 
   3.533123812153266*^9}, {3.533124568034883*^9, 3.533124569146233*^9}, {
   3.533124806916849*^9, 3.533124832060442*^9}, {3.5331256331774597`*^9, 
   3.533125646216082*^9}, {3.533149431075761*^9, 3.533149557792491*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], PointSize[0.02], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7BunPX3X+/O6PVTAwSdshcrv1R+gfA6HHbyl
h3KW/4XyBRzed6xmzP/G4gDhiziErdvgPc+IE8qXcPjH5b/E3Y4LypdxCJX6
vmleEDuUr+BgoHfUpD2CAcpXcuDtvei6995zqPkqDqF/7uReePNyP4Sv5sDd
OPWQgD7zAQhfw2F1h+nvK3J8UL6Wg0TxggVim4WgfB2H0g3VK0tPCUP5eg6n
jwdqzvgpCOUbOMwRyDvTsooLyjd0mJtTflZ9xk+ofUYOLTP3Fp0ougd1j7GD
8gOTb4KHYf41cTi0eybz6wOCUL6pQ+km9yKbG2JQvplDr8jX1qVHJaB8c4f9
HG7+nyTEoXwLBx6TmvqjL2H6LR1M8uWrJDYzQ/lWDiIudwrKp2hA7bd26O3b
ty+0hAXqXhsH09I/AuqBMP/ZOlzMyz1vek8SyrdzkOFNvc9/QQbKt3ew5vtu
8WmaNJTv4FDtVf2u204Mwm9wcFgus/Og9SNYeDg6zLii9SRG9DEkPBocHYJv
fP7VvokJ6j4nB6YKN71mThEIv8HJQbpup32cgAxU3tkhq0TXXkdUASrv7DAt
RlPx7wJ5qLyLA+vV2arnM6UcAE3QqIc=
         "]]}, 
       {GrayLevel[0], PointSize[0.01], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7OumPX3X+/O6PVTAwTtshcrv1R+gfA6Hrbyl
h3KW/4XyBRzedaxmzP/G4gDhiziErNvgPc+IE8qXcPjN5b/E3Y4LypdxCJL6
vmleEDuUr+Cgo3fUpD2CAcpXcvjZc9F1773nUPNVHFL+3Mm98OblfghfzYG7
ceohAX3mAxC+hsOyDtPfV+T4oHwtB5HiBQvENgtB+ToO+RuqV5aeEoby9RyO
Hg/UnPFTEMo3cOgXyDvTsooLyjd0aM0pP6s+4yfUPiOHbTP3Fp0ougd1j7GD
8gOTb4KHYf41cdi/eybz6wOCUL6pQ94m9yKbG2JQvplDm8jX1qVHJaB8c4ed
HG7+nyTEoXwLBzaTmvqjL2H6LR208+WrJDYzQ/lWDnv57xSUT9GA2m/t0N63
b19oCQvUvTYO+qV/BNQDYf6zdTidl3ve9J4klG/nIM2bep//ggyUb+9gy/fd
4tM0aSjfwaHBq/pdt50YhN/g4LBLZudB60ew8HB0eHdF60mM6GNIeDQ4Otjf
+PyrfRMT1H1ODr/K3fSaOUUg/AYnB4m6nfZxAjJQeWeHjBJdex1RBai8s8OM
GE3FvwvkofIuDrxXZ6uez5RyAACXDar4
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      PlotRange->Automatic,
      PlotRangeClipping->True], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], PointSize[0.02], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7CNOT6+sXf3WHirg8Orn7zXznRkdIFwOhw+t
896tE2WF8gUcGsQSwy+6foaqF3FQOGcm8+I1+wEIX8LBwm7PBCYPFShfxuHL
j8VJy7qNoXwFhw8u36bMnGoL5Ss5bJ34ZePib05QvopDTuAh3rhfLlC+msOl
CVFXHq1yhvI1HGwiDC5cnW0D5Ws5FDxJr16SrQzl6zgc0F5kf6lOH+pePYcH
D/TOVNi5QfkGDr/kJn3J/R0I5Rs63NWIW3PTLBzKN3Lo2aZ8WXxqJJRv7BC4
8Y55oGYElG/icC1puZ9hXxCUb+pgwcTBYijhBOWbOSzwLRO8d0cL6h5zh4rr
ShqhzIFQvoWDwb/VlQ+uxkL5lg6vl7FdLz6XDOVbOTSWRv7i1U+D8q0dihrd
3WRiUqF8G4c37rPOXRNPhPJtHUJWObgqxQRD+XYODB+m9Qh/ugyNH3sHhhXW
LWJtoVD3OTiscr05j+FpCoTf4OAQEGW01PVEDlTe0UFLc+P9mTUFUHlHhxA7
R/90GyifwclBTb1mEsOHLKi8k8OL7V38N08nQOWdHQ4UBUdKP7aEyjs77FCT
6/p6PRzqPheHCX8f/l1XmnUAAIiXsfg=
         "]]}, 
       {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7GNPT6+sXf3WHirg8Pzn7zXznRkdIFwOhy+t
896tE2WF8gUcesQSwy+6foaqF3EwOGcm8+I1+wEIX8LBym7PBCYPFShfxuHH
j8VJy7qNoXwFh28u36bMnGoL5Ss5bJn4ZePib05QvopDRuAh3rhfLlC+msOp
CVFXHq1yhvI1HLQiDC5cnW0D5Ws5uD5Jr16SrQzl6zhs0l5kf6lOH+pePYcX
D/TOVNi5QfkGDj/lJn3J/R0I5Rs63NSIW3PTLBzKN3Jo3qZ8WXxqJJRv7OC5
8Y55oGYElG/icCJpuZ9hXxCUb+pgwsTBYijhBOWbOTT7lgneu6MFdY+5Q9l1
JY1Q5kAo38LB6N/qygdXY6F8S4eny9iuF59LhvKtHGpKI3/x6qdB+dYOuY3u
bjIxqVC+jcNr91nnroknQvm2DimrHFyVYoKhfDuHuZem9Qh/ugyNH3uH98ut
W8TaQqHuc3BY5HpzHsPTFAi/wcHBL8poqeuJHKi8o4OO5sb7M2sKoPKODmF2
jv7pNlA+g5ODkXrNJIYPWVB5J4e327v4b55OgMo7O3AUB0dKP7aEyjs7LFCT
6/p6PRzqPheHur8P/64rzToAAMkdsic=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      PlotRange->Automatic,
      PlotRangeClipping->True], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], PointSize[0.02], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7BunPX3X+/O6PVTAwSdshcrv1R+gfA6HHbyl
h3KW/4XyBRzed6xmzP/G4gDhiziErdvgPc+IE8qXcPjH5b/E3Y4LypdxCJX6
vmleEDuUr+BgoHfUpD2CAcpXcuDtvei6995zqPkqDqF/7uReePNyP4Sv5sDd
OPWQgD7zAQhfw2F1h+nvK3J8UL6Wg0TxggVim4WgfB2H0g3VK0tPCUP5eg6n
jwdqzvgpCOUbOMwRyDvTsooLyjd0mJtTflZ9xk+ofUYOLTP3Fp0ougd1j7GD
8gOTb4KHYf41cTi0eybz6wOCUL6pQ+km9yKbG2JQvplDr8jX1qVHJaB8c4f9
HG7+nyTEoXwLBx6TmvqjL2H6LR1M8uWrJDYzQ/lWDiIudwrKp2hA7bd26O3b
ty+0hAXqXhsH09I/AuqBMP/ZOlzMyz1vek8SyrdzkOFNvc9/QQbKt3ew5vtu
8WmaNJTv4FDtVf2u204Mwm9wcFgus/Og9SNYeDg6zLii9SRG9DEkPBocHYJv
fP7VvokJ6j4nB6YKN71mThEIv8HJQbpup32cgAxU3tkhq0TXXkdUASrv7DAt
RlPx7wJ5qLyLA+vV2arnM6UcAE3QqIc=
         "]]}, 
       {GrayLevel[0], PointSize[0.01], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7OumPX3X+/O6PVTAwTtshcrv1R+gfA6Hrbyl
h3KW/4XyBRzed6xmzP/G4gDhiziErNvgPc+IE8qXcPjN5b/E3Y4LypdxCJL6
vmleEDuUr+Cgo3fUpD2CAcpXcvjZc9F1773nUPNVHFL+3Mm98OblfghfzYG7
ceohAX3mAxC+hsOyDtPfV+T4oHwtB+HiBQvENgtB+ToO+RuqV5aeEoby9RyO
Hg/UnPFTEMo3cOgXyDvTsooLyjd0aM0pP6s+4yfUPiOHHTP3Fp0ougd1j7GD
8gOTb4KHYf41cdi/eybz6wOCUL6pQ94m9yKbG2JQvplDm8jX1qVHJaB8c4ed
HG7+nyTEoXwLBzaTmvqjL2H6LR108uWrJDYzQ/lWDvv47xSUT9GA2m/t0N63
b19oCQvUvTYO+qV/BNQDYf6zdTidl3ve9J4klG/nIM2bep//ggyUb+9gy/fd
4tM0aSjfwaHBq/pdt50YhN/g4LBLZudB60ew8HB0eHdF60mM6GNIeDQ4Otjf
+PyrfRMT1H1ODr/L3fSaOUUg/AYnB/G6nfZxAjJQeWeHjBJdex1RBai8s8OM
GE3FvwvkofIuDnxXZ6uez5RyAACcZar9
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      PlotRange->Automatic,
      PlotRangeClipping->True], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->800,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.533123267450507*^9, 3.5331232799208927`*^9}, {
   3.533123387701515*^9, 3.533123439456616*^9}, {3.533123735038846*^9, 
   3.533123812569112*^9}, 3.533124135462051*^9, {3.5331245625402184`*^9, 
   3.5331245695173187`*^9}, {3.533124807799828*^9, 3.533124832699753*^9}, 
   3.533125562900646*^9, {3.533125636004726*^9, 3.533125646780534*^9}, 
   3.5331493729193707`*^9, {3.533149427062237*^9, 3.533149569431739*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "> GLMT Computation, F[N] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     RowBox[{"n", 
      StyleBox["med",
       FontSize->10]}]], "*", 
    RowBox[{"(", 
     FractionBox[
      SubscriptBox["C", "pr"], "c"]}]}], TraditionalForm]], "None"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["I", "0"], ",", 
     RowBox[{
      FractionBox[
       SubscriptBox["C", "pr"], "c"], 
      SubscriptBox["I", "0"]}]}], ")"}], TraditionalForm]], "None"],
 ",",
 Cell[BoxData[
  RowBox[{
   FormBox[
    RowBox[{" ", 
     SubscriptBox["I", "0"]}],
    TraditionalForm], "=", 
   FormBox[
    FractionBox[
     RowBox[{"2", 
      SubscriptBox["P", "0"]}], 
     RowBox[{"\[Pi]", " ", 
      SubsuperscriptBox["w", 
       RowBox[{"0", ",", "a"}], "2"]}]],
    TraditionalForm]}]]],
 "\n",
 StyleBox["\"Light scattering from a sphere arbitrarily located in a Gaussian \
beam, using a Bromwich formulation\", G. Gouesbet, B. Maheu and G. Grehan, J. \
Opt. Soc. Am. A, Vol. 5, No. 1988\n\"Radiation pressure forces exertced on a \
particle arbitrarily located in a Gaussian beam by using the generalized \
Lorenz-Mie theory, and associated resonance effects\", K.F. Ren, G. Grehan, \
G. Gouesbet, Opt. Comm., 108 (1994), 343-354\n",
  FontSize->12],
 StyleBox["Sign convention used in this script: z0 < 0: Particle in \
converging part of the beam i.e. particle in front of focus",
  FontSize->12,
  FontSlant->"Italic"],
 "\n",
 StyleBox["Syntax : CprG(x0[nm] (G : x0/w0), y0[nm] (G : y0/w0), z0[nm] (G : \
z0/l, l=2zR), s = w0/l (used for G only), DoXY (0, 1), Exact (0, 1) , R)  \n  \
   \[Rule] {Cext [m", "Subitem",
  FontSize->14],
 StyleBox["2", "Subitem",
  FontSize->10],
 StyleBox["], Cscat [m", "Subitem",
  FontSize->14],
 StyleBox["2", "Subitem",
  FontSize->10],
 StyleBox["], Cabs [m", "Subitem",
  FontSize->14],
 StyleBox["2", "Subitem",
  FontSize->10],
 StyleBox["], (Cprx, Cpry) [m", "Subitem",
  FontSize->14],
 StyleBox["2", "Subitem",
  FontSize->10],
 StyleBox["], (Cprz [m", "Subitem",
  FontSize->14],
 StyleBox["2", "Subitem",
  FontSize->10],
 StyleBox["]), Time Used for BSC [s], Time used for Pressure Calc. [s], Time \
used for Total Cross Sections [s]}\n     \[Rule] {Cext , Cscat , Cabs , Cpx, \
Cpy, Cpz , tBSC , tCP, tC}", "Subitem",
  FontSize->14]
}], "Title",
 CellChangeTimes->{{3.490897806751107*^9, 3.4908978087245083`*^9}, {
   3.4978092273845654`*^9, 3.497809255598518*^9}, {3.497809287685129*^9, 
   3.4978092893009663`*^9}, {3.497810102443874*^9, 3.497810107548335*^9}, {
   3.4978109575879383`*^9, 3.497810986041284*^9}, {3.4978131922246513`*^9, 
   3.4978133385774403`*^9}, {3.497813392984672*^9, 3.497813523227749*^9}, {
   3.4978750684400253`*^9, 3.49787513220332*^9}, {3.497875203331921*^9, 
   3.497875256222887*^9}, {3.498283195602008*^9, 3.498283400784562*^9}, {
   3.499164322333974*^9, 3.499164357588399*^9}, {3.509713653765428*^9, 
   3.5097136556102753`*^9}, {3.516596731724881*^9, 3.516596734610611*^9}, {
   3.516597219261888*^9, 3.516597220469289*^9}, 3.523783447659545*^9, {
   3.5284509400301723`*^9, 3.52845094488023*^9}, {3.5296451514441967`*^9, 
   3.5296451548044643`*^9}, {3.5296583526231403`*^9, 3.529658398070079*^9}, {
   3.5296598901306877`*^9, 3.529659890616521*^9}, {3.547916609044916*^9, 
   3.547916625220161*^9}, {3.554279385279811*^9, 3.554279386413661*^9}},
 Background->RGBColor[1, 0.85, 0.85]],

Cell["\<\
Exact = 0 : use Gaussian BSC, Exact = 1 : use exact BSC, DoXY = 0 : only \
Pradz, DoXY = 1 : only Pradxy\
\>", "Text",
 CellChangeTimes->{{3.497813550740513*^9, 3.497813609673008*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CprG", "[", 
    RowBox[{
    "x00_", ",", "y00_", ",", "z00_", ",", "ss_", ",", "\[Lambda]\[Lambda]_", 
     ",", "DoXYY_", ",", "Exactt_", ",", "RR_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"z0", "=", "z00"}], ",", 
       RowBox[{"x0", "=", "x00"}], ",", 
       RowBox[{"y0", "=", "y00"}], ",", 
       RowBox[{"s", "=", "ss"}], ",", 
       RowBox[{"\[Lambda]", "=", "\[Lambda]\[Lambda]"}], ",", 
       RowBox[{"DoXY", "=", "DoXYY"}], ",", 
       RowBox[{"Exact", "=", "Exactt"}], ",", 
       RowBox[{"R", "=", "RR"}], ",", "gnmTMT", ",", "gnmTET", ",", "Unmp", 
       ",", "Vnmp", ",", "Snmp", ",", "Tnmp", ",", "Corr", ",", "Cxy", ",", 
       "CprGx", ",", "CprGy", ",", "CprGz", ",", "CprGzMLA", ",", "CscaG", 
       ",", "CextG", ",", "CabsG", ",", "unit", ",", "start", ",", "Timegnm", 
       ",", "TimePressure", ",", "TimeTotalCS", ",", "k", ",", "gnMLAT"}], 
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", "Initialize", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"CextG", "=", "0"}], ",", 
        RowBox[{"CscaG", "=", "0"}], ",", 
        RowBox[{"CabsG", "=", "0"}], ",", 
        RowBox[{"CprGx", "=", "0"}], ",", 
        RowBox[{"CprGy", "=", "0"}], ",", 
        RowBox[{"CprGz", "=", "0"}], ",", 
        RowBox[{"CprGzMLA", "=", "0"}]}], "}"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Exact", "\[Equal]", "1"}], ",", 
        RowBox[{"unit", "=", "nm"}], ",", 
        RowBox[{"unit", "=", "nm"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"k", "=", 
       RowBox[{"nmed", " ", "2", 
        RowBox[{"\[Pi]", "/", 
         RowBox[{"(", 
          RowBox[{"\[Lambda]", " ", "unit"}], ")"}]}]}]}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{"wave", " ", "vector"}], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Generate", " ", "Table", " ", "of", " ", "Mie", " ", 
        RowBox[{"Coeff", ".", " ", "an"}], " ", "and", " ", "bn"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"start", "=", 
       RowBox[{"SessionTime", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"anL", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"aMie", "[", 
          RowBox[{"n", ",", 
           RowBox[{"k", " ", 
            RowBox[{"(", 
             RowBox[{"R", " ", "unit"}], ")"}]}], ",", 
           RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"bnL", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"bMie", "[", 
          RowBox[{"n", ",", 
           RowBox[{"k", " ", 
            RowBox[{"(", 
             RowBox[{"R", " ", "unit"}], ")"}]}], ",", 
           RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Timeanbn", "=", " ", 
       RowBox[{
        RowBox[{"SessionTime", "[", "]"}], "-", "start"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
       "Get", " ", "Gaussian", " ", "or", " ", "Exact", " ", "BSCs", " ", 
        RowBox[{"(", 
         RowBox[{"beam", " ", "shape", " ", "coefficients"}], ")"}]}], "*)"}],
       "\[IndentingNewLine]", 
      RowBox[{"start", "=", 
       RowBox[{"SessionTime", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Exact", "\[Equal]", "0"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"gnmTMT", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"gnmTMAddT", "[", 
                RowBox[{"n", ",", "m", ",", "s", ",", 
                 RowBox[{"2", 
                  RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", 
                 "y0"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "1", ",", 
               RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{"gnmTET", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"gnmTEAddT", "[", 
                RowBox[{"n", ",", "m", ",", "s", ",", 
                 RowBox[{"2", 
                  RowBox[{"z0", "/", "s"}]}], ",", "z0", ",", "x0", ",", 
                 "y0"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "1", ",", 
               RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"gnmTMT", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"gnmExTM", "[", 
                RowBox[{
                "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",",
                  "ds", ",", "f", ",", "wa", ",", "\[Lambda]", ",", "x0", ",",
                  "y0", ",", "z0"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "1", ",", 
               RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{"gnmTET", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"gnmExTE", "[", 
                RowBox[{
                "n", ",", "m", ",", "NA", ",", "n1", ",", "n2", ",", "d", ",",
                  "ds", ",", "f", ",", "wa", ",", "\[Lambda]", ",", "x0", ",",
                  "y0", ",", "z0"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"n", ",", "1", ",", 
               RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}]}], "}"}]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"gnMLAT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"gnMLA", "[", 
          RowBox[{"n", ",", "s", ",", 
           RowBox[{"2", " ", 
            RowBox[{"z0", "/", "s"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"nmax", "+", "2"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Timegnm", "=", " ", 
       RowBox[{
        RowBox[{"SessionTime", "[", "]"}], "-", "start"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Get", " ", "auxillary", " ", "Matrix"}], "-", 
          RowBox[{
          "elements", " ", "for", " ", "Pressure", " ", "Computations", " ", 
           "n"}]}], "\[GreaterEqual]", 
         RowBox[{"Abs", "[", "p", "]"}]}], "&&", 
        RowBox[{"m", "\[GreaterEqual]", 
         RowBox[{"Abs", "[", 
          RowBox[{"p", "+", "1"}], "]"}]}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"start", "=", 
       RowBox[{"SessionTime", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"DoXY", "\[Equal]", "1"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Unmp", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"n", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", "p", "]"}]}], "&&", 
                    RowBox[{"m", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"p", "+", "1"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}]}]}], ",", 
                   RowBox[{"10", "^", "2000"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", 
               RowBox[{"-", "nmax"}], ",", "nmax"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"Vnmp", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"n", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", "p", "]"}]}], "&&", 
                    RowBox[{"m", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"p", "+", "1"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}]}], ",", 
                   RowBox[{"10", "^", "2000"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", 
               RowBox[{"-", "nmax"}], ",", "nmax"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"Snmp", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"n", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", "p", "]"}]}], "&&", 
                    RowBox[{"m", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"p", "+", "1"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], "+", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], "+", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}]}]}], ",", 
                   RowBox[{"10", "^", "2000"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", 
               RowBox[{"-", "nmax"}], ",", "nmax"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"Tnmp", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"n", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", "p", "]"}]}], "&&", 
                    RowBox[{"m", "\[GreaterEqual]", 
                    RowBox[{"Abs", "[", 
                    RowBox[{"p", "+", "1"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], "+", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "m", 
                    "\[RightDoubleBracket]"}], "]"}], "+", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"m", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"m", "+", "1"}], ")"}], "+", "p", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}]}], ",", 
                   RowBox[{"10", "^", "2000"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "1", ",", "nmax"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", 
               RowBox[{"-", "nmax"}], ",", "nmax"}], "}"}]}], "]"}]}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"Get", " ", "Radiation", " ", "Pressure", " ", "Cross"}], 
         "-", "sections"}], ",", " ", 
        RowBox[{"F", "=", 
         RowBox[{"Cpr", "/", "c"}]}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Corr", "=", 
       RowBox[{"nmax", "+", "1"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"DoXY", "\[Equal]", "0"}], ",", 
        RowBox[{"CprGz", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"n", "=", "1"}], "nmax"], 
            RowBox[{"(", 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"p", "=", 
                RowBox[{"-", "n"}]}], "n"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "2"], " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", 
                    RowBox[{"Abs", "[", "p", "]"}]}], ")"}], "!"}]}]], 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", 
                    RowBox[{"Abs", "[", "p", "]"}], "+", "1"}], ")"}], "!"}], 
                  " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"bnL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "+", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"bnL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}],
                     "+", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"n", "+", "1"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"anL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], "+", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"anL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}],
                     "+", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"n", "+", "1"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], "]"}], " ", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}]}]}], "]"}]}]}], "+", 
                RowBox[{
                 FractionBox["1", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["n", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "2"]}], ")"}], " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", 
                    RowBox[{"Abs", "[", "p", "]"}]}], ")"}], "!"}]}]], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "n"}], "+", "1"}], ")"}], " ", "p", " ", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", 
                    RowBox[{"Abs", "[", "p", "]"}]}], ")"}], "!"}], " ", 
                  RowBox[{"Re", "[", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}]}], "-", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}], "-", 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], ")"}], " ", 
                    RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                    RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "p"}]}], 
                    "\[RightDoubleBracket]"}], "]"}]}], "]"}]}]}]}], ")"}]}], 
             ")"}]}], ")"}], 
          FractionBox[
           RowBox[{"4", "\[Pi]"}], 
           SuperscriptBox["k", "2"]]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"DoXY", "\[Equal]", "0"}], "&&", 
         RowBox[{"Exact", "\[Equal]", "0"}]}], ",", 
        RowBox[{"CprGzMLA", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"n", "=", "1"}], "nmax"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox[
                RowBox[{
                 RowBox[{"2", "n"}], "+", "1"}], 
                RowBox[{"n", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "1"}], ")"}]}]], 
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                 RowBox[{
                 "gnMLAT", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "]"}], "2"], 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "anL", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "+", 
                 RowBox[{
                 "bnL", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], "-", 
                 RowBox[{"2", 
                  RowBox[{
                  "anL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], 
                  RowBox[{"Conjugate", "[", 
                   RowBox[{
                   "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "]"}]}]}], "]"}]}], "+", 
              RowBox[{
               FractionBox[
                RowBox[{"n", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "2"}], ")"}]}], 
                RowBox[{"n", "+", "1"}]], 
               RowBox[{"Re", "[", 
                RowBox[{
                 RowBox[{
                 "gnMLAT", "\[LeftDoubleBracket]", "n", 
                  "\[RightDoubleBracket]"}], 
                 RowBox[{"Conjugate", "[", 
                  RowBox[{"gnMLAT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], 
                 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                   "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "+", 
                   RowBox[{
                   "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}], "+", 
                   RowBox[{"Conjugate", "[", 
                    RowBox[{"anL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}],
                    "+", 
                   RowBox[{"Conjugate", "[", 
                    RowBox[{"bnL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}],
                    "-", 
                   RowBox[{"2", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"anL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], 
                    RowBox[{
                    "anL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}], "-", 
                   RowBox[{"2", 
                    RowBox[{"Conjugate", "[", 
                    RowBox[{"bnL", "\[LeftDoubleBracket]", 
                    RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], 
                    RowBox[{
                    "bnL", "\[LeftDoubleBracket]", "n", 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}], "]"}]}]}], 
             ")"}]}], ")"}], 
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           SuperscriptBox["k", "2"]]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"DoXY", "\[Equal]", "1"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cxy", "=", 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"p", "=", "1"}], "nmax"], 
            RowBox[{"(", 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"n", "=", "p"}], "nmax"], 
              RowBox[{"(", 
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"m", "=", 
                  RowBox[{"Max", "[", 
                   RowBox[{
                    RowBox[{"p", "-", "1"}], ",", "1"}], "]"}]}], "nmax"], 
                RowBox[{
                 FractionBox[
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "+", "p"}], ")"}], "!"}], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", "p"}], ")"}], "!"}]], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"KroneckerDelta", "[", 
                    RowBox[{"m", ",", 
                    RowBox[{"n", "+", "1"}]}], "]"}], 
                    SuperscriptBox["m", "2"]], "-", 
                    FractionBox[
                    RowBox[{"KroneckerDelta", "[", 
                    RowBox[{"n", ",", 
                    RowBox[{"m", "+", "1"}]}], "]"}], 
                    SuperscriptBox["n", "2"]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Snmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "+", "p", "-", "1"}], ",", "n", ",", 
                    "m"}], "\[RightDoubleBracket]"}], "+", 
                    RowBox[{"Snmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "-", "p"}], ",", "m", ",", "n"}], 
                    "\[RightDoubleBracket]"}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Unmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "+", "p", "-", "1"}], ",", "n", ",", 
                    "m"}], "\[RightDoubleBracket]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Unmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "-", "p"}], ",", "m", ",", "n"}], 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    FractionBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "n"}], "+", "1"}], ")"}], 
                    RowBox[{
                    SuperscriptBox["n", "2"], 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "2"]}]], " ", 
                    RowBox[{"KroneckerDelta", "[", 
                    RowBox[{"m", ",", "n"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Tnmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "+", "p", "-", "1"}], ",", "n", ",", 
                    "m"}], "\[RightDoubleBracket]"}], "-", 
                    RowBox[{"Tnmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "-", "p"}], ",", "m", ",", "n"}], 
                    "\[RightDoubleBracket]"}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Vnmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "+", "p", "-", "1"}], ",", "n", ",", 
                    "m"}], "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Vnmp", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"Corr", "-", "p"}], ",", "m", ",", "n"}], 
                    "\[RightDoubleBracket]"}]}]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}], ")"}]}]}], ",", 
          RowBox[{"CprGx", "=", 
           RowBox[{
            FractionBox[
             RowBox[{"2", "\[Pi]"}], 
             SuperscriptBox["k", "2"]], 
            RowBox[{"Re", "[", "Cxy", "]"}]}]}], ",", 
          RowBox[{"CprGy", "=", 
           RowBox[{
            FractionBox[
             RowBox[{"2", "\[Pi]"}], 
             SuperscriptBox["k", "2"]], 
            RowBox[{"Im", "[", "Cxy", "]"}]}]}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"TimePressure", "=", " ", 
       RowBox[{
        RowBox[{"SessionTime", "[", "]"}], "-", "start"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"Get", " ", "Total", " ", "Cross"}], "-", 
         RowBox[{"Sections", ":", " ", "Scattering"}]}], ",", " ", 
        "Extinction", ",", " ", "Absorption"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"start", "=", 
       RowBox[{"SessionTime", "[", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"CscaG", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]", " "}], 
         SuperscriptBox["k", "2"]], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "nmax"], 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2", " ", "n"}], "+", "1"}], 
           RowBox[{"n", " ", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}]}]], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"m", "=", 
             RowBox[{"-", "n"}]}], "n"], 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "anL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "bnL", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}]}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", 
               RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]]}]}]}]}]}], ";", 
      RowBox[{"CextG", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"4", " ", "\[Pi]", " "}], 
         SuperscriptBox["k", "2"]], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "1"}], "nmax"], 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2", " ", "n"}], "+", "1"}], 
           RowBox[{"n", " ", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}]}]], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"m", "=", 
             RowBox[{"-", "n"}]}], "n"], 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", 
                RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], " ", 
             RowBox[{"Re", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "anL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTMT", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{
                "bnL", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
                 " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{"gnmTET", "\[LeftDoubleBracket]", 
                   RowBox[{"n", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "+", "1"}], ")"}], "+", "m"}]}], 
                   "\[RightDoubleBracket]"}], "]"}], "2"]}]}], "]"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", 
               RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]]}]}]}]}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"CabsG", "=", 
       RowBox[{"CextG", "-", "CscaG"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"TimeTotalCS", "=", " ", 
       RowBox[{
        RowBox[{"SessionTime", "[", "]"}], "-", "start"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "OUTPUT", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "CextG", ",", "CscaG", ",", "CabsG", ",", "CprGx", ",", "CprGy", ",", 
        "CprGz", ",", "Timegnm", ",", "TimePressure", ",", "TimeTotalCS", ",",
         "CprGzMLA", ",", 
        RowBox[{"anL", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CextG", " ", 
        SuperscriptBox["unit", "2"]}], ",", 
       RowBox[{"CscaG", " ", 
        SuperscriptBox["unit", "2"]}], ",", 
       RowBox[{"CabsG", " ", 
        SuperscriptBox["unit", "2"]}], ",", 
       RowBox[{"CprGx", " ", 
        SuperscriptBox["unit", "2"]}], ",", 
       RowBox[{"CprGy", " ", 
        SuperscriptBox["unit", "2"]}], ",", 
       RowBox[{"CprGz", " ", 
        SuperscriptBox["unit", "2"]}], ",", "Timegnm", ",", "TimePressure", 
       ",", "TimeTotalCS", ",", "Timeanbn", ",", 
       RowBox[{"CprGz", " ", 
        SuperscriptBox["unit", "2"], " ", 
        RowBox[{"(", "MLA", ")"}]}]}], "}"}], "*)"}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.497636864020955*^9, 3.49763708580302*^9}, {
   3.497637313674765*^9, 3.497637339856886*^9}, {3.4976373854645042`*^9, 
   3.497637397728224*^9}, {3.497637438977302*^9, 3.49763764038315*^9}, {
   3.497637691249846*^9, 3.4976377016386433`*^9}, {3.497637760618062*^9, 
   3.497637771260365*^9}, {3.497637903259194*^9, 3.497638063783407*^9}, {
   3.497638099913846*^9, 3.497638222205961*^9}, {3.4976384679338284`*^9, 
   3.497638646353064*^9}, {3.49763871249437*^9, 3.497638721621258*^9}, {
   3.497638801888339*^9, 3.497638859143428*^9}, {3.4976389467824707`*^9, 
   3.4976389541484213`*^9}, {3.4976390746582117`*^9, 3.497639140975803*^9}, {
   3.497639217462435*^9, 3.4976393283942347`*^9}, {3.497639580887373*^9, 
   3.4976395852701597`*^9}, {3.497639615522628*^9, 3.497639625223928*^9}, {
   3.497639718792324*^9, 3.4976397317822027`*^9}, {3.497639811712143*^9, 
   3.497639837695966*^9}, {3.4976399193667192`*^9, 3.497639957613299*^9}, {
   3.4976399931086283`*^9, 3.497640009196087*^9}, {3.497640129548827*^9, 
   3.497640269021894*^9}, {3.497640383930915*^9, 3.4976404356200027`*^9}, {
   3.497640740279477*^9, 3.497640762445775*^9}, {3.497640942141704*^9, 
   3.4976410171205053`*^9}, {3.497641052539583*^9, 3.4976410564774923`*^9}, {
   3.497641130142934*^9, 3.497641133009159*^9}, {3.497641173968375*^9, 
   3.497641175283424*^9}, {3.4976413244417143`*^9, 3.497641349404705*^9}, {
   3.497641431411538*^9, 3.4976414658267803`*^9}, {3.497641501427451*^9, 
   3.49764156109564*^9}, {3.4976416457739477`*^9, 3.497641652477425*^9}, {
   3.497641721783152*^9, 3.4976417597291813`*^9}, {3.497641890582053*^9, 
   3.497642106731271*^9}, {3.4976421488939734`*^9, 3.497642165458894*^9}, {
   3.497642422037841*^9, 3.497642439624383*^9}, {3.4976424752924128`*^9, 
   3.49764247634594*^9}, 3.497642565846753*^9, {3.497643575568694*^9, 
   3.497643585617092*^9}, {3.497643700285748*^9, 3.4976437317640953`*^9}, {
   3.4976438569646997`*^9, 3.497644028535871*^9}, {3.497645005165516*^9, 
   3.497645042548409*^9}, {3.4976451775180197`*^9, 3.497645177772025*^9}, {
   3.497645273756444*^9, 3.497645282690267*^9}, {3.4976775814136763`*^9, 
   3.4976775932556868`*^9}, 3.497677640684863*^9, {3.4976777372316227`*^9, 
   3.497677797907633*^9}, {3.497677917038562*^9, 3.497677937629937*^9}, {
   3.497677969872437*^9, 3.497678035109571*^9}, {3.497678196561973*^9, 
   3.497678226805153*^9}, {3.497678314458844*^9, 3.497678393089711*^9}, {
   3.497678432466263*^9, 3.497678533772499*^9}, {3.4976786656388197`*^9, 
   3.497678665847672*^9}, {3.497678847803544*^9, 3.497678858353918*^9}, {
   3.497679319516535*^9, 3.497679320202732*^9}, {3.497679373229784*^9, 
   3.497679529515565*^9}, {3.4976915609236565`*^9, 3.497691562782055*^9}, {
   3.497721270216998*^9, 3.4977213030833197`*^9}, {3.497721784392227*^9, 
   3.4977217902702713`*^9}, {3.497721872231908*^9, 3.4977218778474894`*^9}, {
   3.4977219185360317`*^9, 3.4977219235725*^9}, {3.497722042720949*^9, 
   3.497722047829918*^9}, {3.497722205600049*^9, 3.497722208068375*^9}, {
   3.497722381403256*^9, 3.4977223993848953`*^9}, {3.497722458784298*^9, 
   3.497722467727737*^9}, {3.49772252922182*^9, 3.4977225297230263`*^9}, {
   3.4977225932210417`*^9, 3.4977226201708603`*^9}, {3.497722653601465*^9, 
   3.497722655689925*^9}, {3.4977231031267014`*^9, 3.4977231070072927`*^9}, {
   3.497723280500778*^9, 3.497723323081052*^9}, {3.4977233731221046`*^9, 
   3.497723377360959*^9}, {3.4977234515876904`*^9, 3.497723457631894*^9}, {
   3.497724127439816*^9, 3.497724155855054*^9}, {3.4977686362830315`*^9, 
   3.4977686881892815`*^9}, {3.497768737436352*^9, 3.497768862435375*^9}, {
   3.4977695579158435`*^9, 3.497769651652172*^9}, {3.497769730435375*^9, 
   3.497769758413891*^9}, {3.4977805330261955`*^9, 3.4977805402644763`*^9}, {
   3.4977807880750237`*^9, 3.497780802648266*^9}, {3.4977825950204773`*^9, 
   3.4977826028314238`*^9}, {3.497790089646113*^9, 3.497790147669817*^9}, {
   3.497790209254044*^9, 3.497790248383581*^9}, {3.4977902871047707`*^9, 
   3.497790368398271*^9}, {3.497790541352887*^9, 3.497790587912777*^9}, {
   3.497790664578618*^9, 3.4977906776312027`*^9}, {3.497790775496626*^9, 
   3.497790818665165*^9}, {3.4977908633542833`*^9, 3.49779088890209*^9}, {
   3.497790947789344*^9, 3.497791012471961*^9}, {3.497801662523673*^9, 
   3.497801673318326*^9}, {3.497801797122759*^9, 3.4978018006247463`*^9}, {
   3.497809139175707*^9, 3.497809140208757*^9}, {3.497809593970996*^9, 
   3.49780979973851*^9}, {3.497809837705937*^9, 3.497809931576932*^9}, 
   3.4978567361374617`*^9, {3.4978567933882017`*^9, 3.497856870216549*^9}, {
   3.497861564321643*^9, 3.497861619550126*^9}, {3.4978617261346188`*^9, 
   3.4978617504107027`*^9}, {3.497862054503625*^9, 3.497862057407721*^9}, {
   3.4978653466245337`*^9, 3.4978653715808573`*^9}, {3.4978654647967587`*^9, 
   3.497865478009465*^9}, {3.497875039881068*^9, 3.497875061791848*^9}, {
   3.497875277986206*^9, 3.4978752925029163`*^9}, {3.497875350292555*^9, 
   3.4978753734123898`*^9}, {3.497875404079463*^9, 3.497875407464094*^9}, {
   3.4978755170290833`*^9, 3.4978755347146473`*^9}, {3.4978758062800007`*^9, 
   3.497875816337322*^9}, {3.497875848312316*^9, 3.497875879686618*^9}, {
   3.497876010858898*^9, 3.497876013827249*^9}, {3.4978996158155813`*^9, 
   3.4978996757114964`*^9}, {3.497899713177697*^9, 3.497899715316806*^9}, {
   3.4984606322968407`*^9, 3.498460634962229*^9}, {3.498460718560357*^9, 
   3.498460738925362*^9}, {3.498460936981515*^9, 3.498460939745914*^9}, {
   3.4989026518347883`*^9, 3.498902653084937*^9}, {3.499063363977989*^9, 
   3.4990634187426853`*^9}, {3.499063482813459*^9, 3.499063571347361*^9}, {
   3.4991643185865707`*^9, 3.49916431941101*^9}, {3.4994307563276157`*^9, 
   3.49943076500494*^9}, {3.516556862184917*^9, 3.5165568862686357`*^9}, {
   3.516556919003004*^9, 3.516557170923005*^9}, 3.5165572172115183`*^9, {
   3.516557618879375*^9, 3.5165576582555637`*^9}, {3.5165577432319317`*^9, 
   3.516557786606502*^9}, {3.51655788372681*^9, 3.5165578839880447`*^9}, 
   3.516558412702285*^9, {3.516596997145884*^9, 3.516597009495743*^9}, {
   3.529645192395974*^9, 3.529645331545662*^9}, 3.5296599249113894`*^9, {
   3.529817189292055*^9, 3.529817194854447*^9}, {3.547883435256064*^9, 
   3.5478834554052343`*^9}, {3.5478837631257067`*^9, 3.5478837968939*^9}, {
   3.547883891080011*^9, 3.5478839022011347`*^9}, {3.5478840341944027`*^9, 
   3.547884040449875*^9}, {3.547884117425733*^9, 3.547884131689568*^9}, {
   3.5478841747634907`*^9, 3.547884191400591*^9}, {3.547884221479252*^9, 
   3.5478842993937798`*^9}, {3.547885512544272*^9, 3.547885525387849*^9}, {
   3.547885612230756*^9, 3.547885647677189*^9}, {3.547886115148745*^9, 
   3.547886124651038*^9}, {3.547887528034771*^9, 3.547887542245369*^9}, {
   3.547888069841174*^9, 3.547888073007441*^9}, {3.547889750887219*^9, 
   3.5478897565099697`*^9}, {3.5478898321142263`*^9, 3.547889854913254*^9}, 
   3.547893688959486*^9, 3.54791639762047*^9, {3.547916942663615*^9, 
   3.5479169441455183`*^9}, {3.5479171748237534`*^9, 3.547917185797537*^9}, {
   3.547917291856192*^9, 3.547917320550152*^9}, 3.547917407111026*^9, {
   3.547917485060493*^9, 3.547917488803087*^9}, {3.547917578901217*^9, 
   3.547917605810567*^9}, {3.547917776518854*^9, 3.547917795567971*^9}, {
   3.547917966385941*^9, 3.547917998668796*^9}, {3.547918068200892*^9, 
   3.547918074141555*^9}, {3.547918267180187*^9, 3.5479182674235477`*^9}, {
   3.54791857086981*^9, 3.547918575879521*^9}, {3.554352425238402*^9, 
   3.554352425595454*^9}, {3.554453623418989*^9, 3.5544536491089153`*^9}, {
   3.554453680187821*^9, 3.554453693914744*^9}, {3.599203270159008*^9, 
   3.599203334007592*^9}, {3.599203537642106*^9, 3.599203537870449*^9}}],

Cell["", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 3}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 5}],

Cell[CellGroupData[{

Cell["\<\
Special Values for the Integrals I1, \[Pi]nm and \[Tau]nm\
\>", "Subsubsection",
 CellChangeTimes->{{3.598163935490984*^9, 3.598163951188561*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "n", ",", "m", ",", "H00", ",", "H11", ",", "H10", ",", "IA", ",", 
    "\[Theta]f", ",", "\[Pi]T", ",", "\[Pi]00", ",", "\[Tau]10", ",", 
    "\[Tau]11"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Pi]T", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Pi]00", "=", 
     FractionBox["1", 
      RowBox[{"Sin", "[", "\[Theta]f", "]"}]]}], ",", 
    RowBox[{"\[Pi]10", "=", 
     FractionBox[
      RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
      RowBox[{"Sin", "[", "\[Theta]f", "]"}]]}], ",", 
    RowBox[{"\[Pi]11", "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "1"], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "*", "1"}], ")"}], "!"}], 
       RowBox[{
        SuperscriptBox["2", "1"], 
        RowBox[{"(", 
         RowBox[{"1", "!"}], ")"}]}]]}]}], ",", 
    RowBox[{"\[Tau]10", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"1", "*", 
        RowBox[{"Cos", "[", "\[Theta]f", "]"}], "\[Pi]10"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "0"}], ")"}], "*", "\[Pi]00"}]}], "]"}]}], ",", 
    RowBox[{"\[Tau]11", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"-", "1"}], "*", 
       RowBox[{"(", 
        RowBox[{"2", "-", "1"}], ")"}], "*", 
       RowBox[{"Sin", "[", "\[Theta]f", "]"}], "*", 
       RowBox[{"Cos", "[", "\[Theta]f", "]"}], "\[Pi]00"}], "]"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"H00", "=", 
  RowBox[{
   RowBox[{"Cos", "[", "\[Theta]f", "]"}], "-", 
   "1"}]}], "\[IndentingNewLine]", 
 RowBox[{"H11", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "-", "1"}], ")"}], "!!"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]f", "]"}], 
          RowBox[{"2", "n"}]]}], "+", 
        FractionBox[
         RowBox[{"2", "n", " ", "H00"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "-", "1"}], ")"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", "n"}], "-", "3"}], ")"}], "!!"}], ")"}], 
           "2"]}]]}], ")"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{"n", "\[Rule]", "1"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"H10", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"n", "-", "m", "+", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "+", "m", "+", "1"}], ")"}], "H00"}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "+", "m", "+", "1"}], ")"}], 
               SuperscriptBox[
                RowBox[{"(", "\[Pi]00", ")"}], "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "-", "m", "+", "1"}], ")"}], 
               SuperscriptBox[
                RowBox[{"(", "\[Pi]10", ")"}], "2"]}]}], ")"}]}], "-", 
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"n", "+", "1"}], ")"}], "\[Pi]00", " ", "\[Pi]10"}]}], 
          ")"}]}]}], ")"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "\[Rule]", "0"}], ",", 
      RowBox[{"m", "\[Rule]", "0"}], ",", 
      RowBox[{"\[Pi]00", "\[Rule]", 
       FractionBox["1", 
        RowBox[{"Sin", "[", "\[Theta]f", "]"}]]}], ",", 
      RowBox[{"\[Pi]10", "\[Rule]", 
       FractionBox[
        RowBox[{"Cos", "[", "\[Theta]f", "]"}], 
        RowBox[{"Sin", "[", "\[Theta]f", "]"}]]}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"IA", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"I110", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", "3"]}], "H10"}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], "\[Pi]10", " ", 
        "\[Tau]10"}]}], "]"}]}], ",", 
    RowBox[{"I111", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", "3"]}], "H11"}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"], "\[Pi]11", " ", 
        "\[Tau]11"}]}], "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"TrigReduce", "[", "I110", "]"}], ",", 
   RowBox[{"TrigReduce", "[", "I111", "]"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"IA", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Theta]f", "\[Rule]", 
      RowBox[{"\[Pi]", "/", "2"}]}], "}"}]}], ",", 
   RowBox[{"Series", "[", 
    RowBox[{"IA", ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]f", ",", "0", ",", "4"}], "}"}]}], "]"}]}], 
  "}"}]}], "Input",
 CellChangeTimes->{{3.598159910682221*^9, 3.598159970309456*^9}, {
   3.5981606945544987`*^9, 3.598160744251417*^9}, {3.598162447336935*^9, 
   3.598162605077532*^9}, {3.59816264476117*^9, 3.598162659084487*^9}, {
   3.598162698109926*^9, 3.598162792908155*^9}, {3.5981628614406347`*^9, 
   3.5981628627035437`*^9}, {3.598162896455806*^9, 3.598162989287019*^9}, {
   3.598163236161689*^9, 3.598163257696924*^9}, {3.598163467308893*^9, 
   3.598163469936425*^9}, {3.598163507599943*^9, 3.598163507737692*^9}, 
   3.598163547462304*^9, {3.5981639005141163`*^9, 3.598163917233418*^9}, {
   3.598163983020094*^9, 3.5981639937521067`*^9}, {3.598164132776609*^9, 
   3.598164150121031*^9}, {3.598164221037471*^9, 3.598164223876235*^9}, {
   3.598180192557026*^9, 3.598180203824321*^9}, {3.598180244564519*^9, 
   3.598180274716071*^9}, {3.598180725612607*^9, 3.598180725747652*^9}, 
   3.5981810768084784`*^9, {3.598186146226469*^9, 3.598186150349794*^9}, {
   3.598186227272194*^9, 3.598186227415017*^9}, {3.601444637026916*^9, 
   3.601444654139669*^9}, {3.6014448863101587`*^9, 3.601444895872745*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Csc", "[", "\[Theta]f", "]"}], ",", 
   RowBox[{"Cot", "[", "\[Theta]f", "]"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", 
    RowBox[{"Sin", "[", "\[Theta]f", "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"Cos", "[", "\[Theta]f", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.601445122304666*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"Cos", "[", "\[Theta]f", "]"}]}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.60144512230648*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", "\[Theta]f", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.601445122307529*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  SuperscriptBox[
   RowBox[{"Cos", "[", "\[Theta]f", "]"}], "3"]}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.601445122308372*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["4", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      RowBox[{"Cos", "[", "\[Theta]f", "]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      FractionBox["\[Theta]f", "2"], "]"}], "4"]}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]f", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]f", "]"}], "2"]}], ")"}]}]}], 
     ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.6014451223618097`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{"8", "-", 
      RowBox[{"9", " ", 
       RowBox[{"Cos", "[", "\[Theta]f", "]"}]}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", " ", "\[Theta]f"}], "]"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{"16", "-", 
      RowBox[{"15", " ", 
       RowBox[{"Cos", "[", "\[Theta]f", "]"}]}], "-", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", " ", "\[Theta]f"}], "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.601445122363011*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", "3"], ",", 
     FractionBox["4", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       FractionBox[
        SuperscriptBox["\[Theta]f", "4"], "4"], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "\[Theta]f", "]"}], "5"],
        SeriesData[$CellContext`\[Theta]f, 0, {}, 4, 5, 1],
        Editable->False]}],
      SeriesData[$CellContext`\[Theta]f, 0, {
        Rational[1, 4]}, 4, 5, 1],
      Editable->False], ",", 
     InterpretationBox[
      RowBox[{
       SuperscriptBox["\[Theta]f", "2"], "-", 
       FractionBox[
        SuperscriptBox["\[Theta]f", "4"], "3"], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "\[Theta]f", "]"}], "5"],
        SeriesData[$CellContext`\[Theta]f, 0, {}, 2, 5, 1],
        Editable->False]}],
      SeriesData[$CellContext`\[Theta]f, 0, {1, 0, 
        Rational[-1, 3]}, 2, 5, 1],
      Editable->False]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.598159942285128*^9, 3.598159970867298*^9}, {
   3.5981606960389423`*^9, 3.598160744616179*^9}, 3.5981625420091553`*^9, {
   3.59816264663735*^9, 3.598162659704555*^9}, {3.598162752624642*^9, 
   3.5981627585630836`*^9}, 3.598162794722103*^9, 3.598162863416828*^9, 
   3.59816295861895*^9, 3.5981629900072803`*^9, {3.598163236483472*^9, 
   3.598163258024365*^9}, {3.598163458543583*^9, 3.598163470683394*^9}, 
   3.598163508257427*^9, 3.598163547929242*^9, {3.5981639031786823`*^9, 
   3.598163917633238*^9}, {3.598163987320223*^9, 3.598163994144449*^9}, {
   3.598164136000073*^9, 3.598164150395349*^9}, {3.5981642215978727`*^9, 
   3.598164224202229*^9}, 3.598180204225205*^9, 3.598180244895302*^9, 
   3.598180275216642*^9, 3.598180726166328*^9, 3.598181077299982*^9, {
   3.598186147321712*^9, 3.598186151806942*^9}, 3.5981862278019457`*^9, 
   3.601444081661621*^9, 3.6014441312573843`*^9, {3.601444647607994*^9, 
   3.6014446549221354`*^9}, 3.601444897748171*^9, 3.601445122364203*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1610, 692},
WindowMargins->{{5, Automatic}, {Automatic, 151}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 20, \
2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 2184, 60, 207, "Title"],
Cell[2754, 84, 995, 21, 165, "Title"],
Cell[CellGroupData[{
Cell[3774, 109, 30978, 683, 885, "Input",
 InitializationCell->True],
Cell[34755, 794, 15286, 213, 28, "Output"],
Cell[50044, 1009, 15289, 213, 28, "Output"],
Cell[65336, 1224, 15449, 217, 35, "Output"],
Cell[80788, 1443, 15467, 215, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96304, 1664, 11935, 203, 176, "Title"],
Cell[108242, 1869, 1909, 36, 27, "Input"],
Cell[110154, 1907, 17256, 354, 307, "Input",
 InitializationCell->True],
Cell[127413, 2263, 6012, 157, 275, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[133462, 2425, 1970, 50, 259, "Title"],
Cell[135435, 2477, 56671, 1330, 1438, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[192143, 3812, 1310, 28, 165, "Title"],
Cell[193456, 3842, 775, 15, 59, "Text"],
Cell[194234, 3859, 40723, 578, 50, "Text"],
Cell[234960, 4439, 319802, 5482, 228, "Input"],
Cell[554765, 9923, 72412, 1694, 1418, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[627214, 11622, 1668, 39, 184, "Title"],
Cell[628885, 11663, 97882, 2229, 2723, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[726804, 13897, 1389, 25, 165, "Title"],
Cell[728196, 13924, 29592, 697, 780, "Input",
 InitializationCell->True],
Cell[757791, 14623, 39624, 905, 1079, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[797440, 15532, 226, 5, 51, "Subsubsection"],
Cell[797669, 15539, 9862, 237, 252, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[807580, 15782, 427, 12, 133, "Title"],
Cell[808010, 15796, 846, 17, 146, "Title"],
Cell[808859, 15815, 2948, 82, 126, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[811844, 15902, 2558, 86, 159, "Title"],
Cell[814405, 15990, 18408, 497, 520, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[832850, 16492, 2612, 80, 177, "Title"],
Cell[835465, 16574, 6811, 204, 186, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[842301, 16782, 129, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[842455, 16787, 2091, 57, 80, "Input"],
Cell[844549, 16846, 937, 21, 28, "Output"],
Cell[845489, 16869, 929, 18, 28, "Output"],
Cell[846421, 16889, 926, 18, 28, "Output"],
Cell[847350, 16909, 948, 22, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[848347, 16937, 249, 5, 29, "Subsubsection"],
Cell[848599, 16944, 16034, 484, 534, "Input"],
Cell[CellGroupData[{
Cell[864658, 17432, 3323, 87, 137, "Input"],
Cell[867984, 17521, 2597, 75, 79, "Output"],
Cell[870584, 17598, 2597, 75, 79, "Output"],
Cell[873184, 17675, 2115, 63, 79, "Output"],
Cell[875302, 17740, 3211, 93, 75, "Output"],
Cell[878516, 17835, 77, 1, 28, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[878654, 17843, 847, 20, 148, "Title"],
Cell[879504, 17865, 378, 8, 29, "Subsubtitle"],
Cell[879885, 17875, 1726, 44, 80, "Input"],
Cell[CellGroupData[{
Cell[881636, 17923, 689, 18, 52, "Input"],
Cell[882328, 17943, 717, 21, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[883082, 17969, 174, 2, 51, "Subtitle"],
Cell[CellGroupData[{
Cell[883281, 17975, 36011, 837, 1169, "Input",
 InitializationCell->True],
Cell[919295, 18814, 7072, 101, 35, "Output"],
Cell[926370, 18917, 6984, 99, 28, "Output"],
Cell[933357, 19018, 6985, 99, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[940379, 19122, 1698, 39, 80, "Input"],
Cell[942080, 19163, 1459, 25, 28, "Output"]
}, Open  ]],
Cell[943554, 19191, 16749, 291, 71, "Input"],
Cell[CellGroupData[{
Cell[960328, 19486, 5883, 148, 131, "Input"],
Cell[966214, 19636, 5712, 106, 188, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[971987, 19749, 3419, 90, 253, "Title"],
Cell[975409, 19841, 194, 4, 30, "Text"],
Cell[975606, 19847, 50220, 1102, 1507, "Input",
 InitializationCell->True],
Cell[1025829, 20951, 270, 9, 10, "Text"],
Cell[CellGroupData[{
Cell[1026124, 20964, 156, 3, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[1026305, 20971, 6524, 183, 247, "Input"],
Cell[1032832, 21156, 1332, 23, 28, "Output"],
Cell[1034167, 21181, 1119, 17, 28, "Output"],
Cell[1035289, 21200, 1262, 22, 35, "Output"],
Cell[1036554, 21224, 1145, 18, 32, "Output"],
Cell[1037702, 21244, 1664, 36, 48, "Output"],
Cell[1039369, 21282, 1587, 32, 47, "Output"],
Cell[1040959, 21316, 2097, 47, 50, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
