(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1551243,      28361]
NotebookOptionsPosition[   1545544,      28174]
NotebookOutlinePosition[   1545979,      28191]
CellTagsIndexPosition[   1545936,      28188]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Generalized Mie Theory ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Far Field Examples",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" of Mathematica Scripts, e.g. rel. PT signal and Scatter scans\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Implemented by ",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Markus Selmke (selmke@zr.uni-leipzig.de, markus.selmke@gmx.de)\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["If any of this code shall be used, please ",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["cite the appropriate Journal Article",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" reference:",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Nano-lens diffraction around a single heated nano particle\", \
Optics Express, Vol. 20, No. 7, pp. 8055-8070, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", M. Selmke, M. Braun, F. Cichos, (early version: \
arXiv:1109.2772v1)",
  FontSize->12],
 StyleBox["\n",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Photothermal Single Particle Microscopy: Detection of a Nanolens\
\", ACS Nano, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1) ",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.532369726316798*^9, 3.5323698534171743`*^9}, {
   3.532369907370092*^9, 3.532369928118697*^9}, {3.5542022160578613`*^9, 
   3.554202221813991*^9}, {3.554361510430574*^9, 3.5543615517729263`*^9}, {
   3.554361589354903*^9, 3.554361590611668*^9}, {3.554362383467846*^9, 
   3.554362414673489*^9}, 3.554452160174601*^9},
 Background->GrayLevel[0.85]],

Cell[TextData[{
 "Check Gaussian BSCs ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["g", "nm"], TraditionalForm]], "None"],
 ", off-axis\n",
 StyleBox["\"Localized Approximation of Generalized Lorenz-Mie Theory: Faster \
Algorithm for Computations of Beam Shape Coefficients, gnm\", Kuan F. Ren, \
Gerard Grehan, Gerard Gouesbet, 1991",
  FontSize->12],
 "\n",
 StyleBox["Table of gnms to check code vs. paper with tabulated gnms",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.554278825537629*^9, 3.554278825974612*^9}, {
  3.5542788625822897`*^9, 3.5542788767720757`*^9}, {3.5542789294937477`*^9, 
  3.554278929668612*^9}, {3.554279065593478*^9, 3.554279071078206*^9}, {
  3.55438431681234*^9, 3.554384337255329*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sT", "=", 
    RowBox[{"8.18851822", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";", 
   RowBox[{"x0T", "=", "0.5"}], ";", 
   RowBox[{"y0T", "=", "0.5"}], ";", 
   RowBox[{"z0T", "=", 
    RowBox[{"0.5", "*", "sT"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "use", " ", "to", " ", "compare", " ", "to", " ", "TABLE", " ", "3"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sT", "=", 
    RowBox[{"8.18851822", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";", 
   RowBox[{"x0T", "=", "0"}], ";", 
   RowBox[{"y0T", "=", "0.5"}], ";", 
   RowBox[{"z0T", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "use", " ", "to", " ", "compare", " ", "to", " ", "TABLE", " ", "2"}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"F0nTM", "[", 
        RowBox[{
        "n", ",", "m", ",", "jmax", ",", "s", ",", "z0", ",", "x0", ",", 
         "y0"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "4"}], "}"}]}], "]"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TraditionalForm", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", ",", "m"}], "}"}], ",", 
         RowBox[{"ScientificForm", "[", 
          RowBox[{"gnmTM", "[", 
           RowBox[{
           "n", ",", "m", ",", "jmax", ",", "sT", ",", "z0T", ",", "x0T", ",",
             "y0T"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "4"}], "}"}]}], "]"}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"F0nTE", "[", 
        RowBox[{
        "n", ",", "m", ",", "jmax", ",", "s", ",", "z0", ",", "x0", ",", 
         "y0"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "4"}], "}"}]}], "]"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"TraditionalForm", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"n", ",", "m"}], "}"}], ",", 
        RowBox[{"ScientificForm", "[", 
         RowBox[{"gnmTE", "[", 
          RowBox[{
          "n", ",", "m", ",", "jmax", ",", "sT", ",", "z0T", ",", "x0T", ",", 
           "y0T"}], "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "n"}], ",", "n"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "4"}], "}"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.554278912511441*^9, 3.554278913127143*^9}, {
  3.554452254946526*^9, 3.554452265362232*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.89349\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"2.93697\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], "\<\"0\"\>"},
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.89349\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"2.93697\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.59369\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-3\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.18728\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-12\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.89258\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"8.15624\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}], "\<\"0\"\>"},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.89258\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"8.15624\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", "2"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-1.59369\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-3\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.18728\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-12\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.26124\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-6\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.30447\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"-", "2"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.59311\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-3\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.18599\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-12\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.89121\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.59803\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-13\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "0"}], "}"}], "\<\"0\"\>"},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.89121\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.59803\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-13\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "2"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-1.59311\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-3\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.18599\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-12\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "3"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.26124\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-6\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.30447\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "4"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"4.44847\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-9\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"2.66905\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-17\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "3"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.2596\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-6\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.3038\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "2"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.59232\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-3\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.18429\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-12\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.88938\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"2.64035\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-13\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "0"}], "}"}], "\<\"0\"\>"},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.88938\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-1\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"2.64035\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-13\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "2"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-1.59232\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-3\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.18429\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-12\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "3"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.2596\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-6\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.3038\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-14\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "4"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-4.44847\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-9\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"2.66905\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-17\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.554278913788273*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"2.93697\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.89364\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], 
        RowBox[{"\<\"0.\"\>", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"6.37638\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"2.93697\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.89364\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.18761\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-12\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.59375\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"8.15624\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.89298\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}], 
        RowBox[{"\<\"0.\"\>", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.91247\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-2\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"8.15624\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.89298\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"2", ",", "2"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-3.18761\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-12\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.59375\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.30456\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.26135\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-6\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"-", "2"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.18665\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-12\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.59322\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.59803\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-13\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.89201\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "0"}], "}"}], 
        RowBox[{"\<\"0.\"\>", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.82359\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-2\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.59803\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-13\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.89201\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "2"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-3.18665\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-12\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.59322\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"3", ",", "3"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.30456\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.26135\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-6\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "4"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"2.6692\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-17\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"4.44862\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-9\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "3"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.30395\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.25978\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-6\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "2"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"3.18537\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-12\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.5925\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}], "}"}], 
        RowBox[{
         RowBox[{"\<\"2.64035\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-13\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.8907\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "0"}], "}"}], 
        RowBox[{"\<\"0.\"\>", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"6.36965\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-2\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "1"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"2.64035\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-13\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.8907\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-1\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "2"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-3.18537\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-12\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"1.5925\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-3\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "3"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"1.30395\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-14\"\>"]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"3.25978\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-6\"\>"]}], ")"}]}]}]},
       {
        RowBox[{"{", 
         RowBox[{"4", ",", "4"}], "}"}], 
        RowBox[{
         RowBox[{"\<\"-2.6692\"\>", "\[Times]", 
          SuperscriptBox["10", "\<\"-17\"\>"]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"\<\"4.44862\"\>", "\[Times]", 
            SuperscriptBox["10", "\<\"-9\"\>"]}], ")"}]}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.554278913818277*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.5542789112639093`*^9}],

Cell[CellGroupData[{

Cell["\<\
Compare Mie-coeffs to Multilayer-Mie coeffs, i.e. check sign convention\
\>", "Subtitle",
 CellChangeTimes->{{3.532092134203248*^9, 3.532092150415887*^9}, {
   3.5323692621254673`*^9, 3.532369269507146*^9}, {3.532431389406336*^9, 
   3.532431415525949*^9}, {3.5324315517142487`*^9, 3.5324315547213697`*^9}, {
   3.533239964567643*^9, 3.533239980388461*^9}, 3.554212804533127*^9, {
   3.554280817362754*^9, 3.554280828161302*^9}, {3.554449589696306*^9, 
   3.554449597935305*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"w0", "=", "23300"}], ";", 
  RowBox[{"x", "=", 
   RowBox[{"{", 
    RowBox[{"k", " ", "R"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"{", 
    RowBox[{"nParticle", "/", "nmed"}], "}"}]}], ";", 
  RowBox[{"AA", "=", 
   RowBox[{"abL", "[", 
    RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";", 
  RowBox[{"anC", "=", 
   RowBox[{"AA", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"bnC", "=", 
   RowBox[{"AA", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a1", "=", 
  RowBox[{
   RowBox[{"abL", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Conjugate", "[", 
      RowBox[{"{", 
       RowBox[{"nParticle", "/", "nmed"}], "}"}], "]"}], ",", "5"}], "]"}], 
   "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"a3", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"aMie", "[", 
     RowBox[{"n", ",", 
      RowBox[{"k", " ", "R"}], ",", 
      RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"b1", "=", 
  RowBox[{
   RowBox[{"abL", "[", 
    RowBox[{"x", ",", 
     RowBox[{"{", 
      RowBox[{"nParticle", "/", "nmed"}], "}"}], ",", "5"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"a3", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"bMie", "[", 
     RowBox[{"n", ",", 
      RowBox[{"k", " ", "R"}], ",", 
      RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.533235545963752*^9, 3.533235634545143*^9}, {
   3.5332357044297*^9, 3.5332357957026777`*^9}, {3.533235869524551*^9, 
   3.533235893120047*^9}, {3.53323601117492*^9, 3.5332360191088037`*^9}, {
   3.533236671228264*^9, 3.533236674665491*^9}, {3.53323670596935*^9, 
   3.5332367304682913`*^9}, {3.533236783471937*^9, 3.533236837237666*^9}, {
   3.5332374280676727`*^9, 3.53323742899039*^9}, {3.5332378275680227`*^9, 
   3.533237859583778*^9}, 3.533238425429583*^9, {3.533238483439851*^9, 
   3.533238484254003*^9}, {3.554282329022888*^9, 3.5542823419788322`*^9}, {
   3.554282433154683*^9, 3.5542824928497667`*^9}, {3.554282542146954*^9, 
   3.5542825550657797`*^9}, {3.554433567974568*^9, 3.554433589770153*^9}, {
   3.554433658070694*^9, 3.55443368207469*^9}, {3.554434031206052*^9, 
   3.5544340350133743`*^9}, 3.554435064785275*^9, {3.554439044319804*^9, 
   3.554439057267705*^9}, {3.554439273197115*^9, 3.5544393239730587`*^9}, {
   3.554440106232521*^9, 3.554440112989406*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.004110836752890822`", "\[InvisibleSpace]", "-", 
    RowBox[{"0.12663761823558708`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.00004425604541849592`"}], "-", 
    RowBox[{"0.0008296495308724097`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "1.7570671895931178`*^-7"}], "-", 
    RowBox[{"3.722141383107679`*^-6", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4.502410455413356`*^-10"}], "-", 
    RowBox[{"1.0164399801205408`*^-8", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "7.872625081683385`*^-13"}], "-", 
    RowBox[{"1.840143574847969`*^-11", " ", "\[ImaginaryI]"}]}], ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.533237429732175*^9, {3.5332378313670397`*^9, 3.533237860453638*^9}, {
   3.533238426774029*^9, 3.5332384380106087`*^9}, 3.5332384850563097`*^9, 
   3.533238611262879*^9, 3.5542823370940123`*^9, 3.5542824991045322`*^9, 
   3.554282555642426*^9, 3.5542837234903383`*^9, 3.554433522180874*^9, {
   3.554433570058086*^9, 3.554433695520697*^9}, {3.5544340354973087`*^9, 
   3.5544340470367203`*^9}, 3.554436015396105*^9, 3.554436047722043*^9, {
   3.554439026491935*^9, 3.5544390577068043`*^9}, {3.554439100314191*^9, 
   3.554439107471158*^9}, 3.55443921913662*^9, {3.5544392493736134`*^9, 
   3.554439268269514*^9}, 3.5544396138937807`*^9, {3.5544396442469063`*^9, 
   3.5544396545587473`*^9}, {3.554439863593894*^9, 3.5544398832035933`*^9}, 
   3.554440113724655*^9, 3.554440824866119*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.02672062053753986`", "\[InvisibleSpace]", "-", 
    RowBox[{"0.12086364771074282`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"0.000045628389033242176`", "\[InvisibleSpace]", "-", 
    RowBox[{"0.0008295004306117029`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"1.757349737003211`*^-7", "-", 
    RowBox[{"3.7221342697038365`*^-6", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"4.50211436273424`*^-10", "-", 
    RowBox[{"1.0165144034779692`*^-8", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"7.805120620562643`*^-13", "-", 
    RowBox[{"1.8293422429645094`*^-11", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.533237429732175*^9, {3.5332378313670397`*^9, 3.533237860453638*^9}, {
   3.533238426774029*^9, 3.5332384380106087`*^9}, 3.5332384850563097`*^9, 
   3.533238611262879*^9, 3.5542823370940123`*^9, 3.5542824991045322`*^9, 
   3.554282555642426*^9, 3.5542837234903383`*^9, 3.554433522180874*^9, {
   3.554433570058086*^9, 3.554433695520697*^9}, {3.5544340354973087`*^9, 
   3.5544340470367203`*^9}, 3.554436015396105*^9, 3.554436047722043*^9, {
   3.554439026491935*^9, 3.5544390577068043`*^9}, {3.554439100314191*^9, 
   3.554439107471158*^9}, 3.55443921913662*^9, {3.5544392493736134`*^9, 
   3.554439268269514*^9}, 3.5544396138937807`*^9, {3.5544396442469063`*^9, 
   3.5544396545587473`*^9}, {3.554439863593894*^9, 3.5544398832035933`*^9}, 
   3.554440113724655*^9, 3.554440824870287*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.00015230303056569275`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.0019441024241995182`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"9.095395592463722`*^-7", "+", 
    RowBox[{"0.000011178141710656034`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"2.8475537439555544`*^-9", "+", 
    RowBox[{"3.421347350915817`*^-8", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"5.441088134869299`*^-12", "+", 
    RowBox[{"6.533589186677435`*^-11", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"1.587115358137613`*^-14", "+", 
    RowBox[{"1.8822785210414085`*^-13", " ", "\[ImaginaryI]"}]}], ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.533237429732175*^9, {3.5332378313670397`*^9, 3.533237860453638*^9}, {
   3.533238426774029*^9, 3.5332384380106087`*^9}, 3.5332384850563097`*^9, 
   3.533238611262879*^9, 3.5542823370940123`*^9, 3.5542824991045322`*^9, 
   3.554282555642426*^9, 3.5542837234903383`*^9, 3.554433522180874*^9, {
   3.554433570058086*^9, 3.554433695520697*^9}, {3.5544340354973087`*^9, 
   3.5544340470367203`*^9}, 3.554436015396105*^9, 3.554436047722043*^9, {
   3.554439026491935*^9, 3.5544390577068043`*^9}, {3.554439100314191*^9, 
   3.554439107471158*^9}, 3.55443921913662*^9, {3.5544392493736134`*^9, 
   3.554439268269514*^9}, 3.5544396138937807`*^9, {3.5544396442469063`*^9, 
   3.5544396545587473`*^9}, {3.554439863593894*^9, 3.5544398832035933`*^9}, 
   3.554440113724655*^9, 3.5544408248725348`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.0001523030007196996`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.0019441023671694698`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"9.095446873451231`*^-7", "+", 
    RowBox[{"0.000011178154148624934`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"2.8468075834252904`*^-9", "+", 
    RowBox[{"3.421100658655962`*^-8", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"5.5339958705445335`*^-12", "+", 
    RowBox[{"6.578374602592188`*^-11", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"7.372118714673815`*^-15", "+", 
    RowBox[{"8.709890423195572`*^-14", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.533237429732175*^9, {3.5332378313670397`*^9, 3.533237860453638*^9}, {
   3.533238426774029*^9, 3.5332384380106087`*^9}, 3.5332384850563097`*^9, 
   3.533238611262879*^9, 3.5542823370940123`*^9, 3.5542824991045322`*^9, 
   3.554282555642426*^9, 3.5542837234903383`*^9, 3.554433522180874*^9, {
   3.554433570058086*^9, 3.554433695520697*^9}, {3.5544340354973087`*^9, 
   3.5544340470367203`*^9}, 3.554436015396105*^9, 3.554436047722043*^9, {
   3.554439026491935*^9, 3.5544390577068043`*^9}, {3.554439100314191*^9, 
   3.554439107471158*^9}, 3.55443921913662*^9, {3.5544392493736134`*^9, 
   3.554439268269514*^9}, 3.5544396138937807`*^9, {3.5544396442469063`*^9, 
   3.5544396545587473`*^9}, {3.554439863593894*^9, 3.5544398832035933`*^9}, 
   3.554440113724655*^9, 3.5544408249260197`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Gold, Refractive Index and Dielectric Constant ",
 StyleBox["(Polystyrene: \[Epsilon] = 2.528 + 0.002*i, Conjugate[Sqrt[\
\[Epsilon]Particle[635]]] = 0.174775 - 3.46177 \[ImaginaryI])",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.4730625444417257`*^9, 3.473062580921957*^9}, {
  3.5296572113383913`*^9, 3.5296572117864656`*^9}, {3.554436946686193*^9, 
  3.5544369474728527`*^9}, {3.554437477441307*^9, 3.5544374841822863`*^9}, {
  3.554437514413484*^9, 3.55443751866381*^9}, {3.5544376968285913`*^9, 
  3.554437706650146*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Epsilon]Particle", ",", "AA", ",", "\[Epsilon]real", ",", "\[Epsilon]im",
    ",", "\[Epsilon]realfunc", ",", "\[Epsilon]imfunc"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AA", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\</Users/markusselmke/Documents/Documents Mathematica/au_diel.txt\>\"",
      ",", "\"\<table\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]real", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AA", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"AA", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AA", "]"}]}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"\[Epsilon]im", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AA", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"AA", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AA", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]realfunc", "=", 
   RowBox[{
    StyleBox["Interpolation", "MR"], "[", "\[Epsilon]real", "]"}]}], ";", 
  RowBox[{"\[Epsilon]imfunc", "=", 
   RowBox[{
    StyleBox["Interpolation", "MR"], "[", "\[Epsilon]im", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Epsilon]Particle", "[", "lambda_", "]"}], ":=", 
    RowBox[{"Conjugate", "[", 
     RowBox[{
      RowBox[{"\[Epsilon]realfunc", "[", "lambda", "]"}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"\[Epsilon]imfunc", "[", "lambda", "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Epsilon]imfunc", "[", "\[Lambda]", "]"}], ",", 
         RowBox[{"\[Epsilon]realfunc", "[", "\[Lambda]", "]"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", "350", ",", "1200"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Red"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Lambda][nm]\>\"", ",", 
          "\"\<Re[\[Epsilon]] (Red) & Im[\[Epsilon]] (Blue)\>\""}], "}"}]}]}],
       "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"\[Epsilon]Particle", "[", "\[Lambda]", "]"}], "]"}], 
          "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"\[Epsilon]Particle", "[", "\[Lambda]", "]"}], "]"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]", ",", "350", ",", "1200"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Blue"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Lambda][nm]\>\"", ",", "\"\<Re[n] (Red) & Im[n] (Blue)\>\""}],
          "}"}]}]}], "]"}]}], "}"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.473018177064423*^9, 3.473018191214203*^9}, {
   3.473062491991147*^9, 3.473062536012376*^9}, {3.554436574008396*^9, 
   3.554436598309443*^9}, {3.5544366622289743`*^9, 3.5544368315922117`*^9}, {
   3.554436888838462*^9, 3.554436931065728*^9}, {3.554437500928031*^9, 
   3.554437528533711*^9}, {3.55443862963262*^9, 3.554438634424026*^9}, {
   3.554438680008026*^9, 3.554438692355144*^9}, 3.554439661944271*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwV13c8Ve8fAHB7lZJxiqTMEEKlzPMpykqLyoikYUfFXda93GtnXEohIWSV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         "]]}, 
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwVVnk8VO/3R/Y92YpkX0uSRMRBoaIRFZWlTcmHlGX2GZKQRI0oKVF2iVBU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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{400., 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"\[Lambda][nm]\"", TraditionalForm], 
        FormBox[
        "\"Re[\[Epsilon]] (Red) & Im[\[Epsilon]] (Blue)\"", TraditionalForm]},
      
      ImageSize->500,
      LabelStyle->Larger,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {266.6666666666667, -162.23392204684737`},
      ImageScaled[{0.5, 0.5}], {500, 309.0169943749474}], InsetBox[
     GraphicsBox[{{}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwV13c81P8fAHAtUZFUilKRkcpIU+T1aigNpQhRlAaJqLhlc4dzRiGVnVFI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         "]]}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwV13k8VN0bAHBk3wmJMkgqJClKtifZSotIUV60SQsqzModVERCQ1SUsoVS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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{400., 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"\[Lambda][nm]\"", TraditionalForm], 
        FormBox["\"Re[n] (Red) & Im[n] (Blue)\"", TraditionalForm]},
      ImageSize->500,
      LabelStyle->Larger,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {800., -162.23392204684737`},
      ImageScaled[{0.5, 0.5}], {500, 309.0169943749474}]}, {}},
  ContentSelectable->True,
  ImageSize->{1078.6666666666667`, 336.46784409369474`},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.4730181646403*^9, 3.473018192171295*^9}, 
   3.473062536593396*^9, {3.473085664854129*^9, 3.4730856853452187`*^9}, 
   3.473260864979808*^9, 3.4732801780186577`*^9, 3.473397979513631*^9, 
   3.473661723722423*^9, 3.4740436186787443`*^9, 3.485510222944957*^9, 
   3.516363031849535*^9, 3.5163634003902187`*^9, 3.5284421853601713`*^9, 
   3.5284503130790377`*^9, 3.52965501569086*^9, 3.529756394062996*^9, 
   3.5301776560038*^9, 3.5301783648910847`*^9, 3.530507311198781*^9, 
   3.531462181802874*^9, 3.532118349001801*^9, 3.532118387876156*^9, 
   3.534054740669859*^9, 3.534161455454688*^9, 3.534166794640974*^9, 
   3.535178771043283*^9, 3.5389964619197817`*^9, 3.538998098899787*^9, 
   3.538998361827409*^9, 3.541857551921183*^9, 3.542354429054636*^9, 
   3.547830744751935*^9, 3.554436538123703*^9, {3.5544365748730173`*^9, 
   3.5544365991464853`*^9}, {3.5544367021219597`*^9, 3.554436783386248*^9}, 
   3.5544368511632347`*^9, {3.554436890453136*^9, 3.5544369665045652`*^9}, 
   3.554437463620884*^9, {3.554437509013316*^9, 3.5544375294596577`*^9}, 
   3.554437577264793*^9, 3.554437838595619*^9, 3.5544385948632393`*^9, {
   3.554438653714252*^9, 3.554438698538019*^9}, 3.554439124148164*^9, 
   3.554439217533042*^9, 3.562388388195293*^9, 3.590468915572514*^9, 
   3.5918771206853647`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot Spectrum, i.e. check Mie-coefficients:  (use H2 and \"-\" in \
nParticle), ",
 StyleBox["CrossSections[w0, \[Lambda], R, nParticle, nMax]",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.532092134203248*^9, 3.532092150415887*^9}, {
   3.5323692621254673`*^9, 3.532369269507146*^9}, {3.532431389406336*^9, 
   3.532431415525949*^9}, {3.5324315517142487`*^9, 3.5324315547213697`*^9}, {
   3.533239964567643*^9, 3.533239980388461*^9}, 3.554212804533127*^9, {
   3.554280817362754*^9, 3.554280828161302*^9}, {3.554436078214307*^9, 
   3.554436094938978*^9}, {3.5544490543838263`*^9, 3.5544490583261633`*^9}, {
   3.554449575221746*^9, 3.554449583528103*^9}, {3.5544554351662607`*^9, 
   3.554455455603405*^9}, {3.5904701610807867`*^9, 3.590470170515452*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Lambda]", ",", 
       RowBox[{
        RowBox[{"CrossSections", "[", 
         RowBox[{"1000", ",", "\[Lambda]", ",", "30", ",", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"\[Epsilon]Particle", "[", "\[Lambda]", "]"}], "]"}], ",", 
          "20"}], "]"}], 
        SuperscriptBox["nm", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Lambda]", ",", "400", ",", "900", ",", "5"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CText", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CTsca", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CTabs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P1", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"CText", ",", "CTsca", ",", "CTabs"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[\(\[Sigma]\), \(ext\)]\)(black), \
\!\(\*SubscriptBox[\(\[Sigma]\), \(sca\)]\)(blue), \!\(\*SubscriptBox[\(\
\[Sigma]\), \(abs\)]\)(red)\>\"", ",", "\"\< \>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<wavelength \[Lambda][nm]\>\"", ",", "\"\<R=30nm AuNP\>\""}], 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CT2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Lambda]", ",", 
       RowBox[{
        RowBox[{"CrossSections", "[", 
         RowBox[{"1000", ",", "\[Lambda]", ",", "15", ",", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"\[Epsilon]Particle", "[", "\[Lambda]", "]"}], "]"}], ",", 
          "20"}], "]"}], 
        SuperscriptBox["nm", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Lambda]", ",", "400", ",", "900", ",", "5"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CText2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT2", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT2", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CTsca2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT2", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT2", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CTabs2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT2", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT2", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT2", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"CText2", ",", "CTsca2", ",", "CTabs2"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[\(\[Sigma]\), \(ext\)]\)(black), \
\!\(\*SubscriptBox[\(\[Sigma]\), \(sca\)]\)(blue), \!\(\*SubscriptBox[\(\
\[Sigma]\), \(abs\)]\)(red)\>\"", ",", "\"\< \>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<wavelength \[Lambda][nm]\>\"", ",", "\"\<R=15nm AuNP\>\""}], 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CT3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Rad", ",", 
       RowBox[{
        RowBox[{"CrossSections", "[", 
         RowBox[{"1000", ",", "532", ",", "Rad", ",", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"\[Epsilon]Particle", "[", "532", "]"}], "]"}], ",", 
          "50"}], "]"}], 
        SuperscriptBox["nm", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Rad", ",", "2", ",", "250", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CText3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT3", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT3", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT3", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CTsca3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT3", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT3", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT3", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CTabs3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CT3", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CT3", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CT3", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"P3", "=", 
    RowBox[{"ListLogLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"CText3", ",", "CTsca3", ",", "CTabs3"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[\(\[Sigma]\), \(ext\)]\)(black), \
\!\(\*SubscriptBox[\(\[Sigma]\), \(sca\)]\)(blue), \!\(\*SubscriptBox[\(\
\[Sigma]\), \(abs\)]\)(red)\>\"", ",", "\"\< \>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<Radius R[nm]\>\"", ",", "\"\<\[Lambda]=532nm\>\""}], 
          "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.554434092057918*^9, 3.554434160352002*^9}, {
   3.554434644670722*^9, 3.554434888381884*^9}, {3.554435076121338*^9, 
   3.554435076223119*^9}, {3.554435205318655*^9, 3.554435205709221*^9}, {
   3.55443556875708*^9, 3.554435574224936*^9}, {3.554435629632328*^9, 
   3.554435636176297*^9}, {3.5544358009402933`*^9, 3.554435819922904*^9}, 
   3.554436069450315*^9, {3.5544362898016453`*^9, 3.5544362948843946`*^9}, {
   3.554437055029204*^9, 3.5544372491959553`*^9}, {3.554437395894459*^9, 
   3.5544374395976267`*^9}, 3.554437870307502*^9, {3.554438022470228*^9, 
   3.554438050749592*^9}, {3.55444913792183*^9, 3.5544491607728367`*^9}, {
   3.554449195899*^9, 3.554449242338644*^9}, 3.5544493446597433`*^9, {
   3.554449458397213*^9, 3.5544494867957153`*^9}, {3.554455205607736*^9, 
   3.55445521453296*^9}, 3.55445540290384*^9, {3.562388815888916*^9, 
   3.562388816320958*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw10wlQFmUcx/EXyXgpfUNLoEh5OQqVUDxSYEB+xuS8iDgcaZRCxKGYBh7N
cMN7n5DQOHKYqYmCL4eg3BDXC0gIiDQo0DhyjPYqhgiYoJCRz9+d2dn5zO4+
u89+n7UKifILX8DhcMLn9/+PbIuFdOzMQNZTjtsr+sRCxE/vWDxIPhuLPS7B
6vNt5PFYmPJ9s5y1ZMTBzGI46JyUnBaHRRZTVnuCyINxuD0YtnnAjewYD02G
TUiEHVkYD9syj5paU3J3PGIkR0dMF5L5CTC+pM3z73vp+sqHExCW+v3l3cfJ
DQnoDE9xeMeFbJII47O59tEP/mUOToSD1aJ2FJCLE7FheolR83EyJwl+d/I/
Lr1I9klC57K9+noujXc2Cd+ea4+07iGPJ8FVn2yz6sTr+Sfjp1qvrfmnDWj+
yeiYnDk5u8SQ5p+MyqaW7akzbzCbC6EokoRV7TWi+4UY2uQy7uT0FnOEENa2
6m98Dy6m8YSYPjeQsCDUhLlSCMHOm6WNnKU0vhD+3oHVEUHvMnNF0FzYPb5t
x3v0vUW4vT9rf2sBOUCEgKheSd4xslAEQ+3sEu/TdH+eCGH3I3ufuNH43SKE
R6XdW5dMz58WwSvdfNjUjt6PL0aRc9PUCV9jZoEYI7y7+3LrFzIfFiPlh+zg
uowFzJliHEnxn+V0vO4nxvXo7Z+rBC+Y9WLs/PDU+kblM+opwcbZ50OiQ1PM
ThLs8JvpL+h9Qn0lkPcHnmr/4jGzUgLd12Fr5vJHqbcE2cNfefmm65n7JLD/
tN7M8dE96i+Fpa5Qt/bSCPNKKS7MDNxvqRyi9SCFk8C9JoA3yBwjhS6n3NbW
/Q6tDykyJP3VTdcGmNukWGild/8yt4/WixSPDKZ8xrtuMZvLYJRT6TS5rpcZ
Mmzcsvzvj1r/YI6QwfO7Nc2bJT3MaTIYu3U8DAm5yVwpQ+DqS7f4Qd3MgzLo
12xD30gXM1eOCe3LuOUbO5kd5ag4YvI8OPc6c4AcyalXfxx1bmcWyrGh7eeK
Un0bc54crqM3/Hgl15i75TDs37YoK62VeVqO2vkl4ixrYeYrMCbrOs9LbWYW
KPDwSuLqgxd19L8qIAiYe9x5o4k5U4Hsv3STd4zIDfPnvRwO7vJupP4K2Mzx
lup+aaD+SoSLoooVT+upvxJ38+wOeDfUUX8l5D0Kz45Tv1F/JUIz1x/7TF5L
/ZX4lXvU6ZOkGuqvRJVb3KiLuJr6q+AQ2WXmnV5F/VWo2zTxYL+2kvqr0LCr
9UxJRwX1V8HQNKb70LNy6j9/3sCj+MkqcpsKKx53Sn8PLaP+KrgMW0Yvu1BK
/dXwnCuMtBy7Sv3VuHFt9Yi5OzlCDTnnxAvTzCvUXw0Drl/t+zMl1F+NLVYq
a5MQ8qAaFZrJxj97iqm/Bm9+8PZKfy+yowblLfUtqpOXqb8GBvp/dBM5RdRf
A4umo3sONBZS//nr4TEUNVpA/TUI5Ol5amvytAYr+Klh/H351D8F3K3atfZl
Wtf/AMIvADI=
         "]]}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJw10glQlHUYx/ENFVEEbVIGGJAjGmlNQgeNFPU3KiNYouCGaGx4hIoUh7IO
cix7n4qM2qBoshrIZQiGBxIgrSAIi5CIEnKMmiyksLrILiAZ9T69M++88533
ff/zvv/P47YrNiTSgsViRU6e/16Z4zD2aHQDWeIOv/9y82Q355201z1iWjPZ
RXfYw3OpDYehG6nd37DpIdNIgkt/x88r+O1MZySBW6bx6i9+wHRvEhYrFrjf
HGxj2jsZwc8qXdj+1IJkrJPPi6vKv890SzJqLnX2fTyL2jUFUXsleQO7f2c6
LgX8vuFC34JWpm+lIF3sdspC38L0nFTEhp7Oq/em3pGKhsj12iS3e0yXpKLs
7I+f5C5oZprFh+PmoycfZOno//komis+2n2JWsMHZ8672W+y6HkDH7bX4sqX
RND6SINzRrvBM4i+LyMNHrbfbbnB+f//0+D3Iu3xN6W0v/YCPPa4XDu9sIfe
FyCzu3RdTelTpvcJkJDV4PnnRj2tJ0B4RHvZzfiXTN8QYPmb4umSPa9ofQEq
TcuPfzRiZNpKiLPmps7xhSO030Ls9XEtSO8xMR0mRBT7gPvdYTPtvxAW9kEh
vIBRpvOFuOO1iLOxle63COEkMw4k5NH7ZiGuf67QhI+/IR8ReNU83xPThpkO
EOHLivhD/Wb6vjgRfJOX3DVPDDF9SgTRw1OiY7tfkJ8IPZoqf/tl/UzrRUjZ
UO1i4D0nTzGuzwqOmu/4jGlfMb5e7WbwsXtCvmKI79r9sZTby7RCjMTC2MoL
2i7yFiPZQzba7d3J9CMxOsoTecEGmmeWBJlOU7iuwzS/nhK0d46ERywmv80S
ZN+rP8fJpnlMlGBbl+6r18vIWyNBhX4wIuE1zUO9BOfU/bzoLJo3gwTaVexg
DznNk70U1lN0V+pyGslfCqu3W/+ue9lA/lKsP9G7NJBbT/5SSL+I4dkM1ZG/
FDbj3g/Cs2vJX4p5a1y1pv23yV8Ge+07X8tNWvKX4dOtsR5TA38jfxlWRpVv
LwmtIX8ZGs9cbH3/0C3yl4FjNi3q2VBN/jIcZDc9PVpXSf4ybCj0uyoL/5X8
5dgYGHc6dmYF+ctxP56btKS5nPzl8DwbMGjMvUH+cnB2Sg5YZ1wnfzl8+i3C
3qqukb8cq2v5/JgfrpK/AmMLItMXFpeRvwLnTSGWTm2/kL8C0RbfK9ZaUisU
mKEfy65ce4X8FWiYMzB+U11K/gqskjfOSOsqIX8l2M52T7i+1J5KhLkuNyZ8
dpn8lQjqtnOeaVtM/krYOIwdO2i8RP5KfLhFWlP1vIj8lfAqXDF1dl8h+U/2
Bztv5xgLyF+F4vn6ha3W1FDh4S2fRUNe+eSvgt+Z8aRd4Xnkr0JbkH9a5omL
5K8C570rNlPacslfhZA1O2a7O1NbqWEqgsPhmBzyV4NVwXE4eecn8lfDMYL9
apontUCNxNFt8/Ydu0D+asQ3TXhvnzhP/mr4rzxuLYqnNquhCH2WqfxLQ/5H
EDl44VvHaI3fPwfyEnw=
         "]]}, 
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw10wtQVGUYxvGFQhcUXErNclAwahRGxYwRE+JRITGBVq1hQSjY3IBQwcIL
t2X37H2XvCSStxVC5LaaCysg6coSA4IiIoVihmGpkJqIhrNiapfv5cycOfOb
OXPmvPN/Py9x6iqJI4/Hk/x7//dkVwYG0/NGwvVPAv+nMANJEfYvu/PIRRno
1bm5uIz6fgYyfrh/WSYjIxP9JyO6LMnkHZlwcIb9iZDcl4niX4NvOYHslwXH
2qhAdRBZloUtfO7n5UvJnVmwTb0X/voysmc25m5veyYKJqdlQ73arOS/QbZl
4/aLSo0bjyzIwYb3Gx1Ce0eY43Ow6e1DG91byeYcHAiRJlw4S+ZJETn/tfTo
h2ShFAEW02Tv1aPzSxHVcLa96dno/FI8LD60RyV4SvPnwqM74b32smc0fy74
X+TlSRJ5QWz+XMxr9k9NaHJgniLD3bbzKVsTX2CGDIsaXAtbVzgxJ8mgskZN
6okay7xDhleP5IYXJDszn5BhyOucZHHkOPq+DGemGU2nG8cz8+Vo62h5sJ1z
ZfaTI7umOLM5mSySI6tt46M76+h9mRxOYV2ZnxS4MJfLIfE/wwt6mc/cKcep
qWUfVfjQ/9nlSEv/aWfSLEdmTw79FreqAiPNH8YhUxweJVE/pl4csk1TY2V+
w8x7OJg9xy5auG+I+nGoi7wUMhLzJ/MAB897m0O/3j9APRWw3CmJuXn6BnOA
AkGSi03eu69TXwWcpm3jZg32MmsVmDAuujAq/wr1VqC+aLaxaaibuUeBXLPT
924DXdRfidJkkU/wx53MM5W4PUd6XSRrp31QokSecqx+pJV5qxI/brto/FTQ
QvuhRJ1/d82ByibmViXW1d5yXnq8kfZFiYnNVuGpyTbmKSo46cNygqVW2h8V
rLzmOuegk8xJKuzi7CXhq+ppn1SYEvehLc1Ux3xChRjLEnPbwlo6XyqUXlkx
Yhs6zsxXo/bCc8WcsxY6b2oI/JeY6k9VM4vUUIX9lbi5pYrOnxoXRXfPhd40
M5er4X2tbEvQK+RONWZOUCSH1XzHbFcjrlr7Zs+ao3Q+NfBQRceumX6E+mvg
MLCoZtnTSuqvQcfMtb9/8LCC+mvQcHXM7fjn5dRfg/qYY3/HTicPaOD6+bsr
5grLqL8Wl6snhpzYVkr9tcgSVzSLew5Tfy0WFPlz7r5krRaW+NRSZ1UJ9dfi
+OCEjN9uHKL+Wgyvi2vaspzM02FMcVrKtapi6q/DjIjKvhgPslCH+ec3zYg2
fEv9dRh56ZHgsydF1F+HWDOv0Hs9uVWH6Uk2F35jIfXXQSe2rh5/9CD116O9
rl98tchI/fX4yrj4LdXBA9Rfj4PnRPaCsv3UX484zvpggXUf9ddjJWfb8E7f
XuqvR0Cl6x8+7mS+AT4C0/oY4R7qb8D6SZdEd4zfUH8DOtz3Hr7yuID6GxC6
c16e41pyuQH6AX287y+7qb8Bc4pNYwRist0A310r984ezqf+eVh22K3AKz8/
8B/0RAQm
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(ext\\)]\\)(black), \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(sca\\)]\\)(blue), \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(abs\\)]\\)(red)\"", TraditionalForm], 
         FormBox["\" \"", TraditionalForm]}, {
         FormBox["\"wavelength \[Lambda][nm]\"", TraditionalForm], 
         FormBox["\"R=30nm AuNP\"", TraditionalForm]}},
      LabelStyle->Larger,
      PlotRange->Automatic,
      PlotRangeClipping->True], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw10nlQlHUcx/ENRiCgNEAgRgYdVJTEFlYQcLGPoowzOsilaUYey3IspxjB
Lux976ocIogSR5AgyqX+gUKaugpORQRoKFIcpqI5BDaAgtLxfH1mnnnmPfNc
39/rt+RAagTfjMVi8f89/7syhxCXPLuv/5T6C/f/DBMilxtUeG4jdYUQrsWt
mgAn6r+EOMfJ0u1/2MU0RPhdUa47WEedJ0LhWLS1WQb1oAiJMauLToVSs7Nx
vaZ9b0UQtSwbRz+2ct4XSN2VjZ2Oz+6VBVAvzsH6yzyBhzd1Wg4Etrbc912o
v8/BttjGkpSXPzO9QIwJrpko80fqfWJsNPeb9/IGdZMYvIX8dtHf1CwJjvk1
th9/+70wCbziSn2i6qkrJOi5/AGnJ+7t/BKYv9teZ6PqpvmluG1nsSjAo5fm
l8Lyh5LS/ri7NL8UJ1tNDrXh95h2lqG5bcdszcADel4G0eVbS9bxBpmOl+HQ
yE4/d89hep8MLjxT1J2IEaZbZOi8k+iQpKYelKH8fGSjfTPdbyWHZ1v6Q0en
IVpvOdj8rDOP1/zG9C459oz4VH84/z6tvxx2kayVEfb0v7VyBM+b7z+RQfN1
yRHrw1f6VnQyPS1HpenIGCf0NvkoILtpU+T6xMT0FgXKUvpbeyOvkZcCF15N
hc2NtDF9QoH+74K89ge3kJ8CqQsyO07pLzL9RIEXU5XFUapm8lTiaea6qK8d
G5j2V2JvQ+LzDW/OkK8S4lVx+Zm5p5nWKcGzzAoar60ibyXcl4bZlnAqme5T
YmbzY1VPYBn5q3B0anm1VdNJpleowJ6obpU2FtN+UMFxbe+37yw/znSWCpVh
N7xl5sdof6gQc788UhCYz3SHCvaXlAuTs3Npv6hQJt70a8brw+SvRsXwjsyx
IQP5qzEsOlA46KAnfzX0IRadWzVa8lfjj9P1Et5KDfmr0WvipY2+UJG/Gp8Z
OM/qBpTkr4G/3LrKaVBB/hrk9c3mlk7KyV+DNVLPq6vcqGUabJ9+8GjbLhn5
a5AdcUMQvEFK/hqkbloUPfBcTP4ahAT5mJZdzCF/LW76Xi2xLcgmfy3OB89c
aVCLyF8L6/SC+vAjQvLXYnzO7JsDNVnkr0VUSUcnujPJX4uttt3JchvqBToc
49jn14V9Rf46uMQPsM+WZ5C/DgWWVU6dk1+Svw4r+i3YdVHUTTpYivsOOrYc
In8djkifmtwWU7P02DuakMY6nE7+etR+knPXeeYg+etRmh+yezSJOkuPlKJY
9ntDaeSvx9bQsx3en1J36BFaO++EpiyV/PXw8ulKdCtMIX8D2l9zlq3NTyZ/
Ayyc3b2FxUnkb4BXjyDcozaR/A3wU1lL2CYB+Rvgtn3X7vV/JpC/AXMX3nCv
Laa2MiL1FVcyvT+e/I0QouX6bGMc+RtREbL5yi1rapkRzsLhZN/0WPI3wuLz
1VftH/HJ34jcL+zylsZSTxvxEXvznsnxGPI/DNfK3IRoXQz3H7639Fk=
         "]]}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwt0glQlHUYx3HGA8hGocjEoA3BQmEmOUJWBf0pikDI6QILmkhgIIZyaOyy
LHufEmvIJUKgkUihgLTCpILgETIwGCqMOMpMOIJlongQZ9b/eWfeeec777zP
+877eZbF7Q9LmGNiYpLw5vzvyg4BKvQ3d2kXy7z+zxAB7k1GX6ngSVlXCGBM
m7/u3TIJ61EBwgozhdYtOawhhIvt7c6VXmLWBiEcy7Yl53WLWA8K8cMI70v/
3CzWLlko6b0VGCoXspZkIeD2SXFTqYB1TxYcs4832VzIZG0nQt7XVc7N3d+w
PiCCse2Rp8X1Q6xbRcgVHb9/ufkga8tsdPm/PXy0LYN1bDb2HiwrHXmVzrou
G3N2VE7ykqhNxDBMh0V0uFOHiDFSHcQ1F1BXiHHP8fuVnCSaNyqG0uf0pqoQ
ej9y8Nr9n9+La+j7DTmY+et8adwL+h+DOQh/fEEzvFPO2lqC4jTOUt5VDT0v
Qe2OuGf3T+WxTpSg3qmlZElRPs2ToM/rxXzVdCHrJgkuelyrjeGV0HwJ6oov
VPVxj7E2l8Ly4/wCu2t030WK8qr2Bb+kF7OOkmJl1x7Hh7U0TyKF1nbWGWeP
sq6WQrI+YsL55HfkIUUq/9MnJtUG1uNSTD7p2z6vIpd8ZChfc/mwh5+OtZ8M
UTOhNTZBavKS4Vz5oqeGcwrWxTI0vF/PczhI+9YqQ++xFn6RlvZrWAb76jUq
Y2c2ecoR3bhsymmG9oUrB9ezceGiItqPWDmkpybiU5XkoZFDe4fbWt9MXnVy
eBYs9an5hDz75Rhq45zmt6WSvwKbPqyTzFUeYL1CgcgTr+scb6bQPiggG49v
i+/ZxzpTgSXb+5WPZ/fSfijwx9DiI2H8JNa/KeAWln4mre8r2hcF7M4Y5d6H
9pC/EruDusw83BLIX4l7xm1SX/N48lcioP3Xwksv48hfiYe1VZXe47vJX4m1
wrNTPy+kHlQiqD1U5PFZLPmrgNYfuSm3viB/FaYHgh+IduwkfxVs7zinvJqO
IX8VGgp3LdAYo8lfhdyLSf3LFXzyV6Hy1Ny7k/FR5K/C2ImoY/sjI8lfDZ8c
vrNFdAT5q2Fvs2GrIZlH/mos0+j4N3TbyV+Nk7N2wQ3GcPJXI/FbK1XE32Hk
r4ZrQTPnrgu1pQalk2ZbMrJDyV8DvwGzqZTeEPLXIKNqenS5G7VGA7Gp80ez
rsHkrwGnw+3840VB5K/Bk7diTN+ZCCR/LaLEqzbqn39O/lqsNnf1V74OIH8t
Gq7XXl9nTp2pRd+DtYoJB3/y1+IZp67pgwA/8tfiqdlNh3nCreSvxfHV3bnu
53zJX4cVN3IeubzcQv46XHHbclW7gTpR92Yf8i71HNlM/jqYjo2Vlf3pQ/5v
7hc6hecGUg/q4NYcPbCxcRP568H1NbWKs6d20aPzp5SiksKN5K+HoD7vaLEl
tUQP95qZfCsDyF+PVTacwPb3qHv0SBZbBHR4bSB/Pazr94Wn8NeT/2HkDZUm
PRd7e/0L48LzLQ==
         "]]}, 
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw11HlQlHUcx3FkJBkZBTRBxVQ8NsI0TUiGy49guSgUKikSA7gKwkK4IAnL
sffu8+wuh5mSR4KMZqQyQQ6HK7mLFoeSrggCArEsuqLwhxam0ZhZz9dn5pln
XjPP9X3ev3k8BXu3JNrb2dklvtr/O3KbGLFlt7M9B82B/zNSjJrdc4tf1pNP
isGkDo9HHiQ/FmPr5mJeYiIZuUhfIRqSrSIfyMWCi9XtLZPIllxo54QMtZtu
cl6Zh5FKL1/ed2RZHjLhkWZ9bXMefua73omtIi/Mh3OY0Kn3FFmUD+Pd6H+G
C8imfOxRGHQnN5FdCvCttalDwCMnFOBr9x0N65aQqwugnMq6r9xBtpPAv+vc
+qJecqQEuncvuYriX88vgU9wqmGF2y2aX4I/dzXOavPuoPmlmFhuaCg23ab5
pdg66j1j6lgXzS8Fv1Nibqjr4TxbhnlthVsL3PvpehmcBfbha9oGOSfLMP8R
KxYWDdH9ZPBpOrTk4TEr5wYZFpx+8UGTgWyRoffXpb+HD9L5jnLYL24evM+3
0PeW4453e/T5KnpetBzs/sbNAafpfWRybNwJXlxrJ+dKOT6rSMkxbqJ5zXL4
7TEm+urbOT+X48qHOLs6q4X6KPCgZm3QsdCrnPkKZJxIs7f9ZKReCgzw3FYX
RRg4H1Fg8nHmSuN4LfVTYNZbaweSc37kPKKA1ZAf9/4nP1BPJeLX1Y93153l
7KdEztu1yxJGz1BfJYq7W3a3XT7FmVXi4JjI4ZJrBfVW4pm1l2FOnODco0TI
4fK5QdeOUn8Vgh9PXG0pLuXspYLthfqXmK6vaD2o8MYRZtpT/Zecc1QIKnS5
4rChhNaHCiUBE/ay+YWcW1XQ3LOlHFBrab2o4N6xbb8tnqH+akwpEfgKDqup
vxrLpjmP35ihov5q1H663au/VUH91UgNWO8WdU5O/dX4yLZmlaRaRv3VmL46
eHZAhZT6axC/ZbR+ppOE+mvgaVg6Mqc0n/prYHG8Zu0LzqP+GjyZuuj6M/tc
6q+B23Clj78lh/prwMQcTyrrzKb+Gmjf/GYg7Lf91J/B066RG+zfX1B/Bg/z
l1Vd8yaLGEwyv+deLsyi/gymmPyn113cR/0ZGGpDl59zI48weHlmsW2jNJP6
s6jyuSWNeJJB/VnwM/oybgrJCSx8y3b1rX8kov4sonM9w4Xp5GoWbRvu+WaO
7aX+LMoDg/mXJpHttHjnD8YlziOd+msRGnQ+JtLvc+qvRURNhenq9jTqr4Ut
67LRQ5xK/bW4e8h7uP+4kPprEZXkWuJgSqH+WjCnY9ktD5Kpvw6BTlGjj2aS
oUPU9VvG0g17qL8O2febPS8ok6i/DllMkVtYWyL11yH5+6LJHnPIFh0uOHg1
V+/bTf31sCbn/RXfu4v666E53B+7bSM5Wo+QGM+jJ5sF1F+PwhtWduXH5Er9
q/8hb8xq2Un99WhKNyfpJeTnejge6z7QyiMvLEThkth50p6EwH8B2AUArg==

         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(ext\\)]\\)(black), \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(sca\\)]\\)(blue), \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(abs\\)]\\)(red)\"", TraditionalForm], 
         FormBox["\" \"", TraditionalForm]}, {
         FormBox["\"wavelength \[Lambda][nm]\"", TraditionalForm], 
         FormBox["\"R=15nm AuNP\"", TraditionalForm]}},
      LabelStyle->Larger,
      PlotRange->Automatic,
      PlotRangeClipping->True], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAAeqy+mi7v/z8W7p7ZEfxBwH2e07wW
4QNAOOE3J/k6QcB6f/rBa6oGQIcgetY0sEDAyMU9d3S6CED7cS5TdU1AwJCE
A7jfXQpAWqBcutUHQMBryLi+07kLQA9PLTaBsD/Avcc67ijjDECohjHOnG4/
wC09LlS/5g1AME/yH8w8P8C28JAvGs0OQC5cXAnZET/ASamuqiWcD0A/2CWw
X+g+wFmaraEVLBBAr7dB8Oq9PsDr3CeEL4IQQGuODJl8kj7ALREo8ZrREEAc
BaVhGWg+wD9X9FxOGxFANpo0+31BPsA8MkyHDmARQE6LvadUID7AZZ2mAnug
EUAVRmEIZAQ+wNI/kgQX3RFAgSSyHCjsPcB0aKe+TxYSQNnHtBXX1T3A+Evl
CIFMEkCaAomeCMA9wL3Hh9/4fxJA/sTW0fypPcBbR78K+rASQFAVTyiykz3A
jbMJK77fEkD1RZ/zx309wK5H71J3DBNA1wUjJxlpPcBLs/FKUTcTQG34pwc5
Vj3AQi5glHJgE0C/vzHGLEU9wORqKTr9hxNAyI2P14Q1PcCdgNV6D64TQGPb
ZtilJj3ABx4EVMTSE0BhJSCYCRg9wO5txPUz9hNA+Wf1Q2YJPcBQL6AidBgU
QJKwLb+8+jzAXAgagJg5FEBREjUwTOw8wEhKjNqyWRRAb/nC82rePMBf17Ve
03gUQMusZcNW0TzAhATJygiXFECeDuSKGMU8wDtqcphgtBRAFdK0nYi5PMD8
owQh59AUQLuwNtJnrjzAY9u8vKfsFEAV+IIve6M8wDbs5t2sBxVA2pu+pJ+Y
PMDBI4QoACIVQEMth1HSjTzAbwH7hqo7FUBb7eEULIM8wH1bPzy0VBVACqVc
2dF4PMDRrM/zJG0VQCz+pt3gbjzAQyzVzwOFFUBqFkxnYWU8wN/rp3VXnBVA
+hX7s0VcPMCrEe4YJrMVQOJn68pyUzzAydSEhXXJFUBoDvWnzEo8wDbyWihL
3xVAzAQOU0BCPMCKfl4XrPQVQDulNQjJOTzAvx+bGJ0JFkD9KqNibzE8wB0h
Zk8=
         "]]}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwBAQP+/CFib1JlAgAAAC8AAAACAAAAAe03W+UZB0AW7p7ZEfxBwMjFPXd0
ughAaGkOOslnQcCQhAO4310KQHiQaIFX4UDAa8i4vtO5C0D5NiG5TIJAwL3H
Ou4o4wxALpposwA/QMAtPS5Uv+YNQMUHKWb4DUDAtvCQLxrNDkAaew5T/9A/
wEmprqolnA9AdvzGkWKUP8BZmq2hFSwQQBkpZgpBYD/A69wnhC+CEECUo1+u
ojA/wC0RKPGa0RBAdkxBq08DP8A/V/RcThsRQEwQStv21z7APDJMhw5gEUAj
UdlGja8+wGWdpgJ7oBFA/73/cAWLPsDSP5IEF90RQMyBmNWKaj7AdGinvk8W
EkA1ORInl00+wPhL5QiBTBJArI2AHFIzPsC9x4ff+H8SQPU1AfPZGj7AW0e/
CvqwEkADxpDNcwM+wI2zCSu+3xJAtbx4zLTsPcCuR+9SdwwTQHxKK1CV1j3A
S7PxSlE3E0BvKiMlVME9wEIuYJRyYBNAr9nj/jetPcDkaik6/YcTQHe9XqRf
mj3AnYDVeg+uE0BA2P2EuIg9wAceBFTE0hNAmSzBBA54PcDubcT1M/YTQATV
0p0eaD3AUC+gInQYFEBmyjuor1g9wFwIGoCYORRA9beMiZ1JPcBISozaslkU
QC/dJ9ziOj3AX9e1XtN4FEA4qRFukSw9wIQEycoIlxRADcq+JcEePcA7anKY
YLQUQGMT91mAET3A/KMEIefQFEDaY6tlzQQ9wGPbvLyn7BRAII3Rzpj4PMA2
7ObdrAcVQPbt7MHL7DzAwSOEKAAiFUDFp52sT+E8wG8B+4aqOxVA+/DM4hTW
PMB9Wz88tFQVQP0V5R0WyzzA0azP8yRtFUAGPkRAV8A8wEMs1c8DhRVATRxq
QeC1PMDf66d1V5wVQG+fFnG3qzzAqxHuGCazFUC7T6713aE8wMnUhIV1yRVA
s6kUUk+YPMA28looS98VQGN+1iUDjzzAin5eF6z0FUDmbvH774U8wL8fmxid
CRZADJKcGw59PMBoN1fj
         "]]}, 
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAAU50WIr32/z8W7p7ZEfxBwH2e07wW
4QNAfuccGJc9QcB6f/rBa6oGQIVl9jJut0DAyMU9d3S6CEAKKBJZZlxAwJCE
A7jfXQpAC+C4Tq0hQMBryLi+07kLQCaoialH/z/Avcc67ijjDEA05ITAe9s/
wC09LlS/5g1ApFNS/XrHP8C28JAvGs0OQN5yhzpJtj/ASamuqiWcD0D/ICsr
X58/wFmaraEVLBBAaFfrtmt/P8Dr3CeEL4IQQHeGJafNWD/ALREo8ZrREEBK
jhcK5TE/wD9X9FxOGxFAv19MfhcRP8A8MkyHDmARQBUkZ/tK+T7AZZ2mAnug
EUBjvcaGR+k+wNI/kgQX3RFAqhiRK3PdPsB0aKe+TxYSQLVHi+vi0T7A+Evl
CIFMEkDl1LD7vcM+wL3Hh9/4fxJAVBhYMAOyPsBbR78K+rASQD29iEu7nT7A
jbMJK77fEkClvyqoV4k+wK5H71J3DBNA3O6CJlZ3PsBLs/FKUTcTQAvIcrH6
aD7AQi5glHJgE0CSfc5J7l0+wORqKTr9hxNAtsh+icFUPsCdgNV6D64TQOWY
One+Sz7ABx4EVMTSE0B+sDvyl0E+wO5txPUz9hNAiCU6RdQ1PsBQL6AidBgU
QA5BR+PlKD7AXAgagJg5FEBNXAgv4xs+wEhKjNqyWRRA2p5XB/MPPsBf17Ve
03gUQG9Wnui9BT7AhATJygiXFEB8aSKHNP09wDtqcphgtBRAi6i/a7j1PcD8
owQh59AUQBV3d9x27j3AY9u8vKfsFEA2vv1pwuY9wDbs5t2sBxVABd9hMU/e
PcDBI4QoACIVQL++FOxE1T3AbwH7hqo7FUDnxPSCIcw9wH1bPzy0VBVA5GR0
cnfDPcDRrM/zJG0VQBDJztKouz3AQyzVzwOFFUBW9POlwrQ9wN/rp3VXnBVA
LAxp4oSuPcCrEe4YJrMVQFHCPQqJqD3AydSEhXXJFUCkAR78b6I9wDbyWihL
3xVARCEXPAWcPcCKfl4XrPQVQDBRp8lNlT3Avx+bGJ0JFkCAEaP0fo49wEqQ
a5g=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0.6931471805599453, -35.96929474125152},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& )},
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(ext\\)]\\)(black), \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(sca\\)]\\)(blue), \
\\!\\(\\*SubscriptBox[\\(\[Sigma]\\), \\(abs\\)]\\)(red)\"", TraditionalForm], 
         FormBox["\" \"", TraditionalForm]}, {
         FormBox["\"Radius R[nm]\"", TraditionalForm], 
         FormBox["\"\[Lambda]=532nm\"", TraditionalForm]}},
      FrameTicks->{{{{-36.841361487904734`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-34.538776394910684`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-32.23619130191664, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-27.631021115928547`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-36.14821430734479, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.74274919923662, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.45506712678484, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.23192357547063, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.04960201867667, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.89545133884942, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.76191994622489, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.64413691056851, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-33.84562921435074, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-33.44016410624258, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-33.1524820337908, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.92933848247659, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.74701692568263, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.59286624585537, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.45933485323085, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.34155181757447, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-31.543044121356694`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-31.13757901324853, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.84989694079675, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.626753389482538`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.444431832688586`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.290281152861326`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.156749760236803`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.03896672458042, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-29.240459028362647`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.834993920254483`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.547311847802703`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.324168296488494`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.14184673969454, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.98769605986728, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.85416466724276, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.736381631586376`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-36.841361487904734`, 
           FormBox["\"\"", TraditionalForm]}, {-34.538776394910684`, 
           FormBox["\"\"", TraditionalForm]}, {-32.23619130191664, 
           FormBox["\"\"", TraditionalForm]}, {-29.933606208922594`, 
           FormBox["\"\"", TraditionalForm]}, {-27.631021115928547`, 
           FormBox["\"\"", TraditionalForm]}, {-36.14821430734479, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.74274919923662, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.45506712678484, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.23192357547063, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.04960201867667, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.89545133884942, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.76191994622489, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.64413691056851, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-33.84562921435074, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-33.44016410624258, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-33.1524820337908, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.92933848247659, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.74701692568263, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.59286624585537, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.45933485323085, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-32.34155181757447, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-31.543044121356694`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-31.13757901324853, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.84989694079675, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.626753389482538`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.444431832688586`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.290281152861326`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.156749760236803`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-30.03896672458042, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-29.240459028362647`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.834993920254483`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.547311847802703`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.324168296488494`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.14184673969454, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.98769605986728, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.85416466724276, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.736381631586376`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      LabelStyle->Larger,
      Method->{},
      PlotRange->{{0.6931471805599453, 
       5.5093883366279774`}, {-35.96929474125152, -28.193105854831618`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0., 
          FormBox["1", TraditionalForm]}, {0.6931471805599453, 
          FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
          FormBox["5", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {2.995732273553991, 
          FormBox["20", TraditionalForm]}, {3.912023005428146, 
          FormBox["50", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {5.298317366548036, 
          FormBox["200", TraditionalForm]}, {6.214608098422191, 
          FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-36.841361487904734`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "16"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-34.538776394910684`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-32.23619130191664, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-29.933606208922594`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-27.631021115928547`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-36.14821430734479, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.74274919923662, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.45506712678484, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.23192357547063, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.04960201867667, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-34.89545133884942, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-34.76191994622489, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-34.64413691056851, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-33.84562921435074, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-33.44016410624258, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-33.1524820337908, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-32.92933848247659, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-32.74701692568263, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-32.59286624585537, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-32.45933485323085, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-32.34155181757447, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-31.543044121356694`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-31.13757901324853, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-30.84989694079675, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-30.626753389482538`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-30.444431832688586`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-30.290281152861326`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-30.156749760236803`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-30.03896672458042, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-29.240459028362647`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.834993920254483`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.547311847802703`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.324168296488494`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.14184673969454, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-27.98769605986728, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-27.85416466724276, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-27.736381631586376`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.56238844103179*^9, 3.5623888562230673`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Angular Scattering Intensity ",
 StyleBox["Test, i.e. ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "check of Multilayer-Mie coefficients \n",
 StyleBox["Luneburg Lens, compare with Figure 4. from (O.Pena, U.Pal, Comp. \
Phys. Comm. 180, (2009), 2348-2354)",
  FontSize->14]
}], "Subtitle",
 CellChangeTimes->{{3.5215555775512342`*^9, 3.521555594875887*^9}, {
  3.521557503283558*^9, 3.5215575314578533`*^9}, {3.5542023253168488`*^9, 
  3.5542023263712*^9}, {3.55428086794656*^9, 3.554280883015832*^9}, {
  3.554362442554748*^9, 3.5543624893347807`*^9}, {3.5723307236183643`*^9, 
  3.572330735730262*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Theta]Min", "=", "0.001"}], ";", 
  RowBox[{"\[Theta]Max", "=", "180"}], ";", 
  RowBox[{"d\[Theta]", "=", "0.25"}], ";", 
  RowBox[{"\[Theta]T", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"\[Pi]", " ", 
      RowBox[{"\[Theta]", "/", "180"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Theta]", ",", "\[Theta]Min", ",", "\[Theta]Max", ",", "d\[Theta]"}], 
      "}"}]}], "]"}]}], ";", 
  RowBox[{"N\[Theta]", "=", 
   RowBox[{"Length", "[", "\[Theta]T", "]"}]}], ";", 
  RowBox[{"S1", "=", 
   RowBox[{"0", " ", "\[Theta]T"}]}], ";", 
  RowBox[{"S2", "=", 
   RowBox[{"0", " ", "\[Theta]T"}]}], ";", 
  RowBox[{"S11", "=", 
   RowBox[{"0", " ", "\[Theta]T"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"L", "=", "500"}], ";", 
  RowBox[{"xL", "=", "60"}], ";", 
  RowBox[{"x", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      FractionBox[
       RowBox[{"l", " ", "xL"}], "L"], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"m", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"N", "[", 
      SqrtBox[
       RowBox[{"2", "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
            "x", "\[LeftDoubleBracket]", "l", "\[RightDoubleBracket]"}], "-", 
            
            RowBox[{"xL", "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "L"}], ")"}]}]}], ")"}], "2"], "/", 
         SuperscriptBox["xL", "2"]}]}]], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "1", ",", "L"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"AA", "=", 
   RowBox[{"abL", "[", 
    RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";", 
  RowBox[{"an", "=", 
   RowBox[{"AA", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  ";", 
  RowBox[{"bn", "=", 
   RowBox[{"AA", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
  ";", 
  RowBox[{"Nn", "=", 
   RowBox[{"AA", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
  ";", 
  RowBox[{"Nmax", "=", 
   RowBox[{"Length", "[", "an", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"\[Theta]i", "=", "1"}], ",", 
    RowBox[{"\[Theta]i", "\[LessEqual]", "N\[Theta]"}], ",", 
    RowBox[{"\[Theta]i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Theta]", "=", 
      RowBox[{
      "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
       "\[RightDoubleBracket]"}]}], ";", 
     RowBox[{"\[Pi]n\[Tau]n", "=", 
      RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
       RowBox[{"\[Theta]", ",", "Nmax"}], "]"}]}], ";", 
     RowBox[{"\[Pi]n", "=", 
      RowBox[{
      "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "1", 
       "\[RightDoubleBracket]"}]}], ";", 
     RowBox[{"\[Tau]n", "=", 
      RowBox[{
      "\[Pi]n\[Tau]n", "\[LeftDoubleBracket]", "2", 
       "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
      "S1", "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "Nmax"], 
       RowBox[{
        RowBox[{"Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
           "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
           
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{
           RowBox[{
           "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
           
           RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
         ")"}]}]}]}], ";", 
     RowBox[{
      RowBox[{
      "S2", "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "Nmax"], 
       RowBox[{
        RowBox[{"Nn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
           "an", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
           
           RowBox[{"\[Tau]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{
           RowBox[{
           "bn", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], " ", 
           
           RowBox[{"\[Pi]n", "\[LeftDoubleBracket]", 
            RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
         ")"}]}]}]}], ";", 
     RowBox[{
      RowBox[{
      "S11", "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{"180", " ", "\[Theta]"}], "\[Pi]"], ",", 
        RowBox[{"0.5", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "S1", "\[LeftDoubleBracket]", "\[Theta]i", 
              "\[RightDoubleBracket]"}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "S2", "\[LeftDoubleBracket]", "\[Theta]i", 
              "\[RightDoubleBracket]"}], "]"}], "2"]}], ")"}]}]}], 
       "}"}]}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"ListLogPlot", "[", 
    RowBox[{"S11", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Scattering\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Theta] [deg\[Degree]]\>\"", ",", "\"\<\>\""}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PCos", "=", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"3.2", "*", 
      SuperscriptBox["10", "3"], 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", " ", 
        RowBox[{"\[Pi]", "/", "180"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", "180"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}],
          ",", 
         RowBox[{
         "m", "\[LeftDoubleBracket]", "li", "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"li", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<m\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<xl\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{"P1", ",", "PCos"}], "]"}], ",", "P2"}], "}"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.521539921710382*^9, 3.521539922349125*^9}, 
   3.521540137383369*^9, {3.521543075368484*^9, 3.521543105137628*^9}, {
   3.521543200579979*^9, 3.521543233001226*^9}, {3.521543312319969*^9, 
   3.521543338918846*^9}, 3.521543372557125*^9, {3.5215457319380617`*^9, 
   3.521545841354154*^9}, {3.5215459395120277`*^9, 3.521546299983704*^9}, {
   3.521546436390168*^9, 3.521546438427196*^9}, {3.5215464745481358`*^9, 
   3.521546480833865*^9}, {3.521546528403769*^9, 3.521546532104628*^9}, {
   3.521546691740171*^9, 3.5215466923126802`*^9}, {3.521548318730534*^9, 
   3.5215486440267067`*^9}, {3.521548679988933*^9, 3.5215487503209553`*^9}, {
   3.5215487983073893`*^9, 3.5215488300140944`*^9}, {3.521549958485528*^9, 
   3.5215499642910347`*^9}, {3.521552000252885*^9, 3.5215520015459146`*^9}, {
   3.521552155551263*^9, 3.52155216223072*^9}, {3.5215522755083847`*^9, 
   3.521552310914034*^9}, {3.521557539297687*^9, 3.521557539508067*^9}, {
   3.521558166592757*^9, 3.521558191631784*^9}, 3.521558316652668*^9, {
   3.521558351726776*^9, 3.521558361151331*^9}, 3.5215648116159763`*^9, {
   3.521565559670698*^9, 3.521565621180173*^9}, {3.5215658673547564`*^9, 
   3.521565937990006*^9}, {3.5215659938550167`*^9, 3.521566012317896*^9}, {
   3.521575004175914*^9, 3.5215750251376534`*^9}, {3.521575074342011*^9, 
   3.521575116943232*^9}, {3.521576393388525*^9, 3.521576446749217*^9}, {
   3.521634528353676*^9, 3.5216345393332376`*^9}, {3.521634644465541*^9, 
   3.5216346488826838`*^9}, {3.533238529605918*^9, 3.533238535213366*^9}, {
   3.533238597414626*^9, 3.533238600338612*^9}, {3.554362505700345*^9, 
   3.554362507140531*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw1mXlcjdsXxk+SytgspE5USKkkMlSPkkqa5/k9U0qGfpmHdMgQGYpSxs7V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          "]]}}, {{}, {}, 
        {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwV1nc8Fd4bB3BFsiou7sU1rllE1jVa7qeMfDPvrIQkIRUNFSWjRAtltYWQ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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., 0.},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      Frame->True,
      FrameLabel->{{
         FormBox["\"Scattering\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"\[Theta] [deg\[Degree]]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      FrameTicks->{{{{0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0, 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
           FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.308952660644293`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.596634733096073`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.002099841204238`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.156250521031495`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.289781913656018`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {11.407564949312402`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.206072645530174`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.611537753638338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {12.89921982609012, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.122363377404328`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.304684934198283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.458835614025542`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.592367006650065`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {13.710150042306449`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {Automatic, Automatic}},
      GridLines->{None, None},
      ImageSize->450,
      LabelStyle->{Larger},
      Method->{},
      PlotRange->{{0., 179.75100000000003`}, {0., 14.953338153227472`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{Automatic, {{0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {11.512925464970229`, 
          FormBox[
           
           TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {13.815510557964274`, 
          FormBox[
           
           TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.308952660644293`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.596634733096073`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.002099841204238`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.156250521031495`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.289781913656018`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {11.407564949312402`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.206072645530174`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.611537753638338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {12.89921982609012, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.122363377404328`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.304684934198283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.458835614025542`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.592367006650065`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {13.710150042306449`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {240., -146.01052984216264`}, 
     ImageScaled[{0.5, 0.5}], {450, 278.11529493745263`}], InsetBox[
     GraphicsBox[
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw913dcze0fx/FIdnKnQreKBg2loT3O+5xTnVOdKLJu3dmyK24rK1EpySiS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        "]]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"m\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"xl\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      ImageSize->450,
      LabelStyle->{Larger},
      PlotRange->Automatic,
      PlotRangeClipping->True], {720., -146.01052984216264`}, 
     ImageScaled[{0.5, 0.5}], {450, 278.11529493745263`}]}, {}},
  ContentSelectable->True,
  ImageSize->{972., 304.0210596843253},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.521557544491338*^9, 3.521564524693906*^9, {3.521564803843656*^9, 
   3.5215648141904287`*^9}, 3.521564906512931*^9, 3.5215650403590612`*^9, 
   3.521565600089951*^9, {3.521565959553029*^9, 3.5215659734495163`*^9}, {
   3.5215750164961777`*^9, 3.521575032236844*^9}, {3.5215750985050364`*^9, 
   3.521575126396615*^9}, 3.521576468000399*^9, 3.521615004901276*^9, 
   3.521615078134366*^9, 3.521621028441462*^9, 3.521621157727475*^9, 
   3.521634280246986*^9, 3.521634549262774*^9, 3.521634658339261*^9, 
   3.521875198602157*^9, 3.5244788784612427`*^9, 3.52730284595317*^9, 
   3.527415526827351*^9, 3.5292155082228928`*^9, 3.533238522759503*^9, 
   3.533238567508582*^9, 3.554202380259066*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot Angular Basis Functions, i.e. Mie-Theory Angular Functions, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Pi]", "n"], TraditionalForm]], "None"],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"sin", "(", "\[Theta]", ")"}]], 
     RowBox[{
      SubsuperscriptBox["P", "n", "1"], "(", 
      RowBox[{"cos", "(", "\[Theta]", ")"}], ")"}]}], ",", " ", 
    RowBox[{
     SubscriptBox["\[Tau]", "n"], "=", 
     RowBox[{
      FractionBox["d", "d\[Theta]"], 
      RowBox[{
       SubsuperscriptBox["P", "n", "1"], "(", 
       RowBox[{"cos", "(", "\[Theta]", ")"}], ")"}]}]}]}], TraditionalForm]], 
  "None"]
}], "Subtitle",
 CellChangeTimes->{{3.5215555775512342`*^9, 3.521555594875887*^9}, {
  3.521557503283558*^9, 3.5215575314578533`*^9}, {3.533641731398683*^9, 
  3.5336417391826344`*^9}, {3.5542133978916187`*^9, 3.554213412138688*^9}, {
  3.572330745352648*^9, 3.572330847874687*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Nmax", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Pi]nF", "[", 
    RowBox[{"\[Theta]\[Theta]_", ",", "nn_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", "=", "\[Theta]\[Theta]"}], ",", 
       RowBox[{"n", "=", "nn"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"\[Pi]n\[Tau]n\[Theta]T", "=", 
       RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "Nmax"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{
       "\[Pi]n\[Tau]n\[Theta]T", "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
       RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Tau]nF", "[", 
    RowBox[{"\[Theta]\[Theta]_", ",", "nn_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", "=", "\[Theta]\[Theta]"}], ",", 
       RowBox[{"n", "=", "nn"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"\[Pi]n\[Tau]n\[Theta]T", "=", 
       RowBox[{"\[Pi]n\[Tau]n\[Theta]", "[", 
        RowBox[{"\[Theta]", ",", "Nmax"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{
       "\[Pi]n\[Tau]n\[Theta]T", "\[LeftDoubleBracket]", "2", 
        "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", 
       RowBox[{"n", "+", "1"}], "\[RightDoubleBracket]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PolarPlot", "[", 
       RowBox[{
        RowBox[{"\[Pi]nF", "[", 
         RowBox[{"\[Theta]", ",", "n"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Automatic", ",", "100"}], "}"}]}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", 
         RowBox[{"StringJoin", "[", 
          RowBox[{"\"\<\!\(\*SubscriptBox[\(\[Pi]\), \(n\)]\), n=\>\"", ",", 
           RowBox[{"ToString", "[", "n", "]"}]}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PolarPlot", "[", 
       RowBox[{
        RowBox[{"\[Tau]nF", "[", 
         RowBox[{"\[Theta]", ",", "n"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Automatic", ",", "100"}], "}"}]}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", 
         RowBox[{"StringJoin", "[", 
          RowBox[{
          "\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(n\)]\), n=\>\"", ",", 
           RowBox[{"ToString", "[", "n", "]"}]}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "}"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.533627119034916*^9, 3.533627442513175*^9}, {
   3.533627477129245*^9, 3.533627504592868*^9}, {3.533627568864394*^9, 
   3.533627652374281*^9}, {3.5336283458098917`*^9, 3.5336283731531973`*^9}, {
   3.533628414665784*^9, 3.533628478540043*^9}, {3.5336437009755783`*^9, 
   3.533643702189127*^9}, {3.53364567369589*^9, 3.533645678303315*^9}, {
   3.533645734975309*^9, 3.533645736461238*^9}, 3.55421339461789*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1m3c8lf///42KyCiiUtFCg4rS7qloGBklVN5ZDSGzFFkpKZQ9ykpky5b9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           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Pi]\\), \\(n\\)]\\), n=1\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {54.166666666666664`, -53.333333333333336`},
       ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0mnk01d/3/81XkkhIvRVFJSRNVGq/VJKUUCqZVSSZo0SKSlKZJZlJhsg8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           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Pi]\\), \\(n\\)]\\), n=2\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {162.5, -53.333333333333336`}, 
      ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0mnk8Vd/3/695nocbaRCKEkpEyj6VoaQMZaiQIWOIEClDUSQq3pUyj6Ei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           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Pi]\\), \\(n\\)]\\), n=3\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {270.8333333333333, -53.333333333333336`},
       ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0m3c81e///3HOEUL23qeMNFWidV2SJKuioj3eDRkpowiJBjIyGyhCQras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           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Pi]\\), \\(n\\)]\\), n=4\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {379.16666666666663`, -53.333333333333336`},
       ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0eHc81e/7/7HPSYrsZO9x4p2Kku6bpKEktCQzkVGhIRIlkoaVWTKTMrI3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           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Pi]\\), \\(n\\)]\\), n=5\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {487.5, -53.333333333333336`}, 
      ImageScaled[{0.5, 0.5}], {100., 100}]}, {InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0mnc81f/7/80GvVsaChUJJUpDWh6olFC0aIkUCpFklMrKKkoykxmysmXE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           
           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(n\\)]\\), n=1\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {54.166666666666664`, -160.}, 
      ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0mnk8lO/3/61zZ5d9KWmTQqskqTOVeIdIG0olW1kSRYuUpJBKZGvfJEpC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           
           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(n\\)]\\), n=2\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {162.5, -160.}, 
      ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0m3k41N/7/zFmsc+CEcqSkJQlqaTOES2EolKRCKnelUJ2pWjTJkv2SiGV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           
           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(n\\)]\\), n=3\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {270.8333333333333, -160.}, 
      ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0d3k81N/3v53s22wY29BCKkRF3ItUEpFKUZFKSpaIVIqSUihL1ij1lhTK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           
           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(n\\)]\\), n=4\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {379.16666666666663`, -160.}, 
      ImageScaled[{0.5, 0.5}], {100., 100}], InsetBox[
      GraphicsBox[{{{}, {}, 
         {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw0eHVY1N3zNl1LIx2bNAsoJSKewQCxsaVUEEFRDB5MFFGkxEBBCVFRUJGQ
VAn5HOmQllRQUpTu2AV/+73e6+Wf5b5m9kyeOfcs1eXMbjceLi4uRUEurv99
/r8/ffj//31/KC+S8o8JkqsympSi45BS4Rud9GUmtCKT29pRqYivIsxDdIkJ
Xd5pgROGH1BihEkdXmRC0cJdj2MRn9Gq7a+8auaYkHOTembxShFK7PZwWDXN
BL8PqasjdcpQ2Il3aWNjTGiw7zta1laJbJ1VAvmHmOBz6nCV3e0aNJDFw/df
PxNY149lLD2pR7FfDXZa/GTCmtyEJxtONaLHW3gfObQxQfHmYoIj+oYy8z3+
fatnQqnl00kdqRZkxmipeFPBhLybtDcPultR7rEtWt8IJmgEfZ47k96OVib1
vVqTwoR1D9QfMmw70UrXhM0+8UzgtaLFFEr/RD9NYiJEHjNhW49vF/P0L/Si
qfOY9TUmSNz88y1iZQ/aW5UXOXKGCckh7kMS0r0ob2SgbPwoR/7u2pTdRC8y
OeiULbqRCSZ7C4rGk/vRDeE20DBmQvmary8MgwbQraPs03F0JjjEnnm+dOQ3
Om7OvPqaiwmM/vM1/JJ/UElWuujKLD1gvWCR19sPo4lsAd1Nz/RgrS53g5PW
CGI/MFzKC9aDQIUvs5HTI8i3KFKh1kEPbuwYeMMIGkO9u1DMqY168O4378x7
jXFEvL4PZ/T0wKy2IAgHjyPF1e4xrxZ14YOO0vvnthNIOZr7bcsvXUie8Z09
8nYCFfg73ztbpgv8Kg8iF/kn0bUpwfLv93XB3yqg6OnnSWRWSplPUNaF9zre
w4Oq04hOrymkL+nA78bOrE/npxHRMRgq0aUDj6vDx5ll0+hM2p3Ilc90IGpE
2X7cYwYtaHTfO3FNB+6vsvRe+WkGca0x4ZV21AHfFYUd//hn0VutCvZHeR1Q
8BmWYsbNogrTyw4fp7UhNeaL9Y2BWbT25/JvnQZtkNj7JcJWfw71Mm8fPx+s
DXXnPs5o5s4h0fc7qp6Na8HFJP2Cy/nz6EVDWa1gmRYk9was62PPI5WHzkot
MVpQ4eV8aNvaBbRfSUHg7Xot0JlJ82JlLyD70mfn0mS1QPGlXpbJ6AKqsZvJ
Iw9qgtC+TsZe9UV0YbEgffMdTfiW2IrU7y6iU9x223kdNSHSeA3v18+L6P7E
zzf6epqwhz9WCw0vIn1q2IavLA24GXuB67ICC1m7fn3TWaUBBWKVs97rWeia
vPORY9EaMBa7/5HOSRZSljFbOuquAT+lpi4/uc9C7nP2qyu4NUDnSvR6vyYW
es+rSzKuVYeuNSKssQkW8jxjoKsaow5XMzvf8YizkQj7+drbbupw7j/zwExN
Nnp5IPL3aUN1aCf3dy2uY6NokcXWtkUGzIuEMFr3sFHYhqufy0sY4JEw1Lf+
OBuJ3rq8de09BtwLZn41v8BGS4yF1asPMIC0iS/x4y02+l39ED6TGXD869TB
T/fYiJ7sSqn5TYfYh4HjZk/YKCZrKfrEezpo7g14tCqOjebjD5yPuECHppua
IQkv2OjAaMG5nZZ0UNhntzo0no2SXnx2fcpLB5fLBZq/nrPRtICa/LVKGpCO
6y+/jGUjZ7syp6l7NHi5+c3NugiOPelMUe69NEi69+Cpyx02qnz5k/VGgQYZ
An/3HPJjo86zSODvDyocj/FpSD/LRt8NXglXvqBCS0y38/HDbGQ+lTJgfYwK
jS8mjl/cykYfDQtvuGlSIXA50afbmI3wu4HPGn8p4EQcXf1SmY2sNjYFhqVQ
wNtE4vrHfyxEIgrKorwoQMhsMCN3s9CM637P7YYU+CPpfKGVYKGnzMuVB3vJ
4COTeqYrloVcUsq2nHEjA6k/6PIqHxa6vVN4Y8+AGnSc9BJt3MpC9r2qr3Lc
1WC9C6M4n8xCKaLuh++6q0JFMzvTg1hEVx2oqdEDKlBa1VWjfWcRHbl1zkrO
TQW2a6ytN9y7iOZL0zafPaIMY8Prvop1LaDkb42V+zqVIDDG4XPPswUkrp+Z
mn9ICVZSeG+zHBfQXHxSp4KdIrDqTQXn6+fR0meancJXBdDJ4Gr4HjiPXk7U
+by1VoDJe/33edfMo6dh7evurJGHRtmSu5SoOaRTuGpjraosnBK2jX9lNIui
2s1rvz5bAepBhe3aHTPoWatSTyB5BYzTM2P3XJ9BT6UemVpQZMCaXP34MTGN
7CTTU3nJUnDxrMhaHo0p5E4PjrZ8JgkyEZtaq3Mn0fLZbVY7VCXhRFjr8U1b
J1FxWnQNj6k4+KteC9/lPoGi+JXnVXREYHfycStRoTGUc9rSK19DGM4xxI4q
k0ZRQ15MtyVdCFQMkn3ThUfQ0dCcGWEVAfiid//RrYW/SJdPdcZXjAc0I2y4
LycMoK+5VOezQ1MIxYdrbnfoQI+meVRu/55AfFvVtzq3taJo+tmG8xVjyCVU
dfzI9maUmn51myfxG0m48RX4k+vRNsSt4Mlbh3Y+u2HUGZWDXjWdSApq/U1Y
reIN0j7XQMw/NQtlEkNE4GWnwb+e3wi7NqGA2VdjhGVWp/t/p1uJKq/SMevM
KaK8Zva7f0AnUXFB/Pe9wyxincWmIxP/+ojlmJur6Sv58eB6mXlX/gki69zG
KxQFAaxh/mK3RNsEkZPBdUJqWQCLpNe2zCdPElg04denMiGs9Lv5ieeBaUJB
SOxw6BZRXI5oElIFc0RoROmKzjtSWL/Ix33lh2WCkczQLJqRwvS7e5uuRv8j
FA+JhMw7S2O3P48MKtdx4RLf5vadBjI45JFvFg+DG2dceb7Lo3wFNhHdmRc5
yYOrLQ1z7Jrk8SuHlMbKpwJ403JZ/7qVCnjM9Yo9S1oQZzMHk+zvKWA1984b
e0IE8d+uerKctSJ+skuF4n5BCGs1cCW6Jyth1kpC6I2dCH5o4sfbu1UVl+q8
XWoTEsd18haFnbGqeH/un1ZfP3HMv4rCO/RXFb/rk3vOOyuOV8UGqJsFquG+
tK7ktz0S2GoDl/XpDDLe5/M+Z+iHJE4Ukq15OEzBGUc84tmp0hhZnPkQJEHF
GrNBd9YOc+K8qvChbyUVr6r+sXK9jgzukAlw/PYfFd/4yx35KFEGh6/jN7k8
RcXn7nfwc0evwNe7yDFxUjSsHWRNoTavwEezHE6pG9BwyIaU2nFJWdw4u/uU
kwcNP3f58/tRkCwmTuXGuTTRcNC7RvenZ+XwwesvhR4P0/DpBA2f4SQ5LPVt
b7Q2Px1nD33f0NIjh8vPm06eMaZjNf2rLqf2yGNFT1v183fo+GMV348DBgp4
7brKNc+f0/HIqRIVXTcFXGrq8kgni44V1C533oxRwK+MvQMd2uhYwH7AJ4dX
EXfKeszRlRm44mhDb1edImZ9XvQHHQYu080eu8uthL/voTbkrWZg262d/Kmr
lPC7t3MDFXsYuD1B4fDKR0o4Km9LveMRBo6vrcgKL1LCfnrni3ecYmDDtFWm
ByeUsEFD+ubtNxl4962tCuLblTFoq2jbhzFwRnFK6vxlZex2hP2+NJKBWY9d
fqDXyvjPVT7pB88Y2HHL8a3dDcr4erltSO5rBr6qmP+6g62MnyK0b30aA1/L
C36uramCjarS83RyGNi0wGS4epcKfmtZyOudz8Crc/w3E5dVcLVpi5/yFwYW
3/Dch/ulCvb9nH6LUcbAi63b1zyoVMEJn2xP3Kti4Kz9Uy4nxlVw9Mrv9w/V
cvy7kvMlVE4V27m3OgQ2MLCV6CP9SQtVfCCjx1T2GwN3dvkGxR1RxbuMau4L
tDDwiWiv9NAAVVx+JKzDvpWBH1gHPfr4RhXL7jZ+IN3GwFMpVCqtShVr/R3X
1+dgz9PDOyuGVPFizbJ5Gkd/aoBb9a2oGn7GTDB/xDmvtuvfHUJPDd88rJ3f
ybFnM6z2RnSbGpba0bDrXiMDf3lt63f3pBoW+dQQnljHwGsjjfQgWA2zN2xV
Ynxl4CNdZ77SEtWwjLvVHZEKBh78GHTb6Isa/piRfCytmIE3P9OsSexQw7nC
k79qCxm4qbTD2HlKDavy7L13KpeBT5YVbXUgkbGxbOpyUBYDl0qHvI6lkfHU
Hq9yaioDf5g+/VPVnIy3LzzxX8Opj7/Dgce/dpBxZndmZSOnfpZXf57tcSVj
ud+VaOgxA2+1dFWiXSLjSKprUMA9Bk65Ibnx2R0ylhe7bPP8Nqe/dKYT9j0j
Y0aEt85aX068fEKL1ulkrMlF7XI4z8Bcp0Dg3BcyvlGXJvPPnRNvbfTDxgYy
9jr30k/DiYG/jat7newmY+fBhvZGO049hRW9zMbJOH63YyefNQPvetlyevUy
GUvYv9z82ZyB0+l+mh/4Kfhp6LpOth4Dq/AUsAdJFOz8YOlwCZnj317MzJai
YAOnlqgV0gz8c7TDWF6egteZ9uwe5WVgtPTgvpQKBdcl7XXcPUPHUm2vCl9S
KDjytHeg1QAdV+XJWVcxKDhT/V5iQQsd9x82Tg3SomD2itkHJWV0LO4fcb1D
l4JvfZih2X+g450W1M1F+hQ8BhWrryfSsfYBldh1Kym4SCY8c2UEHa/8jyG6
04iC+ST2ePvcpOMNCmuMpowp2L/595EtZ+m4Jr4kWceUgoUXZ10znOjYTvXJ
ihkO/iM/4p68hY6TlqYldptRMFfrpL25GR2zPjzeYMXBRd97mY50Ot60Nu1g
EUff8dWmbysk6Fju8BDrmwkFR29bt/HYIg1HSd3ovMSxd2v7nQtb+2n4eigj
I3UVBW+Qu3S8uo6Gv2xR1vc2pOBn8d+k+nNpeAW/iUQlk4L3TA1din5Fwy3H
v0m/16Hg1IArz/6E0fCBoolFhiYFZz9PCGrxoWHnGLW7OnQKXp00bHHUmYbf
iIc8JNQ4+bfXLg21pmFP7X+tvYoc/cGrBnv1aThObJL5ZAUF91KsQwplabia
/7JHuzgFD3yr23mll4pjno+PCPNQcEOnRV9NJQc31g+MzZDx13PHPpa9p2Lt
9xKJgwOc/gjUvJFyhYrLBfsuGJSRMW/2z9TYw1RcUUOsuZZNxndVr4Yab6Ri
0oSf9O94Mv4FOc3uolTMLbY5XfwKGTvsjbrDN07BGhv2u3w9RsbvtzZe39nE
yVuVA9drzn2QMmEQ01EUztxn66SSyfhFgsvZOE6fOCVEksQ/quFk8iulk5y+
nDSJstwQpYZ93jgnjeWRMX9Yb8/pS2rY/nCpuMgqMr73TXYuwUQNnxUXKm5U
UMO1LOe4169Ucdt1tv9/1co43iOsy3eHCk4PjHO94aeMr0TNLNqSVbC3qKq6
rJEyfiLszys/pozjVFasG4hSwlcOW/Vk31HGFx+atPkfVsTO30X3qeUqYeEz
Hp+ufJfDnp3++z73K2C3wZKB2BA53MGuOST/RgGH7+2wumImh/1cZ/kD3RWw
eml57NWHsvhOkOOvN/3yWDW8OGx40wrsXGN4k9kqh0NW59w5miiFvQI8E7oe
rMAx824P5POEsN6kv+XW7+K4bWF5tbGsEJ6V/rtWXl8c75gYbXh0VhA/2pv8
9JWfGA7sTXRapSWA1z5HJGmyKF5XWlgdHMuLjWSqL7XtFMYl5xJT8vSXiNW7
VW58vcaLx58NTvhMsoj3KfwUGsGDyafKTF0/LhKb/ipSH/zjxnqzUyLsjfME
GjvS8/UaFxbve8q/9uwUcUHuSGP3r0Xil8HqhpdqfURkoE0lu3aYeGzQXXGy
uZvgk610r038QzjI8tsGkX8SScv6r8OuDBAuj+UT2tRaiH/JZ9xM1X4RuX/O
VTn2ZhA+R632lAbnEaaZdCy6pRO5rV0SrLw1gO43/9wUcnkWbe+4fbLlMQ8s
NzvhAZs5JKLYOc7ezwtHfny4sygzj56r8n78LscHyU8DP5okLqCbcbrJyZH8
8E7WyT4imbPH8MxPzN8TguOt3UuhNG4wHJX4e9JTHHJ1qRIvLnBDFi3J9TJD
AkwN0ndfrOQGhY+kg79/SAD8tJtx9+SBvrvxv/sTJWHxdKWayQtecLm32vq+
pDQseL+yKf3KDyeKRx/ENK4ALaZ8T7ioAAR7+Zxp15KFiOCI+BVbBUAl/KJZ
3HVZkJDeYWdRIgA2XJc1k7TkQG5z1D3BN4JgInokLfSCPNy/Wy7l90MQWMGp
Q28r5MFE7V5osqQQ1LL7UsyUFOBFyIGPdB8hsCJ5Vj7NV4BY0Zvmj/WFwcYF
XsKcInCdXtiad0gYTqnGqD7bqATXl8p2Rt4Shgsaw3EHw5XgnRyP3PkmYXhP
P27xXUsZrva4f2hxFYFbP69/ad6pAhXygnJFASLwaWw1ueOJCjysT7l8IkEE
rAc9pbV/qoCYWHT+2E8RiLN70hHnqQo7HV6UTtuQYKuL/VTiVTVQvSIQkXeE
BFuWXK5tK1aD4cDVAmKXSKDhn2clLEKGujDNpJG7JLhFz37RvpMMiei0ovNL
ErjVrePJjyCDDMWA90gOCUir/jW/ayNDxhIXbaaMBCM427ZJjAL89Mfmv/pJ
UPnw0KDDTgrMuj+eMZ8iQfCeD0bHzlBg3K77lP4/ElRzfw8duUeBUUWX14Sw
KOyfLvk8m0oBkmP2xzFpUYh/9urF9a8UKN/LU4qVRGHsbB8pgLOnOgT3cJlQ
ReFw+Lof/EJUuN1snLJDQxT8TxdO8qhTIWdmWVZSRxSkGQ3GV6yowPbcHHtV
TxRsy3aGnXSiwsO+mdePmKLgeDb0d+MlKoQJJGTYc3Da6j3mmY84e3Guv1WT
Luf8GaHLgmlUEOrW/vtPSxRSW+NfNpRTweS+77Zehihk/cj5INFNhc70i3I3
yKJgLxOShxeo4GIswduuIApJH2Q/9UrRIC6Vr2NcUhR8VeQKL2rTwPpS4Zkq
QVEYvCj+6yrQYNZeLdFjiQSCZ/abju2nwYOUA+61EyToukXrqj9Fg/GlkvfL
fSSo3Xl3gXyTBs22n2+xW0hgF/7i/ffHNJhO8ZiuKidBIslZjzeZBvS3EWqn
P5JgwqziRWQhDV6MBukMJJLgbfnf9Q8baHCsqHmr+SMS5Mz1bJ/vpUH4L8Mv
J/xIYJr9m7t8hgaT/yy/XTnJOT/MLmFJgA4FvW7tZ/aSYMnnpV+sPB0O8b0x
2GZJAp2jd3ufa9LhUch6vwoS5zyW6rP2TXSYzv154syECNwZOZwmtpcOp7cX
BJFaRMDY+GZe4lE6JNksn3iRKwLJYU/04r3o8EFtQ/LKpyLwXk7sv39X6HA4
z2us6JoIXAlL58eBdPikdKX3gLMIpNh8cOgJp4PhWyvLaUsR2CBDzLg9pcNa
gz35sSoiYF/VeXDLazrUhuQzdi8Kg1vxU4n77+nAs9C0WblVGEoEed8ZfeLg
lRL/FjOFweNA9GczTIeHimUaM3eFwWHeqz+mnA7nN/G9EfMQhjk7tSLHWjq0
0/Z6bbYShjt7GhZ8v9HB7Xfo+SRFjv7rTatZ7XT4bB6RbjwhBBnv6vVbuzj+
xVrqjZYLQRtyjZDspcPHR9zj7XFCMLf/rvqbATo8e9koyj4vBF67/BNi/tBB
YbY/+qCNEHyky7f/HaKD1fC17CklIXhuV/fgyQgdmg9n+zWMCMKnF83PXozS
oaxoI2OWEISqV7w/+MfocFJ4f71buCBsE+nVKOfIDTSj/253E4SaGe6wec73
z/ncOvZ8tSBsf5fcFzNMh6IHj9OdSIJQGqFMT/tLB43hho1hnQIgd7LPctUg
J/7hOzH67wVgQnLCQLOfDrtGtuhvviEAqe6358O66RC38pnfj10C8Kd/Xaxr
Jx108azkGEUApJVkKcltdEjTv+F+a5wf3vDYP3JtooOn44JIHMEP2zbk8d+t
oUOL6t3b6B4/RJtYhmly8l3R8c7Vy5EfUpo3ghGnHguUn0ZMHX64GHoXpXPq
9Us3JdBvjg/KK5kpz9LpQGqeXx5+wAf5vXc965/RIfdl/3YJJz7oKDBTWBFJ
h5Lzs+eatPgg2500UBnK0cc3Y3YSvBBdWFgR9h8dJhr+NoiH8kJ60mr7GA86
WPZybby+lxdOi4kLKDvSoYM4vsl3kAfKi/yaL1hx8KKBqHQmD7jQzKN2G3H8
F93qe/wqD6iTA7JeMjjxj02XHxLjAZVCk6Px/Jz6uTzmr9Pnhu5zr27Tv9Dg
8K1McWKWCwjs/T0ljQbuM+sehhZyQRbboCk1lgaHujYeLtrOBe92b49T+I8G
S0V9zFUty6hQIMHshRoNIgwKeB4eW0bX8C+lGUEaCG9qqO6eXEKGq7JmSsep
8ObrNY/TEkto7gBLpAtz5lFDVvP8Zhaaub63b8GeCofjZy48bV1EY6ZNTwCo
0PKEVet+fBFle4vGCXHmZa9uG394wALS/M4bSR6hQKNPRdBQ8Rzi32vRdf0i
BbKFf3Y+2juNdvw6WnVpSA2kPEZmp/5OoaXYooztb9VgZWb4tZ/+U0gpMmKV
7TE1iNv0a//ZjElEtVI4kN+uCrOmBYeUFSZQqfirUZynAss7XtpezhpH174U
m/47qwLCFuP+D3aOo2j7mBPeGirgPkFP5F4xhu4zaan895WhjVLxgEtqGEmx
yOWkA0oQR6ndfmPvEIomFewzElSCpAkyb0X0XzTJFfYy/oMiCNZ6slq1/6Bl
Se9tDjKKELzxh5Hk0QFEEdce9C+RB6XTkMo07kYfZypvJgrKwr+L7kcyon6h
c1oz37elrgDDE5eA/u8nyt4T9vzI7hUQac/4IZnUib4rGl5qjZEBuwChAwdX
tyMNI+UuW3Vp6OjdY96n1YaYrKH22DIpGJMre56g1oqYLqcbvNylIFRcditL
sRk155favHwjCf31BlOX7RrQIaOogys2iUMdVa9e/XQ9ehNVEOJ0QwwO+wjY
danUIRnX4IKmPFGI+eRGky6pRokrdus6MTnvOF+H3y+tKpRXl3npqpsIxPoV
b90YXYHeZ+r+/fFUGOycI5vIcaXI+1VxrJ+wEEwZytYThiXoz8Fkpa/rBCEm
JiFvU30R8jMYWHPeWwAmV5b3bDPCyMpcQbangw8sTv973DPyGangNpOPYnww
8dRl9NbdfPT8P81SNuKF3QqlKTvkPiKZ2nTm+EtuOM/7q+94UzYS3++wg7+I
C9Jb+y0+pWai1Uqndit9+Ye2BJx8fiwxHcn+N2+ntrSEPtY77VXwSUVRD7dd
UV/NRh6UrZtiOpKQ8Oi2rHXnF1G+rtJU0NXXyCV2y8il5Hk0tvnjy4tnX6AA
KZ9tYcozqLft+FhGSCy6mfP84q3dU6jTW+JA5bvHKGh/Vlpr8ATavd5j082N
D1GdzSEhw2tjaIuxP2NjWhhq6g4hv/k9hIw0hNfXlN5Gfxobv6+yG0SK50Iu
Kr7wQykrj12fyO1D49NqIzjGB/GEZ+zkpnWjVwuF15zmT6KS6cK13DLfkSnl
Cboj44TQ/qO+yt1N6M+ut0bzSTYoNOCrsopTJXq/9HZ0MJ2Krgt6xO4fzUHe
2Y2vBoqG1h1hfJuVuBxLSJDebdjvZoY+UYb37G7+Qgj2K300Ut6DGtEWtQuq
9cSadzP5msuu6OvjOEb+zlbCUiTjX6vaOTRpOx1i4d9FDNm4qiWpX0Ef3jLs
Ott6CN+R5Nu+ITeRtaV9/7WzA0TwsHyj2FQwkpCqMDkq+Jd4WZ3zIVzzAZqx
2rnkETdC6PrmvE/YEYGex2/1s4geJx684XK5PhqFYpbu3zR1nSRyTBIHmwWe
IZEybe/HetOE3r+HF1Or45FI11arbTMzhHfik46OugQ0fcWgd/PnOWJDgF1I
scRb1HLy6b5rAQuEL1q2NL6TjORVzj3t2MIiZN/f5p21eo/Cj+oU20kuETVX
uFV+R2eg3uGTnU3flgnnoAIblJ6FRiy/8Gpv48IpZRrKacafkFydXySvOA/m
VZ+3v/YyD90ZemAtOcqD+xeaf2ozP6Nt9HqPazW8uF+pVmDtti9ok0NPokMo
Py5/kccQPlqOrM7/6nJgCeFs16wWLuFKdDhet/55szCOzTDwSC2sQvC7gCHy
XgQPaOx88XF3LVJdH3nJ5LAo3sad3WQo1oR+ut1VoWZL4HfH29s95b6h8apE
2okNktgy3uajkEYzOkr+2bo6RRKnvLHKpx9sRWvYx6cMfKVwgOvB0L/8P5Bp
4W9DNVkZTNVgO5F0O9Gz9rc8it4yWImnYsJiXxdiSZ67dLteBh9R2Xp0k+Mv
RH15K+9tyAqMeTv/+v/oQWfdfvjVTctiG/M/xcdu9iLxpYE14jvk8CpNX5NQ
nT70Sn3176TXcth7/tKzi/79KEVhm9zoPnl8wsLWpn7zINKXf8DtlqKAXVuW
ogr+DSIDqcgD1lyK2NZk/kncpz+o/16g3rk9itijaO/6FYZDaLPrOe6YOUXc
d2lUPsV4FLn3ZzvOmyrjN1171p7fNInKT5c9YN1XxSdHMvp50ibR92SHqyda
VfF/f6RfGctPobTp+H3Lqmr4vtvRNa5DUygz7IxM5Fs1/G9VtY9VzAySqM4q
tcoi41usdekGgrOI8eiAVOYUGeswZ6Pv/jeLLruvNI9TpGBSqcK/67vm0MuK
uU1lByh4rNMp8pboAir6sfT2Vi0FF1t5y1v4LqDlEwdf8w1x9F8/OKI/vICo
DyvoJEEqzozhy0z9uog2hMU8T7Sk4ouWtrF77rPRcrGLNzuBitcWRLQxuZZQ
tUuZQeRnKla3CF4QO7eE3KV96lObqZj2vtS3ZPcyEuIhrXHko2HDm1lFCSJc
sP9z0p+nDjS8vMc247oNF9yn3lNuPUfDjIcn11kEcEGEKtdmnyAa7oh96LZl
iQu2+ERwfU+n4Zft6jIR5tww7py9O76EhoMdawLTfLhBQs5dt7KVhi0v1TVv
GOGGli6PNRZsGi5J4M7N0eIB0som1wAxOq5b6XF+wJUHjphKLOqp0fG2Ww/O
nG/ngfN2HeExlnRs3HHrQ4kML4jEaWU7b6PjAIcbHcXbeYGcWRNww56O7Usq
vnzAvJBf15Hx/T867tDMC41f4IW0t5JOK/zp+E/WubWaq/hgoc1yb1IYHZfa
Kp2biOcD1q2vvL/j6fhE3kZeZjsffDc7ZH4/mY73myvFTUjww/ke05yH2XR8
ivpKmc+XH0pXrsl7V0LHXPMbKbYZ/BBhozxWWE3Hm8J/neIf4Ifu+NIvzEY6
dl5/OspYSQAE3r+Tm2ul46QrspaN2wWAJS7VptRJxwP/nZlv5/DNAwErZqO6
6di7IcfTJksAdFITj5/rp2Nzea61cv0CkHQrRD1hkI6pilel18sJwpfXB41X
DtFx79r4p2XWgnDz5PUYhRE6vhp/Puz5BUF4mm7mZj9Kxwa01KiKREFoCA5/
M8vBPMZ81yy/CcLjaPcrIxwsEXtwcYFbCKp3ubDXcTCaGWtZ0BeCph/TdkPD
dNwjn9K12kEI2CP2iZN/6Vhg3frezEAh8ITHGvs4/kTxnS9wzRCCp6OeJBmO
v7tWrd1s810I7ocdva/Hiad6s6LnIT5h6CXlTcX/oONjPwwkH+sJQ7/HeT9v
Tj5800O1F/YIQzJlnV98Ax0XRO5Iv35FGN6evbVJj5PPCsHxBNoLYfA/fEBn
BSffp4I9JLpLhCHl/uU7hwroeE+O57+cQWEo/L7zKzuLjo/IPQ2LI4lAbUH3
vuV3dKz0kmh5xBQBrqtNj5059W2ZmeKP3CECflpHedWe0LET6tkS5yUCrOOH
ZC05/fCxebLr7V0RIM/Lbyu4wcHOJMH8ChHofjsLne6cfIR7WuT1iUCAsqPi
//rtxglerrR/IoDMBLbe5vTjnR0TBQ8VOfvl89yzI5x+Vdpk1XdsFQkatF/p
5OrTMVNCbZKyhQSdvHZqfzj9HTLMfbr4CAkiXiTPXhOnY6+Zgf7NF0hQcWHU
9dISDU+KXZxPDSXB8zsvlNuHaPjkipDqJ3EkGI9Z5z/XTsMHdB12ub0nQY3t
T71b5TScYXv+rAwmwcI7VptvNg2D0Qj5eR0JvFI6Nva/oGG39WlO/F0kcDkZ
Yvw5jIZNqgKMNgyR4M/+prP8l2i4WXz/h31zJHAyXVNe6ELDTxo3CazhEQXW
+Ijw32003OXTtWOEJAq95iUSwaY0THq7uvzUClGYIhlmR5Np+OsbWmaOsig0
sle3koVonG3JxrmUKgqHjp93Uh6n4h2mezSiNUTh2/FJg7utVHyGX/Wcvo4o
+H3avPZCIRVbe1dk3NQThdtHfP5r5cyvI2eG3f/3+0Wvyc/ajFAqdnb8SHbm
4OuwxVrgLBWriMqc/6UrCgvjNe3Ne6m41LKCT0FbFCJXVodRzanY6ml8KI86
x/6unuN/Vag43OJecRxZFFSLB71XclHx0UfFvr8VOP6WdhXP9VDwiZmuB52S
HP2mvpPrSilY6rrA4DVBUXBbMPQXeEPBFdeEL5WxSZAnyEe3C+bM50M3NuaM
k+Bo7LOz5BMUfL9nyHlzLwlUBUzvnbelYDHyt4Fr30hwW/rPq63aFHwzdEB4
bwkJtiRmdyYLUTCUyPBVZpJA/1J9i1YdGUfx+uUE3yEB99DqJIHNZDy/aUKv
3ocEzfY/NyrwknG9iRr7vTMJRHedtdv4WQ1vf7K6ZJUeCUYo61tm9NXwX426
qUZJEvBHR526MaCKT+xNHOSfFoEMduN7gzhVbFw4a0L+IALFYbdKBIRU8ZJU
/jreSBG4W+zy16hABXNL+p32OS8CattK3B6cUcH+RvqbubRFoDW1Y1tPkzJe
ZTSZ/iRAGEKu8paaPVLClBmBtd8OcO5zve5uppUSph2IeRalLQw/TWYyPEYV
scPkyqkPFUIwqvkmssBaEXe8bHyLZgSBSWLU6I7JY4HFUwVuggKQZRG4vo4q
i196HtNJK+eHNQp3K8uqV2DlknDx94H8sGLKtsDaZwXW9R6d/87FDx3LfTZ/
y2RwafJ2p4l+XvjryWMl7CaNrftLUlK8uYFtb5o0oSqBlRY/na4mc0Ni8tEb
7m7i2DFg39n3VVxQfcfNZUOKGPb/3cT8qsIFiVqRchtWi+KCA3mzrGNLaNxZ
wpdlK4z/UvUZhlvm0OxtpTTKIV4ctJ/t6+07i1ghWyZConlw3zramf9SZtDT
Zz0HM9q58e26nXYE/zTafIL8edchLnx8g1zFWNw4uiTwvqw9ZZH4hFxf+jf0
oLoF52NfjEaIY6Pfam5UtxN1JupFkNeDLrhs9zpysIsY/PdOYWa0H7kYjxzf
d6GbQOW6fsnUP0it6PmNy7IDxL6+8JvZN8ZQetqKFoNrY8TOUG8jPalZ9DjC
8OT42QUi5YKbyEEzbmjYVSzmm7pIXJDnHbq1wA17Jc6k2g6xiEiJmzZVeTyw
zbrtoP/JZeKEGNf2e2v4QN/S+bhqPjdOOfLf7DZ9QbgXePjoux8CuHZZMfdJ
tyjElmgoXr0piAPqbI69fygGr49uEovUEsL1x254B64Xh3NeAf/d9RHG9xtk
y52eSYCy0iuRYSlRrPqov0WSLgX5WUZBj95I4kD+hsftb2VgaEned1ubLN6h
2F46o6IA/wLuUq4z5DDMXFybd1ABeN5/UL1yVg4Pjy7v/PhIAbiUc0vLBOVx
x7NY7f2CiuDnu8HipJECjto8sJqvXxFMS5pvRfoq4dVvRAQ1LivDRoUPoyYl
SvhgjMDM4BtlOGmyZfdFEofnXTtk2tSsDLI8R780Rinj3Df+LkoGKiBkXZ2d
kKaCl09nNTi1qoBsjG74tRI1PBqgd0h9WRX63/sWsfnIWCVPKUmYrAZKVs7R
0xvJ+Oqd1xdISA3sWzac3FhMxoY1a8nHfdXgfrG/9QNHClZRM3I5M6wGhuS9
7g+uULDc+lPqZgJkMPzRabghioIptr/2KZHJUPjZgL+gkYJ3EEJBq3aQQVd0
I3fHBipW9bp2/208GW5efJC84zAVt8juG7bNJoNng0ruqStU3FX9KkygjAyL
7kXXXryn4oSb5tKNA2Qw8kpeyKqk4vTeUJvuGTJ8qAl2OdVLxQ+xgaEADwUe
hayNLZel4fIUtyffxSlQF34OPPQ578RHoU+xKygAmaeuJVnTMH1Ubv9fRQqI
FDmsD3XmvAtyuXHlahTQtc/wF75Aw8fKSwqN6BRQbdI31LhLwxq7c4f1NSmw
bdXoxp+vOLzwboFzrg4FZgVO5Rrl0fDVG092NjEpQDcND6HV0/Cp4cwlX0MK
WDENM87/pmHXVCmz7lWc89hPxW2Xadir8ZNNkTEF2hR7jySsoOPn8YfuUkwp
UHT66clbOnScl3zvJJuDQ93+TfQhOn6f0Wy934wCX4aHcfleOm47GHJPn4N7
Ni4n6Jyg49VpHZm3Ofrw+eEZ0Wt0PHepStvRhALuWzpnPB/QcaAjzSvTiALW
7AnJza/o+F3V6X/BKzn52t0U9zyHw0tKJ4/+0qdAp5fftXPldFzp/U4tV5dj
j74UUdDGsedvXiyjRYHMXx41fn84POHQYPc4Jz/Rl7lX5C3Q8VbNWCk7MgUs
qoztTwoz8KWsyhFjJQqsMU6JvK/AwKOiF+XiOPnPnjuItTQZWEBQ2zCUU58E
txttxiYMfCD0Zy9bkOPPUPmvzPUMLJNL+jnDRYH18/ArficD36wVezM0SYbr
n/7r4XL8H5YeW+whQ2XymbladwbW2L+epNxIhmOSNUYkbwbe6rPr8nZMBoZG
UXr2NQZ+9s+HeJRKhts22mFVQQy8od7x1Fg0GXLawga3hjNwWB5J3uU2GYZI
q0bMYhh4v1aj88gZMqRdoZfdfcnA3ceNhh4eIkPQI4uEbe8YeO+rBs+968mQ
8V3/s3cGA5c/ORhlpEMGJ77HW3k+MTh7lbvhKikysBvn7s19ZuCL5tdYdnNq
sP5HY/XuYgbOH+ysiPihBk5Sb7bKVHD8eXDjDBurARf5n+PqrwycrT9bE5qg
Bjju8p4vdQw8QtpTZRWkBg9lGoNSGxl45V753fQTapBf+ucA+xsD+3jK26/c
ogZ8DvUaqS0M3Ljg2nVaRw0Ktn91JFoZODlzZU+HsBooM13dV7UxcGcLPnNl
UBXyUo/m8nPwY++NUTvKVKEyuLdqNUe/27nS+9ArVbii7aBY3czAtpMq1Dg/
VfDVitYsaGLghNtZpcoOqmAU2XSN1MDAFe/u3W01UYVpUmrSpxpOfXToyY0S
qhARbbGuuJKBHUvXHZD4owL7PCW+6ZQysNCnkfr7X1TAbau58BjBkfMfcdof
rQLr/uzyl8hjYCKw1sbtrAp0jVzpv5PFwMvFh7sLrVXA/btXn2sKA6tEiPq7
qahAyK2HIepPOZgqvfVVqTLMX7RKEn/EwFEN1xGKVgbyiuL9u0MYmFw7W7Py
lDJ8dQ4NG+T0h/RXdhBDUhn66j/kr/Fg4JD4+jfa3UqARMPKBhwY+HQB95b7
GUrgjiTYW60YOPB7r1HgLiXgPZbFZ2vEwOyr1ev4KErwTD49IpHBwLEbuw9O
jirC5S8Rxtf4GfhuSF241h1FCMgcFXxD0LHWlxP16z8rQJVReO6LFDqe0tg+
ERisAHwnlPYsRnH2soqLhjv3KEBCr3tzzRmOfMZ694Xf8sDzV+40S5aOm/Nj
y9xF5MFQYvruAodH5+mccJNtlAOes2/2HOrn8NYNSUsO0XJQOlckgzJp+KPg
sU+FGnKwVijqVupGGk4WM1RRt5QF6+srf13aRsWv779wb7CXATEZya9FOlSs
tSDYtktVBlq+PBryEaLin6WtFyN+SkPfXKGbUhEFN6k7m3m7SoN4F0/DGX0K
NgpSPfLdQwoiGVNK062qWLyM69mFdnG4nLkt7+hNVbxpyIJ155A41AV53sjX
VcUl7P+U/dvFgJRue8Diqgr+unOrDaVdFH7xPjBNFFPG/AZpkpWtIhAuY90m
zKOAd+a3k71aBcC2hBQj+0oep2tGHAk7IgCLeZfW7togj7PUy0Ta/vCDyPmC
E/b+crhire96oSU+WKsbX7U0tQJbrin/jDR44fgxO+NzOVL4QeuZaB2Jf2j8
Y2rH2S1SWKBlPrdfZxn9fP7Fs7hLEkubnpu/arOEer9baHnyS2L5O19XHrzF
Quc9jAPkHoti9YRX+vEC84hJ7Ah45c2Pl/uPDNZbTSBtRbA5HsqH+22U29K8
xhF37kQ87QUvNg6P0M4xH0Oj7KfnnlVw42sPE4s9F4fQSFTwJX8VNiE07/P2
aFw/yghcXz9f8odoxMlXwgYbUUBm1metP/1E0r+6vTdn61C34KmILJEeAv/z
fOiqXYUKSteEXQj7RhSLUWP+O/sZrShXzVy8VIoOP8qvquVLI27NVWlU+02i
7YZfXok+aSMc+LJK5t9Mo8tnRZZJG78THk75UFE/iy7q2b/5+LuT+HPX8hqJ
wUKmXteNj4Z0E5mhz6uSf3ODO3VPVfGVAeLda+0bx5Z4QN5z9G/vu99EnXKY
vZ4MHzww5t8n0TJIRJQyd1esEwDXNfuuu6sOEau2Od7dzOHfu+yYOpvPjBHr
znd9CX9HAnZIcZ+PxThxcvx56BtCFKL+GEB6wTgxDu4+8n/EwWPoZOTujxPE
BpMDPhJPpWBDfhWN++4UUeRf5H9OXRpaMnmqKllTxD5jxoWoNGmIuGF0YcB9
mghQkPDivBaw3s1Df8XqGULLO9kM/5SFCgWtRelPs4SSV6ZK83E5KBOUzdgm
NUcc+vjs490ROciwvvm01n2OeJFxNqJ9QR6SbjsUvRGdJySvwLNjfgoAm7RT
l+znCV9zmdGbfIrQrmnMjH49T7jU/xQ+IaYEyct8dc9NFojAmKcZWuFKwKFr
uSKXF4jXBroHPFcow/qF85V5uQtEneI37xOKKiCxKf7U0KpF4vmIwk+VWBWI
aOruOuW5SLThr4YbVFTB2fyliUn8ImEv8+xxm4oafD0W9DWOj0VkVNXno6dq
0Mz7mwtWsQjLDX1/hJXJIKUuxcN0YhEHLUKNjDjvmK2REOX4bRbxYKi71YFE
ASe0/HX4HYu4eJLnc6Uth4fYrIkrqmER93boHuoO4vAWbrb1nxEWMRb5ufBF
KQVIRs4vXUhs4u+fIB4BXipcDDRLMtRgE3LDrRYSQIXamYUL+9axCc0zdwLy
fKlwK+/B5qY9bKIpirrAn0uF7qq1vinH2QTPWPWnsWkq+Pw+E957gU183+7X
72NIg/bVr7WuBrAJp1K+hMeeNJC+vo73wn02MXdYRGXXaxoM1e3ibX3CJkLq
jS69+EWDscVbuvFxbOKx2D6xTDk6ODteP53zgk24sM9NHttGhwvJx+FuPEf+
ti79oz8dPl0PdNXlyK216N/efqDDiw9OaQ+fsgkLubi/pkN0+Pyfn2TZYzYh
szgdcITMgFW6XuEV99hEUux/pow9DKgovrArjuNf9kbeyBuBDNjUFxpgc4lN
/DdiaP5fLgdvV/KtOsEmtu+zKlwaYkDMgaGn2ofYhJ2gWZGymjqUhU+6eliz
iUebu/q/7lQHG19tt9CVnPxNtX6V8FeHI57Htj5SYhMtqxNUezPUQTVUsy2Q
m00k707139SjDoj/aq/HAIt4J7870URaA9IcCx0sK1nEwLVxs0wrDdjcdWWT
EKee3nzjQ7lnNSB/q0l+TTCLaOL/emHrcw0YSVk3Eu7GIuonVcPdajQg2C6A
eghYxP7/3swKsDSgkvtwlqYii5C54HhcX0sTMlyOyvCMLxK5ATvPivhrwlSX
4onhJ4tEcFZlVEGKJsgvbnvLf2KRCBBh/R5r1YR3JPPNlqsXid3kBYtmPS0I
DmerKDcsEA6min8D9mtBUQx7bXXMAnH5U5JUhh9HvvjkUarLAhGZ5mB9pV4L
Is02h6uOzBPKGZKKsvNaoDa3sTDn/TzBGvUa1yRrg6bFambk2XnidOaZIxme
2uCYb5aERuaIIF3uH+rh2mCl9rJONmmO0IrUoYl/0IbfZptO2rrOEfhk7pLJ
Mkd+bHj8Z+MsEcb2ifCm6sDpW/SbO4JnCYGk4HnKRh1IV7rSsHLtLIG37Ntf
HqQDx0UEU7yezxDtaTpBWkK6MGiQ2H5q7zRRfWrkTpWGLijGRJzRW54iJEsw
tXmjLjxYq+j88PUUwdtklE7x04UyBXt9z6lJgl9cgXQkVhei8xo1h55MEser
XubzfdQFvlVf3+paTBIy3NWSV4d1gfrpC5/w9QlC/1eq+VYBPQgyzDmapTpB
lP6owdfIemCuEWRrzpmHx7lHqYK79OCLZ3zowNAYsb7vRFpUkh64psuEleUO
E1Zr+uV4CvXgT6DZkavDQwS33T35ugY9SC8y6TjBmb8Wssvl4XN64Nd8S1/n
yh/CJP6mT6AwE07HhnvKvx4kTrt/+vBDiQm6cz+kfep/EyovedRSLJhw4Vak
Qi5lgPhkFunK2MqEDQ6Sh/Kt+4kSvh9X2YeYUNFeVubm2UekHTzxsMqHCcHV
V4OH0nuI9IFDjcRNJnCF8On1NnQTe70OesjcZ8KWfQUx+RO/CBs3C9tviUzI
OT07fd+xi9ggaDcP6UyojhnVW/n4B+GW/b1UJI8JWvz1CQK1HQQ1oMFrZTET
QrY/NGPytROnBgKys6uZUOe7q+HL6lZiMuC1Y0QTE6zW0Ly6PZsJJx6blfUd
TDA5M62QFNdEmEW3cXl0M+Gw69G/JrUNhMwTw2cOvzn+ZElKbGHVEYGfgn+9
G2YC82qllebBr4TT0Ruv9k1w4qu07bHMqiAuZquWO8xw/BnkulQhWkr8Da41
+DzPyVefSgy32xeizfJE2WUWE5ptTnXYXMonDpxiXgpfYsKtpWmrb4xsYuJC
iSnfP478y+GPFi+SiNZ5q/kGDr7+wyzS428kkSbJ+LjIwU8D3HJks6+hmjt7
zl/n4HM3q8yXj75ELqN0ptMyE75nmDzRDkxHxYf2jD1mM2HSccFma8dHNLtL
pFR3kQmlkR4fR/UI1ODwvVB5jgmq/RfW1a0rRv2BRRPHp5ggsnowfrK/DCkX
My6KjTHh/fOx36/vVKE4Wt0pib9M+PBF1D/DoBbdnJqZPtXHBMWOfXNDg/Xo
e66RqUYXExY3FvSMfWpEnQLBDhatTNizov1AedA3JGiwPyKljgkR+oVm+/a1
oJVdriuulDMhPiTqrC+1DbkVm9bp5DBB/crBUVrOd6TjdixIPJkJguO3HTx8
O5HLy2f+O18wYXD69n9NVj/Ri66R43+DOf0ZLNi9x7Ublb42ntzoywSJ/oGO
ofU96FvtwL8lLyY8sxT2dKL2orf9XtJ3dzNBPtQwNKKjD0WpT7W7bmDC1I2g
FsucfqTw0DwpxoiTD4MB4+B7Ayit56SMjjQT/K3VVlesHUQbbR0mf5TrQRif
oMK5wCGke/BTKl+mHrx5eaxf8PgwCgp8+uG/WD1Y+uF27/qGEdSf3BJmeEoP
qrYZfy6bG0WGTi4t1/boAW0uSudC7RiqsGhyk1vDub/I9OURu3Fksknqrh6/
HgjMRH6Zok6gi2Gmtcl/dEGsvT5vV/AEur+2583lGl3wPPz4oP3IBPpueiWb
75EuPMyZY+3OmkTrh6x3T8rqwsGX8d0LzGlkFLNtF9eMDszf/Rj+PXgaze4z
eXSsSQf8nuRH6fRMo7XJWnTjezoQca7SafL+DCoOnIiJP6kDd2ufqjv2zaD3
XgKpJ6x14Abr7UFZs1m0+G6OKc7Whojw7xMHW2fR0XOu48PN2tBTO8bXzJhD
g2bq0zrvtYFmVtl56+wcOvvBI67ysDYU+1VrOvPMoyJZ9mc9M22oFpGavrp5
Hnl7T8pOi2nD7hPLazPC5tHn432Ps3O1YNeu5lkbiQVk1y1+NP2eFqTMPrv6
dPsC4vPvSZB11QKG3vnE0ZAFJH8rSpwmogUZez4rerMX0NjgtsXqH5rwzGZ8
TfSqRVTyyGSoL00TZEXXvk84voi66zujTthpQohRwr69FYuIQg1Y10bVhFVt
f3RGZhbRFVnp/PwJDZh31Y3ZS2Whn/khd2W/aIDvoobZ7S0s9HKVuPnv+xpQ
NHk//fI5Frqk0LJxlbMGFOvtqdd7zEIf2lXXzutqQDZ0XI3+xEItbYppaxbU
ocV/e3ZeGwvFXRhkskrVQafl2+M7syzkP3Nrt8VDdcizb3UUlGajHZbZH9hO
6uDbau6orctGVb5cC6CtDmvYsYIjVmx07N2LfOFpBmw8FjG6fT8bhQ54JRws
ZMC6o0OfbTzYSK6gzdEgmAE+t7+hlotsNLyhPvy+HQNGxzUcZwLYKFHr89QV
JQa4HopQiL/PRo53T5tO9dDhaW1XVPMTNmK1CEgtvqPDeTMx8v04NtI8OGsZ
fp4OWgHPSFUv2Eixp/tKnjkdJB/nd96MZyNp86jgi1x0qG51N/rwnI30vbh1
q8poEBKYXnkklo0a1SS0s8NooPO2w9cvgo02xaRsM9tNA/HU+5sl7rBRh+Pr
6zbKNCBuuKwa82Oj2s5kLe4+Dl88oszz4Dwb7foVU+qWQgX1mpp7Yy5sFJ7g
2njhPyrEbmsuJ9lx/HNaqjFZS4Ul1/HsnrVsdDnS3jyBwz9ZCfYXzmuwkWio
05PiKgqEfOvfmCvGRj3nv56KDKeAi6b0+ZxJFiohNoHyQQpsfqTu4dbMQgds
jGP2q1GA13j9u/IcFrq587X84B4ynNMbjo07w0I9u9suZ3apwQX58lpxWxYa
93PfMe2hBtuSTu1lUlioOn1f69+rqpAt98vbq3wRlWneb03k4/Dzy7/t7z9Z
RHfF33X3hamA7r6tBvZui2juOr2KFasMtrzBu4cWFlD5VweRDpoyjIecz0vH
C2h915y8bZISNKlOW6ndXkD9GF8eyFYE75Q+1rjAAqq+mrVeeY0i1Gilr9hf
Mo9GVY8VjRQqQLrZd0VXP8592r7Qf6lcHvq+XWvwGZ1DD3IiqLe+yQJNzmwm
JH0WjWk/mOE6IAtnbhTmmzvMosry+GTT9hVw5mJSVyTvLNJePDba8kMGjs0W
Oh7YPoMMX304aNMtBWtmA5uppVNIRS+h8NdRKQjCL932O02hU2Lbr2/rkQTt
Vkmz9VOTSHMhOWFXqQSIKa5dsFaYRGtG8mKeFpMgcSOWXmczjs50XWalFYnA
z6P3aFUxY6jb6cqq2C/CYB9Ruy7p5SjasJcnTZkQhDUHHH4bJA4jxSk5twu5
vDDwevi/JZ9BVNNn7pfpMocuqQ7mHInqQiqrkt7uN5tB/CxrLTT9Hc1HKDRF
i06hQebayvfW7Yi2pWbL9fMjKJo+mvy0rgl9GTq2tMG7Da3J/hSmPYiRk2Fc
xs3KfsKMv+pzRVkdweN26qjS0h/i36nuB64yTYQcX+noWeYo0blDceOGrS1E
rfWw5ZjVFJHXudXesPEH8aqTJ9ngJou4Y0NpKlTpJyzsTnucrOXHqV90pp9E
TBAV4vGbiCoBvM1E8ttV30ki2HKq9mupIKZNxSW3uk0RH0Kqv898FMbSb8vy
mtbOELxztlmFd8RwqsXI45+L84TC4kW/JB9pbLInny/4ABd+tIe8xDsojQtc
VxaINXPhxWsj6oGHZHD/t5T/ePdw4yCrhBMz5itwyftv4Tq7eLBBRro5c1wW
b0nK2dC6gw+70AWL7hgoYrtK8gaJQ/9X03XHU/X+cZvr2nvedS6SlSSUOp+G
UqlQRkMqiZSmHWVVSktaNhXZKSJJ5wkZyQxF9sjee//u94/fn+/Xec7neT7j
ec77fV/3cw4f2rNmJ31ziCzKuH1qb8EfPuSk4ntndFwW/egjxz6yJiHfFyW6
JzLkkMGrJrMz1vzIuT0PSdAV0JfxoYenrQVQdI+Uvng1BeV6lTfdWiuC7jhy
ForRqUgkvt1w6pwIyuCX7pq5TEWXTDiZRkkiKKXUTSSTh4awxt8pASqiyN6A
p+BIJA2RBx+lqjDEkDP7r6yOFDpSH1HQSRGUQFBv6KlWTkeJlmfMl/ZIoMYL
R04099ORcmpzKNdtCeSSn+pxRYmBLP3bP2otSyD98scRx54xUD7F0Di+VxJl
LUqNVL9joBddkTvP0KVQTe+X0qQyBvI4sneu6KgUMvQ8nBG4yEAH9TeMnfwp
hfoDL6c2WGGoo8b7Vm6yNDJgm/SxdcaQ4eiXJ4Yd0uhQSPWLPf4YklAYdjCR
lkF6gpaDkIyhjKsXMD5/GWRsEqn5aQJD1mGzYYlmssh+h/am3ZxM5Pu09uHe
QFn0TuDt243iTORQZyNiny2LyvNIERu1mcgp9nzLvIwcctT0+ZBnz0SUrFiX
E7/lUJF3Ne3+ZSayOWFT5cQhjyqoVaK1XkwUe/xb0pi6PKLaj899fcBEK2Pi
xqd85ZHK6Wd6Z58zkd4Pib3GSfJoe0Xb3YBoJmrh5DGOq5FHTIM2pf/63/jP
8jfH0RSQwHTs77hMJuLmLaww2q2AglbkncNymehsdNPVw84KiETIMPkIJto5
P8bx84kCivKBrSOFTGS77n1uco4CuvNWlt2klInahLsaRv4qoMAFzmz6Tyba
b+sd/XxVAV14vCH5UhUThfB9sI5lKKKRn+81N9Yy0SEKyZzfSBEJaRx86VrH
RFuQw9/as4qoZS4R12xgIokWpb1zdxSR/W+q38n/+hFrFOc8EhURv1HdF4E/
TFTX9WXHoVJF9H4ozlKHhUvDxR/f6lVEgV1y2XWs8T5jPTuFeCiousR/1zjL
3jHbvMpBjIJkC8vc7taz/CsbiVbYRkEXLt3JjfrFRBwGX9VibCjIMnY6ULOG
icK8jo5d8aSgROFBc8NKJkp6OHMh9CkFcY/Ux5b8YKLXkw3KHO8oqMIqe7S6
mIloJScTv5RSkH66TJF1AROl5a/x+9ZBQQr1wgm2+UzUOMa+S3iBgnwttOj/
cpio1V8g5I0oFVHsbxUNvWflV7qI3XcNFen8espwSWGiCprQltitVJTUdKDG
+w0TfWU3HuY8TEXCTQJOvFGsfLJbFCQ5UpHl+N27Es+YqEMy9cpjbyr6fau5
6s19Vvy87LOzH1FReOql9k8BTFRMMTaTf0VFxteXTpmx6ufEvwa+/EwqmsQD
Vi6y6ss1yyYpvIiKhGJ32omdZSK//StcmXVUlBz9GQyPMVEwT/4kVzcVWd8L
2Tt88L/frx8cejRBRU21sXrKO5kovEczcA0bDcmUdH3r1WP5e0HsxhvWPt+z
+WrCejUmOkx2E84ToKE+ac94XgorPsyLmefFaMi7Zr2/gwgTqV5m9n2UpqHw
sjaOQxxM9OhVi2aYAg1Zhn0d+zGJoS0rK2RJOg35G3HJVHdjyLxMnFdViYbq
j9fttqvH0Luk2uS6NTTkxGZgfus7hsL+MW5Jq9NQS4OcgN5HDLU8oquMa9IQ
DOjv93yDobX3lJVOadOQ/BXamEkohgJ8y6QcdGiIN4BZ+8EPQ/c+/3vOoUtD
nLkWv1IuYejB79c7dDbSUHKuZ4O+DYY4L7p8nWPhrvcc347uxdClR5TU//oT
VT7zXBfTw5DTOiILWPjLGr3RkxiGElwqA/7rT9Su+c2/WxhDda1Y6W+Wfb7r
1Tnc8ww04OCufeK/fsgMnuV9nQxUPXVj05n1LP9nyeLy5QzE3W5yt1+LhqLI
FboumQzkLp1VOszyb9eGwDfWEQykE7g/8bIqDel7p8SV+TNQynaf5ius+BRX
j1wtPcdA51PcKeM0GmrippyyNGWgUbVd6iPyNBSGKJ9cNjKQ7Wh5qaMUDS0a
txYzFRhIxOpH3kkR1nwHqZb4Pzpao/y2uYSDhgJe0AJSf9CReQ/J3nmGitK3
FKKMdDra+KTQZuc/KvqnFdwT4EpHqd3ftrcUUNHVgLWPLKzpiPsApTL6HRUF
P9tWWbiJjiSuZnVbR1DRnGlb2vUVGnrKPGubfYmKNuocaff1oyFptpGLUgJU
dDZAU9T2FA09vm09ETFGQeAuZ9kDNOSWnGIjV0dBCbmXSO3LVJRrWd7I8ZKC
pip+uR8coaDjo06UYHEK2vVqR3B7IgWVp7Sbto8qIpcrPaWNpynIruLzfu1y
RfRYN4ZTtF4Rfdkm8af0hiIqDLna3PdBAZ3rtiPaGhWQ3qm6A/OWckjYl+f0
0ZPy6J5nf6cfSQ5FnjHrLGCdv98r9ua8yZNFXkjOb8Mc6/zur+/4TpFFDSMf
y/Xuy6F9wfTMqnZpJFb6N7QjURbNZO08XmkpiTSTKuPmP0ojfT5MZoYkiZpz
jR14PKRR1KaeJ+NfJJD8/RF5UwNp9MijjnmRIYG0ImVFYnOl0JzIwzXFg2Jo
0L/y17H3kmiko89R20sEFSmTrifcEEfTvP8kf6iJoMzjuJuhrjhqdXcc+fpZ
GIUkHLZTZd0Xtznko4SfEDriMeAmbCGG9Bdn7psICSDSuyfPt9FFUb/Ojh16
Wrwoo8O0aNJAEJlwcakeeMqDVBi1m2tDBdCc8mGz1HlupNbwQiJmiIyKTLaJ
m33nQp/iqkIkI/iRWb7sjfyTHCjsvsmzyUFeVGyv+UPJepE4Np8qFnCKA2WR
Tc8p/+gkGFLZVMH5ASIwIpC/Mr2deGBoq1dC7iN2qazfIq7RQpQcv8soZvGp
fRujY7pb6wjNz8cySq+1EtdGshRKdnwgdkRiUxTpPMJjTbagY14Tzu4XPVrq
040LlN6MSQ9oxRMe/cnl8OnFfabt3jIYHbiI5yHNRO8BfD7Cz5Hndzcu32LG
vLx1DH8p3W3ZKjKEjzq27rTAZ/A6J+FqrHUKt8rL36ipyA5/Q+1TKO+m8exX
rYlYMzvsbZQr7vCZwVe65p1awjnA7Q2d/b3EHN45NywbJM0F8J5Rya+yiDu4
0SrpgrzQNh+22OTMBq3R6VEJ3QKQ/mRXTUkhGxxtWj5tESUInZ5+7Tdk2OHb
ikXVFQshMLHT69r1lR2C5pR0WguFIZle+Jm6yAH8ty5PuZuIgpjn1VoVA244
98bYMlVYAvL/+vb98uUG3b8M3mBnCUhS1DnOWcIN6/KD/3T8kACph4vGAwd4
IMLevnEgQBIcLHxdK0x4QWtMVUpkVAoyWt8b3g3ihYUQB1cLY2lQ9JFf+F7A
C/NlnVbzsdIgb7njXMF6Pnj10EvN1FQGBquG95SzkWCozflbV4IsUATVvJ+s
I8FCG7mqeEEW/Laq3mw+QYL15jZDo/vlgM2oiLGYTYK2yXd+fBNy8Nj0OEdN
OwliXOoUJ7bLw725O+vUSfwgIKUuJhUqD+a235JdLfjhIwEP2LUVwKjj2id7
T354XWvpWHhDAe5ebnrRGsEPWwPv7swqV4BdP0tXLzbzw+a5naPSdoqA5Qr+
CFrgB/6mWqNbaYqwM928X0uaDOmb89OkZhWBJ36tlZoJGe6IvxKIuEOBv9Pp
Z/zPkME8/21BUCUFzkR07rxwnQx+pMN8jyWoMMj11GfgMRm+XtE8mH6ECm3l
2a9X3pChTJQm0hFFhYM9u48l55ABvbpfrtRBBU0DbavRUjJ0hn3kyhelQeOB
BG2TXjI8+ns26bU5Db5HRxMOU2RoD/f5YXOVBqRDwWMYmwCopz3sCmfp1Ngt
+sifXwD+vt7080gGDVKs3urfFhcAR7LOybBKGrQZj11ZJy8A66qNbloP0aDX
lvokgC4AUz6Ogs9JdMhbFq/wUxYA3qOFE6bKdBh3OXFGY60AiFt9kQ/aTgdl
W8W3QeoC4NXJ7rnpBB3CzjWNP9MQgOF7z1bPetKhJfxsuhUL599sSBR4SgdZ
8exD1WoCsLYv+OradDo8N86z51AVgOdioyeIEjrIFGxzHWMKgMX1jy4/2lm6
3LSU+t//Cx8myxF75+ng9POoMFlWAG739e/HRRmQefD8gqGoAGwrvaP7dg0D
ziwnv9blE4ANQYsP/XAGfDbubJxdJsNZ4zn3CgsGBJSUut+eIEOG5D+xe+cZ
IP6w2a67hwzJZQO3s30ZMC5l8FjiDxlMiYlVs2cMsPnkvCBbRoYHx3LTjyUx
4ELSoZTZT2R4ca6mtPYLA56wZYh0JpIh2JHN0L2SAbwFr7ZUvyDD28TXP8Pb
GHDQZ6qg6BYZXtq1dBiOMaAy08eg4CoZ7u598u84GwbxX3i3l58gg0b9xT0L
whhU2Gvc6txDho1Xh7wlqBi4UkUCdymSQexr1fr8zRg06S1lv+QmA8G0TNu7
B4NyvzgxrmF++Pa8tM/cEoOo/Nozwb/4gXN+wKn+NAa+GVf9tXP5QazAKb/m
IgZHxA/tno/iBzmzLufdXhhUGos/7/Hjh3Fmp+DGWxhkfx/01tvND/Ux1928
wzAYCpBZfLWGH46Ji7j9eoXBk0lS1VbW/tKfUPoVl4LB+xXHRcF+EnxeDzq9
mRgsSLUHiZeSIOnJAP46DwNN37lb5gkkgKEvCfUFGChdmOWpDCDBXqcTsjfK
MPDo/6x09yQJ9kUE7Y+swiAr/jn7HUMSRNrxL2vVY5B6ax3xQ5oEpyt/9Og3
YfBa3CbIaoIPNueXl2W3YuD3fTF43U8+iHFTv5TUicG0wq9l63g+SBZTjxX5
h8HjuAtSdT58cLtYTW2oDwPDnDGxeAs+EBZ637l5EAOKOYdulTof/M50iFod
wiA/KLzAgpMPDuZgG/X+64fk7eY2bOQFadGu4E4W5rKT2n8rnRecLKr82Ecx
WDIzG9gQwAteG/DVUNb1tu/uOgeseKHiT85o2DAG40P8/nVrecEOG9kuzrIv
J8etU77MA03fS4ZW+zHQfpaVoFvNAxs3He+x7cWg/fBzkH7FAy4vp9fodGNw
8806h2vXeODfHtFPnu2s9X0cDti/kwekw0++0GnGwIY2w5EkwQMeSmVVJ3+z
7JuTD93t5oanSvYX2WsxuDJyqmc8kxuGwgMCJX9ioED31vjnzw0nDieqRH3H
oGFTfM5NKjd4isn78uZgoGLXN6A2zAWPFd1dB9IxuLBKzr7ymQt8Xky5b0vA
IKQpgu/PIS6Y3fHGnMVz4eRl9GCVygX9ytfvs93FoN5qIL5ykBOmuj4/V72B
Qdhmr+dX/DlBzrpc8O9Zlv02WxeT/ZywQfzTst1RDJotVkabpTnhUuL2otP7
WfVfGFmtnsoBOYF6pEJtDBgoKm2ghh36xP4VS08x4MH46XPaz9lB1chHdqCD
AdybJijbj7LDmsA35xWrGPB7VOvwrw42OLlI3p70lgFhG9zW27Wu4kZvtY6c
NWNAGcelnLtnVvHY6IcMs00MmHg3tzN4YAWfuR7cFcdgANu2U0nbZ5bxbV5e
2h7jdND2lnB1F1zCz70zvSIYRId3C+u3nQ9dxG2S1Iy2XKCDuGVs/k3ZRdyc
edah8SDrfOuLWVVXXsDpjqkqRyXpEBFF4rm9fQ5P2L0+40UYDf7+ctLzeDiF
845eqCoVpsLXKCbJTm4K99rS5RRVTIGFs5MGEwmTeNKtsMLz3hR4OGdZplAw
gdc/Ie9b7VaEzJFPQR7s4/hF0hL/7mQFcHczSDgeOoar75xI0DyiAFtDNj2l
K4/hjz8y1jJ5FWBp3amw+sgR/KMg7c2Ok/IQtGm0x89iEP/y1sQljlcOzM+s
S+0OGsDfHQA5o3eykDqoWOnxtR9/uNFtWcBSFl4KaKyeW9eHS53k2iYZJwNc
1r0v/qzrwT0PS9Qc05AGaZJem5Z7N65z3WGLa6UUixfIIUXUhRvSgjeWX5SC
L3bG94eOdOJC02Z+BmmSMFt/iVvDpg1X2PK5zpPO4htDOR7Gaq24eqRmtF+h
ODS5DNr6rzTjintTbk2fEYeJIOeQp1lNeLwTSlFPEIPcmDuXZk424CbblTYp
M0Rhud0/uPxIPa5P8/7UTIgA/Umn6BbrOlzLIwlJ2ohAOhI8oHm2FvcxVv2n
qy4MG4SKrgU/qsCrXCbjb3MLgE0tvmW+pRz/Oiw8/NWADCTO3Zeu6v/ANeou
yag588OwlEZol2gJvhMtcufU8MFE/gFRvpDv+O60kJ+dHHzAuz5VKEShCP+q
3nrzqA4vvH66hZ1x5Bt+/LLytNETbnhV1jtpyo/wopGBvu+IC3704V/PPM7H
hY2fqSePcMIBZ7t38XWf8HQtr62fjDkgXZzmcjYqGx/5kWs/4sIO5C0Hrov6
ZuFE+62HcbFs0LCEd0aEZuA/QpWCtYaX8VmltNYzd9PwTL28iMptS7hlra/m
Dloyfu1N6fOwZwu44d6PsRxDCfgR/9+8UX1z+LnSHL3qodf4jet5vj2bZnGV
3VWkBkYc7tWmHnbz/jTuLV10w00hCg8WtRtxb5nEffmzGMYnXuKtJemMvxoT
OBfT9JEd+SlexpBo+egzhhs4/LzEzXyMk/XLQlTDh/FNQ6dFykzv4oUR79eS
9AfwfYsGZ+20A3Dz9YcHsPp/eC+w37Stu47vPGVtGHqlC09udYGxmau4vkRF
yGXBdvypHd+XgWcO+L66bJRs1ohHPuoM3b/jCD7oNrE9+04tjmo9pj7t2ol3
y17c5exVgl94vnuDXYUCbiy+6/r1skx8t/8fhz7y2FbfrshX7XejiIPej2fm
p3Xx1PfT6nK7vxGabe6HPQPNcJOaV/fcmisJ/T9B3zevPY0/L+t74arfQKQJ
hX7Qn7mI29pi4iSOFqLt9QoneuKOrwiHnjzV00EcnsWyy9N88fJ+z0a9PT3E
lCnj3X2n2zi3IJffxdQ+ItRB39189T4+LTffNyg0RBAUkZPtuk/wAjSb+Pzy
KCEycCEzx+o5/vF43Ltkx3FiV/Hc5unucDy6vNj6jswkYeRAlzvSEoPbJncn
1JVMEVham+vmO/F46b/+Nw+Zc0Tkp/BQ9dBEvD9D4ZJn2Tyx/YIr8NSm4K2i
3JrJzouE4Wrd6/Zr7/EC3T+b0jNXiLdDm13ptpk4V6fRXNZaNiR+4t4fN7uP
eGdatC5lkQ2xGWoMjmXn4mFD2vbXwzmQ5m6yxF/uL3jl7idv7c5xor9lOkVn
nL/ibcvSw4QeF3I+duR5f8E3/G2h0cH8Wm7kvHRGQvFCCf5PW0R0LTsJaVMd
B7GpUtxWjG9cpJyEUrRCpf7d+YF/+Sk5tOUpP1pzsIF9V20F3t+48/UhpgD6
86VLcsG9Fp/6UHe1ZpMwevpMRSjt3C+84yPztMmKMHqgmKzedrIOV72i5Xb5
pAh66f/4e7BtA/5WJfhOLEtf0kVfCPpHNuHhEfZOWLQYKv9lzJ766S/e+sS7
cXFRDOlyeW3qamzGZQp+Ze07Io5eb2wjbVZrw6Xv1u/dLSaBeG7KxvVwduJV
z4QpZ30k0Xud50YH4jtxk9L3S+8bJJGiiMmNReMu/Nqgw8hJLSlUKP1AnO1F
N771irNua6sUGmBsO/HepBfnalsNFtsogxQ2bFLCV3vxEOKjgs49GSRj77FY
nNmHJzIcn79ukUHxqYf1oxgDeBGNED3vL4sET9QJGUsN44W3daYOF8ohbKq9
QD1hHGdq7zyaRlNEstVbrR5ITuAJtNNP6y8qop70t5s+3JrABQ3Pq/N8UUS/
JSZ2qjlO4jc3jEa5HaIgUf7B3by603hMaeljMzcqYo9QTM1JmsZtvH3ueH6h
oku87z1GKTN4H5dMcDkbDcnbni6s55/FL+6QZlrspCGvrHchUb1zuJKNlPRi
EQ2dWP9GKNl2Hj9c4Ndf0kVDrmvXRC//nsePt/414+Wgox8qrSPWZQs4+3Si
cpMhHXH6UThm05bw1ce25dkpdDQ1fErgkMoynqyyS3L1Ox0VbLynkhm7jNf/
rVr+0EZHX7JSL9uEruB5i0ohR0UZ6PjPe0tZm9mA191kw1NnBuo/Zrdx0Z0N
2J4cK2AGMNDFCFU+ehYbGBc6Gcm/ZKCa+g7+BTV2SDdzz9NDDPT0A2fAGwd2
aBz2CTz+i4Gmi1rpiq/ZAfnGjnT3MFCGUZO5gywHjC/ZP6SQMNT0hMFYd5gD
hL1bvlfKYsjTq/3Jx4ccYN5Kf9WuiiEvCbmKbg5O8MsIvKtijKGUzJvVtww5
WXqNKDhmiaFB3sj+GldOCDnEtTxqhyGdm5vrjvRyQk/CFiE9Hwy1Wm3tus/i
R+VpM3h/EIZmOs4EHLHigrBx4zULoRjK79phmfeQC5qdo/3PRWNo3beplbTv
XLBlmU1ELxFDD4xNGBpLXBDyW/7F6fcYWvISddiwnhssmgy7B3MxFOfAtVgW
yQ09u5cUpcswNFXk8PpgDTew77lAfKrCkMEpUZoJNw8Y5d5+nFOPIb+CHGae
Pg/UxdR6iv/FUI77PseX53mgYNb73M82DDH8NOLbonggys/6UGcXhtJf2Yfd
r+KBANuWdRa9GKqJ+MMTwcYL4dfXsCsNYIjYcSOTR5sXmLkLpWZDGFIlraXF
2fCC46aCU8XDGBJ9npuVcJcXMlytBNNGMHS9REpA4iMvkD+3/vf+ESRR3F7U
08YLt2VQTzXrekBHiJ8MPx9skk/YJsTCZ03j+xJ1+GDfEW+hryz7n2u/vAk9
zgcNvc4X21nzD28sPlMfyAerb7vuuPZhSJmgNTul8gHfVf9bPj0Ywu0LCkx/
8UG0ourzuQ4MHVg6Xh8wzweXHEaG/rVg6LVmQD0blQTiWZRvxo2s+S0r7hbt
IIFthsEBSh2GWrRW8ssdSLC+avSXQyWGeE+r7BAPJgFXPPW5UimGDrdXjL5I
IwE3/Vez1TcMZVCFYi2rSCD0xnBqhZWfPirSNRkjQch0prr8Bwzp74546SrC
D4+lMptSkzC0Q/hodpUWPyRP1FpmxWIo2a/F3+oAP1wbLVnWfoGhN/6mc6QL
/LD+6Il1yg8wtGw79a/zDT98aWGvvubO8kdGxZUT8cNb6rJY5XkMmW9+0rC9
iR8wiYsPYm0x1Ly2WTl6kh8CL57IGjTH0L1bRUFiAmQwePWbLcOIFd8xI+Uo
jAwK51pHh/UwJPkmZ93mTWRwUb3IkcCqf9M9tu4JZ8jQL1yedJuMofvULYYX
PcjgpKN7OGORgZocIm9uDWbp4Y3W+y0HGchlMCRMIooMO6/lqHo2MVCFwqGB
4TQy3MpM95MtYyC5vxZNJflk2JZ7YVwvh4GsRy81xfwks/bLsEz9GwZK3DZj
d62JDMZ7piPGQxis+vg7h/eSoWo7ifHwBgPRqNUY5yQZKDLnLVOcGIg6bePx
maXvv1HE+vZYMhCFnRRqxysAf/bH33XaxkBbf5yXXRIWgPIxl3FBdQayk7D4
7CctAJcMXRo3SLHWt9KtMaEoAHol61fbVunoW02S7j5MABq66jGRfjqS8foS
eU9FAOhtogLFNXRk9L5ZL32tADymY74cn+lIv+Z+T6a6AIhvKNlXHEdHoeYa
D8M0BCAxUXer2F06OjglzbRh4Zu9Mmt7L9FRcfDn10tqAsDZfrvHyJKOxq6/
F3dTFQD/6Pk9Wqzzs7u2I7BESQBkSnZveEOnoyCBULFRmgAcnI4MjOeho1Oe
QZ0DcgLAZL9K2TBIQz7Gckq54gLQrnqrz7SKht7pHJC0JgvAmHLtz6UPNPTl
5+jcd3YBSKHc+6T/nIaQUyKNfZYMgQHkSG5PGurMlurjHSSDyZ9GpzPHaGif
XvfilSpW/MMm3v6l0JDhDVlL169ksMzqHc5eoCLS3Ftd3lQyfDibfz4/m4oq
Y77bVPmTYXRg8Hi/GhXFYA82cVwgg/7OK8ISPRTUVnrs+5dDZBjfP0w1jaIg
y9n+rwUUMuwtDdbiJVOQH9eNHWQOMlw6qZJ6h6UczGgLcfVd/MCn5uLHdFVE
twejKwde8cM7lVz/r38V0PqPNoUzQvxAQlvuFEXLI8FgCV+NfySgztkbeuyX
Ryv++0Nb8kgQ3msWZrsoh1SjoSDhNAn6+1Yv1x+WQ2nOazf/jOKDmPgDbFkr
MqhZhjNR8gcPNBcoD3NoS6Epr62ktCAeeKM93nCuThLduO/XnWvEA6Ifj4Xr
uUsiupFCsG4eN8yrmKhJ5kkgq7zraoWhXHCsv7pcz1AcKeSi2r5Fdqh/+JuL
oSKCTLkjdNResYPHX+OjyreEkZa7+5XxXeywY8ujMKM8IXR1NuO18H02GBom
+1kpCSLe4Lj7AaQVfN3lX9Qn4yTUNZkTedJuFj8qfdA8+zInOn02982W2zO4
nQmnQtQrDjQbZzvnnTCNH7h2wkavjh29zn2YvrFtEn87KNkat5ENPT1I/7x2
/Rgee827nDoxT2Qldl83Km7HjYrtV8z7+4npn21l4tdb8B+BD5Y/JP8jupdX
hV6fbMR7M5rGX1zoIsJPSV8yEq3Bz+gwaZ+7G4mDNvf8bz/cjQdd0gl3fWBG
HBz/lZ9IdBAyRWocz+/04x9vJ6hQSd1E2l8Pfpv3Qzh7NEe/lOU/Yn/xrP7s
n1F87Jjg3I6FAUJX659JjMgk/pXbqqRiwwQRZt6anbRnHr/XfcZosH+RUK9h
Ss3kckCarWPiRTE+1Oj+++FaNSHYQl0vbJHKhxxwz8Wen0JwutBp25VdJNSP
b2697SwMYvYvPPSv8yPmy5zjWRYicOkLTfjmPwH09/fh29H3RcFBvuNFR5sI
0tQLDO5tFgdZJVc7Bw1RVIAtTfEyJeD6OGdDh5co2rLFUdDHSQImA1p/J0uK
oRtn5F+cmJYAU85FIeO94sgm5t/NGg4pKBq9IueXxuKJ4dya1EVpqBY8pK8y
L4kYJ789r9woAyEi1YLhO6XQju3biz9fkYH0IL7Sv01S6KaitcPOHhn4++V1
SRCXDIoOe/RhoUAWrvnk3Tm0Vw49qHbatWAlD46vvh18HiKHctewHxq6LQ+u
5jzePn/kUOutSW7+j/Lwrjt4VdNeHs3S7IW/CymA04hezx9PBcRttEmW+UkB
ovSmDlEeUlBdy17d8Q5FCOia0Ov5RUFLcV1/hHgooL3Hp11UloqMO07LqqhS
4Fig457HcVT01ZYr1OgCBdRlbE+dtaCht37Nj7X+UeC8YceNbFcaetJzdEmK
gwq3zNzc057RUKO0s9mMAhU+RF+Tv1dHQ5vcR6mRB6kgKlX9rH4/HR2ZeHrM
P5EKIaYl3Trn6chw/8tG5S9UuCZt+UAjiI7cx15KF1ZSwWZ7p/UwoiPrEL0b
XWNUaKZb5GY001HWjmf8G9ho0GjlOEKao6P85WNvrvLSgNpbeslDg4GGpbod
7CVo0AJzwsG7GSjF9cGYrBwN2CSS1DVPMRCfssmtfVQapG7Y4X7Si4GKg9pP
LWA0OJix8w0tlIHu3xspVl5DgyGS6XnnFAYqYp+fr1ajgfHxTXeMChko/+9x
o3lNGvw9JZv9lvVcc5U1mYvRpsGh02a5T8YZSCuy9Ox3HRpYcL224OZjPecL
ovvP6dLAnNPg0IoixtIltq0PNtJgpfSjj7cOhhAcf6utR4Oz/fDmBotXLqRH
pViwcJHf0zBOGwytNrZbLrDGf/fg38B/BUPTOx7J/tefKRibtD8kEEOHPn1y
LNlAg6/Z64tesHjCk1iBr2PraVC9T8NTIRlDamq/XkSuo4Gq75QZ5QuLlxn9
8yjXoEHJ20K9yAoWTzmb3OezlgaeZQXSz1pZ61nPey1LmQbxS2JdvCxe9mjA
NvESgwZub5oeTq6weGpWsGKGIg10g8wkrISYqP1TxXk3GRr0lPy8rK3IRKnC
FesKxWiglfYj3k+Nicbu3Bd6IUADb6uVT7sMmEhi2+mUCW4aqO04lnVzFxO5
b2y1S1tm5TuFlqB2iImIBbVXd0aokPe9O3aPLRMpdfe4u7ZS4ePvmLw/TkzU
qvvmkEcFFRaZOaJ/XJmoZsYkNSSPCi7ZvIW7fJno8EZ29kJWfbnNj01i95iI
wc7fKPiMCq832lZcDGUi4P1eeM2XCtLt9d7KkUwUOfnYesaJCjuzPTfsfcNE
/m65G18cpsLFQjm1xhQm2sBpx229hQo96lsjaz8wkdF2t2ublKjws1GlVDeX
iRQNgvVAgAq00a5JdoKJrqnUCZ+foMBf1+L4zkIm+vBvmeNuIwX6/d4Fby1l
ImO+3DWDBAVeLIzLSP5konHHxOUn8RQg3KOK7Kv+66ec5vS/R4H3ZwJJ62qZ
aO4JXph7kQI49/az1+qY6Pz+B6WbzVn3HwcbrQYm+khsSiDpUqBsOt/F7jcT
5Rb0TzKlKZD94NdG4T9MFKd65cCjOUXQjPbU/q/fctdUudXeRkUYLXswU84a
r2XFl2OVqwhRqn/km1n2YsM3yuS+VAQOT5HNp+uZiL/aSv2yuyK0MbvGbX4x
UZCtSdINC0Wo0Z/pqKxm5du5YM+/9YqgpjGSkVXBRHpyzIpEYUUIfnqVT/gH
Kz4vb82WDCqAVNL65y3fmegqLTTEqEQBJHP7ybRvTERCNxyxVwpQfNWO2pDH
mp9tZL+dtwIYCPveW/3IRNsu9krzWiqA6HF9cuQ7JhqZJ2JFtBSg2nX8iEYc
q/7ueDofb5OH4j1+n+hhrPyudnq9ypaH09y1+4MeMxH5qFSTxQN5aBUPPZ/i
w0RywnkmAgbysCfi2G0jMyZ6UTMjNHpXDiw0Yh+X7GT5h0LCG47LwfjE++bP
eqx8SBdabNaSg0M5WiLT8qx4rCHdD6yVhTuBVmk5LN2w6W8Xm6m4LPBsJl8p
/ImhNlXVhaOdMiATnRoCeRj6UL5UN5khA0lbO40fPcdQ6srFr79NZGBKqV7O
fxeGCqOXGt7clAbk/lBHQRtDkbZd+LF90kCJKPm9Rh5DVlTH3gwpaTjlSEsN
H2Yg3103f2xPlYJtwpZ/eoMZKGk1Uxv/JQnRj114r6TT0fjWvXpPxCRghWI4
MPaYjrLps6pOTeLg4j1gMHKVjvKa7n3lfSUOVl3XV07r0hHz151LkevEoaJG
QHBHFosXko94Ou4Tg8nr/WyZG6joo6kl/bKnCDys3fGqvZ+CPl80+ha/VQQi
HHJC5aMpaM027+hCThFIXDcnRHBSUM7WThs/eWFIvh4a3VOogEYOv4id2yYI
1gXrf4vJyqG6KVz03X0SpG96aF1JyCKpOEUKJkUCy4JzUu/tZdFU9Y1XKTEs
XmYt/XkyXQa9VAtO4c/kBd7jiVte60kjv+glGZe/3PCLN+uHMyaB6qyMxnw3
cgD5TOYTSh8/Knde9Uw9NYOX5/F+c54iofta971z3abx2YFboQ6rfGj7Pe5+
mQdTePA0zw9XUV5UWZr3Zzx/AmfXXxnKVeZERfd/bJs5NYI3njfWHNKbIbgl
+zZrlrTjc/7JLebqU0SMNJfDt12tuEeoisUoZYJQFQnsvMrzFz+xahFPWhkk
wsXWXNGMrMMNdYNnxd43EEFNb6NUjREuTbMI1rr0D8ccLJdqb1cSmi0el33e
D+B1Lsf2JJFqifj8qn1u0yM4w29XOmdJHbFXfMu2aTSJ48PnFD4oNxGDpWHv
3h9ewuU//Exr2txJuLSVkku9VnC/lOLNO7y6CDPLZ3rhpmyAQg8Y9Gd2E1p5
cVcd3DngQ2Q0/kOml7DxvsN4/Z0HpnUN0mbfDhKTZspnmY2suF4Y0jpFDBFZ
wgkzj4b4wInOoVpaM0wU21LcuMVZeoDvt/W13lEi5mXL+C0bYfjdkv64ZGCc
8D/S2vBZTwTc7sjdlD09QUQdcNt9B4lAesz8qdqGCaLlgPmzBzWisGRwLfLS
p0mi7Gz5WMuYOFzxSTmreHyaGLV1rGC7JAGlx081DudME5m2Ct87hiTgBt2/
11l0huBNF22r7pWE1nCBUI/8GcKX8evynzNSUPjH5CC7yCwhKdO69LhDCmQe
J3brnpwl3C4GjPM2sXjX9xuTMfOzBF5XUUdYyEBX38cjddvniJjsybfyNTKg
GOVz9cPdOcLDcJ3yh2JZSOWQynASmSc8aXzqbGnycP4w9raMfYHYKTGu5qOk
AE/Ujxvs0V8gtpd1nw6MUgAfp4Ps1y4sEKeOGRQz7ytCl67pkZKKBWJ9undc
DgcFamoOGk4uLBB0UyRa6kEBkcbahXKlRaLML0/Two4KjoxLxXdcFgmvjKa4
8t9USMfdxi68XCSisr0jGpVoQO/J1eL8vEh0oQ8XAm1ZPMZuT82+xkWiN2wg
r/slDR45ym82nlkk1nrhHPM1NHC4OD84L7JEbL/+8jPBT4eTu5yun1ZdIgYs
sk7p7aDDrsyIsAB8iTgurut24jodXsnvE7Y9tETYvk/x0Mmkw5B5Wv7MmSXi
es7rwawBOrz0tIg2cVkiTnxNP9RBZ0DejFzhab8lwrHvkl6ONQOS7q1YbL6/
RMTse0vVfcQAWR+hsD9Pl4jd+7a8OPKdAX7/9vwzjFgiznXuV8MWGSAsHfDO
KWaJEGvVOf94HQZB8ttunIlbIkx5nvbF2GPAOBU7qc7CNnqOeqbhGGR7rS8t
jl4iBM7xj8RUYsDN21K+IXyJmH2Nxz/gYEJ/bk6PZ+gS0duzfU56IxO4g/vF
w+4tEUKTVYFbzjGhl+/W+Wc3l4jvEpqDSxFM0Kqzk7l6dYmgfN9UebiSCVLb
2W3W2y0RAbtdfu1gU4I7qoefNJotEb81uF6XaiuBdfNblfNbWbikrLfjtBJo
73N5NbBmidDzPXPwYagSdB/RjT4myoonc+u9n4VK8O30tp/fZhcJQ6ln+yIm
lWB6IHqS1rxIDPRLb+kxUwY5UsPHxuhFYqfw9k4bX2VYnxG/Z7PPInG/fn72
VLoynG+wLo0/skhEmAn78pJU4JPY4xMJAovECYGomwm6KvBq7X1Jo64Fgnlb
jf/nKRWourE4vZzDqscgs+X4TyrA+VDDtPrYAnFiq77Y7j4VKGmlflNSWiBW
lv+U7JVeA/G3FW/rDs0TWktQcO3aGnh9z4cn5to8UekSPfAsdg2Ex1wO4tkw
T3ilsV2XqFgDRil1Azsm5ogh5kA9jakK4SI6sjaOc8T+/WrvUg6oQvcY26Pd
tDniXBq70AMPVRh4RtNXapglTnMb5+z/oQq1igav/myeJRz63rvE2q+F/O2b
FxZGp4nmQVmR3HtrIf7l4qUjL6eJDR5MH8V3a+Eq50jawNZpotP4ZWfR9FrQ
1/ZWLLk9RWx3cXPlllGD0IhJC2zNFLHHck7ogYEaDFy8aldXMklwbyypvOCl
BqlJbctWHJPEJKb1rSBMDQwQ6+yNmiDM1tw2P/ZJDfYlTxEvN04QS+yC60wn
1UBIw76w9cw4kXxE2VzjpDrsu/x5btupUaLqjUmwt6c6HMwZDA7xHSGKcOtS
nifqsDWAduNs1DBBM/m1XIrUYfHecZ/hqkEi1qvzxGqDOhwQdrMs7hkg6GzK
z5yH1EGQ/oV5db6f8N21GDkioQHYJzH3ELk+YjzEVZBtjQbceOuepL6mlzD+
zhGya5MGdEulqg3o/CNMQkuPXj6uAb7LIw8UdnUTjzbwu5tf0ADuAr3WXJMu
ol3d29zhugb0d348/sOsk0i/m4CrvNAAq0K7pOdW7USW71bbmtca4L4nVHQ2
o5Ww16k6kvpOAz5IuTnvy2gmpuI6SnI+a8DrwPDyQ2lNRNJOkT2TRRrQdmg+
3SDxD3E5jz/wRKUGtNK2ZivHNRDH9MKU5xs0ILw6OWznyzpCISamp6BVA2bq
59fkP6gljJxpPnk9GmBqi+/57FdNOO/FMzoHNSBRKrSnvO8n8dt2xx79cQ2Y
uLFqU1deSmy2D5P9Mq0B6y/6q3emFhHfHevnnec14ARxK2LPfUREm2aV7V/S
gBKvD5Jf6z4Rp6UULx9b0QAbjz8Nww8zCK58+t/nqxoQkCA79PxRLPH/7y/u
luqqKgwe+/I/E4Syww==
           "]]}}, {{{}, {}}, {{}, {}, {}, {}}, {}}},
       Axes->True,
       AxesOrigin->{0, 0},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& ), "CopiedValueFunction" -> ({
           Sqrt[Part[#, 1]^2 + Part[#, 2]^2], 
           Mod[
            ArcTan[
             Part[#, 1], 
             Part[#, 2]], 2 Pi]}& )},
       DisplayFunction:>Identity,
       Frame->True,
       ImageSize->{Automatic, 100},
       PlotLabel->FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(n\\)]\\), n=5\"", 
         TraditionalForm],
       PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}},
       PlotRangeClipping->True,
       PlotRangePadding->Scaled[0.02]], {487.5, -160.}, 
      ImageScaled[{0.5, 0.5}], {100., 100}]}}, {}},
  ContentSelectable->True,
  ImageSize->{805.6666666666666, 327.},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.5336272601346684`*^9, 3.533627280975371*^9}, {
   3.533627317637312*^9, 3.533627393818671*^9}, {3.533627429946603*^9, 
   3.5336274430258303`*^9}, {3.533627486017456*^9, 3.533627506688431*^9}, 
   3.533627577230097*^9, {3.5336276111747417`*^9, 3.5336276542588053`*^9}, {
   3.533628365497795*^9, 3.533628374971241*^9}, {3.53362842145853*^9, 
   3.533628481990217*^9}, 3.533643706584751*^9, 3.5336457014757967`*^9, 
   3.533645740696294*^9, 3.5341677350790043`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot Angular Far-Field Scattering Intensities (Sca, Ext, Inc) of Particle\
\>", "Subsubtitle",
 CellChangeTimes->{{3.5215555775512342`*^9, 3.521555594875887*^9}, {
  3.521557503283558*^9, 3.5215575314578533`*^9}, {3.53236915680345*^9, 
  3.532369163918154*^9}, {3.5543512817043877`*^9, 3.554351282702311*^9}, {
  3.5543516203018084`*^9, 3.5543516394678717`*^9}, {3.5544490942935*^9, 
  3.554449096269092*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", 
    RowBox[{"k", " ", "R"}], "}"}]}], ";", 
  RowBox[{"m", "=", 
   RowBox[{"{", 
    RowBox[{"nParticle", "/", "nmed"}], "}"}]}], ";", 
  RowBox[{"AA", "=", 
   RowBox[{"abL", "[", 
    RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";", 
  RowBox[{"anC", "=", 
   RowBox[{"AA", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"bnC", "=", 
   RowBox[{"AA", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";", 
  RowBox[{"Nn", "=", 
   RowBox[{"AA", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
  ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"Nmax", "=", 
     RowBox[{"AA", "[", 
      RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]Min", "=", "0.001"}], ";", 
  RowBox[{"\[Theta]Max", "=", "180"}], ";", 
  RowBox[{"d\[Theta]", "=", "0.25"}], ";", 
  RowBox[{"\[Theta]T", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"\[Pi]", " ", 
      RowBox[{"\[Theta]", "/", "180"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Theta]", ",", "\[Theta]Min", ",", "\[Theta]Max", ",", "d\[Theta]"}], 
      "}"}]}], "]"}]}], ";", 
  RowBox[{"N\[Theta]", "=", 
   RowBox[{"Length", "[", "\[Theta]T", "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"S", "=", 
    RowBox[{"Signal", "[", 
     RowBox[{"0", ",", "\[Theta]T", ",", "anC", ",", "bnC"}], "]"}]}], ";", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"S", "[", 
      RowBox[{"[", "8", "]"}], "]"}], ",", 
     RowBox[{"S", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", 
     RowBox[{"S", "[", 
      RowBox[{"[", "10", "]"}], "]"}]}], "}"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P1sig", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
           "\[RightDoubleBracket]"}], 
          RowBox[{"180", "/", "\[Pi]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "S", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
           "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}], 
          "-", 
          RowBox[{
           RowBox[{
           "S", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
           "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]i", ",", "1", ",", "N\[Theta]"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Signal\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Theta] [deg\[Degree]]\>\"", ",", "\"\<\>\""}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "450"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ps", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
           "\[RightDoubleBracket]"}], 
          RowBox[{"180", "/", "\[Pi]"}]}], ",", 
         RowBox[{
          RowBox[{"S", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
           "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]i", ",", "1", ",", "N\[Theta]"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Scattering\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Theta] [deg\[Degree]]\>\"", ",", "\"\<\>\""}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "330"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Psi", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
           "\[RightDoubleBracket]"}], 
          RowBox[{"180", "/", "\[Pi]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{
           RowBox[{
           "S", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
           "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}]}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]i", ",", "1", ",", "N\[Theta]"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Interference\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Theta] [deg\[Degree]]\>\"", ",", "\"\<\>\""}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "330"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Pinc", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "\[Theta]T", "\[LeftDoubleBracket]", "\[Theta]i", 
           "\[RightDoubleBracket]"}], 
          RowBox[{"180", "/", "\[Pi]"}]}], ",", 
         RowBox[{
          RowBox[{"S", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}],
           "\[LeftDoubleBracket]", "\[Theta]i", "\[RightDoubleBracket]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]i", ",", "1", ",", "N\[Theta]"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Incidence\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<\[Theta] [deg\[Degree]]\>\"", ",", "\"\<\>\""}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "330"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{"{", 
   RowBox[{"Ps", ",", "Psi", ",", "Pinc"}], "}"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"\"\<Incidence\>\"", ",", 
   RowBox[{"S", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", "\"\<scattering\>\"", ",", 
   RowBox[{"S", "[", 
    RowBox[{"[", "6", "]"}], "]"}], ",", "\"\<Interference\>\"", ",", 
   RowBox[{"S", "[", 
    RowBox[{"[", "7", "]"}], "]"}], ",", "\"\<Signal\>\"", ",", 
   RowBox[{"S", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"\[CapitalKappa]0", "=", 
    RowBox[{
     RowBox[{"S", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "/", 
     RowBox[{"S", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.521875232886397*^9, 3.521875558977087*^9}, {
   3.5218757880366297`*^9, 3.521875788150342*^9}, {3.521876009594057*^9, 
   3.521876058404348*^9}, {3.521876485035236*^9, 3.521876512802659*^9}, 
   3.521876545743062*^9, {3.521877049650671*^9, 3.521877050124769*^9}, {
   3.521878031924686*^9, 3.521878044110024*^9}, 3.5219502985337353`*^9, {
   3.52195184908033*^9, 3.521951882023034*^9}, {3.521951925371306*^9, 
   3.52195192579802*^9}, {3.521962762836892*^9, 3.521962763323525*^9}, {
   3.521962974288122*^9, 3.52196299146996*^9}, {3.521963601146565*^9, 
   3.521963608655999*^9}, {3.521965142832019*^9, 3.5219651517416477`*^9}, 
   3.5219652782014637`*^9, 3.5219656750521603`*^9, {3.554202975791926*^9, 
   3.5542029942744102`*^9}, {3.554351153644259*^9, 3.55435118357586*^9}, {
   3.554351233072961*^9, 3.554351270055553*^9}, {3.554351314172612*^9, 
   3.554351359330682*^9}, {3.554362554552576*^9, 3.5543625624695997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.4333913644952218`", ",", "19"}], "}"}]], "Output",
 CellChangeTimes->{
  3.521875293313149*^9, {3.5218753256162243`*^9, 3.521875380293477*^9}, {
   3.521875473419138*^9, 3.521875559364884*^9}, 3.521875789122383*^9, 
   3.5218760588764277`*^9, {3.5218764860147133`*^9, 3.52187651326278*^9}, 
   3.521877055630748*^9, 3.5218780447515583`*^9, 3.521950305681384*^9, 
   3.521951830283215*^9, {3.521951871458392*^9, 3.521951882635838*^9}, 
   3.5219519263721523`*^9, 3.521951985851315*^9, 3.521952062814165*^9, 
   3.5219627648186913`*^9, {3.5219629757049313`*^9, 3.521962992347769*^9}, {
   3.5219631692492447`*^9, 3.521963178746463*^9}, {3.521963601947874*^9, 
   3.521963609769554*^9}, 3.521964404532782*^9, {3.521965144520755*^9, 
   3.521965153437274*^9}, 3.521965278998547*^9, 3.52196567539994*^9, {
   3.55420258602462*^9, 3.554202613312886*^9}, 3.5542027218803787`*^9, 
   3.5542028588662767`*^9, 3.554202994851462*^9, 3.5543511840632353`*^9, 
   3.554351271159692*^9, 3.554351363214361*^9, 3.554351490313079*^9, 
   3.5543516578421183`*^9, {3.554351695058728*^9, 3.554351729526361*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1384.2890545586408`", ",", "2431.4804118116936`", ",", 
   "1047.191357253053`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.521875293313149*^9, {3.5218753256162243`*^9, 3.521875380293477*^9}, {
   3.521875473419138*^9, 3.521875559364884*^9}, 3.521875789122383*^9, 
   3.5218760588764277`*^9, {3.5218764860147133`*^9, 3.52187651326278*^9}, 
   3.521877055630748*^9, 3.5218780447515583`*^9, 3.521950305681384*^9, 
   3.521951830283215*^9, {3.521951871458392*^9, 3.521951882635838*^9}, 
   3.5219519263721523`*^9, 3.521951985851315*^9, 3.521952062814165*^9, 
   3.5219627648186913`*^9, {3.5219629757049313`*^9, 3.521962992347769*^9}, {
   3.5219631692492447`*^9, 3.521963178746463*^9}, {3.521963601947874*^9, 
   3.521963609769554*^9}, 3.521964404532782*^9, {3.521965144520755*^9, 
   3.521965153437274*^9}, 3.521965278998547*^9, 3.52196567539994*^9, {
   3.55420258602462*^9, 3.554202613312886*^9}, 3.5542027218803787`*^9, 
   3.5542028588662767`*^9, 3.554202994851462*^9, 3.5543511840632353`*^9, 
   3.554351271159692*^9, 3.554351363214361*^9, 3.554351490313079*^9, 
   3.5543516578421183`*^9, {3.554351695058728*^9, 3.5543517304948*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw92ndcze0bB/AjeWQXeRDl2IVIaWp8tHenvevMQihZ8SinnYZOSJSRXUTZ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        "]]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"Scattering\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"\[Theta] [deg\[Degree]]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      ImageSize->330,
      LabelStyle->{Larger},
      PlotRangeClipping->True], {177.375, -107.07438855091928`}, 
     ImageScaled[{0.5, 0.5}], {330, 203.9512162874653}], InsetBox[
     GraphicsBox[
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw1mnc8190bxr+aGkqbhpVKEkqEissIWdl7fKc0ntKjoa0dDSrKLDQIlYQk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        "]]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"Interference\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"\[Theta] [deg\[Degree]]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      ImageSize->330,
      LabelStyle->{Larger},
      PlotRangeClipping->True], {532.125, -107.07438855091928`}, 
     ImageScaled[{0.5, 0.5}], {330, 203.9512162874653}], InsetBox[
     GraphicsBox[
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw1mnlcjOsbxkcLWSKU7FIiQkm7lmvaVFqmfa+ZaSaEdERlbSwRckpOC6Lh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        "]]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"Incidence\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"\[Theta] [deg\[Degree]]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      ImageSize->330,
      LabelStyle->{Larger},
      PlotRangeClipping->True], {886.875, -107.07438855091928`}, 
     ImageScaled[{0.5, 0.5}], {330, 203.9512162874653}]}, {}},
  ContentSelectable->True,
  ImageSize->{1076.25, 226.14877710183856`},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.521875293313149*^9, {3.5218753256162243`*^9, 3.521875380293477*^9}, {
   3.521875473419138*^9, 3.521875559364884*^9}, 3.521875789122383*^9, 
   3.5218760588764277`*^9, {3.5218764860147133`*^9, 3.52187651326278*^9}, 
   3.521877055630748*^9, 3.5218780447515583`*^9, 3.521950305681384*^9, 
   3.521951830283215*^9, {3.521951871458392*^9, 3.521951882635838*^9}, 
   3.5219519263721523`*^9, 3.521951985851315*^9, 3.521952062814165*^9, 
   3.5219627648186913`*^9, {3.5219629757049313`*^9, 3.521962992347769*^9}, {
   3.5219631692492447`*^9, 3.521963178746463*^9}, {3.521963601947874*^9, 
   3.521963609769554*^9}, 3.521964404532782*^9, {3.521965144520755*^9, 
   3.521965153437274*^9}, 3.521965278998547*^9, 3.52196567539994*^9, {
   3.55420258602462*^9, 3.554202613312886*^9}, 3.5542027218803787`*^9, 
   3.5542028588662767`*^9, 3.554202994851462*^9, 3.5543511840632353`*^9, 
   3.554351271159692*^9, 3.554351363214361*^9, 3.554351490313079*^9, 
   3.5543516578421183`*^9, {3.554351695058728*^9, 3.554351730586287*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Incidence\"\>", ",", "6.580461560983529`*^7", 
   ",", "\<\"scattering\"\>", ",", "317254.9451341895`", 
   ",", "\<\"Interference\"\>", ",", "557246.5580930237`", 
   ",", "\<\"Signal\"\>", ",", 
   RowBox[{"-", "239991.61295883416`"}], ",", 
   RowBox[{"-", "0.0036470331257882843`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.521875293313149*^9, {3.5218753256162243`*^9, 3.521875380293477*^9}, {
   3.521875473419138*^9, 3.521875559364884*^9}, 3.521875789122383*^9, 
   3.5218760588764277`*^9, {3.5218764860147133`*^9, 3.52187651326278*^9}, 
   3.521877055630748*^9, 3.5218780447515583`*^9, 3.521950305681384*^9, 
   3.521951830283215*^9, {3.521951871458392*^9, 3.521951882635838*^9}, 
   3.5219519263721523`*^9, 3.521951985851315*^9, 3.521952062814165*^9, 
   3.5219627648186913`*^9, {3.5219629757049313`*^9, 3.521962992347769*^9}, {
   3.5219631692492447`*^9, 3.521963178746463*^9}, {3.521963601947874*^9, 
   3.521963609769554*^9}, 3.521964404532782*^9, {3.521965144520755*^9, 
   3.521965153437274*^9}, 3.521965278998547*^9, 3.52196567539994*^9, {
   3.55420258602462*^9, 3.554202613312886*^9}, 3.5542027218803787`*^9, 
   3.5542028588662767`*^9, 3.554202994851462*^9, 3.5543511840632353`*^9, 
   3.554351271159692*^9, 3.554351363214361*^9, 3.554351490313079*^9, 
   3.5543516578421183`*^9, {3.554351695058728*^9, 3.554351730588223*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot Collected Intensity with Gaussian On-Axis Illumination for various \
Offsets, PHOTOTHERMAL SIGNAL ",
 StyleBox["((use H1) use \"+\" sign for nParticle!)",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]]
}], "Title",
 CellChangeTimes->{{3.5215555775512342`*^9, 3.521555626722288*^9}, {
  3.521557582146605*^9, 3.521557613622789*^9}, {3.521573346248959*^9, 
  3.521573352335272*^9}, {3.554441384450263*^9, 3.554441391369973*^9}, {
  3.554441603101145*^9, 3.5544416201711073`*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Test heating laser induced zp-scan of particle temperature \
\[CapitalDelta]T, compare to Lorenzian profile (",
 StyleBox["optional",
  FontSlant->"Italic"],
 ")"
}], "Subsubtitle",
 CellChangeTimes->{{3.554356073178849*^9, 3.55435612745815*^9}, {
  3.5543565928267603`*^9, 3.554356622889719*^9}, {3.554361014665251*^9, 
  3.554361018089764*^9}, {3.554361083240652*^9, 3.5543611433330793`*^9}, {
  3.5543617160983887`*^9, 3.554361718174564*^9}, {3.554364695148185*^9, 
  3.5543647080917883`*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dT00", "=", 
   RowBox[{"dTh", "[", 
    RowBox[{"0", ",", "\[Theta]T", ",", "Ph0"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T0Table", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"dTh", "[", 
        RowBox[{
         RowBox[{"z0", "+", "dzf"}], ",", 
         RowBox[{"Last", "[", "\[Theta]T", "]"}], ",", "Ph0"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "3000"}], ",", "3000", ",", "50"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"T0zRhTable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"dT00", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z0", "+", "dzf"}], ")"}], "2"], "/", 
           SuperscriptBox["zRh", "2"]}], "+", "1"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "3000"}], ",", "3000", ",", "50"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"T0Table", ",", "T0zRhTable"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Dashed"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", "Larger", "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<T [K]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
        "\"\<Particle Temperature: R=30nm, \!\(\*SubscriptBox[\(n\), \
\(m\)]\)=1.46, \!\(\*SubscriptBox[\(\[Omega]\), \(0, d\)]\)=281nm\>\""}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5543598062818823`*^9, 3.554359811615843*^9}, {
   3.5543604757003*^9, 3.5543604774519463`*^9}, 3.554360564656636*^9, {
   3.5543606141441517`*^9, 3.5543606144556026`*^9}, {3.5543607177193537`*^9, 
   3.554360825829049*^9}, {3.554360872663167*^9, 3.554360998639737*^9}, {
   3.5543611159384537`*^9, 3.554361127373369*^9}, {3.554361675947673*^9, 
   3.554361693509597*^9}, {3.554362102579032*^9, 3.5543621253106213`*^9}, {
   3.554441816731268*^9, 3.554441817405723*^9}, {3.554450435731859*^9, 
   3.554450441403302*^9}, {3.56275410869878*^9, 3.5627541095780563`*^9}, {
   3.562754167475437*^9, 3.56275417062718*^9}, {3.593959459086273*^9, 
   3.5939594613092613`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxdlXtMG1QUxiuv8WgHCNvK2rnSwDALj6LbYFnmDtANt2GEEWiraMamkSGR
ZoQBSgLM8hwESilQVrY+KMU4GFkIsGSDY9VJIrqooJLgrFucm+KCzdQ6YxB3
b/84NmmaX27vved+55zvxJ4oP/a6n0AgqFn//vf7+KN1Ymj96eTIgwJ4zEIn
KpfGGqs+5jwyjC5D+J9LR59grBzGivzEyv5vObsdGDF18t2tZX6Max34hVLz
4GaQP2Px+rohypT6HueJIVy7crzYlR/AOHcIr6e2PhWxIZDxih2nU+avT3zI
ucWOovv2elVbEOM4O3pXyorHXt7AGG24b9esvS49mHGRDesjzL322BDGXivm
aNo7g8ShjHuseCDxwY73pWGMFVYUlIbMXlIIGc9bcG1xS3FmgYhxiQXfaX/h
nw/ObWQcYMEyYcK2ocVwxnARGzo9QuVABOPqC3jIP/aMtCCS8fggrmiiVRrp
k4zvmXEs+JvK6N84y8z4qdzjaVqIYqw+jz9UZFWL5qIZdw3grzF9oqTPNjGe
M2F3+V+X+3/czFhgwvzSrM/TosSM0/tR54lcSFLHMNb24VTAyYe3J7fyfPZi
x62ZtzY+I+X5M+Jqgtbomt/G82XEV7L33H+7bTvPTw8mFV1V9U7JeD4MGCK/
tn90Npbr3422nerBTW4511uPOq930iWJ4/rqsSHw4KUtZ+K5nl2I0pTmR54d
XL9ONE+kTf7c+zTXqwPfHA02SN7YyfVpx7zGZIPhVCLXow0zl0NduY5k/v5W
vPlI3rRXr+DvbUZ5Bh7b83sqf18jFuwSxUt1z/L36LBmOjH8iHI3j/8sHgi8
GrF9fxqPtwFDDB1hm6v28vjqsHsGF5f+3sfjqcWvXrM5s79+jt9fg327jYsJ
IRn8vko8/r1kOedWJj//NGYuFGfcWVXy88px7Uj0T62Hsvn+UyiZjnGF3TnM
/38CRavXjIM3cvi6Bu+KS7Ne+uVFzofRJDT/4W/N47x+ZdXc6lFVvm8dvhsN
q3D5Ffj2Q+HzH8X7NRX6zocUye2xkRmV73648clyYMw5tS8+ePhq3t3CL9W+
+Om6u/J/+2vo+bJaej/UAYlP0QAkfjwL5H25OiDvdzcC0UfbDFS/ViD6drUB
0V/WDiQ/4x1A8gedQPJb0gUk/wo9kPrw6oHWTzeQ+moxAKm/3B4g9Sk2Aqlf
txFIfY/0Aql/bR+Q/kjvB9I/AhOQ/pozAem/rgEg/ak+D6R/ZWYg/X3PDKT/
xweB+EP1BSD+AReB+EuABYj/lFiA+NO8BYh/KaxA/K3HCsT/vFYg/lhkA+Kf
aAPir3F2IP7bYgfizyt2IP6dOwTE3yeGgPi/2AFkPtQ6gMwPtwPIfFEOA5k/
I8NA5pPQCWR+aZ3gm2//AiJrQOc=
    "]], 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxdlX9MG1QQx7vZwX4wobhih7iV8cMGNyziHLiFnlsHw7lRmAE0uCWLUzZN
qJKaNRYJBQS6Egq0FGiBlv6AjVXrQsimMxxZssDGMkWyzsWZxi0EccIcqB1q
ou69/nE2aZpPXt979753973EoxVFx1YKBALtv9//fh991ANY8uL+S4EkATzi
qAG0C+VLOS7Og148G3nlWodsBWOlF48Vf2LOGeYc9OCRi5djenJXMtZ5sFq8
OzcxyFniwRM9s4o9NY8xHnbjUOrCg7o0IWOVGzdvidhV+T3ney5skmUue62r
GDe68I2Uffsvl0UwTnbht77m+fqtkYyxH69XzU2diVzNuKwfp1WeG+sWOIec
mLPpxmj7nTWMzU5UxIxq9sysZSx3onHEXvdCaB3jSQf+GBn7hy1+PeNyB4rm
MtuuHXycsdCBP81U1Co6ohlDH/4pjcvP08YwPtmLEdkizdjzIsb+HrQ823XV
EOI8a8e9KQ/e+fJqLGOpHX9uNXcafE8wLrXhwgHZ2kN9GxibuvFr232rtV/M
eLwLK1P7flh9IY6xoAsdCXHDp+4+yTirE/PeLvbBMxsZq614PzB3x1gbz/PZ
gU7Tre3Jfz3F82fBqsTbuWLz0zxfFpw93mINHNzM82PG2E9jo9I7pTwf7Rhf
9LDE1JvI9W/D1O8UnqSvtnC9W/GKe9lw8/ckrm8r6s+cOxxdkML1NGGGrnvv
0EQq168FkxY/HJO9K+N6NeOvO+WF57PSuD5GbN7hG38zayvXw4BKzQmh+P10
/v4mFN3cpvxYI+fvbUCttiT9UiCDv68eN42d/ijwViZ/Tx3KnNn6hKTtPH49
fpZxzvjbxh083hqc/8LmvVuYzeOrxqHC+Ym+6Z08Hh0+1CWMbPDl8Pu1uHxE
0e1ZBH6fBgNTr9xeNb6bn/8BNl6YlotuKfl5Fbhm/flo/XN5fP9xXHS8rFFO
5vP/H0X/Ltu2z/2v8vXX8aXr9lphoIBzPkokp85GdRZyFgiKCipzfyk4FF6H
CMs3Dfv+fi28H8QZI2n1+uLw+XBgxejE0sWS8P1w+r1glcdQGo4Plg4XzhRP
lYbjp+tBzf/2a+n5Uh29H6qBxCevARI/6oG8T1UH5P3BeiD6qBuA6tcERF+T
AYj+UiOQ/PibgeQPWoDkt9wEJP/yViD1EWoFWj9tQOqrsR1I/anMQOpTYgFS
v0ELkPoe7ABS/2orkP7I6gTSP4IuIP013gWk/0zdQPqz1Aakf6V2IP09awfS
//4eIP5wsheIf0AfEH8ROoD4T7kDiD9NOoD4l9wJxN/MTiD+F3IC8ceyfiD+
if1A/DXZBcR/G11A/PmeC4h/q9xA/H3YDcT/JR4g80HnATI/gh4g80XpBTJ/
Br1A5lPUAJD5pR6A8Hz7ByThUs8=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  Frame->True,
  FrameLabel->{{
     FormBox["\"T [K]\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox[
     "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", TraditionalForm], 
     
     FormBox[
     "\"Particle Temperature: R=30nm, \\!\\(\\*SubscriptBox[\\(n\\), \\(m\\)]\
\\)=1.46, \\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(0, d\\)]\\)=281nm\"", 
      TraditionalForm]}},
  ImageSize->500,
  LabelStyle->{Larger},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.55435981244519*^9, 3.554359835794457*^9}, {
   3.554359899960209*^9, 3.554359914871399*^9}, 3.5543599456944017`*^9, {
   3.554359981500196*^9, 3.554359989342572*^9}, {3.554360453466264*^9, 
   3.554360477808206*^9}, 3.554360565051209*^9, {3.554360610354568*^9, 
   3.5543606149010983`*^9}, 3.554360718106029*^9, 3.554360833500416*^9, {
   3.5543608796812*^9, 3.554360897812716*^9}, 3.554360974524156*^9, 
   3.554361010158897*^9, 3.5543615406042747`*^9, 3.554361701517365*^9, 
   3.554362132036479*^9, 3.554441847165661*^9, 3.554450449923861*^9, 
   3.55720764092037*^9, {3.562754067083447*^9, 3.562754072392764*^9}, 
   3.562754133069693*^9, 3.562754193617496*^9, 3.593959450482807*^9, 
   3.5939595726915817`*^9, 3.59400367154683*^9, 3.594104926973011*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Setup lens (hot scatterer) & Angular detection domain & cold scatterer for \
normalization (",
 StyleBox["necessary!",
  FontSlant->"Italic"],
 "), ",
 StyleBox["((use H1) use \"+\" sign for nParticle!)",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubtitle",
 CellChangeTimes->{{3.554356073178849*^9, 3.55435612745815*^9}, {
  3.5543565928267603`*^9, 3.554356622889719*^9}, {3.554361726158996*^9, 
  3.5543617308142242`*^9}, {3.5765107007216463`*^9, 3.576510701458642*^9}, {
  3.5904691149579906`*^9, 3.5904691313405733`*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]r", "=", 
    RowBox[{"R", "/", "50"}]}], ";", 
   RowBox[{"L", "=", "650"}], ";", 
   RowBox[{"rT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"R", "+", 
        RowBox[{"\[CapitalDelta]r", " ", 
         SuperscriptBox["i", "1.3"]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "L"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"rT", "[", "]"}], " ", "is", " ", "a", " ", "Table", " ", "of", 
    " ", "radii", " ", "for", " ", "lens", " ", "discretization"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "=", 
    RowBox[{"{", 
     RowBox[{"k", " ", "R"}], "}"}]}], ";", 
   RowBox[{"m", "=", 
    RowBox[{"{", 
     RowBox[{"nParticle", "/", "nmed"}], "}"}]}], ";", 
   RowBox[{"AA", "=", 
    RowBox[{"abL", "[", 
     RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";", 
   RowBox[{"anC", "=", 
    RowBox[{"AA", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";", 
   RowBox[{"bnC", "=", 
    RowBox[{"AA", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cold", " ", "scatterer", " ", "Mie"}], "-", 
    RowBox[{"Coefs", ".", " ", 
     RowBox[{"(", 
      RowBox[{"detection", " ", "laser"}], ")"}]}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "=", 
    RowBox[{"{", 
     RowBox[{"kh", " ", "R"}], "}"}]}], ";", 
   RowBox[{"m", "=", 
    RowBox[{"{", 
     RowBox[{"nParticleh", "/", "nmed"}], "}"}]}], ";", 
   RowBox[{"AA", "=", 
    RowBox[{"abL", "[", 
     RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";", 
   RowBox[{"anCh", "=", 
    RowBox[{"AA", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";", 
   RowBox[{"bnCh", "=", 
    RowBox[{"AA", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cold", " ", "scatterer", " ", "Mie"}], "-", 
    RowBox[{"Coefs", ".", " ", 
     RowBox[{"(", 
      RowBox[{"heating", " ", "laser"}], ")"}]}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"\[Theta]Min", "=", "0.01"}], ";", 
   RowBox[{"NAd", "=", "0.75"}], ";"}],
  FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Theta]Max", "=", 
    RowBox[{
     RowBox[{"ArcSin", "[", 
      RowBox[{"NAd", "/", "nmed"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"180", "/", "\[Pi]"}], ")"}]}]}], ";", 
   RowBox[{"d\[Theta]", "=", "1"}], ";", 
   RowBox[{"\[Theta]T", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[Pi]", " ", 
       RowBox[{"\[Theta]", "/", "180"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\[Theta]", ",", "\[Theta]Min", ",", "\[Theta]Max", ",", "d\[Theta]"}],
        "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Angular", " ", "discretization", " ", 
    RowBox[{"(", 
     RowBox[{"for", " ", "plots", " ", "and", " ", "integration"}], ")"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Inc", "=", 
  RowBox[{
   RowBox[{"Signal", "[", 
    RowBox[{
    "0", ",", "\[Theta]T", ",", "s", ",", "w0", ",", "anC", ",", "anC"}], 
    "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Integrated", " ", "Incidence", " ", "Beam", " ", "signal"}], ",",
     " ", 
    RowBox[{"i", ".", "e", ".", " ", "Background"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.554356122315694*^9, 3.5543561909813633`*^9}, {
   3.554356626977358*^9, 3.554356722056929*^9}, {3.5543618376643476`*^9, 
   3.554361849765437*^9}, {3.5543626744219723`*^9, 3.554362683229292*^9}, {
   3.5543646469585667`*^9, 3.5543646490460043`*^9}, {3.55444092632076*^9, 
   3.554440979262781*^9}, {3.5572085317962847`*^9, 3.557208551031332*^9}, 
   3.572019412613467*^9, {3.572019450519211*^9, 3.5720194739498663`*^9}, {
   3.572020739787889*^9, 3.5720207412157383`*^9}, {3.5721716438793497`*^9, 
   3.572171645706451*^9}, {3.572194991696334*^9, 3.572194996093772*^9}, {
   3.572284337499907*^9, 3.572284340473062*^9}, {3.590469276248032*^9, 
   3.590469357778715*^9}, {3.590469389115734*^9, 3.590469412604969*^9}, {
   3.590469985264976*^9, 3.5904699859546337`*^9}, {3.593960565348743*^9, 
   3.593960565907098*^9}, 3.593963278017269*^9, {3.5940312601506166`*^9, 
   3.5940312611471977`*^9}, {3.5940312939814787`*^9, 
   3.5940312955827436`*^9}, {3.594104888194442*^9, 3.594104889442286*^9}}],

Cell[BoxData["131403.06191645676`"], "Output",
 CellChangeTimes->{{3.5543561299688787`*^9, 3.554356192101561*^9}, 
   3.554360590888171*^9, 3.554360651741777*^9, 3.554361850968369*^9, 
   3.554362147809157*^9, 3.554362731011569*^9, 3.554364649549491*^9, 
   3.554434958320434*^9, {3.554440833850151*^9, 3.554440855104302*^9}, {
   3.554440898956346*^9, 3.554440979745926*^9}, 3.554441109177408*^9, 
   3.554441142571896*^9, 3.554441230809401*^9, 3.554441276854361*^9, 
   3.554448888939465*^9, 3.5544496785951653`*^9, 3.5544498238612003`*^9, 
   3.554450420697639*^9, {3.554505756296371*^9, 3.554505779767385*^9}, 
   3.5545058299040422`*^9, 3.554524580097919*^9, 3.557207291602488*^9, 
   3.557207602665148*^9, 3.557394982352098*^9, 3.5627533438171263`*^9, 
   3.562753444776537*^9, 3.562753659613353*^9, 3.562754218662586*^9, 
   3.5720132454207497`*^9, 3.572014360161268*^9, 3.5720147327628927`*^9, 
   3.57201480113238*^9, 3.5720148843718348`*^9, 3.57201872966783*^9, 
   3.5720190376215353`*^9, 3.572019413413384*^9, {3.572019451239538*^9, 
   3.572019474679587*^9}, 3.572019527148179*^9, 3.572019673857142*^9, 
   3.572019802195821*^9, 3.572020170527852*^9, 3.572020307013609*^9, 
   3.5720207425608263`*^9, 3.572020877703088*^9, 3.572067240184198*^9, {
   3.572087505053825*^9, 3.572087516021521*^9}, 3.5720876644051456`*^9, 
   3.5720877378523073`*^9, 3.572087897684948*^9, 3.572088105156217*^9, 
   3.5720881430751*^9, 3.572088805075115*^9, 3.572088901435836*^9, 
   3.57208905017484*^9, 3.572090620724073*^9, 3.5721145314657793`*^9, 
   3.5721145906079283`*^9, 3.572165767083447*^9, 3.572170233093335*^9, 
   3.572171361275929*^9, 3.572171659275387*^9, 3.5721718292738123`*^9, 
   3.5721719712656813`*^9, 3.572172024896016*^9, 3.572172176105377*^9, 
   3.5721722191948957`*^9, 3.5721727371117496`*^9, 3.572194940373885*^9, 
   3.5721949968922853`*^9, 3.572252556062468*^9, 3.572253318161468*^9, 
   3.57225426578992*^9, 3.572254918900525*^9, 3.5722550688363857`*^9, 
   3.5722553196585484`*^9, 3.572284263841172*^9, 3.5722843486791563`*^9, 
   3.572284380383438*^9, {3.590468937201445*^9, 3.590468949604059*^9}, 
   3.5904690904263678`*^9, {3.59046938292089*^9, 3.590469413060834*^9}, 
   3.590469988605389*^9, 3.590470044812626*^9, 3.591877132687634*^9, {
   3.593958805731028*^9, 3.593958836468582*^9}, {3.593960567120627*^9, 
   3.593960592524935*^9}, {3.5939632795128736`*^9, 3.593963281878175*^9}, 
   3.594002348235551*^9, 3.5940024292856293`*^9, 3.594003547712229*^9, 
   3.594003917142478*^9, 3.594004074771771*^9, 3.594004208185945*^9, 
   3.594006983495316*^9, 3.594007171470408*^9, 3.594031191624083*^9, {
   3.594031261768219*^9, 3.594031302544799*^9}, 3.5940313573535852`*^9, 
   3.594031468862557*^9, {3.594104890628324*^9, 3.594104909061564*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "plot example of hot scatterer (",
 StyleBox["optional",
  FontSlant->"Italic"],
 ")"
}], "Subsubtitle",
 CellChangeTimes->{
  3.52157698243744*^9, {3.521619109724292*^9, 3.521619121363326*^9}, {
   3.554283940666645*^9, 3.554283951305451*^9}, {3.554284178652178*^9, 
   3.554284220170004*^9}, 3.554351081286964*^9, {3.554356784336389*^9, 
   3.5543567867985487`*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Get", " ", "Thermal", " ", "Lens", " ", 
    RowBox[{"{", 
     RowBox[{"an", ",", "bn"}], "}"}], " ", "with", " ", "Cold", " ", 
    "\[CapitalDelta]T0"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]r", "=", 
     RowBox[{"R", "/", "50"}]}], ";", 
    RowBox[{"L", "=", "650"}], ";", 
    RowBox[{"rT", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"R", "+", 
         RowBox[{"\[CapitalDelta]r", " ", 
          SuperscriptBox["i", "1.3"]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "L"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"x", "=", 
     RowBox[{"k", "*", "rT"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalDelta]T0", "=", "100"}], ";", 
    RowBox[{"m", "=", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", "nParticle", "}"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"nmed", "+", 
           RowBox[{"dndT", "*", "\[CapitalDelta]T0", "*", 
            RowBox[{"R", "/", 
             RowBox[{"rT", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]}], "]"}], "/", 
      "nmed"}]}], ";", 
    RowBox[{"AA", "=", 
     RowBox[{"abL", "[", 
      RowBox[{"x", ",", "m", ",", "0"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"anTL", "=", 
     RowBox[{"AA", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", 
    RowBox[{"bnTL", "=", 
     RowBox[{"AA", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", 
    RowBox[{"Nn", "=", 
     RowBox[{"AA", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
    ";", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"rT", "[", 
        RowBox[{"[", "L", "]"}], "]"}], "]"}], ",", 
      RowBox[{"x", "[", 
       RowBox[{"[", "L", "]"}], "]"}], ",", 
      RowBox[{"Nmax", "=", 
       RowBox[{"AA", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Plot", " ", "the", " ", "Thermal", " ", "Lens", " ", "and", " ", "its", 
      " ", "describing", " ", "coefficients"}], ",", " ", 
     RowBox[{"also", " ", "plot", " ", "the", " ", "BSCs", " ", 
      RowBox[{"(", "gns", ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P1", "=", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"rT", "[", 
            RowBox[{"[", "li", "]"}], "]"}], ",", 
           RowBox[{"Re", "[", 
            RowBox[{"m", "[", 
             RowBox[{"[", "li", "]"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"li", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thin", ",", "Red"}], "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"{", "Larger", "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<m\>\"", ",", "\"\<\>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\<xl\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "350"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"m", "[", 
           RowBox[{"[", "L", "]"}], "]"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P2", "=", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"rT", "[", 
            RowBox[{"[", "li", "]"}], "]"}], ",", 
           RowBox[{"Re", "[", 
            RowBox[{"m", "[", 
             RowBox[{"[", "li", "]"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"li", ",", "1", ",", "L"}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}]}], ",", 
       RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"m", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Pab", "=", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Abs", "[", "anTL", "]"}], ",", 
         RowBox[{"Abs", "[", "bnTL", "]"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Black", ",", 
            RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}]}], "}"}]}], ",", 
       
       RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"{", "Larger", "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\) (black), \
\!\(\*SubscriptBox[\(b\), \(n\)]\) (red)\>\"", ",", "\"\<\>\""}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"\"\<n\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Pgn", "=", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{"gnMLA", "[", 
           RowBox[{"n", ",", "s", ",", "0"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "45"}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Black", ",", 
            RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"PointSize", "[", "0.01", "]"}]}], "}"}]}], "}"}]}], ",", 
       
       RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"{", "Larger", "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "\"\<|\!\(\*SubscriptBox[\(g\), \(n\)]\)|\>\"", ",", "\"\<\>\""}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\<n\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"GraphicsRow", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{"P1", ",", "P2", ",", 
        RowBox[{"ImageSize", "\[Rule]", "350"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"m", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"m", "[", 
            RowBox[{"[", "L", "]"}], "]"}]}], "}"}]}]}], "]"}], ",", "Pab", 
      ",", "Pgn"}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5215576356590014`*^9, 3.5215576421910267`*^9}, {
   3.521557743108536*^9, 3.521557744612166*^9}, {3.521558250086626*^9, 
   3.521558276837631*^9}, {3.521566125846176*^9, 3.5215662663818493`*^9}, {
   3.5215671885802803`*^9, 3.5215671970197763`*^9}, {3.5215672579185457`*^9, 
   3.521567262476103*^9}, {3.52156745251976*^9, 3.52156745383994*^9}, {
   3.521568220756316*^9, 3.5215683494438763`*^9}, {3.521568406155428*^9, 
   3.5215684121232862`*^9}, {3.5215684750870533`*^9, 
   3.5215684859853773`*^9}, {3.521568545479948*^9, 3.521568545648259*^9}, {
   3.52156883055453*^9, 3.521568831024571*^9}, {3.521568881999848*^9, 
   3.521568933197855*^9}, {3.5215689664725723`*^9, 3.521568976041115*^9}, {
   3.5215691164808292`*^9, 3.5215691189452047`*^9}, 3.5215715670219193`*^9, {
   3.521572674523011*^9, 3.521572713110434*^9}, {3.521573254211011*^9, 
   3.521573254577627*^9}, {3.5215733955019693`*^9, 3.521573425711733*^9}, {
   3.521573529906595*^9, 3.521573531159856*^9}, {3.521573561833393*^9, 
   3.521573608117778*^9}, {3.521573640119644*^9, 3.521573649127789*^9}, {
   3.521575330100011*^9, 3.5215753303400297`*^9}, {3.521576985146452*^9, 
   3.521576990313398*^9}, {3.5215770337969027`*^9, 3.521577158702272*^9}, {
   3.521577352390764*^9, 3.521577353280781*^9}, {3.5216080047502203`*^9, 
   3.52160800587633*^9}, {3.521612502072383*^9, 3.5216125024060287`*^9}, {
   3.521612536343642*^9, 3.521612639555977*^9}, {3.521612672069219*^9, 
   3.5216127404988117`*^9}, {3.521612776494451*^9, 3.521612833352406*^9}, {
   3.5216135020085087`*^9, 3.521613502332265*^9}, {3.521613706558137*^9, 
   3.52161370804529*^9}, {3.5216144529248657`*^9, 3.521614453735558*^9}, {
   3.521616205744657*^9, 3.521616218810028*^9}, {3.5216168483146067`*^9, 
   3.5216168485761127`*^9}, {3.521616888887858*^9, 3.521616923389971*^9}, {
   3.5216170252721643`*^9, 3.521617042686904*^9}, {3.521617391873863*^9, 
   3.521617403104624*^9}, {3.521619265906094*^9, 3.521619281531039*^9}, {
   3.521623559171133*^9, 3.521623562604604*^9}, {3.521623595536106*^9, 
   3.52162363869447*^9}, {3.521623735610787*^9, 3.521623743216909*^9}, {
   3.521625638970956*^9, 3.521625787119972*^9}, {3.521633727408403*^9, 
   3.521633752618956*^9}, {3.5216460866861258`*^9, 3.52164608693714*^9}, {
   3.521646132483424*^9, 3.5216461590614634`*^9}, {3.5216462216179943`*^9, 
   3.521646233502719*^9}, 3.5216462818482323`*^9, {3.521646316407342*^9, 
   3.5216463181138678`*^9}, {3.521646353630725*^9, 3.521646353772645*^9}, {
   3.521646843981039*^9, 3.521646844309434*^9}, {3.521647312910101*^9, 
   3.52164731644438*^9}, {3.5216476199458113`*^9, 3.521647622243301*^9}, {
   3.5216476969332657`*^9, 3.5216477742548437`*^9}, {3.521647808106584*^9, 
   3.521647809066098*^9}, {3.521648160075623*^9, 3.5216481607202387`*^9}, {
   3.521648197931155*^9, 3.521648230078108*^9}, {3.524470599303907*^9, 
   3.524470600840343*^9}, 3.5244706468020897`*^9, {3.524478585464332*^9, 
   3.524478585941533*^9}, {3.524479314913669*^9, 3.5244793394408073`*^9}, {
   3.524479533428876*^9, 3.524479533579075*^9}, {3.524479817259025*^9, 
   3.524479818123465*^9}, {3.52447995883471*^9, 3.524479967305272*^9}, {
   3.524507530915029*^9, 3.524507541264079*^9}, {3.527398911908717*^9, 
   3.527398921090366*^9}, {3.5274002127402897`*^9, 3.527400213485952*^9}, {
   3.527400267003109*^9, 3.527400279255248*^9}, {3.527404298158904*^9, 
   3.5274042986419563`*^9}, {3.527405333410939*^9, 3.527405339833091*^9}, 
   3.527405451686091*^9, {3.527405902922038*^9, 3.5274059042164927`*^9}, {
   3.5274072723185673`*^9, 3.527407272963524*^9}, {3.527407434273479*^9, 
   3.527407435341906*^9}, {3.5274075778907127`*^9, 3.5274076090404997`*^9}, {
   3.527409426066761*^9, 3.527409427706039*^9}, {3.527410456219054*^9, 
   3.527410457384622*^9}, {3.527415548680018*^9, 3.52741557771146*^9}, {
   3.5542833528056517`*^9, 3.5542833749951*^9}, {3.5542838708918257`*^9, 
   3.554283871014517*^9}, {3.554283977252385*^9, 3.554284000480281*^9}, {
   3.554284040084649*^9, 3.554284059231299*^9}, {3.554284152130681*^9, 
   3.554284164117503*^9}, {3.554284308582251*^9, 3.554284327723525*^9}, {
   3.554284519531152*^9, 3.554284547836619*^9}, {3.554284640436224*^9, 
   3.554284641464406*^9}, {3.5542846914045258`*^9, 3.554284699815111*^9}, {
   3.554285627911924*^9, 3.554285645663962*^9}, 3.55428662713776*^9, {
   3.554302484003981*^9, 3.554302484434682*^9}, {3.554302648319858*^9, 
   3.5543026661707563`*^9}, 3.554303233203664*^9, {3.554351047586779*^9, 
   3.5543510483863707`*^9}, 3.554362698114582*^9, {3.554364635260355*^9, 
   3.554364638602092*^9}, {3.572284432711928*^9, 3.57228444690273*^9}, {
   3.572323079804924*^9, 3.5723230800672197`*^9}, {3.572323116913885*^9, 
   3.572323118013575*^9}, {3.572332050462388*^9, 3.572332056080078*^9}, {
   3.572333478609724*^9, 3.572333483678109*^9}, 3.572333531818612*^9, 
   3.572333941880986*^9, {3.5723340437028112`*^9, 3.572334044804538*^9}, {
   3.572334082534005*^9, 3.5723340827867126`*^9}, {3.594002360586355*^9, 
   3.594002377153871*^9}, {3.594003949872304*^9, 3.594003950530683*^9}, {
   3.5940040506086483`*^9, 3.5940040616849194`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2746.873115049814`", ",", "39.68236958088931`", ",", "71"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.521568225390716*^9, 3.521568261232119*^9}, {
   3.521568302528158*^9, 3.521568354431093*^9}, {3.521568408410294*^9, 
   3.5215684140827847`*^9}, {3.521568478089944*^9, 3.521568488103136*^9}, 
   3.5215685501277523`*^9, 3.521568834729026*^9, {3.521568888868875*^9, 
   3.5215689355685663`*^9}, {3.5215689703295803`*^9, 3.521568978442792*^9}, 
   3.521569017938656*^9, 3.521569124213769*^9, 3.521571570470378*^9, 
   3.521572638682838*^9, {3.521572704601987*^9, 3.521572716912177*^9}, 
   3.5215732598966618`*^9, {3.521573400590642*^9, 3.521573430634733*^9}, {
   3.521573526730093*^9, 3.5215735361786127`*^9}, {3.521573577619235*^9, 
   3.521573613096162*^9}, 3.521573653772987*^9, 3.521575140855959*^9, 
   3.521575335144272*^9, 3.52157655428821*^9, 3.52157695041184*^9, {
   3.521577057849348*^9, 3.521577117399819*^9}, {3.52157714808532*^9, 
   3.521577163162632*^9}, 3.5215773579399223`*^9, 3.521607339508292*^9, 
   3.521607926532016*^9, 3.5216080105524473`*^9, 3.52161250727092*^9, 
   3.521612559622246*^9, {3.5216125916162977`*^9, 3.521612613426138*^9}, 
   3.521612643904101*^9, {3.521612679850572*^9, 3.521612747782002*^9}, {
   3.52161277986202*^9, 3.521612834447328*^9}, {3.521613503812934*^9, 
   3.521613527459951*^9}, 3.5216137230097647`*^9, 3.521614455162567*^9, 
   3.521614675131405*^9, 3.521615082172214*^9, 3.521615599574542*^9, {
   3.521616211738356*^9, 3.521616220762095*^9}, 3.521616850996337*^9, {
   3.521616893834407*^9, 3.52161692515396*^9}, {3.52161703456593*^9, 
   3.5216170445167513`*^9}, {3.521617397129939*^9, 3.5216174057857313`*^9}, 
   3.5216211630292053`*^9, 3.5216235637076406`*^9, {3.521623605598248*^9, 
   3.52162364013445*^9}, {3.521625641736467*^9, 3.521625788379078*^9}, {
   3.521633738833371*^9, 3.521633754013761*^9}, 3.521646088064863*^9, {
   3.52164613668686*^9, 3.521646160226124*^9}, {3.521646223605152*^9, 
   3.521646234682745*^9}, 3.521646283023024*^9, 3.521646319311057*^9, 
   3.521646355120262*^9, 3.521646845908127*^9, 3.521647317804397*^9, 
   3.5216476235614433`*^9, {3.521647698035398*^9, 3.52164777553265*^9}, 
   3.52164781029401*^9, 3.521647852866004*^9, 3.521648161841978*^9, {
   3.5216481991687803`*^9, 3.521648231209494*^9}, 3.5244706064773417`*^9, 
   3.524470648882638*^9, 3.5244785884615583`*^9, 3.524478928166471*^9, {
   3.524479324357978*^9, 3.524479342413069*^9}, 3.524479373581811*^9, 
   3.5244795368972178`*^9, 3.524479583502339*^9, 3.524479821059422*^9, {
   3.524479962584749*^9, 3.524479969887472*^9}, {3.524507534191636*^9, 
   3.524507544256336*^9}, 3.527398924956287*^9, 3.527400216681229*^9, 
   3.527400282406777*^9, 3.5274043023605328`*^9, 3.527405343699686*^9, 
   3.527405458579571*^9, 3.527405907804434*^9, 3.527406204440177*^9, 
   3.5274072771072206`*^9, 3.527407443516842*^9, 3.5274076137066727`*^9, 
   3.527409440118637*^9, 3.5274104694073*^9, 3.527415662357574*^9, 
   3.529215470298458*^9, 3.529215527270708*^9, 3.554202854488174*^9, 
   3.554213325458521*^9, 3.554283876685897*^9, {3.5542842393630743`*^9, 
   3.554284256384837*^9}, 3.55428433080551*^9, {3.554284535640851*^9, 
   3.5542845497951202`*^9}, 3.554284645086898*^9, 3.5542846758730373`*^9, 
   3.554284849201388*^9, {3.554285632851495*^9, 3.554285650440641*^9}, 
   3.554286335737341*^9, 3.554286630873106*^9, 3.5543024883975677`*^9, {
   3.5543026238340187`*^9, 3.5543026713648043`*^9}, 3.554303321180629*^9, 
   3.554303372136487*^9, 3.554304018687449*^9, 3.554351076349028*^9, 
   3.5543627366685*^9, 3.554364642797277*^9, 3.562753808218732*^9, 
   3.572172225811096*^9, 3.57228426887582*^9, 3.572284352945916*^9, 
   3.57228438617841*^9, {3.572284439047213*^9, 3.572284456383993*^9}, {
   3.572323096267486*^9, 3.5723231235835857`*^9}, 3.572332125186091*^9, 
   3.572332807456751*^9, 3.572333591775391*^9, 3.5723340600651817`*^9, 
   3.572334092541346*^9, 3.572360649640194*^9, {3.594002364589574*^9, 
   3.594002381549979*^9}, 3.5940039588910837`*^9, 3.594004071569335*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        {RGBColor[1, 0, 0], Thickness[Tiny], LineBox[CompressedData["
1:eJwV13c8Vl8YAHBFKXt7532p/LKyGpLqfZBKUpQQskIlSiUjIZGRikQiJQ2F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          "]]}}, GraphicsComplexBox[CompressedData["
1:eJzt3PlXzdv/wPHI2KC5znzKlXkoc8J5VTIliiQVKpmLTA0iEiUhQ6RkHitN
mlCkUCQpzRGiaKCjJDL1fZ213q/35w/4/tpPdz3W6Zz3Ofu933vfu9bzbj2X
TQtX9ZSTk4vqKycn++eZcsXOaxMUQaM9ZeIUE6mkOSMRJiz/n2/3S1vMO60I
89unFf+YIZVoDfD4kVWlCGdDt64cPVcqMY6O0lLSVYJVZ+emNS2QSp61uIab
rlOCql3/7r5aLJXsaK1ZZpaiBC1evvPKHKSSPsOT88zllOHbTKWTmc5SSU7K
8ojb85TByXR96p41Uomd6WVrgwhlmLjYWqTjLpUkp09d5livDJZqL7b5bJFK
fO1Xy8kZDoCGjLhpV7zwestKNn/xHQDNtw/+OrlTKrl//Lldz9wB8Ldu0+H5
/lLJpcP1k/RVVCCh6lZ+4X6ppGrnBV+zJSrQo95lOOegVGL6af2/BedUQOxS
FDryiFSissD3vUmdCqw0rtAdcFwqSdLpKAvWVIXf6w8NzToplbxblm/uPFEV
ujIm9TSNkEoyleM/XVuiCoO8XBQioqSSlI6ySQ7equDYa0VY7nmpxDXy1dLd
p1VBKZb/oeCSVBJxtO6b5m1V8C1yHhR/VSr5a9GuKqpQhSe3Xru73ZBKzhf/
6Hf2uyoYNLhl9I+VSuZ4r3cP01AD1+HuLUFxUsndIwmdfQzVYM3oK88bEqSS
xsQNgT8s1aDwbGLv0bekkr0all1r16vBS3g6bGmKVNJwtdB+eaAaBA9OTdmQ
JpU4e58+UX1RDYo/f+y/5jaOX5rh5XeZavD2eaznvLtSycz83F1bK9SAa7Jy
nDBTKhl+vnjAqVY16BCmu1bfk0qCjX0nWiiqw+PgQsH+LKnEZurJvJOD1OFP
ppejKFsqeVWkEug9TR3W/zPXvJ4jlUjiy/Q7FqtDy6hL+rqP0Jt+z1HbqA7l
rQUrDz7G3681bl/BfnUQDHwZ9jFXKqlV8bIZflYdrm503zLhiVRSNO/90FEp
6hAU8C7G66lUEv/k5rKKfHW4LMqojcvH77fSfNqIWnXIiT6ZWPlMKokTBMiN
+KEOVXJZ138WSCWKpQ2FlUoa8Eb7zfwBhVLJFe8f9ycO1IAIgwP6vBdSiYFd
SPnMSRpwyK3gsqBIKjnwyERRcZ4GnLFInaJdLJVIn9aZ7nfSgOUND2z6vsT3
a71alL5NA5ICrGy/onP3Rva+fEADrvVSPVdcIpWYKwrU5kbh3/ew3R9bKpWE
a1vpxSdoQK+anU5+ZVLJQ+vjJUU5GjDMb8LuueVSieZqwe3kMg0YyikdqVoh
lWzs47XQrkEDRviEJ75A6zc0cB/80oDMmc2WwZU43jYffD4racLtg1dnTKuS
SmLU3V6+EWmCpFlS3Iweu3uf92kDTVhVqzTqZLVU4hJzOI1nqgl/jNcdMXol
lchvjC5YvUgTHk9oGlqFLlzPad3lqglSpwOjtr2WSuybwqyct2uC55W8fIUa
vD/XYgaoB2rC1oDXI8+iXfYozjx2ShOyagt3jXgjlZwbUtvv3TVNiNweWZ+K
ji7iO3el4eepWR6c+hbdec/qa64mJLUOPJqFXm+v/zK5XBO8h13kSt5JJfdU
rCvnftSECOf4WRnoIB39BWnf8fo/o43G1+L4j43l/+ilBZwYf+UYdMgMa8EA
TS1Qrnz8VvAexxf0h/0ZqAUuBzOfHUJPfjxAM8dQCyJha3MnOs2jT7QTaMHn
6y+WuH6QSkwULeIr52vB/Lnnhxagd0WE1Q1fpgWrZ1/bZlgnlZx1M+9rt0EL
xo6Jsw5D28yIKHDy0YK8n4dL29ELT72sNw/SguszQW1RvVSydcDqrr4nteDZ
+zpeAlrfflD29UtaUHyiSL7/R6nks5VLoX6iFqQsOFXjhF4QIs7de08LAipU
76Shq71HmGXlawE/d8M1hU94/3rPef2qAt/PG5nqiI57ZTWoqk4LYmZPbr+J
NrJbGJPeqgXvi99u/o1+Oi650+ufFgzxem88u0Eq+dhpGclT1AbzHl4rTqD9
bUJVL+hoQ2ysdeNr9NYpx2v6DdKGYxNi6gc1SiWPlIx3LzbQhuXnTZw2oHnx
1h6BU7XBJmKNayLa6Xzk0KjZ2jDvRtefb2jtkVJBuI02/OkVOH5ik1SyLNEm
y8tJG5qNNLW80Mt7auye7qYN7wNW3UhDT+yX/6TZSxvO/6z+0Y4eGxDYZ0+A
Nih47VYa24z3n1N+/vcRbRC5Kkrd0f0vVncuj9SGA5Mart9A6z109Iq5qg0p
1eMk79Fx9TXebxK1ofH1w0zeZ/w9vtGOvzO04aXf0KEL0TNu1fv1yNOGivCE
AwfQmQcvG7UWa4PpkjX199BNy1vq8l9rg90HXfM29KOa6vIjn7RhaOWWeP0v
UsnPPSdXTmvD7389Y4gdesNej5ryP9qw9M1/6cHoY7atYQ59dQDmXHC5K3s9
sabymZoOnOvTPqYJ3aAxu2OIQAfu7rg1iNsilXB/n5nsMVgH+owxmTkL7XM8
uvGKgQ50RlZFbEOvVU2yzp2iA5MqDw66iM6IdU8vnaED7abGzQVowQRdp6L5
OnCrb0zbD3SNbUToHTv8+/MekoFSqSTMz+zAURcdSDPqVW6Brtk6MmSxmw58
56bf3YZecn5AZT9PHbCovdMahW7uZR8Xs1sHhjwX7H6EHtU+dbZxsA58/Vi0
uhkdu/lm3d3jOlAwOPqm2lfcnx3c7g2L0gGVgw42k9DBljpKB67qQIVwr7Mj
eqLp4P7l8Trg8e9MxR608+8fzRq38e/nDbh7BW0xsrLJJFsH7LT0lZ6gndz6
GDvl68DEyZrFTeiWtkzVTSU6EGD0U1G5VSrRFU06v/E1Xl+jIms0um9eOmdF
vQ7k/70gXYAOdw2NhxYdyBtqeM4DDV16xzR+6MAWr/mFR9GfOj5LK7p0wGnU
zb2J6IyoQ52H+3HgTHjTvRfoo5eyX01Q48Cx+PC9LWiRs+fDF1wOJCSNKVFq
k0oudzx87TCQA42ZwlvD0UaSHwurh3PAzy5Tb7bMN05aWYzjwCh520Gr0B/e
OnfFG3PAMF0/0x990MXpQO8ZHOCuX9J8Fu3+8ZXGgnkc+BDUL+UO2ur6uqch
NhxwXTebU4b+ffzLiwxHDszN5fC+ok8vOWf51pUDHwduzFD4JpV02vRf2+HG
gbdGBv8Goe9s1p7RYzsH+rtMqZuO1i1T7CO3iwMBXx022aGTAo8Vt+3jgCTc
7uJm9NT2lKdVhzgw9EGD70G01YrPqqlhHPhZd0fuMvr+WN7TfVEcaPuw0TAD
rWVyVGPOFQ4ct76gUoK+9VldredNDrjkvY5qQo+Z8ro2IZkDcgbR1T3apZLy
5+euLszgwF5V/3wOOq/0gG9TDgdmvyh3H4N2r5651yufAw4/NXLN0W8O9qns
LOaAz+6IUgf0CxefyM1VHHjelRW5GR1qWfHxzTsOHOqs4AahEw1rq0waOLBF
efiiKNn73T6ERko5YDbxx6wktJPk9qDGDg4skfPpfIx+OiQ/edQ/DizIql1b
jbYeo223tjcX+uU4hreg5w0ZPTJCiQt5+wYE9vwulYyvnDL3gQYXims1J2qj
rw7896yGxwVHCLoxDF2kXpbfqscFuRzPN1PRiR/vrPgzlAu3N7ZULkBv7zvz
8t8xXHBe8e20C3pvR3Lc94lc+PFxn3g72mZ07am6aVxYdzfKPQid9GOBZ/4M
LkzXGbMvAu01btjK6xZcaG0Y7hqLXsqdvs13IReGf/EZcA/9rrn/g5lLufCi
XG5fIfrXxWTH/k5ckPc4//gtenWgitPD1VxQyzAo/Yo2e37h7TZ3LixRD0ns
0SGVDNA981W4jQtTZu1xUEdb6dZdv7+DC7wHNWUD0ZNqNXlL/Lmw4aSb7ji0
u52vw6cgLjTEtRqboZfm8vdsOsKFj1Wjhi1CK2rfOiMN40Ldl5oGFzRvQnL2
mjNcmPr6ru8WdNjK+b0rL3JBr9DnvT/acudGH7jBhWrjAuEx9N0JGQYX47lg
1stp9AV0kEPktF8pXLgQ8FYzAS3oYXjLIoMLz6Nbi++hLeJcL5zM5sIdlSmr
C9Azd7/mVuZxwUpp6ctqtLplTwONQi5kP2nWbkRfy5Bvn1mK38fm0Pgf6LdW
JZ5bq7mgnF48ovcPqWTd7mFPT7/jAvS2+quOLr25/3faRy7c9DgdrYuWGo4R
FX7mQoi9keFodOTiiSZv2tCu98OM0SNMt2/79BPvt39i6Wx04PejeY3/uPC9
16nWxWjxyF9z6nvxYEBKW7MLunFmi0K1Ag8Ol8x6tAm9eaQ394kqD2wmafru
RA/V37wvQZsHF61KVYPRnGR/+6MCHvw3tWfgSbT8qoEx6wfy4PILrVcX0fpX
o/ynD+XBnOv7VOPRFwMUpYqj8fPH5gy+i87c6ShXMo4HTx9IRLmy9xtbPTxh
xIOAw24/itEei33N50t4YFmQeqsGHdN/VlhPcx6sSwm0akT7trVmJs7lgc6h
2cXt6KC7RwvsrHgQmuwyQe6nVLLt2YCiX4t5kJ0wZZci2rtzdOkpBx7kjh8f
rY0OGHGofqQzD+QNku7ooXvKRareW80Dzku1hJFoh41XnWe58eDA6ZTgSWij
VWV1zzbzQLikY44p+uaqEdfmevFAw2Ts13nomfx9SQ938qBvW/bOJWjD1nD1
SXt5EO/5V+qMXnbld+mVIB5YLTae64Z+9VK3l/JhHiieKgrxRK8+YBu76TgP
GvNVU/fIrvfkaVlBOA8ydebnHkRP0ww8MugsD/KNqrLC0Gdat7/zvMQD89Ae
l86hn65fWf7wOg/OiLTcb6C5oT93KMbx4ORZJ71b6FppVqXlLR6YeI/JykBP
5uv/OpjOg5yKZzMfo7drbm/MyeTBpxt+twtlvz//TeL3bB6cvRSqWYnWDtlq
/18evn+euUMtWtlzyFeLAh5kyNcfakKHNxf7birmQZB8cvQ3dMSvUX2PlPMg
ZG1b0h/0iILqM9df8aBoUv3V3p3471fKjmaZ73ig7lqwfwCaZ8vrW1DPg6kl
n6x10OePrvxa3sSDpJWeCrrobIcN/WqkPAhsTU0Yim5xt7B7086DQw4fTAzR
9t/lG6s7eWB9YEq2EfpKh+/Dl/940Lq+Y5QpOi/a/+tjeT4U9bU+MBe9rCzf
O6UfHyQ+AUUL0bOGfnc9p8yHX98e93FA3z8WeC9AnQ8RzxaMWIkuDP9y0FWH
D288l0zfgF54078MBHz4dEIdtqI99gRc5ejxYfHnVANf9FlbofxnfT5Y+WxX
DUAbLlrZcXc4H7zW7Ht7EB31bFHQ/jF8uM3TOnccPSas4p7FeD7wxi6dF4mO
nJdzUdmID6tC/JsuotVjX055No0P92fe945GD8u9dXSfKR8M8qf/SES7L/sZ
YzSLDxqPDVfflo2Xrv6xJgs++Ix7/DgLvb/j2txwKz5sch6snYcOhso3ksV8
MGrxX1KIfi2WW1y3lA87XsgfLENvTV+Ysm85H+bYVMS9Rie6t8rrrcS/Hzrk
4Qd05cjmuXfW4Ou2wvwmtNulqUct3fjwzOJDTivab1dRdY0HHya+uhj3E90Z
u9tw/XY+fJ3uf7ALXXdK7UybDx/+8aOX9vkllSQsmyry8uND0j7gK6N3q17N
/rGXD9N+u7/QQAc3vg3ZFsQHk21LPHnoPfs9Ar6E8MFy6UBVPbQ2Pz/e5Sgf
ZoV8ixqCDk9aoFkaxodXrlLBaPQVW5u7JhF8yM00OjoerbKIfz32LB9GN3zv
mIJ+vbzyndolnB+ZM61N0J6lCe7bruH1Tsw/Pwvd90PaopIYPqjMGVNriVZ+
8O306AQ+1Jgq6NigxZXLzAKT+bB9o5yJPfrbvxq76nQ+FM4Yu8IJfebc/LfD
M/mgWJC1eTVa9aPva68HfFgT8cTbTfb3Hf/ZZj/iw8CSDdu2oK+q/7Du+5QP
DmOfuHrLvn9ueNmc53xo6PVnjh96CufMxwPFfNAdoz9on2w8Eg4cfFTGh7Oj
nL8Fo1N7vMr9U8WHNu3n6aGyz9/RdcHwDR9cz+7ffBI9+bqtaOV7PoSoXtc9
g662Hz/j2Ec+fFtu+fgC2rr6rU5mEx/SdMJWXENv6xF27kMLfn+3U9JY2fit
313T9xveb4NN25PQbcceVQ39wYffbye3pqGd5XacnvmbDxMilVdmorvWx4ic
u/gwYmjfZ9lo/Wqbzd7yAuj/Z/qwPNn9L3A7eaivAMrHFu4qQJs4VIeeVRTA
q5PPnxSjlRx2rIpVEUDrmcUKFeiee0T8NA38+/V+pq/REX6HU+/pCGBz5YrN
tegeowKMcvgCELuphX9EN15OjH0oFkDdipjkZvS95ZmqOf8J4NZFk7yvaG8H
U/d7QwQQUvql+Dv6p1Hp49QRArhr/bjkF7rWvlMUO0YAX4a9KehCK/wbvevs
OAGsGjz/Xq/fOP5ODXWHJglAPn/41f5ojeoj9j7GAnBbGLxvANrvl/97F4kA
lO74OWigxdd0/OeYCWBsing4Bz1rbNSUUbPw9dt7vgrQw/wXagywEED8j9R4
PfRS4TaVz/MFoLq6xHUwutXGcFzeQgEopH9WH4Geb5O097ytAEydtO6MQW8B
9Z7b7QWgH+m0ZDy6p/W61FnLBfDCqfbLZHRzY84FHRcBtG2L2TkNHZMy8End
KgHcdyyUN0Ub3QkYk7BOAJmuKwJmoq95VlZ7ugsg6cKm33PRC38rFBpvFsDG
z6puC9AVf/4o/dsmgOjPNmWL0BelQWfueQugUMVykh16lGjXrh07BZB/ROG4
I/pP1tW08Xvw/rmfq3dCj1V9OPdzgACMd3HHrkI3rDwy7WKQALTsD3mtQxvA
neOLQgSgualvmju6aNMXS/lQAUz4HvllMzqa83xL4nEB7Gm3FXmi3xW19XI4
hd93hsXsHej05Na+8pEC+HU4aIMfWuS5ePeNswK4Pod/YC9azvfSRouLAijK
0ToXKBvPT4urmq8IoEs7MO4gOiu1Pif4hgCqJ/qmHUFb5T8YrX9TAFkf5e8c
Rwf2XqB7P0EAm7JGp55Cr1nSGmmTLIAboxViI9HGL3tcakgTwD2vK5Hn0P3v
lUzecVd2/xX3XUJXXk126X9fALallmuuoVO2fhp4Khu/z3nvGTHord7xO3Uf
C8AwLYIfjzbba7L1xhMBHA69/zlJ9v2/vOw/ugB/38729FTZfEo+Ypb0QgCD
omfvuoO23x3539gSvP+cJ1PvoQsytOISywXgFLu74wG65TL3w8hqAazk74x5
hFazufPkWg0+n11P7Z6gQ6p6OItqBXD5yfYeBehDpr/iT9QJYGReyJUX6Ptx
l1P7NAggbTDHtASdtLTTy6tZANKvg6vL0fyUrz/rWwRwXPmRWzW6Zq2P8cI2
Aa6fvztr0O89dplmfhdA34mV/rXoJ7q1qoM6cf5vWN2rHu04KSA6+I8A5s9O
8m9A1zdPVfnSJYCLqo86m9Fz/tTOmC8vBL2maDepbH7dBcu4PkJY9sq9ug39
VDBwhIKCEDYV8Mw60Otz59S6KgvBOSjjWie6i+u55Z6qEEJv2/f+i7ac4VSr
oSmEAdKeK+T+4H/Pzck0WKsjBJWz95Pl0R0aRivv8oRgxjkt3xftsGuPr4JI
CGMiI+YroH8un7TTTk8Ip+F5mDJ6WdTfNVcGCaFKeVq5KnqAwUaTliFCmNrY
pq6Jvj1JrDhxhBDszv+cq4OeKHcpz3e0ENa9X+LHQ+9QC/DJMhTCpbm8OCF6
5pS5//WYIIQjtnMqdNGFZ3bkwWQh2Gxo+fMfenTq8bV+xkLgl6mLhqAfbFTq
f3e6EBbkZU0ZjrbUXxb7zUQInY7/Fo5C66V+tx5hLgTFiIrVBugf+0y7nGYL
4dZqG89x6GdHY1PDLIQQGbHLfyJ637Ywr9z5QpjT4nDASGZPx1kd1kKwV/h5
cCpa6/jyIYMWC+HFTvtgCfqufyvXyg5fvx8SYIq2f7pGb4cD/h7DMB9z9NIH
KnBpuRCC/9u5YTY64Mw47yfOQtj+zGKpBbrJk1vw2VUIhywUzeajI1fIT1dZ
K4TeSTlDrdGTl40pGrNBCA7tPgo2aH/fin3zNwrhTOfkBlt0XInh8g2bhRB1
tG/OUnTGSY/lgdvw/m3/Eu6IjlDLCTrvJYTsBW3rVqCnPbB6nbYDv3+KcLKL
7PV5ZssLdgmhSd+r5yrZ/YjKVHm3Rwhhan2erkFbVL1qaw0QwoGS4pD16Efe
mf17Bgnhd0rtXHe0j7mnrepBIRR9ntrHA71ojfCV4LAQXp5vurcF3bYhJ2LI
USFI37Vu3i4b//lbwgxOCGFD0tKB3ujxeyc+n3RKCJo9hr3YgX74XXPmtAgh
+Mev9t6FVtVV7WESJQTjIK5oDzqr9xA5s/NC+Dlr9oO96D0mi83NLgnheVTn
8v3oCsUTL02uCmGF3vhfQehM07Lo6TeEoO3879hB2fzbrPzcKFYI8yuWDz6M
flk+bPq4eCEESB3SQ9E6m7S6hicJ4WDvPzOOo1/8TFfTSxFC+irzF2Fo67/f
vbTS8XmxnG4bjr5RkTiu310heDd+roqQ3Y+M3JmdmUJ4u3SJfRS63z315IYs
IbjHB1ScQw8td9tRniOEhAYv64tonjT6XM5jIWT9NnpyGW1Xd0Yv7okQPApe
GF9D+x1W633qmRB2Gkpu3kB/e1g+d1ehEK59O8yNRfuuS2l3KRbCl+fZAXGy
522jR69ZpUKIdn/XlIA+U/Xcd1iFEO5tkc6/hc55dshRoVoIqZvaE1JkPrD+
RuNrIXxvbFdOR6/bqeec9xaf56Uda++g62DdgcvvhfBh+L8HGejqKx1iv3oh
lGSoad+X3f8k32FLGoRQuXzi2gey9ydevza6WQhxSzen58ieT8MhEb1ahPCw
Pk/+MbpY7UrPqq+4fhlILPPQf/0e18V+E8Jt+9cnnqLdusaY7OoQwogdVyqe
odM893MtO4Uw73QUpxC9f8SqTfw/QuiX/NS2CM1/vmFGwz8hlGYaHH+JrvQe
F5ncQwQPosrzS9FXsxZt2dVLBBGjH8hVyNazWOdC874i0DBrG1eFVnskTVBS
EEH1+c2ur9BrtI5wXiqJIKPL9HiN7Hkal9//lIoIMtU33HuLtjEZs99OXQSm
fi31tbL59838EFdLBPo1xYp1suuFh+lW6YigPIs75iN6Kue8WThPBNtv5i9o
QJf0+NSxSCiC76JG9yZ0Q1CzsYquCEYH+wR/lo1P8DDNpwNF0HfRnkstsvUi
nO/vry8C/+oed77K1pMOo32Th4rg3daez9vQ+Vd/iVqGi+DeusA37Wht1+KF
l0bh9/l77EsH+u2tMXqLDUSQumrYr5+y+/1qX0ifcSKIKbbq9Vu2/rdPO5E2
Aa+3WknpL3pe/WOjVZNFcHm6k1oX+ti6/XvUjUUwf6OVZo+/OJ85H9benyaC
V//eacqjx68ya18LIpjVqqXRG619o98gdTMRPJz2bUBf9CbRic475jgeJTv7
9Uf//AqeTrNFsDkyrUsBfXLSxjO9LUTQy+NKuxLa8++29dGWIjg5fO6nAeix
5nF1FlYiqAmPrVBFVyu5K35ZKILFuwoeq6M7rfu9O7RYBAtOJyZpok9pFa8c
YScCtXMOZ7TRg5x0Tj+xx/EyLt7LQa81H+bnukwEujpaa3lo+4aFOl0rRLDi
+XALAfq33xvX0y4i8GzXGilCi2w11xqsEkEor1pBFz2ibMrAvDUiMMnd8UkP
/dr/VJjjehFc9fyd/R/6o/z6B1/dRLD68opIffT1oR3XAjaJoCwzxmMIOvuj
zxytLSLoGvFuxjB0nPPY6KvbRHB3obzOCLTlF/u88V4iyA7R+TQS7aY26mqO
D86/4bqpo9FTD78zW7BTBHY7df0N0Ln2sVeq/UTgmMu3GCv7Pbeyn7j6iyBx
lpbGeHSzsm3SlwAR7JysWjUB7TEyYsX2QBEY5qucnSQbX627pb8PiOD0EJ0V
RmgO/6Oaf4gIpNuGiY3Rn9/O5vQ+IoLGF3NqpqKPLlFqDDoqghcLfCOmo42e
2e3vf0IEAb2zFwH6xGubluCTIoj8LVQyRTcd0NfvfxrHY+LJHDP0rJEtw4Mi
RdAvZZiXOdp/X5Fcr7Mi8HN7M2wW2jrl8/Xd50WQbp1WPRu9cKaz3q+LIoha
kBI8Vzb/DCw2br2C83veq4nz0KWlj0Obr4nAZcjo95ay8e/XHOgSjfcrIyFk
AXq4ZolNZawIxDUu46zRI1PDfs2LF0GB/dyqhej2/8x9HiSK4NrftbtsZPdT
82fx2GT8++BssS16VUZW7yupIuBl2D5YIptvBTe1NG+L4IfFiBVL0WkBhT0D
7orgRovJH3u0/sWxhV8zRZBkdTbcUfb5HvXey7JEMIMHhsvR1561yj/NFgG0
jHy6Am3MdfYY90gE89avXuGMLltknBWVK4LKwdJvLmg7haDWXk/xfqU/DXRF
y62c08/tmQiCo3/qrEZ/Ewb2evkcxzPI7/oa9ItwyaeJRSKoKFk2YR16dIFn
UuRLEQxSicheLxsPuxGuf0tFYJw8dp6b7Ho7HeRWVIjg0IRRZe7oJL1eQVlV
IkjpE+K4STb/K3Q7Ra/xesfnv/eQzbfK2CW73ohgFOxYvQXdU/Xc5ep3IlDd
otq4VTYftKU1Ez/g/N6vsX67zJNO9j1eL4KxZfsbPdHHtu7X+/xJBFYp69Z4
y57nvckjzZtEsHdr9gcfdP9yteFnP+Pztzx0uS86PuIYr71FBB6ZZRU7ZfP/
9sCuOa0isC46tcBP5tfJlee+ieBiZenj3ehDW8beaPuO80/l+BR/dMjNgxvN
f4pgfGxR3F703L3XR4b/wvW25rh4HzohZcuHT39EwCmpDt2Pvvii9MSkLhHY
psX8C0QLR6ZOD+whhsk3e7kdQC9p66wrkRdDR1lTRTC6kH8gSLePGB5brTAN
QTtsNxvi1k8MJRNcYw+hTS4OeJymIAbHyN/qR9BjuM+c5ZTFkBg6xCdU9rwb
LP03W0UMk/5rqjmKNtQ6feaomhj2Ljc3OY7+ULJqSoWGGKxmGV8+IbvekvOv
BNpiOP72ufxJdIq77h5njhh26Xe5nEJHPX449CpPDIc0ih+Eo++1u5R/EqAv
mAsj0K5e5cHDxGK4lLXcO1J2/299N1uvJ4bFTqKXZ2Tr249TvWP+E8PJjYHD
z6JH+Ye+aNAXw6OXp/3PyebPzuRLg4eKIWvzkorz6Cfy5btXDhfD+5GPRlxE
l+g/XXN+pBh03r/zu4TuW7fMoXq0GMo3JBRdll1vgquDpqEYxl001Lsq+zyF
2LWW48RQu3idxzXZ8zlHbt/+CWKYbm93/zq6rcwgPnOSGGx95RSjZeN5tF9D
m5EYvuxdaRuDBtuFY4dOFcP+SQEXYmXrfZ/Kw47TxeDm6Nx4E1272+V3KIgh
LanLIF62Xly745tjiuPZvsIrQTYeK6+otM8QQ483AZmJ6JtXGtIHzRLDVn13
uVuy/czFYrvNHLz/fkKzZPSPqKOzAyzEUHH61L4U9FAX37FJlmJ4MrD6Uaps
/J89H/dmgRiCchvl09GtPeZYKiwUw9EReSa30T2mx+2eYIPfr2Or3x30+vw7
z1bYiiH5Seudu2he71Fjg+3EwDUxbc9AFzk9Sk6yF8Om36tH3UNfXj3VuspR
DNePOq+6j96dbqUot0IM9afGRWWhzytnvtd3FoPXxTfFD2TP0/TJlXNX4uvg
2idHdv0pfp83rsL52zPX6KFs/VWdqXt8jRhubent9kj2+dKZ21LWiWE9Z9DZ
x2i1wZMayzbg/fb573mubP8YVLC7wx2vz+39Jw+d53d3srYHjpd3/rCnsvH+
kqo5YYsYijW22+ajk602ay7aJobq1X32PkOnx52b7OEpBuWm3TcL0PPGS/0P
eYthucaHsudo5ekardd3iGGireG/QvRgq7uBOTvF4Pufm36RbD0QnDB77SeG
sMYwi2LZ+hdgMfT7HhxPzTiPl+hnJ49OUA4Qg59yWlgJ+u3xAW6D9uPzaJyU
Xor++cWjYEqQGBR7XagqQ5tauiyxChaD85OAX+Wy/SvkkPKqEByPhmW8SnTs
ndNS78Ni2J0zxqgK7S0e8y8kVAzfEn/ZVsue32k/jM4dE0OT0oOtr9ADn4df
TjghhtaR/qGv0U8fphk/OCkG61WSmBrZ/rCws2dRuBhU+/15+Aa97KP8rzcR
Yvjuevv1W7TqqB16X86IIfTp9vZ3aD/1Lp9fZ8UwxX+C4nt0xsPxvfpeEIOo
7KfuB9l8Tsh8oH5JDBKl7Al16F8HJiUKr4hh24bQOfXoG+bmJUOu4f2ZsMrx
I/qR3v7hhjdw/saYbfyEzj5/Ms0oBj9PYeTuBpmDNb1NboohJVQc2vj3f/0h
9YjUH5KpPyRTf0im/pBM/SGZ+kMy9Ydk6g/J1B+y12P6QzL1h2TqD8nUH5Kp
PyRTf0im/pBM/SGZ+kMy9Ydk6g/J1B+SqT8kU39Ipv6QTP0hmfpDMvWHZOoP
ydQfsuPH9Idk6g/J1B+SqT8kU39Ipv6QTP0ha6Y/ZH8/0x+SqT8kU39Ipv6Q
/X5Mf0im/pBM/SGZ+kMy9Ydk6g/J1B+y72f6QzL1h2TqD8nUH5KpPyRTf0im
/pBM/SE73kx/SKb+kEz9IZn6QzL1h2TqD8nUH7L3h+kP2c9j+kMy9Ydk6g9Z
M/0hmfpDMvWHZOoP2fFn+kMy9Yfs+DL9IZn6QzL1h2TqD8nUH5KpP2THm+kP
ydQfkqk/ZO8X0x+SqT8kU39Ipv6QvX9Mf8jOZ6Y/JFN/SKb+kEz9IZn6Q/b7
Mv0hmfpDMvWHZOoPydQfkqk/JFN/SKb+kP19TH/I3n+mPyRTf0im/pAdD6Y/
ZH8P0x+SqT9k12emPyRTf8j+fqY/JFN/SKb+kEz9Ifs60x+y6y3TH5KpPyRT
f0im/pBM/SGZ+kMy9Ydk6g/Z15n+kEz9Ifv/FzD9IZn6QzL1h+z+zPSH7PrP
9Ifs/WX6Q3Z/YfpDMvWH7Hxi+kMy9Ydk6g/J1B+yzzvTH5KpPyRTf8iOJ9Mf
kqk/JFN/SKb+kH3emP6QNdMfkqk/JFN/SKb+kEz9IZn6QzL1h2TqD8nUH7Lj
xfSHZOoPydQfstdn+kMy9Ydk6g/J1B+SqT8kU39Ipv6Q/f1Mf0im/pBM/SGZ
+kMy9Yfs+5n+kJ1PTH/IrodMf0im/pBM/SGZ+kMy9Ydk6g/Z78P0h2TqD8nU
H7L7B9MfsveH6Q/J1B+SqT8kU39Ipv6QTP0hmfpDMvWH7P1n+kMy9Yfs/WL6
Q/b7MP0hmfpDdr9g+kN2PWL6QzL1h2TqD9n9nukP2fWO6Q/Z9YPpD8nUH5Kp
PyRTf0im/pBM/SGZ+kMy9Ydk6g/J1B+SqT8kU39Ipv6QTP0hmfpDMvWHZOoP
ydQfkqk/ZPc7pj9k38/0h2TqD8nUH5KpP2TvD9Mfkqk/JFN/SKb+kEz9IZn6
Q3Y9ZfpDMtsf0v1m+kMy9Ydk6g/J1B+yzwfTH7LXY/pDMvWHZOoP2fWE6Q/Z
/ZzpD8nUH5KpP2TXB6Y/ZH8/0x+SqT8kU3/I7ndMf0im/pCdj0x/SKb+kH0+
mf6QTP0hmfpDdj9m+kMy9Ydk6g/Z9Z7pD9n7wfSHZOoP2f2G6Q/J1B+SqT9k
5yvTH5KpP2TnA9Mfkqk/ZPcrpj9kn2emP2TXD6Y/JFN/yK6H1B/SeDH9IZn6
QzL1h2TqD8nUH7L7CdMfkqk/JFN/SKb+kEz9IZn6QzL1h2TqD9nvy/SHZOoP
2fnJ9IfsfGT6Q3Y+MP0hmfpD9vcz/SGZ+kMy9Yfs/Gf6Q3Y9ZfpDMvWH7PPK
9Idk6g/Zv2f6Q3Z/Z/pD9vsz/SGZ+kN2PJj+kEz9Ifv5TH/IPv9Mf0im/pBM
/SG7njL9ITt+TH9Ipv6QTP0hmfpDdn9g+kP2/jP9IZn6QzL1h+x6zfSH7HrD
9Idk6g/Z/Y3pD8nUH7L7A9Mfkqk/ZNdPpj8kU3/Ijj/TH5KpP2SfB6Y/ZOcL
0x+y6w/TH7LPN9Mfkqk/JFN/SKb+kEz9ITteTH9Ipv6Q3V+Z/pDdf5j+kEz9
Ibv+Mf0hmfpDdr9n+kMy9Ydk6g/Z/YDpD8nUH5KpPyRTf0im/pBM/SGZ+kMy
9Ydk6g/Z8WT6QzL1h2TqD8nUH5KpPyRTf0im/pBdT5n+kEz9IbseM/0hmfpD
9vsz/SE7n5j+kN0fmf6QTP0hu58y/SGZ+kMy9Ydk6g/Z/ZLpD8nUH5KpPyRT
f0im/pBM/SGZ+kMy9Ydk6g/Z+cX0h2TqD8nUH7LrE9Mfkqk/JFN/SKb+kEz9
Ibt+MP0hmfpDMvWHZOoPydQfkqk/JFN/SKb+kEz9IZn6Q/b3Mf0hmfpDMvWH
ZOoPydQfsmb6QzL1h2TqD9n5yPSH7PrG9Idk6g/J1B+SqT9k9zOmPyRTf0im
/pBM/SG7fzD9IZn6Q/Z1pj9k7wfTH5KpPyRTf0im/pBM/SG7fzL9ITv+TH9I
pv6QTP0hmfpDdr1i+kN2f2L6Q3a9ZvpDMvWH7Pxj+kMy9Ydk6g/J1B+SqT8k
U3/I3g+mPyRTf0im/pBM/SGZ+kN2f2X6QzL1h2TqD9nnjekPydQfkqk/ZM30
h2TqD8nUH5KpP2TvP9Mfsu9n+kP2+WT6QzL1h2TqD8nUH5KpPyRTf8iuv0x/
yO43TH9Ipv6QXc+oP6T9gOkP2f2N6Q/Z54npD8nUH7Lzj+kP2esx/SGZ+kMy
9Ydk6g/Z8WH6Q3a9YPpDdj1h+kMy9Ydk6g/J1B+y95vpD9n1n+kPydQfkqk/
ZOcz0x+yzy/TH7LXZ/pDMvWH7P7B9Idk6g/J1B+SqT9k5x/TH5KpPyRTf0im
/pBM/SG7XjP9IZn6QzL1h2TqD8nUH5KpPyRTf0im/pBdL5j+kN2/mP6QfR6Y
/pCdT0x/SKb+kP09TH9Ipv6QTP0hO75Mf0im/pBM/SGZ+kMy9Ydk6g/Z/Y3p
D8nUH7L7GdMfsusr0x+SqT9k5x/TH5KpP2THn+kPydQfkqk/JFN/yN5Ppj8k
U3/IzjemP2TXJ6Y/JFN/yH4+0x+SqT8kU39Ipv6Q3Q+Y/pBM/SG7HzD9Ibtf
Mf0hmfpDdjyY/pC9HtMfkqk/ZOc/0x+y843pD8nUH7LzgekPWTP9IbueMP0h
+zwz/SGZ+kMy9Yfs/Gf6Q9ZMf0im/pBM/SGZ+kMy9Ydk6g/J1B+SqT8kU3/I
7i9Mf0im/pBM/SH7vDP9IZn6QzL1h+z1mP6QTP0hmfpDMvWHZOoP2fvP9Ifs
+sb0h2TqD9n5w/SHZOoP2f2N6Q/J1B+y12P6Q/bzmP6QfT6Z/pBM/SE7nkx/
SKb+kF3vmf6QTP0hu14w/SE7Hkx/SKb+kN3PmP6QTP0hmfpDdvyZ/pBM/SGZ
+kMy9Ydk6g/J1B+SqT8kU39Ipv6QfZ6Y/pC9PtMfsusv0x+yn8/0h2TqD9n9
g+kPydQfsuPN9Idk6g/J1B+SqT8kU39Ipv6QXQ+Y/pBd/5j+kEz9IZn6QzL1
h2TqD9n9i+kPydQfkqk/ZJ9fpj8kU39Ipv6Q3R+Y/pBM/SGZ+kMy9Ydk6g/Z
+cz0h2TqD8nUH5KpPyRTf8ia6Q/JdD7iuPTBbsuu3e8+H7H7fMTu8xG7z0fs
Ph+x+3zE7vMRu89H7D4fsft8xO7zEbvPR+w+H7H7fMTu8xG7z0fsPh+x+3zE
7vMRu89H7D4fsft8xO7zEbvPR+w+H7H7fMTu8xG7z0fsPh+x+3zE7vMR/3af
j9h9PmL3+Yjd5yN2n4/YfT5i9/mI3ecjdp+P+P89H/H/AMDjHcY=
        
        "], {{{}, {}, {}, {}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{651, 3}], 
           LineBox[{652, 4}], LineBox[{653, 5}], LineBox[{654, 6}], 
           LineBox[{655, 7}], LineBox[{656, 8}], LineBox[{657, 9}], 
           LineBox[{658, 10}], LineBox[{659, 11}], LineBox[{660, 12}], 
           LineBox[{661, 13}], LineBox[{662, 14}], LineBox[{663, 15}], 
           LineBox[{664, 16}], LineBox[{665, 17}], LineBox[{666, 18}], 
           LineBox[{667, 19}], LineBox[{668, 20}], LineBox[{669, 21}], 
           LineBox[{670, 22}], LineBox[{671, 23}], LineBox[{672, 24}], 
           LineBox[{673, 25}], LineBox[{674, 26}], LineBox[{675, 27}], 
           LineBox[{676, 28}], LineBox[{677, 29}], LineBox[{678, 30}], 
           LineBox[{679, 31}], LineBox[{680, 32}], LineBox[{681, 33}], 
           LineBox[{682, 34}], LineBox[{683, 35}], LineBox[{684, 36}], 
           LineBox[{685, 37}], LineBox[{686, 38}], LineBox[{687, 39}], 
           LineBox[{688, 40}], LineBox[{689, 41}], LineBox[{690, 42}], 
           LineBox[{691, 43}], LineBox[{692, 44}], LineBox[{693, 45}], 
           LineBox[{694, 46}], LineBox[{695, 47}], LineBox[{696, 48}], 
           LineBox[{697, 49}], LineBox[{698, 50}], LineBox[{699, 51}], 
           LineBox[{700, 52}], LineBox[{701, 53}], LineBox[{702, 54}], 
           LineBox[{703, 55}], LineBox[{704, 56}], LineBox[{705, 57}], 
           LineBox[{706, 58}], LineBox[{707, 59}], LineBox[{708, 60}], 
           LineBox[{709, 61}], LineBox[{710, 62}], LineBox[{711, 63}], 
           LineBox[{712, 64}], LineBox[{713, 65}], LineBox[{714, 66}], 
           LineBox[{715, 67}], LineBox[{716, 68}], LineBox[{717, 69}], 
           LineBox[{718, 70}], LineBox[{719, 71}], LineBox[{720, 72}], 
           LineBox[{721, 73}], LineBox[{722, 74}], LineBox[{723, 75}], 
           LineBox[{724, 76}], LineBox[{725, 77}], LineBox[{726, 78}], 
           LineBox[{727, 79}], LineBox[{728, 80}], LineBox[{729, 81}], 
           LineBox[{730, 82}], LineBox[{731, 83}], LineBox[{732, 84}], 
           LineBox[{733, 85}], LineBox[{734, 86}], LineBox[{735, 87}], 
           LineBox[{736, 88}], LineBox[{737, 89}], LineBox[{738, 90}], 
           LineBox[{739, 91}], LineBox[{740, 92}], LineBox[{741, 93}], 
           LineBox[{742, 94}], LineBox[{743, 95}], LineBox[{744, 96}], 
           LineBox[{745, 97}], LineBox[{746, 98}], LineBox[{747, 99}], 
           LineBox[{748, 100}], LineBox[{749, 101}], LineBox[{750, 102}], 
           LineBox[{751, 103}], LineBox[{752, 104}], LineBox[{753, 105}], 
           LineBox[{754, 106}], LineBox[{755, 107}], LineBox[{756, 108}], 
           LineBox[{757, 109}], LineBox[{758, 110}], LineBox[{759, 111}], 
           LineBox[{760, 112}], LineBox[{761, 113}], LineBox[{762, 114}], 
           LineBox[{763, 115}], LineBox[{764, 116}], LineBox[{765, 117}], 
           LineBox[{766, 118}], LineBox[{767, 119}], LineBox[{768, 120}], 
           LineBox[{769, 121}], LineBox[{770, 122}], LineBox[{771, 123}], 
           LineBox[{772, 124}], LineBox[{773, 125}], LineBox[{774, 126}], 
           LineBox[{775, 127}], LineBox[{776, 128}], LineBox[{777, 129}], 
           LineBox[{778, 130}], LineBox[{779, 131}], LineBox[{780, 132}], 
           LineBox[{781, 133}], LineBox[{782, 134}], LineBox[{783, 135}], 
           LineBox[{784, 136}], LineBox[{785, 137}], LineBox[{786, 138}], 
           LineBox[{787, 139}], LineBox[{788, 140}], LineBox[{789, 141}], 
           LineBox[{790, 142}], LineBox[{791, 143}], LineBox[{792, 144}], 
           LineBox[{793, 145}], LineBox[{794, 146}], LineBox[{795, 147}], 
           LineBox[{796, 148}], LineBox[{797, 149}], LineBox[{798, 150}], 
           LineBox[{799, 151}], LineBox[{800, 152}], LineBox[{801, 153}], 
           LineBox[{802, 154}], LineBox[{803, 155}], LineBox[{804, 156}], 
           LineBox[{805, 157}], LineBox[{806, 158}], LineBox[{807, 159}], 
           LineBox[{808, 160}], LineBox[{809, 161}], LineBox[{810, 162}], 
           LineBox[{811, 163}], LineBox[{812, 164}], LineBox[{813, 165}], 
           LineBox[{814, 166}], LineBox[{815, 167}], LineBox[{816, 168}], 
           LineBox[{817, 169}], LineBox[{818, 170}], LineBox[{819, 171}], 
           LineBox[{820, 172}], LineBox[{821, 173}], LineBox[{822, 174}], 
           LineBox[{823, 175}], LineBox[{824, 176}], LineBox[{825, 177}], 
           LineBox[{826, 178}], LineBox[{827, 179}], LineBox[{828, 180}], 
           LineBox[{829, 181}], LineBox[{830, 182}], LineBox[{831, 183}], 
           LineBox[{832, 184}], LineBox[{833, 185}], LineBox[{834, 186}], 
           LineBox[{835, 187}], LineBox[{836, 188}], LineBox[{837, 189}], 
           LineBox[{838, 190}], LineBox[{839, 191}], LineBox[{840, 192}], 
           LineBox[{841, 193}], LineBox[{842, 194}], LineBox[{843, 195}], 
           LineBox[{844, 196}], LineBox[{845, 197}], LineBox[{846, 198}], 
           LineBox[{847, 199}], LineBox[{848, 200}], LineBox[{849, 201}], 
           LineBox[{850, 202}], LineBox[{851, 203}], LineBox[{852, 204}], 
           LineBox[{853, 205}], LineBox[{854, 206}], LineBox[{855, 207}], 
           LineBox[{856, 208}], LineBox[{857, 209}], LineBox[{858, 210}], 
           LineBox[{859, 211}], LineBox[{860, 212}], LineBox[{861, 213}], 
           LineBox[{862, 214}], LineBox[{863, 215}], LineBox[{864, 216}], 
           LineBox[{865, 217}], LineBox[{866, 218}], LineBox[{867, 219}], 
           LineBox[{868, 220}], LineBox[{869, 221}], LineBox[{870, 222}], 
           LineBox[{871, 223}], LineBox[{872, 224}], LineBox[{873, 225}], 
           LineBox[{874, 226}], LineBox[{875, 227}], LineBox[{876, 228}], 
           LineBox[{877, 229}], LineBox[{878, 230}], LineBox[{879, 231}], 
           LineBox[{880, 232}], LineBox[{881, 233}], LineBox[{882, 234}], 
           LineBox[{883, 235}], LineBox[{884, 236}], LineBox[{885, 237}], 
           LineBox[{886, 238}], LineBox[{887, 239}], LineBox[{888, 240}], 
           LineBox[{889, 241}], LineBox[{890, 242}], LineBox[{891, 243}], 
           LineBox[{892, 244}], LineBox[{893, 245}], LineBox[{894, 246}], 
           LineBox[{895, 247}], LineBox[{896, 248}], LineBox[{897, 249}], 
           LineBox[{898, 250}], LineBox[{899, 251}], LineBox[{900, 252}], 
           LineBox[{901, 253}], LineBox[{902, 254}], LineBox[{903, 255}], 
           LineBox[{904, 256}], LineBox[{905, 257}], LineBox[{906, 258}], 
           LineBox[{907, 259}], LineBox[{908, 260}], LineBox[{909, 261}], 
           LineBox[{910, 262}], LineBox[{911, 263}], LineBox[{912, 264}], 
           LineBox[{913, 265}], LineBox[{914, 266}], LineBox[{915, 267}], 
           LineBox[{916, 268}], LineBox[{917, 269}], LineBox[{918, 270}], 
           LineBox[{919, 271}], LineBox[{920, 272}], LineBox[{921, 273}], 
           LineBox[{922, 274}], LineBox[{923, 275}], LineBox[{924, 276}], 
           LineBox[{925, 277}], LineBox[{926, 278}], LineBox[{927, 279}], 
           LineBox[{928, 280}], LineBox[{929, 281}], LineBox[{930, 282}], 
           LineBox[{931, 283}], LineBox[{932, 284}], LineBox[{933, 285}], 
           LineBox[{934, 286}], LineBox[{935, 287}], LineBox[{936, 288}], 
           LineBox[{937, 289}], LineBox[{938, 290}], LineBox[{939, 291}], 
           LineBox[{940, 292}], LineBox[{941, 293}], LineBox[{942, 294}], 
           LineBox[{943, 295}], LineBox[{944, 296}], LineBox[{945, 297}], 
           LineBox[{946, 298}], LineBox[{947, 299}], LineBox[{948, 300}], 
           LineBox[{949, 301}], LineBox[{950, 302}], LineBox[{951, 303}], 
           LineBox[{952, 304}], LineBox[{953, 305}], LineBox[{954, 306}], 
           LineBox[{955, 307}], LineBox[{956, 308}], LineBox[{957, 309}], 
           LineBox[{958, 310}], LineBox[{959, 311}], LineBox[{960, 312}], 
           LineBox[{961, 313}], LineBox[{962, 314}], LineBox[{963, 315}], 
           LineBox[{964, 316}], LineBox[{965, 317}], LineBox[{966, 318}], 
           LineBox[{967, 319}], LineBox[{968, 320}], LineBox[{969, 321}], 
           LineBox[{970, 322}], LineBox[{971, 323}], LineBox[{972, 324}], 
           LineBox[{973, 325}], LineBox[{974, 326}], LineBox[{975, 327}], 
           LineBox[{976, 328}], LineBox[{977, 329}], LineBox[{978, 330}], 
           LineBox[{979, 331}], LineBox[{980, 332}], LineBox[{981, 333}], 
           LineBox[{982, 334}], LineBox[{983, 335}], LineBox[{984, 336}], 
           LineBox[{985, 337}], LineBox[{986, 338}], LineBox[{987, 339}], 
           LineBox[{988, 340}], LineBox[{989, 341}], LineBox[{990, 342}], 
           LineBox[{991, 343}], LineBox[{992, 344}], LineBox[{993, 345}], 
           LineBox[{994, 346}], LineBox[{995, 347}], LineBox[{996, 348}], 
           LineBox[{997, 349}], LineBox[{998, 350}], LineBox[{999, 351}], 
           LineBox[{1000, 352}], LineBox[{1001, 353}], LineBox[{1002, 354}], 
           LineBox[{1003, 355}], LineBox[{1004, 356}], LineBox[{1005, 357}], 
           LineBox[{1006, 358}], LineBox[{1007, 359}], LineBox[{1008, 360}], 
           LineBox[{1009, 361}], LineBox[{1010, 362}], LineBox[{1011, 363}], 
           LineBox[{1012, 364}], LineBox[{1013, 365}], LineBox[{1014, 366}], 
           LineBox[{1015, 367}], LineBox[{1016, 368}], LineBox[{1017, 369}], 
           LineBox[{1018, 370}], LineBox[{1019, 371}], LineBox[{1020, 372}], 
           LineBox[{1021, 373}], LineBox[{1022, 374}], LineBox[{1023, 375}], 
           LineBox[{1024, 376}], LineBox[{1025, 377}], LineBox[{1026, 378}], 
           LineBox[{1027, 379}], LineBox[{1028, 380}], LineBox[{1029, 381}], 
           LineBox[{1030, 382}], LineBox[{1031, 383}], LineBox[{1032, 384}], 
           LineBox[{1033, 385}], LineBox[{1034, 386}], LineBox[{1035, 387}], 
           LineBox[{1036, 388}], LineBox[{1037, 389}], LineBox[{1038, 390}], 
           LineBox[{1039, 391}], LineBox[{1040, 392}], LineBox[{1041, 393}], 
           LineBox[{1042, 394}], LineBox[{1043, 395}], LineBox[{1044, 396}], 
           LineBox[{1045, 397}], LineBox[{1046, 398}], LineBox[{1047, 399}], 
           LineBox[{1048, 400}], LineBox[{1049, 401}], LineBox[{1050, 402}], 
           LineBox[{1051, 403}], LineBox[{1052, 404}], LineBox[{1053, 405}], 
           LineBox[{1054, 406}], LineBox[{1055, 407}], LineBox[{1056, 408}], 
           LineBox[{1057, 409}], LineBox[{1058, 410}], LineBox[{1059, 411}], 
           LineBox[{1060, 412}], LineBox[{1061, 413}], LineBox[{1062, 414}], 
           LineBox[{1063, 415}], LineBox[{1064, 416}], LineBox[{1065, 417}], 
           LineBox[{1066, 418}], LineBox[{1067, 419}], LineBox[{1068, 420}], 
           LineBox[{1069, 421}], LineBox[{1070, 422}], LineBox[{1071, 423}], 
           LineBox[{1072, 424}], LineBox[{1073, 425}], LineBox[{1074, 426}], 
           LineBox[{1075, 427}], LineBox[{1076, 428}], LineBox[{1077, 429}], 
           LineBox[{1078, 430}], LineBox[{1079, 431}], LineBox[{1080, 432}], 
           LineBox[{1081, 433}], LineBox[{1082, 434}], LineBox[{1083, 435}], 
           LineBox[{1084, 436}], LineBox[{1085, 437}], LineBox[{1086, 438}], 
           LineBox[{1087, 439}], LineBox[{1088, 440}], LineBox[{1089, 441}], 
           LineBox[{1090, 442}], LineBox[{1091, 443}], LineBox[{1092, 444}], 
           LineBox[{1093, 445}], LineBox[{1094, 446}], LineBox[{1095, 447}], 
           LineBox[{1096, 448}], LineBox[{1097, 449}], LineBox[{1098, 450}], 
           LineBox[{1099, 451}], LineBox[{1100, 452}], LineBox[{1101, 453}], 
           LineBox[{1102, 454}], LineBox[{1103, 455}], LineBox[{1104, 456}], 
           LineBox[{1105, 457}], LineBox[{1106, 458}], LineBox[{1107, 459}], 
           LineBox[{1108, 460}], LineBox[{1109, 461}], LineBox[{1110, 462}], 
           LineBox[{1111, 463}], LineBox[{1112, 464}], LineBox[{1113, 465}], 
           LineBox[{1114, 466}], LineBox[{1115, 467}], LineBox[{1116, 468}], 
           LineBox[{1117, 469}], LineBox[{1118, 470}], LineBox[{1119, 471}], 
           LineBox[{1120, 472}], LineBox[{1121, 473}], LineBox[{1122, 474}], 
           LineBox[{1123, 475}], LineBox[{1124, 476}], LineBox[{1125, 477}], 
           LineBox[{1126, 478}], LineBox[{1127, 479}], LineBox[{1128, 480}], 
           LineBox[{1129, 481}], LineBox[{1130, 482}], LineBox[{1131, 483}], 
           LineBox[{1132, 484}], LineBox[{1133, 485}], LineBox[{1134, 486}], 
           LineBox[{1135, 487}], LineBox[{1136, 488}], LineBox[{1137, 489}], 
           LineBox[{1138, 490}], LineBox[{1139, 491}], LineBox[{1140, 492}], 
           LineBox[{1141, 493}], LineBox[{1142, 494}], LineBox[{1143, 495}], 
           LineBox[{1144, 496}], LineBox[{1145, 497}], LineBox[{1146, 498}], 
           LineBox[{1147, 499}], LineBox[{1148, 500}], LineBox[{1149, 501}], 
           LineBox[{1150, 502}], LineBox[{1151, 503}], LineBox[{1152, 504}], 
           LineBox[{1153, 505}], LineBox[{1154, 506}], LineBox[{1155, 507}], 
           LineBox[{1156, 508}], LineBox[{1157, 509}], LineBox[{1158, 510}], 
           LineBox[{1159, 511}], LineBox[{1160, 512}], LineBox[{1161, 513}], 
           LineBox[{1162, 514}], LineBox[{1163, 515}], LineBox[{1164, 516}], 
           LineBox[{1165, 517}], LineBox[{1166, 518}], LineBox[{1167, 519}], 
           LineBox[{1168, 520}], LineBox[{1169, 521}], LineBox[{1170, 522}], 
           LineBox[{1171, 523}], LineBox[{1172, 524}], LineBox[{1173, 525}], 
           LineBox[{1174, 526}], LineBox[{1175, 527}], LineBox[{1176, 528}], 
           LineBox[{1177, 529}], LineBox[{1178, 530}], LineBox[{1179, 531}], 
           LineBox[{1180, 532}], LineBox[{1181, 533}], LineBox[{1182, 534}], 
           LineBox[{1183, 535}], LineBox[{1184, 536}], LineBox[{1185, 537}], 
           LineBox[{1186, 538}], LineBox[{1187, 539}], LineBox[{1188, 540}], 
           LineBox[{1189, 541}], LineBox[{1190, 542}], LineBox[{1191, 543}], 
           LineBox[{1192, 544}], LineBox[{1193, 545}], LineBox[{1194, 546}], 
           LineBox[{1195, 547}], LineBox[{1196, 548}], LineBox[{1197, 549}], 
           LineBox[{1198, 550}], LineBox[{1199, 551}], LineBox[{1200, 552}], 
           LineBox[{1201, 553}], LineBox[{1202, 554}], LineBox[{1203, 555}], 
           LineBox[{1204, 556}], LineBox[{1205, 557}], LineBox[{1206, 558}], 
           LineBox[{1207, 559}], LineBox[{1208, 560}], LineBox[{1209, 561}], 
           LineBox[{1210, 562}], LineBox[{1211, 563}], LineBox[{1212, 564}], 
           LineBox[{1213, 565}], LineBox[{1214, 566}], LineBox[{1215, 567}], 
           LineBox[{1216, 568}], LineBox[{1217, 569}], LineBox[{1218, 570}], 
           LineBox[{1219, 571}], LineBox[{1220, 572}], LineBox[{1221, 573}], 
           LineBox[{1222, 574}], LineBox[{1223, 575}], LineBox[{1224, 576}], 
           LineBox[{1225, 577}], LineBox[{1226, 578}], LineBox[{1227, 579}], 
           LineBox[{1228, 580}], LineBox[{1229, 581}], LineBox[{1230, 582}], 
           LineBox[{1231, 583}], LineBox[{1232, 584}], LineBox[{1233, 585}], 
           LineBox[{1234, 586}], LineBox[{1235, 587}], LineBox[{1236, 588}], 
           LineBox[{1237, 589}], LineBox[{1238, 590}], LineBox[{1239, 591}], 
           LineBox[{1240, 592}], LineBox[{1241, 593}], LineBox[{1242, 594}], 
           LineBox[{1243, 595}], LineBox[{1244, 596}], LineBox[{1245, 597}], 
           LineBox[{1246, 598}], LineBox[{1247, 599}], LineBox[{1248, 600}], 
           LineBox[{1249, 601}], LineBox[{1250, 602}], LineBox[{1251, 603}], 
           LineBox[{1252, 604}], LineBox[{1253, 605}], LineBox[{1254, 606}], 
           LineBox[{1255, 607}], LineBox[{1256, 608}], LineBox[{1257, 609}], 
           LineBox[{1258, 610}], LineBox[{1259, 611}], LineBox[{1260, 612}], 
           LineBox[{1261, 613}], LineBox[{1262, 614}], LineBox[{1263, 615}], 
           LineBox[{1264, 616}], LineBox[{1265, 617}], LineBox[{1266, 618}], 
           LineBox[{1267, 619}], LineBox[{1268, 620}], LineBox[{1269, 621}], 
           LineBox[{1270, 622}], LineBox[{1271, 623}], LineBox[{1272, 624}], 
           LineBox[{1273, 625}], LineBox[{1274, 626}], LineBox[{1275, 627}], 
           LineBox[{1276, 628}], LineBox[{1277, 629}], LineBox[{1278, 630}], 
           LineBox[{1279, 631}], LineBox[{1280, 632}], LineBox[{1281, 633}], 
           LineBox[{1282, 634}], LineBox[{1283, 635}], LineBox[{1284, 636}], 
           LineBox[{1285, 637}], LineBox[{1286, 638}], LineBox[{1287, 639}], 
           LineBox[{1288, 640}], LineBox[{1289, 641}], LineBox[{1290, 642}], 
           LineBox[{1291, 643}], LineBox[{1292, 644}], LineBox[{1293, 645}], 
           LineBox[{1294, 646}], LineBox[{1295, 647}], LineBox[{1296, 648}], 
           LineBox[{1297, 649}], LineBox[{1298, 650}]}}, {{}, 
          {GrayLevel[0], PointSize[0.01], PointBox[CompressedData["
1:eJwN03ODFwYAANBfxmrZvGzbNi+7Luuy7bpst8Ut21ttmYtbri3brq29P95H
eEEh3YJDwwUCgbDwgUC8SIFAfBKQkEQkJglJSUZyUpCSVKQmiDSkJR3pyUBG
MpGZLGQlG9nJQU5ykZs85CUf+SlAQQpRmCIUpRjFKUFJSlGaMpSlHOWpQEUq
UZkqVKUa1alBTWpRm2DqUJd61KcBDWlEY5rQlGY0pwUtaUUIrWlDW9rRng50
pBOd6UJXQulGd3rQk170pg996Ud/BjCQQQxmCEMZxnBGMJJRjGYMYxnHeCYQ
xkQmMZkpTGUa05nBTGYxmznMZR7zWcBCFrGYJfzAjyxlGctZwUpW8RM/s5o1
rGUd69nARjaxmS1sZRvb2cFOdrGbPezlF35lH/v5jd85wEEOcZgjHOUYxznB
SU5xmj84w1nOcZ4LXORP/uISl7nCVa5xnRvc5BZ/8w+3ucNd7nGfBzzkEY95
wlOe8ZwXvOQVr3nDW97xng985BOf+cJX/uU/vhGIHAiEIzwRiEgkIhOFqEQj
Ot8Rg5h8TyxiE4e4xCM+CUhIIhKThKQkIzkpSEkqUhNEGtKSjvRkICOZyEwW
spKN7OQgJ7nITR7yko/8FKAghShMEYpSjOKUoCSlKE0ZylKO8lSgIpWoTBWq
Uo3q1KAmtahNMHWoSz3q04CGNKIxTWhKM5rTgpa0IoTWtKEt7WhPBzrSic50
oSuhdKM7PehJL3rTh770oz8DGMggBjOEoQxjOCMYyShGM4axjGM8EwhjIpOY
zBSmMo3pzGAms5jNHOYyj/ksYCGLWMwSfuBHlrKM5axgJav4iZ9ZzRrWso71
bGAjm9jMFrayje3sYCe72M0e9vILv7KP/fzG7xzgIIc4zBGOcozjnOAkpzjN
H5zhLOc4zwUu8id/cYnLXOEq17jODW5yi7/5h9vc4S73uM8DHvKIxzzhKc94
zgte8orXvOEt73jPBz7yic984Sv/8h/fCETxn/BEICKRiEwUohKN6HxHDGLy
PbGITRziEo/4JCAhiUhMEpKSjOSkICWpSE0QaUhLOtKTgYxkIjNZyEo2spOD
nOQiN3nISz7yU4CCFKIwRShKMYpTgpKUojRlKEs5ylOBilSiMlWoSjWqU4Oa
1KI2wdShLvWoTwMa0ojGNKEpzWhOC1rSihBa04a2tKM9HehIJzrTha6E0o3u
9KAnvehNH/rSj/4MYCCDGMwQhjKM4YxgJKMYzRjGMo7xTCCMiUxiMlOYyjSm
M4OZzGI2c5jLPOazgIUs4n8rLD9m
            "]]}, {}}}]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{3.4210000089583352`, 0.9767123287671232},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& )},
      Frame->True,
      FrameLabel->{{
         FormBox["\"m\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"xl\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      FrameTicks->{{Automatic, Automatic}, {{{2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {7.600902459542082, 
           FormBox["2000", TraditionalForm]}, {8.517193191416238, 
           FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\"\"", TraditionalForm]}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm]}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      ImageSize->350,
      LabelStyle->{Larger},
      Method->{},
      PlotRange->{0.9767123287671232, 0.9997451587082566},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], {None, None}},
      Ticks->{{{2.302585092994046, 
          FormBox["10", TraditionalForm]}, {2.995732273553991, 
          FormBox["20", TraditionalForm]}, {3.912023005428146, 
          FormBox["50", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {5.298317366548036, 
          FormBox["200", TraditionalForm]}, {6.214608098422191, 
          FormBox["500", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {7.600902459542082, 
          FormBox["2000", TraditionalForm]}, {8.517193191416238, 
          FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {188.125, -113.56374543279317`}, 
     ImageScaled[{0.5, 0.5}], {350, 216.31189606246318`}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJzt2HlQFFcewHFQAWFmmB4u5coIIseIA46ADOcbNMhpQAEjSMAYFgwYFTnE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       "], {{{}, {}, {}, {}, {}, 
         {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{213, 1}], 
          LineBox[{214, 2}], LineBox[{215, 3}], LineBox[{216, 4}], 
          LineBox[{217, 5}], LineBox[{218, 6}], LineBox[{219, 7}], 
          LineBox[{220, 8}], LineBox[{221, 9}], LineBox[{222, 10}], 
          LineBox[{223, 11}], LineBox[{224, 12}], LineBox[{225, 13}], 
          LineBox[{226, 14}], LineBox[{227, 15}], LineBox[{228, 16}], 
          LineBox[{229, 17}], LineBox[{230, 18}], LineBox[{231, 19}], 
          LineBox[{232, 20}], LineBox[{233, 21}], LineBox[{234, 22}], 
          LineBox[{235, 23}], LineBox[{236, 24}], LineBox[{237, 25}], 
          LineBox[{238, 26}], LineBox[{239, 27}], LineBox[{240, 28}], 
          LineBox[{241, 29}], LineBox[{242, 30}], LineBox[{243, 31}], 
          LineBox[{244, 32}], LineBox[{245, 33}], LineBox[{246, 34}], 
          LineBox[{247, 35}], LineBox[{248, 36}], LineBox[{249, 37}], 
          LineBox[{250, 38}], LineBox[{251, 39}], LineBox[{252, 40}], 
          LineBox[{253, 41}], LineBox[{254, 42}], LineBox[{255, 43}], 
          LineBox[{256, 44}], LineBox[{257, 45}], LineBox[{258, 46}], 
          LineBox[{259, 47}], LineBox[{260, 48}], LineBox[{261, 49}], 
          LineBox[{262, 50}], LineBox[{263, 51}], LineBox[{264, 52}], 
          LineBox[{265, 53}], LineBox[{266, 54}], LineBox[{267, 55}], 
          LineBox[{268, 56}], LineBox[{269, 57}], LineBox[{270, 58}], 
          LineBox[{271, 59}], LineBox[{272, 60}], LineBox[{273, 61}], 
          LineBox[{274, 62}], LineBox[{275, 63}], LineBox[{276, 64}], 
          LineBox[{277, 65}], LineBox[{278, 66}], LineBox[{279, 67}], 
          LineBox[{280, 68}], LineBox[{281, 69}], LineBox[{282, 70}], 
          LineBox[{283, 71}]}, {}, 
         {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], LineBox[{143, 72}],
           LineBox[{144, 73}], LineBox[{145, 74}], LineBox[{146, 75}], 
          LineBox[{147, 76}], LineBox[{148, 77}], LineBox[{149, 78}], 
          LineBox[{150, 79}], LineBox[{151, 80}], LineBox[{152, 81}], 
          LineBox[{153, 82}], LineBox[{154, 83}], LineBox[{155, 84}], 
          LineBox[{156, 85}], LineBox[{157, 86}], LineBox[{158, 87}], 
          LineBox[{159, 88}], LineBox[{160, 89}], LineBox[{161, 90}], 
          LineBox[{162, 91}], LineBox[{163, 92}], LineBox[{164, 93}], 
          LineBox[{165, 94}], LineBox[{166, 95}], LineBox[{167, 96}], 
          LineBox[{168, 97}], LineBox[{169, 98}], LineBox[{170, 99}], 
          LineBox[{171, 100}], LineBox[{172, 101}], LineBox[{173, 102}], 
          LineBox[{174, 103}], LineBox[{175, 104}], LineBox[{176, 105}], 
          LineBox[{177, 106}], LineBox[{178, 107}], LineBox[{179, 108}], 
          LineBox[{180, 109}], LineBox[{181, 110}], LineBox[{182, 111}], 
          LineBox[{183, 112}], LineBox[{184, 113}], LineBox[{185, 114}], 
          LineBox[{186, 115}], LineBox[{187, 116}], LineBox[{188, 117}], 
          LineBox[{189, 118}], LineBox[{190, 119}], LineBox[{191, 120}], 
          LineBox[{192, 121}], LineBox[{193, 122}], LineBox[{194, 123}], 
          LineBox[{195, 124}], LineBox[{196, 125}], LineBox[{197, 126}], 
          LineBox[{198, 127}], LineBox[{199, 128}], LineBox[{200, 129}], 
          LineBox[{201, 130}], LineBox[{202, 131}], LineBox[{203, 132}], 
          LineBox[{204, 133}], LineBox[{205, 134}], LineBox[{206, 135}], 
          LineBox[{207, 136}], LineBox[{208, 137}], LineBox[{209, 138}], 
          LineBox[{210, 139}], LineBox[{211, 140}], 
          LineBox[{212, 141}]}}, {{}, 
         {GrayLevel[0], PointSize[0.01], 
          PointBox[{284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 
           295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 
           308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 
           321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 
           334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 
           347, 348, 349, 350, 351, 352, 353, 354}]}, 
         {RGBColor[1, 0, 0], PointSize[0.01], 
          PointBox[{355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 
           366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 
           379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 
           392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 
           405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 
           418, 419, 420, 421, 422, 423, 424, 425}]}, {}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., -61.35542270693228},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& )},
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(a\\), \\(n\\)]\\) (black), \
\\!\\(\\*SubscriptBox[\\(b\\), \\(n\\)]\\) (red)\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"n\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      FrameTicks->{{{{-62.16979751083923, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "27"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-50.65687204586901, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "22"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-39.14394658089878, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "17"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-27.631021115928547`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-16.11809565095832, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-52.854016626405055`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-52.16091444325777, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.75546433473711, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.467789762163456`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.24465071080312, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.06233215398967, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-50.90818361701113, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-50.77465383152617, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-41.341091161434825`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-40.647988978287536`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-40.24253886976688, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.95486429719323, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.7317252458329, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.54940668901944, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.39525815204091, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.26172836655594, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-29.8281656964646, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-29.13506351331731, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.729613404796655`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.441938832223002`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.218799780862668`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.03648122404921, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.88233268707068, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.748802901585712`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.315240231494368`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.62213804834708, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.21668793982643, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.92901336725277, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.705874315892437`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.523555759078985`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.36940722210045, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.235877436615485`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.80231476652414, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.109212583376851, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.703762474856198, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.416087902282545, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.19294885092221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.010630294108756, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.856481757130222, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.722951971645256, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-62.16979751083923, 
           FormBox["\"\"", TraditionalForm]}, {-50.65687204586901, 
           FormBox["\"\"", TraditionalForm]}, {-39.14394658089878, 
           FormBox["\"\"", TraditionalForm]}, {-27.631021115928547`, 
           FormBox["\"\"", TraditionalForm]}, {-16.11809565095832, 
           FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\"\"", TraditionalForm]}, {-52.854016626405055`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-52.16091444325777, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.75546433473711, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.467789762163456`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.24465071080312, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-51.06233215398967, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-50.90818361701113, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-50.77465383152617, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-41.341091161434825`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-40.647988978287536`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-40.24253886976688, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.95486429719323, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.7317252458329, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.54940668901944, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.39525815204091, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-39.26172836655594, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-29.8281656964646, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-29.13506351331731, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.729613404796655`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.441938832223002`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.218799780862668`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-28.03648122404921, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.88233268707068, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-27.748802901585712`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.315240231494368`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.62213804834708, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.21668793982643, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.92901336725277, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.705874315892437`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.523555759078985`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.36940722210045, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.235877436615485`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.80231476652414, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.109212583376851, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.703762474856198, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.416087902282545, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.19294885092221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.010630294108756, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.856481757130222, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.722951971645256, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      ImageSize->350,
      LabelStyle->{Larger},
      Method->{},
      PlotRange->{{0., 4.2626798770413155`}, {-61.35542270693228, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0., 
          FormBox["1", TraditionalForm]}, {0.6931471805599453, 
          FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
          FormBox["5", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {2.995732273553991, 
          FormBox["20", TraditionalForm]}, {3.912023005428146, 
          FormBox["50", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {5.298317366548036, 
          FormBox["200", TraditionalForm]}, {6.214608098422191, 
          FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-62.16979751083923, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "27"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-50.65687204586901, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "22"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-39.14394658089878, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "17"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-27.631021115928547`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-16.11809565095832, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-52.854016626405055`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-52.16091444325777, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-51.75546433473711, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-51.467789762163456`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-51.24465071080312, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-51.06233215398967, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-50.90818361701113, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-50.77465383152617, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-41.341091161434825`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-40.647988978287536`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-40.24253886976688, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-39.95486429719323, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-39.7317252458329, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-39.54940668901944, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-39.39525815204091, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-39.26172836655594, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-29.8281656964646, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-29.13506351331731, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.729613404796655`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.441938832223002`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.218799780862668`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-28.03648122404921, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-27.88233268707068, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-27.748802901585712`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.315240231494368`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.62213804834708, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.21668793982643, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.92901336725277, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.705874315892437`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.523555759078985`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.36940722210045, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.235877436615485`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.80231476652414, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.109212583376851, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.703762474856198, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.416087902282545, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.19294885092221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.010630294108756, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.856481757130222, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.722951971645256, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {564.375, -113.56374543279317`}, 
     ImageScaled[{0.5, 0.5}], {350, 216.31189606246318`}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJzt1ItPU2cYx3FsabE9LUqUThgJDpUgl+q4OW72AaIhiFUQLymlZDoSkuqc
QAYBiZmZBp3gELxsJF4RL6ABkQiK9CmMiU6dDmXoNDgwxqBzJVtASsFtKT9M
/RMWT3Jy8s17cvKe9/3k/Wj95pRMkZOT085/7/+e715/RljH49TPNOnPH+f3
uf1sEsTnCgbKBzWR9bu/CTL2m+zjQ5qLv9g2TCsYNIWU/DEcyyOa5IC2+dUL
Rk2i2f5WocY28b6Y1+qCz2f7vNG4Ro+6f7BIzjk1UZoLx51oRprHw2tj09n+
/SnEe2c1LNO7s2p145V6o4js73ty0qJtl/rVYhrPMIv8S7256HBXi+p3MXUW
NUa31flw8p6PA5x3ONOnLrbo8p55fOrKr6obXhK6mRQqKl48n70TlkeozkpI
qjXsOdoXyPb5S2mX5Oqmz9cv5IJtVrPxrJSGze15h7ODeWeZMbLQ24W0+vjP
nhwL5cAGZ2l4qQuV3IsKCbWEc1l/TmHcsAtd9D/39Lv0CK4/v7lCnTaVfjAc
zHcbiOLOjpi83MtTqeUL66vv9y9mS8PdsSJ3GWkXvpjzYR3xSOC+rac2yij4
4H7z4Nw4tq+fjIRNW1cmn4nnW56WgYrpcuqpP3InImYJf/u1uKk3XU6HMt/E
1jxZynMSD3TrTstJW1xZdbI8gb3Hb/30iUVOwx65r/3WJHJltzBSHSZQheeu
mDC/JNYFlCXczhfId/fDnBsyLRs7m1q7mgWqzcqqfG5dwXeb7v/d81qY2I+V
PKRs/soWpqDEZq/eXkkKd/w1bZVui4JGta36FvdVbN9fBfl6jaekB6Xy1WuR
r/z6FXRz9iNzW9JqPh3b3vGjh5Je6NedeZmzhruVxVkjWiXtuJMt++34WlZm
B0d1bVfSocKAvpIH61hbW7oks1FJvobtIZJZOg6KUaeanilJnZ83RoY0dns5
U2VRuVLddTnF1uo5PtUWLlnqSrUp0aMSkYGrrp/4Ush1JZ8ZigV7MzIYjtHw
jIZnx/GhyYZnNDyj4RkNz47fnzLZ8IyGZzQ8o+EZDc9oeHacv3Sy4RkNz2h4
RsMzGp7R8IyGZzQ8O67f24ZnNDyj4Xny/yY8o+EZDc9oeEbDMxqe0fDsuL9v
G57R8IyGZzQ8o+EZDc9oeEbD87t+35/H78/j/8N5/A8U0Yz8
       
       "], {{{}, {}, {}, {}, 
         {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{46, 1}], 
          LineBox[{47, 2}], LineBox[{48, 3}], LineBox[{49, 4}], 
          LineBox[{50, 5}], LineBox[{51, 6}], LineBox[{52, 7}], 
          LineBox[{53, 8}], LineBox[{54, 9}], LineBox[{55, 10}], 
          LineBox[{56, 11}], LineBox[{57, 12}], LineBox[{58, 13}], 
          LineBox[{59, 14}], LineBox[{60, 15}], LineBox[{61, 16}], 
          LineBox[{62, 17}], LineBox[{63, 18}], LineBox[{64, 19}], 
          LineBox[{65, 20}], LineBox[{66, 21}], LineBox[{67, 22}], 
          LineBox[{68, 23}], LineBox[{69, 24}], LineBox[{70, 25}], 
          LineBox[{71, 26}], LineBox[{72, 27}], LineBox[{73, 28}], 
          LineBox[{74, 29}], LineBox[{75, 30}], LineBox[{76, 31}], 
          LineBox[{77, 32}], LineBox[{78, 33}], LineBox[{79, 34}], 
          LineBox[{80, 35}], LineBox[{81, 36}], LineBox[{82, 37}], 
          LineBox[{83, 38}], LineBox[{84, 39}], LineBox[{85, 40}], 
          LineBox[{86, 41}], LineBox[{87, 42}], LineBox[{88, 43}], 
          LineBox[{89, 44}]}}, {{}, 
         {GrayLevel[0], PointSize[0.01], 
          PointBox[{90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
           103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
           116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
           129, 130, 131, 132, 133, 134}]}, {}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., -125.49311424426244`},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& )},
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"|\\!\\(\\*SubscriptBox[\\(g\\), \\(n\\)]\\)|\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"n\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      FrameTicks->{{{{-126.64218011467251`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "55"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-103.61632918473205`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "45"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-80.5904782547916, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "35"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-57.564627324851145`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "25"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-34.538776394910684`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-105.81355376126828`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-105.12040658115833`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.71494147320017`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.42725940082339`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.20411584955417`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.02179429279022`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-103.8676436129844, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-103.73411222037593`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-82.78770283132782, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-82.09455565121787, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-81.68909054325971, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-81.40140847088293, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-81.17826491961372, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-80.99594336284976, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-80.84179268304393, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-80.70826129043549, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-59.76185190138736, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-59.06870472127741, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-58.66323961331925, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-58.375557540942474`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-58.15241398967326, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-57.970092432909304`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-57.81594175310347, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-57.68241036049503, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-36.736000971446906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-36.04285379133696, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.637388683378795`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.34970661100201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.1265630597328, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.94424150296885, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.79009082316302, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.656559430554566`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.710150041506449`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.017002861396502`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.611537753438338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.323855681061557`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.100712129792347`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.918390573028393`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.764239893222562`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.630708500614112`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-126.64218011467251`, 
           FormBox["\"\"", TraditionalForm]}, {-103.61632918473205`, 
           FormBox["\"\"", TraditionalForm]}, {-80.5904782547916, 
           FormBox["\"\"", TraditionalForm]}, {-57.564627324851145`, 
           FormBox["\"\"", TraditionalForm]}, {-34.538776394910684`, 
           FormBox["\"\"", TraditionalForm]}, {-11.512925464970229`, 
           FormBox["\"\"", TraditionalForm]}, {-105.81355376126828`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-105.12040658115833`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.71494147320017`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.42725940082339`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.20411584955417`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-104.02179429279022`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-103.8676436129844, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-103.73411222037593`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-82.78770283132782, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-82.09455565121787, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-81.68909054325971, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-81.40140847088293, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-81.17826491961372, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-80.99594336284976, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-80.84179268304393, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-80.70826129043549, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-59.76185190138736, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-59.06870472127741, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-58.66323961331925, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-58.375557540942474`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-58.15241398967326, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-57.970092432909304`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-57.81594175310347, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-57.68241036049503, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-36.736000971446906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-36.04285379133696, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.637388683378795`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.34970661100201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-35.1265630597328, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.94424150296885, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.79009082316302, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-34.656559430554566`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.710150041506449`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.017002861396502`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.611537753438338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.323855681061557`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.100712129792347`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.918390573028393`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.764239893222562`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.630708500614112`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      ImageSize->350,
      LabelStyle->{Larger},
      Method->{},
      PlotRange->{{0., 3.8066624897703196`}, {-125.49311424426244`, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{0., 
          FormBox["1", TraditionalForm]}, {0.6931471805599453, 
          FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
          FormBox["5", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {2.995732273553991, 
          FormBox["20", TraditionalForm]}, {3.912023005428146, 
          FormBox["50", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {5.298317366548036, 
          FormBox["200", TraditionalForm]}, {6.214608098422191, 
          FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-126.64218011467251`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "55"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-103.61632918473205`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "45"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-80.5904782547916, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "35"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-57.564627324851145`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "25"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-34.538776394910684`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-105.81355376126828`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-105.12040658115833`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-104.71494147320017`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-104.42725940082339`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-104.20411584955417`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-104.02179429279022`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-103.8676436129844, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-103.73411222037593`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-82.78770283132782, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-82.09455565121787, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-81.68909054325971, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-81.40140847088293, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-81.17826491961372, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-80.99594336284976, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-80.84179268304393, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-80.70826129043549, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-59.76185190138736, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-59.06870472127741, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-58.66323961331925, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-58.375557540942474`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-58.15241398967326, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-57.970092432909304`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-57.81594175310347, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-57.68241036049503, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-36.736000971446906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-36.04285379133696, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.637388683378795`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.34970661100201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-35.1265630597328, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-34.94424150296885, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-34.79009082316302, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-34.656559430554566`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-13.710150041506449`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-13.017002861396502`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.611537753438338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.323855681061557`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.100712129792347`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.918390573028393`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.764239893222562`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.630708500614112`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {940.625, -113.56374543279317`}, 
     ImageScaled[{0.5, 0.5}], {350, 216.31189606246318`}]}, {}},
  ContentSelectable->True,
  ImageSize->{1140.75, 239.12749086558634`},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.521568225390716*^9, 3.521568261232119*^9}, {
   3.521568302528158*^9, 3.521568354431093*^9}, {3.521568408410294*^9, 
   3.5215684140827847`*^9}, {3.521568478089944*^9, 3.521568488103136*^9}, 
   3.5215685501277523`*^9, 3.521568834729026*^9, {3.521568888868875*^9, 
   3.5215689355685663`*^9}, {3.5215689703295803`*^9, 3.521568978442792*^9}, 
   3.521569017938656*^9, 3.521569124213769*^9, 3.521571570470378*^9, 
   3.521572638682838*^9, {3.521572704601987*^9, 3.521572716912177*^9}, 
   3.5215732598966618`*^9, {3.521573400590642*^9, 3.521573430634733*^9}, {
   3.521573526730093*^9, 3.5215735361786127`*^9}, {3.521573577619235*^9, 
   3.521573613096162*^9}, 3.521573653772987*^9, 3.521575140855959*^9, 
   3.521575335144272*^9, 3.52157655428821*^9, 3.52157695041184*^9, {
   3.521577057849348*^9, 3.521577117399819*^9}, {3.52157714808532*^9, 
   3.521577163162632*^9}, 3.5215773579399223`*^9, 3.521607339508292*^9, 
   3.521607926532016*^9, 3.5216080105524473`*^9, 3.52161250727092*^9, 
   3.521612559622246*^9, {3.5216125916162977`*^9, 3.521612613426138*^9}, 
   3.521612643904101*^9, {3.521612679850572*^9, 3.521612747782002*^9}, {
   3.52161277986202*^9, 3.521612834447328*^9}, {3.521613503812934*^9, 
   3.521613527459951*^9}, 3.5216137230097647`*^9, 3.521614455162567*^9, 
   3.521614675131405*^9, 3.521615082172214*^9, 3.521615599574542*^9, {
   3.521616211738356*^9, 3.521616220762095*^9}, 3.521616850996337*^9, {
   3.521616893834407*^9, 3.52161692515396*^9}, {3.52161703456593*^9, 
   3.5216170445167513`*^9}, {3.521617397129939*^9, 3.5216174057857313`*^9}, 
   3.5216211630292053`*^9, 3.5216235637076406`*^9, {3.521623605598248*^9, 
   3.52162364013445*^9}, {3.521625641736467*^9, 3.521625788379078*^9}, {
   3.521633738833371*^9, 3.521633754013761*^9}, 3.521646088064863*^9, {
   3.52164613668686*^9, 3.521646160226124*^9}, {3.521646223605152*^9, 
   3.521646234682745*^9}, 3.521646283023024*^9, 3.521646319311057*^9, 
   3.521646355120262*^9, 3.521646845908127*^9, 3.521647317804397*^9, 
   3.5216476235614433`*^9, {3.521647698035398*^9, 3.52164777553265*^9}, 
   3.52164781029401*^9, 3.521647852866004*^9, 3.521648161841978*^9, {
   3.5216481991687803`*^9, 3.521648231209494*^9}, 3.5244706064773417`*^9, 
   3.524470648882638*^9, 3.5244785884615583`*^9, 3.524478928166471*^9, {
   3.524479324357978*^9, 3.524479342413069*^9}, 3.524479373581811*^9, 
   3.5244795368972178`*^9, 3.524479583502339*^9, 3.524479821059422*^9, {
   3.524479962584749*^9, 3.524479969887472*^9}, {3.524507534191636*^9, 
   3.524507544256336*^9}, 3.527398924956287*^9, 3.527400216681229*^9, 
   3.527400282406777*^9, 3.5274043023605328`*^9, 3.527405343699686*^9, 
   3.527405458579571*^9, 3.527405907804434*^9, 3.527406204440177*^9, 
   3.5274072771072206`*^9, 3.527407443516842*^9, 3.5274076137066727`*^9, 
   3.527409440118637*^9, 3.5274104694073*^9, 3.527415662357574*^9, 
   3.529215470298458*^9, 3.529215527270708*^9, 3.554202854488174*^9, 
   3.554213325458521*^9, 3.554283876685897*^9, {3.5542842393630743`*^9, 
   3.554284256384837*^9}, 3.55428433080551*^9, {3.554284535640851*^9, 
   3.5542845497951202`*^9}, 3.554284645086898*^9, 3.5542846758730373`*^9, 
   3.554284849201388*^9, {3.554285632851495*^9, 3.554285650440641*^9}, 
   3.554286335737341*^9, 3.554286630873106*^9, 3.5543024883975677`*^9, {
   3.5543026238340187`*^9, 3.5543026713648043`*^9}, 3.554303321180629*^9, 
   3.554303372136487*^9, 3.554304018687449*^9, 3.554351076349028*^9, 
   3.5543627366685*^9, 3.554364642797277*^9, 3.562753808218732*^9, 
   3.572172225811096*^9, 3.57228426887582*^9, 3.572284352945916*^9, 
   3.57228438617841*^9, {3.572284439047213*^9, 3.572284456383993*^9}, {
   3.572323096267486*^9, 3.5723231235835857`*^9}, 3.572332125186091*^9, 
   3.572332807456751*^9, 3.572333591775391*^9, 3.5723340600651817`*^9, 
   3.572334092541346*^9, 3.572360649640194*^9, {3.594002364589574*^9, 
   3.594002381549979*^9}, 3.5940039588910837`*^9, 3.594004072329178*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot recorded relative scatter signal vs. particle position zp (",
 StyleBox["optional",
  FontSlant->"Italic"],
 ")"
}], "Subsubtitle",
 CellChangeTimes->{{3.554356073178849*^9, 3.55435612745815*^9}, {
  3.55435656672488*^9, 3.554356584579178*^9}, {3.554356734360877*^9, 
  3.554356736470212*^9}, {3.554364782529314*^9, 3.554364783728806*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ST1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"100", "*", 
        RowBox[{
         RowBox[{"SignalExact", "[", 
          RowBox[{"z0", ",", 
           RowBox[{"Last", "[", "\[Theta]T", "]"}], ",", "s", ",", "w0", ",", 
           "anC", ",", "bnC"}], "]"}], "/", "Inc"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "3500"}], ",", "3500", ",", "70"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScatterT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ST1", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"ST1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ST1", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Total", " ", "Integrated", " ", "Signal"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScaT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ST1", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"ST1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ST1", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Term", " ", "Contribution"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ExtT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ST1", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"ST1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ST1", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Extinction", " ", "Term", " ", "Contribution"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ST2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"100", "*", "0.2", "*", 
        RowBox[{
         RowBox[{"SignalExact", "[", 
          RowBox[{
           RowBox[{"z0", "+", "dzf"}], ",", 
           RowBox[{"Last", "[", "\[Theta]T", "]"}], ",", "sh", ",", "w0h", 
           ",", "anCh", ",", "bnCh"}], "]"}], "/", "Inc"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "3500"}], ",", "3500", ",", "70"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScatterT2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ST2", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"ST2", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ST2", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Total", " ", "Integrated", " ", "Signal"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ScaT2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ST2", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"ST2", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ST2", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Term", " ", "Contribution"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ExtT2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"ST2", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"ST2", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ST2", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Extinction", " ", "Term", " ", "Contribution"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ScatterT", ",", "ScatterT2"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Green", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Signal / Incidence in Percent [%]\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Scatter signals: R=30nm, \!\(\*SubscriptBox[\(n\), \
\(m\)]\)=1.46, \!\(\*SubscriptBox[\(\[Omega]\), \(0, d\)]\)=281nm, \
\!\(\*SubscriptBox[\(NA\), \(d\)]\)=0.75\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ScaT", ",", "ExtT", ",", "ScaT2", ",", "ExtT2"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Green", "]"}], ",", 
          RowBox[{"Dashing", "[", "0", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Green", "]"}], ",", "Dashed"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Signal Contributions / Inc in Percent [%]\>\"", ",", 
          "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Sca (solid) & Ext (dashed) signals: R=30nm, \
\!\(\*SubscriptBox[\(n\), \(m\)]\)=1.46, \!\(\*SubscriptBox[\(\[Omega]\), \
\(0, d\)]\)=281nm, \!\(\*SubscriptBox[\(NA\), \(d\)]\)=0.75\>\""}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"P1", ",", "P2"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5543562396674547`*^9, 3.554356364414831*^9}, {
  3.5543613961991787`*^9, 3.554361401419422*^9}, {3.554361810078732*^9, 
  3.554361823642433*^9}, {3.554361856256405*^9, 3.554361880790666*^9}, {
  3.5543619150026627`*^9, 3.554361927727792*^9}, {3.554362038059795*^9, 
  3.554362077755541*^9}, {3.5543621789282837`*^9, 3.554362181048173*^9}, {
  3.5543627113598557`*^9, 3.554362725981574*^9}, {3.554364769879615*^9, 
  3.5543648132780123`*^9}, {3.554441756868984*^9, 3.5544417574536057`*^9}, {
  3.5544431776169863`*^9, 3.554443483193014*^9}, {3.554443516511323*^9, 
  3.5544435684922953`*^9}, {3.55444359861852*^9, 3.554443615831827*^9}, {
  3.554443850043208*^9, 3.5544438560808487`*^9}, {3.554443943281294*^9, 
  3.5544439490389967`*^9}, {3.593959271054925*^9, 3.59395929106588*^9}, {
  3.5939596700329847`*^9, 3.593959673625757*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw9lQ1MU1cUx4uRCIZNho6YpXNaO5gyIxrDoDJ7uhjWDRwDPyAKmygVBkzo
BEVRaCdYLYxRwA6BYSmFCYyBWudAPg7gAD/4WPEDQbCEqaCuChSGSOcc9969
5OXll5t3z/+e9z//t2xXtL9kDofDkby6/3vOXoHlmJzAfb5obnHDLF8vQ22o
U9yTsSLCUIZOnoqojgotYX0pwuZ7//itLST8XineXdix5qWlgHD+GcwucNAF
O+cRtj+DzqalGc+G1ISTf8Kxp94Nh9ZnEp4qQY1GcZh7QEk4qgRXhqp3Dw4l
ETYWY1cCxjcpQwlvKcbeD8QL4NQe4Sy36bCu1rfFgSMj7KnDnitOC8IkJwhX
FeGtXpfcuzkZhPlFuDn0BHeTbxbhHC02mlqXbQjJJmynRcNuL6s8MV2XFSLv
y/J1jwbSCZs1+GurgPtAQuuFa5BnXDyTiuFE32+ncXBHz/WaJVmENQWIu85J
1m3UET7+I6ZMyO+kv6giHJOPB+d/nVsfW004MA8vhATEFHQ30v7nokdClVpq
aKX9PoVj1ff8hbUdtL85uNP/B9HUJ920n2oU6iTqhorbtH8nMWir97125V3C
bdm4wtVh2dlRI+GqLAyodU327h8inJOJvsn8jmu2DwnLVCi7OHcvN/4R4fAM
HE0VPChxNtHzpaN9sIjfNH+UnicNM8Z9pm+9PU71K3F4qeu8qY8nqN7jqLpo
2saX/031paD+/Kmm9XXPqZ6jmHY2yCXg0QtaX46OaxMkzSYLrZeIewcq8u6X
vKT7H8LV1brsQSkHyX5xaBavMd24QFkmxWuWtMdlSZQhAg884STx9tD3ZSE4
krWzv1Y+Q9kPl8bWqFxCpwi/ur7qzVS+GTTO1sFh4I1ir5uP2fvQZzH8lbZx
kOqJgNvL7S+1mzvpuhSeNg+nzlNRvxvjwLbceLmT1yyk+iFs4f4y5/guIT0f
VA4/XyVffoP6Tw767d8IFV43qZ+PwjsfunGPpNJ1YwpYOjXGwqMGIe0vLHTc
rPDz6qT7K8G9oi+6+FibkH4f+Lw++jX9pkZaLx3ao7Z4pE6fp37OgOnayU8P
9qlpfRVE1Hyf+VRwmvkDhIkBZlGAnvkHbKRp3nZ1Dcxf4Lk1elIzcZn5D3Ru
YyNzIq8wf8IvcXceSgXtzL8wevh45BLXLuZvODli69YW9QfzP3BbJuf0+BvY
fEDqDPJLhwxsfuBZR/OOFl43my/AwNWr5jp2s/mDWPf47aLfDWw+wefYJesH
HpTDNbAtepHgo0Raz6wBmxMb7o/kUz2yQgDRohVioN/TTgvmt6aTx3lUf44W
gl36s7vGrhLmF4HPFqvDkfVttD9F8Lr1RG+zqoWwpw7EB91td+yn/WnTwWKD
DTdkXxPLN+j8UzRg/g5Z/sFn+6zcezPrWD5CQWWMo9i3huUnLJBePZ3kf5Hl
K6RXSYZH8vQsf2G1tdbz2xXnWD7D+zd7YuKeVbL8BviiNUhj8zPLd8h9d6qP
m3WG5T8ktnhM2yn+/z+A3FK6UtpH/weB5SBQOB4JU2ga/gVCnl0Q
         "]]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], 
        LineBox[CompressedData["
1:eJw1lQlQU1cUhqOVAqKFMh2pUEtBCo4oY2vBwbZ4mMxUUSNLN0QKBaEg7Qgo
UIgSRA2NQqlhK0uAAGFJ2AJEZKnkUAYB2RFJw7AjKhRF1mIHpdZ375158+ab
++695/z3nP+ZeAe6+G5ksVi+r57/36+HazEuVfYKvlwtVL7mDhnO+NlBGLeI
YZDhJa4qsm2dsEKKcQOmh3ZekzK8S4pTUhtOroGMYVERlu+3/gJLCOsVoaE2
e4/f0WKGrxaihf6v85sXCa8WYN1Q//kWaQnDPxWgh85RhyvnShkey8fQ6+os
A5cyhr/KxwfeGVaRJ8oZbpUglES84B2QM/yZBG28F7jWI4TleWgzacGSiSsY
NsvD4QYrlTG/kuHUXPSdLYyYS6hieEsusjfxMzP6FAxfysF0PNM2zKlmeEmM
Cccta/N1axj2FyNbWDekYVbHcE02xrPfin4z9Q+GxVkYGuJhcDJCybAgE7fe
dtuyGNDIcJAIPxR5BKV918SwawbWl/5u0ZveTPRPx28kbupOi1aidxpqBZq3
f6vVTvRNxUfJL+2C7LqInin4eeukWm+qh+iXjL5Jbu0d/X1EryQUhob80jfb
T/RJREGR7qccSxXRIwETGsMcOuPVJH8hPq9mf72ybYjkewP3zimndZpHSH7x
qIwquGnQNUbyicPy1v3aOU4TJP7raGYyGHP8ySSJV4A8/QWvxcIpEh8fc1Y9
s934j0g8VzDSblRVFztNzo/GoNMVlp5Nf5PzeLh24aLovQNPyf5cXJnJ1gLu
M7JfKAoneqxaNBbI+mCseMe6oOvOIvk+AGWmH5iYNi+TeS+cHsgIC9i0StgZ
72bu5Tnw/mX41fA+37U1a/sLOg+Rtmsa3jnrdD1kDSa6uI2zkOwPTuG9DoL4
DUjOh6rHDZyoKsJjoXD5VJSc60AYuLAUZzyjDiDrxTwI55h3o+AlzR9y7tnW
Z72xRvUBn08ynI34z6l+4FOzx91s3z9UXzBOW1cq9Jep/jBhdi/S0WqR3g/c
EJ465subp/cHKfPLVv6rc/R+welChWOy/RN6/7BxfilyrH2G1gfkjsX+thD3
mNYPCIXTdeKLD2l9QQ9bXS5KekDrDxQftZo+7Z6g9Ql2MdUHubvHaf1Ck/hy
R7b9KK1vGLx1Pzr4+yFa/7CwO9+rsVRN+wNiDv21646FivYPGLl71zt29dP+
ApmhT87HuX20/yCosUWaLOmh/QkTI3N6kpJO2r/wfvLmAc3Au7S/Ydth7atF
8S20/yGC4zE8rdlM/QF+sPxZEn3/T+ofYCpRqkafIfUXkGXvEx3Jb6D+A4Mh
O/J2PKyn/gSxKfIjt5NqqX9B91jCMdvcW9Tf4O2z6JzNqqb+BzqTGxwP5imo
P4LmjzfDq3hV1D/hhPOKveG1Suqv4B5e7j9YW0H9F/SkMqMC7Qrqz1DNf1fv
5Dk59W+Y1S06LR8up/4Ong3bd44vl1H/h26/NsVZ8zL6fwD0rBtSnSH+7FoM
M8HBibX1Jcr/AFxNbh8=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"Signal / Incidence in Percent [%]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Scatter signals: R=30nm, \\!\\(\\*SubscriptBox[\\(n\\), \
\\(m\\)]\\)=1.46, \\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(0, d\\)]\\)=281nm, \
\\!\\(\\*SubscriptBox[\\(NA\\), \\(d\\)]\\)=0.75\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->Automatic,
      PlotRangeClipping->True], {346.6666666666667, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1lQtQlFUUxxFwNEPBxGzASUwpBHSAGQckwkP4KIzRRAYaQYJc5LU8VgkQ
V3ZxQaIFdmklHrsssMtjeQ0ggkLI0XwiiJI0hYUYGkWODyCkESjz3nNnvvnm
N/f77j3nf8/537VhcXsFxkZGRoKXz//vVyOwDvWN2p1tlw5ufcW9tShquCGc
LxIwhlo83qxx9TwWzrjVgKMNd6MyYg4xtjOgWUXS8L/REYzVNTjdun12JjWS
sUUNHromvHJPE8VYVo2/dPR8ueuHaMYzVSgrKRswelvIOKYKN8DGvTNpsYxH
KvH2m9e8BC/iGO+rxKHeMdOQ6/GMr+nxj47xP8P0CYw99Pi4Nnhsl0LEuEmH
1qNap6Hcw4zX63CD4Jz/4oojjAsrcM+UW7hlbyJjswr87X5vV7Z5EmNJOWYP
2AzsjUtmPFWGus4dwvOPUxhHlGF4UfBPJcpUxme1uGxdUOGuIDHjslKsXuAg
G/JLY5ylQSONTGXRLWEcr8ac7csHp55KGQeWYMjuh5dzvU9w/YtxxFZy6nin
jOtdhJLdHmnOBzK5voXY8pV3/hKXLK5nAZrEuFiqPLO5fqfQaJ9oTadczvVS
4bz4C8dV7+Vxfb7BhvR70jVLlVyPfLx1+/rEqY58nr8S9c7qBYN6Fc9XgY1C
2UzEjwU8v1z0jdQY4/4ino8cl3xf5/iZt5rHn425I6t8bmm0PN4sLPgEl/af
L+fxZeDN5wbRuhc6Hs8JlNm3bfHOqeL7SzGnJLYg4piB73ccn7x+emVNTz1f
/yjayMvT3nFr4uslosfHV0Pr7Fv4/wkYFKxeHW3byr+PwnN9jtPWJm18PhS7
clXd4vx2zp/iHne/t1pLzzJ+OfpXr8+8OXeW5qFfNGmo0BKHQswtD5Grqp3W
h/FnJ53CF9L6CRDiPhG20K6V4oPKAA+/4I0tFD84Bs41X3RvovzgtW6fbcr+
esofxJcnvUYkBtIHMgJzRkFZRfqBdem75YZ5HekLMZJA798vlJP+oC91s3LV
ael8YFVw4yKLj9R0frDMrKvm15AiOl+odDZ1MR4qoPMHL91T19lqFdUHNNgH
2+3vyqf6AelsTYrCXEn1BT6FY2siHPKo/kDw9YUVeQo51Sf4pjwynvXKpvqF
R+1tDy03Z1F9Q1uCQ/L455lU/+D7YXHF0y4Z9QfY5Uz0Xdx+gvoHrAP8Eycm
pNRfcBWm9g2jhPoPatPvSNcGpFF/wn1B0qWdIWLqX5AHHCjwV6VSf8MNxbzp
B89SqP9heIdJsTohmfwBHvzj51m5PIn8A/56oyjJ9GYi+Qv8vXLYbUB3hPwH
Jp946qWKw+RPkB99fcsdpYj8CzZrNi3ur0wgf4OjueUnm3viyf8g2jq+8e5c
HPkjmNVbbduWHkv+Ceb1Hc9tbYTkrzB9psTKdzCa/Bd8vBcNozaK/BnSz2Q6
fSeOJP8GVe2EqloYQf4OD5oUfStiD5H/g+e3p98/Iw6n+wE6N8X+HFLC74fA
OnCR27SbXDm49T+ZESM+
         "]]}, 
       {RGBColor[1, 0, 0], Thickness[Large], Dashing[{Small, Small}], 
        LineBox[CompressedData["
1:eJw9lQ00lmcYx5lKTfORmGOF7diJTlRD747Key1fq1i0MozOkA35XlrT6Cmq
l8lX8pWP1+v7Y3GEvbzncIXQfBXFdsJs42Ck8OoYeq2573vPOc95zu88z7nv
6/o//+t/v+8ZdNL7LTk5Oe8393/P9cu5HAMvpLp/5VDUtM5dZRiuq+AWZ1dI
GMrQ4l15h2SNAsI1paijfPO0dqmIsEEpqkT3pDZtzCOcVYKmp++0DDnlEFYt
QbPiWUEFL5NwdDHa235oPFZ7m/BSEeJfac6f/Z5I2L8Ida46tc0m3SA8WoiO
R62G1S3DCZ8qxJoW5cWV+dOEOwpQP8LX+trP/vx1PlSAHtLv3vtkJ0e4Kh/1
WhV32PndIKyfj6qaB5RT7eMIp4vQxetb1dChm4S3ivCeU1F+8JYfCXN5OLyY
2QnFVwlLhah3QrKHd/5Lwj5ClGwwm365FEXqEediwdkX1d1htF9hDi428+oq
jUsIC7JRP2bbTLD6PcLBWbjHRMVsuFpC2PkOVtTVug0qtlD9MzEtYjNnqPOQ
6p2BF5p8zdTUHlF907Ei0DBVoPSE6pmKuTxFXs3lX6l+t/H1hI3YJGiY6pWC
uo0tEfaBfxCuuoUBYj5X4z1GOD0Zh/saIoS5E4S5JFTOUNO03DlN2CcRz1TK
jFxHZml/8VjTd1x/f/Ac7ScOs0VrZ8biF2j9sejLOX8a1LZI6xXgq3q3Xm2V
JVrfNQxV2Duy3X2Z1hOFI567re/nrNL9r+BCkXFZUYOM7heJ30iMArNt5JCs
H45JD/JKRAuUR8PQIop/dLetPGEuBOtGQ6wG9CiDH5YO7dfd7UW/5zzwyZBL
/djya7qfI7YV8/s1Z/8h/OY6sGMxdH5ayt6Dv53DsvkU7Z/zgKk07SF1HtUP
/OBr5TJfvPSUvg8Bt3Mz1rZdYtpvGJyTRR84olXDp/WDOPz5yvO+Dj7tD3oS
gzcmxDyi/rsCCn+a8M5p9lE/R4FKcuvaqfrHfKofmK9equhSoN+rCmBp8YdX
g09/oevHgmdGSpxFciuf/h9wGV/QOhsjofvFQ8rnx3J2WZdTPyeCl02tQULI
oAX9/zBgDONhc6XMHzDdEdiYvqme+Qc0nFdML8o1M39Bc0/AxS8m25j/wPWE
8TMl007mT7A8vLkkaaSH+ReqP6rb1j73iPkbPrDujOnV7WP+h73pSoL2pT42
HyBN3HdwMKKfzQ+Ufh/4wr26n80XtC0P6Cpl9bP5g8jYy6PZR/rZfMK4V7e+
VyVdz0cItZMBibdmHhOWCuF41Mnf7m6gzOWBxGj++t/ytL6tImhpmLnLPeum
eohgYSFDDHm0P/18WLHqeCfWi85rVT7Er2pO2hq3Ez5UAAWtm8qn3n7A8gvk
bY+lJMi1sHwDq7lIv2Pb77P8A0PpeY2HyY0sH0EWnfSxq6WE5ScE2Qh6uYNi
lq9wON7cMSW8luUvHOUnW3KyapbPcET4MsOgtYrlN0wINAfCE35i+Q7l+x5r
ybaUsfyH+TWp/eTs/+cD+I+CwS4zeh44l4MsQSBu789r+hc9UFct
         "]]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Dashing[
        0], LineBox[CompressedData["
1:eJw1lQ8w1GkYxx2iCSPVxV2n4yahOnWaO26OPPrrmKv8y/qz1i7Lkv//krgs
SWM6s4QhRHYtW2q01DUu9sk5Q626zqkuuZNyM02IpBNdruv3Pu/Mb37zmff3
vu/zfN/n+f6sRQk+Yl0dHR3xu+f/9/vBO48P9u4Upxb7uL1n7TmMPK+3fHGn
L8dwDqO3B9Te1/XjuE2FmuzvevpvMrZTocv4G19NnT/H1U3oeQVOK3IPcLy8
CWP3f76xKDmA42ONOD8cvtCUxON4TomvdxjNu0sDOY5VYrlK5HijPojjkQZs
y20vGroXzLFfAwqf7wvc9hmf414F5sa71jzPC+XYRYEO+9tkdosCjlvk2Kpr
W7P1ZhjH6+SY9XR6t4tSyHFFPY4suNtsLxFxbFyPpSuuHTYpDuc45yxauwvs
5YoIjl/WYVBaxvG9t8UcS+qw3jfqn+aVURxfrcWKVtXoT6kSjuvOoCY1XfR0
NprjEzV4cs+H4XZVBzlOrMaxL7e8XhodxzGvCr9K9p8ZjEhg+p9GXbuWQyE3
Epnelfiyx8prZjGJ6VuBPUPiwpiAFKZnOVrY8jWawVSmXxkWbbTteZiTzvQq
RVHeGVOtIIPpcwqzRp2s5jMzmR4luPnZzIuCh1ks/2L0TLV7ppYdZfnKUFfi
ZbnJV8ryK0IXnnt+v3key+ckooN2ZbB1Pou/EA2q1TnS7AIW7wnUEdzp+dS1
kMWXjylN7rnGaT+wePJwyhNk2bUydr4U7Q0vhzgPl7DzvscOXl9k//Eytn8m
2qvG/rylrmD7pWHRB/5RnZnVbH0SShX7eo9k1bHvYzBgiccerbWczQtRT+/w
CosvlIy9cYuu4crHNSqO3w0Hec506bYLNA+BZe2+44IWWg+hCeZtI3cu0f4Q
52Dr5XxRTefD6LGCitHraooPHqgj/rBYqqb44W7wj/wlF1ooP1jVONUZNU7n
SaH60dT4b57nSB9oDupqH/hVSfrBMsVe0aOLctIXJgIv/vzXLOVbCJJlO1Zf
8Kih+4HkXW5HfMMq6f5gXe4n+hqLcrpfqHx77agV7xTdPzzuMpf7GBZTfUC9
6SoDF5siqh/ovmUe6z9QSPUF31726frmbQHVH5hNbAh0l+VTfUKj97Er9w7l
Uf3CZMXmtG6llOobdjzpE2SY5VD9Q+XY2k0m/GzqD/BzvBseP55J/QOJzR4G
wu4M6i9Y79l9J+JBOvUftF46q482adSfYOBk4mVfm0L9C6tHtwblQTL1N4jX
mEUq9ZOo/8HV0XlCciuB/AE6T5aWjffGkX+AR5DRXPaLg+Qv8FGT0SvVrhjy
H/iYP1nV2SEhf4KF2w3RzQeiyL+gr/y66YRxJPkbRFsqiuOHI8j/IHxS+Er6
Szj5I/ztcH9Y2yUi/wSZ4b9JrgNC8lfQn0/bozMbRv4LwjXawUPrw8if4c3c
UE6MNpT8G7x/t4x/IuaTv0PVyNfZ5uYh5P+wwdHq8MJwEP0fwEkh8uy8yvya
dx7WTi+KOxp4bv8B+asVwg==
         "]]}, 
       {RGBColor[0, 
         NCache[
          Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], 
        Dashing[{Small, Small}], LineBox[CompressedData["
1:eJw1lQtMk1cUxxHijKssDJjDERIWmBIpL4dIMydH1qSITsZDRVwQEORlxlAr
BLdipUxWWcMbyhuhyJtSCzKYcByPsSEgSHGwEsojEGVgUdiQh8753fslX778
cu89957/Pef/fRwU5RWiq6OjE/Lm/f/79vGtxkjVuvVEckX7W35QhdzENudC
40qGoQozHIdcNUWElZUY53qiVmhXxbBVJfJSR3gVnYTzKzCQsy1SFVDNsEEF
Fl7KL1jfWsOw6DbudAjj5DQRXi3Hv5xkCYP8WoYvlGON+XiulFfHsEaGYn+P
qyP29Qz7yNB+SZHym6mc4Z4yXCtZbJU0ED5Yhlc+3W+2z7+BYXkpHjN9v0Bv
j4Jhy1K0On7+Z0/DOwzn3ELuxqBYuEfJ8I5bODrjtd0yqpHhayUoa1FO6b5o
Yni5GA8ZnLUxb2tmOKwYNb18bqm6heHmItybahFQc+Yew8WF+J4xx0FkiQwn
FSDbcK727Oh9hr/Nx1dff5Hx+aMOhn3zUKQXEh9s0k30z8WsT0zumdf1EL2l
CPz4kFM5vUTfHOzq9Ey3Hu0nembh2MHJP0OdB4l+mWjkcOnQQ9tHRK8MLHqm
uOt5XEX0SUfDpBQLTuZjokcauqS6hrvojpH8U/EPX605J1NN8k3BC+5V7jKP
CZKfBM0TW+evfDRJ8knGyJfX+btlU+T8YsyYVye7Hp0h503C1VP6k3MGs+R8
iej6OmzQdn2OnCcBRyCws8ngKdlfiJWs7EU3v7/JfgL8tVuxzXt6kcSPwzyh
KZc1riXx+Jjt9I2VIuY5WR+NI6kxIoX7MpkfgaogvwR7/3/IeCDqFtkdeNG4
StgT1aquLOej6wy/eb6L9WtM03tFxyFiKS9E7q2DZD3synL0fRK1BUl86GzY
u2PNQpeMR8OYZUKQ5AhhDR9MhO4xraN0fhwM8fQ/cNWSeMUCkA+Z6VvGvqb5
Q71fideKaoPqAxxe9LOSz9aofiCycQnN6/uX6gsLLLO2c7krVH9gObD3XSx9
Qe8HyiVu0tnpJXp/MBxx0yjbR0vvF7jn6r1Pqhfo/cOuen0jU595Wh+gsS+L
v7H1Ca0feKCVGizOzdL6AplkqjBzeYbWH4SPs63sdk/T+oTE7BTp6dhJWr/w
oxlbq+qfoPUNm+8Mczc1alr/IC4/kbXfYoz2B3yVEzoVk/6Y9g/0Ca66BDqo
aH/BsHW1Y/7mEO0/cHIbq2S/fEj7E/Lc3M4UHOmn/Qv2jmota0sv7W9YGuDc
7dvZQ/sfuLZGQosbXdQfQPp930nZsQ7qH3BzsGigMuA+9RdY2NDM82Paqf9A
x9xGNqvmF+pP8G7XZvVFjxbqXyBaMFAWezVTf4N1yZfd4ttN1P9A8Fzpf/5w
I/VHELDLJn43VlL/BDHnBxvlh3eovwLbaj7i+mEF9V94uv302Ki4gfoz5K6Y
togX5NS/gRef3BEVLKf+DsE/6U1IR+qp/0NgeFqK/2Yd/T/A9GX9gYIDhH2r
4XJ0iWDuWm37f+CaYNQ=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"Signal Contributions / Inc in Percent [%]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Sca (solid) & Ext (dashed) signals: R=30nm, \
\\!\\(\\*SubscriptBox[\\(n\\), \\(m\\)]\\)=1.46, \\!\\(\\*SubscriptBox[\\(\
\[Omega]\\), \\(0, d\\)]\\)=281nm, \\!\\(\\*SubscriptBox[\\(NA\\), \
\\(d\\)]\\)=0.75\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRangeClipping->True], {1040., -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}]}, {}},
  ContentSelectable->True,
  ImageSize->1000,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.554356342489012*^9, 3.554356370580905*^9}, 
   3.554361545541397*^9, 3.5543618859770308`*^9, 3.554361932969805*^9, 
   3.5543620546224422`*^9, 3.554362186707753*^9, 3.554362754507432*^9, 
   3.554365016650524*^9, 3.554441003666239*^9, 3.5544411591994762`*^9, 
   3.554441242958618*^9, 3.554441813956923*^9, 3.5544434891308517`*^9, {
   3.554443561938539*^9, 3.554443578390108*^9}, 3.554443610432521*^9, 
   3.55444366376622*^9, 3.554443866768265*^9, 3.554443959874082*^9, 
   3.554450400648498*^9, 3.5572073396032457`*^9, 3.557207456420929*^9, 
   3.557207505622402*^9, 3.5572075872568417`*^9, 3.557207685135941*^9, 
   3.5573950297549*^9, 3.562753388646475*^9, 3.572172260733809*^9, 
   3.5722843272258472`*^9, 3.572284370649775*^9, 3.572284422147085*^9, 
   3.593959298663742*^9, 3.5939596466030893`*^9, 3.5939596798895206`*^9, 
   3.5939632967574167`*^9, 3.594002412372489*^9, 3.5940024452871733`*^9, 
   3.594003728292598*^9, 3.594003931193472*^9, 3.594003985888056*^9, 
   3.594004084109055*^9, 3.5940042219423532`*^9, 3.594006992650283*^9, {
   3.5940071784832907`*^9, 3.5940071988633347`*^9}, 3.594113045494178*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Test Parameters (check if \[Sigma]abs is positive!) and PTSignal-function (",
 StyleBox["optional",
  FontSlant->"Italic"],
 ")"
}], "Subsubtitle",
 CellChangeTimes->{{3.554356073178849*^9, 3.554356077195969*^9}, {
  3.554356748271414*^9, 3.554356767757653*^9}, {3.554450491918532*^9, 
  3.554450495174467*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"SignalExact", "[", 
    RowBox[{"0", ",", 
     RowBox[{"Last", "[", "\[Theta]T", "]"}], ",", "s", ",", "w0", ",", "anC",
      ",", "bnC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"\"\<\[Sigma]sca:\>\"", ",", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"[", "5", "]"}], "]"}], 
    SuperscriptBox["nm", "2"]}], ",", "\"\<\[Sigma]ext:\>\"", ",", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"[", "6", "]"}], "]"}], 
    SuperscriptBox["nm", "2"]}], ",", "\"\<\[Sigma]abs:\>\"", ",", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"[", "7", "]"}], "]"}], 
    SuperscriptBox["nm", "2"]}], ",", "\"\<rel. PT Signal at zp=-200\>\"", 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{"PTSignal", "[", 
      RowBox[{
       RowBox[{"-", "200"}], ",", "\[Theta]T", ",", "dzf", ",", "Ph0"}], 
      "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.521615418633884*^9, 3.521615421317812*^9}, {
   3.521615461623341*^9, 3.521615465555677*^9}, {3.521615659300653*^9, 
   3.521615659561119*^9}, {3.521624560818931*^9, 3.521624575016168*^9}, {
   3.521625098081406*^9, 3.521625104192593*^9}, {3.521625826470109*^9, 
   3.5216258269715023`*^9}, {3.521634051028142*^9, 3.52163405875404*^9}, {
   3.521963684483417*^9, 3.5219637078742456`*^9}, {3.524478950602977*^9, 
   3.524478955682186*^9}, 3.554283312861802*^9, {3.554283594871685*^9, 
   3.554283595223415*^9}, {3.554283663305183*^9, 3.554283686260915*^9}, {
   3.554284777094105*^9, 3.5542847916157427`*^9}, {3.554285658523575*^9, 
   3.554285686089827*^9}, {3.554302723019614*^9, 3.554302724914713*^9}, {
   3.554303338102179*^9, 3.554303347390071*^9}, {3.554303382812953*^9, 
   3.554303391099832*^9}, {3.554351060289485*^9, 3.5543510686330214`*^9}, {
   3.554351760562888*^9, 3.554351766110104*^9}, {3.554351925387075*^9, 
   3.554351996128913*^9}, {3.554352677370064*^9, 3.554352749765689*^9}, {
   3.554353467882284*^9, 3.5543534680400352`*^9}, {3.554353519180559*^9, 
   3.554353522103649*^9}, {3.5543560683424263`*^9, 3.5543560710857477`*^9}, {
   3.5543561733413258`*^9, 3.554356174059503*^9}, {3.554362024924013*^9, 
   3.554362025713594*^9}, {3.554362835906406*^9, 3.5543628373104153`*^9}, {
   3.554441196086293*^9, 3.554441199603572*^9}, {3.554441295894147*^9, 
   3.5544413137356253`*^9}, {3.554447821280139*^9, 3.5544478214306917`*^9}, {
   3.554447910922935*^9, 3.5544479115459833`*^9}, {3.554447960242586*^9, 
   3.5544479606170683`*^9}, {3.554448035328307*^9, 3.5544480422227*^9}, {
   3.554449833358203*^9, 3.554449834675596*^9}, {3.5627538600350323`*^9, 
   3.5627538639707727`*^9}, {3.562754253244885*^9, 3.562754254075968*^9}, {
   3.5939593123022738`*^9, 3.5939593429610147`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[Sigma]sca:\"\>", ",", "1.3842890545586408`*^-15", 
   ",", "\<\"\[Sigma]ext:\"\>", ",", "2.4314804118116938`*^-15", 
   ",", "\<\"\[Sigma]abs:\"\>", ",", "1.0471913572530531`*^-15", 
   ",", "\<\"rel. PT Signal at zp=-200\"\>", ",", "0.0029964181972931036`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5215696862954807`*^9, 3.521569689756096*^9}, 
   3.5215699883214083`*^9, {3.52157009989622*^9, 3.5215701502955437`*^9}, 
   3.521570216619741*^9, 3.521570251322666*^9, 3.521570485618533*^9, {
   3.521570538812088*^9, 3.521570549708638*^9}, {3.521571495653551*^9, 
   3.521571507771782*^9}, 3.5215715386825037`*^9, 3.5215715994796352`*^9, {
   3.521571783956273*^9, 3.521571803183187*^9}, 3.52157187815702*^9, {
   3.521571944524386*^9, 3.5215719582550173`*^9}, {3.5215721189500303`*^9, 
   3.521572180870329*^9}, 3.5215725021064377`*^9, {3.521572734036729*^9, 
   3.5215727483401213`*^9}, 3.521573269479147*^9, 3.521573448521069*^9, 
   3.521573803699615*^9, 3.5215740474190702`*^9, 3.521574353324685*^9, {
   3.5215744183001738`*^9, 3.5215744673379097`*^9}, {3.521574504016616*^9, 
   3.5215745205342693`*^9}, 3.521574589922703*^9, 3.521574633759204*^9, {
   3.521574705675239*^9, 3.52157471255377*^9}, 3.521574751386016*^9, 
   3.521574800194105*^9, {3.521574833888842*^9, 3.5215748611475773`*^9}, {
   3.521575174855918*^9, 3.521575203381949*^9}, {3.521575234660941*^9, 
   3.521575256421527*^9}, 3.521575304785771*^9, {3.521575437177188*^9, 
   3.52157545355309*^9}, {3.521575494158648*^9, 3.5215755234895163`*^9}, 
   3.5215756171020737`*^9, 3.521576520111562*^9, 3.52157655696739*^9, 
   3.521576690151412*^9, 3.521577218531391*^9, 3.521577259193507*^9, {
   3.521577377184387*^9, 3.5215773936899014`*^9}, 3.521612867368288*^9, 
   3.521613556928914*^9, 3.5216135918320427`*^9, 3.5216136554791403`*^9, 
   3.5216142948322372`*^9, 3.5216153925902*^9, 3.521615447620528*^9, 
   3.5216154976888533`*^9, 3.521615593335801*^9, 3.521615670154537*^9, 
   3.521616813958702*^9, 3.5216169411171837`*^9, 3.52162108458609*^9, 
   3.521621115895718*^9, 3.521621176939404*^9, 3.5216245524675903`*^9, 
   3.5216245847270393`*^9, {3.5216246200501633`*^9, 3.521624683321608*^9}, {
   3.52162495347256*^9, 3.521624960997271*^9}, {3.521625054767658*^9, 
   3.521625108864872*^9}, 3.521625141200721*^9, {3.521625824132036*^9, 
   3.5216258306573563`*^9}, 3.5219637094029284`*^9, {3.524470586530177*^9, 
   3.524470614795991*^9}, 3.524470659786065*^9, 3.524478602356069*^9, 
   3.524478956049753*^9, 3.524479124254724*^9, 3.524479246124971*^9, 
   3.5244793525350723`*^9, 3.5244793919867268`*^9, 3.5244795895318947`*^9, 
   3.524479753984036*^9, 3.524479828952655*^9, 3.524479974060669*^9, 
   3.524507550788107*^9, 3.554202883494179*^9, {3.55428358298141*^9, 
   3.554283596796651*^9}, 3.554283631716136*^9, 3.554283688161935*^9, 
   3.554283880468733*^9, 3.5542847141338663`*^9, 3.554284757374186*^9, 
   3.554284853481476*^9, {3.554285666743217*^9, 3.554285693197591*^9}, 
   3.554286292189513*^9, 3.55428633924233*^9, 3.554286635276257*^9, {
   3.554302627722227*^9, 3.554302672255762*^9}, {3.5543033248331327`*^9, 
   3.55430339168244*^9}, 3.5543510903483953`*^9, 3.554351767240999*^9, 
   3.5543519648391943`*^9, 3.554351996708189*^9, {3.554352066767757*^9, 
   3.554352121076763*^9}, 3.554352505465733*^9, {3.554352587591269*^9, 
   3.554352633219063*^9}, {3.554352681404275*^9, 3.55435275029377*^9}, {
   3.5543534391544952`*^9, 3.554353468735656*^9}, 3.55435352362883*^9, {
   3.554353556509585*^9, 3.554353569777886*^9}, 3.55435360610385*^9, 
   3.554356193681181*^9, 3.554360596179454*^9, 3.554360654622122*^9, 
   3.554360698529498*^9, 3.554361050619117*^9, 3.554362026488673*^9, 
   3.554362204536582*^9, 3.554362838009468*^9, {3.5543646251857233`*^9, 
   3.554364655065777*^9}, {3.554434974599214*^9, 3.554434998240081*^9}, 
   3.5544351144726267`*^9, 3.554435154585536*^9, {3.554441179192856*^9, 
   3.5544412107794323`*^9}, 3.55444127954895*^9, 3.554441319584506*^9, 
   3.554447825417934*^9, {3.554447887592692*^9, 3.5544479155726547`*^9}, 
   3.554447964628024*^9, {3.5544480285914927`*^9, 3.554448046946657*^9}, 
   3.554448469096637*^9, {3.554448883424077*^9, 3.5544488959707108`*^9}, {
   3.554449830584235*^9, 3.554449855482959*^9}, 3.5544504878739033`*^9, {
   3.554505767795706*^9, 3.554505791911859*^9}, 3.5545058385494947`*^9, 
   3.554524587962154*^9, 3.562753420659231*^9, 3.562753486419345*^9, 
   3.562753527441457*^9, 3.562753591477379*^9, 3.562753823439999*^9, {
   3.562753860616506*^9, 3.56275386464977*^9}, 3.5627539789628983`*^9, 
   3.562754223898868*^9, 3.5627542584460163`*^9, {3.572172271192609*^9, 
   3.572172286126293*^9}, {3.593959309601837*^9, 3.5939593474867563`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot rel. PT signal vs. particle position zp \n",
 StyleBox["Example here AnNP:",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"R", "=", 
    RowBox[{"30", "nm"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["\[CapitalDelta]T", "0"], "=", 
    RowBox[{"99", "K"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["n", "m"], "=", "1.46"}], ",", " ", 
   RowBox[{
    RowBox[{"dn", "/", "dT"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3.6"}], "e"}], "-", "4"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["\[Omega]", 
     RowBox[{"0", ",", "d"}]], "=", 
    RowBox[{"281", "nm"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["\[Omega]", 
     RowBox[{"0", ",", "h"}]], "=", 
    RowBox[{"233", "nm"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["NA", "d"], "=", "0.75"}]}]]]
}], "Subsubtitle",
 CellChangeTimes->{{3.554356073178849*^9, 3.554356077195969*^9}, {
  3.5543565340701323`*^9, 3.554356549219762*^9}, {3.5543645181309547`*^9, 
  3.5543645289786367`*^9}, {3.554448989441111*^9, 3.554449001864436*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"start", "=", 
    RowBox[{"SessionTime", "[", "]"}]}], ";", 
   RowBox[{"PTT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"PTSignal", "[", 
         RowBox[{"z0", ",", 
          RowBox[{"Last", "[", "\[Theta]T", "]"}], ",", "dzf", ",", "Ph0"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "2500"}], ",", "2500", ",", "50"}], "}"}]}], "]"}]}], 
   ";", 
   RowBox[{"Time", "=", 
    RowBox[{
     RowBox[{"SessionTime", "[", "]"}], "-", "start"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Computes", " ", "Signals"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTPT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"PT", " ", "signal"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTScaC", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Cold"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTScaH", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Hot"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"PTTPT", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"FillingStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Lighter", "[", "Blue", "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<(Hot - Cold) / Incidence\>\"", ",", "\"\<\>\""}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<rel. PT signal\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTTScaC", ",", "PTTScaH"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Red", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "2", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Lighter", "[", "Blue", "]"}], ",", "Red"}], "}"}]}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Hot / Incidence  &  Cold / Incidence\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Hot (dark red) And Cold (blue) Scatter Signals\>\""}], "}"}]}],
        "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"P1", ",", "P2"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTContributionSca", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Contribution", " ", "due", " ", "to", " ", "Sca"}], "-", 
    "Term"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTScaCold", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Sca", "-", 
    RowBox[{"Term", " ", "Cold"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTScaHot", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Sca", "-", 
    RowBox[{"Term", " ", "Hot"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTContributionExt", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "7", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Contribution", " ", "due", " ", "to", " ", "Ext"}], "-", 
    "Term"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTExtCold", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "8", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Ext", "-", 
    RowBox[{"Term", " ", "Cold"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTExtHot", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "9", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Ext", "-", 
    RowBox[{"Term", " ", "Hot"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PSca", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTScaCold", ",", "PTScaHot"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Red", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "2", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Lighter", "[", "Blue", "]"}], ",", "Red"}], "}"}]}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<(Hot Sca) / Inc  &  (Cold Sca) / Inc\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Hot (dark red) & Cold (blue) Sca-Signals\>\""}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PExt", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTExtCold", ",", "PTExtHot"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Red", "]"}], ",", "Dashed"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "2", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Lighter", "[", "Blue", "]"}], ",", "Red"}], "}"}]}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<(Hot Ext) / Inc  &  (Cold Ext) / Inc\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Hot (dark red) & Cold (blue) Ext-Signals\>\""}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PTcontr", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTContributionSca", ",", "PTContributionExt"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black", ",", "Dashed"}], "}"}]}], "}"}]}], 
     ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"FillingStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Lighter", "[", "Blue", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<(H(sca)-C(sca))/Inc & (H(ext)-C(ext))/Inc\>\"", ",", 
          "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<rel. PT signal contributions\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"PSca", ",", "PExt", ",", "PTcontr"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.554355815171976*^9, 3.554355818784419*^9}, {
   3.554356119660359*^9, 3.554356120429572*^9}, {3.554356488070941*^9, 
   3.554356515462016*^9}, {3.5543613138675203`*^9, 3.554361314127425*^9}, {
   3.554362216832094*^9, 3.5543622179261637`*^9}, {3.5543628466195927`*^9, 
   3.5543628577862797`*^9}, {3.554363472034923*^9, 3.55436348331042*^9}, {
   3.554363664206089*^9, 3.554363692097706*^9}, {3.5543637222461557`*^9, 
   3.554363741732123*^9}, {3.554364480824059*^9, 3.554364571480357*^9}, {
   3.554441358510845*^9, 3.5544413600370207`*^9}, {3.5544417391933393`*^9, 
   3.5544417501877813`*^9}, 3.554442836708419*^9, {3.554444151092305*^9, 
   3.5544442588916283`*^9}, {3.554447813559103*^9, 3.554447813828631*^9}, {
   3.55444820108237*^9, 3.554448209401906*^9}, {3.557395221607525*^9, 
   3.557395221822351*^9}, {3.594113071645857*^9, 3.594113073391032*^9}}],

Cell[BoxData["692.580589`8.990985313217063"], "Output",
 CellChangeTimes->{3.554441718955344*^9, 3.554441947925045*^9, 
  3.554442463963841*^9, 3.554442974845772*^9, 3.5544445104571743`*^9, 
  3.554448431386397*^9, 3.554448844095916*^9, 3.554449249668663*^9, 
  3.554450297370735*^9, 3.557395469984969*^9, 3.562754695573524*^9, 
  3.572172695248231*^9, 3.5941137670641947`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxd1QtQlFUUB/AFQWRQEFhkBeORgEKkayGiYnvABwGKsLx1AVlCUScWURKN
RzDxBmGFRZbnLqiDBb6gLAn24AzhKC1mWqbkgxzENIUIWkQw8h6apjvzzc5v
7tx7zvl/38zaiiXCWG0OhxM3/fzz+3rlNuBkna68/erIe69t14C+2Z61OXaj
zFiPC0V7+ip6x5hF9Rjg65MhuK1h1ihRvfdrZVrgBHOZEgX1+ZkrN08x85XI
2+De0vCEI3jtHgX6GPH29+vMYo5T4OG0zq2FqbrMOgqMi/ftqxbPYYY6FI7w
pfsvGTAn1+IfbQvW/9VkxHy2BqdcTwXfX2jCPFiNTrbB0Q5fcJltqvHx2ECe
ZYs5c1gV9qvHe9utLZlLKnH24sbeqDnWzJflWHbDy2aw3ZaZI8fPLiZ4eW60
Y3arQIt3phJjFi9hTjiGJ+5sdj4gdmJuLEcfVcBQ27xlzPdlaDLww/F7vBXM
PBleKb5pz49/l9m/DIt6RkM/MXRlzi1F/2CRhVB7NTMexTAP+2NzAt2ZNVLM
MzrM/VgXmPlSfDWs9fN5C0/KswSXWN039JNsoPyKce+joKIBfS/Kqwi3riu9
njrsTfkU4sXJCxjx9hbKIx8tVu0eSxD70/x5aPahp3lxlJDmzcEC6+WrHaVB
NF8W6vQYfp8/HkLzfIpTpyS3C+Xh1H8mztYLNTgnEVG/GXjml2L53Y+iqL90
DDdwSAkURlM/Kbjv5HBZ2oiY6h/CvKcRt5pLPqB6Saj1Um+TiruT7k/ESm+v
ZBPxLrpPgqvT29bEBsTR+d0o32Y+PnKOjGIMv6AWDvnO7IfjnaiL6xIG6D6O
N75/fTc3K4DqTa8zTtuzRvfvmNmHAvuWDEFryMx5uLDCpMVSd+PM/dCXuLPz
QLyDiurD1Zu39GJM/VXUH1hyV+hbmYpU1D88t77k6vSrWEXzwcFXvr7h3jvp
/CFYXt6Z3bQsTkX5gHpX1C6HNjKkw1Et59JYVzI/A6xqgkNch+k8ZsL5RbKD
ipWxKno/8EIivasniKF6WbCvVW2W5RatovcLN0y1HyWmRlL9PHBOajz7sGub
ir4PiA9oljWJQqmfQtDiOTZZegep6PsCO66jrKAggPorhjdPpBjvAT/muBKQ
T7UX8bV9qF8pxL81fk3it4lZI4WlhW6tXy5YT/0fhSR97cdaW4A5txScjqS9
kFxeS/OUwcq5goxuxSpmngxUjiddiua50HwyuNXf3H5ygs/cWA6/93f8mNDq
TPMeg/ktkdcGXZYyu1XAvCv3bK9G2tH8crB3N2tIsrRlviyHI+JvMOT0Isqj
Eoz7wroPaPGYw6rA44EoJNiES/lUg5lRd9WTb+czD1bDRMomQwvjuZRXDeSU
FsRMZusxJ9fCG04ukTbfzaL86iC/qjwiu4vDrKOAh7UeNyc/f9nB8lRAjPDB
U+9eDXOPAravVX810DPKzFfCaXXF2Z8yRpjLlKA5YxBU2TvMrFGCdW3U1Kmq
IWZRPcg83J861j5nxnrY0bL4tzVNz5jtGmDjSMHxLgE5twFy4v9stXF/1mE8
/DxdXxINnP+u6f+X//nf/b8BcCUTiA==
       "], {{
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{101, 104, 102, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63,
             64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 
            80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 
            96, 97, 98, 99, 100}}]]}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{1, 103, 102, 53, 52, 51, 50, 49, 48, 47, 46, 45, 44, 
            43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 
            27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 
            11, 10, 9, 8, 7, 6, 5, 4, 3, 2}}]]}, {}, {}}, {{}, {}, 
         {GrayLevel[0], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 102, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
           66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82,
            83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 
           99, 100, 101}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"(Hot - Cold) / Incidence\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox["\"rel. PT signal\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {-0.0030189275812348764`, 
       0.00301454211215042}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {346.6666666666667, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1ns81OkeB/BRRJQtEXJZWtokMpFm5DSPGJeQwbgkMq4zXeQyNE1RLmHK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       "], {{{}, {}, {}, {}, {}, {}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
            33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
            49, 50, 51, 52, 53, 204, 203, 154, 153, 152, 151, 150, 149, 148, 
            147, 146, 145, 144, 143, 142, 141, 140, 139, 138, 137, 136, 135, 
            134, 133, 132, 131, 130, 129, 128, 127, 126, 125, 124, 123, 122, 
            121, 120, 119, 118, 117, 116, 115, 114, 113, 112, 111, 110, 109, 
            108, 107, 106, 105, 104, 103, 102}}]]}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{203, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164,
             165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
            178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
            191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 101, 
            100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 87, 86, 85, 
            84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 
            68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 
            204}}]]}, {}, {}}, {{}, {}, 
         {RGBColor[0, 0, 1], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 204, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
           66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82,
            83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 
           99, 100, 101}]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], Thickness[Large], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 
           127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
           140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 
           153, 154, 203, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
           165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
           191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"Hot / Incidence  &  Cold / Incidence\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Hot (dark red) And Cold (blue) Scatter Signals\"", 
          TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {-0.02088785038823714, 
       0.003319069985500612}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {1040., -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.554441718955344*^9, 3.554441947925045*^9, 
  3.554442463963841*^9, 3.554442974845772*^9, 3.5544445104571743`*^9, 
  3.554448431386397*^9, 3.554448844095916*^9, 3.554449249668663*^9, 
  3.554450297370735*^9, 3.557395469984969*^9, 3.562754695573524*^9, 
  3.572172695248231*^9, 3.5941137671538687`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1ns01HkfB/CRSQ0jM665VDNGpc39NmGMrzRPseRSdrEldGEIRbO6LLoi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       "], {{{}, {}, {}, {}, {}, {}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{154, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 157, 
            156, 161, 160, 159, 158, 201, 200, 155}}]]}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{156, 162, 163, 164, 165, 166, 167, 168, 169, 170, 
             171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 
             184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 
             197, 198, 199, 101, 100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 
             89, 88, 87, 86, 85, 84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 
             73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 157}}], 
            PolygonBox[{{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
             112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 
             125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 
             138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 
             151, 152, 153, 155, 154, 52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 
             42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 
             26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 
             10, 9, 8, 7, 6, 5, 4, 3, 2, 1}}]}]}, {}, {}}, {{}, {}, 
         {RGBColor[0, 0, 1], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 154, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 157, 64, 
           65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
            82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
           98, 99, 100, 101}]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], Thickness[Large], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 
           127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
           140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 
           153, 155, 200}], 
          LineBox[{201, 158, 159, 160, 161, 156, 162, 163, 164, 165, 166, 167,
            168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 
           181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 
           194, 195, 196, 197, 198, 199}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"(Hot Sca) / Inc  &  (Cold Sca) / Inc\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Hot (dark red) & Cold (blue) Sca-Signals\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {0., 0.0011852806867116072`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {349.375, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl1ns01OkfB/BJFFsrlVai5HLQ2hrCEDKPULmUy0ZG7tdxiWJFlBi3jNuQ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       "], {{{}, {}, {}, {}, {}, {}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
            33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
            49, 50, 51, 52, 53, 204, 203, 154, 153, 152, 151, 150, 149, 148, 
            147, 146, 145, 144, 143, 142, 141, 140, 139, 138, 137, 136, 135, 
            134, 133, 132, 131, 130, 129, 128, 127, 126, 125, 124, 123, 122, 
            121, 120, 119, 118, 117, 116, 115, 114, 113, 112, 111, 110, 109, 
            108, 107, 106, 105, 104, 103, 102}}]]}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{203, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164,
             165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
            178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
            191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 101, 
            100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 87, 86, 85, 
            84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 
            68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 
            204}}]]}, {}, {}}, {{}, {}, 
         {RGBColor[0, 0, 1], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 204, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
           66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82,
            83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 
           99, 100, 101}]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], Thickness[Large], 
          Dashing[{Small, Small}], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 
           127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
           140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 
           153, 154, 203, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
           165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
           191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"(Hot Ext) / Inc  &  (Cold Ext) / Inc\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Hot (dark red) & Cold (blue) Ext-Signals\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {-0.02159748623124418, 
       0.0028242472909427037`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {1048.125, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJyNlns0lekexzd2mdAkl5Iol21jRxHnkOh9KEQyKuWSasadNhqiUpMGo5RC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       "], {{
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{101, 209, 207, 64, 65, 66, 67, 68, 69, 70, 71, 72, 
             73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 
             89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100}}], 
            PolygonBox[{{206, 208, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
             14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
             30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
             46, 47, 48, 49, 50, 51, 52}}]}]}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{206, 207, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 
            53}}]]}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{202, 205, 203, 155, 156, 157, 158, 159, 160, 161, 162,
             163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 
            176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 
            189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 
            201}}]]}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{102, 204, 203, 154, 153, 152, 151, 150, 149, 148, 147,
             146, 145, 144, 143, 142, 141, 140, 139, 138, 137, 136, 135, 134, 
            133, 132, 131, 130, 129, 128, 127, 126, 125, 124, 123, 122, 121, 
            120, 119, 118, 117, 116, 115, 114, 113, 112, 111, 110, 109, 108, 
            107, 106, 105, 104, 103}}]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
         {GrayLevel[0], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 206, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 207, 64, 
           65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
            82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 
           98, 99, 100, 101}]}, 
         {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 
           127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
           140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 
           153, 154, 203, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
           165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
           191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"(H(sca)-C(sca))/Inc & (H(ext)-C(ext))/Inc\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox["\"rel. PT signal contributions\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {1746.875, -210.90409866090158`},
      ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.554441718955344*^9, 3.554441947925045*^9, 
  3.554442463963841*^9, 3.554442974845772*^9, 3.5544445104571743`*^9, 
  3.554448431386397*^9, 3.554448844095916*^9, 3.554449249668663*^9, 
  3.554450297370735*^9, 3.557395469984969*^9, 3.562754695573524*^9, 
  3.572172695248231*^9, 3.594113767251006*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot rel. PT signal vs. \[CapitalDelta]T or heating Power at zp of maximum \
and minimum rel PT signal (needs previous cell or manual definition of \
zMax/zMin)\
\>", "Subsubtitle",
 CellChangeTimes->{{3.554356073178849*^9, 3.554356077195969*^9}, {
  3.5543565340701323`*^9, 3.554356549219762*^9}, {3.5543645181309547`*^9, 
  3.5543645289786367`*^9}, {3.554448989441111*^9, 3.554449001864436*^9}, {
  3.557397673763517*^9, 3.55739774914205*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dTScale", "=", 
   RowBox[{
    RowBox[{"dTh", "[", 
     RowBox[{"0", ",", "\[Theta]T", ",", "Ph0"}], "]"}], "/", "Ph0"}]}], ";", 
  
  RowBox[{"NPh", "=", "25"}], ";", 
  RowBox[{"PhMax", "=", 
   RowBox[{"Ph0", "*", "4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zMax", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"PTTPT", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "==", 
         RowBox[{"Max", "[", 
          RowBox[{"Last", "/@", "PTTPT"}], "]"}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PTTcontr", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ph0i", " ", "dTScale"}], ",", 
       RowBox[{"PTSignal", "[", 
        RowBox[{"zMax", ",", "\[Theta]T", ",", "dzf", ",", "Ph0i"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ph0i", ",", 
       RowBox[{"PhMax", "/", "200"}], ",", "PhMax", ",", 
       RowBox[{"PhMax", "/", "NPh"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTPTtot", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTTcontr", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTTcontr", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTTcontr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"PT", " ", "signal"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTScacontr", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTTcontr", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTTcontr", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTTcontr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Cold"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTExtcontr", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTTcontr", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTTcontr", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "7", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTTcontr", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Hot"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zMin", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"PTTPT", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "==", 
         RowBox[{"Min", "[", 
          RowBox[{"Last", "/@", "PTTPT"}], "]"}]}], "&"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PTTcontrMin", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Ph0i", " ", "dTScale"}], ",", 
       RowBox[{"PTSignal", "[", 
        RowBox[{"zMin", ",", "\[Theta]T", ",", "dzf", ",", "Ph0i"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ph0i", ",", 
       RowBox[{"PhMax", "/", "200"}], ",", "PhMax", ",", 
       RowBox[{"PhMax", "/", "NPh"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTPTtotMin", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTTcontrMin", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTTcontrMin", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTTcontrMin", "]"}]}], "}"}]}], "]"}]}], 
   ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"PT", " ", "signal"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTScacontrMin", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTTcontrMin", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTTcontrMin", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTTcontrMin", "]"}]}], "}"}]}], "]"}]}], 
   ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Cold"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTExtcontrMin", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTTcontrMin", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTTcontrMin", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "7", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTTcontrMin", "]"}]}], "}"}]}], "]"}]}], 
   ";"}], 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Hot"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PContrMax", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTTPTtot", ",", "PTTScacontr", ",", "PTTExtcontr"}], "}"}], 
     ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<PT Signal Contributions at Max\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[CapitalDelta]T [K]\>\"", ",", 
          "\"\<PT: Sca(Blue), Ext(Black), Total(Red)\>\""}], "}"}]}], "}"}]}],
      ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PContrMin", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"PTTPTtotMin", ",", "PTTScacontrMin", ",", "PTTExtcontrMin"}], 
       "}"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"{", "Larger", "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<PT Signal Contributions at Min\>\"", ",", "\"\<\>\""}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\[CapitalDelta]T [K]\>\"", ",", 
           "\"\<PT: Sca(Blue), Ext(Black), Total(Red)\>\""}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"PContrMax", ",", "PContrMin"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.557396096728737*^9, 3.557396097088546*^9}, {
  3.557396145920619*^9, 3.55739615242312*^9}, {3.557396296715372*^9, 
  3.557396408004874*^9}, {3.55739644413173*^9, 3.55739657885041*^9}, {
  3.557396641533547*^9, 3.557396651146059*^9}, {3.557396749150352*^9, 
  3.557396766386565*^9}, {3.557396820524868*^9, 3.557396844911439*^9}, {
  3.557397055762163*^9, 3.557397275809376*^9}, {3.5573976078528843`*^9, 
  3.557397632241496*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA0lqb843F/z9BAygkeSIQPxZjB9kf
3zFAhz9eI4sSQj8/iGpp8+BAQMofOWt//lA/9F5R5lbSSECxDYR8+OFYP9Qa
nDHdYVBACOq62elZYD8vhg/wjlpUQLucXsYZOmQ/ifGCrkBTWEDHvP0KnRFo
P+Nc9mzyS1xAvSOud4Tgaz8f5LQVUiJgQKItjqbgpm8/y5nu9KoeYkBZNWj+
YLJxP3lPKNQDG2RAjYkPVRyNcz8mBWKzXBdmQKSiBVaqY3U/07qbkrUTaEDB
Hw3mEjZ3P4Bw1XEOEGpA7nHz0F0EeT8uJg9RZwxsQIw+tsmSzno/2ttIMMAI
bkBnaPBquZR8P8NIwYeMAnBApaQuN9lWfj+bI173uABxQGIHosx8CoA/cf76
ZuX+cUCjXlLykOeAP0fZl9YR/XJAPxzdqqzCgT8etDRGPvtzQGSqdojTm4I/
9Y7RtWr5dEAxLboUCXODP8tpbiWX93VAI7hUylBIhD+iRAuVw/V2QBU3tBuu
G4U/eB+oBPDzd0AZOuFvJO2FP+J+t5A=
         "]]}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA0lqb843F/z/lZOFaBPQBvxZjB9kf
3zFAW7hdaaJZMr8/iGpp8+BAQDQeL7scLD+/9F5R5lbSSECIIuRdAFtEv9Qa
nDHdYVBAgvZA+LN7R78vhg/wjlpUQP7OhQ86+Ei/ifGCrkBTWEBy8qCdp9BI
v+Nc9mzyS1xAuGdhqxUFR78f5LQVUiJgQNweZ0ihlUO/y5nu9KoeYkC6PmQG
1wQ9v3lPKNQDG2RA+XHphWUuL78mBWKzXBdmQEJqGvaE1fE+07qbkrUTaECs
h1N2cBg1P4Bw1XEOEGpATEU6G9osRj8uJg9RZwxsQI1FY5guuFE/2ttIMMAI
bkA9zD6JRCtZP8NIwYeMAnBA7mT0Ysi3YD+bI173uABxQH+j9qh5QmU/cf76
ZuX+cUAYtwgppTVqP0fZl9YR/XJAqHXUBzmRbz8etDRGPvtzQI1jsj6RqnI/
9Y7RtWr5dEB557zspsB1P8tpbiWX93VAOjfaP9MKeT+iRAuVw/V2QOOoRXcL
iXw/eB+oBPDzd0C+F4svoh2APy0Du3k=
         "]]}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA0lqb843F/z9stZhRexwZPxZjB9kf
3zFAhxsNWFw/Sz8/iGpp8+BAQFHnBJqGyVg/9F5R5lbSSEB9D7tVvIdhP9Qa
nDHdYVBAryfL19Y4Zj8vhg/wjlpUQHYQQEooeGo/ifGCrkBTWEBg+WXyxkVu
P+Nc9mzyS1xA0z5D8eTQcD8f5LQVUiJgQKz6U3wkRnI/y5nu9KoeYkBCec5u
roJzP3lPKNQDG2RAG9U+gY+GdD8mBWKzXBdmQDiID9HUUXU/07qbkrUTaEBD
56fei+R1P4Bw1XEOEGpAQymMjcI+dj8uJg9RZwxsQCdtnSOHYHY/2ttIMMAI
bkBYtaBI6El2P8NIwYeMAnBALHK0BfX6dT+bI173uABxQAS9yMS8c3U/cf76
ZuX+cUC4YSBQT7R0P0fZl9YR/XJAqf3P0by8cz8etDRGPvtzQDjxOtIVjXI/
9Y7RtWr5dEDncrc8ayVxP8tpbiWX93VAF3KeqZwLbz+iRAuVw/V2QImKRYCh
XGs/eB+oBPDzd0BriVgBCT5nP0r3uPM=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"PT Signal Contributions at Max\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"\[CapitalDelta]T [K]\"", TraditionalForm], 
         FormBox[
         "\"PT: Sca(Blue), Ext(Black), Total(Red)\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->Automatic,
      PlotRangeClipping->True], {346.6666666666667, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA0lqb843F/z/8kujLdq4MvxZjB9kf
3zFAjxA/G8lHQL8/iGpp8+BAQF8UAFfbBk+/9F5R5lbSSEBBHaY/iwNXv9Qa
nDHdYVBAUeFLdryjXr8vhg/wjlpUQGMTl7HBMWO/ifGCrkBTWECulpF2MiFn
v+Nc9mzyS1xA/ckUXfQfa78f5LQVUiJgQJ2yEI7MLW+/y5nu9KoeYkCH3Xy/
QKVxv3lPKNQDG2RA6txWdO26c78mBWKzXBdmQKqQSN/Q13W/07qbkrUTaECA
megS0Pt3v4Bw1XEOEGpABS/nttAmer8uJg9RZwxsQIPU7gK5WHy/2ttIMMAI
bkCefyy8b5F+v8NIwYeMAnBAxcwlGG5ogL+bI173uABxQO3kGxlzi4G/cf76
ZuX+cUDJIjQLu7GCv0fZl9YR/XJAyQyuVzrbg78etDRGPvtzQIwQsqTlB4W/
9Y7RtWr5dEC4H5TVsTeGv8tpbiWX93VAgzZlBZRqh7+iRAuVw/V2QNW4MImB
oIi/eB+oBPDzd0C3bpDsb9mJv6OUyK4=
         "]]}, 
       {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA0lqb843F/z+2HkiwsZ4HvxZjB9kf
3zFAVsYLX8opNr8/iGpp8+BAQLYPR7wUxkC/9F5R5lbSSEAFFZ5us49Cv9Qa
nDHdYVBAAYa9cw50QL8vhg/wjlpUQBQKd2kM6zS/ifGCrkBTWEAFZ9uRwtHy
vuNc9mzyS1xAFgswoKdMOj8f5LQVUiJgQKhkN+GGvk4/y5nu9KoeYkC5+yEk
sBdaP3lPKNQDG2RAF17TyohdYz8mBWKzXBdmQF1YqzkApGo/07qbkrUTaEDN
AsEoQ29xP4Bw1XEOEGpAcE36Vi8Gdj8uJg9RZwxsQHPZRlFkFns/2ttIMMAI
bkA5+nzRv0+AP8NIwYeMAnBADlb5X45Qgz+bI173uABxQD1TX4VqjYY/cf76
ZuX+cUCKq2PtHwaKP0fZl9YR/XJAGrMzQXm6jT8etDRGPvtzQNm8QhUg1ZA/
9Y7RtWr5dEBe9viqnuqSP8tpbiWX93VAlzx/O5wdlT+iRAuVw/V2QA/44ST8
bZc/eB+oBPDzd0BeGyVLoduZP2tutxc=
         "]]}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA0lqb843F/z8Y0YFuFD/kvhZjB9kf
3zFAkLXkro/LJL8/iGpp8+BAQFQJcjWNgTy/9F5R5lbSSEB9Ja4QY3dLv9Qa
nDHdYVBAUR5tPLVpVr8vhg/wjlpUQCIyaCRglGC/ifGCrkBTWEDg323xjvtm
v+Nc9mzyS1xAYMsaUYlpbr8f5LQVUiJgQORFLyO3bnO/y5nu9KoeYkB1XIXI
LCt4v3lPKNQDG2RA9YvA2bFpfb8mBWKzXBdmQGweD37olIG/07qbkrUTaEAn
ztSdibWEv4Bw1XEOEGpAOr7wBoAWiL8uJg9RZwxsQPvWGqqOt4u/2ttIMMAI
bkAIOpOvd5iPv8NIwYeMAnBAapEPPH7ckb+bI173uABxQBScPc9uDJS/cf76
ZuX+cUAq50t87VuWv0fZl9YR/XJA8d9wzNnKmL8etDRGPvtzQB/Fm+cSWZu/
9Y7RtWr5dEA5BsOVdwaev8tpbiWX93VA6+sYH3NpoL+iRAuVw/V2QD0qvXQe
36G/eB+oBPDzd0BcqbagLGSjv0auxoU=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      Frame->True,
      FrameLabel->{{
         FormBox["\"PT Signal Contributions at Min\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"\[CapitalDelta]T [K]\"", TraditionalForm], 
         FormBox[
         "\"PT: Sca(Blue), Ext(Black), Total(Red)\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->Automatic,
      PlotRangeClipping->True], {1040., -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.55739783229137*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot PT Backwards Signal Scans for various Laserd-defocusing dzfs\
\>", "Subsubtitle",
 CellChangeTimes->{{3.554283212944129*^9, 3.5542832520600986`*^9}, {
  3.5543568051913147`*^9, 3.554356808228037*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"NAd", "=", "1.4"}], ";", 
   RowBox[{"\[Theta]Min", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Pi]", "-", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"NAd", "/", "nmed"}], "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"180", "/", "\[Pi]"}], ")"}]}]}], ";", 
   RowBox[{"\[Theta]Max", "=", "180"}], ";", 
   RowBox[{"d\[Theta]", "=", "1"}], ";", 
   RowBox[{"\[Theta]TB", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[Pi]", " ", 
       RowBox[{"\[Theta]", "/", "180"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\[Theta]", ",", "\[Theta]Min", ",", "\[Theta]Max", ",", "d\[Theta]"}],
        "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Backwards", " ", "defoc"}], "-", "Scan"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"start", "=", 
    RowBox[{"SessionTime", "[", "]"}]}], ";", 
   RowBox[{"PTT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"PTSignal", "[", 
         RowBox[{"z0", ",", "\[Theta]TB", ",", "dzf"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "2500"}], ",", "2500", ",", "50"}], "}"}]}], "]"}]}], 
   ";", 
   RowBox[{"Time", "=", 
    RowBox[{
     RowBox[{"SessionTime", "[", "]"}], "-", "start"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Computes", " ", "Signals"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTPT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"PT", " ", "signal"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTScaC", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Cold"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTTScaH", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Scatter", " ", "Signal", " ", "Hot"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"PTTPT", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"FillingStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Lighter", "[", "Blue", "]"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<(Hot - Cold) / Incidence\>\"", ",", "\"\<\>\""}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<rel. PT signal\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTTScaC", ",", "PTTScaH"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Red", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "2", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Lighter", "[", "Blue", "]"}], ",", "Red"}], "}"}]}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Hot / Incidence  &  Cold / Incidence\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Hot (dark red) And Cold (blue) Scatter Signals\>\""}], "}"}]}],
        "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GraphicsRow", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"P1", ",", "P2"}], "}"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTContributionSca", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "4", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Contribution", " ", "due", " ", "to", " ", "Sca"}], "-", 
    "Term"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTScaCold", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "5", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Sca", "-", 
    RowBox[{"Term", " ", "Cold"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTScaHot", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Sca", "-", 
    RowBox[{"Term", " ", "Hot"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTContributionExt", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "7", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Contribution", " ", "due", " ", "to", " ", "Ext"}], "-", 
    "Term"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTExtCold", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "8", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Ext", "-", 
    RowBox[{"Term", " ", "Cold"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PTExtHot", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"PTT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"PTT", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "9", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "PTT", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Ext", "-", 
    RowBox[{"Term", " ", "Hot"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PSca", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTScaCold", ",", "PTScaHot"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Red", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "2", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Lighter", "[", "Blue", "]"}], ",", "Red"}], "}"}]}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<(Hot Sca) / Inc  &  (Cold Sca) / Inc\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Hot (dark red) & Cold (blue) Sca-Signals\>\""}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PExt", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTExtCold", ",", "PTExtHot"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Blue", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"Darker", "[", "Red", "]"}], ",", "Dashed"}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "2", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Lighter", "[", "Blue", "]"}], ",", "Red"}], "}"}]}], 
         "}"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<(Hot Ext) / Inc  &  (Cold Ext) / Inc\>\"", ",", "\"\<\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<Hot (dark red) & Cold (blue) Ext-Signals\>\""}], "}"}]}], 
       "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PTcontr", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PTContributionSca", ",", "PTContributionExt"}], "}"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black", ",", "Dashed"}], "}"}]}], "}"}]}], 
     ",", 
     RowBox[{"LabelStyle", "\[Rule]", 
      RowBox[{"{", "Larger", "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"FillingStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Lighter", "[", "Blue", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<(H(sca)-C(sca))/Inc & (H(ext)-C(ext))/Inc\>\"", ",", 
          "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(z\), \(p\)]\) [nm]\>\"", ",", 
          "\"\<rel. PT signal contributions\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "650"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"PSca", ",", "PExt", ",", "PTcontr"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.521557086872822*^9, 3.521557090055807*^9}, {
   3.521557229779995*^9, 3.5215572336844997`*^9}, {3.521557295298682*^9, 
   3.521557324666504*^9}, {3.521557405874601*^9, 3.521557452037805*^9}, {
   3.5215576511136627`*^9, 3.5215577019607773`*^9}, {3.521557811700547*^9, 
   3.521557815245161*^9}, 3.52156772264777*^9, {3.521567968230057*^9, 
   3.5215679841928787`*^9}, {3.5215706931567717`*^9, 3.521570693787068*^9}, {
   3.52157087015832*^9, 3.521570871470286*^9}, {3.521572782566271*^9, 
   3.521572782868771*^9}, {3.521573002102228*^9, 3.521573010364791*^9}, {
   3.521573304045681*^9, 3.521573313971458*^9}, {3.52157564448444*^9, 
   3.521575725825268*^9}, {3.521575788346366*^9, 3.52157580353981*^9}, {
   3.521576624898656*^9, 3.5215766252021503`*^9}, {3.5215767169623957`*^9, 
   3.521576783126425*^9}, {3.52157682206063*^9, 3.521576867699655*^9}, {
   3.5216146381222343`*^9, 3.5216146383991547`*^9}, {3.52161561534333*^9, 
   3.5216156173382807`*^9}, {3.521617419986599*^9, 3.521617433672058*^9}, {
   3.5216177770957947`*^9, 3.521617781565381*^9}, 3.52161841017416*^9, {
   3.521618756858536*^9, 3.521618758418006*^9}, {3.52161906423368*^9, 
   3.5216190644894447`*^9}, {3.521619398600267*^9, 3.521619468804517*^9}, 
   3.521620148547615*^9, 3.521621051979941*^9, {3.5216224281131277`*^9, 
   3.521622428250386*^9}, {3.521627860548252*^9, 3.521627957435423*^9}, {
   3.521628442426564*^9, 3.521628444178791*^9}, 3.521628621891692*^9, {
   3.521629252971099*^9, 3.521629253714943*^9}, 3.5216297002545223`*^9, {
   3.521630147331232*^9, 3.5216301483933268`*^9}, {3.5216320719474287`*^9, 
   3.521632287113696*^9}, {3.521633353183998*^9, 3.5216333597114477`*^9}, {
   3.521633784669567*^9, 3.5216337911868668`*^9}, {3.521634076180711*^9, 
   3.521634080729796*^9}, {3.554356812649723*^9, 3.554356830758959*^9}, {
   3.55435707506717*^9, 3.554357076319463*^9}, {3.554444266322143*^9, 
   3.5544442673334208`*^9}, {3.554444320136045*^9, 3.5544443407292433`*^9}, {
   3.5544489106796627`*^9, 3.554448910829714*^9}, 3.554448950924059*^9, {
   3.554505881050054*^9, 3.554505885980554*^9}}],

Cell[BoxData["580.10362`8.914020573420453"], "Output",
 CellChangeTimes->{3.554506478303684*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxd1QtM00cYAPAipGQ6HxEQREHFAgriioh0OOGb8hBnB0pgIMwQnMiYGaQb
CJPxEmIRiC1vsGgLwnROVuqA8P4cMDEyTJAgzgeoAyvylkdRkTnuziy7pGl+
uf//7rvv7rv/huDwg0cXcTicsHe/f/8XmrgE3e6Na8dwXzYumFeCN3R9H48J
p4ixGLN6txvsEMwQBxZjclvMqOlvGmKNAmvq8l3rlbPE2QqMrPBobzF9RcxX
YH5pR3/HBO1vl2PglxbVPpbUoXL0nU6e7G2g4+vI8UGQ6FZaE50fLqBVRWBR
8y4aX/R5nNH4orf3GLGyCHmPPqlau2+QWC3D0ukXx1XXnxKvl2GryNQ16cVf
xH7n0CRWxn0mvE0sKcTP065GuZjXErcVYIWNg/2ky3fEnALcKbl4sNnwotMC
Bfl4clO4o8fuQuKIPAz7KfPn6ewy8vylXJyMKq+796iFuC8Hfx0zs7wS1UVs
lIOVGy/rCLT6iL2yUfS2X3raYIBYnIXPJOpTb4yHaP4zcTB9RGM9TterkaIX
tlasb6D54EtRfXOOtyNvmuZTgvrenTl3a2h+4SyKN5k6Ox+do/nKwA2CgMVa
g5wmkp90dPGrSxDKtIklZ3DS+PBAw2MuMScVXaxCQty6FxNHnMaXQeW9GUXL
iftScPShnbFctZLYKxlbbI35PLtVxJiEW4yOjN4XGRPzE7HpoTK1oXAdMcSj
e3dd/ZJhMxpPLIqXf3GgSmVB549BzxWOUPuxNZ0vEm3G4051Cfl0fBH+fSfy
2PVIOzpeOL7NFFzzMXSg73+N7o8Ls+5t3kmfD0bV/oG2xdnOtN8fjawOJD/V
203tgSHdCR5OXi7UHM7Q1gT1Lm831g8dpQY+MOTO3gePVl9ZxvBeNj5cEa30
LLP3YPND3LYHuZeq97L4IKy6LEEV787iB5mhLHFW6crWB7O/i4IaftzD1g9J
rY9slq39lOUHwn2/+tD2xC6WP5AE+u3Tnhew/MIGXcvSp7PbWf4hYLk1V/sH
W7Y/kGQh7ZJybNj+gf3zJ5xD3E1sf6GyMcaEp97I9h8gy0BRlLKenQ+YDvWf
7Ipbw84PdEpWL4qdoPutzIC+o8+2jtjr0fjOwoR7xy8KsxXEoRJIUX00dV6w
hMYrhfEb3vG163SJNVJQrvaz3t9HzyNmwpQWX34rWItYnAVj5pXcCv15Vj8g
afI2Px78htUXODzvHRH6vGL1B2km0c77JBpWn5BrWRYW0EjrJSIPhr9XZUyd
myQW5MO2w4l4Zm6c1T9IbMT6RaXD7H6AG8LOD/78bIDdH/DN/ZOux/wfsPsF
JgKdeozS/mD3Dzx8E2D3+lA1uS/UMjhRbtkca9NNrCwCz83cpUkJT4ijz0O6
3XDqXI+aGC5A5eriGl7/MLGOHE6rjRyjcIw4VA4xvlX1Qx3jxO1y6E85eODy
uglivgJet125m1tH+7MVcLvf1bOygr6vUQD2XDXX3TJCHFgMdtcGW8Xzz4mx
GG7ODHwbsayfmFcCWl5Ta+qX9RKLS+BtXgSssr7jdESvWZinKkAObZIWXBo9
kvfeLQWl/nj/HHD+2959f/7n9/3/ADP6WQ0=
       "], {{
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{102, 105, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
             14, 15, 16, 17, 18}}], 
            PolygonBox[{{104, 103, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
              32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
             48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 
             64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 
             80, 81, 82, 83, 84, 85, 86}}]}]}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[{PolygonBox[{{102, 103, 20, 19}}], 
            PolygonBox[{{104, 106, 101, 100, 99, 98, 97, 96, 95, 94, 93, 92, 
             91, 90, 89, 88, 87}}]}]}, {}, {}}, {{}, {}, 
         {GrayLevel[0], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 102, 19, 20, 103, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 
           32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48,
            49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
           65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
            82, 83, 84, 85, 86, 104, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
           97, 98, 99, 100, 101}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"(Hot - Cold) / Incidence\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox["\"rel. PT signal\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {-0.0007693349890761277, 
       0.000017284085590879134`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {346.6666666666667, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxl13s8VOkfB3Ar2tjYTRJF28WK0roM02CZr5g0yWVmXAaTXHMtJLlUQiVd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       
       "], {{{}, {}, {}, {}, {}, {}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{203, 19, 20, 206, 205, 121, 120, 204}}], 
            PolygonBox[{{207, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 
             99, 100, 101, 202, 201, 200, 199, 198, 197, 196, 195, 194, 193, 
             192, 191, 190, 189, 188, 208}}]}]}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
             112, 113, 114, 115, 116, 117, 118, 119, 204, 203, 18, 17, 16, 15,
              14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1}}], 
            PolygonBox[{{205, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
             131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 
             144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 
             157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 
             170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 
             183, 184, 185, 186, 187, 208, 207, 86, 85, 84, 83, 82, 81, 80, 
             79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66, 65, 64, 
             63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 
             47, 46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 
             31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 
             206}}]}]}, {}, {}}, {{}, {}, 
         {RGBColor[0, 0, 1], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 203, 19, 20, 206, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 
           32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48,
            49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
           65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
            82, 83, 84, 85, 86, 207, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 
           97, 98, 99, 100, 101}]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], Thickness[Large], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 117, 118, 119, 204, 120, 121, 205, 122, 123, 124, 
           125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 
           138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 
           151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 
           164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 
           177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 208, 188, 
           189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 
           202}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"Hot / Incidence  &  Cold / Incidence\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Hot (dark red) And Cold (blue) Scatter Signals\"", 
          TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {0., 0.004227673335228055}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {1040., -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5545064783644123`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxN1Qk81OkfB/DZ0mEq1RK5ik1yFM1owhCP3MQ4UkzjJldkQrmKck1Yd8m1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       "], {{{}, {}, {}, {}, {}, {}, {}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112,
             113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
            126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 
            139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
            152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
            165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
            178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 
            191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 101, 
            100, 99, 98, 97, 96, 95, 94, 93, 92, 91, 90, 89, 88, 87, 86, 85, 
            84, 83, 82, 81, 80, 79, 78, 77, 76, 75, 74, 73, 72, 71, 70, 69, 
            68, 67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 
            52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 
            36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 
            20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 
            2, 1}}]]}, {}, {}}, {{}, {}, 
         {RGBColor[0, 0, 1], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
            68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
           84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101}]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], Thickness[Large], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 
           127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 
           140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 
           153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 
           166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
           179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 
           192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"(Hot Sca) / Inc  &  (Cold Sca) / Inc\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Hot (dark red) & Cold (blue) Sca-Signals\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {0., 0.004227676746032083}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {349.375, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lglQU0cYx6OoESRSrpiKlEMEOQUiWKLBjxAoCVCBilqleEAtESRWq1LL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       
       "], {{{}, {}, {}, {}, {}, {}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[{PolygonBox[{{48, 10, 9, 123}}], 
            PolygonBox[{{4, 153, 6, 5, 75, 74, 73, 72, 71, 70, 69, 68, 67, 66,
              65, 3}}], 
            PolygonBox[{{11, 159, 49, 150, 149, 148, 147, 146, 145, 144, 143, 
             142, 141, 140, 139, 138, 137, 136, 135, 134, 12}}]}]}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{9, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 
             12, 11, 160, 158, 10}}], 
            PolygonBox[{{50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 
             63, 64, 3, 2, 152, 1}}], 
            PolygonBox[{{5, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 
             88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
             103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
             116, 117, 118, 119, 120, 121, 122, 8, 7, 157, 156, 47, 46, 45, 
             44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34, 33, 32, 31, 30, 29, 
             28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 
             155, 154, 6}}]}]}, {}, {}}, {{}, {}, 
         {RGBColor[0, 0, 1], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[{155, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
           26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42,
            43, 44, 45, 46, 47, 156}], LineBox[{157, 7, 48, 10, 158}], 
          LineBox[{152, 2, 151}], LineBox[{153, 6, 154}], 
          LineBox[{160, 11, 159}]}, 
         {RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], Thickness[Large], 
          Dashing[{Small, Small}], 
          LineBox[{50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64,
            3, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 5, 76, 77, 78, 79, 
           80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96,
            97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
            111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 8, 
           123, 9, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 12, 134, 
           135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 
           148, 149, 150}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"(Hot Ext) / Inc  &  (Cold Ext) / Inc\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox[
         "\"Hot (dark red) & Cold (blue) Ext-Signals\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{{-2500., 2500.}, {-5.5952952488718604`*^-8, 
       5.2993445746012836`*^-8}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {1048.125, -210.90409866090158`}, 
     ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJx1lgk0lesagLchY6XIUCwpSiVDOkoHu89QO6Kk2wm3S8lJpMJJtnIqSTaZ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       "], {{
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[
           PolygonBox[{{101, 220, 221, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
            13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
            29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
            45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 
            61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 
            77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
            93, 94, 95, 96, 97, 98, 99, 100}}]]}, {}, 
         {RGBColor[1, 0, 0], EdgeForm[None], 
          GraphicsGroupBox[{PolygonBox[{{213, 212, 160, 161}}], 
            PolygonBox[{{207, 206, 144, 145, 146}, {211, 210, 154, 155, 
             156}, {209, 208, 149, 150, 151}, {215, 214, 164, 165, 166}}], 
            PolygonBox[{{205, 204, 128, 129, 130, 131, 132, 133, 134, 135}}], 
            PolygonBox[{{217, 216, 176, 177, 178, 179, 180, 181, 182, 183, 
             184, 185}}], 
            PolygonBox[{{203, 218, 102, 103, 104, 105, 106, 107, 108, 109, 
             110, 111, 112, 113, 114, 115, 116}}]}]}, 
         {RGBColor[
           NCache[
            Rational[1, 3], 0.3333333333333333], 
           NCache[
            Rational[1, 3], 0.3333333333333333], 1], EdgeForm[None], 
          GraphicsGroupBox[{
            PolygonBox[{{209, 210, 153, 152}, {207, 208, 148, 147}, {213, 214,
              163, 162}}], PolygonBox[{{211, 212, 159, 158, 157}}], 
            PolygonBox[{{205, 206, 143, 142, 141, 140, 139, 138, 137, 136}}], 
            PolygonBox[{{215, 216, 175, 174, 173, 172, 171, 170, 169, 168, 
             167}}], PolygonBox[{{203, 204, 127, 126, 125, 124, 123, 122, 121,
              120, 119, 118, 117}}], 
            PolygonBox[{{217, 219, 202, 201, 200, 199, 198, 197, 196, 195, 
             194, 193, 192, 191, 190, 189, 188, 187, 
             186}}]}]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
         {GrayLevel[0], Thickness[Large], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
            68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
           84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101}]}, 
         {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[{102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
            114, 115, 116, 203, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
           126, 127, 204, 128, 129, 130, 131, 132, 133, 134, 135, 205, 136, 
           137, 138, 139, 140, 141, 142, 143, 206, 144, 145, 146, 207, 147, 
           148, 208, 149, 150, 151, 209, 152, 153, 210, 154, 155, 156, 211, 
           157, 158, 159, 212, 160, 161, 213, 162, 163, 214, 164, 165, 166, 
           215, 167, 168, 169, 170, 171, 172, 173, 174, 175, 216, 176, 177, 
           178, 179, 180, 181, 182, 183, 184, 185, 217, 186, 187, 188, 189, 
           190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 
           202}]}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{{
         FormBox[
         "\"(H(sca)-C(sca))/Inc & (H(ext)-C(ext))/Inc\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(z\\), \\(p\\)]\\) [nm]\"", 
          TraditionalForm], 
         FormBox["\"rel. PT signal contributions\"", TraditionalForm]}},
      ImageSize->650,
      LabelStyle->{Larger},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {1746.875, -210.90409866090158`},
      ImageScaled[{0.5, 0.5}], {650, 401.7220926874316}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.554506478437338*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "2D-Plots etc., i.e. Off Axis Scattering (Exact) Images \n",
 StyleBox["compare to Fig. 4 in \"Gaussian beam photothermal single particle \
microscopy\", JOSA A, Vol. 29, No. 10, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", M. Selmke, M. Braun, F. Cichos\nTheory: \"Photothermal Single \
Particle Microscopy: Detection of a Nanolens\", ACS Nano, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1) ",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.497801502032988*^9, 3.4978015095969553`*^9}, {
  3.554280763949314*^9, 3.554280765315752*^9}, {3.555064244491436*^9, 
  3.555064247379012*^9}, {3.557548317351314*^9, 3.557548325175962*^9}, {
  3.557682939113736*^9, 3.557682965447774*^9}, {3.557739678174349*^9, 
  3.557739834924305*^9}, {3.592717128587262*^9, 3.592717131090042*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Specify scatterer with scattering coefficients Lists anL and bnL (",
 StyleBox["necessary",
  FontSlant->"Italic"],
 ") for Image-computation and analytic angular integrals"
}], "Subtitle",
 CellChangeTimes->{{3.557682998459181*^9, 3.557683009744028*^9}, {
  3.557683090414619*^9, 3.557683090731511*^9}, {3.557739859054739*^9, 
  3.557739883658963*^9}, {3.597410826653722*^9, 3.59741083704416*^9}, {
  3.598291648095271*^9, 3.5982916595281153`*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Sz", ",", "I12", ",", "I1T", ",", "I2T"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]max", "=", 
   RowBox[{"2", "\[Theta]div"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"anL", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"aMie", "[", 
       RowBox[{"n", ",", 
        RowBox[{"k", " ", "R"}], ",", 
        RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   SubscriptBox["a", "n"], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bnL", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"bMie", "[", 
       RowBox[{"n", ",", 
        RowBox[{"k", " ", "R"}], ",", 
        RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   SubscriptBox["b", "n"], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Integrals\[Theta]", "=", 
    RowBox[{"Integrals\[Theta]f", "[", "\[Theta]max", "]"}]}], ";", 
   RowBox[{"I1T", "=", 
    RowBox[{
    "Integrals\[Theta]", "\[LeftDoubleBracket]", "1", 
     "\[RightDoubleBracket]"}]}], ";", 
   RowBox[{"I2T", "=", 
    RowBox[{
    "Integrals\[Theta]", "\[LeftDoubleBracket]", "2", 
     "\[RightDoubleBracket]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"precomputed", " ", "Angular", " ", "integrals"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Sz", "=", 
    RowBox[{"SignalExact", "[", 
     RowBox[{
     "zR", ",", "\[Theta]max", ",", "s", ",", "w0", ",", "anL", ",", "bnL"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"For", " ", "normalization", " ", "use", " ", "on"}], "-", 
    "axis"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Inc", "=", 
     RowBox[{"Sz", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
    ",", 
    RowBox[{
     RowBox[{"Sz", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "/", "Inc"}]}], "}"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"anL\[Alpha]", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"I", " ", "\[Alpha]", " ", 
       RowBox[{
        SuperscriptBox["k", "3"], "/", 
        RowBox[{"(", 
         RowBox[{"6", "\[Pi]"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{
          RowBox[{"Length", "[", "anL", "]"}], "-", "1"}]}], "}"}]}], "]"}]}],
     "]"}]}], ";", 
  RowBox[{"bnL\[Alpha]", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "anL", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Sx", "=", 
    RowBox[{"ScatterOAE", "[", 
     RowBox[{"0", ",", "0", ",", 
      RowBox[{"1", "/", "2"}], ",", "s", ",", "anL\[Alpha]", ",", 
      "bnL\[Alpha]"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"Sx", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], "/",
     "Inc"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.557208723428822*^9, 3.557208724338902*^9}, 
   3.557209168664034*^9, 3.557217980724646*^9, {3.592717147837307*^9, 
   3.5927171492689123`*^9}, {3.598291628290926*^9, 3.5982916310637693`*^9}, {
   3.598291810167444*^9, 3.598291837098282*^9}, {3.5983471265815487`*^9, 
   3.5983471279725237`*^9}, {3.598348662355619*^9, 3.598348664764062*^9}, {
   3.598349732239173*^9, 3.598349734253975*^9}, 3.598350761818684*^9, {
   3.598680078354909*^9, 3.5986800828046637`*^9}, {3.5987285446190147`*^9, 
   3.598728549769288*^9}, {3.598775214258534*^9, 3.598775218782*^9}, {
   3.5987786396176167`*^9, 3.598778650713168*^9}, {3.598807772479103*^9, 
   3.598807831076926*^9}, {3.598810057367909*^9, 3.598810061028668*^9}, {
   3.598810171167626*^9, 3.598810207327183*^9}, 3.598810257470955*^9, {
   3.598855465783135*^9, 3.598855467463873*^9}, {3.59893819740622*^9, 
   3.5989381983433657`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"421576.6246910345`", ",", 
   RowBox[{"-", "0.0007285086695516288`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.598294351474666*^9, 3.5983471293777857`*^9, 3.598348667683465*^9, 
   3.598349735540813*^9, 3.598350763225024*^9, {3.598680062204278*^9, 
   3.598680084091735*^9}, 3.598681124535471*^9, 3.598681972122443*^9, 
   3.598698896542203*^9, 3.598698966267206*^9, 3.5987284871803083`*^9, 
   3.598728551691936*^9, 3.598775221320168*^9, {3.598778641870882*^9, 
   3.598778653048904*^9}, 3.598781667895771*^9, {3.598810052438031*^9, 
   3.598810062224946*^9}, 3.5988101784701242`*^9, 3.5988102085520077`*^9, 
   3.598810258810566*^9, 3.598846821189373*^9, 3.598855469053743*^9, 
   3.598879408977553*^9, 3.5988794623159647`*^9, {3.598938194938395*^9, 
   3.598938199611339*^9}, 3.601470127276885*^9, 3.601479590960966*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "165.47802957487107`", ",", "49.2947276310962`", ",", 
     "116.18330194377486`", ",", "12.236971369337814`", ",", 
     "190.90900256925687`", ",", 
     RowBox[{"-", "178.67203119991905`"}]}], "}"}], ",", 
   RowBox[{"-", "0.00042381863873706087`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.598294351474666*^9, 3.5983471293777857`*^9, 3.598348667683465*^9, 
   3.598349735540813*^9, 3.598350763225024*^9, {3.598680062204278*^9, 
   3.598680084091735*^9}, 3.598681124535471*^9, 3.598681972122443*^9, 
   3.598698896542203*^9, 3.598698966267206*^9, 3.5987284871803083`*^9, 
   3.598728551691936*^9, 3.598775221320168*^9, {3.598778641870882*^9, 
   3.598778653048904*^9}, 3.598781667895771*^9, {3.598810052438031*^9, 
   3.598810062224946*^9}, 3.5988101784701242`*^9, 3.5988102085520077`*^9, 
   3.598810258810566*^9, 3.598846821189373*^9, 3.598855469053743*^9, 
   3.598879408977553*^9, 3.5988794623159647`*^9, {3.598938194938395*^9, 
   3.598938199611339*^9}, 3.601470127276885*^9, 3.6014795912813387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Check some axial scan (",
 StyleBox["optional",
  FontSlant->"Italic"],
 ")"
}], "Subtitle",
 CellChangeTimes->{{3.557682998459181*^9, 3.557683041758239*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"T1SignalE", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"ScatterOAE", "[", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"z0", "/", "l"}], ",", "s", ",", "anL", ",", "bnL"}], 
          "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "4000"}], ",", "4000", ",", "150"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"T1SignalE", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T1SignalR", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"ScatterOARayleigh", "[", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Alpha]a1"}], "]"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "4000"}], ",", "4000", ",", "150"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"T1SignalR", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"T1Signalz", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"SignalRayleigh", "[", 
          RowBox[{"z0", ",", 
           RowBox[{"{", "\[Theta]max", "}"}], ",", "zR", ",", "w0", ",", 
           "\[Alpha]a1"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "/", "Inc"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "4000"}], ",", "4000", ",", "150"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"T1Signalz", ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"P0", ",", "P1", ",", "P2"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.598290939525159*^9, 3.598290962210897*^9}, {
  3.598291066390685*^9, 3.5982911265710897`*^9}, {3.5982911704240026`*^9, 
  3.598291170966785*^9}, {3.5982912233401613`*^9, 3.59829123202283*^9}, {
  3.598291408220356*^9, 3.5982914097640867`*^9}, {3.598291496229357*^9, 
  3.598291498160569*^9}, {3.598291705055423*^9, 3.598291778012333*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQYO6w/0bJ35/oidz34wX2TdgSVPOPRX6vlD+C/W
HDhv/ySoNDMAwt+z+kBsbKNPaR2UP2HVgY5f3+aWTYKqT1l5IGHr7ItGE6Hm
Waw4ENsjuC9M3gPC51l+QFN/pq7NPCcI/8HSAwyTJ/iYxVhC+FuWHDDvNaje
0KsD4XcsPtCw423h9A/iEH7MogOXKy85LExkg/ANFh74cX7t5ylCshA+y4ID
odn9WXL8ZhD+hrkH9qYvdIl8BrU/YvYB47Kbt1ZYhUP4DDMPrNO8nViomwzh
r5h2YBLXNoHPwrkQfsCUA9udjJRfrS6B8H9MPJD/s03p9JNqCN+h/4DYI+Um
5Z+N0PDoOnBfyGbyQ/U2qP9aD7xWeLicjbsL6t7GA/9t2u7ef9cDtb/yQKdF
q7j+816oefkHNivUCn0QhclHHjit4M64zrUdyvd0uPOrY4ltSQOUn+mw/tXP
qHvixVD7Sh0eP1+u/VIlEWpevcMpqdr9tz+4Qv3T4lC4c4mb0DsDqP5OB9mf
Id8q+Byh4dXrcCHzaFlnehDUvRMdcqa/4227FAuNj8kOtlMepenKpkDtm+rA
IX84VlYmAxrfMxyk6rXFGGZmQcNjlsOZnvtzjLuyoelpjkP828Kr3wWgfIf5
DosbFVnjMjIh/DMLHIqP+XVr3UyDhvdCh9STpjnvNkDjR2Wxw9FF+YLF1glQ
/yxxOLv8jdi06kgIv2apw5Hd/ps3PYG6f8Uyh7M37j/MlfaC8K8sd/g8LfK8
T6ED1P8rHdwLXQLX6htB+DqrHKobRZjeVClA08tqByOdTEUtFmh6a1njcLn0
mj7r3U/7IOG11iH39+IHu39C5e+sczhVq1NhnyOzHwDVwzDh
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., -0.0146011046460013},
      Method->{},
      PlotRangeClipping->True], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwt0ntIk1EUAPClU4gmaHMwK5tFEZp/TGbDEuU456s0hzmZMEnNabNMjGbW
ypxZPkp8pfiYNJvzNTeVUouiXbAiUmOWSjMrNQvFLMlMocjKey58XH7c+93D
eexKzoxR2DEYDOG/7/++saCLpN0/WvUpJtKyYVczeRobtVsUFU0910lqn0u4
F9US6kdGIsy39THL0eUdxHrGJVdowvsp7WQs2Lte3IDv+bWR9KwRDss5nJrV
Sord+S7yDBH1lIF8DJezBtr9qO81k1Spl/KFyou6SE98c0Nm30q2UsvvkKDL
QVmKiaXHG+Y3Ead3c7Gb11zpOVNHAs8L2r6/EVB3N5L6XzLTzJMwalkDGVJV
Tk/0xFEz6sioX0Bl1XIydVsNSWGKteMLp6klt8hex5EfCc3nqNcqyOyK/8vF
L2pqKCPbg82sLY75WI8SwnEvW1EHXMf8rhEvO2l59L4Sar6GsGVCG9epFONf
IJWcmoWkdTRkEl5ED2fE/Saex5M+U2LmlKAQHQE16wFzLiF5aCWcTPD3/Fl4
FuOpYNH2yoNXdxzfuwIwbsg5oATMpwDmx6SfmWPb8P9i0PFklknFQaxXKfRr
9TlaI/aXXwFTohCppkiO/aiCDvMx8arxBMarBlWJgfd6PA37XQs7NFftW7PT
sR71EKQL1Vs0p3CetKD4vba07IaG2/A+tMVHqlZSD+kgkauzzX5LxXo3gXNv
t6H0Gcbbo4e7XTxldmQi5tMMbF+d4E9ZPPUlA9h/EHlkzMdgP1ug/0Gfp8Lh
MPVoK+QdiuqdDsR6MNohLjfpBrfRh9q7A2asg+Tr/p04L0ZwsIaprMPrdN4K
OkEnHK5mDdqou00wkDIkXmVvovcnzfCQ7VNwZNjN8hf+uDCK
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., -0.014647259714147851`},
      Method->{},
      PlotRangeClipping->True], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQYO6w94/8wMa4vy2Q/mi6w7IMi6I+ZQuj+E/2LN
gcVhoQfXzQiA8PesPmCzhWmd0U4of8KqA8Ydve88mKD8lJUHupnNpjW/hJpn
seLA/f6pgtlBHhA+z/IDMvvsbhcudYLwHyw94FIu3b2dwRLC37LkwKcXH4L+
39eC8DsWH/j6z/+Lw2IhCD9m0YF7/7kWqht/3AfmGyw8cMLc51FypihEnmXB
AYX6vux/gSYQ/oa5BxZGOR7TzIbaHzH7wBmeHX7dmeEQPsPMA5z6D++uXpYM
4a+YdsB1hSifnl4ehB8w5YA+u7Hvjm2lEP6PiQf2eF+af3JNLYTv0H8g5sTO
FXzpzdDw6DrA9Ofi5LzwDqj/Wg8cC1906KZVL4Rv0HjgF7decfPyCVD7Kw84
q8QyLN08EWpe/oFNYdf4nQWgfIbIA+ymlw6Jb++B8j0dspRtwpcatUD5mQ51
4ZuWHFldBrWv1OHVV4OCzVeSoObVO1TOYXQIYHCG+qfFQbhJ9pC7txxUf6eD
av1R5lX/rKHh1evQc/VO/QquIKh7JzosivF4oF8UB42PyQ66k34ETTqUArVv
qkNoBKf1ow8Z0Pie4fCqTyLBpT4bGh6zHI7bnuJZn5MDTU9zHDqdFBOnP4TK
O8x3WOIb2b5ULgvCP7PA4R6D2aczBenQ8F7ooCHrJrFNA2qfymKHtmV6PNFT
EqD+WeKgouve2/klEsKvWepwc2dWlZNOMDQ+lzk8UTyUYBrlBeFfWe5w2GjF
/Jf5DlD/r3SQDb7/b8cRQwhfZ5XDtNSZ1ZeVoeETsdoh8mKIl5nJf0h6a1nj
YD+544i89H0If8Nah4g/fL9dZZgh6u+sc9C4taxQjl96PwCJYClj
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., -0.01728685202332182},
      Method->{},
      PlotRangeClipping->True], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.598290990355563*^9, 3.5982914404140987`*^9, 
  3.5982915277954187`*^9, 3.59829441835858*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "off-axis scan, i.e. image computation (",
 StyleBox["necessary",
  FontSlant->"Italic"],
 ") \n",
 Cell[BoxData[
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaPoynting/scatterimageGreen.dat\>\"", ",", "OAScatterIm", ",", 
    "\"\<Table\>\""}], "]"}]], "Input",
  CellChangeTimes->{
   3.557417777054468*^9, {3.557417881936799*^9, 3.557417891239431*^9}, {
    3.557589152849036*^9, 3.557589184606813*^9}},
  FontSize->10]
}], "Subtitle",
 CellChangeTimes->{{3.557682998459181*^9, 3.557683071493058*^9}, {
  3.557739838036642*^9, 3.5577398455013742`*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OAScatterImXP", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z0", ",", "x0", ",", 
           RowBox[{"ScatterOAE", "[", 
            RowBox[{
             RowBox[{"x0", "/", "w0"}], ",", "0", ",", 
             RowBox[{"z0", "/", "l"}], ",", "s", ",", "anL", ",", "bnL"}], 
            "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x0", ",", "0", ",", "650", ",", "25"}], "}"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"z0", ",", 
         RowBox[{"-", "4500"}], ",", "4500", ",", "100"}], "}"}]}], "]"}], 
     ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GZ", "=", 
    RowBox[{"Select", "[", 
     RowBox[{"OAScatterImXP", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ">", "0"}], "&"}]}], "]"}]}], ";", 
   RowBox[{"GZT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"GZ", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{"GZ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"GZ", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "GZ", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Mirror", " ", "x"}], "-", "axis"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OAScatterIm", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"OAScatterImXP", ",", "GZT"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OASignal", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAAbs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAis", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5573981170909758`*^9, 3.5573981330180693`*^9}, {
   3.557398163205042*^9, 3.55739824516151*^9}, 3.5573983240682793`*^9, {
   3.557486307536496*^9, 3.557486374276497*^9}, {3.557547571080194*^9, 
   3.5575476165603027`*^9}, {3.557590214826551*^9, 3.557590215520485*^9}, {
   3.557739605798458*^9, 3.55773962377363*^9}, {3.592659733407498*^9, 
   3.592659762095498*^9}, {3.592659993434525*^9, 3.592660004469644*^9}, {
   3.592662249946953*^9, 3.592662257387151*^9}, {3.592890076894423*^9, 
   3.592890077183715*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SignalP", "=", 
   RowBox[{"ListDensityPlot", "[", 
    RowBox[{"OASignal", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Blend", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Yellow", ",", "Orange", ",", "Red", ",", "Black"}], "}"}],
           ",", "#"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<x[nm]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z[nm]\>\"", ",", 
          "\"\<R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, Signal, \
nmax=15\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CabsCP", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"OAAbs", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"White", ",", 
         RowBox[{"Opacity", "[", "0.3", "]"}]}], "}"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PRed", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"SignalP", ",", "CabsCP"}], "]"}]}]}], "Input"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1ncuu/dpZ5ZeqV91qzeauN1hN3EvXvYgWbiFZihRLkQwWFnFk5BiMBBIS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    "], {
     {GrayLevel[0.8], EdgeForm[None], 
      GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxMnQfczmUXx+89HkoIyV4pO1nZZWYnIYQoOyM7O6FCRkZKRoTskb2zVxTJ
JkpCVkb2e/3e870/9/1+Pufzv65zfudc13Wu7//2PPE+T7YWnep29Hnc/3J4
PH73qOKsqrO8HptndRZwlsJZPmdPOcvirJSz0oyVnxnT2EteNnKzOwsyz+ks
4izMPIgmxDg74+y2pf+Pc6DPQX6YvflY389Ta+aivnRRxvIld/aCsyec5XaW
zFmSs+eYa/w8/tzonydHlofcZ5wVdZYe35P41YuGzt5i3VzUjvJMoqdPkpeC
cV7GeelvFvpYij0kYx/56b00LzlL66yws1TOCjgryB7K0IeU6JVXll6XYV6A
eHZi5aijGqmdFXL2orOn0WRDV4h4QXLKcyfZmecgJ1ajDLlZWTMV677C/ZTH
cpKrnr1Kv3Lhf4XxK8TScO60zCugT4fvJXpYmnU1L0L8GcZFOV8a9puGuepW
9Nj9V8ByU78I+em4D+kqOVvu7EtnP+DPTew9Z6957F0q7iyDs2ed1aQ3NdCr
hvgqhu5ZLD2+DPhLeIwbvZ9iJZOzjM5exvcua2VAG4tlZK695ENTlXFeclW3
MpaH/Si3JOuI6e7Oejir5qw696lx/oTarzGXvpHH7r8APmkbe4yjRpy7Mms1
wi99OcbSFnQvTzVnBaJ2n3onGrJ+QU+c++r0sxx5TfDXoNfF6GdRYm97jLsW
zlqyD7HU1Fkz6jRBo/uq5TE+lPcK/qaM3yb3FXx1PMZcbWfveIyF5h5jqzax
ZvgqkNuMcRHidbDX8dUiP8ZoLWo1p34FtEXRF+fMb+Cry7wS+neIFSNWiV5U
xl+PGi/SP/VAfFWhXxoP8hjjRVk7VuedhL5WoabqlfDEOdb8TY8xVoKx7lfc
lKG+aovTz5wNd9bRY3y18hhLfZ31owetiClHjI519oWzBh5juL6z1uS1Yh3p
xF0bj3FSHV9P/NXRt8ba4OvlMcZ6Yo3Ri9VCzqpHrb447U5t5bb1GFPK7+2s
j8d4+ZC5nmKpHf2O6Xsn+Ntz9x+SK//HzoawhuK1PXE+OniMoybssxf7acsa
tcmRrhl76su4KfP3qdGBujXZSzO06n9Xel2fuxcD/T3GRR1q9Mffj7usS7wf
/ub4OnmMwQHOBnqMIz3fZdyZeCfWGoC/Hv7OWBd8g8gdSP2OCbn9yZf2TU+c
S80/cNaNc3WlzkceY0zPVozro5VmMH7Fxd8iZ4s5f0fOWwNOXoyaZpzHOFL9
KeTWZx+qKybF0Vhqa43W3Htr5j1Yrye5Yl7vVpsE7cvUVHwYdziU80+mP+Ko
LXnibryzCfiGoNd8oscYbE8d1RMfnzj7lNwJaIbhl1Z/TvYhfyLjD4l3QKPc
XqzdljW1Rl/yJzHuw/wr7rEf/kmMJxGL8aY70GfJ1+gV0+dKJ+LjWLcnPsVG
OBvpMZ5GsMdPE2q9z3wAdScz7s+8E3mdiX1Dn8ezltbsQlzrLCEm/1Tu9iNi
n6NVjUHU+QD/KJ4foJlCvnJHe4xj8SlGxNEi5qOIT2Mt5YxBL7/Y3etsn7PC
jteacKv6a9F3Zd1R1FAt8Tad5zTu8FtnM/BrPASLaZdy9iXEhxKfQGwZ5xpE
DyagX8pY8YnseQk9/IL5OOppffE4k+cM8n4g95OEeGX3zUVLZ1V8Nv+OeDr3
zU0RZ884W+HmKz3G0nrOus5jTEg/y2McitPljPVcwXgFubOdzfEYc+JklbPV
zD8jLt/XrLeS8VfkjfDEedX8e/YwKyH/M+aTyV2FXlrxNc8T5+hzfHPRr6bn
c9Epvob7+IY8+ec7O0Rt7VGMHKEno4kvoM5I1l5NrW/QjEK3jn5Opc46xsof
g3Yte1D+QvyK/8hZdQdiSXxt8BjHfzu76DEu9B7sJTY94Q7XJ+RspMZPHmNN
bImbTR7jYj/+n9DO8MRZ34huGboDjJcy30feEvazj/Fmam8i52ePMSpefnF2
kOdyYps583fMl6OfhX8LucvJ07v8krNaUdMoHmNQz63s8wB1vmM/m4nNJucg
972S+gcZS7ONesoVi3p3fvUYG8q56TE2fvMYA4e5xxOceyP+X4mJle0eY2c1
dRSbh28H9dZSUxyIo13EdqL9Dc0afPM9cXZ3oledW86OkjuXtQ+Tv4aYOFmH
/ihj+Y55jJ09HuNyN7716MRfyH1+hL1252JQXB4n7xjn3ca60l/yGCuXPcbO
Jc64i/q7WUu+feTEmNxA7eP0dyP5+9FsY7059F6ak6x91tk5Z6ecnfYYTwfY
xz/opd3M/IrHGDyFT7GrHuPuCjW2UOd3j7Fyhtgv5G5BJ/9B8q954txfRXOG
/AOs/TN1N7O+cq57jLeDzA9xj2LnBvFf8d9gfJ1zb6c3h4n9i0/92MG6++nF
H/jOMf7TYzxtY4+/Y2fxqZbegd+o/y/jndRRDTF4BJ3eQ/05MpHau9A+dPas
4+iRe97xGDu36c0D4rvRn6em4kd5HmN8wWO8/uWsiPtcKOqsTtQ4EqeXeOZw
ltNrfjErjo+xtvj6j+cd9BFyd7P+X9gefCcS8mR38d3nDu95jKG7jO8yP8Gd
R139JK/57pGjeTKvMaV9PO212v8Qk19xcXSFGrrDCPvVWHs+Tb372AN8yclV
jQf0+jT1L1PvGronnKVyVtBZamcpvMbSk2iuonsEH7ov+ZV3neeTjJ/0xpkV
Z4+d6T+2PuUspdc4eUzsLEylIK7xDebnyBNjXp6an2UPj7DHCXWeov6fnnie
znMHjnxeu1/FtRdxdpM7V8zvtXvX3E9PlB9j9SFr/0U8AGflnb3itfVUR/VT
UT8lugvkPc1+VDeIX3F9T96K/5Z0i/zb8BmC6V3sXftL642zpnPnc5afz+uc
MJLGa7q76MRXGvLkTweXYuE5OBFDz+CXLzd6aWOx+8wVex6Ok5gnI081c2FR
9qPc9KzzgteYUn4eZ3lhSCy9gE/9lv5Z/MmJZYDFmD8PuTlZT2s9hg9pM3qN
Hfmep04y9vKQdyamkyYf70BeLAX1PWgy0dv/uM+n0OSDg1fZRwEYSkluJhjJ
TywlvMiXmTr58WeBR8X1XtZwVshZNrgJEJcua8I8KzrtKzW5hRgHiGdjvSwJ
9VOxpxfJVU521soGRzpzYeIvMlfPxWZ5YmmI5aQXufC/RI3MnFe9qOA1VtSv
3Mwrkve2s6bOirn3obizulHTPUdN1UvnjXOseRHqPEct/R1FAd6pol7jT5qf
nF10dslrDBVzVpxzqj9lYEN65VX2GneVmBcjnodYFeqohjgq4exlr7GSh9zK
+DOgU05Vr/GVh3lecmI1KpH7PGs+y7qveY21qlg+csVONe4xP/7XGL9GTH0v
yT1oXh19FnylnL3r7D1qa17aG+esNP15mVqx9+Fl6orTgtStzrgAeVmpI01b
ZzWpn5lczcVOITh4hx6Ih/IwUQOdNGW9xqjurRxj+WpRJ1ZPczEonpp5jSM9
KzCuTbwWazXF/xL+2lgdfM3JbYb2Q2d9vPbfHtpE7b+fSVvEG+dS89ed1XX2
BvepcVH8RXgW5dwtOHsxfNK29BpHLThzGc7bAr/0VRi3pIfNqVeRPTdn/eLe
OPea1yO3JfdfHJ843OpsjrPZzt7Ep9jHzoY4a+M1llo5a01P+tAf6et7jQ8x
JQ6ron0NXzXG8jX0GhMNvMZIDeqXxFeKNeSrTm5rxqWJN8Tewlef/Bij9anV
hvrV0ZZB3x4W2mEa16TX0jRib+3wN/Yaf4o3YdyY9UrQA/VjorMvnXXwGk/t
qfdWQs2h1K0OR62j1k+x/yF7aU++avalz1W4N/W2DvEOnFXrf+A1vjp6jSXF
3kerGs2p8zr+jjxfR9OJPPnFU3+vcdcZFt7ANwD/G+g7YZ3xDfQaYwOwluhV
sx813mE//ait3C6cT/mDnA32Gi8fMdfzPc75ZoJ+UIK/K/34iNz3WKM5PVC8
gTfORzevcfQu+xzIfrqwRgNypGvNnj5m3Ip5d2pIU5Z7boxGWjG42tk3ziYT
k6Yn51bvRniNC/Gh960HmreYt6XOMK+x0Y46qtHLWQnH0MvO6kWtzjA0ijVB
+wm5ivXGr7h4/cHZctbsQV3VmYFeHIrNidRQLfH1mTfO0fv4PkX/JT3/FJ3i
k7iPvuTJP9zZd9Sc6TU+vnL2NaaeDaBOB3RfUqsv+n7kdKRerKedmPen1gB0
/ciXZiT3MNbZF5x/lNd4+px7G8g+pO2CfhCxKfhGotd8qtcY7Eod1RMfo52N
IXcKmlH4pZ3mNaamYoPRjCa/K7kDWbsLa2qNj8mfzngw82+5yyH4pzOeTizG
W3d6MAP9t/SjJ/HJrDsAn2Lj0OvehrHHMQm1ujOXZhO6XuSPY/4Jub3wjSdP
a77FvDdxzRsSFwPLucf5zhbQpxr8/YD+rFZtsfUpevEr1j/DN8vZSq8xscJr
jHyFT7HZaFfgn4RvuDfOruZzyFXeKnI/Ze3l5E9CL624+57nHO5wrrN5+DUe
icW0a7jz1cQ/Jz6F2FrW+tnZL/i/ITaF+FT2t5r7/Jr5ZOpp/VH0cxRz5a0j
d3RCfAL3ovtZ7zXW1rH2FWdXnW1wttFrLK1DozpjuK+FXuNwGjWm89zAeAO5
i5wt9hpz4uiks83MxxKXfwbrbWT8LXnjvHFeNV/CHhYm5I9lPh7dEtbQHc6k
tz/Q3x/xK76UXihvGWP5Sjr+SjmrHzWtcmZx7jH0cgu+Hxnr67DZnGUz645n
L0vp7UGv8bSc+QpyZlHjkNc4lE7fK+nrwueZr0QvXyX8Ykl8baevWvuE17hY
Sb3taLZ5jddtCTk7qHHYa6yJLXGz02uc/Ib/MNp53jjrO9CtRXeE8Rrmv5K3
mv38yngXtXeSc9RrfImXY86O81xPTPrd9P4o/nXct/x7yF1Pnur+4exPNIrH
GNRzL/s8Qp0F7GcXsUXkHKeXG6l/nLE0+6i3mzUWoN2ERme97uyGs/1eY2sp
eUvI1X3dc3YKE0cxJqXR98Gn8SuudzKZz+NJ7rPxNa9xcYD6Wkd/H1PbWbuo
8SXer1BDtcTYGZ6n2cOphHV/os4vrKf6WxPyxM5Zr7HzO/Ot7OUQ+m3EztKH
Q/TiHHlnOd8+1lOP/vUaKze9xs6/rPc79a9T5xo1b3jjTG6n9jnufQf5v6FZ
Re6vxHeiueAs4HoZdHbejf/iPvXfrNvTR2n/hI1bzm57jcHz+BS74zXublNj
D3X+9horF4gdI3cPOvmPk/+fN879HTQXyD/C2kepu4v1lXPXa9wdZ36C+1Nf
LxE/if8eY/kuotmHP53rwX2v2WmYOEIPb6K5j/8frzF3mfy9nPVv6u5jD5fQ
XEYv3wPqq5Y4ft7ZCz5b6ybnFHdiVqzfwp/SjZ/wGQfXqPEARpITuwYv8j2k
TnL8j7zG3e+w86Tzp/DZWM9/iUv3GM11dGfxiS/9g+FzzJX3FLkPyf2dHOVq
T38k5Mm8+Pww5/MZQ/L7iGv+B73QuVPh85GjeWqfMfWQ8z5Anwq/4nfgTjXU
w6fYr8b/wuB59iLTuyDf0+SmxncBrf7s0Lu4DdakS+PsNWfVnOX3GUdiJS39
VS/yOgv5jA+9a8pV3l2eaRmnJfcu7ITdPOIzfvSM+sx3Cc60VhFnz6C5hE7z
BzCWjvl9crSHEPtRLflU9x84TU/uM3zOvgBbGieD15f4bNBn7QNydA/S5kH/
iLt5ln1rX7l8Ns/gi3OmcUZnSewhypqVfPbvR/LSwzzYk9RX3mOYS4EuH/Uf
sifFM8Kd+p6dc2dOYC0T8YzcVz4YyYTOi3nw+fBngUuxVQBOxFBW/PIVRJ8l
IeZnrlghOE7FPDV5KWEpP+OnyM3GOi/6jD3lF9Z9wFAaYoU5bzbOnAa9Yjno
QcxfmNx8rPcUXITQ5uTuwqz3NPvMxhqBBJ004jEde3qJcVpq5ISBC7wHYlH6
150V9dl7cYf3qqz+DaizMlHrV2l6EKXGc86K+eyeizJP8sX5EadiqDhMSFvV
Z5xUIa8Yscr48pBbmXEG4sWxEvhys9ZzaFv44v/OKS+50mZEL17ETkl8LzPP
h74qsUzE5H+N+5C/FDWKcFa9m9V9xoo+dwoyr0H9Egl1qvrin08FqKl6WXxx
jkvR34JoqrNOetYqQ+9Lc1d1iYuhss7KsXZNnzGSDb3yavmMu5rMyxIvTKw2
dVRDHJV39orPWClMbi38OdApp47P+CrM/CVyYjVqkluINbOz7uv0sQ5WhNwK
3OtzmBh7FX1Hziwr5ovz9ip5b+CvSw9rsG5FalYgLl1xzpfLF38fXqGWGBrg
bKDP/vtqa/7OVYyJZXFWjxqq1SbgNM4+Dljuuz5jsIebf+GsZ8DuXgy85+xt
etOEeVVy3vQZLyWYV6WOfPV9xmArZ619xlFrGNG4AXHpXkMnfyn8DbCG+NqQ
25r6bybkvke+tKV9cS41f8tZI2eNuU+Ny+AvzVPzts7acf9l8Unb3mcctaOe
9tSNeS30tRm35w7bUK8Ge27D+uV8ce4b08/a5HXA34Re16BGTWLv+4y7Ls4+
4Pzia7izTtTpgEb31RQ+lPc6/o6M5RNbYqcZftUQh2JosrNv8L2BvwLa5lhF
fJ3RSPsO/uas/6ovzmhT8hs7Lss5Kx819sSm2B3EPYqjluzjXZ6DfHHe6tGD
j9APoh/1ib9C/97Gp1hX7qwB4zfYd6xWPeatqDuY8XvM65PXgNjHPuOwqf7u
1lmFqOkH4+/lrKezcT7jq4fPWFJf+jrrR4026KXpjq4784bUaIRfLAz1GXeq
L04a4xuGvzH6nlgvfJ/4jLFhWHv0qjmEGm3ZzxBqK7e3z5hS/qc+Y02sfMZc
T7H0If2O6T9N8Pfh7j8j933WaEMP+sCFNCO4h07Uac/aTaj9Nto+9FH7mUNe
c2Ix/wjqdKOnDen7O2i/ZR/Tfcb6FJ+xNJI9jMC/2tkan3EoTvVu6O/s33DW
MWr+b8j93NkonzEnFqY6m8a8C3H5PmK9KYwHkdfVF+dV89HsZWRCfhfmg8md
in40Zx3ri3PUHd8Y9NPo+Rh03Tn/EPw98H/hrD+9Us+G0q8Z2EyfcTSG+qOp
PZ06Q6n5LTVVL/Y+9GQ+lFrDuHvd7YdoxvuMvwXOdjnb7Wwi8QnO1nHutWh7
oxd33zmbhW88es1n+4zBPtRRPbHypbNJ5M5CMxG/tOJrOPmzGX9GvC8a5X7C
2r1Z80Nytzn7nj72Za1XHDdN+Az8il73wxSXby73rFzxd9jZbz5jTQyuprbW
2IpWOTEG9ZxHvmIj0H7PeB6audRXL6dQfw1jaeZT72v2+RXaqWg2c+6ZMLAe
DpQ3mtxp3Nl6fLrXMfinEhuLb6GzjT5jZ4PPGPkWn2KL0G7APx3fF744u5ov
Jld5m8gdw9rryZ+OXlpxt4TnYu5wqbNl+DUej8W0P3L2zcQnEJ9FbAvnnc+6
s9D/yFjx2exvMz2cwXwm9bS+ePyB5zLytpL7ZUJcOeJwGPPlxL/DP5P7W+Fs
pbPj9Ee9mIR+BZpJjMXYWWfbyfma+CrG8u30GSs7sLnoxeu/zm46G8zXpfp3
JOJL/B5Gu4P87cy/Z93tjFXniM+4W8N8Lfcodo4SX4f/KGP5dtH7+egVO4ZP
nysLOfckerUH327Ge33G03z2uBPbhe8YfdxA/WOMF1FHNU7Q5+Pc2xzuTrUX
o/2FfmsvYkl8/URcun0+42Ij9X5Csw/NvoSc/dQ45TPWxJa4OeAzLk7jP4V2
mS/O+n50W9CdYfwj85PkbWY/Jxn/TO0D5PzOWcXOY2fnGG8j9jNnXs58G/oV
+A/6jK0VjDdx7pPUEjPi4w/G59jnGeosZz8/s+45X5xh1TuErcL3K2P59PWg
vpbU9zVi9ym/x5PSWVdn3Zw1cHbbZyzdcnaZc6t3f/qMD+3rN/KP8LzF+JYv
zqw4O+/sL2d3nP3nM07OExNnYuo28WPk3iauPDF2gedf5OxkL39SK1bnDvX3
JuSJnYs+Y+dv5nvZywn0+4hd5A7kv+vsEnkXqa19pXb9ueee933GygOfsXOf
9f6m/l3q/EfNe744kz9R+xL93U/+aTQnyb9H76X5h757/XbuK86u+oynM+zj
Ifp/YEPzRz5j8Ao+xcTsWWKqcZA68uuHXpwjdpbcg+iuocnoN90hYtfI0/7O
sZ+H5P7Culr/ENrr2K/4xF8qv7Gj7zcqOmsWNX9+ZwX8xpg+b8Wrjx548ack
9ww9fAAX0kjr9xs758n5g/3eYA/XE3TnuWPddSr2pbHqq4Y0Ab+9l6qzEzaU
87SzdM7SOnvJWRq/3eN/nDu5mz+BTrH/4EXcBP1W52n8Ib9x9zccpKW2xnre
h0vpwvjvopNfPvEV4Rkm/xlytZ5y/yZHudrTZV88TxbFl8xvd5jkN4bkTyL+
D4zqztO7+bP4ksjRPIPfmNK6Oq96+JCY/Io/hjvV0B0+w34f8H5chSPtRaZ+
XoXHx9SQ7xrav1jnApqXnWVylt1v+8gGW9WcVfcbB8rVHWVEK06ehJUYt0/g
078D6OLszahxlRk2szjLCk9i8yk4zkI8M+sWhK+UzFORE6shnZd9pGAPWreQ
33griKUmV+y8CFtP4y/EuBCxAOcOMi+MPoQvO+t5ObvmOfxxzjTOyfkC/vj7
kJW64j4tdQszTkNemDrp0BXx258jh3m3w9QWd2WclXb2lrPnElgrTW9KUacI
jORCF8Ui+JLw5/Yba2KrGJyIoefxy1ccfe6EWDLmipXwG2PPMs9AnmoWxdKz
H+W+wDriLiP5ur88zvLir++spN+YeoHYk8zzoCnJneSFA8UrsUZFepEZnTgS
a9VYLyP7fIGa2k8+6qieuG/trI3feG7g7IOo1StFr0tSPxP6Gn7j7nVndTm3
WKrprBZ7qI6mNHeZlbxC+GsyrkFuIXzl/MZcWWd1/MZJbb+xVZZYLXyFya3F
OAfxclh5fGXIjzFahlq1qV8YbU704kXsvIrvFeZF0NchlotYEXpRFH8FamSl
f+rBG35jRf0qzrwe9csn1KmT0Ndi1FS93P44xxW49+Jo3iBX2mfQKP48e4yw
jniq7KyKs/bOOtCDF9CKKfEo5t5kXpm4/PoasQEmNsTFa37jqarfeMpD/fro
SuKvgqYqevkaUqcB62ndEqyZh3XF5cfOhvjt38O+yb+Jbec3Xtqi0VMsvUW/
Vbs6sZi/EXffltwa9LAe6ype1h/no7HfOFIdvU+t2W9D1ihLjnRisB19rUV9
zZtQozHrvMlatdDWxt+F2Osw8L7fuChHjffx687e9hsv5ZnXoY58Tf3GYEdn
nfzGkZ5vMG5GvClrdcRfAX8zrDm+zuR2ov7bCbnvky9tRX+cS83fcdbCWUvu
U+NK+CvyrMS5P+DslfFJK9bqE2vCuuWZ10cvlsTVu/SwM/XqsefOrF/FH+e+
JXrVH+2373m6cafiUN8X6e+S9H1SVbTvOcsTcJ+fzl5w1sNvPHXn/MPpTyu/
vQ/SV3GMttDfU0WN3enOvvXbeKjfGGxEnR7w0dNZL78xOwRND/zSDvMbU0Ox
dmh6kt+IXHH6MWfqzhrtyf+EcTvmn3KPHfB/wvgTYjHedAe9nX2GXrEPYUHx
mdSbgU+xPs76+o2nPuyxV0KtJsw7Unc44/eZNyWvGbER9Lk39bVuc+JaZyzn
HeM3vvr7jSXF+qEdARed0PRD14+5NAPIk188fe437gbCQ0t8o/C3RD8AG4hP
fHVFN4rxB9QcSY0u7GcktZU7iNwFnEXcbHC20W9sKf4RGsW7MW9FfDBj+fTz
oj6K2s/6Gcla6oH4EiPTGWuNoeS/yxpj6Gc3nuqvePyC51jyZpDbMyF+xNlN
Z7eYjyO+1dlsZ1ucfedslt9YGkjvJvuNCenH+41DcTWT8UzyPuGp3AnOJvqN
ieHUn8O8N3H5PmO9WYw/Ja+PP86r5l+yh/EJ+b2ZDyd3NnppxddX/jhH/fBN
Qj+Hnk9Cp/j33PkI8uT/mnP3olfiY66zedh8v3E0ifpfUvt76nxOzbnU/Dqh
pwOYf06tUdzbMO5Omm+4hyWcVXsRgwv9xoLGo9mHtIPQy78b3SBiU/zGn55T
nS3yGy8LeWr+BbHBaKcxlk+sH3d2Qnft+O3g7P2o8SZmN5AziDVidbXPxdRe
RJ1NnFW8bHb2I8+ZxBZz5nHMZ6Ifj38puTPJm08fRqFRPMagnsv8ts+N1BnH
fhYTm0CO9qH3YBb1f2QszQ/Um8udfo92NpoT9Oc/GNiGZj19XId/KzGxstxv
7MyhjmJf4VvhbAfrbfcbI3PxKbYS7Xb83+P72h9nV/NV5CpvJ7mTWHsb+d+j
l1bcrea5irtc42wtfo2/wWJasSbmdhGfQlz+v5ztcXaIetrTVDRr6cs0fDup
MZ8972SsfLGzkJp7GE9NqLEXzR5qLCD3BHdylzP/7OwXZ/uc/eQ3nhryfVbp
qNVQrcXknvQbg/vwKXbKb9ydpMZS6hzwGyv7iW0mdyk6+X8k/7Q/zv0pNPvJ
38jam6i7mPWVc8Zv3P3IfAv3KHZ+J74V/++Mz3Bunf8H9Iqdxad+rGBdvcfi
+CC+Xxgf4u5+YI8HsJ/xqdY5v/G0jfl2clZQ4w+/cSjdl+QtZ74D/Q/E9K6J
JfF1mN5ccnbZb1zsoN5hNL/6ja9fE3J+o8Z5v3EjLi5wh+LkL/zn0a71x1nX
/AiaQMDy1hGT/0/ydrGfPxn/xRp70Et71NlF7vBvv7GYxtVM6+yY3z4jpGnM
39X2jNoe/yZH+nt+Y2on59Z6J4idJH6K8VFqrqPGXvb0E/UuYpfw3Sf3Hr79
+Fdx7+rpaXQPWNvr9u5z9shvLD1EcwrdP/BxGb/yzvB8yPihP86sOLvi7Kqz
x37P/39Y9Dl8iokzMfWI+FlyHxFXnhi7xvMqOQfYyz/UitVRjXOcL5anc97w
GzvXmR9iL3+g/5XYDfrwB734l7wb9O8ya6tH/oCxIo7Eh+bXqHOI/D9Y509y
Ykyq5r/YTXx+6kijrwP1fUU34kfQ6OtGfe+j75nu+I2z25w7g8vP6CwYMD4u
wMwtNAFi8ovRws5eChhr+iwVu5dgKBywf5ukvx/4MGr1QoF47CJz1UkXMMbu
Uvce6x1j/RD70drKjbDOMwFjSvnpnT0bMHYeEJNP/ZY+GjD/fWJJAbv7mD89
uTlZI0fAuJBG2mQBY+cK66nOPWprjUsJuiv0Ugw+y74ewbVqSJOcvCj7eAyz
yrtNz1O5caaAceBh/eQwkpGY/NfhVN/3PiYm/5MB4+467GR2loX3Mwv8KS5d
CvxedPKngN+neKYgLyu5T7CG6mcmV3u66Y/nyVLiy+ae2WFI55M/FfFb/rim
LDpZCP1t+pGada/RC83vwEtfx1lzZ+9ErU6AvWZl7OdeQ9R+mtzUcFzbWR2Y
TAPfR3l3bsFhDvio6Cy3swqwlcvZc/RHvSgFp9KKqaIB464I81zE0xMrRp3n
YFO1n4en9OQWxZ+ETjnF4Ss982fJidUoQm461oyybomAsVYcy0Cu2HmZe8yI
vwTjEsTU9xe4B81Lon8SXx56+BLrap43EOdM43ycL3kg/j48T91S9LAklpn6
ecl/kj5LV5p1irBWCmo/hb8OsQKBOGv5ieejjmpkxV8ATUo0+cmTv2DAWEnF
uHzAeCgXMGYbMy6HPzv+coxTk1cIexqfNOK1DJaN/byIphDn6ODsfWevOHuV
+9Q4Z8JeyjOX/nXOnguftHUDxtHrnLsMa72OX/pijKXtz38faxm1fuqdqM36
zwXi3GtegVzlvYFfPnEY4FxBYvUCxl07Z7Wc1QwYS286q++sCWdR7/SuVQoY
H8orQe6bjOuRWwJflYAxV9lZw4Bx0iBgbFUmVh9fSXLrM85LvApWFV8l8mOM
VqJWA+qXRJsPvXgRO9Xwvca8NPqGxPITk/8t7kP+6tTQvrqyjvgSK40Y96JP
+Vg7VqchtRqhL0O9goE4x5rXCBhbBRnHcspQvwn9r8QdvMOdvB0wlgqRVxNf
eXLE6KfOPuNuX0TTlDxp66ATd80Cxsmr+DrifxV9U6wZvk4BY6wjVhf9zKj9
N4hPo1ZfnHagtnKbB4w95Xd29kHAeOnCXM96nLNigr5zgr8F/ehCbj3O9iL9
ULxyIM5Hy4Bx9Ab77MR+mrNGZXJactcfcN/1qa/5u9SQRvzlJle6bgFjoxhr
FOcexUB3zq3e9WHekJz3AsZLVeYNqSNfq4AxqP8vhv5/GI14Nmbcmngr1uqB
vzr+1lgbfL3I7Un99xJyu5MvbY1AnEvN2zprHzCG2lGnd8AY0/NtxjXRSvMh
fsXF3yxns+nhe7HzOj66Ru37e2mGB4wj1R9Pbk32obpiUhx9Su0PE3ralPn7
rNeRNaqwpjR9uYdBzj5iH/0DxlM/ZyMCxsVwtM3RdyY2El9f9Jp/HjAGW1BH
9cTHAGcDyR2Jpj9+aUcFjKnPsQ/QDCC/BbmdWLs5a2qNruSPZvwB8zHcYzf8
oxmPJhbj7V16MBb9GPrRivhw1u2IT7HBAfv/CLVm3JLzxWq9y7wHdb9g3J15
K/JaExsXMA4f8u+P9O8AVH9IwJj7NOzu2tknziZwt+Lha2eT6ZNq9KJOW3KH
8mxLHXE0gdxhAeNYfIoRcTSL+VDiE1lLOZ+gl1/sbnG2NWDf//fS7w2IWv2l
6Nux7lBqqJa4+5LnRO5wkrOv8GvcF4tpv+fO5xDvR3wksbnOvmN/M/GPIDaS
+OfseQ73+Rnz4dTT+v3pZ3/myptH7oCE+BzqK3d+wFibx7l1/iXOFjhbGDCW
5qH5HCZ0X98EjMNR1BjNcwHjBeROcTY1YMyJk0XOFjMfRFy+say3kPEY8gYH
4rxqPo09fJOQP4j5F+QuQi+tGPw2EOdoCL7p6LWXccy/Jb6EPowjT/4ZnHsg
vZyJb1PAeJqBbzr1p1F7CXWGUUu6ZQFjZwI9X8ZY+Z+gDQfd90XOcjj7Ab10
B52tdLYiYCyJr+XO9nLuPQHjQu/BFmLSxGr8kJATq7EtYKyJi6+oL06249+G
9qtAnPUV6Oai28H4e+ZbyZvDfrYyXkXtleTsDBhf4mWXs9085xOTfjW934l/
Hvct/xpy55PX2b3DI5wNj5pG8RiDeq5lnzuoM5n9rCI2hZzd9HIh9XczlmYd
9XSmM85+R7sIzQD9fz+i9jW+GNgHB+vgYips7CUm3/qAsbOYOop9i2+Ds/0B
Y+WngH1WiJXNxDai/QnNEnwzAnF2Nd9E3qaE3OmsvY/8JdTQeuLtR9aTXuz8
HDB2fmZ+gJhqnqQXD509oj9b6NEvCXnT6MV69GcDxsq5gLFzlvUPsIcDrLWM
mr8H4kwup7bsIL6z1JFGjHzDPa9Ec8jZKWf3nN139quzw2gvsfZP6KUVG384
+zNgDP6KT7HzAePuT2qsoc6RgLHyG7Fd5K5BJ/9u8v8KxLk/j+Y38new9k7q
rmJ95VwIGHe7me/hHsXO38T34v+bsXxH6f069IpdxHcsYFyont999gScHcen
mMYnAsbTOvZ4BDuK7yJ9/In6FxlvpI5qXKbPl1j3KPVVexNanVtM6BcY6r5O
cmeb0GkuPjdzn6eZn6K21hA7VwLG3T/Oxrh3soezsVHjSJye5fmsWydD0Pxi
9iF5yhdfV3leQf+Y3MvUPsDzZ8YHE/Jk1/Dd4A6vB4yha4yvMT/I2XVub9B8
18nR3Bc0pjbTg1PovfgVF0d/UuMce31MP7Xnw9S7gf2Lz0+uasj3G35xuJ38
39DfxH+O9fXnlVgKBq0/D+npLfiQXlyJqQs8g4yDwTiz4uC2szsB+3MwEjRO
bhM7ClNaT3GN/2Z+jDwx9h/PO+RoD7ew2wl1wtQ/kZCnO40G7T7v0mfFtRfF
LuFTTEye5h70efKA+X16dZO1VS+JmuKsuLMSQVvvLvWj1I+gvQJT91knnfMl
w6/4OP0dKl+7qrfnuUPFpbvK+im5hyeCcdaSE0/GfWlPj/FLdw3dVXzXyX8S
LsVWJjgRQynwy5cZvbSx2A3mimWBYy9zH3mqmRHzsB/lPsU6WYN2PuVnc5Yd
hsRSVnw6r/Qp8fuJpaIHMX82cjOw3mO4kEba1EFjR74s1PGxl5u8AzGdNDn4
mi07FqK+akjztL6WczbR2TLYVU5OZzOczXQ2zFmuoHEQodd5g9aDnMTkvwun
aaiTE3/aoHFyF2bEyzPOcsNNEnHpFHuA7hnWfA5NemLP4MuNPw1rqP5z5ORi
DdUr4ux51soNR2LnBXzPM1fP9dlQnFhyYvKX4D7kz0MNrVWBmiVh5WXY0bwU
efWcvak+u/fhS2eToqbLRM089DTGcR76mxlNSeq8jD4fvZemMOd/EbbyOyvA
2qWDxshT6JVXJmjclWaen3g2YmWpoxriqKCzQkFjJRu5ZfCnQqecckHjKxvz
7OTEapQmNwtrpmTd8kHjrRyWg1yx8wr3mBN/ecbliT3NudMwfxV9WnyF6WEp
1tX8pWCcM42LcL6ng/H3oRB1K3DHr2LPUf8l8lXnGWoUZU3xrxrpiRXl7j9w
Vp97FF9ioga9qe6sYtBYE0uVGFckX/Vfx6fYC9RUvZd5lmRcmXgl1noTfx78
lbEq+BqQWx9tF/aqz+/FzvZETZs3GOdS86rOXnNWjfvUOB/+vDw1b+jsLe4/
Pz5pGwWNo7foc0XO/hZ+6csybsQdNqBeKfbcgPULBOPcV6OfZclrjL86vS7G
3RQl1iRo3DV39g77EEtvO2tKncZodF81g8aH8srjf5txE3LL46sdNOZqUV/n
bBY0tmoRa4rvVXKbMn6JeG2sDr6a5McYrUmtZtR/FW0R9HWDxk5H4s05YzF6
oPgbzOvSg0poWjB+h/UK0gPx8bmzUc5aBo2nFqxZh/WK8lTNOY6hrc62RI0x
sd+F2i3IV82uQePwDu+Q3qUqxLXOp84+c/Z+0Ph6L2gs9XHWlx6oRgPqSPMu
uneZq14r8uQXT92Dxl3roHFSDV8P/NXQt8Ja4+sZNMZ6YI3Qq2Y3ajRkP92o
rdw2QWNK+b2cfRg0Xnoz11MstaXfMX2vBH877r43ufIPdvYxayheKxjno33Q
OGrMPnuynzasUYsc6Zqypz6M32begRrtqVuDvTRFq/6P4ayjg8aV7r9T0Lio
TY1+QeOwL3f5OvG++JvxlO4dnv0Zr9TPS3W2wlln1uhEvAWaEfiGOxuAX3Hx
Os/ZfNbU2h3ZY0dyxKHY/Jw85Yu9QcE4R+/iG4hedbsyH0R8NH3oSp78H3H+
9zlvd/o1FvsiaBwNpP4Aao+mTndqjqGm6rXi3lsx706tHmgbkNs6QduSPepd
GModDnH2NWuqV+KoDXnibpyz8fg+Rq/5hKAx2I46qic+9DXjJ+SORzMUv7T6
evND8icw7k28PRrl9mTtNqypNfqQ/yXjD5lPChorffF/yfhLYjHedAf6LPkK
vWL6XOlI/AvW7YFPMbE0MmjMjWCPnyTU6sBc8U5o+lP/K+oMJ/YVve7P2Xqy
5vfkzXG2mJj8YkDMioPJ3JHy9WfzXn2PFTWfYgPRi1+xPgjfN84WBo2dBUFj
ZAw+xaagXYB/NL6PgnF2NZ9KrvIWkTuQteeTPxq9tOJtGs+p3OF0Z9/i1/hj
LKZdwtkXEx9CfDyxpay109ku/OOIjSc+gf0tpodjmX9BPa0vHmfw/Ja8ZeQO
S4jr6w19jpcmPhFN75D73HXWy9lyN18RNJZ2058FMKHvob4LGofK/YGxnssZ
Lyd3lrPZQWNuJDx8z/xT4iuDxtAK7CtylTc8GOdV8zns4buE/E+Zf03uSvRz
WE+9nUd/t7P+NmeruGflrWYsn/5sP+PsdNR8q+HiILW1xzX4VjNeGzSe5nLO
79Guov4u+riA/exiPIU6qrGHPu8m/qez89SeinYzZ9UdiCXxtZ64dOvgYiH1
1qNZh2ZdQs4GauwLGmtiS9xsDBonP+Hfh/bbYJz1DeiWotvPeAnzveQtZj97
GW+i9kZyDgSNQfHys7NfeP5AbBNnnsn8B/Tf4f+R3B/IW8S596JRPMagnlvY
537qzGQ/m4jNIucX7nsF9X9hLM1W6p3njnzufTnEfStHn18XnPmTPJ5fg8aI
ODjOudU7cSJGxKM43cZ8FXVU7xzxs6yldfwhG/8VNE4OU1/rHHRrXuHrCfGz
k/2tRifGfuOp+Q72sZ31fmX9Xayn+msT8sTO0aCxc4T5WvayB/06Yke5A/kv
ODtG3lHOu5Uz/+3sYtBYuRQ0di6y3hHqX6DOX9T8Oxhncj21j9HfDeT/hGYr
682m99KcYO3f6e1JZ6eCxtN+9nEZ/QnY0PyfoDF4Ep9iV4LG3T/U+JE6Z4LG
ymliP5P7Izr5fyH/ajDO/RU0p8nfz9oHqLuJ9ZVzLWi8/cL8IHeou7xO/BD+
64yvce5t9GYH938O31nm++mhevEHOmn+DRo7N8jfwlnPUHcra91gLzfQa+wJ
WY3HQeM4i7OsIbvTC9zrYdbQ/T/rYg/dM717BkKm+Yve3Hf2gDqKyX+EvJtB
49eP/1bQuDvCGkHnD4VsrOdF4tLdRnMB3VF84usOz9vkhcm9Se4RcpSrPR1P
yJP9FzTfPe7wLgz9x/g/5se584irEQ2Z7y45mieFjCndeTI3Th4yfRS/4uLo
H2roDsPsV2Pt+RT17mH38SUjVzXu0+tT7OcS9bTuFbS6v2zcwUM40L08GTIO
nmB/esbYk+Yh+0+OP1PI+MiINsaveHwEM3/AoHQ34EzrnCWumDdkOmkUS4H2
IXW0vnz/wuZTjOWLpHI9cnY5pbGTlXPpa4EHzu5Hze+D3X/J1/2n5PkUeaWd
lQlZ/x5w5lvBuFb8iJXsIZunClk8G/4AvtsJXGqemlzl5eAZ5A5uwv+/6KUV
d9Ll5P7FURr3TEtv1KO8IWNP2qfdOFfI7lk5mqchHiX2HHVUQ+ykc89n4CVK
rnTpiKclJzfsRpnHGIvVyElumDVj78TzIWMtN5aMXLHzQijOmPzPM36emHqf
HjY1z4P+EUw8Sz9zsK7mGUJx5jLA5DPUin3uaJ6e3j1J3TyMn6DGY5jzwnYm
+nmHu1E8IzGtX54eZIUvMZQ5ZPnKzRcyvnRv+RnLV5L4y/jyw5T4KwsbZWFF
4wLE87NWGfyp8BfACuIrR25ZtG85a+TsqnsfkpLsaw5pU4fijGpeyNmLzgpz
ny9y/kJoCjHXuV/h7GnwSfsqHL1Cn/Nx9lfw54SjXGhzsNfyofi7UY7104bi
3Gv+ErnKq4BfPnGorwn1PYa+ZyqCL6aXVgyKpUrOKtOTRvRH+qLwUjFkHOZG
+zy+FxjLVzxkzBVzVpVzVgkZW8WIVcaXh9zKjDMQL46VwFeU/BijRalVhfp5
0GZE3yBkDNXHJ45ivOVlX6VCxqJ0r4WMHcWrMX6NfbVkHfWjh7OezqqHjKdq
1C/BGplZRzWfdRxlcFYsyfop9t+idjXyVbMxfa7KmtpDQeLVOavu4PWQ8VUz
ZCwpVgNtY7goi6YGuhrMpalFnvzi6e2QcVcbFgrja4q/MPpaWG18zULGWFPs
VfSq2YQa5dlPE2ort07IWFN+c2ctQsbLO8z1rMg5iyTomyf469KPd8ityBrl
6IHixUJxPt4IGUcV2Gcz9lOHNYqR8wZ33YL7rkx9zetRQxrxl45c6d4NGRuD
nbV21oo71F2+x7nVu/bMq5LzZsh4KcG8KnXkE7Ml0cfqPeMYKuLsJWcNQ8Zu
A+LV0HTD15W9VCMuXr9wNo76b7JGKdZRjjgUmz3IU774ahuKc1QDXxv0Pel5
G3SK9+I+GpMnfzt6+CbnFR/67zIfYn1CxlEb6remdi/qvE3N3tRsl9DTWszf
plZT1ijOmtJ04B66OPuAfXQMGU/vO+sbMi76oK2Dvjmxfvg6oNe8f8gYrEsd
1RMfnZx1Jrcfmo74pR0QMqb6Yy3QdCK/LrnNWLsOa2qNluQPZNyC+aCQsfIu
/oGMBxKL8VaPHnyEfhD9qE+8D+s2xaeYWOoeMua6scfOCbXqMVe8AZpW1P+I
Ol2JaT6YuN5Hvbv6c2QMeaOdfe9spLMRIWNAzIqD4fjUp9zuHXjV2XNJxsrH
IWNHevEr1tviG+JsQsjYGR8yRnrjU2wo2vH4e+FrF4qzq/kwcpU3kdw2rD2O
/F7opRV3n/Acxh1+6uwz/Bp3wGLaSdz5l8TfJ96P2FfOZlBvKP6+xPoR78/+
vuQ+P2Teh3pavyP97MhceV+T2ykh/iX1lTs5ZKxJt8TZPmc/OfvG2ZSQsfQ1
GtXpzH3pLgfin8x4MnkDeSr3c2ejQsaceBMPY5h3IT41ZAxNwT4iV3ldQ3Fe
NR/NHkYm5HdhPpjcqehHs57uUewsdraQ9Rc4m8Y9K286Y/nqOv7ecNYxyXyK
DeHcnenlt/imM57B3Y3lnGPYxzTqq7dLQ8bTOObjyRlCjWUh43ApmsUJeRPQ
az+tqSmWxNd3ztax3tqQcTGBet+hmRkyvmYm5MyixvKQsSYuxM3skHGyAv9y
tJ+F4qzPQvcVupWMJzH/gbwv2c8PjOdQezY5q0LGl3hZ7WwNz8nEpP+e3q/C
/zX3Lf9ccieTN5Fz/4BG8RiDes5jnyupM4L9zCH2OTlr6OUU6q9hLM186g3j
3meinYpGax9w9rOz9SFjZBp5o8kVJ2JkIb4FzKdRR/e5h/jukL2TF51dYrw/
ZFxsoL7W0WdnBWdNk4wb8bOPuHRibCNPzRexj4Wst571l7DGUs4Xy9M5N4eM
nU3MZ7CXZehnEttMH5bRix/J28x553Nm9eiXkLFyMGTs/MJ6m6h/gDr7qflz
KM7kd9SWbcH3C3Wk0f9vQ/8fIv1/LhSfjWYl6x1yts3Z9pDx1Mv1romzt5NM
uxU2pPs1ZAxuw6fY4ZBx9ys15lJnZ8hY2UFsNblz0cm/hvzfQnHuD6PZQf5K
1l5F3Tmsr5wjIeNuDfO13KHu8ijxdfiPMpZvF72fDwO6/z34djNXvX+d3XS2
F500x0PGzjHy53HWndSdz1rH2Msx9BpfoMZfIeM4HPZ4ImFbd1cozrmYvci5
dUfXnF2Gg/3U0z42Uucy/k34TlDnEv6TIeNOcbHzj7MrjPX8hbh0p/AfQLcZ
n/g6zfMUeVfJPUHuJnIOsKctCXmyM/jOcoe/h4yhM4zPMN/C2XXu6/h+J0fz
GyFj6gTnPY7+On7FDzO+Rg+vYgfZ83bqncXO4fuX3Bv4duAv7u6pmLM3wuZT
7A9nf3OvQee/zd3foj/qRZLz/xkyPqQXV2LqCM9bjG+F4syKg/Mh40Q174SM
o/PExIqY3MPax8i9TfwvYn+ju0CO9vAndh7fHfp3jDNIGwgbO2JT96ixeBSv
H/L52izJ8v7jHqSNoj+J7y79+4O1Nb8XinOm8X1qHGcvqpPTWa6w9U49jFJb
48vknaLOFXqcLGy9PcwdnqL2adb3cg8PQ3HWHhC/Tx3VuIr/IZozaB6QJ/+j
kLEmtp4IGwti6DF++Z4Mm/5RQuwsc8VShI2x68xvkKeaycNmGl8l18M6T4Xt
fMpP6SxV2Ni5SUy+P9DrzDfph2I+ehDzpyQ3GetdhQtppPWHjaXzrKc6N6it
Nc4l6KRJzTuQin1pfAsepRFXd2HjP+77Nnl5nVV1lk//v1jH1ifOhiVZvzKE
rQfSPR22vOxh4zUbvlg98ROGobSsl8Y9c8PTc2jTEMuFL8pncS7G9+A1LXXS
4UtD/tNoX3H2KjWSyJX2Ppw+hJ30+J4J2zwZeu0rPb5n4Ph57kP+Z8NWI1fC
OnnCxsoLcJaH/qm+1o7VyU2tF9Anp96jBI41z0CdJ6gVy5E+I72XJoezUNh6
L4YyOcvM2vlg2oNeefnDxl0+6mQinpJYAepkhs0szrLCU0py8+P3oVNOQfhK
yTwVObEa+chNwZpe1i0UNoYKYqnJfTFs9/o0lhqtzhrkvGI3G/NC5EhbjnhZ
epiXdQtTM1Zb87ScLxCOvw9Zqau7beqsmbM+jvsJSfZZq3sXy+LsJWoUZm/6
fA+SWwE29K6prj7Hn4eBis5K05tSzHOTUyRsvKRjnps68hUNG4OVnFWGCT3z
MC5GXLrn0cn/LP5iWHF8VcitTP0iCbkVyZc2QzjOpeYlnL3srCT3qXFG/Bl4
aq7Pj9e4/0z4pK0WNo5eo4dFOO9r+KUvwLgad1iFennZcxXWzxyOc1+SfhYg
rzr+UvQ6Hff1ErEaYeOujrPX2YfeKfFTjjrV0ei+yoSND+UVwl+TsXwvMpav
PLVU5/8MOesbNrbKsoZ0tcjTszDjJuQ1dlYbfy3WzxaOM1qGWrP0vYGzH5OM
PbEpdptzj+LoVfZRgWfzcJy3l+jBO+ib04+ixLPSv9L4FKsbtq+9ijEuzF5j
tV5iXom6LRhXZF6UvGLEWoaNQ31/oe+V9HVhJWLyH3Z2w9m/YePrzbCx1M5Z
e/rTEi4qo6mHrh5zsVufPPnF03th465B2Dgpia8V/pLo62MN8LUOG2OtsGro
VfNdalRlP+9SW7kNw8aU8tuwf3HQlrmeYukt+h3Tt0nwN+Lu25Irf1dn3Vij
EVzE+BBH5ahTjbVLUbs0mkboyqNtQk9rsse3iTWhbmn20p57lnYQZx0YNtb7
hY2l3uT1wv+ls0lh41Cc6t2Y6djd5Gxjkvn7kvu+s45hY04s9Hc2gHkd4vK9
w3r9GDcnr244zqvmndhvh4T8OsxbkNsfvbRivEs4zlE9fJ3Ray8tmXchPpA+
tCRP/g9YozY9e49+fYQNDhtHnanfidoDqfMeNQdRU/Xqc+/1mb9HrVZoq5Db
IEH7hbNxzno668Eddnf2Nef+KmwcNSRP3H3sbAi+bug1Hxo2BhtRR/UaU7sX
uUPQ9MAv7bCwMTUUa4emJ/mNyG3N2g1ZU2uIQ7HUmz62o94yx81PzpYm2c9w
6UBcsU8YTyBvfNj4W+5sRdhYE4Nfcg+t6aFq6OfCxBjU8zP22It9fMieehN7
n5xJ9LIf9ScxlmY49T5mrcFo+6OZRmwwDEyGA+V1IncAdzYZ34iwsTOAOop1
wTfS2ZSwsfNN2BgZhE+xz9F+g38gvg/CcXY1H0Wu8qaS25m1J5M/EL204m00
z1Hc4RhnY/Fr3A2Laadz9mnEuxMfQuxbzjucdYegn85Y8aHsbxo9/Ij5YOpp
ffH4Bc+x5M0gt2dCXO+i3mn92TEzbDxJt87ZEWdH8X8XNs7W0B/1QozoXRtP
bBhaMSNeJpD3KfFZjOWbHTZW5FuGdmnYeP3F2UFnpxzrp53dSzK+xO9yaswi
vxfra72JrD2BOivDxt0k5l9xj2JnFfGv8a9iLN8cej8cvWKr8X0fNi70Lu53
dtHZXHyKaTwvbDwNZ4+zsTn4VtPHb6i/mvHn1FGNtfR5DevOob5qj0K7hLPr
DsSS+FpAXLr5cDGFegvQzEczPyFnITXWh401sSVuFoWNkw3416MdG46zvhDd
t+g2Mp7OfB1509jPOsaLqb2InE1hY28idyguNoeNqU3ol3DeTfhn0AP5xc93
+Dez1lrWG09cdQ9Qez/73EidcexH6/zAPmJ7+JHaes5ivIXxj+SKRb1bYveq
s2vU1Xuh9+7XsLF0yNkezq3ebQ0bH6q3gvyVPA8xPhSOMysOtjnbHravG38L
GyfbiImV1ax3mPEq5t+TJ8Z28NxOzmz2spVasTqHqT8vIU/s7AobOzuZz2Mv
a9HPJ7aLO5Bfnym7ydtF/7awtj5rjoWNleNhY+cY6+2k/hHq/EbNo+E4kwuo
vZv+LiR/Axr1Vp8fv9B7afay/hnOvc/ZT2HjaSP7OIFe2sXMT4aNwX34FDsV
NlZOUmMpdX4OG08HiG0mdym6/cSXofkRzSk0+4ltZO1N1F3M+tKdJu8059FY
/F0PGzuBZO57dPdZ9XeS+ZNHPJ4nIsaY+iFef6cH6sVB8g+x7gZ6sQ2NtGfD
xo58/7D3y+RvYS8xnTT6/uZX9nSd8SFqSHMubH8HpP8e//+/60GjvDluryOc
DXd2Ew5+ozeXWFffO93EL17EzR9hq/Mv/j/Dxp3iYueWs9uM9TxGXLrz+I+g
24VPfP3F8zx5d8j9g9yd5BxhT3sS8mQX8F3kDv8OG0MXGF9gvoc7/8/ZXXx/
k6P5vbAxpX34I1b7BLGTxE8x/o87vIMdZ88/Ue8idgnffXLv4duP/wS5qvcz
967790bs/B7YesFZnohxcIp6V8iR/gGsnCb2gHEomf25einJ4g/DxtEjZ49h
RWyKWXH8iLh0WvfJiPF1jfl1cmI1kiK2fjRiOWdYO0XEWHuSGhpfh52n4E7j
G2j/5anYOc79B9qU6P+ECfVG/btMvzT3ReKcaaz70/nOhePvw2PqpooYTymp
fQuulHeedcShdKmdDXbWytlHEfPfIhZylsNZ2FkwEmctA318Fr1qiJEAugvo
/sKnvCD17sJCmohxIobC+OVLi17aWOwic8XSRYwx6dMyVp5qPh0x+w9mlRth
nWcixo3yNU4fsXu8Al+6Z/Vb+iix++Qli5guibyHMJCa9bRW7ojFn4Pn5DCd
jnXvUfsy78ez1EkP95WdVdHeHcdPO6ZTJ7P4s/Q6wPvqR58X7go5e5F9iKV8
zvKzhzxodF8Z4UV5KfDnY5yX3BT4MkeMuUzOCsJTgYixlYlYfnwpyc3P2Ec8
M5YFX0byY4xmpFYB6qdE60cvXnTmbPiyMk+NviCxALHU9OJp/Nmp8Zj3WD0o
HDFWXoQlzV+ifpaEOgUT+pqGmqoXisQ51jwHddJQ6zKfE+IpZ8T4k6ahs7ec
lYatXHBSzVl1ehBBr7yiEeOuCPNcxMWhGMtNneeYF48YJ8UixtMz1HienNzM
Y/Fi6DWuSLwC6yk3HWtGWVdctnT2rs7guMzqLJuz1yLGS1U0eoqlEhHrt/aV
h1jM/zJ3X5Vc+es6e4N9vQwXMT5KRowj1dH7VJm9F2eNTORIJwZfo6/5qa95
KWqUpG4G9pIfbQE4qEMPCsFAjYhxkZkaNfBX5y6zEq+OvwC+MhFjsKazWhHj
SM/CjMsSL8NaNfFnx18WK4evNrm1qF86IbcG+dLmiMS51Ly8s1ecvcp9apwT
fw6eOTn365w9F75XuJeixEqxbhbmRdEXY1yXHtam3kvsuTbrPxeJc6+5eBOf
Yq8i/grM05IvDiuhq4ivCP43ucN6nL8d/dFcbIinso7R7M5yJDN2BzobFLHx
exFj8GXqqJ74qO+sQcSYfRfNm/il1Z+Tr5H/HuOqxEuiUa44bcle6rFGNfJb
M36NeRvusTr+1oxbE4vxpjvQZ0lb9Iq9BQuKv0OfmuNTrJGzxhHjqRF7bJBQ
qxTzmtRtx7gG8zLklSXWnj6/wdl0/+WIa53+7KNfxPh6O2IsKdYErWrUpk55
/G/zLI+mKXnyi6f3I8Zds4hx8iq+jvhfRd8Ua4avU8TY7IjVRa+aHahRh/10
oHYzeliJfuo84uYbZ1Oo2ZketED3Dr56+Lswlq+Q46+Gs+rJbI3a9EB8iZGB
jLXGe+TXZZ0K7KUi9VRXPH7Aswt5H5FbPyGuryV38LWh5l2Jb8en2MduPiRi
LDWjd31gQvpuEeNQnA5mrOfHjD8mt7uzHhFjTpwMdTaMeUPi8rVlvSGM25DX
KBLnVfOe7KFbQn5D5u3IHYpeWvHVOxLnqAm+XuiH0fNe6BT/hDtvT578Hzr7
ltpD4ONTZ59h+p6yI3Uas/YwarVH34Gct6kX62lT5u9TqyO6DuRL05d7GM1Z
dQcDIsaZ3q0RcDEcbXP0ir+DpjmxfuhHRozDr4l/FTFuPo8YFyOZd8bXBZ9Y
X+NsrbNyjt1GyewzVbyJ2W/I6cQ6zVlT+xhF7c+pMzVijIqXac6m8xxMbBRn
7sp8MPpu+MeQO5i84azbEY3iMQb1HBuxfU6hTlf2M4pYd3Kmc99DqD+dsTRf
UE+5YlHvzoyIsaGcH53NcvYdDMzkHudx7rn4ZxATK+Mixs4w6ijWG9946n1K
zc8YzyI2Ae13+D/B92Ekzq7mE8lV3mxye7H2TPI/QS+tuPuS50TucFLEOPmS
cV8spv2eO59DvB9xsSrGvua8X7DuSPTf05fP8c2mxnD2PJtxP9ZXrcnU/Toh
X7mr8K1knZ7cl3j9zdkR1l7sbImz+c4WRIyndo7j9s6GJrO96M5GkbsuYgzO
x6fY+ohxt44aY6izKGKsLCQ2jdwx6OSfTv6GSJz79WgWkj+FtadSdxTrK2dj
xHibzvxb7lHsbCI+A/8mxhs59zh6M5PYZnzqx3jW1Xus93wpviWMl0WMpy/Y
4yJsMT7V0jvwHfU3M55AHdXYEjEOpdN7qD9H3qP2RLR7nF1wtjdiLImv5fRm
N/HZ1NlCTJofqPFDQs4KamyLGCtiSxyJEbGyHf82tF9F4qyvQDcZrfiai155
W8mbw362Ml5Nzip0O8jbxR3ujBiLN53dYj4PnT5TGzvrkcx8O8mR/mjEmNKe
Djo7FDFGjuBXfD3jHdTUur+yF+kXUG8XthvfMXKP4luIfy0s6P3ZgO44Zz3j
7HdnJyPG0gk069Hp/hZxXxvI28jzBOMTkTiz4myfs5+cnXJ2OmKc7CMmzjaz
3inGm5gvIU+M7ef5EzmL2MteasXqnKL+soQ8sfNzxNg5wHwZe9mC/gdiP9OH
LfTiF/J+pn97WFs9OhsxVs5FjImzrHeA+meoc5qav0fiTC6n9i/c+wryt6OZ
Te5W4ivRTKS29vtnxFj6g3Pfc3YfrbhYxd4UFzuHI8ax2BGjKaMeT6qosSYW
xK44EUPnnY12vHZz1j2ZrfNnQmwXc9W5HTHGjjA/ypo7WfcGa14n9y/WuRMx
ppT/n7O7EWPnOLH/6Lf0F/AfI/Y3dx/z/0fuDnqoc+9DI+3FiLGzj/WOsc+/
WGN3gm4fvTzJnu4yPkENaS7Ry1Wc7RSae5xd63v0s0Dg4DS5ytvPPT3AfwDf
Zercx/9PxLhTXOw8dPaIsZ5niUt3Bf8ZdD/jE19XeV4h7zG5l8k9QM4Z9nQw
IU92Dd+/EWNI93kI/3Weh9Acph8xzXXm6oU3ar25zHnVC/n+pGdiRwyKS+nP
sdfH9FN7ThG12k+6p49c1ZifzHgdk8x8iok1P08frKeO2v1rrVSMpQlEjQVx
9LQbp4naU6ylJn4BXlLjv01Pk0WtT8q9Q34oajwFqZU2ahxJk4bxRZgLoQ9H
zZcuahylZU2tHaTGPXiU9lICi5pH8Ol5GY7uUS+KTzH5n4FNPdMz/oe7ibJu
kDNonhS1+CNYeZY6qh2r8RB+pL2SwKXm6tEj8jJE7Sm98nITj+k0fx69tI9h
TD1OHjWmnogaA5prrHhGuJE+E+OMrJcR/7+wmYI6T8LTU1GLya/czPCaGc40
zhe1eF5nWfBnZv3Ye7DQ8TfW2RfJLC6d+MrKU/Ns3GcAf7Zo/I41zu4sB0xk
x589gZEQ8eRwl4x5TuLP0cMk6sbWj6DJxTgXXDzHMxc5MV9OdGHO76E3ybgf
rf+ms5edlaQP8r3A3eSlX5rnicbvLA+xPMzl/zy5+3rY2Vxn+aN2H+q3fi99
fWelovY7fL6O2s+/Tcb/Tz2Jf6s+kX8LF+a/B+rvDDc42+jsWDKrl4Ka+jqs
J/e0O5nd2SJ0x53ddnbe2V+6Q7cfj7M/9Lni7KZquXkKZwWcFXRWzVnm5Kb1
O8virCQ+r0svIE7cs56bl3D2srM5zkY4G+lsD+tpL1Xd/F1nLZ194Ky+swbO
PnI22NkUZ12TW78+YJ1S6N6K2u/6K0PPk3NPh13sN2c3kts+qqmf7lndPQs5
q+GstrOXnBWJml+ags5ed1bUWTFn27mfec7aunlNZ7W4m9LcVS38hZ11cFaH
GqXZl/ZX1lk5Z41Ytwi64s5KOHuDeVFy2zhrzT5fdfa2s1ei9rul6sFgcfLq
Ru13I1d0Vok9ac2uaN9gDcUqR+13KE9251nlbKWzqlH7HbBVotbPsuyzGLVf
Z96d+GvO3o1anvz6Hfb6fTadnH3mrCP7KwnH05wNcTYd+9bZevIa0ZepzgY7
+zhqv1O8j7MJzso7a4L2A2cjnXXhTJ1Yq72zdvT1bfrVlD0O4GzN6E9z/O85
G+hsvrPRUfudPM3p0TtoWnJG9VG/V3JU1H5f7jv0sQU9a0mdedTa4Xp6Nrmx
8xprqV4pOGzF3X7EWNbQY/HX6fn7ziqwb52lLb1pw14achcB9/5nSbKfpalY
TbRt6Yn6XotxW3o1lHk9eqhe7uQMC6L2u7Z1xn5R4/l19vMxd9SG3M7ka3+9
6b3uZgSxutyPcj/l2ZF+fs59dkH7ZsJczHT3WH+moFesAfckDntg+r2JY7m7
PvRLv3dtVtRYlLYR2u707i3y5BNXvdi7zrA2aixO42zDqdMEXU/2/n3UWOxA
T+vAx2g4EFuDnE2m7jjye9OvD9lrH8bS63N+AL7m3IPegYnOlrLHXuxlINp3
2eNszqzf99aSmPY2jP3pfndwx++xN9XI6rgpBUOjOJv6LSbVf3E5hbHufgi9
+Zh7G06fNG9LXCbG9K63YyzfA/c+nHH2e3Lb17fERnMv3dnvUPas3/cbY+c7
np+x/lTW7IjvU/o4nh7rbvR7CMRia/b+ET2dSI/HcrY1rDWMnkkj9mO/u6Uf
fR1JvS70SfMPGKt3c7mbV7ir/uS2YL9rWUvnHMO5f8O/ztmP3KHuchznGI8t
xjeatbrBgnxfsPa2qHE5j3vWfYubZc5+oo56NIHzT2QsRvVz9r+mlt6nnsT7
0gdpvnG2ytkfUeNpV9S+PpnEWSdTYyD+AcxLO7YawJlyz5E/iJrKW0BPtLY+
O885e5Tc+q1+DGcf/VhvBvf1CXer/sbucgrz6fRVvHTnrnXnqvEO9yLWvkWb
ye3P68yXZLVnEFvHHamOfg+1WNxE/BN8Y+ndQmdL6OtSnkvove5GPzt7DmdZ
Ro9H4JvN3W3nPpdz1q/IlWYk68XeibnExOAij53/MHXmwop+D8epqPGl/el3
veym52MT9qyfLb8Y/3zuYzF7V1zv2SzWXUSeziy29ju7CBMLiI0jfxFn28Ie
dL7fo8brDlgQE/9G7X04ErXfnaTzH3D2M+MV9OxL4mJxtbNDxMSaOPbA2Z9o
5JtMziRqyX8wQf84ajnfUFPxa46/5E+4r7ufMG7W0OON3P1MuFC/19AX9Wcz
+1nO3a3nTOu4wy30Q/PpxFXzmLMNUWNuA/4ZxDTfxHgmY61zwtlJxurtRHq0
FM13xLbT67PUVb2j6PZxv7OosZm70c913Urf9lP3CHekvTd0fevKu70N7ffs
6Tjr7/VYf27AhrjYzV60p3nM9bsNznNnu/Ad57yb8IkTsbWX/e4jT1oxliLJ
GLoZNe72Ele/9bPqT3H+h1HjT757+M9x/+JAHF9yFkqyNdSjGOPqhZgUc/r5
ngcZ/+rsGjHdu5jNmGRs6TPlENpV7PsC+/sFrXhZRK/Us2Ws9xN1MlCrm/6c
pu+rWVe1n33CPi8fJ7eaK1lvL2v9Rb91T3O5+5vc51Z6sYV+q+/HiK1HuwHf
UUzjW9zrYZiIsfifs7uMT+HfzFxr/kttne1v+vEj2pPcjX6e8Bn2cpv1DnAv
+7lH3dmjaPwz4jL+36Pxz5gznPlvj+31Se5DnJ2nhnJ2MFef9Pm/ljPpbPq5
xmmTjJW8ScbZU87+YV31+0/42cWZ9HX5BXq/D99frLEH/W7mhZz2RWc1kux9
j30GiEUPdy8Ww86yJxln150lT7K66qOYlV//jeAqPbqEXxZEWyLJeMpEnavw
o59R+w9nuQI7V9EXJ2e0s3nw9yt7uMY6B+h/HsdhXmeVnzCOb9D7O9zlCbhR
/25yHzdg4gy9Po1G954S3VF8x/DfYr2f2bfqp0qy2FPc0U3uULVvJHD5dJKN
77CfNEnmv4fmJLrjaFSzHj+fTf2Y72wHvdAedC+XYFF3pp/VGvLa2fKg0R4j
SfbZ8wA2ozCkfsuvn8v5gBqPYNPH93aZnaVzVjjJWBTD54l7+Wz4k3vW1/QB
7G98j1hDrPv5Gkc8VkkypvPBa4D1MnDnunudp6iz9PCXw1lZzhyGTa0hzjQW
l/q5imLxFH29i/YyfUiCU2l05+k4Vz16/HKS6f6hT8mpJ96UK98V3oEnnD2f
ZNzcZz2x+QR5YfasvYvFJ7mfB6yrnNRJdte6f93Zk0nxP09SMM9ET7y8/7fg
8zbsaaw6BZJsfoe6Gos5cVaIcWoYfBF/WvLzUftpmEyDLy9+9Tcb/Y5wrjB3
o5/pKoZyElOPcvFMIpYOxtIzf8gZtMf83HV6eMkEJ2JPPU3LXjOgE6cv05fM
mL6PLJlkP1u2VpLxmsNrPa1M3fSsm8F9RhR7wv7sykK+2GuZZFxWhbNyzhol
GZtZWUM/B/l1uEzHeoWJB+lRNvqVHT70c+py07P/NXXW4VJWXRSnwTtNS0iD
SAlSEkqDIB0S0t0pnQJSkhLSndLdIB3SEtIIUtIdAt9Z3/7Nc+8f+3lP7LNj
rfW+M4N3xnjgpPXMzko46xBh+qvOXhi/TzknLel+kD71LMjIfgRjD36K055Y
lVxvuZ3l8ZkeMxMvDpgImwD8ap4DbSQEr8/YUy+F6C8b2GTFV2ekuQPOrkfY
s0l7IXyzsf8NPGdnTefKMk8KhsJSfwtd2FlNZ7UY6++jPof/nOQvTZ684FIF
rAtTr7ipFGG6TAw/OvszGHUEZ2FYBH/5fkxMzaWzItENi0bk0V5yeJL+CmD6
fFmDmF/Dc0VnrSJMi/L9BN8v4TEl57SWCozT0EO/CNNiE7CpSJzU+BWk57YR
psWi9JIRfVRDB9JWSWcNiFuT84XB6ytq/Zqx/PVbX8VZSw8+ugfqOOtK/Crg
0REs1Hsx6sjIOBNx0oGhsBT+I+AgM7Up5w1nHyJMQyU4J62WizCtfA4HpeD+
G7ApA28VwUnzbOzLpLGmEaazsqzpvs/nrIrP4jdjLwf5NNb7ofLOWjDOybwl
1wrkb0zOXKyVB8daYCxu9PtWlcAxAxgVAU9hXDe69daXXOXotxJ9qb+6nCtG
TO3lgQfNpcvviSu/LOBUCm70OakTNbaiD/FWgP2pEaa5/qxLP9JpTfqohXVh
rQlYCttCrCmHfkN2WITpsj08i2/pppuzccQRRrXpvw5jaVS/hVSfWKqrIPtF
6E8+DZ31drYowvQ0MsJ+o64u+DQgRgnWizOP5p4jyT2mM51dyPmSxGwA3q3B
qITTRwNn9X2Gd2v2vwdj5WsOX9+Ct/QQ5rIR86bgKsyKwLU4/4G+uxL7J/Iq
5o8RpstyzJsRox9xWsDhIGeDGbdivTn1lOVcU/L8APbiRr+31oZeuoFxJdZa
w91w+OxBr/U4K5/K5ArfE+3Ykx57Rrf+pxBHe3pm6Pfd5tCntKjPkaMi7BlS
gzXVqPf6XViXfqozr8V+U/oaQAydk16krV+cLUcTHdmryfnO9DaEGtTf/AjT
6wi0IE1siLD7YRqxDjpbRu3bnW0DM2Gn30+VFvs4+zXCfsNLWpOO90SYzhbj
o7UGnKkLrt25jsd/N2caElPn2vGsquoz3fQF44FwLR6kM2kjjHtf5j2JXw+8
1FN/OBwCHv3BVPuKOSMiUn8/st6cPc0HMW4REam/Wc5mMxa2Kdx9lo/7bRAa
GQzmwnoBcRVveoTdA2PhtxUxBsONfrtnKFj9AvbT4Ei1z6SeQfQ8FQyGc176
mxTd1tajDeliFLXIrz1zfb5cAmcjWRtG/rasSSfS1hjqHcs5+UpjpyJMQxsj
THdj2BfecyNMR+r/9wjTn9a2s74Q/qUDaW+Fs0PkEEZhjQsLaUaa02/TTGI8
2dla9sT7BGdXI0xbe/GRb2/25CONTGSucU+wEmbdyDeOOFeIld/xWhWO+5BX
sfs6jfZzNsVnMXuRrw68dYWDKfC0kryrwHguOA2E1xlwLa1IJz+yNh3TeBMY
67OxPheHtbg1wu7V2WCr9cHMN8LRNHpbBsY/4TsbbvSbUfOoZTP5xsPLL9Q/
nh7mUf9Q+NX58DNGe9LR2ujW/0n4kM6WwLvOjGCuPvZRs3JL2/rtqvMRppWH
EaazP8FuAhwqnvQzkp4OgMtS+ltGbOUYjf8o5r3hqhfYbgSf3XAu7qXFw85u
RpjO1jk7TlzhuJx1/TbLGjBawbp+P+5ShOn+vwjT0zX85Sv9rKafiYwnsSf/
t5yp5jTXHv1Npoa15BkPJ+2d/ob77Nk5CcyF/RbwFK6bwG8jfKxHE/PAei4+
4v00ftNZm8H6Jvx2wIvin2HvTzjSuanEVo6wLs8x3kI9f7G+nfXZzGfio5h6
X6j3qQnB8WKEaVTfbc7hLLvHcBZn+v2eE9GttwfgImz/4KzOSZtHWBfeSd35
JB7DezecSZvSoj7b/e3sgrMXEaZFaXgJ+3vRiTSl10y9pz+ALWNtF7kXEE/n
pEePxzT9KMK0eoD9K3D+ln5eR5iGpL9bzmJ4jHdp8hA5ljOWLvUbBtLiNerb
h+9KcNDvCK3BZwe9nQcHYfAOv1XgdBzftZw9Am5aP+HsHrmuku+fCHvfKSzm
OS0OdTbMZ1o8CT87yav8Z+F6K5zJJ/x6cor5OnIppzQmDZ5GH2cYK84T5luY
ayzNSWfPGJ8l13PWz3P+EbHls409rT1k/RC9HQSfW+AqbvR9e+nyNnvC6A7X
o+yp3534X0QTHRxOI7i3L7O3CzzFm7S3nRr/Qhvy2w1P1/CR6XPke2cvncX3
mF4fRDdMIzzWo/B4HGHcHKSf2B6rVb9/kcljuvR6TGcxnX3iMW3eIId+GyuR
x3R5gXwvwFeYBj0WV3jdRB/6m7l/wewPcNL6fWfx3F5uj+nvY34zJoyffP6F
d90P0mcSfqvjDthqfAw/xfmCWHoWjnC2wGfauU+8E2AibE7Br+ZP0cY58HrA
3mHqvgl2wuYRvk/R3M9ubSFcPkJPjzHt+zyG/RPWdM7vsflFMBSWlcAij8ew
Fq/7wfYv8PXC0SPOvuK86osO9uJGv//wCu284GzIY9cX4JnYY3y+Js6liMi5
dOaJYVhk9Jj/GzQont6hN5k+XyaDO2lGeCXg2Rwf37/xfQeP1zj3Hl1Fo3b1
UNxjWvzUY70lIM4N/D5Qe06PafEZmJ5DH0nRgbT1kbP0Hour9+jRGAuvGNQa
E73LX9/zjov21U8s7oFUzgp47POf/m1E//6xEn3oeay/B42NNuOgd8WRzoSh
sBS/FeFYevyInIuc7UZDqj8xeAc81pf6EwcRcO8DGy8cJwAnzR+jN5k0lhmd
+Vn7Vc9iZ2t8Fv8z/J6ST2Pdw9JKVsZh7WRjPT75M1GD9BSfPeGYEozFjb63
LC3qXvLQQyzwFMafxrDeipErAJ+xwDP8OxEaxyGm4r1GA4nQcGKwy0VtPnrP
TI8lPfZ+oSy6lIbfo9v6aK4E60nRbAr6SInlR0M6o895edFTCubKXd5juvwC
niuim4LOahAnBpqKCQ4aS6Nfo7/k5JDOU4FXanwyOCvirI3H9FTZY3+PnAZ8
0hMjHutxme9xdsVjOtPZ1pz/iJg6l4f+lXsXz86FPsNb2CWgjtjkywJf4s2D
HsJcZmSeGVzFiQeuxbl60jNcsfxwJN+rzt5Sa4AcnxGjOHGkS2mxjLNvGGdn
PQv1fAmuBbh+CfbiRt+j/5xeCsJBQtZywF0F+CxMr2k5K59E5ArfE7nYkwZL
xrD+6xFHe9KlvrffzGP6k270ObIKmCdjTTXqvX5+1nPDR35q1358es1GDJ2T
XqSt75x1QhN52EvB+Xz0Vo4a1F9Lj+m1IlqQJnp57H5o4DENST963RSupeCi
INjpv11Ii0Wdfe+x/24hrUnHQz2ms7b4aC09Z9KAq9brRPEfwpkMxNT+Sae/
U84e+Ew3xcC4NFyLh0xoI4x7MeZfkUfclaSnEnBYDjw0z8y+YjaK0mcp1rOw
p3kZxlk9kfpr4qwpY2GbCowK4JONvQpg3Yq4itcQv+rwm50Y38BNC4/ptRD8
FqSP+tSuz7j6/KB/DyiPr7TYwuE10FlzZ41iGC490YZ0UYVaVNMXzPX5sh2c
VWatMf2WYU06kbaqUW91zslXGpvkMQ319pjuqrEvvJt77B5Q/4M9pj+t/ch6
a/iXDqTjzs5GkUMYhTUuLPTfy6Q5fc+iDuO6zrqzJ97139PmeUxbw/CRbxFi
dqC+2vhKLyXBSpgVJF8N4swl1n/OknjtOVWUvIq922F92WfPTsX8mnzVyNWe
fgfSc0NwagBvzcGpNLg3Yq8kvqVYa4hp3Ade66GJsBb7OxvAuBnr3zDvDUcN
6K0jeJTFtyncDPKY/lRLX/LVhBfh0sUT+d8tW1D/t/Cr8+FnjPakzX4xrNaJ
8CGdtYN3nanIXDgN99g9XJ/ehNkMcFvjMZ396rHvjtaCQ8WTfirT08/g3oH+
OhJbOariX4V5E/qUzvV9/tke0+h8alU90uJoZ0s8prMezsYTVzh2Yl3fzeoG
Rp1Zl43Ed6fH9DQff/lKP13ppzbjOuzJfwdnkjrdfeE1/dWlhu7kqQknr5z+
Ljq7xL3fE+z70aN67QN+veGjJ5poAdbN8RHvk/FryFoj1vuQrxZ1K/4U9n6F
o95w2IscYV1OY9yPeqaz/iPrTZk3xkcxL3rs+1PCQ88I3YtzqWE0GKj+QfQw
LYb1thr/OXA7GB9pcyy1d2V9FntD8G0N9/pst8DZTGebPaZF6aId+8Oopy08
6z39z1hH1sK5WxFP56THYx7T9FqPafVn9ufC+Q5q3+YxXUp/vznbR8/qfRQ5
OjGWLvWdM2mxGbgOwFd46bus+n5aN3wG0tsMcBbGv+P3AziNx7c7Z8eCm9Yn
OFsJP+ep+bWzS84ue+y5eMXZG59pcSL8DCKv8k+F6/5wJp/w68kk5vPBRHhL
Y9Kg9Cl9TGGsOOuZ92OusTQnnW1kPJVcm1ifwfm1xJ4GZtNZW8O68F0M3mPg
YjTcbPVEamgWvS0Dq3Fwuh0+Z+MzmLyqcV2UvZ/oVzpZAIczqGcufkPgaT4+
Mn2O3OVsi7MzHtPrphiG6VH6V89/Mt5Arws5L+396zFdHveYzvY7+9tj2lyE
r/r4y2O6nEm+zeyPBKPF4CXNSh/6LuIKMBN2S1lf5ewPZ688pr9L7I0Fv5Wc
k9akLelTWlvO/jjGv+CnOC+Jdc9pLp7fvZf1m05XEW8amAibSfC7GjymgslR
1tbQyx76Wwc2a/HVGWmuknsut3ZW0Wt7k/Fdx/4JeF7Pms6dZD4LDIVlbmLo
WX8avjZTxzHqOs5YeQ6A1zKw3ku94uacx3Q5I6wFZwm9htFr9raQfxvz2fCr
uXR2JoblvAv+2psLT9LfLkyfLy9Ty354Puvsice0KN8F+P4Oj/M5p7WFYLyY
HuJ6TYv3qPEscRbhp3N63jz3mBYPgsFy9HERHUhbR5zdJu5Vzu8Fr33Uup+x
/PX93MOsLQVj3QPXnb332Guv9CRN6j6aDraHqGM54xXE2QSGwlL4J4CDVdSm
nG30fS009AfnpNVTaGUjHByF+xNgcxzezoKT5uvYl0lj9z2ms5OsJfbb8/it
z+I/YG8D+TTWM0L6e8R4E/PHXM+Q/19ybmbtNDheA2Nxo+82nwPHZWB0ADyF
8dMY1lscr+U6Rb/n6Ev9/cO5Q8TU3jY0oLl0eYO48hsNr+JYutS/K7zx2Pek
U/JdaWl4F/vpvKa5eKxLP7+jl730I/uPtXtgKWz3sKYc+o53yGu6lP7Es/iW
bj44S+a1OPvQ1H5w0Fga1fe8bxFLde1m/wD9yeeOs1jO73Ov6SmR177n/Q/4
yOcWurqJljQf6vzmorPP+Y65zh8h5m3wfuqx+zaj00kmZ8X8hvdT9m+AsfI9
hC/xdgw9hLm8y1wYCVdhdgauxfk7+n5Pjx8YK2aE13R5ivkDYsQljnQpLXrd
3Oe18RPWH1LPSc7dJ887OBQ3+q79M3r5QH71+Iw+xV18r/EZ3Wu93uTsMzSn
XOF74gV7//9NgJjWf1qvxdGenkn6bv9nzvxe06I+Ryb22rP4MvpUjXqvL529
Rj+X0N019u/T10d8Fn2DXqSt5M7yoonX7F3l/Ft6C1CD+svmNb0mQAvSxNde
ux/Se+2efkKPsfgNAmn0Y6+9VqlWrcd2ltprv1VwCx1/i85y4qM1aSwaeApX
jXVNgX85zkiPsTmXxOkvl9+eW9KNsBXGHq9x/QidSRth3OOglRjEvwle6bnH
n4HDU3R1n33FzOiN1J+uH5HHw7oXv0dR9Peps8yMhe08Zzu437zo0wfmwjo7
cRUvA88HYfoOvP3EEjdZvabXaPArvaaHI9WeiXq87N0A4/icl/6yxTRcvkIb
b9BeAvxeMtfny1xwJr/ExFB+6TsROnmNTt9RdxJ8pbE6aKgIOk7KvvDO4rV7
QP1/g/60Vor1HPAvHUjH+ZxVQW/vo2g8GpqR5vQ7FakYp3FWiD3xrmd9C7RV
Hp9U6ColPtLIJ8xjoC1hJcyEp/IlI05zYu10dgGOFTM2ub91Gv3cWU6/xQz/
bkdLzquGp/ArnjOAU3owzgJOHnjNyN5H6CSCtQyYxkW9hrHuR71vDGuxhLOS
jD9j3ce8CBylp7c8YOzHNzPc6HdDslJLMfKlgBfhkp95Svyy0Ed2zoefMdqT
jsrGNA3WBgvpLBe860wC5uqjAjUrt7Rd2lkjr2mlm9d09r3XXstTwqHiST+J
6KkSuOSmvzzEVo4k+CdmLr1Vxucz8gi/cnAu7qXFqs7aeU1nhZ3V5EwyYmhd
v61SEIzysa7fc2nqNd0P8poeWuIvX+moAP18wjgVe/IfyJmLzl56TX+FOZ+G
PCngpALPzC/8puOvwL44eArXouBXBD6+QhNZwToLPuK9Ln4ZWMvIelH8SoOX
4tdj73s40rl0xFaOsC4bMC5OPQ1ZL8V6ZuaZ8FHMuMRKC476TZsy1Ke8Pai/
DDU1j2m9dYXHZvDwDT7SZnUwF96znM0E73L4SpvSoj6XtfLab+j09ZoWpeFc
7GssnUhT0pHe01fC8rAWzp2deDonPf7iNU1395pWK7HfHM4HUvsAr2lI+mvv
bDi8S5NVyJGXsXSp3/SRFltSXwV8pRH9bpB+36cgPqXprRE4CIPB+H0JTjXx
LcTZ6uCm9VrOusBxWnjKTz7VWM9psb6znn7TYm34KUNe5a8P1yXgTD7h15M6
zAuTSzmlsaLwXwwN1CVOT+bFmWsszUlnvRnXJ1cf1htxvjux5VOSve5w9D34
tgXvanBRFW76e02XzeBPv7HUEaxq4K9xB/yboIlXzhL47N5uxl5ZuBNv0l4p
amxIbPmVg6eW+Mj0OfInZ/2cTfGaXgfFNEzHyd/laeXsJ5/9e73+nV7/zbI1
56W9FV7T5Xiv6WyEswVe02Ybcqi36V7TZWPy9QVfYforOAmvduhDv8fVGcyq
gYPWf3A2xtlWr+lvNnvVwa8L58S77gfpU/dqJ/ZrMP4OP8XZQiw9Dys6a+W3
OLXI1xxMhE0d+NW8F9poAF5d2atK3eqlB9h0x1dnpLmEDtMcPuNSe3Xx7cH+
BK9psSdrOjeReRMwFJbn6GGb137TSz2OBNuG4Dsejrrj0wE/1TcM7MWNfouq
P9rpy9nJXPuy14/8A5g3hV/NpbPZMQ2L5eCvvebwJP39hOnz5RxqGQFeU52t
95oW5dsK38Hw2JJzWpOuhlK7ejjsNS2upMapxGmDn87p98s2eU2LvcG0AfqY
hQ6krbHOlhJ3HueHgddwah3BWP76TbLRrHUAY90DC53tgg/h3Ql/+Xahxg30
rN9U68zeIDAUluL3LByP5bw0+bm+r4WGZtKb8J5EX73hYBzcTwCb8fA2FZw0
78G+TBpb5TWdTWTte3c/dHfWzW/xV7PXi3wa6x6WVtYyDmtnHdcp5F9Bzr6s
TQbH+WAsbvR7aNJiN2ofB6YLwXh7TOvtELkm0a9w2AwWi8F9FDEVbwB7mv8I
DtPAYiW9ruLMSPgSPyfhSBqW9qTbW17T3B+sSz/S6Tz6mI/tZE1n9Dlvu9f0
NI+56j3tNV1ugWfxLd3sdnaZOMJoAf0vZCyN6jfOfiOWcgxhX3gtwmeZswPO
nnlNT3957bf0FtPrUmKMYX0082/5GwHpTGefcn4sMXVuG/0rd2unj594fk4D
u6nUMZJ8a+DrV7iVHsJcLme+ClzFyWy4Fud6T6vXP732PfTa78FE+CzmUa/p
chI5VhPjMHGkS2nxuLMTjNezvoZ6fgfXXVx/B3tx86fXdLkIXhbCnTg7w7r6
2+NsL+MlnNW56eQK3xOb2ZMeL8S0/m8ST3vS8ilnD7ymP+lGnyPPg/kc1lSj
cNnJ+lb42Ent2p9Cr+uIoXPSi7R1xdkbNLGNvXmc3wGHp6hBfT72ml7PogVp
IqbP7ofb4HSKnq+BxT4wWwQ+0uJBZzfYk9ak4yA6e46P1pZyZjGxtH49in+A
M1pfRtxZTn+DnA32m24OgfExuBYPK9BGGPdDzPeRR9wdoac/6OcUeGi+in3F
vOuN1N9R1tewp/lxxmu9kfq75+w+Y2G7EIx24bOOvaveSE0dId4d/C7B73pi
nICbR/CwB35308etKLWvJt5pfDdR07/kfxXTcInhM21IF+fhXTrYwlyfL1/A
2V+s/Uu/x1mTTqSti9R7iXPylcZS+UxDsXymu4vsC2/d57oH9PuhPp/pT2u6
77Uu/Yl/6UA6fusssc9yCKOwxveApTSn3+a5zvgfZ9F8tieMpdmsPtNWyGc+
8j1A3a+o7298pZcLYCXMdpPvMnGyEGuQXqf5u6t/yC2tzuGZOcRvMfeTbyIc
rQJv8bQZ7oVT+F57CE7HwP0uXB/B9yhrdzCNY/uM15toIqzFeG7tI5+NH7B+
gr1YcHSb3l6Dx0l85SNu9Dtdj6gljs/yXYWXK9T8iLrFnd9n3D7hfPgZ84ie
E8WyWj+Bj+fo7SlnzjLXa0J8n93D6km96fUhI68RBX2ms9TO3sGd8H6Ofv6i
J70vfwXPl1h7SY4L+J9nrveeei1vQx+ZfaZR5frOWQ2faTGJs1w+01l0Zyl8
Flc4vkF/+g2OD2D0lnVZInzL+ExP2YjzAQ3pt6be0ct7tPMB/9KcmeVsC/qT
9qIT4y3c6PcgVzv9rXF21G86FubCPq7PuLyHblJzn36ChmLCt7B+iI94T4Pf
HdbuogeN/wN/1a34aTmTGo5i8XoSkxxhXaZnrDOqJwPrEaxLgx9Rb1xiNnHW
2Gd4bHV2FixUQxIw8PM6ot9MyhXLeiuAj2pMCq9enj8foyHhrfVP2VMMxXqK
FvXZLruzTM6KoUVp+AX7IZ4Nz+FZ7+kTYq9Z85NbWlc8nZMev0NnhdBrQvJl
gfPS9FMSXUp/XzirQM9J0KZySGeJ0WU+tKh7OgJ8k4CFcEiG9uTjobeM4CyM
v/GZ3ztwSkG8aJzVmnDTekpn+X2m6RC9aT06e0moORda/AR+vORV/nToIR6c
feKLfD1JxTwbmITQmDSYBn2kZaw4XzGPy1xjaU46K8I4HbmKsp6R84WInR7M
MrBWkHXhmxO8k9JXErjRbytIQ7nZE0Z5uCZjT/168f8UTaShxsJwnRm9ZANL
aS+CGjOgDfkF4CkbPjJ9jizrrLizej7Ta8VYhmkN+lfP3/vsNWuu3lv57ZzO
S3udfabLmj7TWUWf/fuRtPk5OfR7ZA19pstM5CvGfiIwygle4l360Hf984FZ
UnDS+pfOqjnr7zP9NWUvjF9+zklTuh+kTz0L8rKfjHFy/BSnH7FWut7+cHbY
b3kUS5rMBSbCJhX8av412kgPXgXYUy/f0l9hsCmEr85Ic+ecPfXZs6kQvBbG
tF8Lnr9iTedqM/8UDIWlXocq87okjoNwXgT+i5L/O/LobAnOC+vy1CtuGrCX
EX50dhoYDQDPRvBZEt/MUebSWZtYhkUn/EtRj3iS/spi+nzZDO4qwrN+Z6Sn
z7Qo3+z4fgOP2TintRxgnJMeRvtMi13orT5xPsevHLX38ZkWK6OHvOijCTqQ
tqo760DcFpwvD14VqLUiY/nru9ZVWVM/+t0p3QOtffbvqI3JXRocm9J7FerI
yzhfOA4YCkvhPxUOvqQ25XzmLOA3DVXjnPRax2daKQIHNeC+FtjUhLf64KR5
YfZl0tgPPtNZbdZ2uDznufcVvyt7X5NPYz0j6jrrzrgo8x5c65G/MzmLsVYX
HFuCsbjp7TMtVoKjyoxbg/GwWNbbKHLVod9K+LZx1pZxFWIqXkl40LwUY3HT
l/PqJz3c6N9AfqTGnvQh3sqy/5vPNDeGdelHOm1BHy2xQax1AUth+y1rzck9
2We67AfP4lu6GeJsDnGEUSv6b81YGtV3WtsTS3WVY78SOMino7OfnW30mZ6m
++x3AdqCTwdiVGO9KvOg4zuL33Smsxs4L//qxJWOeoHRM/09kLO//IZ3L/bb
wIXydYMv8fYdeghz2Yn5D+AqzNrAtTiXVqSrYsSeSF7FHOczXdZh3pUYo4nT
HQ7HO5vAuCfr3ainNud+AN/BYC9u9D3J3vQyBIyH+iK11pua1Pcw1tpxVnsN
yRW+J/qyJw0uiGX9L0ED2pMuJzlbTZ/Soj5HzvDZM6QZa6pR7/UHsS79NGXe
kv0f6GssMXROepG25jrbjiYGsNeC8wPpaRI16DdN1vlMr1PRgjSx32f3w1Kf
/f+Kwv8fpNZgFdZyGzDTd7GlrxHEWU9saXSks0X4tQXLP32mv02MTzEfyZmO
YDcKvrM6/ZVGuy94dl3wm4ZGgfcv8C5OOnNuFPFUVwfqHAaPY+lvDHxOAptV
PtOT8FHM5b5ILY7jXDf2NB/PuDvjHpwfDYZLyPMbuYbC0RDmPxBzLPGWge9s
uO5JLRPgSd/tDWv3V+oO3wMrnc2nR/X6CHxPowdpYQZxdFZ63R3LatwHH9Px
mQqH/ViTNqSnWdQ1G55P+ExDmm9lfyYxpLfrPtPTAZ9pMLyvuvUd5dX4am0z
a0dZ34AupA9peoez8z7T00K4nQum81jfzZ7Gi53tYW8Y2CzgOpz+hEVf1kdw
Nk7AfX5wljZgfYmPOXA2l7GwfQi+ZZwWG6PRkeRV/gVgK4wTur3XbpzIXVf4
TDPj6esvZ9tY095ycBKeW+BqDZgtY/+gz3Q1ljVxL+3+4ewI49Vwc9xnullJ
/PGMJ+B3AI6W0ts2+JxIDPmMI+8yYhxiPg9e5qIHcXYSLlX7GdbX+SKfN2vB
/Wos093fPtPoJs4dc3YXHSyjvqXsz4gSW9eZ1CBOdzr7PQrP8pd+ptPTOTDd
Sn9a++Azjd7wWS3i6zfwPkYNB6hDmEtPe1U7fd732T0gXV5w9gIsdsDtNjDV
2Os33TwmjrS6iPFi4u6kfvWxi+sCxgs5ozgeYjVx137oT3Gu4LMDXBRPz8yX
zuIHTIv7wH45PB7EbtDr32CxH66OgcdB/P9xdtjZTea6P3UfPEQbh1mXFqWd
I6xpbyX47idHWK+3GR/G5w7rR6nrOrVJX9KTnk+r2ZdfTNffLeK8i2U9vHf2
KX/bLMwuRtHIpSgYH6fHtfRykjzSrj7PPUE74vIv+DvN/r/O4vhNr1rbzPpp
MNnEmWfEOEG+deQ5QT9nOSddJ/ebLqP5TWdv4VX4inNxr+9Lf+Q3/UlzL53F
9xvv0mFYj+pXfT/32fs/1aGY15z957PvbV0Ch63UeBY81NtdMBR+PjAM43eV
uvYQZzdz9budGvq7M1PRqOqPoPbjxD9GLYr1//sK7sThfnjX/Bba+AM9SIvS
oXR2k3Fsv+nmLnOtR0cXMfw2P0ysm2hF/rH8Nr5F/PfkvE4c8XAD/yOciQZH
WhcH9+DyIlxcYF3fS7pHv/fo+TX4CbMH+EkLsdz9mdpZKmfJYlsdyfheU1q/
6ew8XArjo/R6B20olvQrnqTRJ5g+U/pZO8PaTmqUXh6jq9P0EK5XekrgLLvf
MBK+qZ3l85tGU/itn7jUJu08I99z+H+BzvS33W8Zv4XvC2AV1q+we4XPO2dJ
3ZkSftNfZr/tXQI/6SiD3+4BD/rMxPddXoPtG/T4FhyFpzhL4PDNHrDn4TVy
/Yfm/o95bOP+A1qITq/R+Hwu/M6CU1ww0PPnE7/pTDUXp+5pzjZwD+j8P8SL
jm9KdBnDH6nVmOw9g+fnaDQmOtV6kM9xEfSv73CkgaM41JucnNJIHPaEdchv
MV+BVUJwjMfzxE/sz/z2fuU1WEbgJ53li22Y5iV/BPd3Zp4TfnzTE1e5pCXx
nM5dv0LT8n1CTvVQFF4DxHhKr8+puyr6y899kY44mcC7OFrVPREb7eZwVhYt
v6JfH5p5TFx9xlCeEBjFp1ad0Vha1N/YJmH8sbPcznY6Dc139ruzBnBf0tk9
6cLZcb/pSVgJs0z0KcwSc08o5kZnp9CK4tQnVip4jwXWyeA1BnqTfqTT5Oyl
BJsU4J4OnFKgr5SYzn5JL9K/+injesjqLFvA8hbALyZ1fAI3ReA1NZqS7gpz
TUv+fOSMw5r2EsJFAnIrfnW//R299hKBTQb0lJpzhRinAof09KX+cnIuMee0
J91Vi214VYG/bHArbqRRabu3s17g3d5v2qrGnj5rlsLXz5pilEErWpfefOgm
K2f0Haq6ftOx9KG/RfyCer/2m+6Lw604li7LOWtGfNWaHYxyMM5K7dnIoVoC
7CcEP+XK46wSV83FaS4wSszaF3Cu9STM/3T20G/6K8uzMUfA6q1NzfnAU7h+
CU75wVD4NaSOROQrCF/iLTl6CPORl3l6MElHfTqr54ziSqPKo79bq+M3zVWD
I+1/AzZlyaN80lMhxqkZS5c18f0GDIsStwhjXaWdtPRamF7KgXF6fL6Gu3rw
XJ5ehWUtzn1F3vA9UYwc0nXH2NZ/O7/pKBs1qb+uYC3N6XNkI79p9TPW5NeE
c6VZy0KvNeh9hN903MFv2hIvvahZdWSCp5Kczxol3tfUUZv+evhNx9Jlc2c/
+u3+LwAvOcCnLPiq/y5++/tbaUq6lxZbRxlXdtbGb9+dyQl+v/pNQ30YT2Ke
B/9K4FUF7h858wRMr7XdtY6zrgHTZRUw/g5cxEM+zlUhlmrJTZ3l4a46mFWD
5zrg8QN9CRPF7BQF6xqcK8heDXD4jrw14b8WOH1O3x3gqBrz5uxXA9fqmOJ1
BN+m8P8VtdSCG/09p3TcgljqR/e27mu9n2nJmnr9mXgj0YD4l8Y6U7PqHRXb
sB4OHw3xqY8mirMmXUlDTahL9elv/Sf4TTea92e/MTGksYV+06hqKRNlX3jr
71K74qu1vqyNY70XupA+pMWBzmb4TU+t4bY5OLRgfQh7Grd1NpQ9YSJsWnGt
QK5fyKf1ipzV87Ccs2YB60t8NIOz5ozX+u3vLqRfr/PLFDCNKm9lcncEW2G8
Ft/JftOm9NCOHnuC93dw0wk+2uH3PbXWgc9OcCpdVWdN96G0O8bZWMZd4Wa8
33TThfg1GdfC72c46kBvA+CzNjHkU4O8HYkxinkLeGlOH+pnIlzq898U1lVH
+BmjWqTl32JbnwvApQ/nxMlyeOlIfR3YbxQltq6NqUGchv92MMyz/KWfhvSk
9+X9saas7fabRhdRn+rSc7MJfv1YEwd6pktPw5zN85smpxNHupzpbDNYDGR/
AJhqrPeF0sE64kirbYineVt6aEkfP3Ftxbg1ZxTnGLE+dZorjv4UYy4+A8FF
8Wq6vS7OOgdMi8PBvhM8jsQWgbX4GI4musNHN3zkv9jZaGdLmOv+lLbXoI3R
rEuL0s5Y1rQn3bUn9nB/pF6XMh6NzzLWx1HXQmqTtlb57bnTlf2x8PAjPByI
bT3swk9/ExC+B8bTz+woGKv+1cSexFU6lnb1GW6937QzgDzibzL7K5wd8pte
tdaX9clg0oczG4kxgRp6kEfznuTROentit90ucdvOtsBr2vg/Bj1HgELaW6L
szPwPtMfqUfxH/672pnsK+Z8Zzv99jchs8GhPzVOBaMV9KXPNdLcCWIN5sw8
6hpKnCHM9Tqh97p6v1zCaa4+Gm3orJSzRgHDYAV51tGXMPsN7sThCHjX/De0
MQY9SIvSoXS2hPFBv+lmOXOt7+XsPuajmWu8FP8DjH8j/i5yLiTOHnLKZyxn
9sDRIjhYCZez4GIm63+wt5U94baN6xx4XIUWVMd+8vwT2+q47Le/ZbnpN52J
101+09Q4el2GNhRrEjwJ0/WYPl+eZG0KayvBfzzx9HlgI/l/owbp6ayzJ+xN
x/et3zR6lRiHqW0afhvwU63SpnSm/3a3g7Gu88Boiz9Sv7PAST6/O7voLF7A
9HefvTB++nvHO367B3Q/SJ/67L2d/TmM55LvMryKs2kuZn9nAwKWaz75DoC5
sF+Ir+Z76XUPvQm/qWB4GAyE299+01k8/luS6m7grr24B3R+MfH24nvNb1rc
54/U6n7mSdyZL5zlCpg2pO8b9HmXvo9y1Tx9wHJ/FLB6r1Dzcvg5CNan4Wcr
WJ0DR2l1FVrR58IHfvs7gG1geRQ/6SxGHMP0TZQ61sDTCWLI9zZxlessPN/S
+YBp+gR4nqSH2AHj9RRrwvtP6j0NJtLff2CvWDfBRHjHBatl9CvtPnXmD1j+
rfR7As2sI+4j8pwGozPUepaxtKj/nnKB8SVnr6QV8hwi7jYw05nHxJOeLoPZ
RWJId/pv2juY93b1TUIr4jEdXF5HDwfA+jK8Sh9/o5/drF1mLmyugvstcNJ8
L/vXOPuOPlST9D/D5fvR2UDyvsdP+a8zFjf6N2vxeoPehUH0gF1vkv8tOQ+x
9g/4PAXT8+C0nTpvU+tdchwlvs5FC9j4OjiIa/33Wvk+J855zimOdJcqjuGV
OGDPJHErTenekEal7RRunNJZfu4zaStpwOq/Bj7yPYm/+NR7/Ues30NHf6Kf
h9SVJmA6lj70784v6S1mwHQfF27FsXQZcPZZwOJLN0/A6CnjR+joMTke0MtT
MH2GFl87SxgwTl+z9gKMzjN/Cd8v0J3mv7oza9DfcmcrnB0KWPwANcYAT+Eq
XMI4FUGvGQJWx1/k+wBfN9Cm9BDm4w3z22ByizhfE+sd2vuYZ1k8OEsKR/+h
xfdwdJ1879HKB/JqLF2KZ+HoA+PY/DeXWPAUi2eOdBqDM8/oXRgEmT9H+zHR
fyhga8IyJed0Plog8p6IQw5ptVAc61/Pcy+1qCb9t58Czj5xFsHnyIz0Lq61
Jr9POefB7yF9JwtY7xXRcW60lR5M41KH7psMxI1Ax+F4MalDNehvIAqjY+ky
S8Det8VkPwb1CFM/NT6kzvjoXboXbsJI/74sXSZy9jnrz8Hv+4BxX5RxHeaJ
OCMdC6/EcK9n1Exnm52tdXYM7aYCW2GcHA2IB+ksCedV0yvukfjU9gKdCbOk
aCEVvX4ZMF7Vs2LmDURirevH5EnOegr8ojGOzvkA+gmS5wtyBcE2wPwdtXxM
vDwBwzczeMeglpRwUyhgOk4L31+BWQ56zUaP6rU7+NYNmAbEVUbiKIY0WiuO
YV0BPjLgk44ccVlLj4Y+pa7M5K6FbjQvwX4mYkhjrQOm0UoB0114X3gXDNg9
kJG1YqzVYP1rdCF9SIulA/Y54nP6TQiWwjQr6+XY0zins2/ZC4FNdq7x6U9Y
xGE9AWfPBExrW+hLfHwGZ1kYC9tu4Kvn5mFnN8mp3NJyIbAVxs0D9jqrf1/K
FzDNSC/6dwC9F52HprSXF5yEZ3G4KghmedivHDBdfcyaXs+k3WrOqjMuADf6
t4BC+OQjr8Yp8asER7nprSR9f0IM+SQjbx5iVGGeFV6yUGchai1G7fUCppPC
gchnTCFw7xrHdNcqYBotyrnvnHWKooMa9KT9jFFi6yrdSCe1yfNNFJ7lL/1k
oKcGYFqC/rQ2JGAabUMcxUhHD9+RuxJ9C3PpqbyzFuT8IWD3gHTZ2FlfsBAm
pcjxGePxAdNNj4BpRLHKEU9jaacM9auPslyzM86Bv+L8Qqx/A/Y8PE6M5viU
hhvFe+TsT2enA6bFCmCfFx4rY23oVXzIpyJcfQcelfFv66yqs3bMdX/qPtD9
kI89rUuLX8JdVfbC77sqkiOs1w6Mq+LTkfUa1NU6Cg+65gbThmDcAzyko1/i
WA8/OVsZsPc2wqwJeAjTplEwrkmPheilNlqQdvUZrmfAtFOSfD3Io/3///ta
wPSqtWKs1wWTopzpTYxa5CtMHs2/Io/OSddzA6bLoQHT2UB47UaP4l7/LWRs
wPQnzfVzNgXepcOwHstE6bsx+4rZ0tmgAP/eDQ4lqLE+eHSmr5XgN4FYYfxU
07fEU5xyrKmnLvSpZ+lZZ084q3P92etMnpbE0H3QFe7EYUV417x9wLQhjUgP
0qJ0KJ21YzwyYLrpxFzrwzg7nHlV5hp3wP9nxu2J/xM5WxNnKDnlU50zQ+Go
DRx0oe8mcNGY9THsdYW/cQH7N4imYNYVP2nhnrO4QbunV8axOuY4G+1sScB0
Jl77BExTNei1I7EVqw48SaM9MX2+nMhaPdZ07+m16Qvi6fOANCoNrXM2mfFU
Z+vBSPgucrYjYBqdB4ejqa0BMXoRU7VKm9KZ3r8NZDwQvhuDVVi/wq4/PoOd
zXL2R8D0t4q9puAnHJcF7B7Q/SB96j7/kf1mjJuTbw68ijN/0PT4lDzKJw3+
AubCvjW+mg+jV3E+jfjT4XU0GIxwtiBgOlPNh6k7hssV09knQTvflnjD8NXf
lLRjHNbqCOYjmHcA/xGMe8PXJGoYQx2L4WgU9c6l5k6sjQTryfAj3JaD5Vji
SIsTib2aPgeAZdhPOjsSxzDdThztdYOnCcSQ71Liirup8Pybs30B07R8e+Kv
Wg7C6yTWetFrH+q+EDD97aTn34izArwPg1VH+pV2Nzg7Sf7+cKi80kwP4q4l
z2QwmkKtUxlLi3o/OJPxbGdbqU/165l5G+6PwFFD6l4JVsJsBX0KM32uGUjM
dEG79+MFLc4tYi2E95/Beg68Sh/Sm/QzhLU5zHfC/xjwGc18GPvzOfs7fagf
3QefutxeZ76g5d2F3wjqWAA3B+B1ERhLd3u5LiH/DnKOYm0xuG8AU/UubUlX
G9mbDjbKMY74OreH8UJwWEpf6m8T52ZwTnvS3d04htf5gN3fs8BZ3Eij0nYs
7k3h/TJg2rrInj5fHsV3Imt6Lh5HK1qX3qSjX1nTGX0W+CdgOpY+9Nq3hXr3
B0z3h+FWHEuXp5w9IL60th6MNjBW7Mnsr6GWSexPAz/l2ubsnLP8rqdqzqoG
7XPMJvDZAg7y3QweWtPzMODss6DF2IouVO/f1Jze7X0dNJ0K0+1wHAv87lDH
dPIdAX/xsBvuxOFczmnvd/DeCW/7wUnr0t6lgH33Q38Pr+9sKM5l9vYEInWn
2LujrO8m1x72r4LvQ2cRQct5gbxL6G8vnN0ImL43wosw/pP5Jvb2U+9p1oTl
NWLsI478lqEHzaXruHENuxcB05bet98FuyOsXXf2HtyPoJNVjFfjcyJg7xWO
o48TgUhtrmMubYkX6fswdejZkyBoWn8VMF0dp4795FZefY6NHjQdHyPnGnB4
CC4HwEpnpDm9lp5lbyO+Z8BoMz5/OXvG3ib2UgdNQ7GDhrXOn+TsFmIWcHsF
ndVwVgqdZnFWx9n3zroFLf42ckhz58H7CnrYQw2KJ33vQANhPs4zvwQ2FxlL
b6+Z/87aLtYvEfsKc13fML6KJv6Dj/X0dRU/1SN8owUjNXcdHq6ipWvU8pL8
On+fePvgSj7vuP4NnqnAVBrQ+4+b5HxLff/AnXQp/en9Zhz8/kErt9CBtJM+
rmEUP2j8CePnzj44SxY0vUrD0tsRatTrmDR6j3rvk+cumsoRNC0mDJoG77Ev
HdzB7zo53tNHyqDpMib9qU/pRZp8QI6TjFWnnmlPGaveYNB8pT99Ji4UNLzS
kPMoeR+hzcfOuri9zs5qBu3Z4XGWkfePj9HpE3T1lJgFiavnZRF0eo465KPX
+Ti8z39MrjPo72UgEusXzC/D22tMmL1CG5dYuwFW1+H5CjrSOHHQzv+HVpIG
bfwWn4+Dtv4en7CmEsLRKzD9KGgYv6aeREHT3Hv8xU2KoGlaGHrAW+8nHoOT
9j5Qb3R8pbmica3n7EHjOjp6jMlceoyLDqXHNDwz4vCe6T71ecmtfMndOG/Q
NCrfu+g8Nvq5w5n0xIjDe7C0zio6a+WsgrMvmFeg9uTE1Hv6L9FlkGdSAF2m
RgeKL+wi0E0mZ8WCxsE7sPdQsxedSUOF6eUx+PnRcoCxDw024plYmhoC3KMP
wT+CmN8Rt6+zfs6m4K/7IhQ0nYlrcZAkaNqQFrKzlgCukoOBuP88aBqRvWZN
MRUva9Dm0l5OZ3mC1qtwSw/X4ly5cuGnnEkYJ8U/N+MkaPYNelZsvQ5kBo8g
OcXBe55LH8NNfnSZkmt0sM0E9uKrAHxGwyc52GWAw084HwN/zWPCUxo0I9P7
o6+c5XNWJWj6034c9tOgjdjUHuZWefSsSI99xFo6zsWlpnzEjIdfOmqvHjQt
SlvFndULmv4KwX2GYKQGxVsOePOAg9Z7O2vgrKGz5s7KOfuWfeH1KRhnc1Ym
aM9GaasWez56kk9puChHLuUMsPYZ9dV31tPZEme/OdvnrGzQNJeDOCHyfYEG
pAXpRj714tp73HZgnZN6P8cSsSaTxsoHTTu5WFPMCsyTMNdYmpNeKwVN9zmo
KTc+qqEyPnlZ/5h5MtbygGlRsBc3ek8uLZYAr8xci4NxfvhNgeWD85L4Cjdp
S68rtem1HL0WIId02Suu4dgMDWgvFTwVJsaX5JOm7/F6LY3pedI4aM8J1a73
V0WwDKzpfVjHoGnua+JJh+nx09rAoGmoBTmlQ2lfWpRmOhNLGBWj/+KMy1BD
adY+BTOtf+OsibMxQdPfD+BUFQ2UACthlpUzilOKNWE4ytnooOnul6C9f+zu
7LCzFc5WBk1bZcFSMbKRuyIayE1faek/B1zojDQkXZUnbxZqKA8e34J9VWrX
PCf75TnbEv7KErcemtdcupT+2jgb62yZs6XO2rJeBW46BE1z8s/DnvCtC/Yt
4Ej564NdA671wb4EuIWfCyXpqTqxpaMazKWzX+Na3T/CtfakwbzUVRnOpMXa
mN4fdXXW3tnwoN3PdeHke3xrgvf31K79mUHT2SBiKFb4Pdf3rNWgjk7g3Z74
0pBeBxsT/yvOS5fSlfShZ1MvZxPJJ+zqgUt9xoo7Mmj3QyeuyrkurmEwA+xK
gl8jtKC8r5xddHaJ9YZg24T9MvArbMbB8RjW5CM9NnXWOmi6FM/l4DTMQTPm
LcGpBby1Bw/Ny7Mv7et+GM9c738GB02PrVhTrp+Yt2FeibH0N9TZMMbtyDmQ
PG3gvy3Y9QDXJvTRP2gaaYePsJSGq9Nfa/I2gJf69NKBfsTdKHjoEwVvxfkZ
v17oUzrtjK/0MStoehoE3t3AvDs1qtYRzhYETaPSsHRSi3Ftzg0m1iBiaC38
ObU7a+2JNZx6FwdNQ6PhV6+F0twkZ6vJLbx6Mh5PrPrg0BPspgZN073AqDfW
EDz0TG+MTyPmWp/rbIez7c7WB+294VRi9oOfLeCj3pYHTSuHgqbvH+FY/gOc
TWPclPmv3Au6J4bAo7TQnHPae+DspLNT9C+t7w+a1n+Igq20Nxsd/MTa/KBp
Tngq/hz2wlqcR84hrIublpyVT1v8hOMEMG5HvGFwsyhoGuoNL8L4V+Z92BOn
HYg5hB4nR8F+JH4d4V1z6W8ZfY5DA9qTNscwD7/OjWVtJnxsdrYraJpcSG7V
0J4+9Domreh1bm/QdHYyrnGms7+QU5o8S8ytQdPWePZHEHsBaz2IrefW70F7
dun+1/2ZG1yEz0R0sCFoWhJ+e5ztZr83+AmXKeAk/+nONrK3Bl/t9yOONLKe
uAeCphFpJV7IvY9x1/vEGUCsdfSrvufCy1Di9yHvQDAN4zKD+WzwmMVYutrG
fDBrP7E+m9hzmeu6nbH0J43upLbwvTUOjJfDzZ5gpM4Wgr3ODuP8VjiaBb6r
4GI4/Mwn71DObQSDTfSv3h666zr6nkJe5ZQWl1GT6lnCnrT4G/PRnFecM5xb
SL3yGQMXl4Omy93U+EfQtLiSerW2gjzq/2nQ9HcuaBpbyf5BalpOnt3E1eeE
a0HT9H50cD1oWpFmVpNjImPhoOfKBsbC4098pYO1QcNkLbisZX0ytd8K2nvD
OE5jcZ2lDRl26zm3Hk7D8TfAs/R43NkJZwlD9nr/2tldZ0edHaO+Ncx3wN88
6jvt7BG8il/db9KTdLUNO4cuZLNZWwRWC6n7EHgq/nnOLwVbYbeTPeW9RJ5d
rM9nfg6OtlLzETDeRry/qHEX/uLmatA0vZZe14BFGLMw7sfxl680541n+noC
19pbAteaS2sXqU+5/gmaVg7B1yrq28eZv51dcfYmaNqU73L8D4LBMs7cJsYh
sLsZNM3qtUF60v2n2jaD8RViKse7oOlS3D0MmuakyxvOPhB/NVyfoG/1v5Kc
h8FpLXs3OH+AWHr2bQC7k8S4Rc0xQ5ZXftKgNPZv0DS7hrjKGxGy11rVl8qN
UzsryFndF6fp8Sx9XkAbO+HjDHt76H033D8LmkbOoQmtBUJ2bz9jLu09D9o9
cAnc9Dw5A+fK9QK/G/R9kBrOU8dF5qpnO+v/117A/l1e/0avfE+pZRd5LsGN
NCk9PQCrh6z/F4zU61V6Ow6Gx+BXfvvgRHNp6x9qVZ2Z4xlGftd39JDt3cTE
Uwy39tZdE4dMi9o/xL5ivifufbgVx3ecxQoZx7fR0B3sKDyrVsV9g45uk0/x
Pg6ZLv+ln3v08y9nVYNqjRayZ40nZJh84Px1YqlG6TNLyHgNOvs8ZM+1RCGr
9QG13yfPCXqWNj8JWUzlSU4u5fkTXz1X/wW7J/Cnc+pdOs3nLC9nveAsvBVH
mn2MtlTXsyia09pLdHUBbt+C2XPWQyHT0Yso/vFDNle9N8DpJTGkwbPUqDpe
sad1YfEaLtRvspDheJm18PM/dsg4FDdJQ5H6+4/6PgoZjsI0fcje33wEl/+h
RfXsBUvVcIn4QTh6Bofv0FWpeIbvZyHjJSU6ld2Eq3bO2jsbDl83wCAdNagW
9ZQnZNpK4Cx7yPCKRU/qrXTItJIV/hVbOhJ/KeBTfsJCz6j8rKdEB9KD1jOG
7Jnlof944BKX93vxqOdjcL7N/RKTey1JyO43D3EegmkE8VT/S/BLS59fUUty
7otBzlo4axkyzQlDYSn+hbOfXlKDwWesaS8ENtm4B76kRy81PUJ/Wbmn/qPm
t/D4nP0XaFLjXPSUhDqjwWEqcsQEj9wh01YCalCfOUOm0cTkzELehOg2ERgL
h7hgkBeMVbPP2afUmZQaMoBlBHm1Ls01dhiVcuP+7pqJfr3wmgbMdE8kpqZk
aC45faifAmCamrnOFWKekv6jM4/NfuOQ6a8M9X0BZgnBQlyrp8oh03FResiI
bwX8FT8GtcQFk7RYGvpQHGm5CjHSg4X61P0pvIoROxO19XPW11lPZ/Wc1SdO
HjDICFaZ0Msn4CANfuusPBwodmZnOegrIZxKI9KbNCotiocAXGteimsW/Mpw
Lin9JyF+JvoQ3t+F7H2C/HW/fxMyTWVnTZgUBpfPqSkh45xR6s4JtmXgSHkT
s6Y9abYidQiPSqx9zDw3scuSOwHz7GD/NTwVYZ6BM1/Qn86Vc9aM2hKRtz9a
beRsejzjZ3M801UhehcH1eEkP7yHn1nhtdJw3CjKGen2K2qrzTU9NfbDvwk+
hcGyEFhqLp22AYsmYN/UWauQabUifjU5l44civc9eaTxEs6Kw62u0l4x9oqA
VTF4137VkOk6H/2p92oh01wJ4iwI2WvFiJDpSf2XgqvK1Kz4GYldgvMlwb8c
/IV1Ka02YqxYEZzNQN/qv0yUHjIRQ7G+pe864JwPTqpSd376KEus7JwR/+XB
qxZY6kw7+m8CR8qbC8zLk6sI+SqyLp3lpu+K1FaWHqUFaaJGlJrag4+wqRuy
+6wGfsKoAZhprWMUDqrSz3fw3pm9Avh+Q17ppLWzn0KmF+HyA30qbn1wFFd5
6bcF/bUkdmH8CzFXzq7EqgMu2chZG19h2dzZjyG714RlW+LrjHTZjd7rMhdm
bai3Dth+Dwb1qVfjhs56E78cHNajD/l1AFfhNM/ZfGc7OVuS8/3jRd7rxTiv
OnpwrQfneg40Ao8KYNKcnsrRU2X6GgDezcC+GfMO1FIdboRfJ+XmzI/E/Bbs
9Uzo72wq5zVuAj7CpiLnprHXBV5qUV8FuK6Iv8ZDwbYtmKrH7iH7DKH3bPpc
oToGOpsRMq2pxpEhew5Ocdez8QxXcVkVPHuBeW9w7cPZGpyXSZujnI1mHK63
C/PO+AkX6XSIszngs5E+fwZHxZb2pOHaxKjFfDC9Kob00w3fbvTcHTyG4NOD
tbrkGEBOcd+T/erk7MDaBNbPO9vubAfxx5GrN5g0wL8+81/ZEz56XgrHEYyH
ganwGePsN67qaSx6EP594bcVvbanrhH01Ybe2hGzLWelHemkETGk+R/pVxod
RLxZjKUB6XA26z9Ryxjwbsm6fDeETKfCrykx+1P3D2CiWnQfDgUrYf4L+Aib
iewNoYeh1D4MzCbhp5pnwJFq3eJsJrWq5uZwJc3+jM9M6hxP3h74ziTWYvzD
+tS1M2udmP8Mxh3IMZBauoCJzq2F48nO5tLvDvrsTv5uzKWV5VzD87FgNYfz
0tYEzvUAg9VgNRE8JoHhRHyVfw3reuZJWwtYnwSWup9OwdsiZwvp76CzQ87+
wb8PvfSD37D+dNXzYD3jqVh/NDAE/tTDJriaQX0r6Wc+3A4HuyXgPAheBlLT
QnDfCpezWR9J7VPpYz05dHazs2PgsJZzgzn7E/hqvALsx4PJdOqdi88QxkPh
cgI4r4KvZXCmGneB8wLqXUg9m4m5h3oXY6PoeSRz7W3Bfyb5hoGT/PQ82Bcy
rS1l/ht7o0ORelqGHcBvKTUuo9cV+Kn/beC6At6X4z+GM+rzDzhT36tZ2wKm
4bPj8dH+EXyOMl/DdRLjVfgKS71m6h5vA0/rnB0HQ+H5O3XOoda99Csc3jq7
4uxqyF6TpqABxZlMLHEqbUiTp+FhMzH2gvuf+G0i33zyb6bPM3ApfnY7e+Zy
nXTX0EeWT3PlV56T1KBaz4HPfnhaSvyLIXsfso2+toOhMDnMXJrbgQZ2Mv6d
8XxqOuvsibNL7O2ivj3govv7ATUtg9uD9CssHuG7m9520Wc4xl6w/ZNYG8Fr
L/tbqUEY3QyZfg4TezM17qfvA4x1vc54H7is4JzO32L8B/gJo7/YO0gP2pPG
bnPVfBXnVjK/w95Rci7j/AGuN9iTHvWcWM38CPm2hSJf1y+E7HX+OL5rGUtf
J+D7JDo4xXgDPf5Nnw/B8E9weQxOx4j1L1fFuwfPF8h/OQq3p4khrV6Di33w
cAYutoLdWWpVj7/S1zP2pBnpULq5S+/H8FGvz7n+BQ5H8btDXTs5/4qr4l2h
1t3Ue5l1XV8zvorfHtY1fkMuxX1BX//he43+/qbXa6wfgMPr7On6Pspc2EeL
bz56LfvAnuY3WZOmXpL3InsH2btNr7HiW07FfBcyfcaIbzE0/gPfw8zD61qL
iV/0+BZTuD+FlzuhSP3GiW/YSgO6X6WTh+ggrIu78PMv63Hj2/i+s3jxbS12
fIt7F58T7CumnlUn6fUlOEtL0uEj6npCbVo7w/wZGnhO/c/wfUSN0uL72A4f
Z9diW9ywdl5G0cg18PsP3t+gCc3fwuk7cH4PX2E+o4GfcHxNvEvwpb0P9Cwc
hYFiXyGuuIoOD9qLBUbi5jb8xgFLYXqLPZ0TrsLvI3f9H3qhCNM=
        
        "]]]}, {}, {}, {}, {}},
    VertexColors->CompressedData["
1:eJx0vXk01d/793+UsUyhSKYyFkkZkxzFG5krIZmSkCRjyayQSiXEKRIhMhSS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     "]], GraphicsComplexBox[CompressedData["
1:eJx1nXm8H9P9/69d0VQpHfu1xVq9tjCWOrbWoPYlY0sykchIYpJJRjLxYfJh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    
    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      {GrayLevel[1], Opacity[0.3], 
       LineBox[{4861, 4862, 4864, 4865, 4867, 4884, 4885, 4902, 4903, 4921, 
        4922, 4920, 4918, 4917, 4936, 5431, 5432, 5421, 5433, 5434, 5415, 
        5413, 5398, 5397, 5383, 5380, 5363, 5379, 5376, 4882, 4861}]}, 
      {GrayLevel[1], Opacity[0.3], 
       LineBox[{4821, 4822, 4823, 4824, 4827, 4841, 4843, 4845, 4846, 4866, 
        4869, 4870, 4872, 4886, 4889, 4904, 4907, 4923, 4925, 4938, 4939, 
        4956, 4957, 4955, 4952, 4951, 4970, 5465, 5467, 5454, 5468, 5469, 
        5450, 5449, 5426, 5435, 5418, 5416, 5402, 5399, 5386, 5368, 5396, 
        5382, 5377, 5358, 5356, 5354, 5340, 5336, 5322, 5335, 5333, 4840, 
        4821}]}, 
      {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0LFKggEUhuFTNIRtWiRIQUsgQVfwE+0GQm4NRU2R5b+V1hV4Iw6RtDWq
mTg2NojkGEKC2B490PDwHr7x7Fykx7WliCjzmI14ok2XHq+8MWDIiDGfTPhm
zoIfVnIRGTYpsMU2RfZJOOSIMmecc0NKjSoP3NOgye1GRJ07LqlyzRUVTjmh
xAEJv+sRe7rLl7ugedZYZWFb1rnOmPDOlBEfDBnQ54UeLZ5p08n+/+0PAFUx
vQ==
        "]]}, 
      {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0T0rBAAcx/G/QRYMhzIorDLcK6BYLFe6V3BhsRyy0YnycJxCWdydh8ui
1IXDKoM8vQKDktUg5Wn0KcOn72//dY9MpLN1ETHKTiKiSIkyu+xRocoJZ9Q4
55Ib7nngkWdeeeeLH35paIloop0uekjSxyAp0mQYY5JpciwwzxwbbLHJOgXW
yFNksS1imRwrrFIgzxSzLDHDEFnGyTBMigH6SdJLJx0008h3a8Qn9faHvvHC
EyXuuOWCa2occcUpVQ6pcMA2+5Q5Tvz/8AcO+D8c
        "]]}, 
      {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0T0oxHEAxvGf0SB1WAyKjEoZrDLIpshgvsVGBuGOQ8ng7TqXl8Gdw/29
LtTVoUwGSaSMFgZ2g0Upn8vw6bs829McHx0YqQohTFTEQphkigRJpkmxzCpr
pMmwToEDikRcUOaKa+545Iln3vjgix+q60KopZEW2uigix76GCTOMGOMM8sC
WTbYYZc8OU4445RjjjgkolTZNoSwxzb7FIk4IM0WBTYZZoUU00wxyhBxeumn
k25aaaeOJn7rQ6jRT/3mhXdueOWBey4pc0uJcxJEFMmSJ8MiOdKsMs8cKcaZ
IclS7P/XP2RcTJM=
        "]]}, 
      {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0j1IFHAAxuG/YzgomoPgYDQ5OEizgwhODSI0NOjlnV9E550fIEJwdFpD
UtxweuokCuqi3R2YnnrnF6aDg+ZsUENrS9DQ0iMNz/Z7t/dRNNEzWhVCyNFb
F0IfEV7QT5QYAwwRJ0GSMcaZJMUb0swwy1syZFkgxyqb7HDIJTd85Zbv/OQ3
f6muD6GWJh7TyhM66KKbZ8QYYZwp0rwjyyIrrLFFgTyf+EyJPXY55YIvnHHC
MUdUKHN1v2kI4YACh5Q54pwiFfbJk2WbdTbZYoNllpjnA+9JMUGSODEi9PCU
Ttppo4VmGqnhAX8ehvCLH3zjmjuuOKdEkQ1WWWCOeabJMMsMH0mT4jmTvGaC
MV4RIclLRhimlyEG75u6/7/6B4erX8E=
        "]]}, 
      {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl071LFHAAgOFfe0OazWG4N2QqZKamnh8E3nkekRIhilySgYk5Kg2nmxaU
UYsgwTXYYFBYDVEU4reemV9FnSX0BwSGg084PMu7v/ltt2Pdx0IIHzifG0IR
xZRwgVLKqOAyVVRTQ4Ra6qingUaixGgiToKrXKOFVjpJcpMu7tDHACmGGOYB
YzwjzWveMUeGLHv85YDjJ0PI4TQFnKWQSiJESdBBkl76uUeKhzxmnAkmmWKa
t8wwywJLrLBGhlU2+M43dthmi03W+cUev9kly09+8Icvp0L4yiobbLPDFvMs
sc4yH9kkwwqLzDDHLJ/5xCve85IpXpDmKU8YZYRBBuilhw7aaSZONVUUco4z
5JPDCf7lhbDPLlmWWeQN0zwnzRiPGOY+Q6S4Sx/dtNHDLbq4QZLrtJLgCi3E
aaKBemIUU0eUWippJEIN5VyijBIuUvq/5x59cAg5RHiD
        "]]}, 
      {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl1FtoD1AcB/D/3I2x/Xdjs81/V7O7a0juSs1WNMODmsvyIHuaPPBC8yA8
TBJCeVGslCI1SUNJIUK8uI9dmN1sZjeffx4+53sezjm/fqfTCe2s2bQ/IhAI
5Bgig4HAFKYSxTSmE00MQWKJI54EEplBEsnMIoVU0phNiHQyyCSLbHLIZS5z
yCOfAgopopgS5jGfBSxhKctZwWpK2UgZ5VRQyTb2sJf91HKYY5zgDJe5yg0a
aeI57/hKGwOMhu8k1h0QIosSFrOWDWxmG9vZQTX7OMAh6jjJKeo5ywWu0MBN
btHIQx7xmCc85TkveMNbPtJCK+384Ccd/KKTLrrpoZd++vjNH4YZYpC/DDAh
zjtgCpFMZhITGc84xjKGCAKM2jdClHlvvPP5RR9/+Mso3QwSSFBXthFhPiKH
6ecnnQzQQxet/KCDdlr4zjea+coXPvOJj3zgPa95wjMe8Jg7NNHAfW5zi+tc
4xIXOU09RzkV7kF/R8L1Za18JavlPVkpq9hCOetZyUIKySCFIEPWD7KbZrbz
kqfcpYHrnOccJzhOHQfZRQ1bqaI8XJ91VFBGKWtZwzJWEc1SprOIJSxkAfOY
TwnFFFFIAXPJJ5dM8phDDhlkk84ssggxm2SSSGMaM0llBkFSSCSBeGKIIza8
Nvj/X/oHpDqgeQ==
        "]]}, {}, {}, {}}}]},
  AspectRatio->NCache[
    Rational[2, 5], 0.4],
  Frame->True,
  FrameLabel->{{
     FormBox["\"x[nm]\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"z[nm]\"", TraditionalForm], 
     FormBox[
     "\"R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, Signal, nmax=15\"", 
      TraditionalForm]}},
  ImageSize->700,
  LabelStyle->Larger,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.592661037212965*^9, 3.592662237147835*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SignalP", "=", 
   RowBox[{"ListDensityPlot", "[", 
    RowBox[{"OASignal", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Blend", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"White", ",", "Green", ",", "Black"}], "}"}], ",", "#"}], 
         "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<x[nm]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z[nm]\>\"", ",", 
          "\"\<R=30nm, Gaussian BSC, \[Lambda]=532nm, w0=330nm, Signal, \
nmax=15\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CabsCP", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"OAAbs", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Opacity", "[", "0.3", "]"}]}], "}"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PGreen", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"SignalP", ",", "CabsCP"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.557547718459428*^9, 3.557547857138774*^9}, {
  3.557547904135912*^9, 3.55754796910988*^9}, {3.557548126572126*^9, 
  3.557548136643323*^9}, {3.557548219181638*^9, 3.55754822490097*^9}, {
  3.5575482848319893`*^9, 3.5575482899882174`*^9}, {3.557555056603607*^9, 
  3.557555087377116*^9}, {3.5575551679979353`*^9, 3.557555170751629*^9}, {
  3.557589142163062*^9, 3.5575891439061327`*^9}, {3.557589188489479*^9, 
  3.55758919932087*^9}, {3.557634033331483*^9, 3.557634060143515*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx03U3rK0t+5fvDvR7qBZyhG3p2JzW0ZjXoiWaFRxYUGASGLTCoWljYMtmo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    "], {
     {GrayLevel[0.8], EdgeForm[None], 
      GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxcnWXUVVXXhk/HAyiNICEtDZISAtItjSAC0iAtKY2EdIgg3RLSXZICCiq+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        "]]]}, {}, {}, {}, {}},
    VertexColors->CompressedData["
1:eJxsvXk41G/7/z/JWkJZixgSEmVLKjIVIXsUKowoSypCEdVEyRohZB2yJUmF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     "]], 
   GraphicsComplexBox[CompressedData["
1:eJx03U3rK0t+5fvDxUPd+Rn6Qr+AGlqzGvREs8IjCwoMAsMWGFQWFrZMNiq5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    
    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      {GrayLevel[0], Opacity[0.3], 
       LineBox[{11329, 11304, 11305, 11306, 11307, 11309, 11330, 11331, 11352,
         11353, 11355, 11356, 11372, 11374, 11390, 11391, 11413, 11414, 11412,
         11411, 11410, 11431, 12056, 12057, 12044, 12058, 12059, 12037, 12035,
         12019, 12018, 12016, 11998, 11996, 11994, 11976, 11974, 11956, 11953,
         11938, 11952, 11950, 11329}]}, 
      {GrayLevel[0], Opacity[0.3], 
       LineBox[{11281, 11255, 11257, 11258, 11282, 11283, 11284, 11285, 11287,
         11288, 11308, 11311, 11313, 11314, 11332, 11335, 11354, 11359, 11373,
         11377, 11392, 11395, 11415, 11417, 11433, 11435, 11434, 11432, 11452,
         11451, 11450, 11470, 12092, 12095, 12093, 12076, 12078, 12080, 12077,
         12049, 12060, 12040, 12038, 12022, 12020, 12001, 11999, 11980, 11978,
         11959, 11942, 11973, 11955, 11949, 11932, 11930, 11927, 11915, 11926,
         11891, 11904, 11902, 11281}]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl0KFKQwEYhuFfsXgDC6IHzJMjBrEZNjQo4tzyihYVccmwOIZ6BYJl4gUM
1gSDinmMOatheDQPTA5U9AHDw/vlb363Vj6eiIgK43zEkFcy3njni29++CUW
IibJMcMsCSnLrLHBJltU2aPGCQ3OuKRFmw53PPLAPQOeeaJPj4zSYsQO65Sp
UGCbFYqsskTCHKM0Ylqn+LQ/yHihTY8ut9xwTYcrWpxT54JTmjQ44pAqB+yn
/z/+AbesPUg=
        "]]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl0TsrBAAcAPC/ImWwmzzW05GFTAZJGeTRieEG4rzOMbEpg/gGstwnsNxk
oAzK+3HJTufuHLNSSn5l+H2CX/tsbnytLiLmeElEXHLFNTfccscDjxQpU6XG
B7/Ud0Y00EgLbXTTSx/9DDFKmnnW2WSHfQ7Jc0SBM8554pkqn9R4p0KZN0q8
8kWmK2KJaZZZYZUt0mRZJEWCQQbooYNWmmniJxnxTYUSRe455YQLjimQ54AF
9thlg21yZJlhhAxTpJhkmAnGkv8Pf+q5Sl8=
        "]]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl0b0rBHAAxvHflbcjk7KYWCTcJRYpUsSkS4pYZDEoRIhY5P1sJpnk3WBS
3g0MNikv3T/AIJcNmXzK8Jm/Tz3FfUPtg5EQwgQn5SFss8Mue+xzwCGnnHHO
JVdcc88jz7zwxgdpPolUhBAllzyKKKGaOlpJ0Es/I0wyR5INNjnimBvueCLF
O2m++OWHb3IqNYmSTRaZZFDAXDyEBaZZZIUkS4wyxTyTtDFIN5100EIZNRRS
TIR80jFbSPHKLQ8ccsEaW8ywzirLjDPGLMMMUE8PXTTTThO1JGikgWqqiFNK
jIrY/69/N9ZQ0w==
        "]]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl0j1IFGAAgOFPAh0klPP0UBS8PF0u7xpMpwNdolsarpwSwcPBKYMCQWgJ
zRRFUOr8K9CuECRxqSUQ9KZbjwhBhMYbHC6iISjwAYdnfpc3np/OPakLIazz
JhnCHPO8YoHXLLLEWwpssMkWO7zjPQd85pAjvnHCKSUqnFGlxi9+c+N2CDfp
IsEAGbLkeMgjJpjiGbPMs8wOHzjiKyXK/OCcS2r85T+N/XpE6aCdGG20kqCP
Xnq4RZxu0uym9dimyCf2+cgaBfbY5CUbrLLCIi/I85QxHjPKfUa4S5oeIjTR
wL9UCH+o8pPvXFChzDFfKLLNCnPMMMlzHjBOhlGy3GOIQYYZ4A7N9NJPgk6S
xOkmRhtR6mkhkrr+6Ap9tV7Q
        "]]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl0jtIFWAYBuDfEnOocDCQCqJCTM3UBvFSBpVdNAmCBgcvHXDwdkxxCA+5
NpSpNCbqoBQapZ7AbiCWx8G1KEg3pzolFF2oCHvC4eF9x5ePb3+k81I0JYQQ
pyU/hAYaaeIKEVppo50OonRylS666aGXGNfp4yb93GaAQYa4yxgPmCHOY+ZJ
8Ib3rLBKkm+kHQ5hJ/vIpoRKLnCZCC30EOMG/YwwzgxzJFjmHaus85U/bLC9
IIQMsthLDvnkkUsRxZRzgkqOc4wKyijlLOc4QxWnqeVlYQiLvCDBEk9YIM5T
XvGchzxjlmkeMcoUk9xjmDsMcos+mummiXpqOE8ZJeSQTSYZbBwJ4S9JPvCW
1ywwz30mGGKAGNeIcJEojdRRzSnKOUkpRznEQfawgwPsJot0trGLVLb+3+FW
v9mi/5JfSNF/yh985zOfWCPJx4LNP/4HkEd5vg==
        "]]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl01toDXAAx/G/ByUTyZNE9nIiDuVSm7mOmW0azjadzWHZVZQVGrFyeZK0
FE9KLiUpJbGSBy0PMw6zi3XscrCZkYdNLUVYPuXh0/f9V7/MqobY4SkhhA9s
WhJCFtmsIYe1rGM9uWxmC3lsJZ9tFFBIETvZRYwSSikjTjkVJKimljrqOUoj
xzlBE2c4yzkucpnr3OI+LbTSRoo0Y/xg2tIQZpFJhGw2UMxuajhII02cp5kb
3OYhj2kjSR9pxpngDyEawkxmM48FLCLKClaxkVwKKKKYHcQoo5QSyqlkH3tJ
sIcK4tRxgHpqqaGaKg7xcXkIwwzwiVG+8Jke3jFEH52MMEg/KTropovXJGml
nec8pYVHPOAed7nGVa7QzGlOcYwGKolTSB5ZrCTCQuaQweSyEH7xjRF6eUMr
T7jDTS5xgZMcYT8JtpNPDqtZTIT5zGUGGUxn0l5T9a/+ZoKv/OQ744wyxgjD
vCfFEGkG6eUtA7TRQz/ddNBHF528IslLnvGC9uj/3/0D3Y+gHw==
        "]]}, 
      {GrayLevel[0], Opacity[0.3], LineBox[CompressedData["
1:eJwl1FVMF0AAB+C/YmEh2ImBhYCtm7qp882B9SAPzg2s2Y3d2A1idwcmKnbj
jOl8sTfBF2cXYufHfPjud3cPt93vtqvVZ0SP4QUCgUC8oWyjQKAQhSlCUYoR
THFKUJJSlCaEMoQSRjnKU4GKVKIyVahKNapTg3BqUova1CGCutSjPg1oSCSN
iCKaGBrThKY0ozktaEkrWtOeDsQSRxe60pN4etGbfgwkiYlMJ5lU0tjKdjLI
JItrPCKbXL7kdxOlD+pQn3Z0oDvxDGAIE5jKQpaxnBS2sYvjnOI6t3hMNjk8
5SN5/KFAdCBQkCBCCKM64UQRQ3Na0orWdKQTnYmlG93pSTwJJDKIwQxlGMMZ
wUhGMZoxjGU840hiApOZxESmMJMZTGcaU1nIcpaxlCUsZhELmM885jKH2SQz
ixQCTdyfn411IAtRhBL8sVdUlqQY361LyeIEE8Q3e78pbP5X/iKPr/zgC7l8
5hMf+cB73vGWN7zmFS+5zwtyyOYJ97jLHW5xkxtc4Bwn2EImqzhAMpsYz0oG
kMJMZjCOJPoxir4kEkcsbWlDJA2oSER+T5TPv0OM/uQj+YbnPCCLy6SzlzRS
WcoU+tOXBOIIpx2hROafSQ1CKE0wf73VL/LI5TnPeEoOD7nGfS5xh7Pc5ipZ
XOQKFzjPGc5xktMc5QSnyOQ4GRzjCIc5xH4Oks4uDrCPvexkDzvYxG62s42N
bGArqaxnC+tIYzNrWcNqVrCKldH//9V/KXbhvw==
        "]]}, {}, {}, {}}}]},
  AspectRatio->NCache[
    Rational[2, 5], 0.4],
  Frame->True,
  FrameLabel->{{
     FormBox["\"x[nm]\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}, {
     FormBox["\"z[nm]\"", TraditionalForm], 
     FormBox[
     "\"R=30nm, Gaussian BSC, \[Lambda]=532nm, w0=330nm, Signal, nmax=15\"", 
      TraditionalForm]}},
  ImageSize->700,
  LabelStyle->Larger,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5927165052046013`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rayleigh limit : lateral scans", "Section",
 CellChangeTimes->{{3.598344024345619*^9, 3.598344041725375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"ScatterOARayleigh", "[", 
        RowBox[{"x0", ",", "0", ",", 
         RowBox[{"1", "/", "2"}], ",", "s", ",", "\[Alpha]"}], "]"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "3"}], ",", "3", ",", "0.15"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sx", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
          "AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/", 
        "Inc"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Scax", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
          "AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "/", 
        "Inc"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AxR", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
         "AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AxI", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
         "AxT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "AxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"AxR", ",", "AxI"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Re(Ax) and Im(Ax)\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x/w0\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PR", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"AxR", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Re(Ax)\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x/w0\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PI", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"AxI", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Im(Ax)\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x/w0\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PSx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"Sx", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Signal\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x/w0\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PSsca", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"Scax", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Scattering\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x/w0\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"PSx", ",", "PSsca", ",", "P0"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.598283684591071*^9, 3.598283762703781*^9}, {
   3.59828384052494*^9, 3.5982838531812677`*^9}, 3.598284392493264*^9, {
   3.598284462276121*^9, 3.5982844915394278`*^9}, {3.5982845435566273`*^9, 
   3.5982845918124866`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEcB65aZswSOXzI7uwZEGA7IP/u6D7BVS/3zZoJ
AqwHXK9Vvao9/G9fGhiwHLjAWrRKJo9jvzEYMB9gnL7uy5mtAvsh5jEdmPbX
dl55o9h+iHkMBx72KB15k6AAVf9/f81fGYX77zWh8n/2T+wWEed8abI/HWz+
r/0LeEpUZbkdoOb92J+2/hH7r1q3/RD3fN0v/Towcr6Iz34TsHmf99/Y1v9l
gq8f1LwP+49y/+5oLfHaD+aeebM/b1cXdwa3LdS8F/vDZuufqpijbg/R/3h/
tcu1CRbNAfYXwOrv7K9hZdptWBBvbwGWv7x//7fIjUtb0uwNwPzD+9uCTJQO
eWTbw0LQx6mqdur/HJi8fc7bRYogeQj/sr2Tve8GkP4TEPPtJdkdd4DMh8g/
tt+Xe74XZD/Uffan3C9sArkP6n770/wzREHuh/A/2P+0vNID8h/U//Yml1S/
g/w/AxI+9n/dzkSBwgcafvanD/VxgMIvBRK+9oVHVoLDF2LeH3tpMQ1w+EPM
+2//cI0/OH4g8gwO+Y1LwfEHjV+HDpM980HxawSJf4djCtrfQPEPTR8O3OEN
a0DpA5p+HDZy3XwNSj8Q89gcIg0c94DSFzT9OZw5ILQZlP4AesIsTA==
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., 0.},
      Frame->True,
      FrameLabel->{{
         FormBox["\"Signal\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"x/w0\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      LabelStyle->Larger,
      Method->{},
      PlotRange->{{-3., 3.}, {-0.0009247739638299003, 0.003539840672438543}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0.12, 0.12}, {0.00008929229272536886, 
       0.00008929229272536886}}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEcB1Zqx0r4C2XYnT0DAmwHnNYKankVVNvNmgkC
rAfW3VzoGs/VZ5cGBiwHXv+fmWMzfb6dMRgwH4jf2lo+78V6O4h5TAfk8rbO
5f2yD2oewwGzb9Jbha6egar/v1+2Ppnd8cRNqPyf/dpyJhKuCs/s0sHm/9qf
FJf1aqn5J6h5P/bXM/3/q370D9Q9X/cvfX/9wILjrPYmYPM+7698KnfJfRa/
PcS8D/ub14itU/suag/mnnmzf0ei7DcDO1l7iHkv9h+9v/2R9GIlqP7H+21W
zVAV2atmfwGs/s5+qdn/jk/q0bK3AMtf3j+pKMjm9gpdewMw//D+I/zH2pU2
69vDQvDUzuSZU0wMYPL2G4Uh8hD+Zfs//RD9JyDm25/7DDEfIv/Y/m3sTLD9
UPfZF/7bAXYf1P32hekKYPdD+B/sHzhKgf0H9b99boca2P8zIOFjnxx9Hxw+
0PCzT/Dm+QcKvxRI+Nq3pJWCwxdi3h/7dBNXcPhDzPtvb+ReA44fiDyDw5Ud
tuD4g8avw6o9D8DxawSJf4dX8rvA8Q9NHw6Hv1wFpw9o+nGQPvgInH4g5rE5
vLMLAacvaPpzKHkzF5z+APsKJGU=
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., 0},
      Frame->True,
      FrameLabel->{{
         FormBox["\"Scattering\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"x/w0\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      LabelStyle->Larger,
      Method->{},
      PlotRange->{{-3., 3.}, {0, 0.00024727466497056745`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0.12, 0.12}, {4.9454932994113495`*^-6, 
       4.9454932994113495`*^-6}}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {
        {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEcB07u3cY4xyHC/uwZEGA7IG2SZJIyKdx+1kwQ
YD0guXTbPhanaPs0MGA5sN4hYtm0l0n2xmDAfGBiqrt82Mkce4h5TAcUBXoE
Z6eUQc1jOJB1rCruZGkjVP3//YsyjWWDErqh8n/2865jKsyaPdU+HWz+r/0L
U089Xcy2EGrej/0flhlGfs9cBXXP1/1sHzL3H3622d4EbN7n/U1nQ4rUb++B
mvdhfxpbBrcr2xF7MPfMm/3t0ZXbF3Sfgpr3Yn8d8/TkkLMXoPof71f/96Xs
YvAV+wtg9Xf2m6pprPzQft3eAix/eb/tpVkhCyVu2RuA+Yf3N/Qr9/scvG0P
C8HFxz2/GIfcgcnba0eoguUh/Mv2bIFzwfpPQMy3/7NWE2w+RP6xvR0zxH6o
++zVT00Cuw/qfvvVLtlg90P4H+wXGIeD/Qf1v319qynY/zMg4WMfKB0CDh9o
+Nnbf1EAh18KJHztBRddAYcvxLw/9oKs9uDwh5j3397+7EVw/EDkGRz4tonH
g+IPGr8OO65NEQLFrxEk/h3WrHunAIp/aPpw2D794nJQ+oCmH4fDX/8eBKUf
iHlsDqJhPRag9AVNfw4zVD6xgdIfAILoJM0=
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEcB3YzPZvvcUpp/9kzIMB24FiP2+n433L2s2aC
AOsB8Qe9B/+fsrJPAwOWA94aDxrzZd3sjcGA+cCy4ixHtzm+9hDzmA68EP7S
u8Ix2B5iHsOBZZu4n7pOj4aq/7//6vx/1WvY0qDyf/YLr32e7vy+0D4dbP6v
/Z+dPjJsi6qGmvdjv1e56cKzE5ug7vm6f72T7Cn9tlZ7E7B5n/e/V9CvZljY
DDXvw37HFvfEtpPF9mDumTf7n509dvBHYfF+iHkv9u9J3T19xZLJ+yH6H+9n
i8uOFRBcvP8CWP2d/SWaYmdOvViz3wIsf3m/YECuwNObm/YbgPmH94u4Kojw
Ptu6HxaCz5mqtYz/boPJ2we/PC8MkofwL9uzTLzBD9J/AmK+/anXfadA5kPk
H9tXX98dDbIf6j776MllU0Dug7rf/uuD8m0g90P4H+yTRf9lgvwH9b+9xCHF
OpD/Z0DCx97k/bnToPCBhp/9d45f4PBLgYSvfc/BZEZQ+ELM+2M/++8bcPhD
zPtvz2XMXQOKH4g8g8Oc9dfB8QeNX4c23+B+UPwaQeLfQbzbyQUU/9D04bBy
4/5mUPqAph+Hf97qh0DpB2Iem8OSp78OgNIXNP05eDNtXQlKfwA/mDG+
          "]]}}, {}},
      
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0., 0.},
      Frame->True,
      FrameLabel->{{
         FormBox["\"Re(Ax) and Im(Ax)\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"x/w0\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}},
      LabelStyle->Larger,
      Method->{},
      PlotRange->{{-3., 3.}, {-0.08980102336046124, 0.44263933998365185`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0.12, 0.12}, {0.01064880726688226, 
       0.01064880726688226}}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.5982837638215017`*^9, 3.5982838346090403`*^9, {3.5982844147410994`*^9, 
   3.598284439868105*^9}, 3.5982845126083603`*^9, 3.5982846304460773`*^9, 
   3.59828702320485*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ZX-Scans of Re(Ax) and Im(Ax)", "Subsubsection",
 CellChangeTimes->{{3.59872712745253*^9, 3.5987271389003973`*^9}, {
  3.5988078527765827`*^9, 3.598807885273038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"OAAxIm", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAAxRe", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAAbs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OASca", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"OAScatterIm", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "3", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAAxImP", "=", 
   RowBox[{"ListDensityPlot", "[", 
    RowBox[{"OAAxIm", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Blend", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Yellow", ",", "Orange", ",", "Red", ",", "Black"}], "}"}],
           ",", "#"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<x[nm]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z[nm]\>\"", ",", 
          "\"\<R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, \
Rayleigh-Signal\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAAxReP", "=", 
   RowBox[{"ListDensityPlot", "[", 
    RowBox[{"OAAxRe", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Blend", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Yellow", ",", "Orange", ",", "Red", ",", "Black"}], "}"}],
           ",", "#"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<x[nm]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z[nm]\>\"", ",", 
          "\"\<R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, \
Rayleigh-Signal\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CabsCP", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"OAAbs", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"White", ",", 
         RowBox[{"Opacity", "[", "0.3", "]"}]}], "}"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PAxIm", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"OAAxImP", ",", "CabsCP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PAxRe", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"OAAxReP", ",", "CabsCP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{"{", 
   RowBox[{"PAxIm", ",", "PAxRe"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5982869759501467`*^9, 3.598286978847269*^9}, {
  3.5983469063306026`*^9, 3.598346985010714*^9}, {3.598347187607497*^9, 
  3.598347188744857*^9}, {3.5988101166847763`*^9, 3.598810117359132*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1nMHKLN1ZhRtHXkIP2zvoocMzrVlw5J4GBGt0ZEPAgh+KFAkoCkZRRDGo
UWOMxngJZ/hdRg/7Enoo2rXW8ll89qR5zrvr/f+H/rpr76pd67e+//V3fu83
LpfLn/zm5fI/7//7+vLrb5f/+zIvX8iD/O37VV/JX77W+El+/KCO38i376rf
Tr7/sPof5O/96M1/+J/0My9VH2T5ub6S5efxkyw/H7+R5ed+O1l+7n+Q5fdf
v6Kfean6IMvP9ZUsP4+fZPn5+I0sP/fbyfJz/4Msv+d/0M+8VH2Q5ef6Spaf
x0+y/Hz8Rpaf++1k+bn/QZbfrfxu5Xcrv1v53crvVn638ruV3638buV3K79b
+d3K71Z+v/vv9DMvVR9k+bm+kuXn8ZMsPx+/keXnfjtZfu5/kOX3k1/Sz7xU
fZDl5/pKlp/HT7L8fPxGlp/77WT5uf9Blt/Hv9HPvFR9kOXn+kqWn8dPsvx8
/EaWn/vtZPm5/0GW36X8LuV3Kb9L+V3K71J+l/K7lN+l/C7ldym/S/ldyu9S
fr/9i7P/+TIvVR9k+bm+kuXn8ZMsPx+/keXnfjtZfu5/kOX3B/9KP/NS9UGW
n+srWX4eP8ny8/EbWX7ut5Pl5/4HWX6/+Dn9zEvVB1l+rq9k+Xn8JMvPx29k
+bnfTpaf+x9k+T3+5ex/vsxL1QdZfq6vZPl5/CTLz8dvZPm5306Wn/sfZPld
y+9aftfyu5bftfyu5Xctv2v5XcvvWn7X8ruW37X8ruX3vX+mn3mp+iDLz/WV
LD+Pn2T5+fiNLD/328nyc/+DLL8/+if6mZeqD7L8XF/J8vP4SZafj9/I8nO/
nSw/9z/I8vv2M/qZl6oPsvxcX8ny8/hJlp+P38jyc7+dLD/3P8jye/0j/cxL
1QdZfq6vZPl5/CTLz8dvZPm5306Wn/sfZPndy+9efvfyu5ffvfzu5Xcvv3v5
3cvvXn738ruX37387uX3+/9AP/NS9UGWn+srWX4eP8ny8/EbWX7ut5Pl5/4H
WX5f/p5+5qXqg+zrL6qvZF9/0fhJ9vUXHb+Rff1F/Xayr7+o/0H29Ymf0s+8
VH2QfX1C9ZXs6xMaP8m+PqHjN7KvT6jfTvb1CfU/yF6//x39zEvVB9nrd9VX
stfvGj/JXr/r+I3s9bv67WSv39X/IHt9+7f0My9VH2Svb1VfyV7favwke32r
4zey17fqt5O9vlX/g+z139/Qz7xUfZC9/lN9JXv9p/GT7PWfjt/IXv+p3072
+k/9D7LXR3999j9f5qXqg+z1keor2esjjZ9kr490/Eb2+kj9drLXR+p/kL1+
+Cv6mZeqD7LXD6qvZK8fNH6SvX7Q8RvZ6wf128leP6j/Qfb8+i/pZ16qPsie
X6u+kj2/1vhJ9vxax29kz6/Vbyd7fq3+B9nzz7+gn3mp+iB7/qn6Svb8U+Mn
2fNPHb+RPf9Uv53s+af6H2TPz/6cfual6oPs+ZnqK9nzM42fZM/PdPxG9vxM
/Xay52fqf5A9f/kz+pmXqg+y5y+qr2TPXzR+kj1/0fEb2fMX9dvJnr+o/0H2
+f1P6Wdeqj7IPr+rvpJ9ftf4Sfb5XcdvZJ/f1W8n+/yu/gfZ578/pp95qfog
+/yn+kr2+U/jJ9nnPx2/kX3+U7+d7POf+h9knx9+fPY/X+al6oPs84PqK9nn
B42fZJ8fdPxG9vlB/Xayzw/qf5D9+3nQz7xUfZD9+6n6Svbvp8ZPsn8/dfxG
9u+n+u1k/36q/0H278tOP/NS9UH274vqK9m/Lxo/yf590fEb2b8v6reT/fui
/gfZ37+Nfual6oPs75/qK9nfP42fZH//dPxG9vdP/Xayv3/qf5D99znP/ufL
vFR9kP33qfpK9t+nxk+y/z51/Eb236f67WT/far/Qfbnt9LPvFR9kP35qb6S
/flp/CT789PxG9mfn/rtZH9+6n+Q7TfO/nqJl6oPsv1UX8n20/hJtp+O38j2
U7+dbD/1P8j2+/9eS9UH2X56rWT7afwk20+vjWw/9dvJ9lP/g5zPr/474qXq
9Z7P73xfyfn8zvGTnM/vfN/I+fzOfjs5n9/Z/yDn+3e+6yVeql4e+f59/p7v
3zl+kvP9O983cr5/Z7+dnO/f2f8g5/fz/PfzZV6qXp9Dfj8/98jv5+fv+f2k
n+ep35Hz+0m/zBvIOf/Rz7xUvf6Ocv6jn8/TX2t8eeT89/l7zn9nv52c89/Z
/yBn/nL++/kyL1Wv70HmL2e9/o4yfznH1+eQ+cvnHpm/fP6e+Qv9vM7/Ef9d
L/NS9foeZ/5JP/93vtb4+jvK/PM8vj6HzD8/98j88/P3rB/O/ufLvFR9kLN+
OOsrOeuHc/wkZ/1AP3HWD/QTZ/1AL3HWf/QzL1Uf5Kz/6CfO+u8cP8lZ/53v
Gznrv7PfTs767+x/kLN+P//9fJmXqg9y1u9nfSVn/X6On+Ss3+knzvqdfuKs
3+knzvUX+pmXqg9yrr/QT5zrL/QT5/oL/cS5/kI/ca6/0E+c62f0My9VH+Rc
P6OfONfP6CfO9TP6iXP9jH7iXD+jnzjXP+lnXqo+yLn+ST9xrn/ST5zrn/QT
5/on/cS5/kk/ca5f08+8VH2Qc/2afuJcv6afONev6SfO9Wv6iXP9mn7i3H+g
n3mp+iDn/gP9xLn/QD9x7j/QT5z7D/QT5/4D/cS5f0Q/81L1Qc79I/qJc/+I
fuLcP6KfOPeP6CfO/SP6iXP/j37mpeqDnPt/9BPn/t85fpJz/+9838i5/3f2
28m5/3f2P8i5f3v++/kyL1Uf5Ny/PesrOfdvz/GTnPu39BPn/i39xLl/Sz9x
7r/Tz7xUfZBz/51+4tx/p58499/pJ879d/qJc/+dfuLsn6Cfean6IGf/BP3E
2T9BP3H2T9BPnP0T9BNn/wT9xNn/Qj/zUvVBzv4X+omz/4V+4ux/oZ84+1/o
J87+F/qJs3+Jfual6oOc/Uv0E2f/Ev3E2b9EP3H2L9FPnP1L9BNn/xn9zEvV
Bzn7z+gnzv4z+omz/4x+4uw/o584+8/oJ87+Qfq9yu9Vfq/ye5Xfq/xe5fcq
v1f5vcrvVX6v8nuV36v8vv2Mfual6oPs+afqKzn7P8/3Sc7+z/P4jZz9n2e/
nZz9n+f7Qc7+3bP/+TIvVR9k+bm+krN/9xw/ydm/Sz9x9u/ST5z9u/QTZ/81
/cxL1QfZ82vVV3L2X9NPnP3X9BNn/zX9xNl/TT9x9s/Tz7xUfZDl5/pKzv55
+omzf55+4uyfp584++fpJ87zD/R7lN+j/B7l9yi/R/k9yu9Rfo/ye5Tfo/we
5fcov0f5/eLn9DMvVR9k+bm+kvP8Cv3EeX6FfuI8v0I/cZ5foZ84zx/Rz7xU
fZC9PlJ9Jef5I/qJ8/wR/cR5/oh+4jx/RD9xnh+jn3mp+iDLz/WVnOfH6CfO
82P0E+f5MfqJ8/wY/cR5/o9+5qXqg+z1n+orOc//neMnOc//ne8bOc//nf12
cp7/O/sf5Dy/ef77+foov4/y+yi/j/L7KL+P8vsov4/y+yi/j/L7KL+P8vso
v5/8kn7mpeqD7PWt6is5z9/ST5znb+knzvO39BPn+Vv6ifP8NP3MS9UHWX6u
r+Q8P00/cZ6fpp84z0/TT5znp+knzvPv9DMvVR9kr99VX8l5/p1+4jz/Tj9x
nn+nnzjPv9NPnPwC+j3L71l+z/J7lt+z/J7l9yy/Z/k9y+9Zfs/ye5bfs/z+
61f0My9VH2Rfn1B9JSd/gn7i5E/QT5z8CfqJkz9BP3HyQ+hnXqo+yPJzfSUn
P4R+4uSH0E+c/BD6iZMfQj+xr7/8mn7mpeqD7Osvqq/k5L/QT5z8F/qJk/9C
P3HyX+gnjt+30+cbeZC/fb/qK/nL1xo/yY8f1PEb+fZd9dvJ9x9W/4P8vR+9
35NfUzzI8kl+DVk+ya8hyyf5NWT5JL+GLJ/k15Dlk7ya4kGWT/JqyPJJXg1Z
PsmrIcsneTVk+SSvhiyf5NMUD7J8kk9Dlk/yacjyST4NWT7JpyHLJ/k0ZPnc
yudWPrfyuZXPrXxu5XMrn1v53MrnVj638rmVz618kj9TPMjySf4MWT7JnyHL
J/kzZPkkf4Ysn+TPkOWTvJniQZZP8mbI8kneDFk+yZshyyd5M2T5JG+GLJ/k
yxQPsnySL0OWT/JlyPJJvgxZPsmXIcsn+TJk+VzK51I+l/K5lM+lfC7lcymf
S/lcyudSPpfyuZTPpXySH1M8yPJJfgxZPsmPIcsn+TFk+SQ/hiyf5MeQ5ZO8
mOJBlk/yYsjySV4MWT7JiyHLJ3kxZPkkL4Ysn+TDFA+yfJIPQ5ZP8mHI8kk+
DFk+yYchyyf5MGT5JA+meJDlkzwYsnySB0OWT/JgyPJJHgxZPsmDIcvnWj7X
8rmWz7V8ruVzLZ9r+VzL51o+1/K5ls+1fK7lk7yX4kGWT/JeyPJJ3gtZPsl7
IcsneS9k+STvhSyf5LsUD7J8ku9Clk/yXcjySb4LWT7JdyHLJ/kuZPkkz6V4
kOWTPBeyfJLnQpZP8lzI8kmeC1k+yXMhyyf5LcWDLJ/kt5Dlk/wWsnyS30KW
T/JbyPJJfgtZPvfyuZfPvXzu5XMvn3v53MvnXj738rmXz7187uVzL5/ksxQP
snySz0KWT/JZyPJJPgtZPslnIcsn+Sxk+SSPpXiQff3AeSxkXz9wHgvZ1w+c
x0L29QPnsZB9/cB5LGSvt39Kn+SvkL3eVn0le72t8ZPs9baO38heb6vfTvZ6
W/0PstenzlspHmSvT523Qvb61HkrZK9PnbdC9vrUeStkr0+dt0L2es75KsWD
7PWc81XIXs85X4Xs9ZzzVchezzlfhez1nPNVyF7/OE+leJC9/nGeCtnrH+ep
kL3+cZ4K2esf56mQvf5xngrZ6wXnpxQPstcLzk8he73g/BSy1wvOTyF7veD8
FLLXC85PIXt+7byU4kH2/Np5KWTPr52XQvb82nkpZM+vnZdC9vzaeSlkz0ed
j1I8yJ6POh+F7Pmo81HIno86H4Xs+ajzUciejzofhez5m/NQigfZ8zfnoZA9
f3MeCtnzN+ehkD1/cx4K2fM356GQPd9x/knxIHu+4/wTsuc7zj8he77j/BOy
5zvOPyF7vuP8E7LnB847KR5kzw+cd0L2/MB5J2TPD5x3Qvb8wHknZM8PnHdC
9vnU+SbFg+zzqfNNyD6fOt+E7POp803IPp8634Ts86nzTcg+/yhfZCkeZJ9/
VF/JPv9o/CT7/KPjN7LPP+q3k33+Uf+D7N/rH9Mn+SVk/16rvpL9e63xk+zf
ax2/kf17rX472b/X6n+Q/fsmz6V4kP37pvpK9u+bxk+yf990/Eb275v67WT/
vh2fv/v3wPkkxYPs3wPnk5D9e+B8ErJ/D5xPQvbvwf75u38PyjP5JOzr74/z
SMj+/jiPpP6/vtb4Sfb3Z/v83d+f8kweSfWvz9l/b84fKR5k/705f4Tsv7f5
+bv/3soz+SPVrz5n/73V33HyR/j/5c9HPMj+fNbP3/35lGfyRuq4+pz9+dTf
cfJGqn99j+2j/++luN7tU57JF6nx9Tnbp/6Oky9S/ep7bJ/6nUq+yMl6LcWD
bB+9VrJ9NL5ydeyj10a2j/pVrpJ91P8g5/P58n5figc5n89ZX8n5fM7xlQOU
z+c8fiPn8zn7VQ5UPp8v9NE+eH9/ykc8yPn+lI/2vXyt8ZVblO9P+Wjf2nfk
zq3K96d8tG/fv2/06Vyd5INUfSXn940+yQep4zdyft/ok3yQ6n+Qc/6hT+cA
JQ+k6is55x/6JA+kjt/IOf/QJ3kg1f8gZ35An84tSv5H1Vdy5gf0Sf5HHb+R
Mz+gT/I/qv9BzvyNPuZBzvyNPt639bXGV+5W5m/0EWf+Rh9x5m/0EWd+TZ/k
e5Azv6ZP8j1q/CRnfk2f5HtUv52c+TV9ku/x5uR5FA9y1j/0SZ5HjZ/krH/o
kzyP6reTs/6hT/I83pz8juJBzvqUPsnvqPGTnPUpfZLfUf12ctan9El+x5uT
11E8yLl+QJ/kddT4Sc71A/okr6P67eRcP6BP8jrenHyO4kHO9R36JJ+jxk9y
ru/QJ/kc1W8n5/oOfZLP8ebkcRQPcq6/0Sd5HDV+knP9jT7J46h+OznX3+iT
PI43J3+jeJBzfZQ+yd+o8ZOc66P0Sf5G9dvJuT5Kn+RvvDl5G8WDnOvX9Ene
Ro2f5Fy/pk/yNqrfTs71a/okb+PNydcoHuTcX6BP8jVq/CTn/gJ9kq9R/XZy
7i/QJ/kab06eRvEg5/4PfZKnUeMnOfd/6JM8jeq3k3P/hz7J03hz8jOKBzn3
5+iT/IwaP8m5P0ef5GdUv52c+3P0SX7Gm5OXUTzIuX9Kn+Rl1PhJzv1T+iQv
o/rt5Nw/pU/yMt6cfIziQc79bfokH6PGT3Lub9Mn+RjVbyfn/jZ9ko/x5uRh
FA9y9h/QJ3kYNX6Ss/+APsnDqH47OfsP6JM8jDcn/6J4kLM/hD7Jv6jxk5z9
IfRJ/kX128nZH0Kf5F+8OXkXxYOc/Tv0Sd5FjZ/k7N+hT/Iuqt9Ozv4d+iTv
4s2v8nmVz6t8XuXzKp9X+bzK51U+r/J5lc+rfF7l8yqf5FkUD3L2v9EneRY1
fpKz/40+ybOofjs5+9/okzyLNye/oniQsz+RPsmvqPGTnP2J9El+RfXbydmf
SJ/kV7w5eRXFg5z9o/RJXkWNn+TsH6VP8iqq307O/lH6JK/izcmnKB7k7O+l
T/IpavwkZ38vfZJPUf12cvb30if5FG9+lM+jfB7l8yifR/k8yudRPo/yeZTP
o3we5fMon0f5JH+ieJCzP54+yZ+o8ZOc/fH0Sf5E9dvJ2R9Pn+RPvDl5E8WD
nOcX6JO8iRo/yXl+gT7Jm6h+OznPL9AneRNvTr5E8SDn+RL6JF+ixk9yni+h
T/Ilqt9OzvMl9Em+xJuTJ1E8yHn+hz7Jk6jxk5znf+iTPInqt5Pz/A99kifx
5o/y+Sifj/L5KJ+P8vkon4/y+Sifj/L5KJ+P8vkon4/ySV5E8SDn+Tn6JC+i
xk9ynp+jT/Iiqt9OzvNz9ElexJuTD1E8yHm+kT7Jh6jxk5znG+mTfIjqt5Pz
fCN9kg/x5uRBFA9ynj+lT/Igavwk5/lT+iQPovrt5Dx/Sp/kQbz5WT7P8nmW
z7N8nuXzLJ9n+TzL51k+z/J5ls+zfJ7lk7yH4kHO89v0Sd5DjZ/kPL9Nn+Q9
VL+dnOe36ZO8hzcn36F4kPN8PX2S71DjJznP19Mn+Q7Vbyfn+Xr6JN/hzclz
KB7k5B/QJ3kONX6Sk39An+Q5VL+dnPwD+iTP4dt/A9A4O2Y=
        "], {
         {GrayLevel[0.8], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxdnWWUVMfX9WeGlsHd3d3d3d3dNWgIHtxdQ3B3Dx4ILgGCO4QQHP64BgsB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            "]]]}, {}, {}, {}, {}},
        VertexColors->CompressedData["
1:eJztnXk01t33969K5oSMpaLMVJIkMiRzMk+3IRIhispMZUpEQgmRuTJHqcyZ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         "]], GraphicsComplexBox[CompressedData["
1:eJx1nXuATfX6/0cpSq65DIUJqb4nmVDkko9Idi6pkJVLjOvOZWaWidkMe2zk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        
        "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2380, 2402, 2400, 2403, 2407, 2424, 2425, 2442, 2443, 
              2460, 2458, 2476, 2494, 2934, 2905, 2916, 2899, 2897, 2880, 
              2881, 2863, 2846, 2857, 2858, 2838, 2401, 2380}]},
            "1800"],
           Annotation[#, 1800, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2359, 2360, 2363, 2382, 2383, 2405, 2406, 2409, 2412, 
              2427, 2430, 2445, 2448, 2462, 2463, 2478, 2479, 2497, 2495, 
              2493, 2511, 2953, 2941, 2954, 2937, 2938, 2935, 2919, 2901, 
              2903, 2883, 2885, 2866, 2878, 2862, 2859, 2842, 2839, 2824, 
              2814, 2821, 2381, 2359}]},
            "1600"],
           Annotation[#, 1600, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2324, 2344, 2342, 2345, 2346, 2361, 2362, 2365, 2369, 
              2384, 2388, 2408, 2411, 2426, 2429, 2444, 2447, 2461, 2465, 
              2480, 2482, 2498, 2499, 2514, 2512, 2528, 2543, 2986, 2958, 
              2971, 2970, 2956, 2939, 2940, 2920, 2918, 2900, 2902, 2882, 
              2884, 2865, 2864, 2843, 2844, 2827, 2837, 2823, 2825, 2809, 
              2796, 2806, 2807, 2788, 2343, 2324}]},
            "1400"],
           Annotation[#, 1400, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2308, 2310, 2311, 2326, 2327, 2329, 2332, 2347, 2350, 
              2364, 2368, 2371, 2374, 2387, 2392, 2410, 2416, 2428, 2434, 
              2446, 2452, 2464, 2469, 2481, 2486, 2501, 2503, 2515, 2519, 
              2529, 2530, 2545, 2544, 2541, 2556, 3000, 2989, 3001, 2999, 
              2988, 2974, 2973, 2932, 2960, 2955, 2942, 2936, 2921, 2917, 
              2906, 2898, 2886, 2879, 2867, 2861, 2848, 2841, 2803, 2826, 
              2828, 2811, 2810, 2793, 2805, 2791, 2789, 2776, 2764, 2774, 
              2325, 2308}]},
            "1200"],
           Annotation[#, 1200, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0C1LgwEUBeBrcOx12AeCbqwYNFgEk8kgmFYG4hDMYyv+gK2sCqYFwWAS
wWQQRdM2XTGICi6LiFH8GGx+PGB4ONxTDtz8Vq1YHYuIEh/piE++GDAknURk
yDLFNDnmWWCZFYqUWKdMlW3qNNmlxQGHnHBKmx4P9HnimTfe+SUmIn7kN0MS
dycTcUGXG64445wWxxyxzx47zNKgRoVNNlhjlSUWKXBnY07OkGWSFCP9gFte
eOWRPj3uueaSLuPJ/1//ANVaNpk=
              "]]},
            "1000"],
           Annotation[#, 1000, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0T0rBAAcwOE/Gc5x3Q3Ybrj7AgYps+nKpkxksBjkDDJT8gFkMHsZblBc
tiOLvCRFDJS7M5HzclmUlHhkePZf/XITM8PFloiYpJaIqHNPg2deeKXJO198
k2yPSJEmQ5Y8vfQxSIERxphmlnmWWGaVdUrsUuGYc26p8kCDDz5pTUa00Uma
FEl66KaLLNWOiCtq3HHJIddccMocB5TZYYM1VlhmkQWKTDHOKEMUGKCfPDky
pAl+NDR5o84mj39d3HDGCVvsc0SFPcqU2OYp8f/lF3M7P9c=
              "]]},
            "800"],
           Annotation[#, 800, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0bsrBHAAwPHfncEz5SZZUOe5sFhYTYrBYBT+AI/BZFJkNGBQZLkjJnkM
MjB6HXnmUk7yGDyjDFJ8yvDZv/Ut7+lr742EEIbYyQlhlz32OeCUM8655IZb
7rjnhQ9++CWSG0KUAmKUEqeeBpppoYNO+hhkmDEmmCbBEutsskOKNNc88sQX
32TlhZBNIUUUU0IpZdRQSzVVVFLHc34ID7zwyStp7lgkwwXnHLPHFtussEqC
JJNMMcIo/QzQRTettNFIE3EqKCJGhChvut7JcMMRVxySYpst1hhngxWWmWae
BeZIMssUM5zk/H/+A5WGTQY=
              "]]},
            "600"],
           Annotation[#, 600, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0j9IFHAYBuCflnRZiHCTUIOETiEkx2EkZUI4OAROOgU3Nig1RJuIJvZH
MCFtCiUQykzCUyGvUFGkhOOCQPAsCwkNgxJOLEHpORweXr7l4/3gK0+0NbUW
hBCe8yoSwhivGecNSaaY5i0zpHjPLPMssMgSaTKssEqWT2ywxg6bHJKj5GQI
xygnSjUVNBCnhUZucYNO7vCEHkZ4lO8nR/lIiixptlhnj18UFYcQoZQoZZzh
HBWcp4oLVBMjTg21XOIiV6mnjitc5hoFp0M4OOUmeYLj7JoL5YY8ZJ9//CXH
b/6wxU9+8I2vrPCZZT4wR4ok44wwxAC9dNPObW6SoJnrNFBLjErOEqUk35cD
/XfY5jtfyLDMPO+YZIJRXvCSIYZ5yjMGGaCfxzzkLn10cJ8H3KOHLtrpzO+O
HP3hfw8LY0k=
              "]]},
            "400"],
           Annotation[#, 400, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl01toyFEcwPH/irWb+xiGGsoDSqGV4oWwuW1zv8xlmzsbG5ZrWjLKho3N
NvfbhiapzfYgZssLS8sllIdNUVNkE60pPlLn0/fpnPN7OCcuLSslMyQIgm4K
woKgkJOc4jRFFHOWEko5RxnlnOcCF6ngMpe4wlWucZ0b3KSSKm5xmzvc4z41
1FHPQx7RQCNPaeYFb3hHK5/4RiddBOEW/RjKKMYxiWkkkMxKMsgmlyMcp4QK
Kqmmnsc8o4VXvOYDH2mnky5CIoIglEj6E0MsI4hjJKMZy3gmMJHJxDOFqUxn
BjOZxWwSSGQOc5nHfBaQRDIpLGQJi1nESlJZxQqWs4ylrGZwVBAMZAjDGUo0
w4hiELHE0J8B9KMvfehNnXN6aQSRhBJOGD0J+BMZBL/p5hc/6eA7X2injc+8
p5Vm3tLEc2p5QhU1lFHJMdaa4aqWUkQ+eeSwnXRSSSKRqcQzhjX2RusP7aEf
tYOXtNFECw9opIFa7lLNtX93U0E5ZyimkALyOUEeRznEYfZzkFy+ej8HdB97
2cNucthFNjvZQSZZbGU7W1jHNjaziTQ2sJH1pJPxb7aw///8L0P2hiQ=
              "]]},
            "200"],
           Annotation[#, 200, "Tooltip"]& ], {}, {}}}]},
      AspectRatio->NCache[
        Rational[2, 5], 0.4],
      Frame->True,
      FrameLabel->{{
         FormBox["\"x[nm]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z[nm]\"", TraditionalForm], 
         FormBox[
         "\"R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, \
Rayleigh-Signal\"", TraditionalForm]}},
      ImageSize->500,
      LabelStyle->Larger,
      Method->{},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {266.6666666666667, -105.}, 
     ImageScaled[{0.5, 0.5}], {500, 200.}], InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1nMHKLN1ZhRtHXkIP2zvoocMzrVlw5J4GBGt0ZEPAgh+KFAkoCkZRRDGo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        "], {
         {GrayLevel[0.8], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxdnWWUVMfX9WeGlsHd3d3d3d3dNWgIHtxdQ3B3Dx4ILgGCO4QQHP64BgsB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            "]]]}, {}, {}, {}, {}},
        VertexColors->CompressedData["
1:eJzt3Xk0V9vfB/BvhgaVREUlhEoopdBEhkqp3EioJFcq4d4QkjJcVwiVlFkU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         "]], GraphicsComplexBox[CompressedData["
1:eJx1nXuATfX6/0cpSq65DIUJqb4nmVDkko9Idi6pkJVLjOvOZWaWidkMe2zk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        
        "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2380, 2402, 2400, 2403, 2407, 2424, 2425, 2442, 2443, 
              2460, 2458, 2476, 2494, 2934, 2905, 2916, 2899, 2897, 2880, 
              2881, 2863, 2846, 2857, 2858, 2838, 2401, 2380}]},
            "1800"],
           Annotation[#, 1800, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2359, 2360, 2363, 2382, 2383, 2405, 2406, 2409, 2412, 
              2427, 2430, 2445, 2448, 2462, 2463, 2478, 2479, 2497, 2495, 
              2493, 2511, 2953, 2941, 2954, 2937, 2938, 2935, 2919, 2901, 
              2903, 2883, 2885, 2866, 2878, 2862, 2859, 2842, 2839, 2824, 
              2814, 2821, 2381, 2359}]},
            "1600"],
           Annotation[#, 1600, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2324, 2344, 2342, 2345, 2346, 2361, 2362, 2365, 2369, 
              2384, 2388, 2408, 2411, 2426, 2429, 2444, 2447, 2461, 2465, 
              2480, 2482, 2498, 2499, 2514, 2512, 2528, 2543, 2986, 2958, 
              2971, 2970, 2956, 2939, 2940, 2920, 2918, 2900, 2902, 2882, 
              2884, 2865, 2864, 2843, 2844, 2827, 2837, 2823, 2825, 2809, 
              2796, 2806, 2807, 2788, 2343, 2324}]},
            "1400"],
           Annotation[#, 1400, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], 
             LineBox[{2308, 2310, 2311, 2326, 2327, 2329, 2332, 2347, 2350, 
              2364, 2368, 2371, 2374, 2387, 2392, 2410, 2416, 2428, 2434, 
              2446, 2452, 2464, 2469, 2481, 2486, 2501, 2503, 2515, 2519, 
              2529, 2530, 2545, 2544, 2541, 2556, 3000, 2989, 3001, 2999, 
              2988, 2974, 2973, 2932, 2960, 2955, 2942, 2936, 2921, 2917, 
              2906, 2898, 2886, 2879, 2867, 2861, 2848, 2841, 2803, 2826, 
              2828, 2811, 2810, 2793, 2805, 2791, 2789, 2776, 2764, 2774, 
              2325, 2308}]},
            "1200"],
           Annotation[#, 1200, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0C1LgwEUBeBrcOx12AeCbqwYNFgEk8kgmFYG4hDMYyv+gK2sCqYFwWAS
wWQQRdM2XTGICi6LiFH8GGx+PGB4ONxTDtz8Vq1YHYuIEh/piE++GDAknURk
yDLFNDnmWWCZFYqUWKdMlW3qNNmlxQGHnHBKmx4P9HnimTfe+SUmIn7kN0MS
dycTcUGXG64445wWxxyxzx47zNKgRoVNNlhjlSUWKXBnY07OkGWSFCP9gFte
eOWRPj3uueaSLuPJ/1//ANVaNpk=
              "]]},
            "1000"],
           Annotation[#, 1000, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0T0rBAAcwOE/Gc5x3Q3Ybrj7AgYps+nKpkxksBjkDDJT8gFkMHsZblBc
tiOLvCRFDJS7M5HzclmUlHhkePZf/XITM8PFloiYpJaIqHNPg2deeKXJO198
k2yPSJEmQ5Y8vfQxSIERxphmlnmWWGaVdUrsUuGYc26p8kCDDz5pTUa00Uma
FEl66KaLLNWOiCtq3HHJIddccMocB5TZYYM1VlhmkQWKTDHOKEMUGKCfPDky
pAl+NDR5o84mj39d3HDGCVvsc0SFPcqU2OYp8f/lF3M7P9c=
              "]]},
            "800"],
           Annotation[#, 800, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0bsrBHAAwPHfncEz5SZZUOe5sFhYTYrBYBT+AI/BZFJkNGBQZLkjJnkM
MjB6HXnmUk7yGDyjDFJ8yvDZv/Ut7+lr742EEIbYyQlhlz32OeCUM8655IZb
7rjnhQ9++CWSG0KUAmKUEqeeBpppoYNO+hhkmDEmmCbBEutsskOKNNc88sQX
32TlhZBNIUUUU0IpZdRQSzVVVFLHc34ID7zwyStp7lgkwwXnHLPHFtussEqC
JJNMMcIo/QzQRTettNFIE3EqKCJGhChvut7JcMMRVxySYpst1hhngxWWmWae
BeZIMssUM5zk/H/+A5WGTQY=
              "]]},
            "600"],
           Annotation[#, 600, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl0j9IFHAYBuCflnRZiHCTUIOETiEkx2EkZUI4OAROOgU3Nig1RJuIJvZH
MCFtCiUQykzCUyGvUFGkhOOCQPAsCwkNgxJOLEHpORweXr7l4/3gK0+0NbUW
hBCe8yoSwhivGecNSaaY5i0zpHjPLPMssMgSaTKssEqWT2ywxg6bHJKj5GQI
xygnSjUVNBCnhUZucYNO7vCEHkZ4lO8nR/lIiixptlhnj18UFYcQoZQoZZzh
HBWcp4oLVBMjTg21XOIiV6mnjitc5hoFp0M4OOUmeYLj7JoL5YY8ZJ9//CXH
b/6wxU9+8I2vrPCZZT4wR4ok44wwxAC9dNPObW6SoJnrNFBLjErOEqUk35cD
/XfY5jtfyLDMPO+YZIJRXvCSIYZ5yjMGGaCfxzzkLn10cJ8H3KOHLtrpzO+O
HP3hfw8LY0k=
              "]]},
            "400"],
           Annotation[#, 400, "Tooltip"]& ], 
          TagBox[
           TooltipBox[
            {GrayLevel[1], Opacity[0.3], LineBox[CompressedData["
1:eJwl01toyFEcwPH/irWb+xiGGsoDSqGV4oWwuW1zv8xlmzsbG5ZrWjLKho3N
NvfbhiapzfYgZssLS8sllIdNUVNkE60pPlLn0/fpnPN7OCcuLSslMyQIgm4K
woKgkJOc4jRFFHOWEko5RxnlnOcCF6ngMpe4wlWucZ0b3KSSKm5xmzvc4z41
1FHPQx7RQCNPaeYFb3hHK5/4RiddBOEW/RjKKMYxiWkkkMxKMsgmlyMcp4QK
Kqmmnsc8o4VXvOYDH2mnky5CIoIglEj6E0MsI4hjJKMZy3gmMJHJxDOFqUxn
BjOZxWwSSGQOc5nHfBaQRDIpLGQJi1nESlJZxQqWs4ylrGZwVBAMZAjDGUo0
w4hiELHE0J8B9KMvfehNnXN6aQSRhBJOGD0J+BMZBL/p5hc/6eA7X2injc+8
p5Vm3tLEc2p5QhU1lFHJMdaa4aqWUkQ+eeSwnXRSSSKRqcQzhjX2RusP7aEf
tYOXtNFECw9opIFa7lLNtX93U0E5ZyimkALyOUEeRznEYfZzkFy+ej8HdB97
2cNucthFNjvZQSZZbGU7W1jHNjaziTQ2sJH1pJPxb7aw///8L0P2hiQ=
              "]]},
            "200"],
           Annotation[#, 200, "Tooltip"]& ], {}, {}}}]},
      AspectRatio->NCache[
        Rational[2, 5], 0.4],
      Frame->True,
      FrameLabel->{{
         FormBox["\"x[nm]\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z[nm]\"", TraditionalForm], 
         FormBox[
         "\"R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, \
Rayleigh-Signal\"", TraditionalForm]}},
      ImageSize->500,
      LabelStyle->Larger,
      Method->{},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {800., -105.}, 
     ImageScaled[{0.5, 0.5}], {500, 200.}]}, {}},
  ContentSelectable->True,
  ImageSize->{1078.6666666666667`, 222.},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.598731739253353*^9, 3.598778369635963*^9, 
  3.598805008583809*^9, 3.5988445075004597`*^9, 3.598863320553392*^9, 
  3.598939006966662*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export Data", "Subsubsection",
 CellChangeTimes->{{3.59872712745253*^9, 3.5987271389003973`*^9}, {
  3.5988078527765827`*^9, 3.5988078543687277`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/markusselmke/Documents/Igor Pro/Ax2ThetaDivIm_zx.dat\>\"", ",",
     "OAAxIm", ",", "\"\<Table\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/markusselmke/Documents/Igor Pro/Ax2ThetaDivRe_zx.dat\>\"", ",",
     "OAAxRe", ",", "\"\<Table\>\""}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5983470588915567`*^9, 3.5983470633197393`*^9}, {
  3.598347095527939*^9, 3.59834710765908*^9}, {3.5983472012255*^9, 
  3.5983472474684267`*^9}, {3.5983486860576878`*^9, 3.598348693428831*^9}, {
  3.598349708714876*^9, 3.598349708978825*^9}, {3.598349750507668*^9, 
  3.5983497564222937`*^9}, {3.5983507747730637`*^9, 3.598350778862563*^9}, {
  3.598728593393001*^9, 3.598728603233245*^9}, {3.598775243476985*^9, 
  3.5987752501088467`*^9}, {3.598778671719615*^9, 3.598778676343685*^9}, {
  3.59881027999765*^9, 3.598810287501093*^9}, {3.598855483965534*^9, 
  3.598855489133478*^9}, {3.598938229084383*^9, 3.598938235692376*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/markusselmke/Documents/Igor Pro/AxHRAbs_zx.dat\>\"", ",", 
    "OAAbs", ",", "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5984417008125896`*^9, 3.598441710843589*^9}, {
  3.598728610337118*^9, 3.598728610609045*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
   "\"\</Users/markusselmke/Documents/Igor Pro/Ax2ThetaDivSca_zx.dat\>\"", 
    ",", "OASca", ",", "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.598810135089028*^9, 3.5988101380486097`*^9}, {
  3.598810293453168*^9, 3.598810297757118*^9}, {3.598855492485551*^9, 
  3.5988554944135323`*^9}, {3.5989382421642*^9, 3.5989382443004913`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large lateral offsets", "Subsubsection",
 CellChangeTimes->{{3.59872712745253*^9, 3.5987271389003973`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OAScatterImXP", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z0", ",", "x0", ",", 
           RowBox[{"ScatterOARayleigh", "[", 
            RowBox[{
             RowBox[{"x0", "/", "w0"}], ",", "0", ",", 
             RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Alpha]a1"}], "]"}]}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x0", ",", "0", ",", "1500", ",", "50"}], "}"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"z0", ",", 
         RowBox[{"-", "5000"}], ",", "5000", ",", "100"}], "}"}]}], "]"}], 
     ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GZ", "=", 
    RowBox[{"Select", "[", 
     RowBox[{"OAScatterImXP", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ">", "0"}], "&"}]}], "]"}]}], ";", 
   RowBox[{"GZT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"GZ", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{"GZ", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"GZ", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "GZ", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Mirror", " ", "x"}], "-", "axis"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OAScatterIm", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"OAScatterImXP", ",", "GZT"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OASignal", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OAAbs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"OAScatterIm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"OAScatterIm", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "OAScatterIm", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5573981170909758`*^9, 3.5573981330180693`*^9}, {
   3.557398163205042*^9, 3.55739824516151*^9}, 3.5573983240682793`*^9, {
   3.557486307536496*^9, 3.557486374276497*^9}, {3.557547571080194*^9, 
   3.5575476165603027`*^9}, {3.557590214826551*^9, 3.557590215520485*^9}, {
   3.557739605798458*^9, 3.55773962377363*^9}, {3.592659733407498*^9, 
   3.592659762095498*^9}, {3.592659993434525*^9, 3.592660004469644*^9}, {
   3.592662249946953*^9, 3.592662257387151*^9}, {3.592890076894423*^9, 
   3.592890077183715*^9}, {3.5982851187028627`*^9, 3.598285128027338*^9}, {
   3.5982852142107067`*^9, 3.5982852442343397`*^9}, {3.598287027612644*^9, 
   3.598287029885201*^9}, {3.598294339961944*^9, 3.598294340425638*^9}, {
   3.598698977149907*^9, 3.598698980293133*^9}, {3.5987285647953987`*^9, 
   3.598728566580104*^9}, {3.598810079866789*^9, 3.598810113538896*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SignalP", "=", 
   RowBox[{"ListDensityPlot", "[", 
    RowBox[{"OASignal", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Blend", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Yellow", ",", "Orange", ",", "Red", ",", "Black"}], "}"}],
           ",", "#"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<x[nm]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z[nm]\>\"", ",", 
          "\"\<R=30nm, Gaussian BSC, \[Lambda]=635nm, w0=315nm, \
Rayleigh-Signal\>\""}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CabsCP", "=", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"OAAbs", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1600", "/", "4000"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"White", ",", 
         RowBox[{"Opacity", "[", "0.3", "]"}]}], "}"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PRed", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"SignalP", ",", "CabsCP"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5982869759501467`*^9, 3.598286978847269*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1642, 1006},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 20, \
2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 1983, 57, 244, "Title"],
Cell[2553, 81, 761, 18, 146, "Title"],
Cell[CellGroupData[{
Cell[3339, 103, 3266, 99, 154, "Input"],
Cell[6608, 204, 10132, 275, 206, "Output"],
Cell[16743, 481, 10930, 295, 210, "Output"]
}, Open  ]],
Cell[27688, 779, 70, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[27783, 784, 519, 9, 67, "Subtitle"],
Cell[CellGroupData[{
Cell[28327, 797, 2687, 67, 114, "Input"],
Cell[31017, 866, 1568, 29, 33, "Output"],
Cell[32588, 897, 1478, 25, 33, "Output"],
Cell[34069, 924, 1496, 25, 33, "Output"],
Cell[35568, 951, 1464, 25, 33, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37081, 982, 584, 11, 67, "Subtitle"],
Cell[CellGroupData[{
Cell[37690, 997, 4893, 129, 199, "Input"],
Cell[42586, 1128, 44866, 749, 351, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[87501, 1883, 814, 14, 67, "Subtitle"],
Cell[CellGroupData[{
Cell[88340, 1901, 11852, 341, 405, "Input"],
Cell[100195, 2244, 36136, 648, 252, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136380, 2898, 666, 15, 85, "Subtitle"],
Cell[CellGroupData[{
Cell[137071, 2917, 9701, 255, 253, "Input"],
Cell[146775, 3174, 42947, 748, 319, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[189771, 3928, 991, 28, 76, "Subtitle"],
Cell[CellGroupData[{
Cell[190787, 3960, 3855, 97, 97, "Input"],
Cell[194645, 4059, 324042, 5415, 342, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[518724, 9479, 449, 8, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[519198, 9491, 9251, 250, 250, "Input"],
Cell[528452, 9743, 1132, 17, 28, "Output"],
Cell[529587, 9762, 1181, 19, 28, "Output"],
Cell[530771, 9783, 33874, 571, 241, "Output"],
Cell[564648, 10356, 1391, 22, 35, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[566112, 10386, 539, 11, 164, "Title"],
Cell[566654, 10399, 544, 12, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[567223, 10415, 2830, 73, 94, "Input"],
Cell[570056, 10490, 4422, 81, 348, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[574515, 10576, 587, 14, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[575127, 10594, 4484, 121, 138, "Input"],
Cell[579614, 10717, 2771, 38, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[582434, 10761, 415, 11, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[582874, 10776, 13076, 291, 256, "Input"],
Cell[595953, 11069, 4083, 58, 28, "Output"],
Cell[600039, 11129, 116364, 1931, 254, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[716452, 13066, 392, 9, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[716869, 13079, 9425, 263, 304, "Input"],
Cell[726297, 13344, 13102, 237, 337, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[739448, 13587, 359, 9, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[739832, 13600, 2794, 53, 52, "Input"],
Cell[742629, 13655, 4750, 67, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[747428, 13728, 1079, 33, 68, "Subsubtitle"],
Cell[CellGroupData[{
Cell[748532, 13765, 15834, 458, 511, "Input"],
Cell[764369, 14225, 377, 5, 28, "Output"],
Cell[764749, 14232, 10867, 197, 369, "Output"],
Cell[775619, 14431, 20444, 359, 248, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[796112, 14796, 485, 9, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[796622, 14809, 9904, 293, 335, "Input"],
Cell[806529, 15104, 5441, 107, 369, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[812019, 15217, 245, 5, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[812289, 15226, 17829, 499, 543, "Input"],
Cell[830121, 15727, 96, 1, 27, "Output"],
Cell[830220, 15730, 10799, 196, 369, "Output"],
Cell[841022, 15928, 19267, 337, 248, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[860350, 16272, 1030, 23, 146, "Title"],
Cell[861383, 16297, 497, 10, 67, "Subtitle"],
Cell[CellGroupData[{
Cell[861905, 16311, 4251, 115, 205, "Input"],
Cell[866159, 16428, 867, 14, 28, "Output"],
Cell[867029, 16444, 1086, 20, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[868152, 16469, 206, 7, 67, "Subtitle"],
Cell[CellGroupData[{
Cell[868383, 16480, 3262, 91, 131, "Input"],
Cell[871648, 16573, 4217, 81, 209, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[875914, 16660, 654, 18, 77, "Subtitle"],
Cell[876571, 16680, 5658, 166, 148, "Input"],
Cell[CellGroupData[{
Cell[882254, 16850, 1707, 46, 80, "Input"],
Cell[883964, 16898, 153933, 2544, 323, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1037934, 19447, 2197, 53, 80, "Input"],
Cell[1040134, 19502, 347486, 5717, 320, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1387657, 25224, 115, 1, 80, "Section"],
Cell[CellGroupData[{
Cell[1387797, 25229, 7231, 201, 199, "Input"],
Cell[1395031, 25432, 5448, 112, 252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1400516, 25549, 172, 2, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[1400713, 25555, 6403, 182, 233, "Input"],
Cell[1407119, 25739, 129991, 2202, 237, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1537159, 27947, 156, 2, 35, "Subsubsection"],
Cell[1537318, 27951, 1061, 19, 46, "Input"],
Cell[1538382, 27972, 313, 7, 28, "Input"],
Cell[1538698, 27981, 417, 8, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1539152, 27994, 113, 1, 35, "Subsubsection"],
Cell[1539268, 27997, 4446, 122, 114, "Input"],
Cell[1543717, 28121, 1775, 47, 80, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
