(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   4745907,      81833]
NotebookOptionsPosition[   4742986,      81742]
NotebookOutlinePosition[   4743422,      81759]
CellTagsIndexPosition[   4743379,      81756]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "EM-FIELDS (near-fields) and Poynting Vector-Plots\nExample Calculations",
 StyleBox["\n\"Light Scattering from a sphere arbitrarily located in a \
Gaussian beam, using a Bromwich formulation\", J. Opt. Soc. Am. A, Vol. 5, \
No. 9, 1988 (Field expressions)\n",
  FontSize->12],
 StyleBox["Implemented by ",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Markus Selmke (selmke@zr.uni-leipzig.de, markus.selmke@gmx.de)\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["If any of this code shall be used, please ",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["cite the appropriate Journal Article",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" reference:",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Nano-lens diffraction around a single heated nano particle\", \
Optics Express, Vol. 20, No. 7, pp. 8055-8070, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", M. Selmke, M. Braun, F. Cichos, (early version: \
arXiv:1109.2772v1)",
  FontSize->12],
 StyleBox["\n",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Photothermal Single Particle Microscopy: Detection of a Nanolens\
\", ACS Nano, ",
  FontSize->12],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic"],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1) ",
  FontSize->12]
}], "Title",
 CellChangeTimes->{{3.5215555775512342`*^9, 3.521555594875887*^9}, {
  3.521557503283558*^9, 3.5215575314578533`*^9}, {3.532076727719061*^9, 
  3.532076729051992*^9}, {3.53211414098179*^9, 3.532114150162614*^9}, {
  3.5323692225660763`*^9, 3.5323692484039*^9}, {3.532431102089347*^9, 
  3.532431299376902*^9}, {3.554281314181758*^9, 3.5542813180666037`*^9}, {
  3.554527298627236*^9, 3.554527298921464*^9}, {3.5545273737991667`*^9, 
  3.554527374029914*^9}},
 FontWeight->"Bold",
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Test: Fig. 6 of ",
 StyleBox["\"Energy flow around a small particle investigated by classical \
Mie theory\", Phys. Rev. B 70, 035418, 2004, Z. B. Wang et al.",
  FontSize->14],
 "\n",
 StyleBox["used parameters:",
  FontSize->12],
 " ",
 StyleBox["nmed = 1.0; Nmax = 6; \[Lambda] = 635; q = 0.3; R = q/k = 30.319; \
w0 = 28100; zp = 0; nParticle = Sqrt[-2 - 0.2 I];",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.5545258380243998`*^9, 3.554525853587685*^9}, {
  3.554527247755272*^9, 3.554527338854006*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsnQl4VNXZx7taq37WWpeCW2sttXVpbdPNrlqjbV26pK22to2KS1Ox1qRs
HQR02CTKMkBgWEelgUJACFvYEiAIwxLFYAlLRCMEaoBRghp0bOb7zX1nLjdz
7z0zmQSycP4PD89k5txzz/Iu//esn7/n4V/f89EPfehDL374Qx/6CR+inyMa
GhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoa
GhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoa
GhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhoaGhot
QENDuK2LcNxRU+r3ePOj8Hri8Hq9geojNQEvv3jzfcUha+Joaq+n79DhAxye
y/eX7myaYb4vUF5Zk/DSuqpSb05WRmZmVlaWx1dYHPAVVdXT3qV+rzxLTqU1
DaRsqCnNj37j8fhKG8znw1I229vHz5x07Huv5NAE4VBpwJuVaSArtyhYLV/z
Fnku+t6qysJ4KfILg+Fjv3ryCyucG7G+wusttr6sJoVGqAkW5RlFycjI8gZK
62KyFm0EedQTr4Kt2V06xTN2+livtVny/YW819YKiagr9/nK6xQJwnWVvtys
DAqamx/weQsrQ2aL5ftLjiQkri3PN4ojrad4i9lKlNZfeqx9opnnemK9GAi6
KWG84vFG9hdWVIesCRLfGK6Jy1e+SIy/sKSqzmiehuoAUi/fmjnyjXcSTRr/
yltcFcsfAc7PiXZeVla2x19U7PcWvvifgIvsHauORVopr4N8amh0fBjGwSLw
Xl9xeVWDRWGj+l6Cvoettm7mjLF5cesfKDesgaGV0V9zPSXVZID19mAuM7Ny
/IVkVXQkmmfAVFmvP+4jQtVFvlxDPbOyc33FhoNpUkR3i51gixKgMOwKNa8N
FsYq7vWWVstrsfNRM8nb1pRYqtDEhTVxrG+m5aSOtY+RX9RzlFcesdUrinCV
R5osjozM3Mr6aGMVe7O7dunStUumv7w2ae9Xl/iyjIYPBI8lrirxZWZ0oed8
xZXH7Hl9ldn/WTmBBNudk+WptPTQkdpgfm6+5ZtwVWkgJzs7SiH8pU2ebYJQ
YU6mp7g6mr4kkBMtWY6/pMosg2NpHb9MLFi0ubJLa9sPRWwoz8+im/KKgjXV
UVSWB2jy8vpIuL46P4vu65LlC8YTh6tLPF275FSGwvzqzeDX7JJK47HqqhI/
3Z0fijSUeDOjGRYGq6uCaB6fM/PLzRzKfVGpyPIWVdeFjoRqSow/c4oMTlVf
7cvsYqQ33xgp9fCNhzdaCx1/e5bl7Tm8vS72fUZxdX1iRUMVOVFpzCmvofQN
VaU+XpThKTakOhyMFr5LdqAy+kddMNtIWRnPo67cK7V2bMHqolzeWNKEpKgb
ob7Y+MZXWtUQDodqyvOM1wVFHBtqbFUIV0VfEWt2RafwbL7xLJympqqi0Jdj
KGB2SbWCM9QHyDDT764LtV4yyS2qra+vDhZmUhF/1FYcqSnOiGbeJVDVJPNS
T0b0pVn+2iZfO74lJnsoWkLLHqk2Ms8prFMpSkNFIEdEF6n15UQLk2P0oNsb
42KTU17FE8WGPHTxB+uOVCAMGf6SYFVV0BOtbGEVEhWgVTODofoSo0b+oCht
Q6kIcH5xTageAS6SrqwIhd1lL1ad3MLqmI4FvZldvEH3JtfQ6Mg4Ul0Uta5R
gccy5xoGwVcbFjuGwsa9eYNVZWLqjL2qNvOpDEQtjOFPK/0oWjbWO1RbEbWB
GX4hJNUlXsOSxyLKUEX0ka4ZnmB1XUN9qLIkaue7Zhda2YujxXazRU2hMuzu
al4vT2X4LCyrviKrS5d8gxpZq+DuWNN0UvHMi+iL0kKv0Tj5dkIWri0Re37s
X1aA8pTnU/IoH6j0RdunsMrmWC2oLSX/zPK6cENNcdRmVkRNXG1JLt1RGiz1
5UQNaVHcGVVGq5OZZYxleEus5Dlk0ICsYOxVDYTNRpHMbyJ1pZ5Y3REhuuCY
2bci6gLySqJ1rSkih8x8f352tG27eIwvnUvr9KVzweqDmdGUivY4oWgwlMVf
eayDqooCFcZfVVHdiVbcWxrr+XB1YWZOsfFRHGXA4q5DhflFoaj2+S0Z1vuj
dc8WLl0bpRwxUTRRkZ/R1RunJQ2VhnvNLBG3WVcSbVUHj+fw9kD07TH3bQs6
6guzm0hCNO/S/KhKFhtmI1yVY9APebAykG1tk0p/VnZhdWKWMRg8pwmzikLR
CDXFudYmNWpdkR1XHHkdRa2wFLWBnvCUymdlp8SfNdslpu9ZbvLGs12d+Ngx
1FdkRt9VFy9pfoZHDFd9vuh7TpElyEK2o19m+5t0sdtbYrJXYTMODZVYuSy/
o3paUlVZRVe0LNbILm9sKh6h8kwjaggF87P9ErM3BFBOX+y9RTk5CIy1SWMC
7G8S9pbkZoi5dpE9p+rUlBRVaCKn0Ulh2AFT4A2X3SW/ItTQxCrKT1ZbFy7O
zTCYnihjyJcRc8QxE5plGnzMda74fskzS1QyZNifzCZExQjT8i3K5myxXW1R
UygMu0rNG6K0rWumzyxGuDrQNcN3xF4Fd8eanpOKZx4rVXVhTkIXCKLUKMtb
UhpFSaF4xhqxkGL9JJ+uOcWuRDdclR0P80G5t0t0aAXP6/XHHVUlueVLABtN
7DTeEpeWBA9oVPbYNxW+TLOJog7RG7TnUxXIiqep8WTkxPpI2tBTEnYsrXMV
XAtWU5xjTdC2iElm3N+Fyv2BeC9X+LLz/H6DCWQUy0xQfdATk/8EeQuX+GV0
K0HUxb3mGKOZtUaskVuVIArh2vKKY40RCvpkSKfB8Ko5xY4D3QlvDwW8EnM5
O9NwjREhesubfl0THX6JJw5GQ48uxTVhowz5RkRZYpS0Nq9Lhtvo7ZFgfkaO
PxC1P9lNhoJdG0F035NQKyPw6VJkNLKdyEWbPT5KqewUh2drjYjMjRSV5GZ6
CgujueW6aKiYoC4ZfpnvgBpWyIdQwOPxZGdEixEfYebtmZ78qC74EqiO81uk
lXx2SmO8NCETO5o+3hDt+njdXd7YVDzqSjNk+DdsrqKI9s6x94bDkSZNWmsM
eOZUNuW84dpgSaWayFU0sfCwYecQUkOjU6Cp/tYYA3G+YChuFY/pT9TbWu1V
Q5UE8tjbWrzkMQvfUGQMuWfnl4i215THZiklzyzjXVUGtzGjzjhCJUVB85Vq
i+1gi5rC3bAnUXOx8CaDKodbxF2btQoKxxpJy0lJ5tmB2ORypTHsWVSTaOyr
igtNcmeEq5nEsEcq/F0TiFzTRmuCUDnm1BfPpcbIxOqJjJJ4ZMSzuignPvSX
FZtJlzYjNs/010Qj9CbPJvg1oaN5hZUNoSBtnldiIwkGqY6TxrrKKlMkDDcB
E3As7euuVXAuWLgacW0ncyvS0V2z8wsLCwMBX5ZFmCvys/IrG4yIxiBg9GB9
eZxRGPLWJdsf4KlCf36OGW5IhnlFFbXVFTL4nB0wRNQYTDYDiijCoYpgsKKy
qqqywrrAqVQGonGaWYVu40Tydh9vLyz0ebLib3d2piKQWf4Kx0wqYuukomM4
hvEJG8N3MQEOV/mbxkdWRKmmvzosQh6bIFY3QmzwLbGEwval5R2IXKj8GJFT
dYozCcxqOltt+Qm5za2NzYdmJtq/OCoKc0XpMnJ8lcd6qc7vKawywtgMrzFa
GA1nsoK10SnsJhzM/S2tR+TCVSX5xwJG1zeKeORX1dZWlhflGNM6RU0mC5oS
OQPHmjQmwAHnRSZKIhft9IwcZBWB9WYnr5qGRgeGRX+P1JTnyLxYKG4V/cXl
5dGRH/73RwlVE3sVEvKQkZEwF9NQXZwZc/3ZmFXzewsLErKXpfSrSSx2ikTO
wbBHkqm5zF1mGx4tXJVlmTdxIHJOjjWSlpM6EidghUU4ymzj8XKnhCYMdppd
1BCdrs23Ebkms1pNXlTRpAElfWxmrb6mSBbaZeYLhWwI1VZVBgt9Mc8S47dR
XhSlo9HqKIkcRQsYE7XR9ncahzT8o9NcnjHm5imtcyztc0vHO1fBtWBGZylG
KU8gpKNzUK6obqEKcR5rcAZhmxUyqJhdeKS+wtuUyBWVlhuDsd6MpkQu/s8y
fNpgI3KQjCKviEepdZQ1XJUnE4KuWtXk7cX+3K4ZSiLXRFMSMjEls84Yb/FU
15ZmZuRXlEeZkqe0OujNiA/v21Bb3LWL16AJxuBeF6+ZzrUR7GzWQBIiV9+E
yLl3itOzDZUyMGUvfpU/S0xNQ1WhU/scQ6iqxKA90WC5KLbmP+TPpRb1Rkya
ScQbKsntmouJqEzgYIq3tAqRw+YbqzsyzT0j7m+UHs/MjNUl37ZYVUnkHAS4
ybPqEbmMXL8hrdEl2868WkOjc0AoTZeoZkZdrcdfYSyZjSlsVq7PZyxy9+Xn
WUbRTcSWbRfbHHR9dSA3trAkxx/bBmWx7SGZ6KxwGzKKJLfYKRI5B8MeSarm
4WJjULG4LnKk3NM1tzQhzwQiZ3esBprtpCRzYvCSkiKfsKlsb7DWtY1k9kpG
NY3FhCkTuaYNKH/K7F44VFNZESz0ZNnnxcK1pVmxADwcXaNSLnPIUb5k2Rdh
92vhcm+MyHXNyLV3moMfNFBVmN01J7pNxrG0E+b4nKoQci9YvT+ryYx5GyJh
uPtIZZE5xmpyBnNkOysnJ8d5ajUSLCqxErlAdb3RmF2yfcfWv2UbnLzJwE+4
0j4TZ2bu4jHtb68v9hU1n8gZoUfGsfJUFcbGe42B6OqceADoNpgsA90ZBuRB
kwO7NoJMz9m6XoicBCZ2ISS+yPImEjmnTnF4NnwsiEuAmDKj/LGaJk4aRh9v
qDenHUtl90SMM0eJXCg6Pxml4tn+Im9mRlGNnYOp3tKqU6up1MsQj6zCcGyW
P8O2djcJkXMQYMuzqU6tYg4K9dSqRueFCLxNfxOW8URik6GJDrfp2lcD4YYj
8YdqgwEZmpMZRqttl+nLQrflvilY7BSJnJNhT67mUq+s/CJ/doZ17a5yavWY
Y421WDOd1JGma+RCQYPXuQeSFdFNDTEyHGetTaZW3VYRxjo3/rOx+SIzIXEp
7CvD7vvoFN8+43GPQfE9OdFuysk1N/km+rWaIsTGA3OtLZeFWIlUwZHIGUWK
UXfH0pYHHb5cF1QUrD6Q7WLzTzicBLjG542yVgtniBICjxFeEQcYfzu4rYbK
wvzialk16ou2RshvbLH0xKaww7IB0Gcd+3ZWeXefmCSBc6m8RaWeLk04m1FL
Y+Gc51hkJIumohuajJGaoBEYds0tcS5CdBbeuq3AWBcalyj3RogZk6arFCTO
ypXvDFXKssaVli0G6k5JXBTKo7J+uNC2cTWElGYf26dQU+zpKgtcm6LSl+U5
tvai3hLz1uZn+yyxbZdYbvVizSpSeYuT7FXnewpDTlJR7ktcjOBoe5VvtIgH
IW18xseC+oCCyBkxY6IAS0nqG9xlr8pRyIN+X7KF1RoaHRNKImdVWJu9ck4W
CZVm5xSZf8meI+FgVhYUMqYCMzyJFruh3tjMqbTYrrYoISt3w56CmscegbdY
s3Uicg6ONV7s5jgp+yCGTCs4TdAYMIy5ua64TrayyuxtQCiTK0s2cvbEt+AZ
ZjMngVMHvQ7jM5W+zK45JQ11FT5vDJ4cgyTneEriA54JxKw455jLi+5ItTEB
u1yFq4syzKXp4VDN6+sdSvumQxVefl1RsHY0IicjKqYAh+trizwZwtiN7XhN
9nlmHhsnkbXl3jgfCR+pDeZEQ5WG+L4YWYcvY+zxbcv1cgZIZlFlnFIZ+2Js
AYJknl3pOvcsCXIS903EvveYpQrVlGcbNEb2UGT5ypvufM9pun1HRmxiUiGD
zPkuSy6iy3Q9TYpdbiztE8qkagTZmZvhjY8GhcuNnd358Z2lskok0xNf41pf
mWfpIGWnRAymERv9PlJbZazp7ZLjMP4Tyo+u6rSqWXVe07kGwZFKX3TiOzYU
bwxkiS43BDMIuIyvZeVqfJ1DpWVJXpK3xGQv3sINyF6uUZcmmUSix8VEl8B5
EstmLBT0N8lf/caY0MbeLitAMrwWTl2VbTNWVVF1ji+3CJVnJQhwfU0gp0tW
NDp2lb2E6kTCDdWlseocqSrOy/XHZ3jDFQGPx1xyE67x5+YWK/f7a2i0R4QT
11cIGmJk6dhicVnVljAZKmahiV4LSSiOrdiXVSXCZIzZLnPEqb4wdgyRubuh
obLIE/VTySy2qy1qCpVhd1fzY1Urj28ItbZWkyq4OtZ48mY4qWOZS0XCoRKD
+Jl7HxIgK8csuTUU50bNXUU4UmsYea84qVAwLzPTW5ToVmSbp8zX+DKwipVR
m1YUKCo3HHW42hNzZKFiX36gVDb/VWTbxhnsU6uyKcb8JrprNTZFjvfJNs+i
MWFIWsaxpVl10V0MOYGSYHlpUaHfk5WJt3IqrWMVFAUz+iK236QtUVPqM0+P
McabY5/9L+4M5BpUH1m2HJBIyJPpDUbCtYFc2YobDQ3iH6JebN3yeIYZWYFg
tKWPVBbKN16JKRpqCmWmPiMzKzP6bGa2p+kCOfxXVqxIWblO5/rWBswE2fnH
RKBJqYxfYyWJOe5QZbGcxZGTE02WkeO3736uLsy2LJ6s9WQ4D1nXyNL6jOyS
ePHqKgqzY62XNWXGiCSNUF/tN9ZqZufkGMQgu7iyyWBhtRx/RANkRU2Nt6S6
acWdOiV63k68+vGuzMrJL6+263iDHGSXke2Lt15Dud8TK3O231oUmZmN7u7M
zo4myPQE68Lh2vKcTOkgT1Tpw5U5WdGohO/zsuJrUPNL5ijf8oKL7D27uiQv
M8PyfexzwnEBteV+mWGJnjMZaw1lvf48fIxNbII+abHs8tpwuC7oycqMNXuu
30jQUOrLjRUsIyt2UmioUg5EQoAzo42Q4S2uVMheTW2pWZ2ulurI8VNVhRQp
I07M6/0Zxw7IitSWRGtd6GxyNTTaJzACnmNG4NhB7rWl/vhuhUx/dNAjbNor
zEhF7AC0cDAQU1j02mOe8Wssg4lqYmZWtqF0ovIYgayMmDLm+cuFXZXKyXVo
ebZxzltuIYwvVYvd1BYlzNIec5c2w/5YYLpCza155BkbQk00qcL45ya5OFbr
BE6KTsrIPJCVYc0nWnJvYdAlucwWNT1WoqHamxlt9gzLukQZlrRPksb2IGTm
5GVnZOTKYGZs/Y9hLbMLY7tUarxd4l9mZBdV2iY4ojQsp9oMbwvzs2KLLX0V
sgy6odqXHe1NT7S5sh2iXWNTQ4x2GgSySSPExtDspXX70rFgsdViSafj2xhh
Z5oZbpULL8L1dXW1dXWhE397xhFeXFsbqnd5cbjJhR6tU1kXhOtDlKQu5DLk
0hD9tbamJmTVuuPaKc6QvMOhujrXop58aAjV1dTU0HktbveGujrLEt76UJ1F
MpFVff2DhkYkOkRmzI7WR+1QcmvXUB+1rKG6UPvTn1aw1SfQSckbQjjr+qZH
gLrvk6WPEtxrQ0P9kfqEtOEjIdAih2IIg6sFNuaJfElXr9lL6/alwysIw9vH
AjkNDQ0NDQ0NjVTRUJWXmdM+jk9ToKE4p0v28ZvRiC4gdN36oaGhoaGhoaGh
0TI0lHizvc53CrQw48q86HqA1s9YQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0ND
Q0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0ND
Q0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0ND
Q0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0ND
Q0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0ND
Q0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQ0NDQyMBjQY++OCDYDB47bXX
nnLKKT/+8Y/Xr1/f1uXS0NDQ0NDQ0NBICdXV1dnZ2aeeeupZZ511xhln3Hrr
rYcOHWrrQmloaGhoaGhoaKjQ2Nj43nvvlZSUXH755ddee+38+fN//etfX3LJ
JZMnT27romloaGhoaGhoaCRBfX39+PHjTz/99D/84Q979+7t2bPneeed5/V6
27pcGhoarQZZRGH/JuFLDQ0NDY0Oh8OHD48dO/aiiy4qKCjYv39/r169zjnn
nH79+oXD4bYumoaGRmvirbfeWr9+/fLly3fv3v3++++3dXE0NDQ0NFoBQuTO
O++8xx9/HCLXu3dvTeQ0NDof9uzZ8/DDD19wwQWnn376t7/97YULF7777rtt
XSgNDQ0NjZbi7bffnjx58ic/+cnf/OY3MiJ37rnnPvbYY21dLg0NjVbD+++/
P3r06Isvvvi73/3uT3/6U3T8zjvv3LVrl55a1dDQ0OjQwIxj4UtLS7/yla98
5zvfIUi/9dZbL7roIr/f39ZF09DQaDXU19d37969S5cu06dP37Rp0w9/+MML
L7xwwYIFR48ebeuiaWhoaGi0CP/73/9qamoeeeSRU0899YwzzjjnnHMeeOCB
gwcP6lBdQ6PTYOfOnd/+9rcvu+wyora6urq77rrr7LPPDgQCb7/9dlsXTUND
Q0OjpYDL7dmzZ/z48X/5y18mT568d+9ezeJSh7TV+wYc2032Br733nvm8nLd
vBonGFu3br3mmmusRI6orWfPnvv27WvronUMvPvuu9hJPrzzzjuHDx8Oh8NW
Lf6fgaNHj0oareAaGhonHjLH2tDQIGxEzJFGKvjggw9efvnlZ599duPGjREn
Gy5Ebvv27aQpLy+nkduimBonNSorKyFy3bp1W7ly5cGDB7t37/6pT33K5/O9
9dZbbV20dgrzbJYjR47Mmzfv6aefRsH58I9//GP48OG1tbXWlBhMIrX58+fP
nTsXntx2pdbQ0Dh50WhBREeUKYPYfPr06ffff/+kSZP2798fcWk6vsRjLlq0
qEePHvn5+Xv27DnhJdU4qQF5u/322y+77LKFCxe++uqrN99889lnnz1z5kwd
VrhBFPnFF19EZwcMGDB79uyHH374wgsvPOWUU7Kzs2lDU9NNm1ldXd2rV697
7703GAzC69qy9BonAdzOgdTnQ2popAg0JRwOE6HjHwsKCurr65PqDk5z6tSp
3/rWt/r163fgwIGIJswaJwrwij59+px77rkPPvjgiBEjYHTf+MY34BsffPBB
WxetPUIU89ChQ927d0fBKysraUDir7vuuuv//u///vSnP0Hk7E/973//27lz
56233nrLLbds2bJFz2toHG8gqG+//fZrr722e/duZBIRPXLkCIKnPYuGRipA
U7Zu3YqR/+Uvf7lp06YUFQdF+8c//nHjjTfOnTtXx+waJwzI57p1677//e+f
dtppp5566ic+8Ym+ffvKGLKGIwi7nnrqqSuvvJLgizAtYsyx/uUvfznzzDPd
iJzMsS5dujQjI2Pw4MH//e9/NZfTOK44cOAAcdk111xzhYGf//znK1asiOgh
Ag2N1IAGeTyebt26Pfnkk++88479/iPHsIhvsPM/+tGPsrOzd+3adQLLq3FS
A8H74IMPKisrhw0blpeXN2PGjLq6Oj0Fo8D69eu//vWv33vvveYsKkTu/vvv
t47IObYe1qBHjx5f+MIXioqK9My1xvHDe++9V1VV9Zvf/OaMM8748pe/DJG7
4YYbli1b1tbl0tDoMHj++edvuumm6667rqysLGIx6a+//vqUKVOI3O+4447u
3bs/++yzb7zxRsSyboEE99xzz5e+9CWS6aP1NU4kCC4Qubffflvfz6UGnK1/
//7nnXfeyJEj33zzTfPL++67DyJ39913r1mzZsSIESjy3/72tyVLlvCTldTN
mzfvi1/8oiyla5sKaJwECIVCq1ev/spXvgKL+/e//41MVldXy+ixhoZGUhw9
enT69OlXXnnlH//4R3QnEudpO3bsgMJdddVVOTk5Xq/3Bz/4wWWXXTZq1Cjx
BWLqDx8+PHjwYHwE0f3evXvbuCYaGhoWiJLu3r372muvPf/88+fOnWuOqpkj
ctcaOPvssz/+8Y+fcsopcLb58+dbg7IXXnjhG9/4xtVXX41v1XcdahwnvPHG
G4sWLTr33HNPO+006FxmZuaECRP04ICGRoqAmOXl5WHGe/fuLYojJ8X5/f5L
Lrnk5ptvXr9+PWZ/ypQpX/rSl26//fb//Oc/kTjZw7BPmzYNgvfb3/725Zdf
buuqaGhoNAFKCn+DnkHGNm3aZK5zM4ncWWed1atXr3nz5g0fPvzzn//8Rz7y
EXR569atH3zwgSTes2cPXvWTn/zk008//c4777RpbTQ6LSByJSUlV1111U9/
+tO77rpLzhcKBAIRvXG1E+HEdOXJeWgJAfuf//znD3/4w//85z/NgB2G9txz
z91yyy19+/Z97bXXDh8+DK/78pe/nJWVVVlZGYm3D9Z+5syZV1xxxXe+853F
ixcf70Zzy//k6SwNjRQhS1vB2LFjL7zwQjciB22rqqpC348ePYrf/NznPkdM
9+yzz5qDIfv27bvttts+8YlPYB/++9//tl2FNDozEFfChOrq6tdffx1SN2rU
KITz3nvvjcQPVTh06FBtbS0/IYShUEhvvemgkI5+66236ESCxGAwWFpaWlZW
xv/Lli1bsWLFypUrV8SxdOnShQsX8j+/rrBg+fLlpQZWr169cePGmpoaMqyv
rz+Zl9msXbv2hhtusBI5YbNvv/323r17YXEbNmzwer1XXnnlxz72MYnWIxbu
REf87Gc/u/zyywsLC4+3cknBKOT+/ftfMbBr1y4KqZdha2jYIVyuf//+55xz
jhuRs+5axVGiyxC5MWPGmKcrw+h69uz5mc98pnv37liDNqmIRqfHli1bFi1a
9Oijj1ZWVuKR/X4/wnnPPfdE4q4fv0PEETJAAk3k2j8++OADmBV9B/f+z3/+
A/uCnw8bNgyL1K9fP4/H89BDD8kNXDNmzJg5c+aSJUs2NcXixYsHDhxIXGn9
cv369XzPI9OnTx88eDA5YKDIEwIzYMCA/Pz8Z555Zt26dTt27IAb8HbKQEk6
/WjPmjVrrr/+ejuRixib3R544AFsO/r1yCOPXHLJJVlZWQlEjj9/85vffOlL
XzreRM4cL4WxU4wvf/nLvLRbt274IymShoaGFbK9F+VNSuREs957773c3NxP
f/rTQ4cOPXTokKQkh0GDBp133nn33nsvkW/b1UajMwPPW1BQcMYZZ/zkJz8Z
MWLED37wg89//vN4cPkVdwwTeP31162zZhptC3svhMPhurq6nTt3rlq1KhAI
jB07dvTo0RiTkSNHzpo1C/YF2XjhhRf279//xhtvwLJKS0snTpzIZ7kV9AMb
CC158MUXX0z4nhfJIxs3boS28T+ZkO327dshLTDGuXPn/utf/3ryySe9Xi9v
h0CS7Pnnn3/llVfsx+SKRHX0EwtlSA0i17dvX3NoiyaCL914440//vGPFyxY
QBAET7v66qvhbAlEDu9wyy23nAAiJ6AT6RH4G56F8nz1q1/NycnRy/M0NBJg
WqfHH38cZUmRyOXl5UHkJk2aRAJJiU0gxIMKkh5P2nYV0ujMQN62bdt2zz33
nH766aeeemrXrl0HDhwoR81HLESubQupYQdU4bXXXoO5wRNmzpwJcxsyZMiD
Dz6YnZ0Nl9u1axcG5OjRo1aeJlYIawOpe/rpp82Y0Y7//ve///73vyFybgn4
iQQ7duyQP2UxSdgA+fPed999F3oAkevTp89jjz0Gq5w8efL8+fMhezwL7bQe
gduhidy+ffseeOCBhDVyMGEI0mc+8xkMO59pEPjtVVddZRI5AY0GYYZQXXfd
datXrz4B7fDmm296PJ6LLrqIMtMdsFC0m+Id7/dqaHREoJJ+v//iiy9OZWoV
v4mC40Nnz55tXSN36623fvKTn8Q+Hzx4sE1qoXEyAOFEwDDpuBJc/OHDh02H
IkROXwfZHiARHz21ceNGbAtx4hNPPAENWLly5ZYtWyB1oVBo9+7dU6ZMgSmJ
wWlsCjOTFIkcydwSWImcKS0JOx0wZQgV1o8PvGvnzp2bN29eunQpJfR6vdAe
PlByqAX0r+NO2aMv9MVZZ53Vu3dvk8jRHXfddddHP/rRP/zhD2gQ1YfKdunS
BTtPf1VXV7/99tsRY3yMRrj00ktvv/124qkTUFooNNzytNNOO//88yGWt912
m9XpaGhomBA7tmzZsssvv/yaa67ZsGGDlch1794dIvfHP/4RqytfEhmRskeP
HnxjPUzy+uuvJyWhnFY0jeMNRNQctDGBu6msrMRf46E6rqvtKLASIdMOQHL2
799fUVHx3HPPPfbYYw899BAcrLy8HFvx1ltvwcqk18wDZqdOnaoYSTseRM4N
yMy6devWr18v9MYctUOoCF137dpF4DBy5Mi//OUv8LpFixZBeCB1VjHrELP5
77///pw5cwjYrevfhC8Rhn/mM5/5xS9+gc3HmBOqX3DBBb/85S9nzJghRzXy
f//+/THyGH8eOQGlpYRwy4suuujmm2++7rrrPvWpT2VmZpaVlanbuUN0xMkJ
a9ccpz5qtOH4vasdYu/evSjL6aefjmmV+CtieEaZMP30pz+NWcY+L1y4EB2/
8cYb16xZY938RfR69dVXf/e738WcnjyNptGugLjKEvft27fraOJEApXHy8Oi
4W+jRo0aMmQIZmTWrFmEdXzvtolArhI4YURu586diirA2TZt2kQ8K9cZJBRD
Agfo3FADzzzzzPDhw8ePH19UVMR7O9aR1NjqW2+99Tvf+c6SJUsi8TXSq1at
uu+++370ox/ddNNNVG358uV9+vS54YYb6EpzUU11dTUR/de+9rWZM2eegK2j
sn0JpwNzwz1t2LCBYn/uc5/z+/3mTDcfKFVpaelyA0uXLsUC6Cmh9gkFwUb7
XnvtNez2tm3bYO90IppIb9Kn9P6KFSvKDMiHlStXyv506XTUFsvz8ssvV1VV
YVJO8ouAjx49Onr0aEKw/Pz8UChkfk8oPXbs2F/96leQtzvvvJMPxG6ErlZH
iZUjarv00kv5ad++fW1RfA2NKJF76aWXMAV80CNyJwDYzLq6umAwiIno378/
RmDjxo179uzBmBw5cgRrPGHCBMWKJqzu5MmTTwCRg8LNmTNHvduRd2HrcBOO
e7XEB+3fv3/atGkEs8Swhw8ffuWVV1avXj19+nSYz8SJE6Ecb775JqRI8Zb2
ANgRpf3617/et29fc30pnpTC03e1tbX0nUyLY8xFlYTswdIJ1Xv06HFirnXg
pfQsDBOvTctTHl4NkaPw5hgC5ceVE7vR+AgA/+PN33rrLT2Y0N6A/MgdW7AL
LMaCBQsKCgr++te/3n333d27d4c5PP744//4xz8IjsSGb9myhQ6Fsw0YMIC4
6cknnyQxisafWIMnnngCmkcCrAfajeYiFYQecJh+/fo98MAD5NmzZ090c+7c
uUiISDUFOBmOHiLehK3dfPPN1vUPaLGYa+wboRmaToPIvIOpLNjY3//+90Rz
mMGToaE02idkjZy+POh4wDpPgdPHDmBjMcWDBg3CeBLZ4VKxk+bgG58hOdAe
RYbYmWHDhplrNhzTtAqRg3QR4EMs1XXEvq1Zs0axWQY6MWXKFGiDWTxxT7gJ
WmPEiBGDBw+WklhL295IBeWhppAiTD0+Tpin44SX9TOk7pFHHrnuuuvkKOAT
UCleQXfcdNNNV199NTJGy3/zm9/81re+BQcw2fIbb7yxdu3aHTt2iEuyL7fQ
OAEQYUjY0A0TkFH6efPmFRYWErINGTJENqcHAoGZM2fCsggN6Ds5+RP6QUqC
I1mDKl2JahMkPv/883A5aN6//vUvv9+PteFPCImkEWzevLmkpATjD1dBT8mT
z8jP7Nmz4Xjo5sCBAwk2ESSMCS+C8MNkKKSbwHdc0BpYoWuuuQZzhFlOqJTV
kpvfyAeMGLrm8/mI6TpHU2h0ROhdq8cb2FjsJ0Eu4fNdd91VXFwsu03FsZo+
tNE4x3XTpk0YaresSEyCRx99VOF5W4vIvf322zAW7L+6dkmJHGTGSuSs5aQF
aAeezc/Pv/feezGGMg7Q3uxhY/wEeDzs/fff/9BDD+FJ7bbdTCygN+Hkt912
27hx40Kh0AlbhIYbwhl17dr1TAPnn38+vtgcRYwYRA4vr5401zh+sEsCOgK1
FvqEtNBfvXv3hozBsjAdmGjZnC4QziYWAPZFtMXj1gz5kmeFuQmRI1vhdQkB
+5YtW1atWiUH25pyK2dUys50Xs0jcBVy6NWrF5RywoQJZE5WZWVlqGqnuVpU
zOakSZNuvPHGRYsWKeZErIoPs7399tuxCfjQ9j+toNGJoUfkjhNkpzB2cvjw
4UTEGNKKigqMqrla3s4EcP0bN25UEzmCaMJkxXvFIr344ouwiHZC5PACCxYs
cKQxjcbdIjiswsLCl156acmSJTQXjA6+evjw4fY2UkR5oHD9+vWDy9ERjmmk
T1Eo/F3fvn1LS0uPHDnixvqOB3gLtI33DhkyhNiBJqWvrV6mrq6OLsOJy3Tw
CSiShhX0BVYXFoTY5+bmyuznmDFjIF2oybZt27Ab7777LlxCaFJjU1izgrOh
pI5EDoNDKGeOyDkSOTRu9erV5g0FkfhAk/VFQu2QE8qMXCH/M2bMIFIg+IJw
3nfffQMGDFi4cCHVwXy1txAsdYipoc0JtH//+99TR+yPY0ozrKPpCD/Hjx+/
Z88ezeI02hb4a1wSflMO/uq4mti2kCkSc4YUL4kpGDRoUCAQgCfL5gVsHXRF
LuK0Q8Zw6Is5c+Yo3gIbTErkMEckmz59upstirQSkZMJRyFybkTlzTffpCmK
iorM7WAJwFvhCGbPni1bdPFi5eXlcLnRo0cvW7YM1yNTz43t42DhRmO/KjZc
ccRuo7HHgcLj9drEwpujnUiUvQC4Y1w8JHPcuHHIm17YczxgF1do8+7du9ev
Xz9p0iRUGC40YcKExYsX8yV6umvXLtgX/zcreGkhkcMWJRC5VCqFQZsyZQqy
HQqF3njjDURo6tSpjz32GDqLzQkGgwi/dV+PGwttn5ANXGVlZRgutzSydo40
2E8J005kCTU07MC9onpYA+yJvpAxDVgtNhQOQ11QUDBx4kT8OB5TDg9pjJ8c
gi213qieAAzjkiVLeNDtXakQuYixvI0OlUEwN/vZWkQOsaHM27dvd0tDm1Cj
RYsWubFKqRQeDaIbsZCQ1157jegYsgEPbCcX35h9Lccvu7WtmcB6bkz7AV2/
du3abdu2yZhPeyte54DZqrJxe/LkyX/729/69esHpyJseeWVV9AvjIPZ/hgH
2NfOnTub1R2tPiKXCg4dOjR37lwUXzinjNchS+jvihUroKl///vfsVG89MUX
X+yIJyGY2q1II1MJ7VC7NU5OvPPOO1VVVSi4ecBsW5eoQ6K+vh4jhvl66KGH
evXqdfDgQTHR5lQFf2I2n3rqKcXZy/RCIBAgHnRLIJxnwIABipLwLiwz5Mq+
LM2KlhM5qR10C6tOqdwkR4gchVEMD+LXSktL5fh0a/z+/vvvQzl69uyJa5g2
bdrLL7/c5rGGlRurzXg7GUK0Q9bIyWaHdli8zgFZJiGHKA4ZMuTZZ58tLy9H
97G3pmWwylKbEDmCSmIl6/rJVIB5IUhEW63re80AB33nJ2wdZgHievfdd48a
NQrN7RCMLsVhQ9Oqaw3SaCfQmx3SgFV/MVBQr2kGaEnM9ZgxY+xWi6CVZBhY
GtwtW0JabK/b4ivJZMOGDT6fT128N9988wQQOUFNTc1zzz1Hmd0MGm1FmbH8
bocsyUQkNNi8B8eKrVu3zp49m3KuX7+ehqV9+Macpe0o8zXtChA5GhPy3NYF
6Tywjr/JpuChQ4fm5ORMmDBBDsGWkXlFDgj/6NGjt2/ffoJH5NRziG4vnTFj
BvLjNgssDAe+SuwGhSM4FTbLu9B0cx+B1lwNjdaCJnLNgjUKIzKFwwwePBgL
iUl8zwCUo6CgwL4eTIgcP7lFpuQJKZoyZYpiOyGdBSmC86gL2a6IXMTwF3Pm
zMGGuyXgp5UrVzoSOZlgraysxA9Sr40bN9JEMmujF3elhwMHDsyaNWv48OEy
0a+bsVWAvqAswt+wCWhEKBRC61Nc87Z79+5Ro0bJbujUX9pyImfuWk0dpEcl
UfxUqkYaBAzNJXaYOHHiI4888sQTT5SWlh48eFATOQ2N1oLetZoG6uvrIR5P
PfUUXAhjSBtKuA1JW7Nmzfjx4xPOGYukRuSIXgcNGqTYSMiLyATbqy7eiSRy
EC2InGJqle+3bNmiJnLbt28vKipy3D5AORcsWIAXMBfkHDp0iFLhFKZOnVpV
VaV5SHNRV1e3aNGiefPmbd26FVKnN9y1BOFwuLa2FmLTp0+f3r17I+eYU1iK
OdWYYj6yGx15PsFEDnvVXCJ3+PDh+fPnW6dWFTDHzGXW9fXXXy8rKxszZszD
Dz+Mndy2bVubL5bQ0OgEgBsQlaNQkBPtE5MCsyMne0yePPmVV15JmDGR1SMz
Z860P0jbbty40Zx1tZtrITyPPvqo4u1C5Ihn1YVsRSKnPhBYRhGhBEmJ3OzZ
sxUjjbt27ZoyZYojQaWceA2TyAloc5oa3wSdmzt37p49exIOalCUWcM8R06v
8GkurAImJ/diB3r06PHTn/60V69eO3bskAXwaeQMoUKYZb9P6oCzrVixIuHo
xdSJnPUcudRx5MgRcoZzphECCLml6QKBwP3333/33XcPGTKEukMOtfJqaKQN
/DXqDDk5dOiQPlRKAezza6+9ht3GSNJiMmmSYHYwiYsWLYIg2R+nnZcuXerz
+eyDdQK+IUDu37+/ogxC5FavXq0uaqsQOYwtDE1NGikzFri4uLikpMQxshbL
jM2HyLmduxIxqAXt5rg4sK6ubuHChbgh+9GjtCS/UkLoMUU1bwvVvkANWnvd
unX6QOC0IbvCYW59+/Z97rnndu/ejUouW7YMhpN2npCZqVOnNveyTogZisP/
6RG5rVu3wh4pf7NUBsswYcIEnk17LJcHMaRz5szBoqK/jzzyyH333VdUVNRc
SqmhoSGQXat79uzRAZECUKNZs2bdcccdw4YNg/GaFszaXHzmJ6yTncjxEznM
nz/fHKyztzO0EDr92GOPKYqBCS0vLz8xU6t4pblz5+ImFOO0srEUokVKmKqb
8OBZKLNi2khWbeEc7e+CH8I61q5dm7Ds0BRXCN62bdtwqX/5y1/whooj2TUE
sN+ysrINGzbIDXFa5VMHQghn69evHwQJ9ampqZH7qhBRwjTUM+3GTI/Iwcah
Z3KKo/ll6kSO8kPJUJ9mUTISjxs3DtOR9rUOlBZlnz59uhxVTa0JxHr27IkW
z5gxwzxCQUNDI0XozQ6OMDeYv/fee7QPces999zz3e9+F9uosNUEmKNHj8ZF
2n86ePAgln/27Nluz8K+hBEpSkU3URLFUbSROGmEyMHBFMlSmVrFupKJepyW
XxcsWEBKt/N+G40TdGUIyG0uT1bdUH17JjIlDZHDS7qV4Y033vB4PD/84Q8f
fvhhqLI4Ah2VuAFRxLNnZ2fj5aEfmvo6IkF4EFFkeODAgd27dy8sLETkzCPg
IMMETWiKYkN6UhCgpUHkSF9SUmKukZP/IXIQrVSIHA8GAoHt27c3d2wNuoUV
asn9XJs3b8b+YIUi8dOZiBxfeukluBySiZ2sra11m7zQ0NBIgBA5xeFmJy1k
AVhBQcGUKVO2bNmya9cu2aCqeGT37t0QOfvptWSFycL6KY4Wwb3C4iBgivzJ
WVYIq0veDomcLMpyI1c8u8SAfXIKIldRUcHjinkr6jty5Mgnn3xSJrnGjBlD
1ZrrE08eyPkYSBEMJOECdA0TZrO89dZby5cvf+KJJ6BDtBsEI2Hc+NChQ8XF
xStWrEibEhN3kAO8i65p1oOOmx0gnMQ1a9asSUrkqMu0adPSIHKES3iNlhC5
F198cdSoUdXV1WbJZflcQ0MDRsnn8+Xk5KDIOCY9OqehYQd6YVVbfOjWrVt3
7NiBVdf71wSNxpm6K1euxJLwPxRLjofCfBE4Kx589dVXMUGvvfaa/Scex1Yr
FjPzljlz5rScyMkMLwRMPQPbikSOesnUqlt5qBpkD4olHtDOHHh22bJlS5cu
tbM1EuM9eYW5BM6xDJSzqKgIRodzef311+mpyZMnt9DXdFaYa+T0uKUaBLko
EeEbMQLSGwqFEg78l8+oG+JdWlqaNpEj24ULF27YsKG5Y3poMQQygcihtn//
+98p8PEjcsSksk64WU9ZQcwFN4bOmRpq3d+KHdi0aRMJHnnkEUoIX9VSqnGS
w1xNJKecwTQgJ6bmojKQExQzGAw292TIzgcZ5MfHTZw4ESYAMTNNN/SsoKBA
fYwqv44cORKzY/9J1vMrjnk5cODA7Nmz6RpF/lAUiBz8RF0LOA/57Nq1S5Gm
tYgcZGD+/PlTpkxRDCbgnmB6JHPzdLwCRwOJdWRrJSUl5K8YNIYf8iw0WAS4
0bhtFrdID1J+KZhmLCb0gcAKiJAgPxs3bvR4PHffffesWbOEwrkllhE5NK4l
RG7x4sWVlZXNzUHuVUnY7PDcc89R5qqqqgQix58J9oc/m0vkZHwMXeNBBClt
ncLGPvroozSyW6glo3MvvfQSvdCzZ8/ly5fL4gqtyBonJ/4XB+FPZmbm5z73
OciG6Z3NqdVULpjr9Hj33XexeJMmTdq8eXPCYZ7YzLFjxxJIuj3baFw8OmHC
BPuKffkJcqigyhjVZ599Vn2gH8SSMiS9eBQ6VFpaqvbUrUXkwNq1aym543G+
EaPuGGQ83YIFC9zOjCINwokDchzMhMjRIwoih9wuXbpURuTMDOk76kj5IYFy
erB2AQJCBrp+2LBheHbIgx60tAI5wR6OGDECmkHogdSpN/tEDK1EtQkl0r64
lldAVCAtzSVyW7duhbPJSjMTzxmAnlmJHHH6U089tWXLFmt3E3L269dv3bp1
qR88JSaR2L+wsJD3pq1QdXV1Sc+jbozf+YWFGThwYK9evfigz53TOJmBzv7z
n//82Mc+1rVr1yeffDKByOnNDnK6yKhRo2BK+/bts4eosv5NQeQixtQn1slx
UcfLL7+MLVJEvrgM6JCC6fEsmfh8PsWyf0ErErmFCxcqiJyYcRzBjBkz3Ihc
xBjfIB83Iif8qqKiYu7cuY5EDpI2efJktYhSBl5x6NAha8HoCMQbF4bAy7iK
IoeTBxA5HD3OffHixbt27dILKky89dZbhANZWVm33HILwg/HSHqdLv9jPyFL
BAtpsxpehO5L8NisB2FraHqCYDsSORQEJaK7E/a3jhkzpllkXh6HUKHyLSFy
CCGlQuvV5sWcbN2xY8dvf/vbn/3sZ+PGjZOJkvTeq6HRcUFQM2fOnEsuueSz
n/2sJnImGuP3bdEaxKoDBgy48847V65c6XY2SP/+/QkkFRlC86ZNm+ZG5Ah+
FXZPiJyCbGC7iNnhmUmPq2oVIsdbhMglHSXARxCeq4mcjMhJVvZGaDTO0JMj
uRISyE/Tp0/H3Shab8OGDSUlJULk7GfC4NE8Hg/1Jf+TxAUo2ko2O1RVVaU9
gtRpYFZfVpgQaj3++OMrVqyALUAzUlxqgumYOXMmxCntYhDg8LoElpUKUidy
skYuYVh77969gUCgWUf7SglpK6rckqlVTC7Fo1RuN90kgCgvPz8fUzN48OAH
HngAvk2tGy1IrxgaGh0FUDVISJaBoUOHXnDBBSNHjjQHtE/mXaui/phrGAvh
6po1a6BhjkfgwkCwOT6fTzER8Pbbb5MDzMduVfCYxJ6jRo1SFIYuwOSmQuTc
thWYaK0ROdzB4sWLk067CJFzHEwTUP1FixbNmjVLceAnPmX+/PkbN25MoME0
JhQRr8FbFFP/PGgSuYTH8RS8nX6R2x5XrVp1Mhy4Id6NTiT0SDjiTx8IbAWM
ghjhqaeeIkxbsmQJzSUHTRPbpsIx0A4kijA5YX6zWYDIjR49urkXrUaaT+Ts
a+Qgcrw3DSJXUFAgp482q8BWwM3KyspSOUVZlqZgB9BcOoX+wlDTXyi1uXAu
7WJoaHQITJgwIS8vr1u3blOmTEH+P/vZzw4aNMgMNjHy6AVB2WED/HnybPeW
U0EI7mbPng35qa2txfS5ETloALZLwWpgEUuXLoWw2X+SGx8wXAqDg5mCTKqJ
HD01ZsyYE0PkcHCYWVxb0uPWq6ursaiIkCLN6tWrIXtum3bliJLi4uK1a9cK
W7MeSmASOYVkbt682dwUbN9XuGLFCtngQ1bTp0+nxw8cOKCuVCfA/v37Bw8e
/Nvf/hbZs3pqiBwRB7JEEHeS38qHGUQsf/e73w0ZMiS9i96wDOga8t+SiXuI
HMZZMabthhYSOSQEBmvdOpoU0ixw1/Hjx7fw5F7sD3qt2I1uhXWHNcKM6GKa
fv3rXw8fPjzhhjINjU6JT37yk5/4xCc+8pGPnGbgwx/+8DnnnNOjR4+IoZWw
AlnwsHz5cnjIxo0bTxLbDlHZsGFD7969oU9YY5oCS87nLVu22BMLkRs3bpyi
cXAKGNWtW7faf4LjycYBt2cxTdu2bYNjKOJT2YmJcU663JfXQZxaSORk3RrF
TmVvBYbdseImRMbcBn6FUeN9cDcJgwP8JHvrEE7FuAHGnOalOo4uGN5CCeUn
Ggf3gWtTL3fsuJBqIiQ47iuuuOLKK6+k5a1NR3/BXgYMGECIRxefJPousMoG
CjJ06NCf/exnWVlZ8+fPT48MvPvuuyUlJQsWLCAKTrtUdAF6nVTR7GghkcMG
9uvXjzCnuTsIMJK5ubmYrJYwqE2bNuF00ibAkM9HHnnkrrvu6tu3L4bxZBhm
1ziZ4TUwaNCg/v37/+pXv4LL3XDDDUVFRZE4kZM1cmEDnX4FkayLI6ArLy/P
z89//PHH5bw1vt+1a5espLU/VV9fj8GEKigi0H379sE3HK91wFjBiLD2bs/S
7DKuRcHcbCNEEZdBHKpegM2vmOs5c+acMCInvFFN5OSIG0ciJ8QDBgtVIx/7
wi3cDRT32Wef5YOicehH/IsbkSNn+QmniZvr06fPU089hXfrTDTGHEpCnGiN
zMxMwjeIHMTVqtd1dXXLli1DkHDEBw4c6PQqb8dbb71VXFw8cOBASA7tAMN5
6aWX0ssK/oba0totGZuiPJgOFO1ETq1KgZ988klySHGhmgk0EW+S9BwkNTAv
vDq9M6+koSg89aKyOTk5Pp9Pnx6s0YlxNA7MBZH4JZdcMnz4cJmeM4mceNiT
ZNUoHOZpA7KKXsb2qfjOnTvHjBnjSOSwNitXrty8ebOifeCBQ4YMcZxhlGsd
1q9f7/asHF7neEeVCcz14sWLccHq2sngXkFBgXpKtHVH5JISOWgqr1NcbMHr
oFv24/FFJmfPno3oum1wazQOcIYryoYIex/JIXXSIDA3mpEMN23ahAsIBoMt
uVmpfQJ1xrV17dr1nHPOueKKKxKI3BtvvCEXbagjgs6K2tpa1PzBBx8kLpPj
hogR1IcuKiC3qKxbt64lRSL6mzp1quK0cDfQiWkTOZMLNZfINRrnNAqRa4n8
YHyI3VKcWrWXgf8xmGSCzXzxxRcJzYYNG7Zjxw59nI5G5wZ2G6dMKIqjNyMX
vBh/mkSuTQt4fCFjca+//jrkbe7cuVSc1uCz+HEZkSOscyNyZWVlMnPnlj9G
ddCgQTAWx5/geIqtwdgieIiceOCWhjLAQEpKStTVxGVjw7He6t5sRSJXX19P
wdR3XvA66ITj+kMT5EACR7YG76JGMgPu+KzcxCF7JexpqCY5iLOWayCoF8Wm
s+CHCxYsEG/SOYgNTnnixIkZGRk9evS46667vv71r9PRCZsd7AcCd+Igzhyo
bGhogM/069cPIvfaa6+Jx581a1YgEGjukJQJtGPOnDkIXktKSAgjm0Cb9RQ1
2rJlC5Fd2lOrID8/P70Rud69e6sD26TYvXs39ja9gEI6dJWBw4cPY/QwodOm
Tbvvvvvmz5+fygYKDY2OC5l2sY4/y65VU8E78dA0VYOkYc3wYjJJB7MiGBci
h1WvqqrCnNp3PkYM31dUVKQYUIrEiZzjyiviRK/Xq9gaDA+BoUGHFPnLHV6p
jMjxOqy3OlkrEjlSzpgxg9wUaWBNOBf1vRXYZBrB0afA8aBbilkYuq/IgONE
IdXEXwuRQwwoydSpU+vq6viME1yxYgXEXqrZ0W+toh1owx8agJ907969W7du
48aNsw7PHjhwgP4aOnRoQUHBhAkT+BWWC7Hp0BVXQCqF+tAgeXl5CAnqbHY0
coXrT3t+GRsCEUp7QE8gW4Gau++VvuYpCp+gF25Ejj/tJig9IkdzoUHQ15as
TKMXnnjiCbhoGo3fGL9tR9ipuC1qsWHDBkJmufC6UwqzhkbEaUMWgUwwGMSX
EaEn3Q7ZcYHR27Ztm5wlLnaDRkDZMW5C5KB2JMCmOa77xQAS7ilObCB/csYt
Oh40B7MaPHiw4tYGmaDBBSuMD55o0aJFL774YkQ5dtomRA4CnDDsYy8VLE59
/atMtUgDJmRFrEHXKIYsSA9Vk1X99mK89NJLFE9mvWUOF59uUm7id8omB2p1
9EBm//79PXr0+NjHPnbGGWdccMEFZ5111kc/+tELL7yQEMOUTD7QrcgzgQNS
t3DhQniy+oDEjo7333+fKExuCDUv/AXEF8jkpk2b0nb6cInly5e38CyXiRMn
okFyMFrqT1ER1By9SBiAciRysuneflRdekQONUnvKgorMLyEt6g8b09jRC4S
37YjdrUxvqEVFYCcy6ZszeU0ThJA3rBja9eu3bdvX0suQW63wObAzSCrWDP4
gBn9oeM4bmI3oa8mkXM0TbW1tXgBxdyoXM6I5bRfu4C9xeIRwCoWrdH4WCSM
j1sCSoudh28kPXe0FYkcXg+Pn/RSTlLCMKm7ggzI8nv19CvdsXr1ahmXsBM5
flKfGUJ16CPHaRoKRvFkwJNfcWqktB4+DA+HIc+ePZsXCZfroMNTNNETTzzx
jW984ytf+Uq3bt2EyF100UVDhgwxW08OBEaQwnF01rv5pFLwnFdffZVYDMKQ
QNQPHz5MU9D1aY/IbdiwgQgijQ2nAikPUd7zzz/fXPOLYYH+Uf6ERZ5uV3Q9
+uij9kDVXCPXLAGg2HIwY9rrS+V1RL6QLmxmeuKHXsOB7YsEEGnMCC1AgNyh
1VlDI0WYBwKLnHc+acdGYXCweERq1mlllB2iMm7cOLFsWFEZ9nEckRMipzjz
FiJHyP/MM8/YTyEgQ6w9PM1t5YY5yQuTdMtf5oXnzp2b9OjmViRy8kb1ykAB
FaR9HNcHmqUi9Mb4K2J/qr9s2TJHtkxJ4IqK9okYN3lRI8fpVzhwIBCYP39+
xKgXTo3WllEUs2qUECZJsuXLl0shO6IuNBrnq1A1hHndunV33nnnpZdeOmLE
CFicWR05ELiFs4EdAlT54MGDtAbS7rgGHm0qLi6uqKhIj8iRP9ICkUtv66WJ
AQMGpLGBOnUiB1+CrKIdSH6CAg4fPnzJkiXNnYuh4pgFMkz7GGSxw0SmkMy9
e/emp2tINUTUnGSxFk82QNH1GKXOt5tJQyMBstmhs17RhQfHTEGiiN0SppVl
EGbs2LFi2WBZq1evdjxgpNE4VxzXDxV0e5GcZzJ79mw7UYHIwSTheApriUOZ
Pn26gqhgtPmV6NXcbuyWkvLLZge3BIKkRC5iHPw+b948SFrSCcdNmzaRm4LI
CX2ifRRjFzQCCRw3ANK88DT1gJ54Fkis/Sf8rEnkIsYBYvy5Zs2aSNOWpJo8
PnXqVJnuUbyrPcOU8/r6eoS2Z8+etJu1mugCdUf4kflOOQgvwLkjwBBauJx9
SYkAuYXI7du3L71XoIyFBtJbXS/lIZNhw4ZBJpu73bJZRO7ll1+WsceExEg7
wRoK0lwqRdvy9jR22lqBHBJlKAJkNYiavV6vGXkJzIrI9hbyh+xhmk7CY3Y0
Th501l2rMjSBjcKmEZrZq4bZlBuvxLLJdoOFCxfas8LZQRJw/Yq4G8YICSwr
K7P/JNc4Ku66kn0WEDkhio69wLOkIRMZMFT0FKXduHHjxIkT3RIIUiFySAXk
B2eXdFvZ5s2bseoKIhcx6FNpaaniGF6qTyaO6+iOHj1K8I4nUuQvC+Ecp54T
iByenZTYf3tK4XJTpkyBy5lN3UH1otE4NI9aJLgwWVnUv39/v9+/ZcuWTnlc
A9wMdSYoQPvs3WfOPpCGCKu520VNoPWzZs1atmxZehIiT8G3CdDQi+auz0TT
m0XkhL2bnEfeTowpGz+bW3ghcmlzYEFlZeWoUaNeffXV9BoQwS4qKiJUdyy/
5AnVpAUGDRq0detWOaOyo6+D1dCwI+Gu1U4j5HgrrBm2y23MgYrDK0aPHi2L
4tREjngZJqBY5Mbr5s2b58gNeApTKZsU7Gg0DmXC4+BVFSRNlvC5beq0As+F
ZyHQVidLkchRKZPIKYytjFiqiRZpaB/FijuI3IwZMxzJMC0DT5ZNr27FoIWx
2I6HlFqnViPGCcb4X8fOihgqQFFJb7Z2ByVybqirq1tqYOfOnc1dYN8hgAyM
GTNG7oh3lFtzYSSRETKT3lFmEaMlocRugpQUUgwykU3TaRA5VBgT1xIit2HD
htWrV6dB5Cgw8U5LpnIoACo/fvz4tIkckN06jtdDmMOwstXlySefxJQpDhXX
0Oi4kF2r2KJdu3Z1ml2rBw4cQLsxUMLiHI05uk8gDD2Qn4TIOV6+kDqRc2Qa
PEVJFLtNIXLPP/98QUGB4qIc2a9BCJx0/IQAHx+NF1MnS4XIEcySBmaV9KU4
I6ij4uqKiGH58SkyoekIXMycOXPIxD4JQhNBw4qLixW75PApkydPpu72n2gT
mBsiITlD5KjXihUr3LLCpUJy8FOpMOcOB3ONXOc4Ny8B6DXkBMGWJfSKCr75
5puIASKX9rFjvGXUqFFod7qFjQK5hXER4DSXyCGZPp/PvufUTuQgS61O5Pbu
3cvbd+zY0RIRouUpZEsuy6MLCJPdLLO50wHFpwWoKdxez7FqdD7IrlWIBMFR
J7iuqNHY3QkZWLZsmXr9D8nw7ObJZpgyHnE8yY2Ad+3atdh8hU+HOhIbynBQ
gmXDbxJx08huz0LSsEUjR46k/d1cD14JzjlmzBhFjQTYRigK5lGdLJXNDnIu
B9Yv6VWMQuQcxzNNQAuhRrSSWwKqTw7wYXs705Vy3peiJPQgtcaF2X/icfwd
OUjkjgefPn260E43N2TOsSIVHX2ONQFC5NTz4B0I1l1a9CysgAqmsg8XgUQx
MX1pT0OUl5dPmzathdtGtmzZgjRC55orXbCXvLw8ujKBmSQQOTJXEDnCw7SJ
HOaohUQOlYdIb968ubmXvZqgRpgUx8M/E0ArYUUJ0Ai6zROo0nuphkZ7Qyfb
tYoNh1HMnDkT3622z7KqzSRyWPVZs2bJASAJjSBXKigYCOlhMtCnhFW7kg8W
j6DYMedIfEUucbEcqOs2SCILaVIhcthkikoLqJOlMiInZ6qsX78+6ahUKxI5
2Jr9dZSkuLhYTeRoIgWRKysrowHF4MuLUrm1Fm9YUFDAg51pjpXOojFpK4T/
1Vdf7egDFGanIPmwOARbulWh/vII3AnFlEt403s11EiOF07vcQG6j4qlMSoI
kXv00UftO6SsRK5nz55QzSeffHLr1q2tS+Swn2PHjoUGp83BIvGzgChD2oOi
+/fvJ/RLfYUhpuCVV16hy+x3OmtodFx0jl2ropK46WeeeSYnJ8dkCwpVtRI5
WRaF3ZP7uRKekrE78xQyx9ywDHYiJ+khMIWFhW63cguRIybFIyjKDEuhDD6f
z606JuDkkyZNUhxJJ0hlRE72TaRI5CZPngw9UM9k4V/oGjfLL4cGw5rsEyVY
XX4if8V+EzWRk5xlRK7RuNxHZsTUxhz/MmrUqDvuuINXd5o5VjoLyZ89ezYU
AuHs6EQuYnSinBsmp6ykOHZK3UtKStR3BCuA0YDGLF26NOkcrgI8JYPeaZyl
hpr06dPHrukQG7Rgx44dMiKHSRw3bpwbkdu1a9ezzz5LUzT37URDRL7oUQsX
5Kxdu5Z80ibDVEdO4ExlOknqyCP4OwSmE8xAaWgIEjY7dNAgBaMKi8Pb4p7g
J0nvsYoYrA/PLidaNBpnpgUCAVmKb20EPkMecHyKoSQ55A0mJpvxrY/zE6bS
jSIKFLO6JoTIpTIiB5kkWdLpnhRH5PD169atS3oQEz5Fto8pbCP2k2rSkorw
H1GkmtJWCcBW454UeyXIn8yXL19uX9FHqfBi5GweirvagLpSAiQEPwiFljnW
TjDBitOEgUB7Ou4auUYLRPerq6shqCmebCwPEsAiMGlPMSPziARSpLgCOCko
MCYLOpTGkBRRycCBA6uqqhLeToZz587leyhcz5493TY7RAzrBCByaRxoTMkd
LwhrLjZt2pTG9WRWyOUUzRoYxKBBdOn6lgwnami0HxBP4T2JUESpO6hhl2Pc
ZsyYsW/fPuyY+k5PAdwVAyLHjgmRg26JVTcbQQw+RgaT6EYOG42DxOVs4QRr
LBumsFQFBQVuXEiG7Hg1lElRWpwvpXVcyZ8AiBwlaS0il+KIHAmCwSCJFesS
aYGSkhI1kcPdzJs3z/HCo6RETsYP7UeeCuhopMIceU6dyMFjV6xYgdPH33Xo
8+VMyBq5Ft4q1R4gekp1UF5UL+mMqvVBdHbt2rWEHo4bHpM+3mgcNUwOcllM
2mYToZ0zZ479CJFUAIMaMGCAXDxnFoz/x48fj73ieyRWsWtV0hPaYJ0cQ6ek
QKEwXC3hYBFjkZvf72/JlNDw4cPTuGVMDpXau3dvJxiR1tCAyKHgqHxLFiq0
LYiq5EBaOcV92LBhiltNBVgwuXDZHILjw7Rp0yQyTRhSk58cT5oV4BSwCWPH
jrXPMsjOd5PIORp8iBwlgYQoCoyhmzJlitsZJla0IpGTgSzMdVLBwIpCpNUL
ZqCFZWVlEDnFaQ/bt28vLi52bGo8EUROQT8oLZwTk+5IFOlZmJvpsFInclSK
FqD7aFLEgPw7uuWH+dBZMBBarEPXRS4xQfdFopo1WIrEIk4LFixI4xg9eQuy
RNBBBNeSQdr9+/fDsiBdaXQEz8oauYS3z5o1C6KOwGNVkh4/QtNhndLbN4r1
ILps4VFyPD5x4kTCtLTPM5w6dWogEEjjsmAsUkVFxUsvvaSvftDo6IB7oOOy
5rnDDcfJAjMs+YwZM2Amjcb1qY899lhSpRYiB30VC0bd0egnnnjCvFDbmhIi
p54b5Slsmv38EBJjNletWjVixAjFuRl79uzBFlkja7c0qRA5DDglSTrekgqR
o/xQL/xd0tkTWgCGU1RUpA7PKT9pFKNqPI67cSRykHNKAt11k1JZszR79mzH
6N6NyCWVefJcsWKFXNOJu6H8puvsoNOsaMf8+fPlqJbq6uoOeiAwLY9SoMIL
Fy5MwxFj93h27ty56b06Ej+3EOOZRg4mWrL3E0Lu8Xjsmx2oFNZMbv1Tj8hJ
XeB76d2tgDaROc+2RAvq6+uhYUS7CgvpBnOZn9zdkEYxiGgmTZoEl5Pz5Tqi
OmtoROJr5DriZodG43Qg7BguSW7gihgXr6dB5OAhGzZsePzxxyO2faMmkdtt
uWM9ATiF5cuXUwx7AigQdlWO53V8li+xsYMHD1bYMdJgpsaNG5eKvd2+fTsV
SRpip7LZIWIc/L5kyRIhcgorx09QR7icWpDwI3PmzFGsSpLlW47Difv374d+
UB7F2AXVmTdvnuM8EUQOR2Y2IAa8uLg4leNwTSIXMYZe6SwepJE7rtmnkZct
WyZHRx46dKiDngGOTCJORHDr1q1LY00IOsuz5hnRzQUWA6lo+dUG2F503z6q
lgrQuKeeesoeFgmRE5ablMgBiFwaa+QixirBBQsWpHGUsRVUnOALfUx7WIy3
P/roo1QwjTakQXw+38qVK+FyiEQH1WgNjY5L5GSrKVbIqsJ42BSJnCyKE8KD
g964caPX643Y6IpMrRIzShM5ajoGDedeWFhoT4C7wdbNmjVLUZitW7cSWatr
CkWBniWdf8G/UJHhw4cn3UqW4ohcMBhcunSp4iRkMyXtiacwd804AmuJl1FM
+8rmX5LZ25kCQ9LEa7uVgeo899xzjkQOCldWVmZ6PcpQUlKSykJ3K5GLGIO3
kElqoa5pewbaIWvkOu6a2IMHD75qAOHctGlTGqQaQ4H8b9myJb0CNDQ0ID9o
fRoHd1ixdu3aUaNGpcejduzYYd2/Y8KNyEGWqK8jkUtvRE7OROLZFsYCSCO6
mdTIOEK6HtO9efPmNKansc8FBQXQOdQBTq73sWq0W8guBvlsN3fmZocTXq4W
gYqgdxCkBP1NkcjB3EjJ45JSRuQGDhxof4sM+mHr5GA6NyK3aNEiAnz7TxgK
on4FkSNbyBLGXFFa3oupsRfPLbexY8cmnadIhchFjGOmli1blgqRw61g1c3N
I45pcC4EvzKR5Oh8pbmWLFliD88pA4QKx6eomprIwQNpxsb4GWKlpaVJVxKS
ePXq1XSurBKUMuO7KcnixYvtPrRDIOFmhw7E5aS0SILsUYX/0N2Ko7YVQA6J
ztJjUJH4aY3qO+mSgrqQCSwrvavn4R48bl9x6kbkqDLqbA/x5O6qNGbY5Y4w
DGkLl+Vgw4WRppcJT82cORM9TWNIDb2m+jQXH7AbcpR0pMOe3qDR6SH7uZDS
BDYia+RkeLyjTLJQfjQOcoVrTtgmmSKR4ynoKzG1rGqDG6xfv97xcA8hcnK+
rmP7NBrnk8BhHNfbYJ0oJJbKrSSHDh0igfooXWysI890rBe2ety4ca1I5Gil
VE4YeOWVV2bPno1JNNeP2dNYx4IcM4G/LV++HOpo314h20aef/55xc4LyAk8
0L5qKGIsMhSn3ywiFzFGEZcuXbp///6I5dQLOSNazhBLmkN7A7oj2y2Rlg63
2QEGhcOVw/kRzvHjxyNyaeSD8MNz0liXZRYDet9CIkcVkKKysrL0pEiIXIoj
clVVVRgxNNRO/EaOHJnGrk9BYWEhgtTCZZYUtaCgIL1FbgIZX0VJm5sDJefV
GBz8IOqAaMm4nCZyGu0Njca9AyNGjLj66qu/8IUv/OEPf7CedIFb3Lhx45o1
a/bu3dtRjlbAiuJD8cv28/ZTJ3K4e/NwWrlw1vHQElkWZd545ajgGKIpU6bw
avtP2BbsqmLAE7tKAvUhclQTnul41G0C5AiOVhyRo+4Yf/VGjIjRLNQREkWG
ChtIZXF/9kuFrPngU/A49k0TQuR4VkHkamtrYcW0gJ0oUrwEIocDTYXI0a0U
SU5MNcevZHQR9o7YqG+Ca4fA9U+fPt3j8YwePZoG6UDTSRAeOi4UCklMSvgz
derUNFapodQI/4wZM9LuO4qBpKXHIU3Q8hChLVu2pFcMjAZlIBJM0DhHIkec
JZplt41+v7+8vLy5xl9eCgWaNWtWC4emqcLw4cPTGxUUUCni+vRWO2DfsAxy
Cg1mUwSswwU4Gp0eMBbs9tlnn/3Vr371e9/73rnnnnvPPfeYjlKmVlu4YPWE
odHYpoqnxg7b79fj18rKyv79+ysOuBDIiFwCkXO8z50EkAcaUJEbcdyYMWPs
0zSUB6qQn5+vIJbYwDlz5qgPvlPwzARgiJ5//nlizNYicoTJMn+d9NWwazwL
hVS8mp8WGVCcUgJFnzRpkr0xZfnf2rVr1UQOMulG5GRo1CRyFDXp3l6ZMhYi
l/CTHPVcVFQkbdjeQnhFecwRObqjQzgsqQsCJpcryZyCDGfhhZu1tqoxfnII
DApNSbvXZFtN2jOzAqqAqKd9VSvRpSMJdCNysDVzMYkVELm0b9pavXo1ZiSN
oz9MSFdiP2UBQ3o9glT4fD5UNQ0vhiJgNMwqUAa6lZBBsmpveq1x0mL79u3E
TQTgGzZsQFkuu+yyb3zjG3JjFFLasTY7oPJUB1rleKcMv1ZVVfFr0nPPEqZW
FUSOrPB6jj+ZwC9gRhwXDO/evRs7qXCXe/fupcDqWHL//v1Yy1TuEsLZlRpI
uo691Ymc3GuPd1McfQzkWLY0iJwsV8NJKbyGmsjxk0nkaFJZV6OulJrIyak1
tE87OVw3YcwwbMA+090RDwSW687pBfPUX0QdMgaRa9b0qLQDlpDoKelpk4pM
VqxYQQ4t3OmACZo8eXLau2awG7LQMeF7NyInl2HZ1WfGjBnPPPNMemSMKjz+
+OMUI23CI+WnMeFy9Eh64wkE9bIOMI3ABBONW7RWX0KGFl49pqHRukA13n//
/VAoVFlZ+eCDD1566aW9e/c2qU4HInLYCjR92rRpbodw4rYgHsTpSacJYB20
BsQjFSLHT+rFMJgCsUL2n+RYToWVw95iae2ji1bQO4FAIJWRB9LAOswJRAVS
JHIYtBSJnNxrb8532yFdtmrVKjpIYSTLysqmTp1qPz6FZyUSSY/I0cI8W15e
LjOJBw8eRJAQAHWlhMhRJPv8nVSHyvIrNUo6CHxiIKVCo4cOHfr973//2muv
HT16NDKWQORoB7weXdYhDpGjnOgR+iWLl6QuVIoehFA1Kyt5HB5L16c9IYiW
QSAJA1s4i4FVQa/TPsAEwwKDsm80aC6RQ60INpvLJ6XuuI8+ffpgkNNuCik8
xZs4cWLabggxlnmNNM60xzIQEZjWWySEksCx0xvi09A4HjC32qHRX/va17p2
7Tpo0CBzFx6aWFVV1cLTkE4M3nzzzYUG3JaUoM5YNvx1UiIHkUDrsW8SwdEI
slAwIRntQ0Nh9hVEjjSwDrJyfCk/Pf300wpa9eqrr2JF1T4Fq4LRTiX8p4kg
copTc03s378fq570hGGIMXxPTeRkhITGh8XhW9V1WbZsmcJ5NRrn0c2YMYM3
2gcVIahLliwRT+RYQTnYavny5fa+QGZkTZEsLId3UQyYp6Kogu3bt+OyFacI
wosoFW1upRltCNr2oYceOvPMM7/4xS9ecsklF1988ciRI63MmQbE6yGxFLud
Hwgs7UnQQTkT5t3oF9iU/cr4pKC+SAK+O23uLetaU7wZxA5TSBA/YpbmXnEl
z9KhUHQYu5VpyE+yeA9mIkRu+vTpaiKHrkGi0hsYpDEphmwWSONxE2gl5cTQ
pac+PIWSYqmaRc6lI7AMmIKtW7eaw9cRY1kyRG7SpEmyy0lDo80h4oqUwgTg
Kr/97W+7deuGjkfiRAUFx3WijOgC0Vn7XPzc0NAQDAbhM2bM5TgilzqRww7L
qSCNxmYQjMCqVasSkkn78N7y8nK3rBrjJwbbR/XlLeTs9qyss6Lx1SSNwDA/
Pz+VraPNInJYTvW9YBGDpdBKZWVl6gyFdNFKyJX6TCq5ElfiX8c8eXzmzJnI
pAw1WNMkJXKILj4almJvK/kJqtlcIldTU0NDKa6BoO4mqWhzFkcBiFB+9KMf
XX/99XDacePGQefuuOMO63YVGhCui5zATmmoNi+zGocOHZI1S5Gm7Y+lmj9/
fhoRKNoKsaFx5DD/NIq0ZcsWlDrpDiAF5L0E1MOGDWvu2SPyrOxf27ZtWwKR
w5LArNBrYrShQ4fm5eVBWcePH68gcqgVRC69iWbe+K9//WvKlCktvHEV8045
4Z9p32KPhtIgjkcPKSBBKM2CcSAMtMpDKBTie5S6w+1m0uiUwAtj8QoKCuAD
hF09evQ466yzHn744YghxpANZBWDcNhA+zzdWraOEr2aJMGxkKkTuXfeeWfd
unWmH8dTEHw5mjIID8RDEfij/ug7NsQ+CI8pUB8tAlfBwJJAMSNAGhzHyJEj
U5k1wC+vWLECH6fuRJmkxstD3dUZknKWgaQZRoyzc2krNZGTqEER/vM4CcjK
Pmf0wgsvjBo1CovtNvCFAMD0FESuuSNyJsmH9iiSkTk+CP7pePKJPU/Fn0m/
V+csoQf0hhbGQefk5Fx++eUQBuvcPT6X5lUcAtN+IKuV5N4Wa4NQcnoklUUU
dkB0+/Xrl8rWITukDEuXLp08eXILl6Ngc2677bb+/funN+aD/g4fPjxhRC5i
2Cs4Kv+vX78eioW+FBUVqYkcKZEQxcV5atAUt99+O9FuS06Tk0UX2K70jgWO
GMeq/+EPf0D90zhSZtmyZVBZO6PGTcCHabH2rykanR446/z8/PPPP7979+7Q
lWuvvbZbt24mu2itNXKiwuQG48JiwD1MleSDnACGm5PoBsfHG/mGyDFpQCqs
g6APTVcrVHOJnHlBj9xL6PiU3EGvsHL89Ne//vWf//yn/SchcoqFWFJg+kIx
MYF5fOmll3w+XypEjoaC7qZyKgKh68CBA8eOHSs9orDAGH8oSiomGmOO75C2
cktfVVWlPlGfRqPFiD7sM5V4HHwfTsfNZfAI0g6Rs7sDfoK2zZ49u7kjcphx
qq8mchFj9BU3ZJ65p2guOBXVLy8vh0rJ+AOP0MXWb1o+RUvU9uc///mUU075
3ve+l7Cay9zsYL6iMY6WvLG1YBaGLkP70E375C/9i2ZBqJo7fcCDvXv3vvHG
G5MOMruVjcLQ0ZiOlux0oDugHF/+8pcpTHpEDiI6dOhQWSNn/Z7cli9ffuDA
AZQFaSd+53+IHCkRMD7biZzs9McLpCcA6NEXvvAFXIwchJI255GxeoQzvccR
+G9/+9vSns0tA45pyJAhCduHpTUwR3g0+xkvGhonGHjq6urq+++//+Mf//hp
p512ySWXjBkzBiYj1rIViRyRPk7285///Kc+9Sn+79OnD/Zk3759kJxzzz33
//7v/772ta9Nnz4dvgSvu/XWW88888xzzjnn5ptvxqgqcsb2YvSgZ7KGQaFQ
x4PIQXhgO25ETi5s+vGPf/ynP/3JTrSEyCnYAt4f80UaxRGU/ERU6Pf7U1mF
Qjkx7zJ+qGgoDB0U+qabbvrHP/5hn7RKQOpEDhqJb1VfI46hNnmRW560CQns
M1+LFy/+1re+BW0Wa29/XEHkSAxhnjx5soy7tjqRkzyLiooopGJ6CE3My8u7
6KKLUIcrr7xywoQJkLpevXpdfPHFfHP11VfT0S3cCymgBWjG3Nzcq6666r77
7rMeckjrrV69GurIi+oNoA7oTrsadkAZYXF79uyxrlwyQaegvGvWrGnuAj/k
87vf/e71118v47ppFAyegMKaU/9p5BAxDM7tt9+ONe7bty9mM418ZJLFvnlf
drjTdAlETkbkYEr2OVCZpUVt0xOAZ555Bmt/ww03yM16abcJbogwMO09vBA5
evaaa66R65ibVQw5P8p6YV+jBXgxHBbarbmcRttCZohwWygdrABHY8pkaxE5
jMCmTZu+853v4IyI7370ox8Rb2JDFixYgJpD4f7+979ffvnl6BoUArtx1lln
QSRwMbA+bJrbOoSjR4+SLSxLDmw88UQOk6ggcuTDg1QB12A3QTU1NePGjVOM
PuFt8Sy4foUJlQuhaMZUdtZbiZwCtOpzzz1HF1x77bVJ18ZAYxxvH7MDW4dv
RZwUafAjZOhG3aV/rUTO7G5ZygIt+dWvfuXWpDK1CpuyT602GnsVkX8x1xR1
ypQpeOSklUqdyEWM0B43ap7tk/ArMvzoo4+ef/75d9xxR79+/TIyMrKysjwe
D96Hjrj77ruvuOKKzMxMOEbat6DylJyaSwCFPNMdZPiFL3wBBmsOXlF36OKd
d955dxzITHPvbUd00TUxHeZkFq/evXs3WSFU5pcEIHxJShQkxRVQJMN0yN1V
jqVCznH6MJNmcQ8aZNSoUV26dPnJT36iPlDIEVISakfZ0rui3QQi2q1bt49+
9KNz585N7x4BDAJaab/WCiJHLANXtxM5tGbw4MEYh4RGQywnTpzI9+lte3n6
6ac/97nPnXLKKbRtKut43UCZEUt0J71F2oQqOJePfexjXq+3ufuRDx06hDWo
qKiwuiHT+PA/NA8vkOI6QHKjMFVVVdTIbFIkmW9QGXSk/Yx+a3REyLlSCXwA
M4tpavmuVbLFXOPyVq5ciRjjqi677DIUc9iwYXiuAQMGIMYPPfTQJZdcguf6
zW9+A7sLBALBYPBb3/oWCigsyCreMkpPrARTIsNUJP/Ej8ihqrDWj3/84zfe
eKOdEe3cuROr4nhqqOgy3hCrS4EV/si8DUpdI0GKI3KQQ0zThz70IZhDUo+2
cOFCGFQq44HYTwiPmkbCImhqaqQoHg6afBLs+ZEjR5566im8MJxn2bJljg/S
jKtWrYKeOToUXNv06dOFyNHyOCDqlXRFTbOIHFrw/PPP06GOOyIJCmBNX/zi
F/Pz8+lQKB8UvU+fPuedd94jjzyCLvzxj38U0pX2+mpUAKm+7rrrUDH4MO6e
2OrKK6+kCqZPMQ8EficOiFOKjEh6DcEmLpNxxe9///tQBTKh9wnQCN/kSyIF
aoFTQ30I7vgSNafBJYq09751epfi/fOf/6TwbkKCz6X1Ur/USZK98MILRAHQ
p29/+9tEtWkQBulfOKR19CZ1SAVpE1j0aaed9pGPfATlSo8+wQALCwvtjAXC
4Di1KqfwIfNY+wQXQDehUDROehsNCI4gchgTWhWjmvYmaN6Os0B30tsAu2PH
ju9973s0KfYBVWpWMbD8ckC0m+PACyCQ2BbMhaPImV+iVvfff/8FF1yAwN92
220bNmygeQnNfvCDHxDvf/azn3388cdlDFZzOY1WhMzuEdxt3LgxjUN4TIhk
IrQQtj/96U8XXnjh73//ewgYFA5GN2fOHMwIPuviiy9+8MEHrzFAVLt169Yf
//jH+BpZIZ9A5GS5FLYuRS9z/Iic4+nrlGrz5s34LKwHdNR+lAe2xY3ICeRA
FeqoJnJLlixJuivBLK3MkqiTEbb36tUL2wuvJhRVJ6aO4jSTvh0rRznVnAcJ
QRjUzJBM6JoEtwKh+tvf/gZnhupMnTrV0QsjM9hwmkvGbxPATyaRI3OoFG9x
TJnw3tSJXCR+f5zjdbFQ3KysLKrw6U9/GgX5+c9/Pm3aNCrVrVs3HC4y1r17
d5Rl4sSJad8BSgtAcn7xi1+ccsopX/rSlyCNZ599dl5enjXKkDVy6V0oIDNN
/fr1O+ecc/CbMM/LL78chyX7XCBsX//613/9619Ti9/97nd4MXrqK1/5ylVX
XXXzzTfz5U033QRJkxjNjcthKCZNmoRjdVz33mjc7UK0CF1v1jXryNvIkSO7
du2K2ONPn3jiieaOjTQaxwZiXtBZt1OvUwGdThhLMYTIpXGGLUqE2qIm9qsQ
aD3Ez3GNHMA4YHIT3ogqEc1hvtK7otEkcgj2oEGDWnJdlxi69PY7mEQOop5G
MSBp9KyjNRBxRcJ79uyJSNspYqNxOUXEmG7A651//vnZ2dmZmZlnnXVW3759
kdUf/vCH5557Lj+hAnA8eqSj3Iap0VEgu1ZhXIhWS1Z9CBB4WARifOmll0LV
CHux+TgUNHTfvn0QOQzpn//856997Wvf/OY3YR1C5PhTJsusb6c8uBv4Veo3
SqdH5BqN4x8diRw/0TKjR492HFQnPbH56aefjhFDQ4uKihIS8OzAgQMVuzhp
E2JkShJxH0A7ePAg5VScf2JCLrZI5YhRovLrr7+eYp955pk5OTnqTsfCQ+Sw
k0kLQD5lZWX2U1wSCrl48WKInMJcb9q0yX7wLwXAElJmTOLgwYPdvDzxCI7M
cUTOSuRgSnAzKHSrE7mIcTwFrMa+g5WW/OUvf4nAQOdwCigIJOdKAxRs9+7d
EDkinVGjRqV9Kpf4lP9n7zwAqyrP/88QV8VZrQOtC5UqDtTioLXailVbtW6t
WxTByp4JEAghhGx2wggEhCAQRsIIe+8gJCiKlfGzgCgblZXknP/nnse8/9M7
zn3PuQna9j4/m9/l3nPe8bzP+D7veF6GAB0EU6Fl7dq1k81L6hlJCPzpp5/i
wT2gCJQlKSmpefPm8+fPBwA0bdqUWvDmMkeXlpYGn0FxOKz4+Ph//OMf5513
nsxm/O1vfwOy8qTDbAnIBNTRt29fh/AHg8DAYVI00ZRRmXIWnuDoESFQKCLk
YS8i0oLCqgDQA4Go4cOZZ55JM4AcnoFcVlYWLA00WYRdBJ5wLxDIoUGpqamB
QA6jDdhAwr1tzlRADnrggQdQXs+bLfFE4HNv5x0UkKMZACe3zUA3qdoh2TjK
gmJi8B0sBuEbGi1HaXAHRPGUSVRC7EmwQ+/whpdccgma4jbnTJSi5ExVeNgB
54h7xQcBe7DnOCzQwltvvQV445/YltjYWPwUth3LTyCPKcaq8Mx9990nS6tK
9fiAXwNcubpIyBWQW758uR3IYY6CZpHFKw0ePDhwqYu3vv76a9yxWDBU1S9f
HNby448/RpcdTqVJvQ6byqQWYI9O0ioaiTkCyDnfEwFvgY4YHJp9+umnP/nk
k87sohcgGR0gJyubDinX5BkAADjHgS1AIMqxg2fZOEeQS5tr1qyJUIWCx4TM
ALmwM3LIKs4LN1odQI7Cke3AOyix5E8//TSSjztAvFEEgDSup27dunFxcURA
7777LoKE5Y8wdRWyB5SVwwLoo59H27t3Lz0CyeTk5HjYkkRpdBDEBavfe+89
wrRWrVoBzl988cXbbrsN/8XItm/f/tJLL33zzTcBrhdeeCEeED4TxzVo0CA7
O9thvlFSoyBsDnNlhDZFRUVhUyDaiaJwqSBb0VZigcTERA+4ha4xdq6EwU7q
sKo0w/OMHMyHpWhE4GIoQo7ZpJ3oOBAO28WIAO0IKuVaHCxJYI3YDTB55ECu
Tp06YMWwOhWKkFWEn9H3wBM7kAMhq1O0mq+jjwiV8z1l/Lp+/XowWNBIRJAe
8cvtt98OlvvLX/7CP4mpiXrQBeJluSWwfv36fHbO0RSlKLmlqgJy6GBBQQHB
ZkJCAqKOuT7jjDP+8Ic/dO3alRgEP7Vx40Yi4muuuQbBRpKvvfZaIAfOtGHD
hvfee69fhli5BKdfv36utm0IkMNUOrwl8+RYQrkrSr7EuctJXr+HFZALdHaU
AwrFdIgFA6BiguwP4K3wdFhOhxlFeo1fECAXaqVp+/btmEr7qcNQpAnk6DvP
XHTRRWLxHnzwQeeTYrIfSWclTmbkwGnO2IC+MEbbAi7hUhQI5DDsMOGGG24Q
bj/22GOhkh7/HICcaaFfwhZk2A6iiGWAoPXq1cOxrlu37tlnnz3nnHMuu+wy
oE67du3wy8899xwKgiBVSVLuUF6MHuGzCgsLAZZ89uA0TWtuqkePHhdccAGN
j4mJoUAwGy5MgFyHDh3AqKg2Q4akDRgwAGDZvXt3TAEYL9SUC0OD/MAlWRoI
NaOCuCKQzrfm+dHWrVtBlUh7hEAO6aKDnk9WostYyLPOOitCIAcDwaV0KvBd
hBx8jgWWGTnMGkPTv39/BFIuNQsK5AgisAk0z8OKjB3IQcgAXPIwKSdV5+bm
ogiSVMHV64T8CshBBKpElPo75VCErKyswA2E9uYZVtpVegcMCyyZcPiDDz44
77zzELMHHnjglltuOf/883v27Nm6detf/epXCsihEcTOgUdOohSlSEiAnOf7
oxUhlgjnI488cvnllz/xxBPXWYSOz5s378477yRO4ae6dev+9a9/xY+PHDny
l7/85U033dSkSROEHEdgTy0ic1kYXvydKyCHd+ZFLG3Yt9ApbJoE9VQN/gla
lwOQM60lHgDJ+++/f99997Vp08ZvSZHSUHmi41A7DykT+zlixAiHw1AwRG5r
1ZkQEyCHJXQGcjQMI9+xY8fHH38cJgMbnD0aZdIAzbuQYBfuw2FdzLS8qlwr
EOoBAXJ2dw8f4FVGRgY28I9//COOKZTE/uRATsSY1gJm4uPjYYVySZh6JL9B
gwagtVtvvRWbDyIFUeCAcIV33XUXSoHuFBcXR74RWh24C/xJDjtIQmDP3gQp
Ai3gK4GjOE1c2J/+9Kc77rgjPz+f8uk7AO+hhx665557BMgRmgHksAlEZ37y
Jo1EaNEFQAgj4oDiZLcDDtHVxQqEbI0bN65Zs6Z4eZrUu3dvt0CO4Zs4cSII
yjPTCGZROtC7aok3IIfwwwG/K3SFEPLx48djUmRGLjMzE40gWkSLEcVQQE7s
oberRRHpX//61zK9j1QTrXtLSSevIPwqR5ArQirQIOEqjobP8EF/Ww7GMy0t
jTgi7GoOMt+3b9/A83eYFLwAoc2jjz5K8Dtz5kwcHBqBXvAlQI7x4ssbb7zx
1VdfJS6OHnaIUhUSIQZSB6TBYUU4D4AkY0aaNWtGJP7MM88QNROGAxTBcsg2
/gvMI8f29+7dm52dfffdd+PCiBntE9qGlY8Oe56eno4DdXX+AmcxzyJncyTo
CPsjxxMAchhYD0DOtDAnPUpISMAt+plHSoOrALlQ+52EXUOHDnUwHZSJdYWT
oTKn+bWWjhBZh71EEv5guvPy8tatWxf2oiKqxmuA/ZzLFKJAWuucJR4IB4hy
BnI8IDv9VNtoM00FgQDGHDzOTw7kpM10gYFAhoH6CjDIiUXYjjrcfvvthOqo
Hr8WFRUBh2677TbgEDIT+VZVZ2JAV6xYoVyJ27rAb/ANTuKvGZFu3brVrl37
xRdffP755/FccpP722+/DSjFr+HW8WLACTQOy4AXCzyoIrsyQB0A9bAOTu50
CJrY1oFgMiEeeLJ58+bPPfcc/Mf+BJ4UcCZqpHdqGt8DwS7EHta9++67b731
FtaPgMUDkANFUEjQfVboqSSLEyAn13VJCu4dO3aAkRi1wBopCkMU9KewRI2A
86ysrJdffhkgBFcjmWuCP4SWHlaIEGmGFT1q0qQJ7aEvDDrd0W8Mg4tgh4X3
eLSkpCTcll8ATl2CaV955RV6gSFCx3/729++8847V1xxBRoB/4cMGXLllVci
hJEvgUUpSnYCZuDgcCVAkciP0gCKcBOSM0qZa6w0Moxrk7tOxHii79SI3fa7
FIw2oJLoFIYIY+UKyOGUQXGbNm1yfqwKgZxpTen36dMncOUxLJCTwrGfoeYP
DSu5PRG05lVEFIi3CnXcz4+wQpj3wJO2gcQQzJ07t6qAHJ0CSgGitm/fHuoZ
fsrPz6cvgT+VlpZSvsNNWD8TIAe8n2wRHVFzRzJZx1Aifvhi8Lb4TUZ5586d
6htv+Eqf0FDwAxiSOIvGuK0IZQEL4ZtatmwJHGratCm+KTk5mXDm0ksvffLJ
J3v16kWMduedd44bNy4xMfHiiy9+7LHHunfvftddd91yyy1y3ZtfpbALyAHo
DQskGDg5N6p/sFeqw/IsXboU4cE6IZ/Iv9tEGRIlBRVLzWbIX4AWUoGQq6xi
botasmRJqCOWWHJsjhxMtgM5hpsggvEqLi4O3IHJN4zUsmXLPByXRnqxYJQA
AAt6WNsV8ToSEhgXhyWEmfgOgATEUgmIXOVjpPtErGGjYNPKMfLee+9hZ4Rd
Sp7hecOGDevXr09IQhTzq1/96qmnnsJ9NGjQ4Oabb05LS3v44YfPPPNMcGb0
qogoVS0BM7CiRBDetsr4kQinXX2U+Qr6ZaDPwr4RNtIkQUGuzALKS0gY9r7L
/xQgZ1pGEhiAgxMg56D7hnVf9vz58yVbS1grIUBOxytVLZAzra1QODIHDLl7
926wU9DTrwLkHJbVfj5ADn9EH6kFnyvQ2i7wgZ/t8KZajbwkBH711VfbtWun
nJE+gT1w2fim008//ayzzjr//PPfffddUChDD4o7wyK+bNWqFbqM2Dz++OPy
Zd26dV977TXJjWPvrNyygaagv4EYz48YDhjr4bgBWkZANGXKFFm61eewGiZw
oOwAdFu1neAenFE30HmYvOJFxBiVDFw3lMMUhHIAOdnOZwdycADWAeSCjnhW
VhatiiStyvLlyynE8y4dO94GEbkFhIqZKPWYMWMYJlejbFqTgZrji68E8vXu
3dvvOkLUvFOnTkQuoDW0g7gG806x7du3v+SSS/hSchgGvbYmSlGKhKrqsEOE
JGqIIhQWFuI3aZU3IIeOON8sYP4nAzlnkvTC6hZdZ6omICdew2HZ1LR2+MB8
OhXqAYAchcjpVz8CyOGM/iNm5Hhr06ZNvE6lQIgqCZSqhGRpFTVBqDzspqB3
iATeNiUlJTY2FqeJNqG86BHjAsbr1asXWEJ9uWXLFnBjjx49eBLHJ95WAVce
ANUnJSWFVVshOTdKwOK22TIQBQUFoXK6OvTXtAAYykW9ES5bwJaMjAzEw7M8
YE9gF4oWOHZ0Dc0icKC1cBWGKyAHfpP7MkB0QTkAdsL26sxHhSK6lpmZib2K
cBs/ERxmU/MahUDCmKelpbnd72dY6dkBorJSEFZC8FB0FlbbF+gNKwuiJB5h
jCShpWFtJeJL9IKhZyCiSeSiVOX08wFyWDYcX7t27WJiYpZYhCFylVArCuR+
ciCHp6bLzlnvAHIjRoyoViCnk0fuFMzI8RYdadmyJQbc81HHKicBcshtJHMC
aCs8RCwRY5kBlliMfyLP9mun5EsBjYFTjjQGYcjLy9OcC8JBT506VRP12Yn+
Ai8RD2+9Rl9QLlBQJCjFsLLoIJ/Ox5GcCdnu1q1bUA7AZ2RVprME0Q0ZMoQu
qxk5gJwgusB9mCgdr+AIPEsFlebk5KC2kUzrmdbMGFbRM9alIzTj888/d/s6
3OPFwDx7fqQm+mBsenq6H3CV2ARpRzvUNcHqS1EWD52KUpScCaXDLUa4XlAl
RNgyZcoUYl5MLpFRs2bNCCddBS+ytPqfAuTQdEwu9TokDfuPA3IUO2rUKDyI
wzPVPSNH7UHzup9KIIcQJicnx8bGFhYW0tpp06YtXrxYBvonX1IBO8EK51lT
Z/JbBXZYGnZe3sJjou/Dhg2TxHE6VSOHADm3VwpSODrOcHsDKoZ1egW50r8U
LCgdPnwYy4bWe7sMSwiIAs4JejAcqQasLl++/MiRI2BjRpnq+IsAC5CbPn06
TPALc9TYZWdne7t6TNGsWbOA5RFmu5UNe3JXlwdug5RoA0z2sIsS0cKE6hxn
lnnpnj17guXs0mhvcFAt+MnVP0r/lYQ0Ep7L3nJvd6NUCYFYgFXEj7L7GlOD
QmHhXc3ICZIJu2X65wPkJD+JGVq7/+OAHCCBqPanAnKwsbi4GF8WNFvLqQRy
xPXDhw9funQpI4iDwI1OmjRJJsHcbt2pcpJtZuDMcePGffLJJ54vx4yc1q1b
17JlS/RL0+eiU0UWuQJCMh+CqCMA3la1UAFkgBGMBICZViaftm3bep7WE7FZ
YVFQsIGpIfgFyBGeA+TQWSCfHcihyOid7EUMfJ3H4FIkyahRLuSKKCbCeaeP
LNq3b5+r0wqKUG0Gy9UtXaKVBFyjR48Ou6qrWkVFzz77LG9J4rsoSIvST0WS
fgSLigv2cIStqoggjjBK0IKkjgcFuT21iqWSzfbO5vrnAOQM68pIWovBUd8E
PhYFcn4UFsjB84KCAplh9mPpKV5aZWSlncgzY01ds2bN+jlscpapb1x8YWEh
iLdKkg97IEnj//rrr8fGxhJIIpBh18L2798P+MRvuj2ggfrAf8TSG0oB+YwZ
Mwa58vCunaZPn96vXz9vWf0rKkmuWQmKlI4cOYJmIeEyNSdADo2Qq7QRwpUr
V86fPx9DEVQI4c/UqVMjOVCJLNEAopgIowOUDncgOyo9YEI8GuPldtoWKikp
AWkTDIYVRSQKY9uqVavXXnstJibGni4ySlE69SR75FRuyZ9EGiWTLZhHHe6T
2arc3FxXQA7rgRELm6zj5wDkTAtLYDFwYWZ0Ru7f6b9jjxxdkBOa8g3jSDl4
CvOnXl6RhMDwUO5a/Ukag3detGjRwIEDUQG0r3v37i1btmREnFElQguKo/Fu
tz/BfIaeuMlba9FxMFjY4/AOJCt3CQkJ9NHbtJ4MEyAcuZKDJIHP7Nu3b9iw
YQBFAXIIfHZ2Nn9hGlYRpcAiAZCw9kFfR3cwgw55gXRaCFaUqyW8FWJWzndl
ZmZSlAfgzbu8FR8f73fFsPMrhi0rNX7BoV7JV9+lS5eOHTvCz6+++qpHjx6y
EOy2qVGKUlXRT3vYQTRIUs5icJTeqWsRXGmH5l2rPx8gxwM4d9WqwGf+44Cc
JHOOAjk57KBSbZiWPMy2KMKt4JGTSghshtvDVuWkVpaREzymTJ7LcXVGFlF3
yKkoYHjq1Kk619X5EQI8YMAADy9K1ajVpEmTggqVfiHgil69eiESkSw7ysmF
r7/+OmghQDgAzJYtW2CjzMjJHjkQEdoEk7HzaWlpDH3Q1wF4tBCj5Hk+zbBS
Xnfu3HnZsmWeZ3pFIPEIY8aMQVbdsktEBekCu+rf7CAk1xfCZOcDaKjP/Pnz
GQWJg7CiycnJkZxEjlKUIqSfHMjJDVlDhw61K90pAHISeZmVQA609pMcdqDj
DutE/3FATmbknNvwP5J+xA7kxDchJNToDU5UITFGdIcBRQYizMPvgYQbMD8h
IQH5NwOSTwYFlmIoaHZeXl7Qq6kcSNb70GJvuWrVhQ6eEa90WTYler5Q3rTm
grKzswVSBm0M8paSkrJ161bMBWrIEMuM3PLly5cuXYp9AHtkZmaGuj4DX6CO
tUbSyEkWeT6ZK20D98bGxm7atMkbkEPAGDW3OUxo/KJFi0ChzgiQx+xYF27H
xMRgWyKB+lGKUiSE8gIVIr9r1TNJjh3x2qdmRs607hYk8lq/fr1Zeddqenr6
Kd4jJ8vH6oqun+2MHDYNICc+Nyzt2LEDg4bXcHgmbPoR3I1DQmAA0n9KQmA7
kIPQNfCAugbop1pglQW4N954o0uXLvTr1O+RA0m2adPmvffeU0cvFSsceIIK
IIcFBQX67lJKA/j169cPffcw0WRYCUNgl6urXQMJdWvdujVFRbJJEmg0fvx4
hMqeyMVOxAgIGBYVncWwEO+AYIFzADmZkUPwkpKSUIRQg45JLCwsdHX9mSLV
pC1btgwfPtz5wuWwRFOxyTTe27ZGjAxQ1sN2RHwBHNA5KKECNHBdYmLiCy+8
EPZSoShFyTPJygUK3qNHDwKHtLS0jRs3ql/lsAOqvXv37gjPZHkg7AlYQh1W
VcFXdQM5GIJTAPaYFn+weESygWteP4c8crSNsdMZGqz3/Pnzp0+fHvZJ0z2Q
05yRI5wH9sATh2e2bdsmiUlDPYD5zc/Pp6jAnzCV/4kzcuonVE+AqEJ3+sVW
FcnSKjxETU7xYpB0Gb177rnn+vbtC2/1OYDOotoMBGOnOUsj1clYIDkeuA2L
xo0bh5J6zk8rBI5C5kMtiWoSAAlT4NCSqVOnojjgPXiF5QHBSiIOBeTgAKAU
PBnKnsilqxGuEhIp4GUIxCKc2WPU5CYOD6+D9oHun376qVv0jnVyZnJQysrK
uv/+++HtT5j5IUr/3QRCQzKvuuoqdVHO448/LuESVgX0IrtTwBunPhGB32FV
+4wcX1bf0iq9xpdNmzZNvgE5jBo1KrAuudfeM5BzxqJSOCDWwdxJYnwMmk6M
LKcnwCr6d63qADnMMoCHpoZ90qwEcoHcsNP27dsBUQ55zMAYINKg+6UZNTro
8O7PHMidyuOr5RYFfl8lCYE9E2AGD9u2bVtUw1WCCLm4DUDittkIOdCRXrts
qY8Qj/Hjx0+ePFnyS3gowbQgaE5OToSZPTCPSC9hWtAJSYmCs7OzibkwOH5A
ThJMiQ0ZZ1FQzovAZGZmokEU4hlzUggSTmu98VzRhg0bUCIPh09NK0zmXXTc
7Xo6XBo0aJBbKIuQPP/88y+99FJJSYm3lClRipIzFRYWEvxedtllsbGxOJEX
XnjhxhtvVEfpJSGw7JE7xVMEclhVXfJur5qfNm7cmJub62q3qv6MHL3GvgkT
qJfuY/cC3wK/gUz69+/vYIFxiL179w41I4fNDAXkKHz9+vVYWgdTI21T8MOZ
aCTOAi+pE8PqA7lNmzY531Nvb61OvlZ4NW/ePAcwRliBv5ag2E8gJ02aNGbM
mFDja1jpR5yBnIwUQA5sFpgcNZCqFsiZ1voXBcr+zGpSN7q/bNmyjIyM1NRU
Wu63WynyhMCeCedI9IQh6ty5M0OpHzkaVo5lDAL66MpMISqwYvHixd6yy6J3
cvwzkpEiuGAsiF8imY4DAMM0kEngllppG5Lco0cPhhvLc/jwYQwapkPNyMEB
MbM0ZsCAAQ7rnrKUHOFmG8LPuLi4CE92gDa7du1Ky93eqiaE49NJCudHCExS
UpLbu9iw5MC/N998E63XySccpSi5JXS2tLQUqUY3+dyyZcv69etPmTJFfv0J
DzvgX2gVehpUSQXAuIrp3AI5tQoZCsiZFuogRHVAJjt27OCBwMwGWDAACSAw
lCXhAWw79TqDtF27duXl5cl1Fc5WES8JqsR26dzToQ/kgBw8qbNFn3GcZ5FD
TMpPgDSQjIOnADrisILyDTsJNpbprMAq+AY/VVRUFBTI8RNOWbiNU6MoxM95
koQC9+3bp25p1/QmzkAO2UP7wJBVvjlNbQmLiYm5/PLLz7SID4mJiXa8CjRl
QPFW6BdydSpXVxHmIRZlZ2drbuYUErGZPHmyW7+MAQE6Ll261MNyA7KBhERy
76dpDUpycjLRh7fN/2rDCeEJ40VLgoq9afUUuIgF4HmsFsE7oi5AToJiNM6w
Tv4C7x1gPHElmISIzBt8EpJbEjCwctmot0KQTPhGIWirh2mukpISOuLqMg55
Es3VvN9BEYZ0+PDh6DVsx9tGj69GqcpJTAF2DA3FFFx99dUPP/yw8ssyI3fq
DzvQJNrgEPrxvRgu/TKrA8iBtQYOHLh169ZQRWGfZ82aFRQRyWRd0OBXLAa9
A9I4pLcyrOP8BQUFAAnniQj5FfuckpISFD/4kT6Qmz17NkhSZ7n2+++/l6Y6
PAN6yc/PVzkDgxL85AG/+7sNK4Uy7+Iggm72Fg6sXr1a7qoOLNY+IwdXQby4
adORUTIjijdZtGiR85N+b4UCctJIsDF9rKbbVwHSTZo0ueGGG+Is4sPf/vY3
+0Dv3bsXHuJ38FYIzClzOlQEGANagNIlO4Tmi3IyCODHeLm902HLli0MOhje
dD//eeTIEQIxwEAkt5zTgBYtWiA/kayryuEFxMYB/GPQ+vXrJ3EKGAbTKkur
y5cvZ5TpiEg+MD4nJydosjgVJwKYAXsRnlbAZnbp0gXBi2RSrri4mMBNIKjb
cjBxIFtY4VbCiW5GjRrlyidiT+AqYx0fHx/NKRel6iBJjo0pQCNuvPFGDDtm
XGQb7UDkUBaUHb3DCCC9p8Cwi1MmTAYjhQq1PAM5DL43IBfUR2DxJKwLVRSY
Yf78+ZLo1Y9kfSHUXJZh3UQ2y6JQNsqwbvSbO3fuyJEjdXZV7dq1CxOksxKk
CeTkom3gmY4T3LFjB31xvusWdoGgpk2b5mCWgSIMokwI2OvFs4B7V6xYEQrT
Uia8wg0FLpjyPG2DObL1DpRIM3Ry9ctJQFd3UBrW1Zyywd4MBuR2796NtQfA
V7muGdYlZV27dk1KSqLl4IcHH3ywadOmKLh6RvbIffbZZ3J92CnbTcHQgytQ
NORTbgfTfxfwiRy6XeCWtX5kxts6Mi0Ezzgcr9YhNFdum4qkEMYr7DlQwo3c
3FzZCEfLqRcTylvLli2j+yoaxTZiVxmCQHOnwFJpaenbb7+NKnmblBPOY68S
EhLQuEjykOCekpOTHY7ZOr8uxlAf/BuVaYJAgK5khhdxE+g7JiU9Pd3blb5R
ipIzAQawn1dffTVADrNm32WBphCuyl3z0KmJ0A0rk1tWVpa6fTLwGcJJb0ur
RUVFOkAO2yhAThqDWw/cq8ZPMiPnoNRgBoCcoAu/n8AMxMVyNjYo0U7cLrrv
kEoO04pZxrDoTPXThTlz5tCXsHYvLJCT7jBAYvbDVg3RU3EfZrDZD/kGRATC
CXoiVZ5B/PDXYDm/LshY8C6uOZSI8gptyM/PDwRyuBXAIT/JrktNICdTOrTH
7ZQ1YQJ1IQBBxRtBXbBgwZQpU1zt9tckmIPnor8yjXPttde+8MIL9i2O6BTN
CzxZXH2ux6jM+Y8qyYWA4FhXqv3111+Dz+1wVIdkxzug0UMGOcYI+xBhcjAs
KqHcxo0bIzlHhuJTiBLdoMSI5+TkIFQyF4TQYgcQcpAzQA50ByJVFyXwGJGU
A75ChPLy8niXiCMSqcCtdOnSBSZ4K0Tekm2xrg44K0Jm5F1XlcK3wYMHY/P1
D0eb1ikSWI3b6tatG8yXPAxROBelqiK8yaxZs0BxF154YbNmzRYvXoz7Fr2Q
U6tE7jyj7vI7BU3C2qDjWB5ZI3OYkXNl7Wk8FgzNDXtEggbAB1RPbSsidA2K
LiR7rcMsEyaaX2lqILrAVOKs5RKuUA3Gn1K188KltCHopF9ggTQmMzMz7HkH
HSAHYfzhkuBY5yVIsOjUqVOxuuI0gz7Ml0uXLoVXDnML+A7MLybRfnuUNEZ2
nhN3hJJSxmL27NlBgRySxk8MhwJyROv6QM7tlUNUBN8cMgTCUpypzph6I7k2
/c4776xfvz5wzo5k0H1GAXQBK76ziHbCump1OtSVnZ1N7AYsgZ/EPq5MDYIK
S93eHkW/QIzU5a6tFqEgyLNm+sRAEuuKKKIRni9/F0Lge/XqtWnTJocQGwsG
ZN2xY4c8A69QIrlwasmSJQhDWloanyVw0LlFS3bZwfZIBAPciJEhKHN7w4Ii
wzrkMmjQIG9zqryL8LvdAY6tQHeIXjUvH5dn8Ghr167Fs9Df5ORkGhxFcVGq
QurUqdNLL71Uq1atmjVrnn766eecc86tt96qDjsgeKf+sIPM+cvesCoEcqa1
EBYfHx82BAN14EPVVBh2ZolFfo/RMH4CVDhPBUj2kkDHhB3gReynw7tYYLnn
2uEZysH24gclrne2D9hq3AdBt/OTOkuryIbcKuW85UOhLKAL7XTwWXgZ/Etu
bm6oWQ6x27JDO7AQydUZasbPtIaVmGX69OmBs5f4sqkWSV/gEkMme+Scu+Zh
Ro636CbSK9IVtKmMKbXPmDGjOpI3UiYo8f7777/55psHDx4MkLBrGX0HD6Mm
GRkZAwYM4C9uS279ribXQ7ErVqwASzCs8J+Ou1okNa1JJA+XBcj9tva0mfqE
NYAzckjWw+umxWdCqvXr14fK36tDqHzv3r3nzJkj+U9CjRHsRa3klBMmKyYm
BgEAoqNKRKy8m5SU9Pbbb8s2D4wq8MbhantBoTyTnp4e4fZp4BCSJokT3b4r
r6DLqamphB5ut0ca1gYeMDBI2NWMqGEdficEcCVvuAkML4OOcevSpQuqHUnK
mihFyY8ISPHFxGs47gkWYUjBHiJjp/7UKjqFXtMe5zULb0COktHcsECOUJFe
wxYxDjiXVatWBb0TCmMo5/cdSiP4wl0GXSbbvHkzdthhZQdbgRvFCDuUz0gR
PqslTuepDNgLPOvfv3+oe3yEdGbkYBHuQM7BOVskgSWMqYPpM6xLdQFaAHiH
PYH4LNAF8MkMgEDEvEivw7ZJubQXpxZot3fv3g0SUKcXwc+AOsy1Q6eEkApg
j1t3ZgdyQYmu4Umx/NLTKiFhF8KMRN19991XX321pICALfaWoB1z585F+GkA
Q8xfQDjev/qcDk2Ch6NHj0YmkRBY6ioHPo1n4HjL7aEDhGHQoEEeNu1jH4jy
gPpAI89sQb/otbdbEhRhl4iPnGfPaC32BwWU+IWRbdy4MTIAuwgSZUYOLHT7
7bcjb1g8egSoxuaE0lZBQfQd2wUfvF1tZlYGwikpKQqIeihEDsDSHW/7EMaO
HTtlyhTN9XGFkwnzsULKS+oQiiazfzSYGqnX23JwlKIUlORiODvxjfKkcmrV
7cpRJHTo0CHi67CJPT3PyHkGcoRUgU9ixEBxGKJQRRnWWVG0Pui6D3qNO3BY
EmI4iPoTEhKcZ71oJ83IysrSMaowTe1DC8XksECOGouKisBdcuGF82BRTkZG
hvOYInK4b9yNWqgNfJhxIRAGrYnRtj/A6/PmzaNfDvYcMcZ3A88CS2Yg+ElN
sPBPYKFz4mJpAHEQfsTtpVo6QA5FoKcOR108EMUyCg8//HCtWrXq1Klz2WWX
3XDDDY899hhsV+BWDjvIzen2DRXV4XSMyo2RaIEkGgI8wHlXs2QHDhxAAYmn
XM2roFBDhgzBt3o4QojfBzoi1Z43DGO+4uPjIynBtHYGAqXWr1/vvL7JgHbo
0IHHZKtMx44dL7nkEjmGr4Ac6nnFFVe88847suRXWlqanJwcaiFA6uIvFrJr
1644CM8YzLQdp/Us51u3bpVb0lwxU9qMzQFO6wNyeYwuw0ZXt4FQBfKGA6Kb
mBfYKwvT+g2OUpQcyPh38vsSK7du3TrZpRnJAXlNQsjRSp1b8LCEhKJu41n9
GTkCKHyouFosHkBu0qRJ8qtdeXkS7++8PAoowlYExYF4BKKzMWPGOBiE3bt3
O2djMCrzRAG95s6dq+xh0DJlQQHrTQzuwIewQA5O0mwFihzaD7LCawBdHDym
xObgFpgsqVmDFihTajQ+UBQZKTwCTHaoBaGi/DVr1gQFcjIFp4Ac0URYIGda
i1YASIfdbkFJB8hh5FevXj1jxowIr3+y08mTJ6m6adOmv6mkBg0aPPTQQ4y1
Ojwihx2UE6/WSQMKl92JqLzMjG3ZsiU/P9/VkVUGCziNi3TVVLo5fPhw6nLr
/SHqIqCQFGTe1gTRnYEDB3q7lUAI9KWyqDk0A2sAMAawSV0Y8zvuuKNu3bpY
JITWvkfu8ssvv/POO/knIwJPgEY87Gzz0VmCR4bP2yY3aTPv9u3bN5KkHHAg
JSWFlnvYhwC+Asy7yiZnVt7Pu2HDBn3hoZswGWeBXjModDnCkzJRipI+yV2r
BMuY2eq+NkgwBpApNzc3bKiC9cY6OSRwC1o+8CMuLi7sJDzqiRMHV8iuEiwb
rUpISDADZop4UiCNWKGg/MFOggowjIE/4copOTMzU+a1gsakghXprHOzDWu/
VlJSUlFRkQJXobAcXow2Y0lCRcEOQE5exxEUFhaGtb3YWHBOqMsUTFvIUFpa
mpeXhwd3kDFYjecKmrCFJtGeoMumijZu3MiYBr3fHIxHyVhmqZ1/0mxNIOc2
zbupAeSE8Bc4OJpdVXonU17IiRxC/8Qi+MmXqgrgPaxAPBYuXKi2x1cf4ctA
cQBsqQgoPnr0aM10LtJmpHTixInOF/gGEkxAYPjrlreMtRyZ8XDLp4g6ihwf
H4/iR5LzmdFReeFC1WVao9mtWzdJ1/bdd9916dLloosuOvfcc2VpVe2RS09P
B8jVqVMnOTlZVlTBRYMGDQqbzHD79u0xMTHeEoAoWrp0KYPuebsdPSXeoS86
qc79SPZkoguupilgHQxkBDUV37DSrfAKgbaAXuS8RYsWGD23DY5SlDwQco6p
R8Wqb3lFkSAE8INOfk6MIQroKnKXVU5QU1g3YVgpR/Bl8iQ2au3atdheMwBr
8SRgEisk8wlB24wKA4YHDx7sB/YMK5mGZJQVcBIKd2Fa8fsZGRnOWFquDOvZ
sydmLZT/FVfCr9SI0Q517C4UkDOsi2gpXxYxnWckZM0Lr2fHCYGNkXEZNWoU
iMhhkciwlgUlG3zgr/jxqVOnOsgDA4e7ATAE3RMFYsEzqrgAE00fJbuXsxxW
K5CD1bNmzaIlnrch+ZERguzP4PpBj5LI5RTkjUQC+/fvL9sREWA6C2f0Z9rh
ITKGrAa91CAUGVYGOWTJw2znpk2b+vbty7selgKlhevWrUPlI5lo3bVrV/v2
7ZENB8GTkaWidu3aCcolhGncuHHNmjXPO+88IhoBcoAooi3C24svvrhGjRoP
P/ww6MKwkhmC7rAnDghNLAmi0rlzZ28HFoQQb4xbQUGB5+OrGOqUlBQiL7dt
4Pm5Frm9zn6FRa4UE0Mh1zcjOXAVpmFzwhqBKEUpcpLDDhKXeVtH0CecOI54
yJAhDrNbilCHefPmuY1oJHEoauv8mGElJcvNzZX9WpK1g/hUIIS9YXKR1rBh
wxy2Z/MM4AGYIVsN7a8blVl/cUbO0AtLBe4Kuj5rJ+zDhg0beFId4gtko3wj
d7nS8qC4KBSQo5EyAeKwkiXmHcMOAwHbcigyVL9My4yD4rKyspxPgR0+fHja
tGlBE1NQDn2hLocJBJlWXbBgQVCLDZwGJarNiost0hF4b0CO0Rk7dqyODQfn
8HBVZRC1BxGqd34lyx45xlf2ylafyouc5OTk4MRl6IlT0AXnlGj2100r0uQV
twtzlI8RYODcImQYgvPFRjnntXYgeip5aD0fVqXxXbt2TU1NDbsyi23p16+f
yCctp9n16tUDrZ1zzjkyIycJgZGu55577qyzzuKnc889d+TIkXK2RUB12H3I
KNSAAQOys7Pd7li2E4PYqlUrwZAeXqd3gFLEwAMUxHTIDWWu3tq8eTMmwtXa
aElJCWOhbiXD5mMEImFalKKkSQLkVEqHagVykldN85oAAXKuTreZVn4w3ITD
2QRFGEmQjGy6Flw3evTowJVcDAjgEGATqkzDOqpPvfQLIBH4gKBEfJnziRLM
PggqMTERByT8cTjaSVFE4thwmdtUFfk9yeBiiwYOHBh4AX0gkDMq1xyx7YsW
LQqEnep1WS/u378/xtnhtKNRuUOGHjEocs+Ow5PYQIYg6AFqapw+fTocdlgf
OXbs2OzZs2XSL7B8hgBxUjhQss2EhTFy6RjddLU5B0SKnBcVFelsdZaFzuXL
l5+aFI5m5R45OexQ3Sq/ZcsWxE9tBgBWgcYZJn1gLDcyg0ZcTcdJDm0PB0lo
4YQJEyZPnuztWi65npU4y8MioJBh5a7p27cvtsi5y3KcE5URw1JcXHzPPffU
rl1b0JpaWoV1hJnPPPPMmWeeWcOil156SQwdNla2asi2VYe6kNKYmBi118KD
rCJ1lICow2G3rytclJmZKcdCXb2OqedFt1egElljuFxt0ia2JZBUQA6nEB8f
D7o7Zaodpf9ZQjEBS1988QW+0n6atToIkDB06FB7knkHqm4gR/nYJZVvjbYB
jWTTVOCUGk9OmjQplN+Xw2IYTFnOCOQhdYGaCGmdraXMtqWkpGBAwqZuo0Yi
TWJwgk0aLwjHr3z+CWDLyckZNmyYX4F+QE4cOkaSboL9QnkxKuUVKiXSx2oF
3qJlLw2Cn/SaimSV1gwdLGAwQcvAsKALPbgqhjUoTlYk16eqa9fsRDuBpjJ5
KN9IOouw2IBW4St519XpM/wmXV6xYoWONslpXHXu5hQQnULsEVegNTC7+lQe
9k6bNg1pUSEMNfIN0YeOSzUq94DBH9ncqAM75Rm8NnqBrLpFqgB+pMgeH7ki
hh51c9j5EJaAvp07d169erXsmXdoPFjx/fffx9YhOTwpu+AEqjkDueuvvx4s
Lbs4kNKuXbvCLmcxMKzUanFxcXKE1m2n1KAAqFxte1avm9aG0oSEBJrhdrce
zxN1MqauXkQ14J6cQtV8RU7lAFnlFfgPIMdwEdlVa7gUpSjh31EN1BljG8nd
0GEJ9QfCjRs3TjPLojcgJ+lwwy6tSvnYWzyaGBn+OXPmTMF1djKsAxrwZ+TI
kc7LNICWtLS0oBu0ZOWUX51XiqUlcl8qFiDwzJQfFpLZQqBLnz59BIXabY56
GIMPRqJ36oJdM9iMHN0cO3YsAxT0LjAg3MaNG2kYUBxjzsNqPifo+h2jXFBQ
0KNHD1lcMGwU2EIMrNyRKvFvoNFbuHChZMh34B6iwhgFdcF4OsoHyMmqK6LI
0Avadzaw1MhbKvucJoGr9YGcYa0aM0CyXfMUGHyYzCj37NkTNM6YRrKJ3ZnQ
qQ8//JCBk5M+prVzHiAnO/M1IRnABpQr01OazJFzskRVbm845cUpU6YMGDBg
m6d7BNAvgiDqdZvNSfULVQXqgMFC7ZpQJMlV0Ho5IYXZadq0aZ06dQKB3PLl
y/2AXK1atRITE4U5tJn+EuiFnXriSfQLLMcgupVSGTvUEEslmYrdvm5auIh2
eltdhVFEZM6pNf2I6hgLtFg/wmJQsCpIrFpVRw5hr4dMhlGKkiuSww4e5qvd
kiRks2fPcCZMmQcgJ5cg4KfCPolS482x29IeXHxRURFWIvBJHgAj4ZKcl0tk
TinoJjfDOtNEw/CeQY9k+j2MB8QjYLXAfsTmfnbP7gQFBUmK1+TkZCLWTz/9
VHFYPvAXaIHXFhgZFMhRyLp160aPHs33fk4WO8ZP4jVKSkqAeQpeBp1ko/FA
sk6dOqWnp/OiykgftKeGtTBNM8aPHx/qTkYKBAwwOs6bDDG5PBZ0JwyDS/kM
t3RNJkgF7TsbdsHJADlXaMctkMPvI7GLFi3SryISQlrQRDnHV61aj/Lm5uaq
fIaGtYGBbgKTNP0pj/E8w+pqhYt+5eTkILGuPL5hZchByNECyfih/64Q/jop
KYkuu83jJHUh3uArmq1zwylwKD4+XpJ1m9ZU51tvvXX++ecLVFN75IBeSC8C
pvbIXXjhhe+88w4CoNA1v2JnVq1aFbbZGKKOHTvCWw/neYXmz5+PZXCV1sNO
EvJ4SOrCi5JL3NWwMpQAM33YSadwKAi8wn54sYEDB4ZN8xKlKEVIckVX2EPo
kRM+EU+qv2YB0CKc0ZlbsxOqtHHjxt69e4d9El0DIw0aNEjmIbHhuAxaGFTT
4c+oUaOcMRhV47mys7NDKT7eoaCgAHijs3+mrKwMyEQLU1NTMX35+fmfffYZ
zQhVOIZC0uHyMG3YvHmzbOtSwaykiFd7d/2AHCUTOWKC7PNsPLx27dqsrCyZ
haM9QXdVAXL4iViAKnAc+Bde4UX6q+YAg2I5+VK22wF7Qtl2mDB27FjJIxGq
EAh3TweDHvulJXhnQnJ58ptvvsEPUmO4Qfgxrx1er/pm5ExrdBA8tzvxPJPs
kfOQl8MVIRUEYuBnBUvgodx8pL9/TG6pkB0L+lVLUKbPf0UgMXCCXDPn6kXT
UkAqdc7+7UAMPSLao0cPNDds7bL8CiiSaxoM61AJWBduEyqCytq3b08vaNKI
ESMwaxg3eE40SiD2wQcfoAh2iMvrDEqLFi3AG6F0UAV3W7du7dWrFyOrcKAr
okkpKSmoszcouG/fPnCR3Hrm6kVkvmvXrm63q2GuQa2uTh/TPBRZWWmYhkmk
nKDLHFGKUlWRmpGr1lpQHwwUeEA/ssZQYKnAJG4rAshhD81wky24FQJDBeTk
9lVwY9DQCQOCQ1+2bJmzHZDkKosXL/arXU090f0PP/ywX79+mhcz8QrN27Zt
G2+1atUKkAZGIkjEOGPNwMZ+rcW+0QZ6gT3hFXqkLB6Wky5MnjxZMIkdyGHV
seSULCgIwuzAfCAZVhfzLhv/7D3CgwBXgFh0ljKpLi4urm/fvgsWLKBkmeqx
466gY4HsgZEGDx6sMu7aOSYfaNs0i8T1hJrcw3IC5OhF0AGSjM1qPyRsoc2S
scFZSADPhNiauzoVCZDTxwN4TyC085ncKiQkBPDsbfVQkwxrDydMADMoDIyK
EcfJXeSa5aB3ICvEw1XtSDUxoNvsH2gKwowUecviCwgcMmQI0iIbR92+TjT9
5ptvOoN5o/LASEJCAtotm+pVXdSbkZFBRLB//34KEUgGipA8csoEwU/iJr+J
a6AvNpPvQ/Vd3jUr8w937NjR22Y50xodKkKzvGV3wVzQd1e3oFIR3OjWrRuB
nqskJCgyLN1WeRONzitg1NzcXPtJVaS3T58+HnYGRilK+mQ/tWpWzxYdw9od
QYCMDoZyxIEkl1IFzbLrUJHMyCkg51CXYW2/wfZKaCmJ1wiKg04X4Hqwh6BK
50hQFijRfXEigZaKbwAksAKARNWaUxOGtX4K7OH5TZs20RL8I7E2hRCAyxXz
+BF1zgIDK3cM9e7dG0sutotC5LIMOTKggJxkKUlPTxdTI+lHaBvFwkkqFY9A
maBQWISnSEpK6t69O6+MGTMG7ESXAUXKfYTiuR+yxZIDHWEp4hf0nKn4jiVL
lgwfPjxsVn8KAQiFSsVPj/Ly8tT9rZhWytSZOSktLc3Pz9fJG2wn7P+ECRNc
zQjhQMHnp+aAm6wXjxo1CmRbfQmB4Tayp06bysKlAtuaRoAxQg6JKVxVXVBQ
AP/d3iMgs3+EDN6m41BJ5NktFBc+oNcoMrGGwzyVtAptzcnJQa/tVxXIT4Dk
Dh06+O1PUDc7qG8wFMnJyYHzfmAP2iCnSp0bTGcxy+3atXN7XYIQr6empoJ2
3O5gFML60X2Mlb4UyWOEtzRbZ9laEXxDhuXGVc23JLW7fWKEMSUAx+pGr+uK
UvUR5mvDhg3AA+StmvbMoAJgAGy43EqvqRHAEryA891YgRXJfjZwiE7+HzQU
q6gMF14DqBk0gTwlY/ri4+Mdtq2KsoOasBhgpKDTDvIMfKYcfE1sbKzcSm/f
eOZMdFAuzMXIYJToLAEyUTaIKCYmpl+/fqAUzAiYSqAXTq1v375yGhQCm4Fh
aJsAOSAc5nTKlCkLFy4UkImfHThwoGTC5BsaRhW8npaW1rVrVxgLkFu7di2s
A7mBz+XqXk1Dx/PUi7CBJ2kq0IsWBhU5KVC4BJ53Zo5hZRJWO6kCWwKLJk+e
LI4DJsBztbjj3GzYRbFu77XnLRyiqxu3Gc0iizxfY6RPADmGHmcKb5HqKvcv
0mv6MmDAAAWeDWtrIuhRLXDrFEWEgsd3daeDzDwjz24BKrogOdlcvSWEoGKp
VJYVTVIrzkOHDs3MzHQGgfIw6tymTRvQgl/vUCKiKgQb+2NHOIFATvZxwSJl
IdXkOcD+/fffJwAMu6ELs0C4ivx4u4IKqfO2U46mYtn69+/Pu873z/q9ZVrW
njhdE2mLK4EPoGsQsv6eB4YGIbfXQlF4GblqTbOQKEXJLcnyFoZ93bp11Sdp
KBHhqqvcSigRcCI9Pd1tWgbgDeZOpy6e/PDDD9XCGdoHUJGF0UCiQHyKuijB
wYZQDkGZygAcNL2tzFISVwJpCDAHDRokS0glJSXEuUAOMNXhfydGR33mV7UM
ikEDnPBP3po9e3avXr0SEhIAKnAPlw0eAw8nJibSHh6TBHSEhwAqamTQqREn
QuE8yU8AQvwmT4IGZ82aBUPi4uLAfkT6Uik/ieUXo3o4NPE8xVIjBcI3ECAG
jbYR+MN2YLOc7Qrq1g0r8zz1qoxeDgzHT8kFE4LJ/Z6knUBreKvmNACr+DK1
VhuqWIYPJ8gAhb0X2I+ABLDO1dIedQEhGBG3lwt7oG+++QaV/+yzz+TOzeqo
Atkeb5Fs4pIvcfp4UsCGPtpBGWWXnX7VyBvjKzfI678FHzAawB4P1zHwLpEC
Iu32cKLwAZyAXqAOYRu8c+fOli1boqSBhlqucQmEN4FAzrQunujQoQMPq9t8
FKSUuM8hhZ16GPvQunVrnncVeqhIlmiRkXW1QqoISwJmduutMOBUih1zJfMY
T1mt1hRawl6Mrd8tGER2gE+3ZiRKUdInWVpFKx0WxSIk7AN2lfDcbewvV4vq
n+WXpVWex1noADlJkYFNkH9iwzGSoUJyyYIrS73OUwqYR6AL8AwMEHYqSU4K
oP6Shg6AgTen1926dQNB9bBRnEV8DxAStIZxGGSRXGxNIfQd1wmiw1ZjJ1NT
U+X6J7rGh4ULF1IXThyAhK2eNGkSDgheAeMlh63s7uAnPjBeRJFYJH7CVuNM
P/74Y1qIMaRG/mLw4yqpRwiKjY3FrEkOCli9du1aUC7ATNCgA1tAWfQIFCfj
6Mzwbdu20XhkLOgzMkfK2Ekhsv1PJ6uA3LkZ6sowB6IlHvZolZaWMvRu9+N5
IBpG91XKxOrQesQGTfE7wU3XiAtcHc6lBPvWcQdSvQCfMGT6N2XIY4g3Ii25
IvWbJ++C31BAxNvD3CYoTnLBqWMLQaswLYDapk0bySvu9xi4CItB8Bi4WBkI
5HgXwUZn8/LyAg/noulUgX3QyUaCJUHHP/nkEw/3gzBMGAc0xRWsklowRNhA
xMlVpYyO2AEd5GlU7gksLi7GEmpiMHmre/fuksBQfY8B6dOnD3Cuuq/Di9L/
LCkgV31VyIUOuDa3yo6DBquo68M035JkDiUlJWGfBE6sXr2aSFb+KfcgEB0H
XVlAB7/88kt+dbh01V4yUComJgbXoAMDBILyFvYcOwOaAsDgcPmARd27dy+F
7LeI74m+cfqULzNLU6dOBfDgIjEggCvA26hRoyS/BPaEBzIzM7EhsIUncYs4
2bS0tKVLl/ITKC47O5se4UrwBTCcMjFcWDxe5y1GDY+MbccQ8cDo0aPzKwk4
hDXGnGLlaKE0D1fyrUXSBfwjn3HEsFQtwprhzrHSnrFjx9Ipddmr87wZxplm
h3I9tJBRUJe0UiZ91zkbiL+bN28eJbuN/b0BuYMHDzIicLWa4ilFakYubMpZ
zyTnN/1CMHwikJ56NQuB/7Ms0l/Ykr2sjJrDhSN2Es/LX+zA4MGDQ8UCDq9j
NJAukI9cV+3qdSSEiAxAJccWHAQSy0CMKXvmA6ug6g4dOhAlBeKEoEDOtLAQ
6ux3dalKxBQfH09M4Sz2YrKwA3TBwxWojKlc8OdKuYzKM/hYeIIRt4lPgc3q
huWwJNzA0kqaF/1aGFD7KTPT8iwpKSnEF5piGaUouaVTAOQwPmADt3cXGtZN
63Ini6kN5AwruYSkfwz7MIYIOIR5FAPIX7kKNtT2trC3pqonxcpt374dyAS4
wpa6XTLDyWJwKAHHB16i3gULFoBAZLkzw6L09HT4A2+Bu/wF/ADAeAAI1KVL
FyJ9gWRyXgDfChAdOnQoxvOjjz7Cz2JIBw0aJHvAeBcrl5WVhYXE4UqaFLwD
kTuPYf34hkKorn8l8Zk28JdXgB/UQgtXrlzJQFMgEA42OkwyBP0e0E7zZCee
DoozrE2JjDXdDDUoMA3TqqQIlAgrdCa+ZMUWfrpNHeDt1KRc8eDQEW8UyD1E
EQHAjwOrNm3aVOV75Bj3CRMmoIN+G6gQEr7Uv/ISHIgwgE800/GZlfed4eJd
uUtABQxBvD2sq2KjkH+Asf7cpnSH0AY5Bz0K3HXoIz8hTm+//TbGKuhj6KbM
pQc2IBSQQ8YQAGTbb3pKfgXQtm7dGl12njk3LdTXqVMn4jsZa1dslzOhrtY6
FZMxNQShbo9LEJkimZor9Wq6FUa52s63cOFCGOjnRDBojJEHAYtSlEKRXd1Q
ZJxa9Z1axQ7g1rFXbu8sNv99Rk6HJKrdv38/SAY113kebAN6kYCLd2kkRilU
/IVZI0DjAf2YDgzAK+PHj+/atStMwODTnePHj8tmMyH8CAr++eefY9OwujxG
+Na5c+d27dph6PBl9AWsAtBaZxFok4fhKh8WL148c+ZMuVVcbhwDDOCVJB9I
qkUgSVnZlDuwRo4cyd9+/foB1Z5++mm8OdZeUoiA7nJycqidz+BbXuRh3gL5
UDK2aLZF/HPVqlW0lmaAMzGPay3C8sttU1hLrB8NSExMpAt4On7lYSD9gQMH
VMeFCbAIvApnQJU0ifJ5TCeHg1h1Sqa6UKf7QSkUmJ+fL4E/I4JN5hsdaZRM
hsuWLXOLrGCCh0u66QuDy0BHnoTEDwD7YQzQjqB9qsOpVTmQ+/rrrxF42ZNp
/x44jbDpX86FeDOyaipVh2AdQA436qrBQCkazKi5zU4m20oJjlw5aOkdaBPt
0LkBisJ79+6tMvAokhcxkhiKUDmrg+6RE0Kde/ToEVRxEAl0HH2k8LDTjHQh
NjZWtnC4mpPkYewM3PNwrTwgkNgT6+1qKRzXkJ2djUTpazRGALyNZdOfFsY2
SvJh06Z6yCS+zMPUZZSi5EdIL2K5d+9eu8oD5D7++GN8sRxCrPJTq5Qph/g8
JJDEyGRmZrq678awDsfhuIEupiMuFdRH4TgXyQ3LN9gi7J5DFmKeJ3J3laZY
csGBVYjUhg0b1r17d0BOqo2Sk5Pj4+Nl2xtIBosNeCguLsa+YbrlgCrOl9gQ
a0BTgWTYWLxAt27dOnTo0KpVq9dee+2FF1546aWX3nvvPeATVeBfBM516dKF
KigZeIZ54Vd8FsyhRkLpO++8ky+pGriFvZJZuI4dO1IyFg9fD8rt2bNnTEzM
W2+99cwzz1DF66+/3rJlS57BC9AR3gJ7CK7DjSJFtBYBAzh99dVXiBZQc8qU
KZTf0yLwIS2hSWlpaVQHnpQtdsBXnBHdVJMAztNx8hPWlb7QAHUnjh/JjbqS
OtW0pkEYX0CvDhTnXdAIQFF/rE1Ly3gL7Oo2+qb9CAndAV+ZVRRSCZf8cvoh
V0iRXApQhfpu91ngBz80hQogBkFvTglajmGl+2PsXG1PcnvKWCoiGAHZAlr0
Z9WEwDCSus0t1EeXAT+LFi0KtTVOEXxDNQivBO0EPomSys2AQQtxAHKoKmZE
EhAF/oqmoJvEI2HPI8hhIlDKduvqLk2JksfkaMCmTZvcMpDmYcHgvKujFnIf
GV3WD154BaPtKqMvtoVgXy1ySU+xBthSRDqahCRK3kgZCnARjr558+b201Vy
anXixIkY3uo4tQo0wmsQ7XpwTAADlEh/TVZ6qnK+6SyA0jwexiCYlUcPwCR9
+/YNZY4wIKtXr8Zyak7K2a00KszrxwPoWCXJP2UvGS0BSGDiwGOAJQAt4Ao0
BaaSU67AMDDVK6+88oc//KGOReeee+69997797//vUmTJtdcc029evX+9Kc/
8RZAEbDE89hMPgClwFFgJ0rjXT4ATfkGzwIgJLoXfHj//fffcccdlPDss88+
/fTT119//WmnnUYtF1xwwe9+9zuqfvPNN3kSLwM3eLdFixb85Z9EyrNnzybs
lQhd+qK6GarvcMa+g84MmEcKytsFCxaABnHfoZ5B1PHR6qI3uUMBeKCzfx7X
CfZAO3QGWpGskAKP3c4zGNYRD2A2UU+VbF2Te+WKior8ljjlZgeAnDNU9kYM
IoAcGdj+7zdyIszgFp2dq0KMFHiYoEb/fkzETKadXV3liRAS98F2t/uXZHMm
7+rvS5HyJQ8bmoJ9C8t/MBKxmDoF6fcwPR06dChxn2xjCHzdAcjxPOxipEKd
CwOmotqYx7Bb0WgGQI54Sv9qMzGw8BBp50UPx1fpGn2n8a5GDXMq15Ppv4Xc
0kidFspoAvnQO78dQYIhsVfVeqF5lP6LybCOexPmv/TSS2eccQYO2p7gVPbI
YVKq6dTq3r178ZsbNmxw9ZZRuUg6xSLTzQSF3HEPkNOZDMcEzZ8/n8DTtGyL
3EBBlK0OSwZ9BX1EVYOaVg+kSpCRwgLQZUBXUlIS/iUvL2/gwIHgq8cffxxY
1bBhwzMtOuecc66++mow21NPPQVUwy+A7vjAKDdu3BggV6NGjdq1a4Pubr/9
dhDa3/72N8AYyO3BBx9s2rQpf5EEynzggQdAdE888cSf//xnUOIbb7xx3XXX
ISeUf+GFFzZo0IAHeF2qoCVt27b94x//2KhRo8suu4zHzjrrLBDjPffc88gj
jwD5OnfujHWV5VqZr8NsMo76SZ/0CZDGwAEaQ9lGagRPggfUKifSKEmMdRqD
mvCwzk1edpJEIvgLD4lEGH0cdyQpp1S/EOD27dsz+s2aNfPDVAA5XD/gVpIN
Vu240AWAHIPiB8AAcnwvt/3qEIESUgQr9Jc7eRLUqn+bs9Du3buJklA0t3yA
q8B1ILH+i9IwmINqOGfTlZ+QQEKqwHtPFIGyUDEHJOkA5EwrtG/dujXCEHRC
m9bCT6Qo1CXIdsKDaKI+PwIuEksWFxe7napCQgjiZHVVfwhgKXG6qyXOLVu2
YPD1I3eUF1agX34Nk21yHtaRoxQl03JemIJrr722Tp06ePbf//73gUCumg47
IMly0tPDBjnexRcAAgmxXb0oeUIAcjqLufidkpIS/IVKVoaiyX2LDm/hJSdN
muR20S0USU+BHESmsuoKkJMVQP4JOvr1r38NZDr77LNBYo8++ii2HR+3evVq
ycp75MgR2XQn0330mpAQu4pH69Sp01133cW7Z5x55sW/+hWv/+IXv7joogvP
Pe/cyy6//DSL+PGCCy6oe27dW2+9FdiGkFz6q0uffPJJuV/1mz17AK4wR1XB
Z1q7Z88exAbEwmPNmzdHqOrXr//LX/6ybt264Mb3339/2LBhclUuH3r37s1w
LFy4kD5W1ayvXBMwduxYlQQ40DILqKBetf5Cm+VMmU4VeGra7/ZaB4CcbFP0
YLHpwsaNGwsKCiJJOUUDiJv+/ve/C8x+7733/IAcLonheOWVV8DkjGAVXuct
U9wIJ933wwYIJKhATY2GJVQMEIL669e+a9cuNNftDOqaNWvAQgAJV2/RO4wG
oY0syOq8opZFgEY6SXeR8O7du9O2oKcYTMvQDRo0GHjgt3fOTs5ADlEh+lM7
SAOJ7wFLkydPDqu2IrqCkZyf9CN6AZDG4ulbBrVbIC4ubtasWZqbdoSHyFWL
Fi2CnvANRQSMyKH+lRCY3/79+8t6sT2moNJu3brpn9qOUpTshH2bM2fOX//6
19jY2EsuuaRJkyZBZ+Sqo2qCrHXr1oFGvB3EAzDg1MLudvMjSeM2evRoHW8o
ZzFULm7xRISoDkdTZd4MPSWKd5UCNLALGDECUgwpUCclJWXatGn43M2bN2N+
H3744fPPP/+666677777GjZsCFiSS+1pnkykyJIlgAp05EvpnDdhwrjxE8bz
//KmggMXL//yi62HDxwAog/LHvbEo49ecsmFl1915XUNbrzjrrv+9PsH727Y
6Jbf3HrXnY2ffOSvr77wavNm795/X5ObGzRo36717KJZu77effjgoX9++eXC
+Qvy8z6aMC5v/DgfYdJhDuAcY2VUpkwB2gHU8ReYr2eeeeaWW2656aabrrji
imuuuQYUgYn+3CIQFI4JmAp4gNvKkXmYERKwhA9ScwVBgZxcfbto0SL1DLZU
fy0Mn0tTt7m8k5S2Eb9L7hRXLwohugi8w2JxWAKnARUuvfTSevXqXXTRRYFA
TmbkYB0DJ9MgVbjACm/heeC5UfAS4q2f2hfNGjNmzOLFi/UbxuAiYwinfmtR
QHQtKyvL7Q5euebM1WFV01ovloNFodbp7JP8RKNBs7RZScZ9/+3euTOmS+dN
m0pNw/dFOf/PqDAr+Osrw/S9YozyAbnFR4/+4Pun+s+0/rOKLN1Ump6SvP3L
L6xCgxBD1q9fP5BnqAUO1TbwZEZGBoGb292h+COCfdm06epFVBsh0c8zL5tn
evXqRcisv/6OpcJB6BxLEaLkgQMHEmj7YXXaSYSLlFbHyleU/usJY4XbBc5h
Xa+88kqAgR+QAzlUx4ycYe1Fx9YNHTrUdDxfH4oAchh/AXKuCJzw4Ycfono6
DwNCMCNqCk4u+crNzXW2D99//71s0NJ0HHblZUTwU9hzDDWmTzZx0QziPqLF
+++//6GHHnrrrbf4+/rrr+MWcetqFxn07bffwlVQU8+ePYF/U6dOmztnzszC
ghmFM/gzfcaM6QXTCwumLl66aMLswqKZsxncnV/tHD0q575HHnj65b8NykxO
6dOje6e2/3jrldbNXk1N7pUxND22d8zTf39m9qI5+7759tNNn8yeM2vN6mWb
Nq2ft2j+9BkFMyl6xvTCmQVTp02dMnXKyJycxMTE+Ph47BV2Se54pWG0EBtO
24YMGfLoo482aNCgUaNG119//QMPPJCQkACkB0KARbGiYDBaPmPGDNqmf3OH
8JDnQXH4i9LSUgewLVMEcE9CYPmGIQOiq0sxnOvCedFUt3js0KFDRUVFuBhv
m2Fg0cKFC+ma52MIEokgVPhfmP/222/7ATlJCGyX2yrcLIcME7gFHjWF80Bo
/RudQNGMlKv8XYQMhG+aEzvSX7Ewcj+dfkUQQj5hwgS38S+DAq4OvGDL3ir5
gH0AjYMVAzfzG2XGibLy7w1z0pSJU8Z9uHfvt2UG6I0O+HpEueAtWaSkrFEf
jltd/PHR4ycMCwHyE4D1qGn8YFJC+Umj4sTx49kDB86ePfvQd0cCh1+4BIs+
+OADHZkkdm7ZsiXS5TcZ5UxEE8R32ASEXzPVjDyGzUxLSwt7EbP9RdNKcojh
kg2Kmi2UxJualoq+Yzd8LP13UaQ6ykFK3aYzilKUTJuVJigOBHIYCjQUXZA7
ofhnVR1kM6wrViXlhelp4iUSIDd27FjNUxKoG94H5KY2afD68OHDnVdbjMqD
EtiE9evXh92PJ+unNAn3lJmZCbBBo7F7kv535syZzz///M0339ykSZPnnnuu
efPmWM65c+fu27dP8Jtp7f0D79GvTp06ydmrkpISySyH0cibNL5nYvyAYUNn
L1i0YOGieXPnfLKpdOsXW9eUrBkxe0R6XsaISQPbvvzHD66+aMKtDYobNvyy
wY076l+z7fqrtv7mhjW3Nxh59w0jX//rsqk5Q0en5BXk8e6Ozz//dPPmBcuX
z124aNHSRVOn54/5cPTUgmkzZs8umjNn1apVkiujS5cucXFx2EaESpwOraWp
IDSGHqsOkGjWrBm4jq61bt2aF+X2LsKHkSNHtm3bFm7gFrdt26ZzAA1YlZeX
R/dlpsIMMZskQUShRSqdHe/SYFl6CyuNPMBIgQPd3iaJzDOanu/IhjngClyh
froDO4mPo2qcDuy94YYbAoGczMiBb1UOnKraKSeVojt+Lo8qkFKAnKYLozFo
VkFBgf5yG6M8yiIdb6vW5tBcJMTVuXjTQsKSzNbVQsP+/fvfffdd+BNWomBX
cnJynz59gk/4+4bK2LNnd4e2bdauWX3ipK8R1oycD7+VH/3O/HqnWVJsrl9h
Fq/L7dtr5fjRx9YsN4tXVpSsN3f9n3n4Ozrve7LCB/5Ommb+nKK4xMRt27cH
bYyoEmHjmDFjnDf8yx5jORrvvAPQvzdW6kUsif61JqLRWGBX02tiMXB28NbV
EvCIESMw1/qmQN0Io5ggH7AMFOXqqsooRclOdiBnD8bxniCW1atXYzTAFdio
qspHSo2S3ENdBuS2BBTBG5DDZc+YMUNzZzVmEw4AJ5TrBGbgxMePHx92Gy2u
8IsvvsBz5eTk4Hr8Zm94HU+E3QA8wAeMYb9+/VBkABhspzr4g74D4a666qqX
X365e/fusRbJldYqqqUQ/GDv3r3lpw0bNkiBKSkpgDowIV8uWrao5LMNe/ft
KSsvxzF/e/DAnNVz0vMSX0t4/qm4B99p1mDCXfU+qX/lgksvyrrg3A/OPuPJ
Oqc9VqfOI3XO+Ovpp7U8+4whF9Sdcfkl6266cvpfbm3f+ZE3U98ZMGnQms83
Hvz+e98ibnnZ8WPHtn755bwF84bnjEjs21eOvoKpQCygDjgQExOTnp4OuhM2
GtYlsFu2bCHQ7tixo6Sze+qpp+69917gHBgVpyD3w8I34Ux2djbYD4yBKPpN
ZzFGcv3EkCFDGBdJb2U6ChVVgxyUDPAkfONdTWdBjXhqrLfbRTeAHAiEAfKm
RzCNbsoBQA+vm5U+Dt4yKNddd10gkKOFeFuGY+jQoVlZWbAUFauSOXkqYhwp
3G9cYCauTX8uAiYQ/bm6zIuqkR/URB8/I6hICJGR2yOTRE+YC1fZ6hgOWO2Q
J0RIflq5ciWaHjIpRwVfGssWLUtNTP3iy+0o27GyYxXf7DFXrzLH5prdOpsv
PGPefbt5y01mw5vWX11vS/0rj99yI5/NO242H29qtmllDhtevmiZuWsneg2z
tv1zW3xM7Mcb1pVX+LNORUlEoJgatbUsaBfkSzCVzDvpT42a1sIQhtG+nVXz
RYQNo+EqM7AswWwPAVyD0oIFCxBs/VeQEMlX7DcrwuiD5Ks1/X6U/usJtHbp
pZfefffd9gULddhBotSqzSslVwl4201tWOe4scyjR482XeJAyXWgv62UduIF
FAyjLliEOVKJgh3elak2oCBOYeDAgSAWQA7gShKmJSYmorlFRUXYKGqB23JZ
lVw/8dxzzzVu3Pj111/PyMho06YNYTjlUJpyRpiCcePGgXwoGcgEAgQ78U+8
MMEdHZTsf3L7eUWF79xxhVG+6/D/5azOfubDF64del+9vo16vlL/44aXjr7o
/N+dduYFNU8/q2btM2rVOK1mjdNq1Kpdo9ZpNWudXrvGmTVrXlCzzl/P+EXe
JRcVNbnyyQ4Nbxr2UMuC9+d8OevIiQO+vTe+DTg+bCa5ROCVXOdKB2k22IPG
YO5gGv9E0tThEfoLXgVXx8fH9+jRA7Y888wz99xzj1wxibWX6SN6unHjRgAe
KGjUqFFyKVjPnj3pKQVSi7WIPJURoeSwJ6xlFRV8osZUttVh8+XCiLAQHRHi
YUmb40r2JIiQ1SX9t+wtB8oyyhFuW5UcF6GAnMwYMILIG38Bt7LpMZIaTWuD
X25ubuAGObzzRx99JCk+dMpBKnheXYLsTGpKB02R+zd1pltNa2KNWhA5TQMl
b8nBZ2TDFcInmiOcgdVhRRf1R/jBsSFPKBgGRiQzo/+EceMPbNti5k0y32tp
PvIn846G5i31zZuuN2+42ryzkfnKi+a775a3bGG829x8p5n5+mvmffeaN13n
++/mG8yGDcy/PGJ2aW9Ozju2fcuwYYPmFRWBwUJxDxYhk3RczhY5m0SiJ7TV
7akHAUuSFUf/LViKnOsfOTGtyVtQlgo5dUhy2usfQWK4cUCBM3hwj2gdM15V
Oxmi9D9IhHhNmzYFNtgji+o7tSoHQomYvK0xIef4d8JeSjBdAjm8EnqEQ9HE
pXhtvIb9vBvf4OnUOYuw5cgOMd7CO2zduhUrgUWSa1LxYnI2QcADiIVwtWXL
lm+88Ubbtm0x2oCf3r17Y8fwX8r7UxpOFuQDhsEwMmTAGOJ0HOXnn30miYJt
a4sVpu//jD3f7Rm7LvepnGevS7vnd0Meaje19dLJfT555P4Odc+uW7s2sM2X
k6RGjfNq1PhFDYtq/finZg3f/06rUePO02oP/+V5BU82eCvldzcPuq/RgD+0
nd5m/rY5+4/ttwbAUGG6dJk2E6cDt7p06SKJPgA/YDDia/u8GU/yE44AO8aA
0osnnnji5ptvbtWq1cqVK8W/y5ogT+JQ4BLRK94ZTAgAhpNYRX5SuW2d5YHX
AYSAZ2WrQc44+sLCQjVhGOpdtQ6L56Ivzg8HEk2lFsCY58yfdFnNY3smeEVs
8utf//rNN98MXFpFNfBNEripid/InQvjNXz48MCpqt27dzP0BGWakInhg/n6
abfpglyjGeqApx9JT+EAmohV1O84j0lqRzllo/kWNpaxwJjo5MRjaOLi4iRx
XKiHv9y3Z1Bs29I3Xi37U1Pz1t+YN17rg2f33Wc++7KZkW6uXVzx1VZj/zcn
Du0t/+5g+aED/FdxaJ+5batZNNscNLD87TeNB35v/uYG80YL1D35RPHbzfKy
s//17bdGaGlHf3v3TtDZKsZwEGYygq4y8MgZAYdTFUEJ68pbjL6r6QLUE9XW
XCqFIUC4rKws/aNtADkcCt33YyZ9xPRVx714UfrfIRQQkw5ms8u8/dRq1cYI
eOfFixe7TetkJ9qJa/CwtMqLgB/CLh2bYFg5hEFxI0eOVF9ii2DLoEGDPGSq
NKzjnPYJGbV8AMDD7Lz88svPP//8+PHj5Zac1NRUDIU8L0AFfwTaIYSXFYpV
q1bFxMRg3rFXcvGBIXNkFT5gVWH42Hv85LHirWvaTmp/TcY91wz8XftZbdZs
W7z/u/3HC2cuu/6m39auXbNWnTqV2K1WTR9sq1mjVh3ro6IzatY467SaD559
+rxHHtlRmDeudOLLeW/VS/ntrZkP952R9OXXW61+VFibcawDctYfuTEEFNet
Wzf6Igc36F1ycjJmWdZKxCvBZ2Ab0TqMxRvSwccee6xFixZALFCf36qN4Ge/
GQzl3RzcHN8z+uBwtYWAbxB78JU6DRp2Qm/Xrl2TJ092zkITlOiIrDh70yaZ
x2b0gfGR6KNcs964ceM2bdr4LefZEwLb6/VclyKiJ/ssqCLMC8qoeWuqaflB
+/mjsCTZILE2clGCzivwB8jEW5qThEII89ixYwlSMAthgZzqLGqblJQk0/vO
rxAGdujQAZupDNdJlM2nZT7dkAML5v4DGyZ+lHvXHbuuvdK8/mqzSePyDm2M
iXnmp6Xm4UMVJ06UV5SfMK1jDxW+50+YP+6FK0OhKAbj/8MPxhdbzLFjzdb/
MO//rdngun9dc2Wve+5eM2rkiUP7fHvtfEdaedT48XSrNdEPTcmfGNO1s87x
LsIQtJuQxBViAeSAl9xuIRsyZAgGxJWhlozxmnsjGUdM96hRo/SBHCpG3A2j
/KblccE0lQBTkqXrNzhKUbJToPFBRD/55BO8z48IoeqwHGG47BzzXAJ4TO7c
cfsiHQGGpaWl6ezJEdy1efNmnld5gA3rRBsWNZL2KxJgmZGR0bt37/bt2+MI
cCIffvhhYmIisSFGW000YfdKSkp69uyJQWNQAN7Dhg0DHeHWcSLKLJSZ2Gkf
oKooO3ng0MFF6xZ2HdGpYad7Lo+9s2X+PxbsWPzND9+WV5QZJ0+cXDRveaPb
7q1zWo0zz6pZo46ah6tVI4B86K5mjdNrP1L39JVPPGasWn68ouzLg9vGfjz6
hZwX63W57b4ej6WPT91Qsu7IkcN4BMPERpdV+Ex8hbScEQf8dOrUSc780hFJ
q6IWPoTVWDlQHzAP8ViwYMHgwYN5JT4+HmgHAozEvkktQF8AMBGxyiVrWJmB
Z82apWmKjX+/wtWVUoBjYYLmiemghODBClgUiTLKpKIcSPcLZ+A/AHvDhg1g
GDnA67kWOyEAcpV54EQHbSBm0c+pQvMQoVD359pJGi+zoOAl/VkytGnixIm8
5ar7BFxDhw6lL2GlVG1TQeAzMzNnz57tsPtL2iC3QfkhmTKzvKyi/KhRdtyH
r8qMNSvM91v83203l9a77Ls/NzWHDjA2lZQfPlxRBtxzozg+bHey/Mj3FZ+U
mqkpFb97cO5ll2696dqyD1qVry8uP3H8pGGACE8aFcdpl1Hmi9cM8+ChA2np
qTNnzpRFWOfuY7cJWl0dJKHjmETkxNW2BMKHzp07ywyz5mh+/PHHjKPfTLUD
ycoyKqM570fEyohjBOzprKWu/Px8DMu+ffuiS6tRqkKSZAXjx48nejpw4EAV
lowKjxw5ksI9l4DWoDsegByEC4uLi9MP0+Q+JhTcrNQ4HBNoUHJ+emiAEBYJ
eINTxm4QOYJeYAi1pKenA+SoVJksKgVUz5s3r1evXrLpd926dUS1aD1w1M+y
ESQfPnpo/YbiqdOmJQ3r81Cfhy/pfcf9Ax4evjzrm6N7yoxyLBoe+kSFcfRf
2w937PjRxRf/trYdvtW0PteuVbtmzdqysFrDmqireV+d06ZeffUPiX1OfPvN
cWtf3PHy45u//ixxduKdqX9o1Of+9sPbTyiYsnLZ6t07/1Ve5ktrYO2f+3GD
JYYL/zto0KCEhATGDstMBIpxRrrUhJssoa5fv55nwHJALJm+4y24vWTJEleT
JH5E+cBvuG1fmgTJgOucnakf0YyxY8c6b00PSshMQUFBJAujci0psDNCU2/Y
yP49TgTA8Oqrr7Zt2xa26Kd/cSbw8/Tp0ykwMO8KbMTbIhiaPeJhzasxpHd4
ZPwjEqUP5CR7LSKh87AQcguEQ4tdpWtGo8eMGaOTQA/+9OjRg16o64atSstO
Ei7x6fsj5kfjzaYPmjdeW3HbzSdiY8tKPz529LsffFtjvSyLn/AFg+aJiorv
jh0r37SprGOnittvMW+41mz6iJk/pezw4ZMVRpm157YcMPnj/KJvA2dcz57O
aWFEx7FasbGx+tehShfgFTbB1ZosRqZ169YYVf2cJ8gqYTUGSmfCULpDx4m+
wyJYITwXAomMBSoX5WRnZ0fPO0SpaknyyMnSngdr4EBYV6LLSBJZy9Iq/tTD
jgI61b17d/3UlIAH3IcYdmECyov5JagcMWKE+iZsOXYGUiagAovRv39/lJdy
AC0ocrdu3YAu6r4/+cvDuG+Q2/Llyw8ePIgB5DGaZI8BZYCOHz+2fv0a0FHX
br3GzBzffWa3+ul3PfXh84Wfzf6uHGRVbhrHjQrQnHm8ouLoiZPmxk+OtG8/
+5qr3j7zrEa1al9Y80coV7NmzTqyP65mjTNr1mhYq2abs89adNNvjvboeXLr
l0fLpRTfnBv/ffvdng9Xj7g/+/FbBv+p96xeBQvz582YsWHtun3791fIEoxt
SVTmlECkK1eulGUvmGDHcqYFcUHIIDfJgr5gwQIcK4/BKIy5yg3lViD37t07
ceJEkLM9FgbPUyYs1SlNmCwX36trI/QbwBBPmzYtwh1ucAwAEMn5cSOA1E+E
D8iYPSFwlRD+lKDD7+yA1It5Wbp0qf50KDoCINQHALLj3dU9gDNnziRwcHV0
cefOncRfeXl5+vKA/WnXrh2yFDapIGONfI4aNcrvEhyUmREq+2aXkdHP/N1v
zfq/Nh98qGLMyPJv95yoKC8rrzhhTY4HRezOZFSY5RX8X9nxcuNoRcWJvfsq
xg43H3nQd1yi0W3mgAwqRfl9LfClKykvs6wfUUCXLl2QcLVlImT5hkGsikFz
lbUAxceybdmyRfN56TWm1fmGCz9C7PFNxcXFYS+AU1xdu3YtvdbPKjlgwAC7
DKtycEz4FJk/1CwqSlEKS9V02AEpRSWJXj1czqVINqoRoLlNFW5aVleuk9Z8
Xo5mAD/sq7H0AowBwJBLncJO3dvXUwhagSipqamAMWAbEBFPt2TJkq5du9ov
6BEFJ0KcNGkS8TieBT87evRoPkv+AaPyiGVFpSHFPHbu1GXe/IWrt6zsMqPr
9Wn3Nc9/f8M3JWUVJ609Nb4I+oRZccwo96UONU/6DP7+3WVFhYdbtd7S6NYV
9a6afsmv+p9X9/2zznjrjDrd6/5i0iWXLr/iqs0N7zjctUv5grkVe7/1naQo
O1nmC8apm3i8jDKPnDgy45NpD41+/rrMe3rM6lKyde2G4uJZhQWbNpWKPfQD
sdOnT8fm03FkDGTSp0+fxYsX268SoEd0B56npKSsWbMG4wYTCgsLeQW+Ab3c
rrQS//I6cEKOpipCiqglMEutwzgyRvhft7lHTAvI0fFIgJxRmd9M/x4EV2RP
CFyFsdt26+5Rv82BhpVLH4gFjNdM9oUuIC20UPOWVdlaj1LoT+PwCk0lQtRM
OieESAwfPhwp1azFtK687927t85JTFAugRv2ym/xzrcb9Zs9ZkxX867bzAZX
m506mRtKjaNHT1aYJwxgGEpa5g3uWxvnykGCZrlvBv8kIdvJY2Zpifnee74z
rb+pb6YlHd/79VFwXLk1M2htpUBr6VTnzp2RcyPcKTAsXlJSEqMpOcN1JO3Y
sWOMCzZTH8ab1sZUBMCVuQBlyal5zefl4B490tSXzMzMWbNmBco8JWDZPvvs
s+h5hyhVIVUTkENzMd34ZW/57YUMa9s/dsPVTVhCIISpU6fKqUNNohbCNL88
Y5h6rCvWOGwbjMrlRewJtggLhjnC+Mt1LQLVADOBW4UPHDjA87Gxsbt27dq/
fz9Rec+ePVXoJ6ZJliNLNm4EByYnJ2/fseOfB//ZYkabS9J+235aq+2HrLUe
XxqoE1Z+Aky08UNFxfEKbLQvM8nJ8goMSsXJMvPAfvOzT8yJ482e3YxXXzHf
ambG9zE/+sgsXmMe+Ppo+dEfzIoT5cbJsvKjxokTFUT8smmagiqszXDl63cW
Pz/x3evSf9t3Sb9vfti7e9fuRQsWSAfNf5+XEw/bunVrIlnYCCvoF6OpsJx6
bMGCBfzEX7wYkS9ACHcJ9zIyMsAz+lFwaWkpTJYcFGYl8IYQA4yq/vXrknuE
VzwsO8o5C539XaGIBiNCgN4Ip/VCkbqiS04BV1WxQPH09HR76CSjIHcfIyGa
zGS4eV7/RiRcf15eHkBd/9yibNhwdW3EwYMHCcfy8/Mlv7TOK5JrQqK2sIAZ
kAD3goS93+72gbfbbjZvvqmsT/zJPTuP+WI0SeeLkpafKLOAlnsyKipzCPtm
1FGVE2UV5bC87LtDxuAM855G5g3XmSkpJ7/Z5Wt9uVHmC+gqDOucyIABA5BP
nTCH7vOwHGB3HlDFnxkzZgB1XF1VDKt79eolq6uar9AkdFz/YAVhNWKmH1vR
66B7OST5CTZK3xxFKUphqZruWkWA0XSsZYTphVFnAjq3ONOwsnygdwAk/bdk
JRQb4qdictFYv379lGO1m2W7fQYA0OX+/fvjtmg5IEQsEurft2/ff/zjH8q/
qxJo58iRI7FCmBTM0dChQwF7arv4j/N7ZjnDVDR3fquOnebNnQtLdx786oNp
bS9Ku6dtYeedR77ylVfx4/FVKd73v3LzpJXw3QdnfMsjht9titLu8soPinc+
0FhhlFkwqMJXjCGn134s1TCWb1365zGv/GbwQ8NXDDv0w8HDRw4vW7Zkztyi
r9XE6Y8P+5YwAFHt27cHVOPOYAv4Fvvmx2F6hO9OSUlhrPkJQDtlyhQ+E7fC
z4SEBIbSb7tj4BBgafGzfhMmhrWBKjc319WhFQaFscMHuTW28Ky4uJi6IrmF
hzbLsZEVK1aYVX2W3LSQ0ujRo1u1apWYmAjbI3coMhYbN26kzX43f5mWWjF8
OK+wUxDyPBET+F+ygujUjmow7gUFBZpTHBQrp2sDs0M4EHIF1gIBhn1FPQA3
0HqdHbbYt7i4OBhYViHXNKB01jFVouDEXmajhr4psiEDKw7stybby36swXd4
HXxlerOwNsU35J8Ea+WGCdo+efwHc+wos0lj84b6ZkL8sT1f+yJC3w6LHy0I
cL1jx45hT/QY1i4LYk8GSH/dE0uYmZkJKtOXTGSAV/SX400L+xER66et27Nn
j1z7qClm2dnZYLlAoMjrSAVBayRTHFGKkh8h+SUlJZhflaSrqorFnaG/EU4g
g4JAAh4mDCW9QM+ePfVfMazUUsTFgdaAb2bNmkVpQeflYB1ImICdAPyjjz4C
h9BsVBUc8t133+E3Bw0aBIoLDLeBiJhEsA0/YehwRqA4tS9L0bFjvqXJNu3a
L1ntS8hw+Njh3NWjGvVt9Ob41z755lPr4TBBucwWAmmwXfQCLynfK5hNg8GQ
AwcOtO0aCikJx8uPzv684A+jnv7j8GcWfDrzRPmxY0ePLl6yOH/qtJ07d5n/
H/X5CAGgj8BgvCfV8VcugPBrHj/RRwCt3JNOM/D+QD5JFAzG69Gjhyy4BMb1
vCv5BgOzexnWTZHw39UGdbghV6K7lV5pycqVKz1badFBIgLgPWjWWyHOhIAR
sMipOoQz8ptcRLpA6RMnTgw8CYgrHzx4MCGVpnlBOClHhlKndpCS9EWzqceP
HwfFjRo1Sv86AIwJqCwjI0Odv3YoX/4iOZ06dZoxY4bztJUIM04fBcGG/Lgj
zqw4wYcTJ8onTDZ/f59Z/xqzb5+KPbus7QjloW63j5ys2stNmYTf/83Jdq2N
W28yG91lFkwDUpb7Mpr8uI8aNSRcxTI7AyfhBgERtkV/3ZPHsrKyUGf9w3dU
NG7cOAZIZ0ZCxJUxxSwgbJpiiRhjHvEpmhPLGIFQhxrQhTVr1lTVIaMoRcm0
IAqKNmbMGNmXXlXFytkBzdzsDuQZyMkUAd7f1VuygQGGBP6Ea6Y7H3zwASYd
L0OAhokGs+HuUfDmzZuDT2QHBagYKydTQLC0sLAQ7BTYBSwJvq99+/alpb49
ZmvXrgXGCFC0ozhQ4rKly9q372jd/eo7Q7pk28InRz7x5PCnVn4x37DC8xPg
ICOMO8bEtWnT5uyzz37hhRdozKFDh4DZsbGxcjxQEmRdccUV77//frhlQd80
38EfDmQvHdpg0B8eHfvqqi+X084jh4+M/2hC2oD0z76wjreoaN9yatSSmJiI
twU2wN7Ro0fbp86kp7LGCtSUaxFkcZwoGJ5QwubNm8ED8fHxDBCswMgzIowC
kTvfDB8+XM5H+AE5uomXX7hwoZjNsCtcQtQFczyc0xEgR/s9bK5TZFh7JmFR
NQE5ySNXhXvkDGsjHHqKM929e7dfmXhA+gKcNjVmF/GqGzZsAEXrp4ZAAAiy
dLbRSoFgVzxsbm4uMq9ZxeHDh1NTU8EJ8ooOlpszZw5YUWfljrHGXBBNl/94
3qxC7kI1Fi0yH37IvP5Ks1P78n/9y/dNeVm5b7dqtW2S96UY8UFIa0OFYXy1
zWzZ3LzlBvOpJyvWra4oO+kDcuaP3QeKZGZm6mx6QZGxM0uWLNFf+8YkYgxd
rX1jhxEz/dRwci0saq4JF+n1kCFDEGPNyXZiVeBrUP5g1iSVnE45UYqSDsmp
1UiOJAQlpBSUgrJHUohh7ZHzBuQwigA5/H7YSznthLun2WlpaUG1DDiBYqKG
wAbJHzJixAhJGyvTaJIvjm9EfzH7uCQC86A7K/iScoAZtO2f//wnbiLwPnd6
8dnmzZkZaR+vB8X5dsVs3vf5q+Ob3Tb0z1M/zTd8iyFGueyKM5zMO5gnLy/v
wgsvbNSoEY4S34Eje/XVV/Fo/AXu0nEM2muvvVavXj1a4ohDLFtuGt9+/03c
gqTrMu/rVBS3+5BPfg4cOjhk+OAevbpv/vRT07ZFzbQWnXNycrBsuDZBKTRA
7TRW8xj0Vy5UFZgnbr2goEDm0/gVSZBb24TwlfQL/oeaXQGUzpgxQ/8ybiEZ
RFfb2oXUjFwkQM60JAcUR8erI2yXmx1kUalKUJxpRSV0HOcV2GBGGaStCeQQ
VPSdIeMtzbbBKMRAP0s/CBYRcpXoD3lAeq1ISosIYxMSEnDWOhOzBC+0XxBI
xY95fLAOO82/v2DeeLX5+isVJR+fKC/zHUMvrzhm5enVb7k7qrDm3KxpNzk3
ZXzxqfnys76bI1o0N7d/KVNXRuWeELmPRqePM2fORN81z6xZaxDHMLDEwvo7
ErHYI0eOxObrLMiK5GNqkpKS9E8uY5cw/ppADpfasWNHuY3L7yecAr2r8u1M
Ufpfpmo67ICaYy31U4CGIkmRvXbtWrcvoj6gqY8++kh/q7wQFpW3xPWHsiHY
CowST9qjOVwYjgx7JbAN1Ldq1aoPPvgg6MlZOeDQr18/TBY+q7CwEE/hd/aT
Dyh7amrqhAnjLPhkHjp+OHvdqFvT7ukyo93eH/ZaIXSZbzXEsDbMhCZwZlxc
3MUXX8xfGoYXe+ONN0C5DBNh9csvvwyX+H7gwIFXXnnliy++6OzmfJMGlrUv
3VX6zISW9w57svCTaSfKj9GMf+3+V0LfhP79M8Wx/j/2zgMwqir7/4Cr+1NX
1y0/V38K9ooVUReXxV7WirqubVUsgAjSm3QIHQKEUEISCKGkQYDQEyAhEHoo
oST0Ir2HmjIz7/0/753k7TgzeXNnkqz+d3MW2TB5c9+9557yPbec485AxiL1
2RkyIse4GLX3vh4GGYQ8cuRIAcNyfI5vAcmsrRlYzYgwladPn7bZ/eRXy5Yt
Aw4FKgM/O5BDEvBi8CegauCKBOsyMjLQKdii7ijLImuvDUSdlJTE1LgLsG6e
LouIiADVqLRGO+g7061Y+xUx80j+bE+yBcwr1ENXpIiJwCaonPISbuTl5Um5
Fr/Po/sYAbCrkYzISLoLYtMv607XhEj9mbpGGpB584oKCp0up+5CwfRilyT7
qRzS5PqDFHOQvCNObW6y/vwz+gP36JOjnefz3d9Nt8FOKotgco8MrVfZx5d5
HzVqVL9+/XBM6vdxiBdUtiyt+AUjL3eKFdsn7CV4VDEm0n63bt18Hqqkkxj/
gFIlV1EV2VNlADlEd+/evYSZKgd97QmtwaoT9wXRBwAVob1VrEHxW3gQXifJ
28v6lrttkRMXkg119OjR1mYKtmv48OF86N2OYLx27doBTnBA/Ay+kilwbxkn
hXMktDedlGF8th/d9u7kD++L+NuCbSmaeabFKXWyNDvrrpl1Dd58882HH35Y
yh7haD7++OPvvvsuKiqKH0pfYVjm+vXr16lTB/BjyyZdrs1dKro8dW1svTEv
t5zf+cC5fUYnND1ny+YhQwBpcz18K93IysrCgu3atQsOzJo1CwzpcTFTbCzw
DCzH2GXJDp5g+qKjo6VCma48m8wFjsYnXLQbnKYxI3FxcSqliDzIAnLqh659
EsPMzMxkFioDyNEmXhW43rJlS2a8Qm7PAQhBR7K87PGrDRs2gIIU3SUgE7sh
BRdUZpkpBnLDK8UpxsvzPIBTvaAnPe/du/fUqVMVn5dDoXKe0+8QcPTdu3fH
AhtWwtzQZDJcu3boH7yt33u73r6j89Bh8zqD02FUWHAZOXor84ycnMBzlmT5
Ng7kOS/ka126GddmG/5N37DWvBpfQju2bwcI5eXmqcwUig8P1VEQPCEKzs7O
VgdyaWlpvELluqtWmt4QuKiepxqzgISrn9zr0qULob13/2VXOqBTu1VURfaE
tUFlKnZrVYBcbGxsQPk2fZIAuSDqZGlmuUw8QqBATsp7DR482N+qlKaVplEC
eHjktJf8FaAIn/5FipeJ10Odedf8+fM9Wsbj4J4wBcbUGEtgjvyC/Kh1MY+F
1+81r1t+oXGFsyQ4N0dmMzw6iVv505/+9Oijj0rSVAFyX3311ZgxY5o0aYLB
FC5t2bLl73//+yOPPJKcnGzLJ+MGrADU3cdy/5nc+snI12ZuTSpyFRrGX3Nm
LlsWOmzYmtWrPb4mSaKIas+fP3/hwgVcKnzziKBlpiQNoHv6GtnUBiNZp93c
n/cmPgeNR0ZGBrqFQftMJRwIdB1PNwEY37VSrARN1lpiQCnuFQlPh0sqf5Al
JPyHyQg8s+M+HfLzpk2b+JXi8ibjRTWYOMW3o6oAP/XKtgge4gewVAR+NLti
xQqCCO97NGURgkp8pFJZFQ3CoWMlJO2hLiDq8iV9VLj+5yf0198qXrnaWeww
iyqbMZLLWJirtPU4E7yZZF2ocGiuS/y8LU9v+I5+7x161Fg9P7/IpRcbFx+M
i+1DRgxLnJZ0ViEbG5anTZs26tVXi4qKmCkgscritlZ63xnOq+eqIlLGpDBT
il1CkumSSrUXeYBoFMzmHTKgLI0bNybiU+xnFVWRXwLIIWzp6emALvUo1Z4Q
Y8IcgFz58SEmDncfHJAT5xLEugreBB2cMWOG31PN1lrcuHHjLEDCh6g8gba3
SdHMY+FYswEDBgD/+ApDI973LiV26tQpOl8CqDTj9Ere8dwvEpo+NfbNpblp
AQ1HDp5df/31ADmpQZabm/vPf/6TPtCZWbNm1alTR1bqtm7dCpDjMdtj9rLr
Yq4FavqFovPjs8c/G/VSz/SQoxePmR7AdfHSxUmxsbhLy0JqpcSLwsLC5PBk
VlYWSNLn/jtPzps3LzQ01P3GAd2WSpcq610wcNKkSWChQG9logWLFy8GWqsn
C7UIfsJq2UYsz5Yl32WwTE15araWRe5n5MrfmjSCXI0aNcpnmXvmMSIiQhFO
E3zhi/mK35fKe4EH6IgsqqgMB64SSnhcmi7rFXppbhM0UfFoumbmNoEVKggc
2cZKSGbdf326d4f+/rv6Pbfr4SOcZ07/vNn/nS6zPldRkatLV/2R2nqzptqe
XQ4je7BLjuotSFvQun1bqw5LWSSR6cCBAzGVYGmVmeIZ4rj4+HjFeEoEoGfP
njk5OZgdlVeIYcQaKx6EIDzHXqlnOMS2g9a8zxDSN8n3rtJIFVWRCklNT8L/
H3/8saJOVqNHtDl48ODyewrsYXBATjcdFmDSzy6hL9LMPCSjR4+2ceWC4ojp
cDr00P1JOCmZbH1+UXLNgTF0MzdRXFyc991eGLh58+aRI0cKEuZVBUWXZuWm
/Hns851mdsgvynfZXm3w7irO4m9/+5u1Ioc7++yzzwBymDLe/tBDD+GtNLOg
wFtvvfXwww/brMhpJRmozHPZxgRr2T+ufSvx65em/HP5XvOyhmlTM9IzwsPD
3Y2VWFocYpxJCN7Ro0dxedhqn9fZYBSMdU86J+VCCIozMzP9bgiCEqdOnbp/
/35FF28RQC4tLY3pUzw/7070ChTn89ZzoCR1LhCD8jflQegFzqs8KYu9Cbli
Hj1gp7A9ISGBXyn6vl27djFqxWJbtIkkA0qJgxSnGMdNzKW+UyD2Z9GiRYq2
kfCBWCMmJkZlw5qQZPz48T+52YpeT0vSG9TT69R1Ll/uMjMJK3a1UshlJCQx
FgGzlhrVux68W581Tb98yaEZ27yAOVBZ9x7d09OX2C8CyCgkx6Z6dI/1wD4o
VrOSV4DSmWJFrKibu5zqNUcgZlYK7qg8jNsC1fu8HEHwXgXkqqgCSc7IVezW
KjgE7ejTp0/5m8KZzjcpiBT0Ul1C8bqcB6F9WO+ZM2d6fG6tLOmm0Y43yX1l
XhbZ+vXr573IJoTr+eGHH/bu3StLc0Sp3k/iarHwgD2tZO9UO55/rNuikIei
3l65L9M8ohYAaea9j+bNm99xxx1TpkzRzaWA999/v1GjRnheTNOrr76KA4XD
mMH777+ff65atarM1v6186LJhs+ZS6d7pg98atyL49dOKCi8JHvOxNG0BvPF
wrvvhAIXcXaYUOwhsEcSjPjsNg4dKC5gxmI7jg+e26/LMTUA7OXLlwdxAIyp
R97oWBDfrVggB4SoDGvP1MDAkJCQ6OhoxVt+fknK2/lcP+RzsJyiAiKHRBZ+
V9GlNZkpULfilQ10MyUlBcFQPHKvmSmMCDq2mbewVbq0cuXKMWPGqABRQr+v
vvpKqof8q/MXz+lfNTYq1w8IcR4/LofU/DZVeWSkI3G5ily642K+1qebkZq4
dWvnj3vNKq1GZQjwXOK0aSF9+6pgYwwdTgEWKYocnOnVqxfzpbICb+2uEuip
n6bACgEv1UtAEgUsWbJEcQXvyJEjmHGfxq179+4qyaWrqIoUqTIuOwiQw1OU
vylMNKACXx9EhlW+QrSOHQ5CX+RqZ2RkpFxB9Tj5I0VCJUGEx102bEhERATO
xedLCf0WLFgwYsQIzUz6Cs5JSkrSf3rHAS8jBV4tgOfUtJzjWxrG/qPBpI/3
nd5lHpYJYCy8i07iX6666qo33ngDlMjQAHIvvfRS//79iQ2BrIyXvjVr1uya
a65p3769/Rn70qsVmgnoDH83Y+uM58e/2SN94MmLJzW9pIYEFhss552vDLOJ
PQRLgPEk8a/H2SqLEE5Zz/Gw5Hv27KEFnKAs5Xl8V/zvnDlzgpNqYgeC+uAy
5wiQU6/wa0PMEUCuMlbkJCEwtHPnTmSs/FW6YHiFADnNrGeKgihWAaDzyAbY
TDFBGTPL7Kxdu1ZxRYVmiRe8q4p4kxXfgUL9Pi+sgFfDhg2T5aZ/MWfjBv2N
V/VHaxctTHEWFug/N5ADwhU5daPoMkIyf67+wl/1F192rV+tORzmzQvDBORt
396hg5HlUoWrCAP8UbnCIzwhzAQLqZ8U5UmMtqzDqzzPLHTq1InQ0q8WWP3B
Wiqu4BFo4Lk8UKW006pVK5oK4vBGFVWRT/qFAzl8PS4VdQjiGqDUTRg7duxP
Yl410szrqzg7LLm7gbJ2VEERHhsumpm8F+g4dOjQsnqLhRkyZAjN6uZxIMZl
nRCzekjjOL7w8PB/DcRZOGPn/LphxjWHc5fzdT2wVFKamZ9t3bp1L7zwwi23
3DJ8+HAM1yeffEJ0zEyBPYxNEvOBRx55pEGDBosXL7bdjnSZxVcFzTnMdFOu
zUc2vRff5KOkVtuP7XAa+a4cLvOMImiKZj0sPFyCewBsyZ8MN2bOnCm20ful
IASetBamLI9J43L3wTu6R5j5StDLYgBssMRqr5saKlSBQG7v3r1AFIBchYft
khBY7gsHuu9cFuHH4blPIIfjVgym5ICZ+jkKOQSLxqkv9xE6+Uzt5ZPQRLSV
sEvR+BChTJgwQarR2T+J3hEGLlmyxBOyxiUWPvNnV8O3tC0bzYJZlVjHQYWc
ZszoMm9BOHdvd7z37uXa97smjneeO2fWXuYR49AvWAvGqsASJAR+Al8Vp4DJ
io6OVl9hA8gRnG7cuFERqx84cKBr167YQ8Xnidwx2op1YGEIkaxPIAf0JRSt
jDvpVfSfSva2GhvlnhC4Qqx6ZazIBZqYSzOzSmZlZUVFRalnFHf/umbevQX2
eHgWKVrhnrfBQheSPCE2NtZnm3IfdtSoURKwY9MGDhzocZmdZwB42C4rOTCA
6fTlUwNXjrhj1EuTl8cKLgsilxSczMzMxIBg6MBO/CDn9KxdKkxxr169GKzC
nZeSTdXSXAXaiQvH+qX2eT3yjYScpAKHkfbKpblkJ8vnvdQNGzZMmzZNFuuY
X4BrWVsz8ArjCTpyn0Tp85EjR/gVjLLaFywNemQsRmKuoISZGVm4cOHPviLH
wBma+oEcIWvIiOJak0AXHi14ALnyd1U3V1oQHu/Ey5KEbd68eX5fJBqE+Kkg
cGkN5kRERIim+H1YN5eIVVLzWeqMTCKlKjcj9NJ1YCyVCvZmdgj31qxeVWSI
tZmWkRYcBcd79Ui6s9bhlm1cP/7oMoBcJd5RVSEjIwpRnstILld8+fzZtq0m
/t9NB9p2Kj50BKEqLoF4Rk5jK5+G/dixLYSoUtvL/kkJmXm+b9++Eq8p7p6D
neiPIvYmfrTKatg/KW+n5UGDBu1TKztCICBAzvvhaSb5XemtoipyJzk83717
d0kd5n68FknGvwM/sIcVJVcVC+TQYiBHoCty6A6uHMQiSXeDeztWlrf37t3b
yvlz8uRJdHnr1q0WrnDHyXv27Bk2bJi4SO/0cQwBBIjL47vYJdw9waBHSjrd
XDegz+5ZU348s7/ZzBa1o99ZmmdehzT2M4PZcNHMu2OwlJ4w1+4sxY7BLrGW
Fqm3fLn4QtL6yS9EvhaSOfRcwTmse0FhAWjt+++//+ijj/BZmG4LsmrmpWap
jylra/Hx8WWBH/gjGdV8CicBNfaQB2TnndZwu7TmkZ4uIKKfc+fO9XkB0y/B
QMSjQoAc3VixYgWSFkQt1I0bN37xxRe/Mwn+e4BS94TATHr5t1Z1MxcrUYl3
jlN8GdhM7kr7JfQCyCfr1fYkwrl+/XoMl9+s4/IwRik1NRXtA8ipQAimks5Y
NRf8kmTSS0pKUsn8D/N79uy5fXuebtZQAClhTbRTJxY3+jzi/245PHS4Zlzf
KDbXvH5OKKeZBcPMa+quYs1VFB7e8/bbVn70ScGePQ4dIOcUIEewgN0DxiOr
fsUJ5UpOTmYW/BY5laaYMuvalwoRORLHKfoyOkwsgGAo+hc0CyBqFVK0eZLf
SnE6SVfi8TDWj35WAbkqUifMIyr297///corr7zhhhtuvPFGYmdrNQlLjrNA
2JzOklp/5X9jBQK5/Pz86OjoL7/8UrEwijuhJqGhoS+88EJ5rnLAvVWrVhEV
Llu2bPHixWgxhsgbGcJGhgxUrl+/PsrrM+pnLDg18ao8IJX+rN/CeTl316VL
l7fffhu8vWXLFjEAe07saDT1k7cSP91+Is98Mkjr7j25Hp/IP4OQAZfmWL4v
463Jnzad0W7fCWOdjcHCjd/85jfVTPr888/dr0kym3g9ScjPqOGYZE72aBbr
CqBq167dp59+iqeAdd5HJX/88cdx48YxL/CWRiIjIyWJaNCbhoDAqVOnBrci
BzRiBgGWQXzXg4IGckeOHGnZsuX1119fx6Rbb721X79+7ttedJIBImZhYWHg
3nJedhAmA2Di4uK8u4ovQ3EUN4hRWBrBq6q8F8UEwyM5iglaeSzSJPsdQK00
OSTgkwgOSKC+D8vDigmW4T/QF0Tt1EsOKWBQXNt3jnrx1UX3P3xp+nTCKvN4
mivAi00VTuC4Yt3YAzDLv86bO/7Rh6Jfe/W4aZpcxundknteYC3AiQoc2rdv
H2ZZBFsliEhPT3///ffVLx9lZWWBzdSzyU2ePFnmQuVh2RpWXJFD0mALI/Ue
5vz589XRZhVVkW7KHoJKbN60aVO8zLPPPvvwww9bfuoXfkZOaks9/fTTKuWn
3UkzEwK3bdvWyrkRNGGdcEaoJOG5T8cnpQeefPJJAS0PPfSQrMl4KDtxK8gt
JydHN9fuBg0aJD9bBGKsWbOmNHLzzTcPGTJEN6J1x7q9q96Lev3b2S1OF53S
ywHkLLIHOUHhH9fGQxs/TGj6VfL3u44bV/zwsyBVmM9Yrr322k6dOnmYStCO
HDLkyenTp+PavI+4g8AbN24sDCEM+f77733eL8Ng4v2ZINw6mCGInXSLNDON
8ODBgzG/QXx39uzZUi4h6A5YFDSQy8jIeO655+rWrTtnzhz688QTT+AH3S9N
SELgiko/Yg/k8Kega0UFRELi4+MJl1Qe3rt3L1gUeO/3ZoRWetk5MTGRxlWy
v6LjCCTypn7SEpbSvn26fukJ9oTQIy8vz+U0QFKR4CSCu/Xrutd9Iueh2trc
ma6CS5pe7AzqEEUFksvIMmRk/3VpTgPIrV+3+K/1hrzy8v4NOU6jyITxlxgj
prhFixZyFd2+TbmLKlXYVPqA6D711FMYQ0XEjjXAnuzevVtRcTAa7733Hrpm
v44hv2J+kTq5HOEXhTLAUaNG+dy3rQJyVRQoEXdjkQjMx4wZA2BD3e6++25E
XTcRyC8cyKGPX3zxxWOPPRbo9T3NrHj42muv3Xvvvbjm8q800oJPFyAhvNTA
Am9Ur179z3/+s898BQcPHiT6E4QAuu7Tp49cibUI3/rJJ58IbqHbkomu0FG4
eHvqq2Nfaju73ZlCs2SV/vPut/giTdt7ek+LOR2bzvx+pwnkYAtQ7aWXXmIs
tWrVCg8P9zjliIsEfV2+fBmnSSxPiOFt2IFkQ4cO/cMf/kAjt9xyC43YXF52
N61BTzcmFzUB+SiuC7kTLwXqI3KgkfLLW3BADhEFgdx///316tVjCAQUL774
4uuvv+5+d6NiEwILAeQYtXdX8eyIseJyR3Z29vDhwxXPyCEzDRo0aNKkiWJS
OAxIZGSkTV4ddyIGJOx9+eWXFXfJpUwJsNk+iJCFYpBD9+7dAaJosUPXCs1a
9UYP160c9lSdfQ0aaNlrNFexeW7u57yyqsutKg18Y1684OeN2Qdeeb7/gw9u
nL/AUVhkLKi5SnrIcJC0fv362efvFQ1ligG9ilcGmDjsf/369VVQom7ucSOK
GH/Feg2TJk3CIQ4YMMB+z13sPCB8xIgRoFaVnMMYNEwW/a8CclVUfurdu/eX
X3750EMPZWVlHTp0CCB35513JiQkyG8rD8j17du3nO0g/xjS2rVr33fffepV
e4Q0s7InGAAUQfwbxEEjj9bsHyDe79y5M3jjmmuu+fjjj2XhyONbMH/KlCly
AVOAnMfxGxrp0KGDrD4999xzcvin0Fm4aOfCt2LeGrZ8eLFZUsHI3/RLS0Ck
6T+e2dN6bsdvZ7XacbzkxDtQQXDpk08+6T19ixcvxvcBV5AWzBoC6W3WsJzY
ZASARh5++GGe9zkR7guMQe+oynfpQ6tWrR599FGQSaAyk5+f36tXL0AUpr78
ubVpDSUKFMjJFUIUnGhi4cKFqA9YGvWJjY21/JqsyAVR8cSGkkzy/pwhgCcV
0ywAL0GhKsDs7NmzmLXf//73DRs2VDkjhyCtX78eSIkO+pUQHk5JSalTpw5A
ji6p9FxUOyMjQ8VQvPfeewA5gjiz6hazWyyJPBYtSl3wzFNn333PuWMHKMFp
rHcV/bxbq2bqb61Y10zApunZa5yvvRhf685lCVMvXrpoGqOS0AkgV7du3b/8
5S8+q4t6EA+jKSrZ+fRSIIcFGDx4sOKiHNiMiVM8Gk1wfccdd7z66qtYZr89
ByUSDiBLRQq5mgFyQ4YMITzxRn3oZlnnfquoinxSSEjI119/jTHHXR48eFCA
XFxcnG6aLEIMBFj9RIFf0sybg0uXLm3dujX2Leh9Ltqhb9HR0VdcccVNN900
cOBA3dcNgrLo/PnzUVFRV199Nda+Xbt25a8+Zv9eXBXBF9bmhhtu+P77730m
0/AGcu77xTyMlcAEyV7kp59+KpUFCh2FqTvS3optGLlyjHnJwbgQ+nOfnPEk
enPgzL7v5nT+albrHce3m+bfOIvVqVOn6667zmeG4czMTEAaUFYzC0+A9Hxu
9hGGv/766/Dk+eefD67ARwCjMFdxP/zwQ+QNrxHosUyioW+++ebXv/41AuCx
1hpoN9AaeJKcnLxhw4aALiNYQK5evXo4C2IZgNxf//rXRYsWWe2cOHECJ4Kk
8QAoi7+ZHSn3GTQGxp6ArBYsWJCbm+uu8gA52lcEcitXrqQdFSBnxQjvvPOO
331bWUvH+dIZ+9TBwgHk8LPPPqNxdSC3du1aeq6CjYHWxNQdO3ZE950C5Iz1
OO3i5cJJocPWPf5w4d/f04zsHAA8l1EL62cN2Ry6y0Hc6DIToRi7v8f0zz6e
9qcbE0JDT545Y5yRK71WCzZD5LDVERERUljBpudICMYZVthnB5UWLCAHUITP
KupAVIjjUEzzi00GyP3v//4v6ua3PgVvxwohqCqnAVFGGkcpxJLI15Gu9PR0
nDIcqIxKylX0n0oxMTGdO3eWnSl8DV7mnnvusYppAjnQjmXLlu3atQt0wQPl
X7xCHQh+33//faBjEJcUrHaOHz/erVs3ATZffPGF3xvr7gRqatWqlWxT1q9f
XzGUC5okNxoG4Q9/+APoxaOwu9UlDyDn4e5xN1gJrBZokM7LhwC5tJ1pb058
Z7wB5Mxk6pr2ywNy2v4zB5rO/aHRrLY7ju8QjwgTxowZc/vtt3/11Vd7vUq0
Z2RkWHfz8cVwz+edlB07dnz88cc4CASgYjNm+BiFmcfs2WefrV69euPGjdWz
VwlZ6OKDDz5QXG0oi7DwSUlJw4cPJ5wPaLyamZO2nklS9ZXheKAdGgc24+wQ
NuA0QwbkqFe58klg8n79+vE65sj9ECkub968eSrFzvjW9OnTERi/t0SRK1DT
I488AqvfffddlRU5Ggesgsps4krxsxDdkLOdfoGccAyDKXmM/eaJBeEA4cRE
mECOFsBIRiMHjh0d8cU/d95zh/ZBQ33Hds24EFqS28e+zUollzE4I5ecU66A
aMV6k0Ybat0c2aTZnj17zawkJU+i4MQLNWrUIA5SuTOOqBBKqMQ7RDR16tRh
Omi8R48e9uBHZoSwhXBGpXFGhVu89dZbaR9fY7PbK9AUduAu0RfFdFgoI5bN
kn++fuDAASnoA9SsAnJVpE74x2nTpv3+979v0aIFBvzVV1+tXbu2dbEOdCS3
VrVSKv8bASRy07OcDeLE5eDZVVdd9corrwgYUGwwNzcXOyxAjvFW9mIOBgGf
26BBg9tuuw0b4rOffoEcX+FzcAuAUJK8QUWOwkU70t6e+FZkCZAzzIn2cx+e
8SATyO03gNxMgNxO8T5YralTpz799NNYSO9NBERx4sSJJ0+eRFr4Ge/pE/OD
wAlDrr/+enyfeknEYIZgEgGOOPGPPvooLy8voBYALUgp3wU7LVmyJGjJl2Xn
U6dOgSICzSMHAWwaNmwIfsbr9ezZkx8+/fRTQKb1gOSRc/+k/LqfmJgolx3c
G2Egs2fPjo2NVUl8CjxDDCQBYFnPSOO01rVrV0QCVr/xxhs4VvuW+RaKRss2
SZ610suqu3fvBsNfffXV6ityuGMMbFpamt/tNqTiwQcfpGULyBnHz8xvrNq2
edAzT++teZP+4TvajjxDwbWfH8gZOUZM/GKiSt158ID24XsFd9Wc8vrruZs2
OZ3/Wh3DOGP9CLiuueYauOH3aAGRDmYBWbVZYRNmgoIaNWok99+ffPJJZsTm
8JtWWjVj6NCh3sGjNyFsuMXf/va3NP74449nZWXZqxvtozvEPiqLzDwMigPh
C5CzZEyvSj9SRYFTQUEBqOYf//jHr3/96xtvvPGmm24idrYU7Rd7Rg6FAm3e
f//9Asbuu+8+QnvF76IvmPennnpKvgu4iomJKU9nVAgw/PXXXz/wwAOYa58P
HDx40Ep7hanp3bu391VcOcT40EMPWR4EIJe+Pa1h7JujV4a75MaqYVcroD5m
BZIB5M7ubTq305ez2u84vqvkI01bvnz5l19+Seyp/xTZWvYQOURaMGvJyck+
gVxxcTFMe/jhhxHaCsl4ZkPoQlhYmFwcRng8inrYE1o2efJkJk4CB9BLEEXl
3CnoW6v0hLcjh9atGRjo7ljlskN5Uu15U1JSUkJCgkdX5RpLWTPrQVIPa+bM
mX43rVJTU+vVqyej+8tf/qJyR3jz5s10zztfsXcfYJ1lcxSBHJA4KioqPT3d
58EP6xO48c033wggsYCcw9yy5IvpG9ektWpx9rGH9A/ecu3IM26Dai6zgMrP
SQC5IvM4hy4p7davNyqIPXhv+J+fXL40vaCo2Dqta63IMTqib7+1GxDCkJAQ
92zeZRF61Lx5c8Fa1atX93tSTkISoL6kb7JvHJW3GofCw8NBaPZBDc0iqPZ3
OoSYVuTfOlrg3iYAD1GvAnJVFBDJ1jzIAUtC4Ox+Yf8Xe2sVp4AVxVDjWMGf
r7/+unoqAM1MMxsZGcl4scaop9+wvfyEeRk9evS7775b1iEfbFdiYqIsC2DG
J02a5J11ltht5MiRL7zwgrWIUewoyshb9Mq4lzrMaZ9fIAbBTLX+yyJt58m8
L2a1/Cy5bd7RnXqpJcR1SiJ3j6clzW9aWlqBSbBl6tSpPj24rJJ99dVXs2fP
rqgV47II4/zDDz+IVQf8W8XdVF6KTea74qavvPLK1q1bq5h6GwoOyElv4eTi
xYvbt2/ftm1bYI9Hgo4TJ06AOlatWoVABnRcwYYEyHkg7YCAHONFHtAI+1O1
2KsBAwbccMMN1qkJlXQlUgrW7xLrsWPHmjVrBlpQB3KMEfHGqMppT5/MlA8Z
nSzHuQM5l7kiV1RYGJUYlx0+oui5Z/QX/uJcnuUqLjSjtp8ZyJmlG4yLq/TD
SFm8IVt/4xX92WcWtGubkJR44vQpSzQBcsyFALnrr78e3bGfdESFZ7CBfldr
mXEmxcJafq+vysLX+PHj58yZ41fwPIAcL/JZiMGddu/ejfqonNWhnZSUFHri
HbBX3VqtokDJPuMNkox9K8/ZbG+qECAn2oSXB4NZJboCcjp8FzsMnCv/FUIV
khNujRs39nnWSyst3op5wQrhWwnrAH4ej9FVPG+rVq2sbUSX5tp4cN27k95q
ktz0xPmj5rEal+uXtbVqbL6s37vq7clffjqr066T+0o/NI6cwX/Cc48v4DHh
A0LCUKRCJZatrNZhyKBBgzZs2FDZQI5g54svvgCGXXHFFcQOoaGhVsEIv9/F
Vg8dOvSll1564IEHHn300bCwsHJa6fIAOe2niZ09+g/CjImJ+fbbb3v27JmV
lVXOhMBCoDicsoeiBQTk6BUoTop92Dy2a9cu5kgAgzqQIwoAa9lvzSOKhIrW
eQxFIJefnx8fHz9t2rSydoRlOLwahst2sDuQM87IofWXLg0NH527YL727hv6
E4+75qY6CwocJpDzO7RKJTO9iMtBVO0yKlBoS5boLz2nv//OxpjYmPHRhw4f
subKHcjJMVFvrfcgBAYD6Nf1eAA5aNy4cTZTKeuiS5YsIQD0W8XDA8jdfffd
iJP9FjkSCJBT1O5NmzYB5LzvElYBuSoKjspygmjE8uXLsXLr1q0LojC9T6rA
PHKAMZoKokSXfJehASTKkyFWnWQZECOTnZ3t87d0IycnJykpScayefPmzp07
e1skyRXsnjdv94ldn0/58rWJH2TvX1PSVoB4xqMQmP3X1a8GW1RYXDBzfeIb
497olz7oTMFZ2XDBj2NLJ0+e7B29MrrExES5EZCbm4uvL2vbi0aAxwsXLgz6
1ow6ITCE27iAwYMHR0RE7N+/PyCQw/ximRnLvHnzVLIT2BNMA9gEUWvV73tP
nDiRmZmJi0EOFXNt2b9RN51y7969Pe4dwz0mzmeGQG+SM4EElfb9T0lJefzx
xy2fDniQ9V6bb8FJMDmKaT+b/Ja5q1u3rvuKnN9Crrj1kSNH2pz6kI7Rjmy7
uwM541fmrzdv2xrSd8DO7M36d830hx/Uw0YXnz5d7HI5NNfPm2fITHPndJhX
aw3YOS5Cr/eE/lmjIytX9uvVe+f27cYGsNlF961V6De/+c3EiRPtkTPqj6Fz
P6vpk8BaTZo0ue666+S+A2+JjY21vz4jh9Pk4oy9OKECoEQLYEMtWrSwrwQk
QA6hsj/pYZ3WmzJliveGFwFOFZCrogokJBmTTuBPaKmS5FCFKhbIrVq1CjCg
eEvInS5fvkyIjUf+9wA53UwcROwfHR1dlj/F3FlBKKgP9+dtNPBogBwclvXJ
sQtHey4JeWb82wu3GctWWkmpalXC4BQWFq5du7ZPnz4+SxRhb1NTU3HEsFpg
Q6BicL7gfHjWyNciXopZHXnZccllLCQapQanTZuGj/NwoDRuZQzjZ16dkJBQ
1g7L8ePHca8ZGRkVsnCkQufPnwfLKZZK9yA52OnX+6sQnoLpwNmV8xa5N8ll
h4rNI4e44pQ90DhDQJLt7y9YdPLkSaSCFuxlD9eMNWjcuPFjjz32xz/+sUGD
BsiYvWwgZoAK5tTvOXbUhG5Mnz69V69eHTt2RF/8FvjAeEZFRdlLiyQn/N3v
fucB5IxzpObeacqC+VOmTj1++Jjeo5f+WG29QzvXwYNgpwKzMNbPSGYHDcBi
LA9iN9q01B++X+/ctfDwkQkR49IXLzl/8aLMFuIEBpbRXXnllQDsuXPn2s87
1hIOY6Ltox4mBQ4PGzYMhyKlS3EKfg0UMQUP+90nBZV98MEHt9566y233PLp
p58CugjD7RcNsOHEJkYaQH95bHTzcm5YWBghocfDMTEx8fHxVUCuiiqK0DWM
pwUnfoFAjqYIwYJYkQPILV26FCMQxBJTEKSZ6arASyCismI6fCgARqoGHDt2
DJfkfZ0Ws4Zx69u3rxXxnbl8OnTVyDtHPjdu6RinZqC4gJAc/isnJ+eNN964
+eab+/fv713SCD+IZ3/++edfe+01nGnA7NL0w+cPtUzt/vrUf2TuXWxkKjDX
GohGsXjimt0bpANgM/w7ABJThq+HIWUtDW3ZsgWQUFH1pFQI+LFw4cLgaq3C
SUy3YjkAe8JTwBYmrsKveFRsQmCZWfBMUlISM+7+K7SAuUMjFA8Z0iu/W6tC
YDOCIKQLr8p82SM0XD+Rggi234GgfeBw6bPmds2wrK8AVwjc7FOm7Nix4/PP
P7fO9UEdOnRgfl2lHr/vgAGz58y5gImLjtLr1dXfel3PWe/Uih2a6+c9QuE0
kRy9MIDclo36W6/p992pjxntPHN2UnTUyPDhh48eljHA5C4mdevWDWikktxP
N2vOArcUs3AgY7BasXA21hXLj92wn0H8Cw3S8qhRo+izRAT2y9r0dvz48XzF
PnzwWJHzaLB58+bh4eEqt7mrqIpUCID0y7zsIHT27Fl8AYAn0HUJOfKNTZ45
c6ZemcnHPAg1x2vwUp8GhOgyIyODOBSQSfcWLFgwZMgQ7wVD3NPAgQMtjFfk
LEjdM++ZkX/pOqfz6cunTSAXADckHd/vfve7li1bSgzozQ06Nn/+/Jo1azZt
2jQIYcg+uOqtqZ9/lNwi78RW3axXf+nyJamgKvuq7m+kfT6XqyvAPNyxuG/3
M13yc35+Pv4apFfOG6ABETgTkImDDuKl2Hbm12el3UAJnsDAQCvTqRAiygAn
TJiwePFiEFGFrPiVBeR40bp161RYgc9FccDPKgsdGzZsmDZtml8sqpVmlJ09
ezY6Zd8NrTTZBZJpnxbDIkRltEk29V41M4sdLjsuLq5t27Zt2rT59ttvsQ98
RV5w+syZsWPH5ublGQUetm8zwNID92jJSdrlS3qAa+8VTkXG8r9L04uNXYC5
M/Tnn9FfesG5eiXIbsWyjOHhQw/8uF8vRbyyoYMlad++PYbXftdeuJ2dnT1s
2DD7ArXWwwCtQYMGKQYgmA5kb9euXSrife7cuXHjxhHMSkJgeznBhMbExBBh
qewRSKFzd4sqjcMi9MVvmeAqqiJF+sXeWhU6efIkFrushB72RMwbGxsb3HeD
Jhl7jx49vG8qCRG6At5ATZqZNa5///7eVQ8uXLiA6+nevXsJCnK5dhzf8vnk
L16MfG/bsRwjSg4EyGFzGjRo8OCDD1qsEJSLz8L8Yrvk6iI+/aWXXpK0GwGB
kCJX4ZT1Mc+NeaFHWsjxC0fl4M/WrVsx0ampqR5NSd7XkSNHwgdkDxRnbTG4
Pyk/w0kMrGLJ9Yoi8JvcSVFJY+tBjA4mgwRUzqrZkwA5yTpYsYRO4UQGDBgg
lX/Lf0xON4EceNvjfLusyKkDuUWLFikuvQqQ42EV1Id+Sb1XlYd37twJ2/0m
GRZigFFRUfPmzVMZIECOAaLRaJxgHtlX3Zq7DXXYuWOnw+VyFlzSW7TUH7xX
H9DPeeJ4kWZXxv3fQOa7NSMDydmzjh86a48+qPfp7Tx2jM937czt3bv7tq2e
KT4Y2vDhw+GhSqY1bE7Pnj0RQpVhYjG6du26fv16FWwGk2U/XbEEA9A6MzNT
JVMlgkQQ5HdFTggtRsu8gRwOghZ+3smtov8kkq3VCr+1SnTTu3fv8jclR1aC
SOermVcPwAmKS/EVSIcPHyZIx9H47BUWZvHixb169SIMBDNgPcaMGcMseKxH
YeIw7wK9AHKnL54atCzsnpHPx66LLHIVqcfpvAKvfccdd7z//vuCLekA8XK7
du1atGgxZcqUgQMHhoeHy0XaZs2a3XTTTUOHDg2ootm+U3tap3R8LuK1xA3x
hY7LRv530zASinofAgGZYOdBSowRwRsxYoRVnt5ypvKD4HB+W9np4zyIsdM9
wvkgqoEUFRXJal75d/MrD8hJHjkQi8ruoSLhlRISEjzyewQE5BB4ALBKRAmT
QUS8rqxYyZ3kLiphkd9tLOkknBk/frziDi8PE60Qbtjjds286NSlSxfsmCy/
lzxsArmV2WsTk5KOHj5spt115E+bvuyJx47/+Rlt5bIiZ+HPe23VSHHnLDIy
pGzcsOvll9fVqpWfkuK8TK+cp08fGRc+avWaNYU/3VDQzOyRaK797GilSQli
YmKQEJVjzEAyCYFVsJlmpi3iYcXycPSBeVQBcthJupGenq6yYu8N5IQAcpWh
2lX0X0soBXo3depU4taKqmOF8cRHjxs3TlGJbAggl5ycHNyqGpYEl6pi7SuW
AEWbN2+2Tkp7W3j0mphOLrfu3buXJxcuXKiXXheV52UTFrx39swZzbgWWpi5
O/1v49/4Z/yXxy8cMtMSmEtfRnuaYXHLwHbEjzRy/fXXf/7558AqXrFhw4bP
PvusX79+vPS999678847QZLyxv79+992223EyH5qIJrvdmi6Wb3HNXf7vOcm
vPNJQpPNBzeYo3AuXrIEfOidSJ9mkTTGjmBguuPi4ni1z5KIxAIgIn5bsWvF
KgT/0YX4+HiVzPAeRLcBgQsWLCj/XnBlAznZoir/yqG110k4QICglZJuRjQg
KL9n5OS36kCOqAd4j49W2ZkipkDRGK/Kw2guLRPd2JfptAaIhvIweNUvG2EF
oRPhrceFMtQnLjEhbfFio3sGrtMO7N8X0/CtfXfW1Pr2cR07btZwcejGpVGt
UNccmkuvtGWcIl2qgplJijUj34iReMR4Z5EeOjTnoQemvPbK/pyNTmOz1elw
FM1ITs5cmnnBC1ahOKAXlQjayIScng6+VbnXDN+IjokQFf0Uxt9nDjeftGbN
mjlz5igeWgsNDVVMqmOzIlcF5KqoAgmrCOoAd2FJMHoVEp4jq+gyQRnGuZxN
YVFx/UGcHmcg9AFFlpO0/+ZFbLiKgRoxYoRHiCcLIHh5fgvUgeeyQNe1a1cJ
M91XcsBdCfHxY81bt9jvYxeOdM0IeWjMa3M2JZv3ySzsptmU8oGBNH7ttdcC
3miQ1yUlJdWvXx/3yq+6dev26KOPSr023kKX1ICc4bbMGkLa2YKzA5aPeCbi
+ZErhucXGuf3cnO3hfQNmTJ1ikcjfGXTpk2TJk3KycnRzeQDmOWybgXyOXMn
ax0qDK9YQiMw1H4TYXkTSABIAw4M4pK1OyEG69evx7NUxnqyJAQGNYEukM8K
UXmcGvAVvOQ+X/v372eK7Y+9CfEAPCeysK9vK+0IkJs3b56KJ5U7yAwWabRf
NNPNQAOeK/poIBlAjm74TU+nm7cjIyMj+duD2+gjny9atMhaZcremtvzr3/Z
edvN+vMvaFnLdEdRkZEAxChdX6RrxUZ5vsoEckYxCc1hZK80fnZoTmPffdVK
/c2/Hb3tlqi339m+abM1BADYzFmzvMEPw+zbty8KrqK8iEdCQoJigXvkFnim
eNkTDcJ3KAI5+owdVgRyBJgpKSmKQM47/Qii/vXXX/+bT4xU0X82Sa1Vy35W
iN8UIDdx4kS/p1j9EgqOygRRTkgzS7EDVPR/O4qTN2JAYmJi0GKPM0jWvuG4
cePwGvyMsx46dCjGQfrpbuoPHDgwaNDAhMR4vlfguDx3x5wG4xo0n9Xs0CUz
w6SRGt68+qCXad2ZX0LCWrVqff7550SysiZWr149mIMf79Chw5tvvnny5MnC
wkJ+BeS78cYbiRZtgJwmQA4bb95n23hkfcOEb16I/jBz5xJ6cvTY8XGRkZMn
x54757kYC6ofPHgw8B5HfPbs2bi4ODymzxeBNIYNGxYeHl5RS8SBkqS5C7TW
qm4COdwHeKacQE4uTSD5lXGvTRICN2/evFevXoRI5UzOI/KMmDGh1h0fkWQY
GB0drZKMBTwDNpPMWn61FanAm+PT4ZJfbIYBmT17NjPiUQfWJyGWM2bMoHGV
ghd0lQ5LdRL7J3VzExbI541AsAPffffd/PnzLUVYuWHD2I5tDr78rF77bkeP
zo5DhxwmvpJ1MKnAWklkpH90GcrtlLQoLr2Qvy6d1zt30h95sPCNF0M++jhr
1eqi4pJFRWxIRESEd7QOsoUzKJGKaBFRYqAUz/bQJuhR8fAq3YuPj7e/UGwR
DguNU1S30aNHKwI5xI8+EBK6n+sDu/4sew1V9B9MctlBgFwFAh7ACa7Q4xZb
oER/jh8/TrhqH6f7JJAJxnPUqFHl6YBuyxP3XSSfv0J/JVGSzzYxgKGhoVLd
AJfXu3dv69S0tS6H+tPI+PETNmzegJHde3rPV9Oa3z7qhQlrIwudRQLkzIKM
ZQI5WTeoXbv2M888w3TQMsawSZMmvBof9Nhjj91xxx3Dhw8HfuDf//GPf9x7
7732d4SN5T8Dwhlu8fiFI/0Xhzw3psGI5cNPXTp55uyZhemLFixKPXX6X/ZQ
WME8hoWFDRkyhKnEZ+ErJcuTN2cwj0jOhAkTxAL79dQ2FLQ8Y2PpAyAn0Kx6
AuTKvyIHRMnMzASBlLPOl08CJyOTiAGdtMdCKmQddppvkntxB7m1qpJ+hK8v
WbIE+cdHqyAoQCMtqyAoBI9waeXKlSon5Hk7OAE/q3KOHezBeLOzs/0uafIA
fVgs+6c/JViEUjAX0j2Xs3hScvzUxPhTYSP1+n/WH3vYOXOGdvlSsaYXG9GT
8VBlJiRxmam8jf+ZO7m6w+XUpifqzz6jP/qgPit+5LDQBampFy5clCHv3Llz
wIABW7du9eYAs2kVi7cnjBIc8NmINwG3iEP9JhURysnJAWfa34hxb1kdyOFW
FIEcIgofGKO7RK1bt44A/99/5qeK/oOpMvLI6eaOBsYzuGRcFgkAwAAGEbyg
ktOnT7cp/KROYCG6gdXasmULsIqW3deRbDgmaeW+//5778sacv4Zf/rDDz/A
fzm61r59e6smrHVeDjp2/PjMubOWZqZfuHQufW9m/RHPvz3pw43H1+sliUiM
CNpmv2X37t0ffvhhzZo1CSTpklyJ/fLLL9u0aRMbGxsVFdWlSxdQJeblrrvu
euedd+iJPUNc5p9C5+WkDVNeCnvpu+nNc09sPnsmP3Np5vJVWecvntdL932l
/8gYuCg8PJy3YNB4e9++fX3Wv6Bvcv9CMQRgOJhTxANHwOww0jNnzlhLoEEL
M40kJycvXLjwJ0fTFYhZQ+ZTU1PLuZLGe3GFwd2c9UuVkRCYaUV0CZ3cD6Kr
X3YQIAe8VwFy8BbIp5gXjnAAOyCY3G9QwMNYDNn6tyee5zHwpCAQ+57IXjBq
7r1ChQXo2bOnVd2guOBi5ISxaSuyLuzeo3/9tf7A3a7XXnWuybzkKHQ5NKdR
66ES85HQtkOAogHkAI0Off16veF7+j136O3buA4dXDg7JWnqlJOl938la4fP
nNVyelBlwxRYPnLkSOJZxfsOSBTGQeWqNVosaWdUMDx4DwlUjJvi4+OZepWH
8RRIFF7DHcgxBBCm4lJhFVWRCqEaG03ChJa/rpBFFQXkMAUoQhBbtHxl+PDh
3lXpAyIsFZZ20qRJISEhrVu3/vbbb5s2bQr0GjNmDCYCV+g3VzwszczMbNeu
nUdCMEE44r86d+6MaYJjoB3w1XqMZ+lpOhPOGWtuZ8+fS1+6ZP6c2fsO7QtZ
FnrjyGd6LOhy6twx83icmSO47HnDjxDG/vGPf6xTp05ZtSNx7l27dq1Vq1ZY
2Ej7Mz/mloshJpsPZn8Q/039qLdm5szcd+DA6pWrdu/a5cDjEMe7Ffvm7XjS
0NBQyXSBSwVP+kRxGL1p06bxpKA4+wPkPAxyw6ISzsPeJk2ayOx07Nhx7Nix
CJ7KBbSyiH4CFWbMmBFEI5IZI4jDAO7EexMSEqQsb3na8UkVmxBYCI6BeydO
nOh+qK/ygNyCBQuskMeesGwxMTF+YxMhAg3CRlnDse+GSAiS5jc9nW7iQ/y+
t+Pmi2lpaTDNWpy5fPFCx/Zts5ZmFOL3ly/VX39Zv+c2vXULffcuh1Nzai5n
ZR4SkQCN/4p1p4M/+w+4Gn2uP3CX/uYrWtZSvbgIqJ6QOBWbLMAVcDJ06FDs
lTesCujkG9YJI6myiI06TJ48mcZVymdjUZOSkjy2NcuiAwcOTJgwAaVQWetD
qJATlaN6PoEchiUrK6uci/ZVVEXuBJAjtARm5OfnV2AVJDzR0qVLFTMslUXY
B5w1ah7EHUDiX5CJYs5wIfetUl5NpBkWFhYVFQX4sSwtwAyIiCLPmjULyNGh
QwfG6G5VvMcLh9FcEJoFa91tBeqMV2rbtu2mTZv4GXdGhC63D0obLLnYwFvA
QrNmzJqWNq3J9Ja1RjaIWB16QbsAknMZqdcdhOz8DIoyV5F0p3mITTdOLOsn
T5+ePHFik2++Ghkedvr0SVkxc5o7Kdi4gsKC5auyOnRuGzMx+tixo5p5JsdY
69OcLuOP4UFKVwhL7lUcyN/fLrXrXaPqNZ3eZtrc6ZkZyzHaDkex2V+XVroc
hxhgePv27UvPYR3Wb9SoUZKkSyvNNGLxAVQ2cOBA62Sa9SuPJ7HPcAxoHR4e
np6eDmSycvvzOuYd8ACGd79rE6gQ8jxTQH/kQmJA30VsgjvV6f52Igj8O2IT
dCM2dPLkyZkzZyLYsNFvMKJCojUETXBsn1l2TT5Xqeygld7RlnPsKiuQAQE5
qQyicgEZPqDpcMa++pJemkSI3oLYVbw5fnzcuHHeldN5I9YDn24tY14uuDho
+OAdebloHTGRNn+u/kID/a5aeps2xXt2ypEGnd8YmivhlFvIFCA5jPpf5ok7
reSMrdMMH2nRUPFTJ/TOXfXHHtLrPq3PnFVwyai7t3nXrj4D+yPblp0k1vB5
kIBYbMCAAX4LrgmBhwHbiqthQEfQryLqA5uB4VX8Gu6PkBDDrqIO5QRykZGR
SFpAKZ6qqIrsSc7IVfjlOEwTQG769OnlcRO4fsI9Ijv9p+DHL0lRqhEjRgSa
OlvWwfAms2fPBqfx9rKMgGbUHszH3Xfr1q1Xr16rV6+2jkx4d5VfEZI3atTI
58FveIVTaNWqFRyT1CWdOnWCdW73WHWr5aNHjqbMmtUhtN0T3f/8+NDn4rMn
OJ1F5jk5g9EOTSvCzmuFDldxkauw2FVUYNh8jLZOWyddxflFBZedRvzsMC+p
yWVX/ENhQdGlgiI5Ss3nxaZzNi4zuJwlB6BN1Ffg0i9r2pHzx4cuHPxoyFNP
9/prtzFdV61aefGCj8xO+HSAWZ8+fbDqeGpcJGNkpNbBMwuhMU34RNAXoujN
Z8sXYDmXmIlNoqOjd+7caQPvaRAGAvaCO8zPGwEAdElQZUBYzgDbZkr5QF/q
/nacGgKDwwq6ERuSJNu4LV7BMMsfvmmlR9+Tk5NBhlppbjqgC7OgcvUYBeFJ
ZEPl/gKR1JQpU1TuUEgSOSJBxfR0PKyYHwwBAx+CJ1W4B8QdNGiQ96UAviur
01Yje7bn9unbe+eunajcZd3hvHxODx+uP13HWBbr3F7fs9tZ7HKURG2G9rqM
zCBOpx7MBQjzmKuh3S7zbEYx7ZhFVQ1keOak3ref/sSj+kP361GjnflndDML
ycXCosFDhqJ61iFeDGBiYuLx48c9jB78QZ2RLhW7jbFFchRPI+AOeKPixdWk
pCRFCcfYEmNahxXtSYCcylUsbyCHmBHY8vUqIFdFFUiVUdlBN/UCq4jvLk/e
eGQePCaZdQNyppgR3o6yBAQjxQGhnqg/BtZazbO3RdLJsLAwvuJxRsid4POi
RYtAfcTgHkfspKg9JhGcg5nCqQEGunbtiiW0Ds9YDxv9cbqOHD48MnH0fe3r
1gt7Zfa25CLz4gO21uFyFOtFxraI7rosUM1RoB35Ud+0Tl+eoc9J1iNG6+Fh
xp+RI/VRYfqo4eafEXrkGH1mvL4iQ9+ySTt6yHnposus8+gw1+JMOFXkMtMS
5Beem5I9qe6A5xv0fislPflcaapAd8TFcNasWcMQwNLECIcPH4alI0eOtE6G
a26Eu8eEyqlp92G6N0sjWHuwB8Gs+16JzRYY87J27VpaXrhwYaArugKl8Be4
9YC+qJtAjkksZ5Ioxou0BAEjVUjyyAnU9LuHqELSAtxmigEtVoPEQeiF92Uf
7++iazExMXKJ2y+QQykAUd6Y35swPojcqlWrVAQAzZ04cWJ8fLyK30dJmSDF
oyNIYFRUlPfFTMR40qRJ7it1GUszoifHHD5qLAmibIAr7dxJfchg/cnH9Dtr
6s1buHbvcplr9Gb1LgPRGVoZFJBzChI0z8IV6y40vdCoxaU7Dh3Quv+g13nI
WAns0a3o6I8XMTlOrI6zuNAROtQ4I2EpYEZGBtKORHnPGtEWAqwC5JgjgJzi
PixPEmIrOizZtFVJIHzhwgWkF7WtbCDHJ+B/ZLhCKqpU0X8neaubx63VivIa
yC1KgWEM+tS3ZpbtwxfExcXpAbozqSapWKfSfdT0dsaMGWlpaYoI0PoisAGr
NWXKFKAL5t1yHO7dpk2e6dGjR5cuXdwP80sHsHh79uwhcidek/JVGEkexrx4
3G+SNi8UnItfM+Xh0Pr3Rr8xd9scYulizVnodBk7rPy+4IK2Pss5sJ/ri8Zn
6r+4/u7b59/0x/7XX93qf67qeM1VP1zz667mn27X/E/30h96XXfNhJtvzLj/
7gP1nyz+qKE+uJ+2doXr3FksvIEJDfeh5Reci1wXU3v0i/XGvj1706xCR1Hp
AP41RkmG3L1799WrVxM4p6amduzY0X3rRAYro8YpDB061Co77r6LKn/n5+dj
jdu3b48swZ9ArR9wBSyH8Vcx5u6E7IEWkCKV0zjuZJ2uDzo/GwNnpGLtg/u6
xUBXKbk/IJcdZIMsuB76pP379+PTQU3W29etW4fyqozCAnIqL5ILht4LXB5k
YCETyIFaFRfZYmNjFbezQdoTJkxQWTKF+RJNeEsgRgCOue/kJsyeFTV54jFw
kXmPyWXeHnVcvqANHqHXraPfXUtv3lTfsN5VVGTEbcArzVWsBQXjjLvn5n9O
67iEietyNuqf/EO//0699gN6/77Ow4fMtTi90Fi2R7md05NnYJMtpWDiMFAe
10hlOJMnT5Zcf37FDA5gNhWraSC6TJNiuhIkUBYM/T6JAR83bpziPmxwQM6K
WTBoubm5VUCuiiqQMC+gCwsqVJRtpx0MOBYs6FRysneJbZet1YA6RryGGVHP
AyYuD9Qx06SgN5sEvg4fPpwAHFWVxXOPak3gGfAeyCQ9Pd39UqRWehGMDnzz
zTfgFiABXQIVtG7dGtuF53U/e4+FP3XxdP/M0dcOfuypUa8mr00qLjJqWzvO
nNTT5hV9+vWWO2oP++11z15R48bq1a6vVu1/qplUvZon8UkN80+1aldXq3ZD
teq3Va/29pW/GnT9tStr3XLh3bf1KbHaoYMOh/Pg2YOjM8IeC3+53vi3p+cm
n3NedOhOYzPG9CRMFh5z4MCBwDYpbYn5wj6D6HDu3nBIVj4Brlhmn2BJQCCY
EAOL7w76LioTAUigb4FaTsAYbl3FC7gT86ue78InaWaRI4CcZDMLaLzuS51z
58594403OnXqhDq4N8KIaB/tgCHlLyVmETYEVQXbiPrQLG4RJOx9NsybAgJy
QDh0R+XYG3JFm7Nnz1ZB45JxEe1T6QMsZaQqFgYx6Nevn88t/qVLl6Ig7vzp
HxIyb/qMi+fOW/nijPS8mu44f0EfMUZ/+kn97pr6Ky86ZyVevHDmsnlAzjg1
F9zWqpE1zoBwl4gKda0IuJg0TX/hBf2e2/U6j+kToovyzxaXVG9hGMapPKfL
tSgtbdmyZZYhYq67du3qM3nItm3bAFFIhV8BwxTABwJAFQ0FREmlZj+jM18K
3Bo/frwi6mP2MTgqp3HKA+QwRxERERUeRlXRfxVhTLBX7i6Gf65Zs2bJkiW7
d+9WSYOpTgStkZGRwV1c1UrPqmGHsQYBfVeuSOAX1G86aObp5aysrNGjR5cn
vY9YM5QXW9e3b1/gnMf1TK006RY2vEWLFhgZq0q45bLpP8oeEhLSrFkzon6c
Bc8AifmEvyVV/snSoZ28cGTk0mF1I5+/M/pvsWvHn85bW9Cl26pb7mpy9VW/
ryEQjb+vqFbtVzWqX1nD+EGgW8mf6iUIrvq/IB2fVf9VterXVa/+PzWrV2/0
P/+TekvNix9/vCMlql1ql/tH1Xt74t/n582+5DQOGxcWFx45cWz7zh0rV61k
rnv06AHsxMfhwcPCwoAQcXFx1o6JJVrYNB7gYTCeVZ3cY2eWUJoWwsPDYaDg
YQufBDopgihEFAP6OsYWDBBoWmABcjjuoCNuqVsEBTpYiz9wmMG+++67V199
dZMmTTyCKTmAhzghfrikciYEtogYBD+IJbHmC7aDhFVCOXUgp5nHFyWthN+H
5X6NYl0YFB/1R4BVHt6+fTsO2lJeG0IMiFZycnK8oQ7BRXx8vCgI48IsD+nT
Z93q1YUOs5KD7Hsau5ogKF0ruKzPTtFfela/5zbtsXv1kB7aqhXapUvOYO87
mAcwzHwjBZf09av17l2NDdy7btXfeMuZPN1x/lyRSy92OYp0OuMEyJmn57S8
3FyCSutMNZJG7EbY4i1FTBAKrpJHCM6MGTMGyXEvOV0W8Qy6rDL7uumDCGcU
YzGUolKBnHzCMMeOHRtEZtQqqiIhzM53330HfnCXIsAbvhIMg8xX7PFL4iBw
iPsFzIAIjRYgl5SUpCuvw/AYusNwoqOj1b/iURy2QtAsBmf16tUEXwASwIDH
sS7o9OnT8+bN69y5s2BO66WWL95rZr9s167dDz/8gM3HIQJ7cDRGKfmFaQvm
LUyZnbJi5fLFmam9Iro/3OLxuzvUntSkzrybb3q8Ro2SRTZwmQHerijBa+b/
XVWt2pWl/65u/LP6ldbvAHHG//2KR2pU+1V1E+DVrlF9wu+vn/NMzWcb3VGv
43NjpwzNzMpcmr4UCzlv3vysFStwUtu2bYWBdG/KlCmtWrUiSF+wYIHspbqj
L5waDwNxwXgYNMtmWg/ANDAwrgEMTGThXRQjuLngiyBnuSLh0SUbIuqH1YEe
kwvoAqZPunDhguzvBzdeNBp48PjjjzN31157LSrvfpNUN1ETszNr1iz8kZVK
ovwkdzB5tRxEryQgx1skm7TKkaqAgJzUKfAuEOyTkN6EhASVi5bIsHu8JiTT
MWnSJPhjycn5CxcS4+N37dlTbJx/0yXTj7G1apRY1Uzz4XJu2aZ1bHfmkQd3
3HLjxQfu1ds013KytaLL5hVU8666sX5mbLzyFeP4m5E9z6GXFNSTaw0le6kO
45aTS9uQrbdt53j80Zz/+9PZO+7Wv2/pyN1c7DS6AH5zlqy3ayW3501o5J5K
BeGBDz7rnwKMO3TosHXrVhUxjjbJb+gtTaGVKilidHO7X3YH/HZAN1fk0ItK
XZGDXcw4NlzxskYVVZFFmpnNTEqlY9uffPJJ9yt1HgmBK5CwcmCwRYsWBe1/
0RTcTUpKivpX0JRTp07xXvmWyqs1s6AYIaEsHlbsijfYeN26dcOHDycKA17m
l14NEO+JV8IihYaGNm3aFMy2bds2j8N1sixJCwShgB8MI2hz/vwFc+bOXbFi
9fbtO3bt3JGXt3V99rppi2Z82e3dUQ1uHvC731zxq+pXVLviumq/vrb61VdW
q16jZPWt+k+2Uy3wVuNfq3LVq8uKXPV/fV7j6itqXNP0ut/Me/yOyG6NZixN
2Zi3OXfnjp07dgCKwFpE3Fi/fv36ff/992BOfBZQzeM4EGNhKmHvoEGD2rdv
P8usz+jOZ/iAscU2All5xtqVrkCSNDtYYGCSIpCD82AGgGVAm6RMGQNBAgPd
k7UIIZk2bVpqampwoghvAdJ//etfX3zxxVtvvbVx48YeQK4y8sjp5iyvXLmS
ybWqG1cSkEPeFMuhSl5lRSBHGKJYjIY+0FUUVsUdI/ajR4/22N2Wn4loZMtV
/imX5WGXO7R2ldxK0EsSSvLvi/lHpiZMr/P44dtuNu4j1K6tf/alPmWyvmu7
8+IF4xqqCbzkZnqBZtx4cpTWg3AaF9JdznOn9b279BnJztattCce0e+udeiO
m+Pr/2V3YlzR2WMX9eKikmNzPjZtMZVDhgyxhIeuoiOgd3ewJPv1IKJu3br5
rbiqlV55hkuETioyDwBGgDERfh+mQfUqXTRb2StyRHmgUGK08mS5rKL/TsI+
rFixom7dujjrK6644rnnnvMAcpVxa1U3ZXj9+vULFy4M7rAQSkqvZGVGDwRf
yR1J9Rt/6CMhEgiE2Nn9uFoFEkxOT0/v06dPWFjYvHnzPFw8/AFIT5w4ETjX
v39/HvC5vUv3YAiWH2szZcqUyZOnMK3Lly/LyFicmZmxdduO7fvzNo8ZsPH2
2zv95upba1Qv2VatYayvXVWt+q+qX/mrajWudANxsudaAudK/rKW70w4V636
9dWqvfvrKxfedc/xfn3ztmSv27R+zepVWatWZJm0yiSgDi772LFj3tsrGK7N
mzcTa3fv3r1Hjx6Wl3cfFDAD3AJ+A6NiIS0IV4HHt/TSi6g4X2CANdH2ROcz
MjJw2QGFz3SbV+AUgt6jx1cikLA0uOHDQIR/69atERER991339dff+0N5JAc
cHiFy7lEHJJ9t/KAHJ4RBbdiIhvCe6J3ikAOeZ4wYYLK1QzkAZFWzG8JkFu9
erU3PEBZevfujfrQSUFuspXvncVOK/1jbh4YOG3vgR9jwkL39+6jv/euXvte
/a6axp9nn9HbNdcjRukLF2ibNrmOH3Pm52sOp15U7Dh3Xjt8sChnvbZmhT49
UW/VUn/6KeMsHN+67279s0+Ohg+bEjZy267dl51G8Qhdk+3akte6E7NJ1OYO
d+Ebtsv9HJoESjCnc+fOAGm/BxR5WJJ2qlxggdBKDAXt+11MZqaILhWvkKOz
iJZKgBD0ihyNA+Rkg6bqjFwVBUREJWCDhg0b4iv/9Kc/1a9f3xvIVcaKnFxg
xDtLyBnEgZ89e/YMHz48oL5p5kXIgQMHipbZvFQWuvF62FJQnOLlRGsgPo9s
aT8l60P5AT7A+ZSUFBBdaGhodnY2dsayRbKVvHLlyjFjxjRv3rx9+/aoPBYD
8EbfsAM+8bAZf9Ny4fbcbXiBtHlz9oT1O/jaszP/eGPDq668yViGA9H9SjZZ
a9QwYVp164ZDKWZzX50z/wUMvKlGtU9+feW0P/7h0HMNjvbsumzypAWL0nf9
+GOxo7isyaSHjBGfhTfEgOOae5sk+dXdvR4jYlx4+a5duzJZQNODBw9ax0jc
mRwQq+0nTjerleF/mXG/z+ulUERyo6k8bxHIITExMegSPPj9yZMnB3dl1SKY
SRB01113+QRy9FBqrQqhBYrg1p4Qb7yhlFOpPCBHbAjQVXG4CFV8fLx9/hOL
li5dqpipBrUl9MCV2z8m/CTmmjt3rjvslM/pG5ou5Y/lcyAfKl/W6Smt5GKp
ofDbt20bFhm5ef/ewjPHtawlerdOer2njRoQd9Uybrby56F7jFKtr76mt/hW
/6qR/rdX9Wfq6g/eVfJb489t+ssN9B5d9SUZev6542fOxE5P3LFzl7PY6dCc
ZmUH38ViAGwjR4507zY2atiwYd4YDIliTondFJM8I65+RUVYh21BtJgpvxKL
tPTs2dPvqqAQiHTmzJkq2+Xr168nQFAZl8eKHI336tVLcbu5iqrIndA4dAqJ
wlDUqlXrmWee8QByBCx4DcukV5SM0Q7aDUYKtGCl1W3MBSZCfT1EMzOWMMxR
o0b59e/yAGYTa4MtUu+hx2P088KFC2iozwQX3kt8PI9VB8UNGTIEpcbO4/iA
rNZiu+xK5Obm4iy6devWuHHjZs2adezYERyOVZw5kz8zZ8yYNmnKxGHDhiYm
JqSlLZo5Y9asOXPTMjPigCnRE9bNm5XTvuWpN1/d+cA982783dDrrvnoyl/V
rVHjwRrV769e/c7q1f9Yw9xnNU7S1bi+WrU7atSoWb36XdWr88xrV9RocfVV
cX/47Y7bbz3ywL3HvvhnXmzs3PlzFq9ctnbdmoVpi5KmJfM6oBfuSS754qz5
m6gcgNq2bVt6CxAFgRM4w14LIcvAGRffHTx4cMuWLQH5yJ5KggIh5BNhCKLM
h0WIIm+Pi4tTvMiGZwFTMZCAVpWx82ASxVd4E8AjISGhnLEVI42MjPQJ5HCa
Y8eO/eCDD/5RSsBpVKD8ig84DwkJmTBhgv7LAHKS1RmRU+k8QE7xgoncFlm0
aJHNM1ppVmTiFFr2Lv7CpADb9u7d6w7kkDQPeOByWxRzlZ5ty968OT455cjx
E+YnmqO4WDt9yrl2lWvcKL3JN/rrr+tP1dEfvl+/5/blf/rDnltvcjxwj/7o
Q3qdR/VXntcbN9LHhDlXZGgnjriKLjnN03dHjx5NSpiyZ3deEUhOk+rNLp9I
jifDwsJycnKs86vML5PuDU6YKUJLBEDFgEuRZb8bQ/IKOE8sppJQiE52794d
IGe/vC+/YiDYNJUDdSiL4pMeQO7AgQPR0dGyz15RZ1Or6L+EBLFIOe9bb73V
A8ihDgCJlJQU2QKQgpgV8l7eiDPCPruXdFEnPBHaOnr0aD2QXTaUKzExkZBN
5WFwhZz61gOpHAF/8NFr165NSkrCZ4FUCVH79+8P0EJJGS9eGGaCjf1asDNn
zgCBQDWhoaGAT1BYWloa8NXdicMHjKckFuNdvDEmZkLMxAnREyJjYqJnz06Z
MD5myNDhvUMGtGnZfHT/PlFjInv36j8lcUrkmCFZo0fs+6FLcbsOFz76+8Gn
Hsm5+5aMm/+w4E+/m/m/v53wu+uibrhu/A3XTf399TP++NuUP/1h1b137m5Q
/+KHHxY3aZb3ddPpbVrHjhk5ec6MuPmzU9NSM5ekz09LW71+7fbt27Zvz9u0
adO8efMmmMSQ+ZvOI0ggNwZl7bHivw4fPozdw0fDnBEjRgwdOpTQmyfdHbG3
eGD3YAKOGKM9adKkGJNgEYwaM2aMvBcfgUMJtHgH5poWrAIT9oQdZkZUtofc
afPmzfQ5OGjEwJlohqaydWhDNkDO5xm5IDTU50uZZVCi3H//2YEc1gxrYCWa
tiECWNrEDKqsTCKWzK/URC6LLJPVu3dvn0AOtjBk9wxsmBSpEezeAYdxqq0E
UcnJNVRrTc7meTNSTp844XQ5nC5XoVGXQSstv+LULp7Rd+5wrt/gSpgb/dln
a0L6Fy5bqeds0vK2OM+fdhgVvgyU5jKTQzq0YofmOnHqVOiIwavWrysEE7qM
pEImwHN6YzmmmJANrbQCT1Re1ui8+QY/wVEqC9posTqQQ3mxhCqJTZjNH374
AWPlnU3Rm5gRQJcKPJNzCx5q5ZM8gBwM4Yu4jyoUV0VBkwXk3DULk4vfycvL
O2/SpUuXKkrG5N5BcnJycJWGcGSI/eTJk/VAVvMYGrhI5XK3lPEiulQsXqyZ
J/aXL18+bNiwtm3b4q3wO4sXL162bBlIlTdiLvD4fIKd4bd0o2/fvphx/Cmf
wHz6Bod9JqmTc02pqanAIb7YrVs37E/nzp0ZPlHtHJPwX3ASEwpQHDBgwLBh
oWFhI2gcrNuqVevGX37Vo2f3viG9WrZp+fmnn/3lyXp1nnj6m2Ytlm3MnpY6
L2fD6o1zZu6aOy1z3OCZfTttjR51burkgnHjz0ZEbQ8bkRMTuXZy1JaUxN0Z
qVvWrszdtWPZunUJ05PjE5Nmz5mdljp/1ozkrIzMnE05S5dnLl2WsXDhgrER
EYI/GSlImIHTeaCd9JaJw9rTyT59+vAYwAkxADxgKr3X06wNWZxaZmZmXFwc
32LsAOPw8PD4+HgGDlfxhpK5mllLT0+HFVh+XtG+ffshQ4asW7fOmkd7aUEs
s7KymHe+4vdhfgusso61K8rh3r176VtwOYGl7ht9K2dWEL7O1NSsWbNRo0be
QA4gLWfkKnBlQF7BTDHdeC7+CdQhTqlwIIeYEUOpAzmVGhBnz55FgN3LUtgQ
koyUqmTAgNXDhw/HMrhHx/IKeoVcIc/WG7ESGRkZHoGJ66f3DeTRjZtzZqWk
nDh5XApslVwpNXCc3E4tuR8BRSfEZedsKgCemf90WvdVdevsnVGmq8jlGhoa
unRZ5uXCQq30MZ8rckgL2o0yWkAOq4iGHjhwwFuQUNKePXuqJGmhNSna4lcf
dfPsAZYB1GcvuiLbSCNyBVf9zixqogjkMNdYZuy5X93xAHJEsoQAVVdWq6g8
hPzfdNNNTz311L/njJxmJmcD5+Bng/gu9gE7YOUZUyHUirGMGjVKZZWGIUdF
RWG97bshdPLkSaAImAHkAJDA29onDcbdMHasE2YhNzcX4AHm6dSpU5s2beDG
tGnTsC3Z2dn4Arrq4bJ5HY3zOYaFdwHwaGGXSRiEjRs3ghAAThjP6OhoWsNT
TI2bitfu0qVL69atmzZt+uGHH9asVfOee+6ht7GxsXPnzouKHh+XmDhjZnJa
Rtr0hbNX5aw7evLIkb17cnNyFi1etHXfrqytGxeszMzdvXNrbi4oYu3atXhh
8zLFcl6UmpoGo9IWpS3NWIoP5aVYJEYB5ECoGAhst3pIb3Gg/MzYvQ9fwRmM
GwhfztHBVTw41r5du3bAV/APiJcWCLeRTDhjs24mpc0OHz4M1urfv//IkSPp
ud+p18xj2FKMSeXIMQPkYVlwUARyRNxS3CGIaz6yv6NYlMSGECFk7Isvvhg6
dKjH+Xk5I8eUwd4KXxlg7lAroDJvRFYrHMhhFiRtr0rW7oCAHJYKdVMEcmAw
FXwC2MBxowvehQ+Qc/TLAhgMB81SqSfF87AXNKVSNGfypMnrsrNV1pOJT3m7
39viiDSKD5a2VozlshgK4r2Vs2XLFiIyFf4zfIn1VMJqjAy2FOnyC+Rke5dI
k076nVmssSKQ082jj1Jz1v4xdyDH0OCGVaawiqooONqwYUPdunXffvtt91iy
8m6t6qX3HUaPHh1ogSTdtO2yd6b+FYATkAk743d3GMuGFaVjfv2+nC2UpSf3
5L162btR7ifwPU7HYU9QZIABrwYOhYSE4PUEzMh2IfaBIeCAmBR8In8D5KQW
Ic/IvhXYjDAzIiJiqkm0AIYBzg0cOLBVq1bNmzcHzr377rvjx4/HwPI5DMFK
z50zZ9jgQaGDBiVPT5qRMnP/wQNrstduyNm4ZcumHw8eWLc+e/uu7Tt2bt+x
A5O8HSO5xSQakSU13kIHokyik3SVDjAKHsAB4Vv5LT5r0aJFdD7XpG0m0cji
xYutr/B1+swX+/XrR8tE1jgF3ohXKss12x9ukd8yTStXrqRB+ON3K4evIJZ0
SUW6kEPGBZq174k7MdEgDdgexKoarMBHB5qF2J48BFVu7/bu3Rtxgg9B1zHx
SWg6AweLwgQMToUDOVAo2CwjI0OlM8wvs6yCigFywBjCRpUpRtIwTSq3kvH1
6Ca64A3kCDrALWJ/NLOaGHgDMOnXVMolAjissiYpNU1UkvmgO3BV5UniJiTH
OgLKV1BtdNy753C+V69eKtd25OQPwaMKkMOKhoWFuZd8taEUk34JQI4BonTl
vMRURVUEetm3b9+hQ4fc/YtHHrnyn5NxJ80sd66YncmDwJaYC5X6PhYdO3Ys
ISHB/uyKEEY4Pj4eE6eXMWQ54sLbsW8dOnQIrj6FRWXhPZAn/GFScHkZJsmO
IegL6DWilOBDamoqjoYHli9fzsO4AKAdWAiDhhUFwvXv3x8UB0oHxX3//fc4
UOwtf+N0aAGvETtp0ryFCyPGR2cuWzYxNnbHzp1x06elZixJmWfUMFqclpa6
cCGRfmbmMuAf78L6ASlpvGHDhh9//PFnJg0aNAi+0UPsc7du3fiZnkhC6aUm
4cTBZrxxeCnhyOTUIp3nASAinp2ZsrHYgQqh9TyujVcMGDCAIVguUvcFufE+
sBrXefr0afulNsl3AbfVD+PRGnwA3KJx6mMRb45Mqqcw9dugz89pXO6qALP5
uWLXBxgyPh1wjmzLipzfnBJ6IEBODsEqZmlGsAk0VO4hAuREOBVX5BAeFXmg
n0QWPsNkFJN2rA3K/Px8tJg4yC+SkbU75EQF82A60GWVJ9WBHMrunl0HBWGW
fa4lYj/HjRtHYOWXqwghDMHMqoT8IK7OnTtjBv2uyEHYMcTglwDk0DhicJVE
1lVURYESigPywdET6lZsbC6Eb0XH0f1Av4j9B0WoZ1XFCWKHQ0ND7Q/ICXxC
uUaNGmUf0GF+ASQ4ApXIt5KIGQFpwApiW6L1uLg4UAoICnTEEPCYQKmQkJAe
PXoAscBv7du3B92BzBcuXChHlTAdPIbLGDBw4My5c+KnJWUsWwasOnrkSEJ8
PL5kdfZafA2NY/Nnz5nNk3h5GsfLg3NWr17N14cMGcJ727Rp07FjR36gZZAS
n2Mhhw4dSn/4hK+sXbs2Ly8PvsHhoCuNlofEdB8+fHjq1Kn0zcr969OGw1Wp
biBnaWzsPPxkvCpn5q1uIPN4WzmPrY7lcLggRlxPRZXN8klyRq7CEwILiUdG
LHGLSALYTAUdVRKQY9aQBJWNRYAcIZKcivf7sAA5FbPAY4CcU6dOeQgYeg1u
RKkt4CTWxmPtzifxXTiARa0oICcdA0Za5X3t2wRuuZfeQ9MRdfdCLRYxWUB6
v4fZhGAIzdoYfOs8J/yEV1u2bLE3Mr80IDd69GjkVvFIdhVVUUCE5mITpk2b
hr0NYgNUpX2CR0xEQJ4dsQdeAjBUki4KWbul9kEl6owCgnYk5UhZzxBLhoeH
E07K4fxKPdUA3sCAy1YmaIGOwS5ALG+nDxMnThw2bJjsb+KYsDZAO54BoUnB
CEFZYWFhmGI+AZ+AxMB1eGpsIwaHTyZPnow9jx4XkZWVOXPm9MzlS48fOzY9
KX5DdnZu7vYxY8dt3pYbOmJEXFwCQAL+YPpkpyMyMhJ4Rq94Ee136dKlV69e
eAdex0sx4HIWjmfoJ73lc8mVyj+joqL4m7HgH2V0eC4YW6koRQgwL1DTpu48
3QDuguUk/4kN4tq+fTvToRiMSDvAYJjDkAMCcki71J3XKyErtUUC5NwPylYI
WR22LnUeOnRIYgG/6lNJQA6zhvyrALk9e/bwcHZ2tvqKnCKQ865jopuyl5GR
AaOsvonB8XvaX68EICdkVdry2wGMD1x1P1bNMOmS98onnzB89xQrNoSxwkzZ
L1hJ3+gkkazfrVULyCFXPy+QwxQT0wE+EbDKWC2poipCx/Py8oLOeeWXkFtQ
CuocUFESwBhAAr1Wx5bEg6gM7sDn6orlT2U5DrznU6HkMXxc7969MewqVt3b
U9My3SbGl/S/IAo54dasWbOPveif//xny5YtAWDWRir2HAyAWZOKCYcPH87P
z5fcxfhfcFTbtm2liO3cuXNHjRoFouOfgD08JhiPd9EIRgl7K/tKBMtwEjQV
Ex2dl7ttwYL5IBMMZlJiwob16/fs2Rs9fnxuXh7oa8aMmTExE8HDNAUkw1nk
5OTEx8fTFC0zFvpGU/wqNDRU0sfxQ7t27eRkmsPhwLTSW7wSfpz+E48DBa1t
Yr4YEhLSpEkTbz588sknslcruemYfXrOZCGf3iceVeYF/uNcxDnqZeyxMkFx
cXGgUPs2McI8pnguS5qCG0yiyi6/+7eAf0idyuHw8pBsrTI1srVa4WunsEtO
fu7fvx+ZWbdu3c+1IgczFVfkkDeUyH7R1RoFDysCuUWLFsn2vcfnUpAXw+gO
5NAOn0k8PAgQiGhV+IocWkCbKoMCl6L7hIcWjMFM0SVvDIYZJJTDaqnkfsRM
MVkqO4+gMuwek6WytYoMIFoqOzvYTJRCvTBrQEAOLYiIiFA5L1pFVRQEVepl
B710BUzq6Kl/Cw8uB64U83ehUKgqNtPGKWvmJSa0Fdtikzrg4MGD48aNw8wG
tAon1UJx3Jg4DHKrVq0aN248aNAg4lxZj4LJOLizXgTsYbAY5+JSsjpPB3AB
mzdvxrwMGTKkU6dOckMfWMUQunfvTuOgiwEDBoCmYC9Qdvbs2f369cPGwnPA
IQ/zM0ZPaqUB/HiMWPKYSThEKa2VmJAg11QXL17MwHHBMFPSxMGNPXv2YKXF
GoPrwGNy25egmAEuWLAAOEQ7oLXmzZsPHDiQPvCYu0dgIEWlRCP8inG5cwDC
OGPlYBTfldIG7du3h4eMGgOIQ+RX7isbfv2dZlbKABOWtccqOzUqScmA0JLb
TTFvgGbe15bUNAGtyK1atQrkA/MD+laghKDCFrA3nEFOKipvpEXMsiAoxI9X
/H8B5OikdNjmGZkU2AXkYFz2MiNDFrHxvl6KKQBi8TrLyBBN9+/fXxHIyQJ7
xQI5lI4nVYAcdgZL4l4TNjs7G1b7BEvYDVpWiceZAgyvCtQRICdpfm0ek/nC
mmHxVOAZthHQpXKiUsqmMGWKQI4nCVEnTZoUdP3lKqoie6psIKeXJvpA2dW/
gjZhABXz+uqlVSSwWmIxfOqXVBbABGEGy3KUR44cwUSgdIoojkaw0nJUjC8C
tGShA3sY3AYiAEDS0YeEhPTt2xdvC+toU1ZNZc8U5IZNSEtLw+717t2bOJpv
wWRJ6QZoAVnRn+XLl9MNXB5YBTA2fvx4OgZUoAUMkQXksIq4Gz7nWwycF2H3
eCOghR/4hEak6C24EWjE1OBwQYmgO17B37yLngAFeYxZxiHCCh6gb2Ba+knf
gtibhrcIJy5vzZo1vIUGAXWSMk4lwJcpZhRxcXH03GfJNs08UCcDsW8NlAs3
1NfKmBG4FFAGRcmQhtmvVBSn//SMXGW8iDYRVERixYoV/7+syAmQs7+TZe3r
ybVcv0c45PIyrPBGR2gEcZA7EiBiUtxaBUehWQikylJqZQA5nmGmFIEczWIZ
VIAcjWAuVG5G0AFsIN7B3g6IHklmS/sjOvJGXo2RUUkPCORDsFW2segh1hUz
i5Ek6C5PVZoqqiIbkq3VSrq1KgR8wj0h+bLpqfIKYAaWQbEmpm4at0WLFuGy
7R/DWoJnylq1w+njIzB9Nupm9R8rijrHxsZ27959xIgReBaft0W0n5LHb4nu
MXG8d+vWrUCmDh06NGrUqE+fPuA0xg5sACXyABaDuJIX8TrMHQYHhACqAVqA
Q2iWB+j2xIkT6TloCrQDK+jMzp07+Rxmbtq0CXAFDMOqAMl0k8MC5GAdMAY0
SFM8nJOTg//lV7Qjz+CJaBYoCEylG8ymjF3y8eLRcnNz6Q/4sFu3biBJOiMA
TKo/4NC7dOnSvHlzTBmQUrIiMygPXtkzSjehkRxi4UWwgl4pbrsj3mPGjEE8
vPfcNTNln6Szs4/Z4QYsXbZsmXhPvzJMszzskdLfnmSWYX6lojjdxEJyRk5d
HwMlxAN4LBc3fuFATvomAYjfFTndtBLoC9GW35VMZMAq7+7xK+wt+uhesZSf
URCVFTkUsEePHop1xyoJyIGO3LdW4d706dN9AjnsmCKQk3hNZc0KHUQGPCrY
epPItvplBzSiV69e9jIghGWDVyq1V2RFDuvauXNnwd6Vrd1V9N9JqBhqiBbj
tSvpFDoWD0xCsKNYdBX7AGwAJyjuxgqSAaHZL4CABNA+sIfPSBZrj30ODQ1V
WYQHimAfWrVqJTn/A9qc4kX0Fp7TAiCno0ljx47l7XLfUxAObfJPTBDoCPMC
JACG0TfMAgYfUMF7ZcsSU8kDoBHGBfCbPHky1pvPeV6KLGDEwFc4NSlJRpv/
j733jvOiOvv+1WiMiTF2scSoELvGEkusibcaY2Kv0WhU1NgbINLrUrfAwi7L
rpQFFKMgRVRwVyBIEzQCGhEiaGKMyQ2JiXee5Pe7cz/fed6v+Tx7nuOZmTOD
bGGXuf7gtcz3zJlTrvO5PqddV2AROVJCIzVp5Sfy2bRpE7DME1AIy6KNZh1+
e+aZZ2CtWkmgnNSCwkCTsFbAO/Wi1x555JEBAwYoH/U1VSZzEBLsLS8v79Gj
B5R11KhR9fX1KIZDgD1czvQjVgy7X1VVBe00ShV9xWQlHywoeWy22jv2H3Tn
oxSe1pNHkVQdprkUOjO70xL6kb5r9DsIUVGIriwrD19YaCWmFagB05NtmciZ
rhSR8/Mo/fThhx8yOiAnqWogMm9fTTViiFyh4egmNWL+lWVjkYHGeM/oabAp
iBwYxWSQkWuAFFVPInLgABCU5UwCGIKNyOirBBgE7RuLyCklIwKFyeIeENgE
u7JcxKOjmZUDL+DPFh0uyiWXLRKIHMOwrq6OEZTFidAXEG1gAexMY4MMRE7E
D2DPHsoESATc/B6r+BWojC7HaROEXxlxGmueEkIbQObS0lIQ0vYP7Ef1QkOg
Cl1E5V/F7aIwDhpQd0w5vK5bt25APcCi7R5t6GhT1Syf8hCIGDJkiG7gAsK6
fQCDwnhhrGFNEAmanYdwPLl1ElUwRE4IptiFEBWaHT4G85FH+iBc0eJveCZ1
xyJQCzmmMw0CmyLbYcOG8TpdpiU+Kjhy5EhSYp2dYyfUkSqQBtZHAhoTNggr
I8+MGkiZ+a6CCEAjowG7jWjRCZMK8qOBsRFM+OjcuXMpfNLX1bmkgWhlPMBG
AriBzoRnqZFCiNKbzRC+h+6AXw0cOJBOX7VqVRNdo6N/u3fvXlRUJB3zJ27x
FTkUXvE7UlMCTUxnssSAEJEjZRYiB4miAFlYRBOtyAEXOoyRmidpGCy2UxG0
KCn2qHzRZLnCgI2gTWiu1Hkx333xxRcbkchJgDsMRBa3POBtRiJHFzOoGQjg
DwQ4j+mQSxNJU99alaDD2sDKkhgABBmyH1TDpmM0a2trPVuigIOWj2KN9aef
fsp4h64kvS4QIH+QGX4C6MXm42AF5Qf0qMvQoUMffvhh6NmCBQuAO4y1Yz2p
Al3AYH/88cfvuusuTBWdIpiCac+bN69Xr16YXeNmSouQ48ePh6ppCVHrY5RN
mPnRRx8BrQsXLoS/wZeoGq+AKphvUQVD5IIQwaCI/ArTw0gtWbIE20eDmIiW
zNb5OgyWr0M5IE4wNzl9Vfn5480336SaAwYMgI/xusJY8CKM7v777+/fvz/f
ivqXoxkpCZWlqLrQgfHFRvA86gw/+l/exfyROZMRYxNjEZtWwqg9/fTT2uVx
0mDC4IRJdlx5at0y+0IW6SFyWXZqgpCTQ06oRTN4J6ApMIIoG+oEqWt046K2
1UZV586dUYxtmcgFDWGnUN0s7EhOBaFzWYgc5fQQOfuyA8DCcM6Cw0yUGFDQ
sywbAdndj6CuzFOyFIBRzDii8GYsAzJghb3ZamTx4sX0V5YNU3qWsUwxWpDI
PfTQQ1pt8Et2IkeeQO6FF16Iycg3VXNpOmmGyw5BA80YMWJE6u4t2g7wkhhG
EWR2NDFnzhwGrOf0LwYLrGYiGc1QW65lZWWexZBCeKkBWw+h8u+9CsqgfAx2
jEhRUZH2EIGyaPF4wjx07ty58LHHHntsyJAh4JhgXz9BfUtKSsA3ym9epzHh
VNAeGJq4K9AH/sDiFJqWhytWrIBF0Lnr16+HvtLFpOEt6K6ogk3kqBq2SY0D
PCqKAUBdWVlJyYOG9SLInrmxolUdGgSkMgWj5Fjt0tJSLDg9okumNAh/YNGG
DRtGa2AsmKTHer2ghJ988gmoi0ml1jNnzmR27InbJdG6B3QRFqTWiNUZ8Vh6
JHrpRp1Ly9Bi6GfS65QZFYJwxpYnKh9++CH2LuOZN/ghdD0j69tKaVKHwEFD
+0OY+/Xrd80112Q56dqyRA7FQ11JmeXGIkQuo4sY2lmzgyi9gcg5VxuyEzmt
yGV0T52RyGmcMgSy7O2SErRkvmbGJtM9GjDW8S9fBygyEjl5gGkpIgcRhY5m
6YLsRI5xffXVVz/66KNNbWFz2c6lGYicBhTYBTfLYqqAhZdeeonhnzF/OIk/
PCXIAMGAh0T3ucAEqEhVVZUfmfnEuHHjjD8iDyZgvxjjffr0GTp06IIFC2yo
sd/CZNAaWDpYFsQJ+DJgS2mpC6yMHGgHAyx6nQKAt5AisyYA91i+fDm8TlH8
eEhvkobKwqz4iZYkc+gu6AemCWxtIsev2BFoIT/97ne/w05BiiBackAn3dCy
J2TD7E7STfy3f//+jvsOXqRJsSCPP/64NlwMvAN9r732Gi1JaeGudhRIeyWN
FqAYlJZGGDNmjNzqxra2oXMbNmyoqKigplQzNpnWEuvq6jAWjrUyC24QuaRI
iLxOqWg9Oivj1TO6GOtGHVMNEwUjGX3dDPuqQahCfK5JYz6azegePXpgylPT
tyyRg5CgyahxrPI4kp3IMRFDIfk3+hMwOGjQILL6YkQOeGncrVUNkEmTJmV0
dAbh0dxQ/9U91lgiB9+bMWNGloPHLU7kIF1MZrOQ+exEDvQ766yz4PNb5EY1
l1y2VJxYq00ngCRomcWjiC5XZgxTjhGU89VYrBBAMYgY9cCUc2+R//IthjkW
3LOaB7pCJ6A0Yh1JRcJewItKSkp0ait25PIVmhp4v++++yA5UCP79IgOBxYV
FT3xxBMAu3NghtICNeQPEdJbhdCrFaSrU6dOuuhBGlk62llu6EC8pUuXBuEi
wNixY80WpE3kgvDkz4ABAygexYbRYaqwbps3bwafoaMyhfwKzpObCYLGk9Wr
V2OsIWbkbzY3g3B1DjoHn+zcuTOUlVIZfNY+MvnIo4jOQpv2txkdvYMhgOuS
EuIRe2PUpMc4apVSLR/tJp6A0jQCxj1KxigDplyXW2P7l9fFijOuZVFN+Ab0
LJUeUGCy1bXuLDlvpUDkMO50PQWjm5puxwd7BxVfuHDhNr61imbKnWAW05yd
yDF+zTzIEaYzaLU9r9QEJyOR69u3byMSuaBhEJlDwqnCiLYZl4fIATipV8Il
2wKRy+gQOJXIFRqiiYGBvXr1yugrJpdcvrD84x//wFZioZg5Ju0rNYoAp6tW
rQIwU/0vwRYUKSA1z0LoeXXJkiWkjy28BtSGDRsUxzD4vH1ncGntK2mdTRtq
zKeUv6cYtB7JIBJ24BizXhSEZp1vgavQHowLiG2DnkgghYTC8WsUoOgmuBn5
gyF68X+HQqX69esneqzWWLx4MUySPyjGe++9xxd1e1Q8x1yKdIgc3IzvAsjk
iTLwk65y0GWgq86rqzH5Fk90ucws7mGF4YG6yhdY5Eon5TCR/fv3B/yxXDag
aeWNduvduzdoL1cq0ebVRQ/SyBGKadtoSkwJPA1aLn5ic0IJ5UFbqGn0cqjC
X4L5HiSHTGJt4dhJCWyhpsxH+JZ/X0nKQ4Mr26YbgEbQB+hut27d0Hy6rNFP
5ZmW50OjR49GW1KJxLZA5EjcuESOfmfaxYCNMpMobWNYMRBil+8c0a3VxiVy
QdhrOZHLGKIry4qc8BlIqa6u9of/ziWXrRfdWkUtUeMmnZ4XwhAPaLV/1qlt
stLSUq1H+ctTCG+DKjR2kOwHmAkRbEf4YGcIA2HKXFdXFyQckqcMUDhMjMfH
BT/RgJjFiRMnGmCxU2Iogf1Ro0aB6kCK41KJUkG3+GngwIGM+th1PC0WUQxz
0l75w4uqqqpk1ESraGFMp1jKZ599BpEAyYOQKNIItbW1Zg/UIXL819CbP/zh
D3ChZcuWQUUoHuBGK5nlQUpISjihrgaoJCSDEvBpvmgcbtiNQBXQsfLycoyF
WYgwCfgihenTp8/UqVOjWxtKg9pgPqgOfDhJKwphbCyKB1tLmgKj5JgAmxMa
ofWouOe08+bNm59++uk5c+ZkJD90DWX2X0UshN5RsIPy/98MRA5TRecah8BN
8UXD5WhqhnzqDZE2SeTQWLQldrMD/YTIGdqGrqJ4sa6Do9JERA7JiVwjErkg
tK1gWmrgmFxy2XrR1mpT31qVyOWsdvqShpV4UVIsVEcKoeuMsrIy+d+IFXlF
i27pAhfQmKFDh8aOMnLG0C9YsIAEsYZY5QdJQGDSOPFizHoUsPDss8/ec889
Ckht/yq3upi5hx56CLC1fzWLXSKBkEm+YoJWaIOYUmHRwBPDWBS3Ai6kJx9+
+GFlZaW4GewL26H91kLc1qo8KpNGBSBbGk1HtnSll3dpMZWNomIfIa6OLw64
gWKq8tHY/lXQ0kGDBmGzyNZeNKPMMCh46ZAhQ4Bohw0qDQ8B8OLi4sWLFwvt
Y+PqohIU3viFcxIUQscgFCN6SIyxABHl60mmn+eQbYx+Fl+gyOrVq+l346Ym
VlCzmTNnkmejECp7LZTSamE2+Hwj6LKDrkw26cQtCD0DK56UP7GMOGQgtTwi
chnj3m6zRA4FdogcIwIOk8WTJ4VsdPcjiLzDZfSW4xA5hgNkib7eGiKn079t
iciBnz169DB7KLnk0nTSPLdWzbdAFRA7yYIUwqhMixYt0pXVLIKVHD16tOe6
4nvvvVdaWhod8joAJrdyUQFagUp4hcZ1NGdRKco5ZcoUZ0QrMRUBrhXKyt4Q
lPB1SBekBUSKuj1XGnAACIKMwQeM1xH9waexJnZgKQpMP5oCA8vz58/n0/Il
DmuCp9kU2iFyulbM58SfoWTYIHnQRcAiyIa9HkjZ5JNTNNi0jxzNwU7JzVny
MrQK04Z5he9hjp2m020LPg2km5jUNpfjXxJQciwvn7Z/smXNmjXU3fiXsxOI
okOMqayoqf0i+knmmOAk2IdtQpU9nutsYRJBa9AUHiSH9EL2PBc6tkiUCT01
duzYG2+88dprr9XtSHt9kq6nZzOa7K0UWpi+pjBJNlcFRp0mTJhAO6QacQpP
+7cBIgcM2kSOGQTDPEsckLVr19KnGW8lZD8jBwqROGO2DpEjf961XQQb2aIV
Oe31p7LZ1kLkABnm4B4wySWXxpLmJHJByLsgG9jiJN2G4TBIPStstvzrX/9a
tmyZInPFZgifAccYng7CyIPHxIkTky45UkLjwThqhQvhNvHAgQOBdAM7pgB6
nSEMn4keetGhvuHDh0PkDGg4bIQvYnyheVhAbTWaZbpCeKQKbMQW2+WBesFX
5X6E/0IPKioqzPYZYAKgaXUulshpQQwTqSJRKazqpEmTtN+HfYEHgodmGS0I
VwZAKuxRdOOM79J6FNI5HmZXE5NB+1DB6OvaCIbpkX8sVn/00Uc0L8VLuuZJ
+fk6aXQ6xWlbtQ99F1UzmgUjJZ6QtKhIKymORuynbdE27sKFC5P4CYXBIpBh
Fk+wqaICo5k333zzDg2y0047/eIXv7D1EI2qqam56667evfuzaSpqT3XQVoG
DBiQRL1UZqg1syoFgPPnBt9AkxV2JPXTbZLIoboMxowXnLOvyBW+6Bk59SDv
2vdYjWQncnT9bbfdRtumxvNqFUQO03Pfffcx9jW+ci6XSxOJiAGjhiEJv0Lf
mmEF+LPPPsMIQhKSEig+e8ZARZg/ACTp8DnVkQeA6KknOeTUmZzoENOZtJkz
Z0bzFDgw5IcNG8anbeDST1AIhjmcCkQyB95MUEuwfcKECb169YpSCLPaps3l
J554wmaJQQOfpMpTpkwB9u3OolXnzZtXW1urh3LEZ07EiaSVlZXZGOUQObUJ
tRatEjMEro3XNXgXNvG1116zmwuaB0rTUFFMgy1MnjxZl1aSOA/2Zf78+f36
9eND0eOFaAJmSLvD0aigH3zwwbhx42B6ouLRdTkaiikDCWJJFJ/Wul90SZAi
UaOkq6b0CKWNvfcaFYr07LPPikvEIjlfx3YoakZqblmE8qM2J5544imnnAKX
pgtOP/30iy++2HZnhxqgPyg/cxn+bupRz2iCtPgvhtM+NDvWOdXgUlpUnVbN
srvdVokcpdUMK1Wa57IDQk1pma1ZkeNdTW9TPXW0CiK3dOlSZvr+YxW55LJF
8q9//QuUYJxWV1dDbAxNEpHDWCvQZ8YzsVsjjH1KAomKHa0FK1xUltzWrVvH
YEmK/4JxXLlyJVDmTPF4DpD26dMnaj21xQBOjhw5MnbOqxKWlJTQjNGlDAXJ
Imfgy7GPQDQPIXgYrFirXWg4BobJ6969O0bWbAsajodpoDpAk+1+TXdveW5A
WCTNbKTyacAc5mkXOErkFJLV7PFBVDBYWEwTCmHFihWokB3+oBDusdIUpHSO
GhbCGxBMSEeNGrVs2bLYZR9VjWKXl5f3799/1apV9oVftSdFoovr6upMMQwg
//nPf6Y8WJDoNQERPzJE4e2lS1v4FaqjNUxbwF4Inr1t7QgzEZqFj6aeMeNX
DNPYsWN1ITeaWPFn/ZGhtki02Ei94OR08YIFC77//e//x3/8B5Mdu92a1CGw
Ux76VIclPHf30GdalabQkq8nQ/mmzniAvA0TuSzuzoJWReQQsMKOF5MkLU7k
ADT6y68tWBCwK7/mkEtjiS4MHnroodpq+fKXv/zDH/7QnJCx/cjF2ppGFGUO
SQOHGeDRBKJeGN8s0225qIX1JQ18TC2AA11xygB+YlsVs8C5oQA0UYBOnTrF
Oi4uhE48+vXrN3ny5Og9VnnJADnFQm0rr1j2ZWVlxmRH27kQHh7j9QkTJpjt
VPMJBDs4YsSImpoahxTxvKKiAmBRYn4FZwYMGKAjZPo65mzKlCn2W1EiB1PC
kvKu2TFRfA01hRYb+QocxhgR5Q/0wXzsw9t2sZkgUHfgNNqnJo3CkNE+TqQt
CYWEG1OSqOMaakHd6U1FkXAypynkACSW6pPbvFCcbOESWCUIeeyam5j8Cy+8
kCWUD4kh5OZMnVNC2hOLTJtn9DC8pUKtmRHsvffet99+u30iTkQu46L31ojp
wQ8//BAN8exH50Su1RE52qHRiRwTuqYgcozWLEQOLc1I5IDoWEAzgglgsm8H
v8gll60UYAfucdBBBxUVFTE1/vnPf37UUUeBmfpVZ+Sa09GNAkiBRVElB8/5
CcOXekwiCIkHeIjBTUI/KmUiv5tRrFChY8aM0b1Ie3QXwjsIIBLgH0u0oMTQ
GPKMlhygYN5HYRxWwFvYTWpkoqBGRYCzYcOGIUOGAO+m7sYOBiG7eP7552Es
dv7y0gYfGz16tHkOhoDedLpJBkDBAJ3NXIfIaeUE+46GoBL6rioF4zUtjFWa
OHEiKOosKsLWoGHgWywIY7BAfjn+LUTE1AU9JPO6urpoJtiIyspKSJfhz/an
4ai6FxklS/o0VeDF6P4sSGsvUEvkUI6uTPL/pmNyxutLbBrTqtBgKG7s+p4i
22rhtFHEblLsUf/+/du1a3f++efrtrJJRr2oIHVH2+kR/kW7kjZ/G0XQKBqB
QRdlSoWG5V/6SETOn1VO5FqWyKm/0FsdPzA6s/VEjqzAkEbfWqWzdL8+9QgB
GYKxWfasR40aBTAmuTtQjAxaPr/mkEsjCpNxRlNVVRUGHW5z3333dejQQYa+
EN4Sbc7LDkE4DBnyjIXo/ilDAzwH07KcJNfFz2joTAnm+M033xw2bJgzfk2A
iei4FseDMMQiibZcY/2iKKYYg9ec1zI1xY7Dn6urq6MMxC7qmjVr4Fq2LxGJ
YIH8Aa7JkycLkAVQ8kOyatWq3r17G5zkCVkNHjzY3hdWGRyDEl2RQ/iKQM88
ga6gKvaFC1oPwhY1T++99x5klR6xq2CoBZ+jgkwoSOZQOFvWr1/PTNZZk7Tz
Z3JNczk5oAnQVNQ7StWCcB8Eax57WIWGVUgF5Wmer127FkhPCozOFIAMMU9Z
DrZBUWhS+L9TMP6GM2sDNDWT7KKv0HqlpaXt27cXi3Oai19hEQ888EDnzp27
dOnyyCOPaK24SY3O8uXLGfKwx9hfFTCXjqA1/MXIidy2sCKHUtXW1tqdtfVE
DtS98847AaXGvewA4URbstAzqg+MG8dHHsEKoKtJGqgowzRRk/plzWW7FYYz
EHTUUUddfvnlZp2q+VfkgnBNQFf/nOcMNwxoljBeQUMow6QdLpgMQ1gLjwVr
OQ6qAE+IvWVPI4wePRp8iHI8bbl269Yt6kaVMlMMcMwheKKFQ4YMAaIdnmCL
YjGQzDBSx9xTkSlTpmCXDW7Yqy7gHgUuNByiwxLNmDHDuJILGi7YRiNTRIkc
OfBfKmIf2cIYAYOU0KRBYWhVc8sgsNgaZInEDjkMGnaZSc8X7bN8USk0LIoy
73AOcZEJzP+1115bsWKFs26jeA20krP6alq4rq6OMkeBtxA64zXLtkYwEEC6
uXHmfAshw7Fjx6buThbCWBvawHXaX7cvY5Vta6QQrgBjR9q1a3fEEUf07NmT
T8P2bfOE2mDcob5U87NQsKGpfj+2UmgHZiJY/yQzzXyTUqUSCRE5uEFTELnG
jbXaJomcBhflp2qNS+RIAwySc2ojfLEzcqkDTZfItp7IgeRkBVjlLC6XRhf0
EyAF24888kiUMLBurYLz2G7UknEBpDfD3VU5PausrHTWqXR8LsvpI7CXYpND
EkTAXgYNGmQT1ELo9LK+vh4iJ+9qdnrt6j7zzDOxoLdx40aolOEzRmgxhSSw
V7EK4Vk7asEroGjScJbL1kWLFsEPY9cVC+HhMSCre/fuYp52VpQTxgudsH3o
Uc5Ro0bZTIz2AWMVx9N+PXZFTqcHSWyn5CtYLrPEx0/03ciRIw0JsWktn544
cSLsyNGiQoNvPd7iE2vWrIkNrirhWzU1NWVlZWah2CRYt24dZBtD5vi5VbhS
us/cibAzhFHDDKPdF4TsHS2C8zv8GfCnDHKUHe1BOpdfs+yKUs4333yTlLZe
keGyZcsYj41+44Cc4dgnnXSSHI/ssssuO++88zHHHGOfB0BX4b3Nc9nBFoYe
DFP3Z6NNKiKXujWgW6t0dBYmA5ig/P7gekHYR0x/0KssGxM5kQvCEGMMt0Yn
cvD8WB8mjjTRZQc4P6qVSuTIB/RDYWKJHECE3Um63pVLLlsjDGRGU/v27Q8/
/HAmC8bI/u8woDyjEpsCkrz00kvNpoGgHB/VVouGmCJMgW9ZwESUDM4QxNlZ
oABqVFxcbAcIIH/oEMjmnBbTT1rfi3oF4Sfg4oUXXnj22Wdti6DFzLq6OmaR
5qqIeQWi0qVLF/DWJI7WAgJGy0NXkhZ2+BzdMXjwYHlxt5mY2NTAgQN16VI/
kSGEAXpm+x8m8/79+0evlsQSOYSHwKl9Eo9O4YmCPpiCUTUeyvDZdpmf5syZ
A5lcu3at/ZNZtUO7SDBgwACqFrsTKpHPCiiWjJ1dcfpo3LhxsG4Tc1aZYNoo
PFAcNQTyboF6R5Gfn3SDw7Y15IZV5aEJQ+a8paN3qQELTIEplX2QgI/SgE1x
qY3mxcbdcsstF4dyYSg33XSTvB8rjeMQuBnWDfQJOgjFQG1iz+NlJHK8iGrR
Zfb1jSRhRHt8EduiUAtSWr/kRC5oMiLXsiG6IHI0bCqRw/QMHz4cPIm9owTB
A7Ez+lXOJZfsAp6AElC4vfba6/bbb8emYJSNWWnOEF1GCuEVSFgEI9dgl4Ip
mPNR/tcpf01NjVladBJ8+umnr776qrkCGTSskkF74F069+4UBuIHbXD2QEU8
3nzzzYqKCuf8jEIhlJeXOzFhyRlzAMUy10hjnVTAlCCi3bt3j90NVP5Y2969
e9tOiU2yzZs3Y02ovlmYIsGf//xnYMTeouVXqgxrilq9JCLHRyFa9pESOggk
fP75522Ig4Hw9eiOYRByOWwHLChqlNUUVA1DYBLEAqy2YhV/wVlkox8poYk+
ZtKTOW1FC8TeON6wYQNfNHG7bIGpguGOtgDXtDD2IpZqUqSFCxdSzSwXTlUq
u7R0h9y4Nfrqt5SZQU0J/5clPLSVp7q6Gih4/PHHPfHIGrdUQdj7NDLMKqp1
QdgmixYtykLkSIkZ3ZgWvzUI+RI19ZMu9S8zSnQgJ3Itu7Xa4kQuy9YqLc9k
hEEdXfEANPr168cELfW+Ri65bKlAKjp27Kitlq997Wt77LHHiSeeaOJTN/9l
B4kAmRFhDJx8j0ycODHVuhVCd7XFxcWxDrhMmCdnpQtcnTJlitbcnEGtGKBR
l2KF0OkHU3X7kLY4Ay02ZswYe53KFIwZGUwjGv4paMAWago5LCkpiX7RCPg/
atQomIzzehA2FN/t06ePTbfkTY6iGngphB7koC7AY/QUdxKRYy5J4YFT+6Og
MQRblNJUqq6urqqqShFLnZpC80iv7xYsMSkpLbYYMia3dU4aI7o2C2Kb7WMJ
AE5/8QnnYqmW12BN0cNONBo6H/V3F4SnDmgKzI25S6J/dXc11p0g5adhaYEs
FoquxO7Q1yo872IHscVZTmQ1hVBmmhQSDuOVN7xm+zSfKysri71PxMChg7IQ
JHCDaVoWIge1UKS21JQiclkc+m3nRE5CCzAPZeC0CJELwmtZtFgqkeNfiFys
x3JH+ChqCSiltpXCyTGcbSKnQURTg+q5E+BcmkIw7syCR4wYAYSWhsITc3mw
pYhc0BDlgSGpE2v8d8GCBUnRFhwB9uE50QNRokkrVqyAYzjGgldiHREDnvAi
0kdnWAAFIADbdACKsayIBvYrhfCgPmOcdvagQSF0rSZHTEkJMPEQGCyLE95F
XQYH4ysksN/iFdAVLLLzUZPSwkGkSZOInE7lOZuGJCZzOsuUR5lPnjwZAI+t
LK2NytFK5pKpU0eeT5s2DW0kZSyLk9BWcPuXXnpJV8DMCiddoIse5rijfgVF
SU/5owuhEF1KC4UOIjqzaNEiOLNjbiAMDqe1BQqKAmQ5aUbr0VnLli2TFlFy
epYapSp5E0lzOgR2pBDeemYYRikTzIRhyKDwEEt1MRQu44ocfYeSZCFdOZHb
IiIn14j2/kVzEjkSwM+ZRmU5z8ZcDJVLPcOAXSgvL7fP7iYJ4xcD+tZbb9nB
GTW77NatG5W1+W0uuTS1FBrOnzf/rVVTgA/CQEvCZAbCwoULdZrLMxC00ATw
woWCyFH5QrgpxhiHY9gW4Z///CevONRLQt0x/bLvtigIRUVFheMmRcFSGfUO
jPBfrDOEMBp91fkcgGmCokYTQMngD9ROa0EOIaGVoBzV1dU6xmY4DLyid+/e
zq6iQtvH+l5OInK0HlikFUXzEHCDYIPeTjwsWNOYMWPMUUBbxKn4hE5dRolc
EEI3LV9TU+McMnRSKuQZaGzTyEJ44ZTXzXaYKRW9w3ejKk2NqALGIhqEAg3E
OtsnNoOQ8EA1kwLAYaZpE3NUzyNyXIOl1iQCJSdbDHESd21qaTaHwLGiQxFm
R8AIDUKp6M3U9kSvUAYtBfslJ3JNGtmhpYgcKDRy5Eiwy5+yEB6nKS4uBht1
2dyTGPQG0umCVCKHAkMjUUInJUDRq1cvKXBO5HJpdPHbC6wMY+2VV17BljVW
wMfsIj8P8rIFhowdO1br0v6BsHnz5tmzZ8fyk6BhnxQLaz8E92Bx0Z1Q6BBM
A14E03MWvmBBzOZ0hdP+CQsybNgw54AWmAY3A4j8wcUUnYEqx/4KAuiCw/Dh
w+1bovaH3n//fQDHIWAUHrgeNWqUfRSqEHrUxzzFnrxNInJAH/b0xRdfdLAX
gBV620Wi1mjOlClTkpgYpYKoJ3GGQnhDYcKECRCbaNQGu0jY/T59+tAy9nOs
HiYVSN/YEB9Wz2k67BecLWoWZdmj16JJCT12eL7OMdJZsdN5XnkhlFRXugC+
uWiJevAh7HgLQj1Ebv78+fQyOoCJb86t1SDsJnRm0KBBcCd7ZGVZkZMoVmyS
A0lb6GiwJWnp2xYKgxpncaaXE7ng8yG61GLNSeT++te/jh49mpSpqsJw7tGj
h4NascIkizyzrMjR/sCCc+ICrGAeDWw2Q5jLXHKJCkQOEANYAJzmJ3JmUY5R
DIWD5Di3FGMFMgOVit1bEdGqrKy03VXpmgMW3wZVbdKBCdhiLHjw+XBdCjRf
UVHhDFiMYE1NDYDjbKrqVJ4H3gthoAQwjcomkZZCuOtK/kkclRygAVAU57l8
IzveMFSFkpKSWGeYSUSuEIYopUHoF3vHUzuhvGKHeS2E8c6oOMQgCoDit3V1
dbRwrA83CR8iB8xN0nVp8W0qjql16qKwDnzdBn/6EcpHUaMaglbIu6BjMbWk
Se84S5rYVtJHD72o5BQJ2xcNEeII5cHyyrUURcUINvPdIkdEnu+7775+/fot
WrSoOUe9WYllMDIQ7NmTIXKpVAodgPYk+Ra2JfsZOUacE0fYk2dO5JxYq6gQ
ww3gbWYil0q6yKpXr15ZOguAKisrs8M9Jwntzyh27AJQAGNsqVXuXHJhjK9d
u9azt9WkUgiPWslTGbMhxU3wLyGKlVVVVcWedNW+qhNXlDoy9Kqrqx33cfLZ
C3uM0gy5Jn7llVeCzy9Avfnmm9ggZxQDLJAcBfZK2h8E6yBa8E9hWjSZmJ78
kMe6BIcPyMOwQ0ephby3OfSA0mLsaNJYYPQQOZjVrFmzaGTHPQhGf+zYsTYq
igxjVngevRirFymVQhNGjZThcti10tLSJPqqfKDQEELa0KHQqA0VcVZdUAMS
v/TSS86tUtLThhA5h+PxXN6VFXjLiNk/jaWpKAOfyBKaYfny5czWwXmdP2xZ
H1PUlK6ENtBKTRqZKyrqbnSGfhwzZgzqZxSMEQeRA4sakcgxrunr2Phojnz0
0Ufkqas3/pQ5kQsiRA4opp2ZVUWXyLaIyAEULUXkqDiATxVSFUBEzr49oVAO
Oh2X+qFccmkKsS87tMh2j65bwgSwccBOahnk+WHy5MmxoMd4hJg50P3JJ5/U
1tbKH4gNNYw7qBrwFS3SW2+9NWjQIOdSJCabCT7m21gfbYZigGBonvO08kky
fPjw6MEeQ2boiHnz5pWUlCStkMAe5eA0GnQM+helqdQOwIdexubmIXLUGlAC
rBy+wXO+Atw5zngpGN0BksfudPAQIlRTU6NvxXJdiCuv00c62JZEhqHo5OOs
j9FuNAulcjgbswNIbNQRHLWgudAQpxaok+K22xME8iRnE0LXKRiQPnXq1CyM
4v3331c4DJS8xS+12Zcd/JOmphN0BiI3btw4nRvkvwzDrl27MrRT98uyEzkU
mD7NQuQYvJBbRn1qa6BR6BssIrXpth8iR+sx39lKIkdD0SZZHAJnJHKa5Hbv
3j3LkiyjMrrOFisffvhhcXFxfX29ufGNggE12sJIfT2XXJpCWvDWqhHB+KOP
PurEFIgVrZWJlTnCu8Bs//797Q04PSwrK4uu4K1btw4CFq07CKzz2KYwhfCG
xbJly3hu9hZ1gHZjGPTBbyxAbMwWPC32V61RgAOgQZInSa1DRgPUFsJTc1VV
VVrVt4GUjwKMsT67Ai+Ro6aAPxYQzmx3B2WAstLy0UCokFsntpctig2nuxJJ
/Qs4kwM9S+IkE4m9gJeSzJn5vv3221gWezmFPxRHVY5wnWVYvkKLOQ4Ag3Aj
FaNjX+fkV4wmyqllNztxoSHuxoIFC4K0SZAs3RNPPGE75m0pgcihyaaaLWJ9
+CiKVFRUBKVhXHTs2PGxxx4bOnQo7Z8aajM7kWNOlJHIoZnovFzEeMochK1H
nmvWrMmJXOMSOVJC7E2beCT7ihzdOmTIkFjHko4A43Srv1VVO4CavuvcufPt
t9/O1BJ96Nu370svvZSqt7nk0nQiIsf4bcHZhA413XLLLbFBlBzB/oIMsavl
unEwYcIEe0xps9UsTJlqmmsOzgqYLquWl5c7nIr/jhw5UkeszZ6jDq1NmTLF
c9DIxNLyHI3TTVUdto/tCCWg4mYFz1SZImk5zqngxjBcV9JxLA+Ro3aAP6Ta
3FE1vzJvpZC0j2PFjH/gpP1T0K+yshK0j8VepYEH0pIeA60N0GeffZb2tPPR
STw4kr0oWgjDYAG5zq6rqC8GbuHChU7tUC3sKaTU2KNCGEEDjVq+fHkQIXKo
itzWpRpKUmLTIfyeJcdmE9qQzsJo6opTSxFLBiYN+9Of/hQ7uGjRImZzinax
jRM5yqnbtdEwf45sEZGDCUAOsxO5LFHgg9ZG5ECkLAcVshM5ioSqZ8kzC5FT
d4O3TN/o3BUrVvTs2fOKK67o379/Fv6ZSy5NJ8ApIx1EXbJkSQv6owYKgDLw
wV5UccapOAZWOOm4OBjLEAO3bYBlLEOiootFICHgE6WOPJfroeDzrA/0dnzN
6Ygd7M5zU9XcOEjaUCuEx+coc79+/bSTG7UOivmFvYvWAoyaOnWqc0VXAjTR
rUmhB5KInASwonGikUbJDVMr6uKUk2pCpfioQzWNvPXWW3xRVYi9oa+jUwZ4
k6zkggULICFmZ1APYWtwdXPmSs/lNxgC7GRVCC9Owv2cclKA+vp6VMj2T0gm
WMPYkJ06HzhmzBj/IWfyoSUh/M6t25YSrBVkeOjQodDmWAf1HjEtRt3RAUyq
4wYnCHWe4Wx706I9GZtRlgIZu//+++lNXlFwtyxEjszpO4ZMasm1Xd5YRE4C
PkA7s5yKR40nT57MBDCaJ0VCbQzHozHpEaidc5YjVuBaNTU1GRlXRiKnKZL2
B7Nk20RETmG//OUMws7KeMOUeRPgn6WtAC6AJZUea3qIyFYypb377rvRMRM0
XCVkUJCVfdSZBAwWBoV98Bj95CGt18w3x3Npe6IVOQMpLbhWwFASuIHP0J7Y
YSXvHCNGjIjlnLxrzmJJtM4DQDmbcYXwnilw5IzxQsM+rI0nhTBiaXl5uR2J
Vctx06ZNgywFn9/TtEX3FxSgIaltFdceKxb7axBa3okTJ4LJzvNCGHdy+PDh
0YaiWyFFWIek9RY/kYMmPffcczoNaH+Oar788suYpygy84TGJ8+kxUkMNO1A
i2ndLJbsYchgF3A5jzcSPkQ+mHIRA2VCNcmZJrLn1OA81oGGjTLt5cuX0y/2
dEDlwUZDCO0zz2QC66MlY53DoxjwkIULF0brQqfQO5SWn+CHCmmUVKnmFJ2R
W79+fRLlThV6ENL+s5/97Nxzz33wwQcVqszkRhvecMMNRUVFJNMdnzvvvPO8
887r1auXfSlVS5pM3xjOQBCqRTOidX4yUwh3tJlnwbfJ3194Ebks6/wZV+QK
4cEDelNeAf2JaRPoDUMsqsyQEIi0fWKWVqqtrc1ynZmZBXO6LNd7g2xErtDg
ZLvFV+QyEjmGM0Ru3bp1qfyH6oBIWVpVZ+RSy1kIw9wwz0UJ6dYhQ4ZUV1dH
1/Hg5Cg8YwRtoZBMWOgynlx77bU0suAaazVw4MCzzz77yiuvRJ9Rp5zO5fKF
xXYI3IIsTviMdR48eDCWcdSoUYqB4hRJ+6SMhWhRQZW3334bWmUfWCU9k18F
j7AT8y2sM19xrkCSXo7RAoubKbq9s7rFr2ApNkiWOnYMKp4sWGrHfnKEApBG
d0tjE+hDFDV6EFchYmkN232cRBtVSfdAgzQiB1QCUFEfeoXQQQoA5QQX00/g
FYY46ZhfIbwxGuvGzRYs77BhwxzfvI5g8aOLchQMDqaYFOYhik0taCWng3hO
BaMO/cB8OJvWcAwzwexSr1h3ZGAyRg2zHl0cUBdUVlbCe6k1s4AWPx0n2crL
DloPad++/Q4NctFFF9HsagE6F2vFw4cffpiUGMfzzz9fyXbaaaebb77ZsBd9
mlaiIxhcDD1KhSn3LAqpqIwmQIC+S3Whjxml97ME0aCoWmfzp9SvzCWxvBAq
f2LFFKZBokTu448/ZkQzZzRqKZXeIiKXmjLITOSCbWNrNZXISRhKVVVVDOHU
bqVIUZeYsbJ69Wq6IDVqnogc6IQFoXNLS0udrRZFiD7mmGNQeOwIJoP0p556
6o477qhR8OUvf3nMmDEU6Z577tljjz308Nhjj12wYEGWqxa55BIrjXXZwWy4
AMhYCgycE8GEUY+SM+R1toRfN4VisyNghIkq4BO74FZo8BEhryCOKOCCHVgh
aNg/dY7TkA9EBdSKLoJhRBibGG47MagLcNlBWhXOFfYF6/A0CK0KONu5RdP8
9re/LSkpiY2XpHbTmh72KAqSJnBD1Bxv3LgROuT5tJ/IkRugWltbG90O0zYQ
DRKlLopQFnXab/LkFUgg2XrOomD+qC/5J623FMKLDDArus+m+hT16aefRgFs
3EYZQPIZM2aYZUA9B4dhfZTEgW4ywe6Q3iZd9BHa4niTlqCosDgIW+yGIJlg
77p27YqqGDJfCN3r8V2zz6KhwajBRhsnq5RkcygmzmxSi22p0D7acMQUfoFw
QijV1Vdf/c1vfhO9xfzddtttRx55pJzCMVI6d+4s8/TYY49B6fnvbrvtdvvt
t6NOP/rRj44//nh5/7Y/SusNGTKE8QWRQydTsYiW5BXULAuVgp5hIpMOGBhB
PUAVCpClNSByJE6N+qSv00RRIveHP/xBccrM50g5fvz4LESO7zYukZNkJHIq
sOJlZHQ/krrKalJmXJEjJfWKPXzoCBpOwTJ+nW5N9R9CVzKWly9fDvYOGjSo
vr7eVi3QoHv37vvuu6/oGQjDrzD2gw8++M4772SaACYfdNBB9957b01NzVFH
HXX66adTvIEDB/JQEbpTy5lLLrHSiEQONQZgb7zxRoD9rLPOghHpliKjG32G
clx//fXAF2OB0Tp8+PCTTz6ZqQrDwex88ROky/Y66whEy5wtcSCXMcg02fa2
wXeZ/mOsbXSSGQVd5dLNzoSPAnrYFPvr8h3HRw2lIVseMvApuWeuR8Ni+jWW
k1pMawvl5eVJSEuadevWae/JqTKkiHoBko7rGP0BkSsuLlb4qljb5CdyQXiM
Z/LkybHLI/Ry0v0ykC0Wjc3qlr3klVRl+zJCVER+QEVmvs50mBfNXQzzUVJO
mzYteoyN53A2xyGMZty0jF1x1BjaQHmiS2oUhnygCkmagLGmGVesWGHYC//C
o2644QY0jZxpkOrq6ksuuYRZ/FVXXSXOCdEdOXLkmWee+d3vfrdXr14U/gss
nSWJHAI/8MADRUVFCqC2pa/DXWHatDZFffTRR4844oixY8dizRlrRx999F57
7bXnnnvynJa59dZb+S91QSUeeeSR4447buLEiU4zkqFckcCO6Hf/gq2mA4xT
SHsq6+BDb7zxBvQslcnouGN06T5WciKH/lAv049gLxM0eHuUyDHSGZJZrmZk
X5ED56lUFqdtfJ08sxA57E4WIgeYy6kR6iePB/bABHV/8IMfXH755dg15i8C
f2YoNCz5owb8cfjhh99xxx1wuXbt2jEG0YT58+cfe+yxHTt2HDBgQGo5c8kl
Vhjj77zzDuN36yPEgcDnnHPOfvvtd+21115wwQWHHXYYoA2aMd4XL16MVdp/
//379esHbgNZu++++wEHHEAy0oNL5tMMOmxE7EoXJdRZtai/XC2yYX/tkOjm
XqqzrPTXv/4V/qMjZ46/DuwRn7YzJ1vGoy4t2pdVgX1FZo+WU2lgAti1qB8z
uzoMfIZ2UvjyQrjdzIfkJ9nJh47DmsCHoy7OtBAE2Hp4ZiqRwwqTIPbmPlUD
HmOP7tOGNGxSDDK1DO1Gp5gYqdE0Cu0aexLPZEL14TxYXpuHAJvMamfNmmVW
dAthMGs6AmtiyKR+ohOxCNTC5hX8yiye9LYGyh8L7CV254WKQF9j1wf4NKyV
Imnvu9DgLfCiiy7acccdH3zwQQw3Kge2n3DCCYwaWNAZZ5yBcmLlech/jz/+
eAYIoyZ10ye70KoYuDVr1qBdSbekswiVgkufdtppZ599NpXCVF1xxRVUrWfP
nqeffjq0jWb5yU9+su+++1IdmqJ3796HHnponz59oqcNgY6BAwcOHTq0srLS
s8odNOi5cRTjL7yIHF2chcnQJnD1RidysVurrZrIUZ2SkhIa1gwccIy5Uuxe
Jywa8MzimgMil3qOVPmjIaBTrNd0RzAlmJ7U6uvWMAqQWk4QBuyaMmVKjx49
UAPnTAuKjQGic2FozGWcWTyzzksvvXTXXXel9W688cavf/3rJKPReOU7oZx3
3nn+r+eSS5KgumAIRh+F35o9evLBAJ100km33347hh4AwQAB3ZhUhvnNN9+8
ww47wNz69++/fv16TNi3vvWtqqoqWAqTEeifWWRT/ILS0lKhvbMGpVNw0a+T
DGTDFtixyLUpCRtx8gGsKJ4zTSNzWKKzYo8FZ3QPGjTInqnJg3FNTU3s6XfT
GlSNWniWOwBk0sCIks64FsIbGYx6eSpzhJqCe7GtQbFXrFgB2sQGv5CkEjkS
JAW0BRghWuJLzkoR6ArhodmjrkuM0MKYjLq6Os/h3g/C6BJmbS0qPMdAaF3I
/hAVhzs55/SWLFmCoXGWEOka7bo6+/j0C4mdMF40FKQldn0SKMYKRItaCCNW
0MhGoxhfmOB99tlHOy8PPfQQGRYVFcGFIDAoMGPnqKOO6tat2/XXX888aMyY
MXwUUnTZZZdphuIX9YXtO8WsAdrJnDNyqdlGvxKEo4DWY3YGN2M2wRjv3Lnz
McccQ0WwX9TovvvuIwFEbu+992byhSpC4UCAxx57LLpCQlOjM126dIEEOsE1
YuWtt96ij5JmQEYoJF2PImVZkwEGs7gjDhrOyGUhcoxcihpdk2+9RE4FoLPo
cdNWkLqk/VMGqU6UpWZLWzFy/efZDJFjOPi3y5VSAYNS15ypEfMpRqsnT2VI
HYuLizFntFXS3AplxsB94xvfsInc73//+9tuuw3ydtNNN2FoOnbsuPvuu4vI
0XqwOIYJo8NfzlxySRL71moh4dB+FtHpOMYs6ISGw2FE2zZv3lxbW8vf7dq1
499+/foB1CeffPLRRx8NGELMLrjggrPOOsumT2I4jEHHypAt1j92x42ZERbc
LLIB4PzL2Jk8ebKzU8NPYCCzKmfM0g5wNpDEXqOQZ2Db+XChwecbxUtqCq3q
UBjPclwQcpURI0Z4nFVqPQFDH53RF8LbtcYvmSPQTlpJy2JJX08lcjr9FbsH
StuCz7SViI39iUIY6xZ2BH4mrfHqELjfvxPdpFBrnti79A40GFQ3y5WFMOLb
9OnTneNzugxLhk5WOpQl42Weg8Oon2NT4AxwqtjD8GQO4yUrZzGH53QBDWXs
CHVB/++66y4I24EHHgiM8wke0guffPIJswPm6ccff/zPfvazU0455YQTTkDH
GFCXX375j370I60Jp4qKxwjSOSLMk0yeXWybyCW1rf8T1LS+vv773/8+LA67
piVuSk6lLrnkkvPOOw8rduSRR1511VU8hLhC5CCxXbt2pVKKUxz9KJkwZ7ny
yitRjNQyoPxweHmb8ReVEUQXp1K+ILxugIZkiTxL25IydRsO/UcVmfJELX5r
J3JUyt5I9RM5kDmVyAlS0NUs9zKyEDkJozgLkdOiPbVI9eMHXDPJGjhwID2Y
pHvAtUPkSMyo58ktt9zCMKeyTFj23XdfkvETcw2GCTSPmU5qjXLJJVYYYu+8
8465tfqF91kU5iAIWQQKDIyfdNJJ2Atmr+eff/4111zTo0cPuBzUDmD57ne/
e/rpp6PDsCzMAfMR49lDZFI3EJ0FkE2bNjHHj3UFLA8eYlxmB40hU1ZWZjup
CMIxqyUjm7IWwhsNhtiYdYwNGzY4a3S8RZnJVkfxY5uLFgDn5RMvdkkkaHDg
MG7cOE+TYtyplO3zxAjmBiiDZEZ/KoQ3AbGG/i2qVCKHYsDHoCKxdy0/aIjH
Gq2awlpNmzZNK12xTWSTnySVA4FHjhypne7YNDwkBxiac/4NBZs4ceJGK5qq
uBlfdIyvc0fVZIulRv3s43OitcZhlC3kiQUkH/snGg0dQM3sRVESYNNpWNK3
b98eImcufdAdvXr1YqYD1GPiv/e971144YWLFy+GyP3kJz/JTuSCcEpSUVFx
2GGHad3v1FNPVfRek4DBQs/C8ehc+jHLZqItNCYvnnvuubvuuuull14K/aDB
R40aBUkz91h3DIUnZ5xxxn777detWzcaGRBg+haNMWf6F62g45L25W2hCrRt
7KlFJ1vADUXNQuRo7SjmxArfpUmzxFZ45ZVXaOroCbEokaMNsxM5LH6jEzk6
BTKTdOXcKUB2IsdQyk7kyCcjkQO4Uokc/I0agZ9ZiByKx9dTaTxdNnjwYPl+
yUjkQKdbb73161//+jHHHMPUG33Q5f1vf/vbP/7xj2kcxs43v/nNJ554InZ7
JZdcsggDB7XcevcjImAKxvStb30LzaysrCRbVPqoo46aPHnysGHDmJs/9NBD
6PApp5zCHAQrjLG+4IILMFsOgMgBr4nRoIJhWOGBsXGgGCz8ZHMehiTIQBmc
lLCjqVOn2htVWmFgcBUXFxvfUIXw7gaIjfW37Q5ghSXS2k5sIwThoSmmbNGw
qsHnSWZRUZEHNuUEmIEfu4MD8tSFEvsuRG7BggWxBTCSSuR03gyrGrseSDNi
SbF98priaA4tD0f1hzicP38+1jC6gW6EToEd0drGR1k0jRblyMr+FbsJhDoB
0VBynpjFN9PL9fX1cDyHD0AC0VhzBlLpUQZSOqtbEuYXlNMsvGgKIEd80drx
Lczr4YcfboicWByE55xzzqFP+Qoj4rTTTtOF68suu+yHP/whw8HTmEZEbi++
+OIOHTp07dr1/vvvP/jgg++99157W5mPUraSkhLmGllCWzrCKLviiit2+Lzc
c889UCAUD4oFITnuuON4gnrTgyeffPKuoUDtzjvvvNT5BaZNJMEDR1SBgblo
0aJUFooSkjILkWNWgi4lHd20hckpCmbPFJJEZD6WyJWXl9tEjloPHz48SzkB
hE6dOpE+y+5Jdvcj0BiFs0m1AtmJHFlB4GmuLETO+GdLqVI43Kh+KpEjK3V9
qpJgPrp3727H+IsWL2hY9KCangwLof/Au+66C+aGktDyzEYZg/ZgYUQDWQzS
XXbZBb7Hv7vtthtg2LKBMnNp1SIit/UOgaXADBxwGyPFVAhtx5Ade+yxtg6j
3hdeeOF11113xBFHAJurV69man/WWWc5Vy+DkDKRQM489XzdunUQpOhlyUJ4
QA4YtM/4yX29E5JVvuYqKiqcHUn5Gca0BVbQAeBXs377Q+A8MzLPQX05nRsz
Zoxn50XbuJj+2JV8UWJeB69qamqiPuKChkupsd5FeJfeBGn91/NTiRzdB1qS
T+ztVEoFx5s1a1asjaAjqB2ExFMAwHP69OmOPzpbtEsrD2xJCRBmuLSSvTwC
86RsdL0N9dAMelNLiDYtpA3JwTGg8GQekoNZzpVJIgfpmN0j/I0ao2xmJ10n
JClD7JqkQ+Ro3r59+x5yyCHMaORYmE65/PLL27dvP2nSJKwb03YwP9b5SVR0
UxuGhvJgamkZ8rnppptsVq+tVS1jfoFFeIqH1bvhhhuut4QaSeELoTtBOKRm
YZBboODMM8/cd999L7nkEhrQb3/5FQqtQ3eeskEXMxI5GoGmYNSn0h50w3Si
X5inYKOTYrXY8sorryQROfmRMxUEkRxqlyQ0qVbksnRcdiIHAKJjWa6CZidy
5EaT0rCpK12K6oJqZVk8rKqqyuKVkdGXcc2ZZh80aBAjIjalqslPdBB0y3Pt
SBpLZaurq2+77Tb0E31GVe64444bQsHwXXvttf3790e9GSYMzP333/+oo46C
7KHSuUPgXLKIOTxmPwRs0ShUDioVu9qQURhW4NsZZ5yx8847Q9569uwJL2J0
o8aACdwJpd19992vvvpqkA0+ts8++3Ts2JFke+yxBzMUx81XELl9YJzrRqEG
ww3l0NKNeci7AwYMcA7IKewpLMsZsJ988olWJwLrxDhQCWLYC2LkD9Y5H7KF
F0EzOEAS95CQBnxL8tZbaNhcprJK43SK7oOMGDEiFnV1FwMz6oevVCKHwMOp
S+yyofYfabTYdQlKWFdXB83zzK8VKBwNSbozUgjvx0Fm5C02NkGhIUKHzXO0
KjVx4kTbKJPDlClTyMpZA4RH8dBZvpMzCvrIvrIBF4I8aEvL6RH0h8qqs3hX
hy3NZCFK5OBXhx122IMPPsjXR48e/c1vfnPXXXeFrWGgMRZY/y5dujCLv/32
2x966CE4nu1HN6Mwanr37n3ggQdCoubMmWMrA+pHc32xyA5avv7v//7v///z
YtxZmwTmCX/QPvQFfCbLt0gMyaH7PMqjcLHGC7FHRPmob2pK2LgJIecXOA8g
sJVErqysTPEs9ARtQRPUKf48dW2k0R0Cg97obZZwUdmJHI0Pi6ZqqXnS1wwZ
+wKFp6gKfJbqZoE5F9aH6X92IheboR4yiHr16pUlwGsh9AzJoFBK/mY+aA8Z
nqiawAs9DoLx0JxNyiWXWEE9mPiDjczNmRczfbb3vOR+BFBC07ZGkYCXcePG
6RMHHHDA3nvvzd/Dhg0ThjBOQeajjz66tLSUJ2vWrLn88su/9KUvfeUrX/n+
978fS2kKoa+GhQsXYsox6ApPz2CPFlKXIOwQq4wgpoEwSWdfUjuSYIuTw/vv
v+8EtafA9fX1zhk2mhFYhvQGcUuXhdCJK3Ux341NI8d0fM4T2ZaRDsiDQrH7
qpQNcIaWxB4aBxOoe+pxi1QiVwg9qEDkktLQ7LSktvyixYBMwq8wjp4yoHiQ
an8oTGxEbW1t7MFICfXVdqRtrXTPhR60CQYfQgnNSpRSmjuq9qKBoanmNkch
PHmItYo9s0dHUAZdLtbSH42WNJooEn136qmn9ujRg8JAtyBy+4Wy1157nXzy
yfzKxISJz1e/+lWmRRdeeCEVyXiSrdAQbknXSA866CAyHzJkiL1Y7Vx2sN/N
8olmEKrPXE9e3WJLhe5BpVDO1NPpOo2ZhcgBDvR4lhN6EDm0yx9gV5JE5PiW
QgMbrUNt4PCwjiw7m00R2QEiR8rUq7jBlhA5AJORJd9WqXmC8xn3FkmZ5Sgj
VgYl8YezV90hckVFRZ4OhW498MADjH30bdsZJrlsV8KImz59OuTq2GOPPe+8
8/bff/+7777bLDU0lkPgf/7zn2+//Ta2DJ4DIEDAFi9ebBarGch//OMfeYL5
wJDxkJGIwQLNYqfAxh5hgAAN8gQlMLixlI+fmJ7b+4xQHXCJcWcvv5MhH62p
qXGc69ICFIwmshPTIKS00ZIyA7M89GxZKmAT4mko+ZAH3oME00k56R3KY4Kr
Oht5WtBLiiApCgpj8ZQhyEbkSEMx6NOoFzv9l2KQSSxKUwX6l9c9UVMVzmbe
vHkec4zJwxCTJmkVlK9jps3lU4nOavLQXrQE0hW53p7L0+kQPD5hm6FCePkF
fRNN1VK2HG7Ebg7SPmgpNktnt15++WWP6SyEXpHRZEYHCgPrZryYUUPx+LR0
lSpgiVDC2Pb3iOYLlJNxcfrpp5955pmU3HSTgtWOHz8e9kvDUlo+miWMUbMJ
hadUEHiPFabTHb/6sZKdyOnSisIi+0VHKP0TEEkSkYO/0d1MZIzmowzFxcVZ
tlbbJJGj8WnSLGaIrzO/zkLkdOjRf39EdcciDBs2bMOGDUmADJKAZp5ojLnk
0tSiLYOrr76acTp//vyjjjrqhBNOkDfXRiRySfhjnOg6T7LkKQMqPxtYOnA7
us0nswjs28feABCgJup4BLI3aNAgzYJNGXQ51F470oLeiBEj7M0dTAYNOHbs
2GiNjAAvVVVVf/3rXz07VorJJSKdhAlYCqocuwylQ1BY4aSLEqJ5sd56bcmy
tUqVF4eStOeOfeRbscyWNgTe4QkeF17UhTQzZszwqB9pyMQfT5zXFVDVFJI/
KNuECRPsaYLcfsJenLqsXbsWlOZ180SLq4rVpWVPAfiKFSswDdGZO2xQDnPg
S5REhntrZu5buuNpRM3er1+/srIytIhGuOiiiw499NAxY8aYxR/sEe0AwaA6
K1eu5F8YRWq4q2YW+D96ztQJgIotGDyqrq6uRYgcgxe1jw0U6AhpyDCWyEHa
AShD5ICvioqKLFur2yaRo0FiiRwpG5fIobHV1dVZ4nNlJHKUjeHA4E3a+udb
ALv8D3/hgZlLLlspOrICJ4EY3HPPPYcffnjXrl3NSoWIXKw7sm1EwGpYXM+e
PZ966qkoVmgXEhAwm0cMNEAm6pWCmsoxhXmi8zzYesfHiG7eQR5s/FGIB9vc
O6KYXB7/ckG4XAay+UOxUKO33npr+PDhnt1bLE6SCQNzRo0a5d/30WqbPHF5
0qA2uqqZdASar9DOsZ4xeJ1+0X0WT0k2hrEt6BcPPL7//vswbYWUjU1Am5go
6ubrWn9T2cyL/BcC4/ivU4gH+Kq98MW/CxYsIAd7U1LxtpxlYdkCHvbu3Zte
y3LtsemEwtAOZ5555iGHHPLzn//8pz/96X777XfNNdfYvaCt1SxHvFpW0HBG
JYNRG6xO76OZsRzJkf/6r/8CPaivZ2VYAj9hyEPdUwsmv3nMKz1pVFoAobKy
MuqcLUrk4DAZz8hRTsDQH8jMSFMQOZp0zpw54IzgkX9nhBI97Mrohp0mnT2z
v06eoGtsbAhHGGiMwSx+WmgiIC51axXt0uEK5xaDSsLwB3+y+KzLJZdmEEbZ
yJEj995774MPPnjEiBHGpQPUgsmdiXa6bQqFZ5gPGTIkiOwz6hwdczQz4wYk
oVs1NTUOKDGiQQBzPlDVpx2WLVvGeLcvh4Inuhhl3tX9grKyMk80B94aO3Ys
b3mmn2BCUVGRfZwvKtgmgMW5b2vkb3/7G1RkzJgxQdyaj+jT4MGD/XPbQug/
hEl0EpEzW9tgO59LchICykHkXnzxxdjqyJ0ddMhzvwzuRONDm5MiQRTCKw80
CKX1+CGhSbGtgnelQTGgiPB241ImCIN6/PKXv3TO9RVC1yLRS6Z01uzZs+0D
pbQq1NS5QKr0MKXHH3983LhxWTzKNqnAfFDU9u3b77DDDjvttNP3vvc9etAu
FTyWKpjIDtvyCoPiwsA8zaKo+WndunWolsdMq146kop6pN7HJAFELsuKXHYi
BxGdMGEC9Myc1ZRsDZEDsUtKSujBLJrWFEROrocUZjQIW5jhSXWil1PWrFkD
Fvl9qigTdBLKp6vK/q+vWLGCcZ1K5ArhmVgGe2pQDwzH9OnTwdtoHBxagx6h
9bY+fmUuuWyl6DoM6ophffXVV6+88soOHTow9PSrZqwMDR3yAR+2NIh2M0ih
4TZo9IwcoMpzex0Mcw/CQ3UcQrVhwwag0kYqsuW/WlcPGiAFyF27di2Uz/Zo
AcjTdNCSJJJGo61cuRLU8iwRkDOcGWPhR8sPP/yQciYtmIiOiktECwO200Qw
dv/6AzXFxJCPf0UuCGGT9lFTRKFMLBr9ifU1Vwijw8tZXCwM6iHU1wR1TUqG
LYbveW5u0iz0Dl1gfx3bhGLbsTPk5ZiUToHFVx3XIlI5m7YpqAeJnfCstAOt
FHU43FJCNelZWoxKYUadSzEwvXnz5lFgtJGe3VKHwM0sGHcaVj6+7FowSBnm
qQadujOty0LkQEKmb/CuVAAUkcsSExa2IyLnMAHGKYWH53wBIse78mKdxeVa
UxA5BiyqZeb+IkK8Gy0PsxsgMcvaL/3LPD2LGz0QyX/QQkKD6/ytv0bad2A2
+t577zkDgaGBPlAFc7gitWy55NJ0Im+lI0aM+O1vf4v+d+rU6etf//q9994b
BP/X5xWDSGdRkCyRiFtEGGW/+c1vnLsGjFamcsAaoztoQCStaGmLxFAdkSja
wcY0fv3oo4/krStoWIZS8FmHswGzY8eOjfXbpnz46NSpU5966qkksyjSqF0e
fzXpjsrKyli7QyZ0IvCSFNxKG6+QWD+Ro8AY+kceecTjxk1CAnlHj/2V8pCA
yWzSwgjWFpD3n+fBLGLssIyehTtaY9y4cbRwkpGl3cBtMrFJC51C59oLhvy6
ePFintgsvRDeUSVzx5UKM3SF0jZ9KlZAJ9qTdxoTm25iSWybw8cWXXaoqKiA
5jHwt9QhcDOLvAIy6XB0jIHAwPf4+TFb5IDD3LlzU52fgAzgAyoU67nRFgg/
g8KJDhMrv/vd79BtiurEkUEo0vz5880wJ2VGIocSMvFJjQWvL4JazNAVhiYp
5ZYSOaCDwWIgCP0BbGOJHIAJPctC5MB2UCs1QBhFpT2ZqPo3TIOw+vD/+vr6
1BrR3fSm+bRag7YtLS3lW6l797nk0jzCqO/Tp88+++zzi1/8Ajy85JJLOnTo
YNagGuuyQzOIzt4zxzS3FRitTOJGjRplpofaNITIOWdIABkYFJhmEy05i4Pi
CpSUIVwXPiYfIyYZ8zVwJgk9gDLm15dddpntvtiRQugRorq6WgWL3UOkbFr6
w3LF2gg+BIoOHDgwqYl4HUSFWfmXWWhAmuLSSy9NoqZGaF7MZWyEAgmmB1aQ
VCl5BPV7BpZDOTTTE3oVgtqvXz9mH0lXPLT+xrdsWwAHmDNnDnhum5gPPvjg
lVdesRf3Cp93Rmdqwev0BTmY/XR+gjkwzTf6prsnfEI+wVrFFozjELili5Mu
ECfGoxNrCTpKl3mWxQoNsnLlSgZU6habnPCXlZWhLf4VGIAI08+kMroZ5wjq
ygREK3J2wYLw0P6yZcsMkWNGCXNgPKYukGYkckKzklCy3NzMTuT4NKPVDAHK
AwJ8YSKnr8tpZyqRY/5100030Uep/AqIg21mCYnLMKc6DpED8MvLy5mHbuPr
1blsP8JwBrRvvPFGxVY44IADBgwYIBBoXUSuEAasf/HFF8EN420bClFUVGQO
oxbCgPUm4rlBY2Bn4sSJdpiGINxMgc8MHTrUvEu269atq6ysNKetlAzTP378
+KRADBC8Rx999Pjjj/e439emJ6CaBCyyHWQFjdRCWdSUUE3w1myLR4X2gVLC
u/xrBTCTYcOG+Qss0YKnLiPEkk94EeVZsWJFrOGjGPTX9OnT/dtAq1evZvLr
uUhC6/Xs2fP0008nq9hFOb4u3y922DIe0ps8sQ0EtgDrDyswEF0Ij+EB+86C
bSEMsoCy2b4OQHiemAvFmjVAMzx3mbc1sf3IbeNlNsVDf6BDwJTpNcXamz9/
vv/1ILxTmYXI0cu33XbbrbfeSsuktgkqxFzYvggT+2n0atCgQbR29DwbaACR
M84kFQLgtddeSw1tkIXIFRoO6l9//fVXXHEFhCR1RY7yZCRyilBmiJwoU+wZ
OW2YZiFy5AlxSiVyZHjyySc//PDDqbdWqQhYQcVTF5zJatasWWYurycMc2Mi
/a/nkkuzCVaGcYdJBQGw8jaqoK5ou8bFNo7qEp0fBkiplCiW7bZXi2xwM8e/
68aNG5988kn7uFQQshRMv9nr1HkJ/gszNO1QCN2bTJkyJWnuzyvz5s07/PDD
4UVJvt2CcG1q9uzZFRUVJttoGjAHSkOapBk07BTz4YmfTgLgSxvNHiH/zp07
t2/fHpImy5jU74XQWRySlAADBBlGtZIudqFvvO6/RUufYhowyh4nugprdccd
d5h4qU4aNJkPwbJsvo11njNnjr08q606HtphfINwRWLGjBnOoqvcMiuwl57I
nQUGlyJRZbKi7llOK207gpLQ1JhO6pLk3GMbFAY7FItpmkwz/6UjonFyowK+
zZw5M9Vfh2LInnvuuQznJEfERoAdsNRz9ckIYALJsXUydkVOJ82YEaTqUsYV
uSC8D3LOOeeceuqpfMizsqRBh0pTzixeaHSo1ayfM3lkLkPzRjuCsQ+PzXLy
jdHNQEva/tZDykmaI4444p577kldeaBh0Q1gP3VJDYhgFMtHXBDyUuoCB24t
4yKXXIJwqsvAhD8whJ2rVdumiKqNHDmSiR6j7+mnn5ZzXYnCmDJDDCwbbVbD
7M27QuilpKamxvZZQSO8/PLL9pIXOLB+/frq6mqZ+Gj7YFnuv//+HXfcESLn
8RGqKGBmCzKWscAxyKGqqio2En0QHvzWWcekr4CZAwcO9Hv8CEKEv+yyyw44
4ID+/fs7fCYqHhfH2g6m/SdOnJi02aFbFf6VEypOs5vrsVGhQcaPHw/zPPLI
I/kj9gSgXKhhYW3ftjrnxteNJSUZaTCazj1ZTAPszlkLpfDo0oIFC4w5UCRu
8uQP7CPcL4lYbrOyadMmeqRr167l5eW02DZ4uckRMxYwr++99x7ll+IpjFrq
/qb2zWE+/mVqWAeDYq+99urdu3eqHUej+LR90jJJBg8eDD2LEjmzIldouGPV
iETOfOKUU07ZZ599FL09KbGaBSrFJJFBkXrwD4yyrxvQVgwc262cyXbWrFkA
bBaXCAxqRpl/WgE43HzzzV/72teuvPLK1Ih1JMY0OKcTY0XReAUaTM3AAd7N
vf7mss1KoeH0rz1YZI8YicxbW4u3HBPB6le/+hUzPpu3AK3GM4CppjzROX7h
MAS8OHr0aLvWjGI4ib0gBglcsWKF/ABHJ3e8i434xje+AZE77bTTPEfOaF4o
lmLdJoEVfYGBoF5BHDGQCxQYrMdyMbusqKjwLz5gCGifww8//Mtf/vLll1/u
7EFHhcTYrNhdJL1FL0yYMCFpA4XSQoyBSk/4hkJ43YCOS9pbocfHjRtHmXfY
YYdLL700acmRMsAG7V6gspAuTKTdaDrXp2T2UhvWhIHgFJ4ndIphO6TnXZRE
o4YGbxXr2LZoRW7p0qVYWJ0Ha+kSpYg57cYQwMjSy/yro5WoVpaDajoA6bfO
dXV155xzDgr205/+1Fm6jwplYFxsjAs07AijPnZFDvChVMwUmo7IMSq/9a1v
UaOhQ4d6doHVLEOGDJk3b17qCi2JaXPbvyJ/MLqjRI4OAjfooyzbtdBIdNJf
dyYdJ510EtW56KKLUr01otsM59S92iCcHYvI8XW6lerkLC6XVieKtSrn29s+
pBsBGJlBM3fu3r27vRaEjYbaOScoPvvsM1CC6aH9EPx/4YUXmLXZZ6WgQCUl
JfaCDyjEu0n7qu+//z6TRLDlq1/96nXXXWefrLOFRgaixdA8Qi9Aw4wPDUeg
lPJqnsS3sQVvv/026O0/DsSku7y8fI899qDYAGPq8t2vf/1rKJZnGRBQBbGT
8qF5aUDaWU6nk7ZOPv7449mzZ8PQkm55TJky5eijj6bMBx100IgRI2Kt2J/+
9Cd6GRtnh1iFZ8pimmRyH6HTdKY8KAn68Morr9grVIXQLTCEzXZGR4Z9+/Yt
Li6mO1rRkDGCeth+5Fq6OFsmOgwJf6YToeiQitTT7CSG+Sg0myfZ3Llzzzzz
TBTsrLPOgtL480SZoWdZwq2OGTOGnKOBlWE+MA2Yg4BXRC6LU5GMW6sgZLdu
3fbdd19qdP/996dSmmHDhqHqqW6TdT2cEW1qlLQiR0rFOvEzbZ1QZTTp656t
Vfq6Q4cOVOeEE06Qd0qP9ipeT5YAEC+EglLRF2BjqxsRueQSNER2aBWXHRyh
5Ez34HL23uh7770HE7N36IAXSAJMw5nEKYqrAp1LyAcAVzB68xDErqmpiQ0I
SwFI/JWvfEVE7vrrr08icjRvZWWlx1VC0OASpEePHkk8DZChvjCNJKiB6a1a
tWrixIme2XcQ0sW7775bN1+OOOIIbUN7hDwxHJ4pMJ9TSNakBOvWrYOkqQ2T
gFrrhEiS16bly5f/6Ec/UrGvuOIKGjOaBtvBhxTmwyzjYG21/mayVUQtx6Er
hg+6jko427uwNewUdsFkSDf16dNHrk6SqrwtSytyCOyIIeeYXZQKfs4A9Fx2
lsj1IgPHc1wKlSC3448/XmO5V69eUeplC4MIbclC5F5//XVIV5RtQhvGjRsn
IheE9AyMYhA1FpGDrmsjkhqdf/75TJH8p8UgctCzLERuxowZGYkcsJBK5IKQ
dDG1ZA6uDQvnV6koHdSpU6e99tqL6uy9996MvtiimlMrCsSThcihQgoBg1Ll
a3G5tFJpvUSuEHoaYbSa4E0MdtgCOGNzoUIY7AB25zyEofGuzU/Irba2Fnw2
po0/3nnnHSAuFtUx/SAYk8Qdd9xxt912u/rqq5OIHBg1ZMgQv++jv//979ga
T4SvTZs2+SM8QuSgN34iJx5y3nnniREdeOCBzIX9plzH+6OumI1gWUDsWbNm
JbECTC2tCpXy4GQh9MTOh5K8B8Mnr7rqKhX77LPPhtNGD1dr/Q1kNiHnCmFQ
M+gZFL1gCd9yTEwhdC1CRZyz2Rs3bsTEG0+D//mf/4nakCzLhtG2KYq1yjCh
vuh8q3OwoANymj4wrv3zo6AheggTFk8oBIjW0KFDDzjgAIXDuO666/wxsORU
2R+qWLI0lCiRQ69sIkelGNpob+oCoyhfKpED9E477TSNl6OPPto+HhArjU7k
+BxTYGAhdaSghCNHjoSZe6YVVOfcc8/deeedqc7uu+9O03mu/wfh7XKQMAuR
Y4o9YsQI0KnFY7LkkssXllZ3a9UWefTFsOrQlLyozZ0717ZNQNPChQv79+9v
v0gCcMN2axmE0Aqe2Itv8lwHIMTejOPryvyxxx4jfwUFsxtQ7akoYJMmTfID
LyRwwoQJjoMUOytqiuXSUbTYbtIOsvzfJvUjZQZy+/bte9FFF5188smQT9J7
ShWE1wPr6+upgicNv2JckqYDVFwXBDzH5IIQe7EISVt+VB8yfMkll9xyyy2U
OeleIcn41V5/C8K4nHV1dbYho/dJ5nA2CoDdcVZfMdn0nVzhQfxg2tTUCcvY
uoQZAROWzp07w4JWrlzZStcVtfwuj5Gpx0LosqefftpzvxUlh8nsv//+Yj7H
HXcc4OCZdzDdQKU9t9SNwOKYBdgzQRWVYQiwGCIXhGt3TspYob90PNizdscn
mOnoKIKYj/++Q7AlRG7mzJkMKFNOmoKhpMM5dko+17179zfeeCN1pgCRU5Bi
Tyc++eSTOu8nefDBB83xwljRQVYFd4v+ah4yoktLS6l4azkfnksusQIaMNYA
EOC91UG6XLB+/PHHMByqwNyQWa1z44B6gclOCEXwCu6HUTZ8QF5/ncgR/M18
LYlcBSGIwT3suKhR3IDdvfrqq/Kt4UEeXaFNOt7GbJE56QsvvOBBb+296rh+
LJezH/Ihc+DfXzDKj83y7JwG4f7jM888k7TTRCMD9dHAWI7QfRjcefPmJRlQ
7cBSbNohCZ/hinxIHpVNmtWrV8+YMcM+mm7849mvoyr0tb1yKB6ue7v0tU5a
2rdiW6PQ9RDvVnpGTmJWVlFOBo5Wcf1mnTmaWaeNCoTqrrvu0jEJ5Bvf+EbP
nj09K9ubN2+Gz3huqRvR1WYnkkiwFUSO9BBI5lae2QTDpLi4+KCDDjLMp0uX
LjoekPRKRiLHcIBT2af+aNVx48bZvhYlIFWfPn3efffd1P1KRhwQ7dmwYIp6
//3377nnnqY68kCSBAJ8ERjUMYnYNMYNKZnQLK3O8OWSiyO6tYqdhca0rlmJ
oFv2GhiZMGECNIZ5tx3lPAitM9N257aC7ofaXkqoO9QOwLehjGFeVVUVe0BO
gk0ELuQe1jj2d6ADuw+S++8UaP+3qKgoyYkHpYIsGbdvsSLfKYbIJX1IAnz5
QzYYAUV/+ctfwuU8cAcI19bWxoYR1+egTHxOjgiSPvfvf/8bAgZTSlo6KITn
oikJbR5rcdT+sHqnoeRww+bb2Ojx48drO9g8RAeoAqpiVg7Vp5gtODZaxHf9
VWgVossOZierldZFJaeX4TOQIr/DEOaq4INnt/TXv/71VVddteuuu+4cSocO
HUpKSjzhAxgUzBk9Hh3tlHzavmtgiBxDhsnFlhK5ILxjBXx5vNgxOrp16waR
+9KXvrTLLrtQr2uuuYZ51tYTOZRn6NChQKVBA1UkSpLB2N69e6e67wvC3gEf
PEfpmMbCFW+44YZzzz33zDPPvOiii5544gmaLomk8XzSpEngQBKRU540I8C1
jYeoyyWXLNJKb606wqgEDR555JHu3bs7MztG6/Dhw+11tkLD4To7dBRT+3nz
5tk3WxV9CXOf5AdJCUCYJBdzegjJlEejpDRBwyXcKVOmJC24YQ5gaKNGjUpq
gSAkJ3AVfyxXI3/605+gZ1kO+VA2qD42ywPykFXawbkXbAtk+LnnnvOfOyqE
5/cgS56VE6XhQ0mxuoI4F8TYCIAdBmiewNkwxPBG+6YMsnDhwpkzZ5q1Dj18
6623HnjggSFDhrT2tTgJtpje3NgQGbb1jnoJ5adGKJjHcQQQBw/3XNhh3KFR
q1atYuI2YsQIUvopjU60ZiFyFAndixI5YKG0tJTpm5lxZCdykHCmGx4ix0dB
PEjUgAEDFDNlw4YN6PzWEzmwDhSitU1W/A2WRn2Yi8iZGCgeoXgLFizwH1eQ
9yfwjVHMvMx/ZZXEXbp0Ac+d6hhth4WuWbMG05Cfi8ulbUjrvexgC8NTXA6Q
sTGTEQ0mP/nkkzZB4iEoWllZqZhQGtoAEVBvthqD0NYzT6ypqUkiV3wRzlBR
UeGZ08kNnfFWF7vdqVWFF198ccaMGUmWCL4B66AwnhbAkIGHWUJUB1tC5ADD
5aF4TrjJlwssKGnBkAoybRfT8+8vA79+L14wELiWZ4UTsw4ltj1I0Pj8V158
9YQywCops+MKbNGiRbBuMxy0tYrJnjp1apaD061CNm/ezPTk3nvv7devH/Vt
G/tKKBh2GaYdOyGlrydPnpx6LYIXUVFGK3ro57cQOYbP9OnTU3cxGBFRIoeg
ip06dVL7Fxr894IVPE+NK5FK5MzrTK8WL16cBD62ZCRy4KSInEEqSDLDramJ
XBCWnyHMQE69BksD6tOxVaaOzPJyTyO5tCVpM0ROB6hAFWDTjgOoo2U2QDHM
V65c2atXLwGC9mfhP2YHRAOcXyFXcIYkcqUAYfCTIBkktQXDjNUTi7MQelGD
KoicxKYhAWjpv3GAgQaKs7hECLaEyEFTly5dylzYsx6FpViyZAnFSyJ72jZN
DagEB4MNJiGwKfnzzz+PBUwijfQLZMw+R6cqzJkzx64C1pB87I140svXivGU
gv5A5jHuWbzTtxbRrVVICNMQ6tXaXS6YIxaYZiZomzZtitYolciZsQntgfyk
+ptFzxkRtKHf1U+QQOT0R1FREWppiDQsTg7NUglGFiKnTJjDosDmrIJ/RS6L
H7kokfvoo48YbtETbgxDMDYLkYPB1tXVpRI5vkj7gCGpRI4m7du3byyMyOsv
jdzqLmvnkotHdGvV2KnWPkkBYCEnJjoDQ54ZHHzMxnYA8Jlnnhk7dqx5wqDG
ggNlAlU1AqQCC+6J5A6Gz5gxw4kF4AhGE4aG3UxKIBu0ceNGeJoODMd2AWjp
DyvPW++//z4mI+P2X3YiR858F0Lr8SlKuy1fvhyMTYoTwROol+OYNyrwXjrL
XjqLCj/V19eD/Elp0AEKA7G0V0toYRi1zXJFGt99911T2kLoXYRm0YlK8sGs
YzuSQt+2FnG6g4rDH7JEwGxdoj1WzDe67UyawAE5zUjNBFLBSEyN7IBukFvU
62BUwBYyjD2ZP3DgQBE5e0XOdj2dJKlEzohD5GJFmwK9e/dmTGUhcqNHj8Zk
GETVlfzoGAEuSKnQJ/48mecmxY6xhZYpLy+nOqmFhLfDxu0TGioDL6L2noNz
ueTSSoXRgbXCeDE9b12xv2NFqyhr1qwBPJkkAg4wEMdPO2jPFNK+/sAAB5bB
1aDhrCzIBlgBRCIesasWzOxGjBjhOdAVBP83OurG5FA+hfCiJRheVVUlvI1+
SzdqycdD0iiwDqt4CmPLFhE5dINm9Czb6iggVE1pYnFSASAUzDRJNOmuqanx
XGGjpoA5djnpLPq///1vSkICexmN4j333HMwUlO2v//97wrlYOyCNrxqa2sh
nPy6YMECmLw/TMa2LLQDDYUO0322UonIpUarbHWinmU0Qddtt2bCBHrTDrmb
JPDA559/3nO/KWi4dEOGTDqyELmKigqUP7oEFCVyTIWML2tPno1L5IIQDYYO
HcroSD35D2GDTZkVOf5lWDlRklV4KBPVyRKOdvr06bDB1E3qTz/9FGWGpKUu
pjGJi3qKBlLo3DyOai5tUrBc2FYMOmaxDZyWMXusq1evxiJjwiZMmOBsqUC9
qqurzcF70sNmtYMWNKAQOTA77tevX1KgARCPzCFX/hCiQMfw4cP9R2oxCnBp
hXONTcBzMLZnz56eTHTzAoLqSWPLFhE5koHVnvsFQQNuix7EmiE4Hs1uXx2N
/RYdUVZWpuu0SaJNKA/Fwm6C5HYmGBTMLghvlFy7vVht574DDydOnDh79myz
o9oa5++UmcpefPHF3/72t6mObfuYDtDINA6WEe1tjbWLFVMRMA2q8+6776pn
C2FcAHQYtpBKaeBRCxcuBBI9zSI9YbbIZCH1JAMtX1JSQl9EgQIix4zDgAPj
i/Eb9awblUYnckDipEmTsoSY1zqbOYhLekYQI8veGFXTMXtlsGchcgy0LF1D
fUeOHEmzpxI5cmP4m3kcaoAJQB8oZM7icmmTojNybeYgtxHdROjfv39RUZFz
/p/pZGlpqX07DFbDvNI+zsHrkCsQOCl/jAWAz1zS7w9kzpw5IKS/qGQFnnti
OmAC+NbgwYM9mWjVLvVbRraIyNGA2CwtpiUZuA8++IA0ZJiUAP6AWSGNZ9av
lb2pU6cqxHlSVtDFZ555RstrsWnQZ6wDfM/8Cn/DrPB1+ZnXi6+99pquNhQs
4dNPPPFETU1NKz0XpypjcO+8884vfelLxx9/PG1la6kuO/ziF7/o27cvLdAm
L+5RKbqVyYV2KlE5tGXp0qWpyz6MWQajn8hJgItp06bpIJYnMWo8ZsyYWCIH
wYZvQHXMoVymJ1HPulFpdCLHeGHCS7apHImUts83ETmKHSVyTKaY/aWe9FAk
r9dffz21a2hqMNC+MJskaDU6r4keBQbGy8vL/YF1csmlVUvbuOwQFa3LMTVz
fBkB6atXr66qqrJxA/AEVO2jF0ziQAPFVY8VrCEkzX8PDiYAPPoP0SkZX/d4
3KWPli9f7l/LUhAKDLT/W0a2iMihHlAgwNaEE4rNEKtEIZPWdSnh3LlzaQ3/
WWWIFplAXD18z3DCpPt9ujyiyK2mFoa2mSfUSJ5hDIuTKzlIdWuEfVWBPqIW
WK6DDz54hx12iBI5DJxW5OgIs6/X9kSXwRnaVFPr56BB6vEqXslI5N555x30
RGcsvxiRY8CifjrRFzQQOfRzWyZytGdlZaVZnKeoDMPYFTnoGZ9O9aYCkPJp
GtyzH6QMAduxY8f6j7JI6BcAk1FAdwNKoGsbuNSTSy4eacNETjPxt99+u7q6
WjGbgnBlhqkiVMEsRBTCWD9lZWX23S4FEAR+k/LfsGFDcXGx/07W+vXrBwwY
4D9vE4THTmpraz2cEMsLKnpuOgThWcd58+YBWf5vGfkCRG7lypVJBkunhkhD
OZOshs6H06qpBgi+N2vWLM+eNZiMBXzqqafkTipaKjBcboHtbdMVK1YYh34S
GoEyy/NeoU3cUVVrMAE555xzLrjggosvvvjEE0+E0zpEzlx2aKsszgjzArgH
HQ1pp2dTgQ5CwpTKs7BshAacNm1aKuVDVysqKmKJHDMLusacEMhO5IAUiFzq
7YCgCYgcPAqQMWyKATh48GCIUzSg6qRJk8gwtS5MysgQlM5O5FK7hoEPzYYi
bty4keZNQolccmkz8o9//INJZZu5tRoV3X2oqalR3HPdY4UqGIQBYDHxTNxs
JPnggw+AX889TUjakCFDPFf/aEkadujQof47jySDWjDJ9QTLBttBRX/saflC
afStVQEgOD979myYpAeWaT3F4cJqxGoRD1evXk2CaDQfR5YtWwbf8/jVRzBk
lD9p4wZ7RBeTQMZO5aEWdD0Ib1CdT5Cmvr6e/2LB+ZVqtl4WJ0EnO3bsCJF7
5plnOnfu/J3vfAe+YSewHQIbacOWDohj7kYj0Ne6ROmpKfORmTNnOvfcY2XT
pk2LFi1CnfwXBMgHNsXXo+41Fi5cOHnyZHtFTqMjlU1RHeqSZdEY5gMvzULk
mO3CD7MQOcpsjuIAnp06dXKQQdUBi2KveDjCEE5dkVPmgBWYnETF7W6lwQFD
IJqub6tanct2KzpGNWzYMJTcjC9za3XlypWpIQtbo+ioFWzq6aeffv7557Ul
al9ZVdBnnpiKg8zM/kaNGpV0bAPMAXmAC8+kGIijSVMJWCH0XdajRw9PGia2
xcXFfj9LcsoBJHrS2JJ9RS4Il21fDsUfpxvDxFw46vzByG9+8xsS+OM7BKGd
ojv8BBhyTvk9K6K6uabjkSqP3M7A1lQ2baSiDLSbvLvwa2uP3UAdBw0atP/+
+3fo0OHGG2889dRT99xzzyuuuIJqGmvOEEB177777vvvv/+BUIYPHy5+27KF
bzoB7tAHZl70dSpDoymynKhn5oWiZlkgAnWB3ChWoL1QQXPSgA6CEcmnsT9D
sgJbsnicYxxRndRjkGRFSuhZFvr6q1/9ytQFJGREOy+qVCTLkiHzJsVBTm1w
0jB4Y+d3OlGgv5k+//CHP3zqqafooLZnznLJ5be//e0NN9zQrl27wYMHm+mP
bq3CWxibjPe2qvaF0MfU9OnTS0tLmaXa+2sQBuiWHT9dDsRGjx7tOe6FXZg6
dapnqsvUXh6W/I6hFPXVQ8DAt9WrV5eUlHiW7IJwmQVEzRifK9jCrVXaQRc8
PaRU1wRgy0kLbiTgo7Rz6nFlJt3PPfec3/sx6kqRkmIkiR7TQeZ4pPbZZ86c
aceiFfmE1YwZM2batGmpjka3fcF03nXXXTvuuOMOnxdom1nAgSrIuSKjflUo
69evp2fb6tiXMFRnzZr18MMP19bW+hd7/x2KJ0GhIcSzjmj6203JGEFRSsNX
gFzjKlwq6vEcbn+dPLMc+iJ/fzQrk2FsCaPCd20zoTMVzlFVlV9VS82Q79I1
fhanDMnNNFdSVnV1dffdd191dXWSQ8tccmnVAnYxVd9pp50OOuggyIyhKG31
1mqswIUw7rfeeqtWcoQPEI+JEyfaO02AAGgPB4uFF63tzJ49W6Fak7CCbzHJ
hR74nbpASHR/PykBZVizZg2s0n9sWIeQszsH26IVOWwBhWSS66c65EaeHocM
NCyN9vrrr/txm2STJ0+Gp3lAGy798ssvJ90Q4a1NmzaB6o7butdee83EV1XO
L7zwwkMPPYSJTz0G3ypEgXHLy8uHDRvWt2/fs88+e7/99vv5z39Oxc0Zrbbq
EDhVdE7ykUceGTBggMf5di6tSAzpBR5HjBhx/fXX24vPueTSlkQBZU444YR2
7dpB5IqLi81ie1u97BCVQsOFviVLllRVVQnJoSiK525P0v/4xz+OHz8+liQI
N0g8c+ZMexEvKjAlSCOGw18qSAtfX7x4cVICOogCw6P8+yMQuYqKitSLFXbx
sq/IFcLz89OnT/dv71KX+fPnK15trFAFeBSsVaQiyYzyKwSYZvGQK9JQJD4X
y5O1IKDDTvZX3njjDUM1dbUBDu+PCNaKxCzs6L901sMPP3z00Uejh3YyEbmM
odzanqD51dXVHTt2ZGKSJUJ9Ltu+MDd87LHHmL9s2LDBrGq2dKFyyaUxBZOH
qbr66quPO+64rl27QuTKysq2txW5giU64VZSUlJfXw+vW7t27dy5c23OQGvU
1tZ6SBGMxcR7ikUMncqbNWuWJ41Eh4c9R7N0hI/P+fMBwcAxz+0MR8Qz/X53
JWq05cuXp4ar/stf/gKzSooYa07OMKfwT5mBYqoMl/Ps5NKJK1euhAB7ju3B
POlH21ibUKq0KpSSv2k3j0+V1ihm1/h//ud/Nm3ahILpsJBJgLIxScH2MR9B
/9tMxbOLPOE8+OCDlZWVtv//bbwptvHitYiASIzxLl26mBO8ZuO7pYuWSy6N
KS+88MLgwYOPOOKICRMmTJo0qV27doMGDTI6rzNyb7/9NlYYYMd0bg/+dqjj
hx9++OSTT0JmXn311WeffdZ2qMVPzNmT4mopNCovJl1vlA2Ve145NvegClmN
Hj3ac2gHpIJwLly40FMdnaMjn1Snmkb+/Oc/z549O/XegZGlS5cClVqRS6oO
ugQB8xeVj2I9/RMH8cann37a8eRsC72wYsWK559/3sNdKTM6bxNyrDZPxo8f
/9xzz0EUW2/4ra0ROQS+9957+/btC69OjVrVVgUlHD58+COPPILGitDa0tKl
+39imHkSMkfLHK1CNIH/c0k5byOiIgHUffr06dmz5/r167cHs5XL9iwHHnjg
Pvvss+eee/7gBz845ZRTdtlll2OPPbasrEy/mssOUA7s2nYVig7WOn369Ntu
uw1GZz+nEX79618nrT79+9///uCDD8wt19ilJ9KsXbt21qxZqYd4sSYvvfSS
Z4uHHCiJ/8YEXQafMVuWqaKdR6qfnfhBh0w0Xk9J/haKJ8FvfvMbyIOIqyfZ
73//+9dff91/cTU1Dd3Et+xjA5999hmzmLvuumvlypX+7d02LHIIzJBHqdpS
iK4vIAyBurq67t27M9VFM7WSs02t5zi3QTMWzJPSA+/bLPKbutg+o6ZMmXLr
rbdWVVX5r67kkkvbkMMOO+yII4448sgjDznkEOjcjjvueMABB4BdQThAtpOt
1SSBySxbtqyyslJe5mzxYKaubvlzhstloVVk1Sj+KlOvdDmypZ9Lunm3pZlT
WeXjXxP4n1D8n0u9aqc2Mbf26Ov58+eD/DBS8/Vtx2Q3m2y3lx2MOItvzAWK
i4vvvPNOcwqUxmEq53cc1DyiqPSXXnppUVFR0hYAk8orrrjiggsuqK+vN7iE
2vPfa6+99uSTTz7xxBNPO+20gQMHKhod3JX0PP/Od75zYoOccMIJCxYsoOJ3
3HHHqaeeyk884Tlz//79+/M81T1Ik8qKFSvWrVv3/4WyaNGihx9+mAZZvXq1
6rsdjuJctlthCDz77LOO+5Ht57KDRz7++OPa2tqXX35ZK1Q5LLQ90bnH6upq
z3btdiKxDoG3c4EvwdyeCAXi1LdvXwj/tuCIjIKNHTv20EMPveWWW2K5N4p9
0003fe1rX9thhx0oPGRPi4pz5849+uijebjzzjsbdzSdOnUi/bRp0zp06KCf
vhTKTjvtxL9z5sx55513oHz8ZJ7rxR/84AerVq1qwSU7ytajRw8oKKzyvvvu
44/8amou26cwDBnFcnlthmRO5CR/+ctfAHDHxVwurVpkhZm/LFmy5Mknn1y8
eLEh6tszV9+8eTOE9vbbb8fuL1y40O8eZzsR6QPMbf78+TfffPOPf/xjcHJb
UBKAuqamBiJ36623xs5BQC2xMuTb3/627nGj548++uhee+1FL9fX169cuXLA
gAEHH3zwcccd96tf/YpXSHn22Wc///zzb7zxxptvvvlGKH/729/ee++9M844
Y8899ywuLl66dCkPx48f3759+0MOOQQqlboN0XQCw7z88ssfeOABWKhcjm9T
O+C55NKyApF79913W2OI8MYVeSZZtGjRoEGDsPu5dWsb8sc//nHy5MmwOHM7
Ncd/3bmuq6tjzrJdnYn1iM3tme2OHDnynnvukVeilm0fP5FjktKrV6/99tvv
nHPOgaTttttuFRUVOvv64IMPwseuu+46+Ninn37Ku1OmTHnmmWc++eST6dOn
w/0uvvjiVatWgf8k5l8hHkTutNNOa9eu3Uv/h70vAXeiyNoe/xlHwX1DcxX3
cXdGmHYbnXGNjivONOq4trtGFDV3FDUCYouC7YKNIEGBKBAEokgQiaABiUJE
ghCQCEaggQAGCZiLNtrjd/+3qpK+naSTu3A3tN5H79N0urtOnTp1zlv7+++z
O4lEQhCEqqqqYDDYJutiQC/RBOvRo8fAgQORi7Yd4eXgaJ/YunXrvHnz0Exb
tWrVb3MvAivYitRhw4axE5/N+79xtexAMCMyOyJt6NChCECVt7/7rYHPkasX
MCG2n0/Pnj3HjRtnrj1vfT9QmciBc1522WW77bYb+NtDDz0ERnfVVVexAZcP
P/wQ1I711B188MGXX345iBx4ey3dlgdEbvfddz/55JNPO+20008//ZRTTnng
gQc0TQORO+OMMzp27Hjbbbe99NJLr7zyyl133dWpU6eTTjopEom0Doky9Yzk
UIXvu+8+yACLbcP+QA6Odg4QOVSWWbNmgcjxI4YZampqoJDBgwfDh7eHCc8c
jcWGDRveeustRECwcd7jVITf+IbAlcFYBLOZH3744bPPPuvXr9+DDz6I5oB5
Rl5rOskKRA4/TZs27dhjjwXLWrBgwcSJE4866qiqqqpJkybpug4hweVuv/32
/fbbzzypDaQIDVVG5IoOcQPTQ2UBkTvzzDOLjng777zz8ErRboQtjblz50Lz
/fv3nzlzJt+3mYOjMoqGVn/LRM5cxcZG39LpNFzi0KFDFy1axHYLZ+6xrcXk
sMHPFLV0IGbq1KmKooRCIZOE81KzAoaNdsr8+fM3b978G99+xBZFm6cxOvf4
44/fc889oHOZTKadELkff/yxW7duf6Q48sgjO3fuvPPOO4N3gf+gIYOKsH79
+k2bNmmaBo531VVX7bHHHg6HY8qUKePHj//Tn/50/vnnz549e20eGzduZMfc
nH766R06dLj77rtvvfXWAw44AKTuqaeewq+t0yGJTKGJAf52zTXXjBgxAo2O
3/ICcw6OBoIvdqgAcAOwuJdffvnNN98Mh8PgdWxwgbuUdgUUx/Lly6dPn47G
O5w/Ah/vbqoAELlx48YNGDBg7NixS5YsqXxAPAcDXAGjcz179jS3kv6/8pv0
NhdMIgdatWrVKutPixcv7tKly+9KcOmll4Jw/vvf/95///1HjhzJurNQ6Jdc
cgmY3gsvvODz+UDkrrjiCuvsEQY2R+7AAw9klFWWZVx36tQJ1aqFeuTMb0LO
d99998knn+zVqxcqcsO3uOTg4GBEbs2aNW0tSPsFPNjkyZPvuuuuZ555xjzJ
i3O5dgUENQTZPn36gHizrjm+qKEc2IbAsVjs+++/Z3sPtrVE7RrWnqitW7eC
zg0dOrRfv36jRo1q+Il4TYZJ5E488URY+EsvvTRo0KDnn38ejcrHHnvsoIMO
OuOMM/r27atSwEEdffTRHTp0GDhw4E033bT33nuDleF5uK/+/ft37tz54IMP
xvVbb70FInfMMcfgCy9RDKJYsGBBPB4XBAHkDd/ftm3b+vXrb7/99j333PP0
00+PRqMtNEduy5YtSK5Hjx6gcGiOsSFsXnk5OBoOEDkEwW+++cZ6RhWHCXPa
bSqVevvtt9GeNXehbFup0IBdu3at7UAPihIeeN26ddZzSCEz7qxevRqkHc1z
tuPupk2bVhcCLyK+f/fdd9abSMicINR+YG4ZMWPGDESxDz/8sB0K2Q4BIjd3
7ly+2KHh+L/8GS7sAlVpxYoVgwcPvuGGG8B/li1bZj2puXkBIjd8+HAQuaJu
t+OOO+6QQw7Zeeedn3vuObaEAYAYPXv2BH+7/PLLIV7Xrl1///vfm6/g2u12
oy6DNYHIlXbl4ZX58+efdtppIHLvvvsuW6P6ySefnHLKKTvttNNDDz3UvO19
qBH+54033ujevft9991nnQvHIxEHR6OAWD9nzpxgMPjVV1+1nDv6dQCe7Ysv
voC7GzNmjLmfqtmh0ZrOZ/PmzYgg++yzD7xr0caYkCcSicDzV1VVgXYywTRN
Q+sbLWtzvyk4c7j06urqImf+5z//+cUXX5QkyXpz1113RcwCg2XdXG3rZk0B
QNui0ejQoUNHjhzJt7dtONiGwHxj5O0E2kFffvnlq6++6vF4nn322SlTpqCh
1OxVAzVu4cKFI0aMeKUEcERIHbXS3BWEbWv82muvjR07Fu2vzz//vG/fvldf
fXW3bt1uvPFGr9fLJATzHDVqVOkHP/vsM7ZdMH4Fz2dj7vg7e/ZsJPTmm2/i
m03uv7X6DVZz0fh6+umnFUVpD01jDo4dGiBy8XgcHgmVi2/RUwHmUB009vHH
H8OLsrlYbULk0ul0nz599tprr7vvvpu1x83U8VO/fv1YA/ycc84Bw0GzF832
3Xff/Z///OfLL78MRgeah9Y6coFrPHbSSSchEg0bNmzIkCETJkxA0/iWW25B
Y/+iiy4CFezfv/9ZZ52Ff/bo0WPDhg2tlscKgKEuXrwYoQdFgAYIP6anUdi4
cSMCfe/evWHDiPV8y8TGomhqHPSJphOs8f7774dKQYGaUaWNsurShyEnaN6P
P/7IWFnDW2G2j21nFYMwaIEGg8F7770XDPO9994Db+Szjjk4th/Ws1b5bJnK
YPphzhD06aOPPgLJQWN5zZo1putuHY8Etvbkk0+CyN1zzz1btmyxpgtafuaZ
Z4KedezYEYQNVGf9+vWPPvrofvvtV11dDVERaB5//HG00xHNPR5Phw4d/vWv
f4Hv6brOHP7KlSslSQLxw6/IJizkxRdfdDgcaNS3+SICNDfmzJnzIsX8+fOt
UxZ5LGggYDzhcBhqBC1H4fJa3wSY9mZaHVoTq1atGjNmzF133XXnnXeiNQSC
t/1N4wpWXfqT9U65OaL/V/5MBOsIctES/u1Z1sH4GxTSs2fPm266CSpatmyZ
OY7Aqy0Hx/aDr1rdHoBXhEKhgQMHjh49uojktKiDQozo168f65EziRyA0hw/
fvyxxx4LbvbII4/sv//+PXr0gBd96623OnfuvOuuu3bt2hV0bty4caDuIHgP
P/zwTjvtVFVVdd111yH6IAbBzS5atIj1yJ1//vlgqs8999wVV1zRqVMnfJAt
1mtNmBETDBOGOnz4cFVV586dyxe12aJo64xaOzvk+8i1KFAH0cR47LHHnnji
iUGDBr333nvr1q0z24BtLV0LguXOyvfgmsDfXnnllaeeemrAgAHsdC3ecODg
aHZYe+Q4GgvmlL7//nv4q5deesnr9X711Vet4KnKEblVq1bdfvvtBx98MNhO
LBY788wzBUH44osvQHumTZt27rnnsjlvHTp0uOqqqz755JNHH320aI7cbbfd
Nnv27FtvvdV6E0yvV69eCP2tH4nYso5Zs2aBUg4ZMmTJkiXmdJpfd1hsGljP
CetF+aUQpro4kWs5mEqGwlEZ0cpDOwh1qm/fvjNmzNi0adOvfvoKMvjdd9+F
w+Fnn30WrUhkHK3IZcuWWWfB8ZrLwdG82Lp16xcUmzdv5jtKNQpF/R5s+OCZ
Z5554YUXQKJadAWlSeTuuecec9vbn3/+Gf7zhBNOAPXaeeed9913X1wceuih
aBGvWLFi0aJF33zzzerVq19//fWuXbuC7D3++ONPPPEESN2VV16ZSCQQZdhA
Kh675ZZb9thjj3vvvRdN6WOPPfbII48cPnw4m1PdaoOYCIWgHJMnT0YsePXV
V9HcsC7C5bHAFqx0wHtFUTzssMM6U4CWx+Nx85l0Og1DnTdvHgIuP5WveVFa
O1ArofBoNIqmULdu3VAWEyZMQHsEym8FUofUWyEVBA7kETY2ceLEBx54ALan
KAryiJvWBXRFi385ODiaCzU1NZ988sm4cePmz59vDZQcTQPYzsKFC9mCMtAq
c2eA2madgsiI3J577nnHHXesW7cO7Atlt2bNmv79+++yyy4nnXRSd4p//OMf
eOaoo4468cQTjz76aLhZFPeqVavuu+++Aw888KGHHurTpw/rnWNz5PAdyA8i
J0nSbrvtBpqnaRp8MljfP//5zzlz5rTQqlWzy+j/8pu9JJNJxLtBgwaNHTuW
n5TdcDAdjh8/Hnz+D3/4AwqxY8eOCKywSfMZGA8sAc0Nv9/PNwRuTWzZsuX9
999HA+rhhx9GtXrzzTdDodDnn39edASVdYradqb40UcfoQW0/Yfd2w7Zw5Ag
/LRp00aNGgXP8+CDD8JjvPPOO/xoYw6OVgZi97Jly9avX8/+ydtK2wNzAOun
n35avnx5IBB46qmnnn/+eXOX2uYCW+zwu9/9bu+99/773/9+DsUZZ5xx0EEH
HX/88R9++OFPFEj3iiuuOOCAA84999yddtppr732ArX729/+hovjjjtu9OjR
jz32GD6y++67n3rqqfgCfr3zzjvBnUDkdt11V4SbTZs2ff311zfffPPOO+98
2223rVy5suUa1GyOH0IPsjZw4ECEvJbYz+FXD7AFKPCYY44BYUDrbPHixWDp
VqoA44lEIqB2uMk3BG4rwLZRT1977bUePXqgpGDwb7/9NgollUr9+OOPzdVy
8Xq9s2bNQrXaznqE1yESrOW7775LJBJo+Pfq1euWW27B32HDhsGckB3eIuDg
aCtYFzvwoLn9sM5qhutD0Jw7dy7bdB1+G166WZScyWRef/11ULjTTz/9rxRd
unTB3zPPPBNxwaTl33///ZgxY8Di7rnnnhdffBEc749//ONuu+0GzjZ58uQN
GzYMHjz4rLPOAgNkXwCuu+46EDlZli+44IJXX30VrAD+ecaMGTfccMPVV18d
DAa3k5HaZp8dsAje+/TTT6N1j0hRtDkeH45pOL799lu32w0eDn5+5JFH3nTT
TbNnz7aWGh749NNP+Ry51kdpvxbcBUwdzaWNGzfG4/HevXt37979oosuevDB
B1Fzo9FoMplEeaG+V6Z25WoHiCIjco0VFclt3rwZLgINUrQH4RPQrLvqqquu
ueaa/v37o7WlaRpk5kPzHBztAXzVaitg27ZtsVjs5ZdffvbZZ998881PPvnE
5Fq1rcWfEcpXrFgxc+ZMNJ+tqbcarOOn5gK3tWvXhkKh4cOHg+gicoHotr5g
vzIsWbIElJv1snbt2hWM7rLLLps3b55pZojOIHJFJztwqtx+sG7duo8//vip
p566//77n3vuuZEjRw4bNgzNnKlTp06bNg0kCswcHvv7PCrsIYPmHj5Vbok3
7m+hYMfEgDeiyYbG2vvvv+/z+ZAoeGCvXr3uu+++V155ZcqUKewAoJbMOgcH
R1PAV622GtiCCDjhUaNGoen9xBNPsFNp0Phtk9WgbXUaqWEYaMsjWEAJ/fr1
Q4RCk99cG9IeDo/YcQG9bd26df78+TCtNWvWzJkz59JLLz388MNBlc0QnE6n
P6AA5Vu6dCmqPwI07JDrvD2gqBRQHUC3QO1QR+A6JkyYMHr0aNCqRx555L//
/e/DFCBaffr0GTBgAFjfQAo0GFHiCxYswE20j0Dj0X40fzWfeeihh9hH8Ldv
375erxfEb+zYseFwGCaEVhVqJR955+BoPwBbgK9G8w11E67e9Ops1Sqq/KZN
m/g5KS2EoiEV+Ea0ghOJBLzro48++uKLL8JzIuy2zhFppds9Ne+Xbf+Ja2QZ
tGHatGkIKB6PZ9y4ccuXL2c81vo8Z3HbCVRwTdPYVCsQ5h49enTu3Hno0KFm
lcd9VHnw5/EUKIjp06evX7+ea77NYa0C5YqDTVeDJ89kMpspksnkZ5999mkh
otEouB8cO8p64cKF4HKflmDZsmWwEHwBn4LZlJvkxismB0d7AGr9O++8c/PN
N99IUV1djYrPfgKRQ42GP0dNR43mVbU1wfrooH9VVUFvwOtQTHPnzi038Npc
pdPsLM66U5nV4cO6VqxYEYlE3n77bbT3+/fvD0YRi8WaMGmHoyGA5mfMmHHW
WWcdf/zxUPh777134YUXnnzyyajgfC46BwcHxw4KOPCvv/76+uuvN/d3Pfro
oxFYa/MDMUuXLuWrVtsWUDtaxIlEYtasWePGjXvqqaceeOCBMWPGoFy2bdv2
888/N2+54Gs//fQTmuHNvuEM6BykrampWbBgwZAhQ3r16gXyhozMmTOn1boc
f7NgFDqdTj/yyCO77bbbPhQdO3aELfG5ExwcHBw7LjZv3hyJRNAqP+GEE8Df
Zs+e/eWXX27atIn9ilBuzpHjnedtBWsXGa7Z6Ni0adPAghCUwesmTpw4c+bM
ZcuWpVKpH374odyU4wYWH9tr95133rFuL9Y0/O9//4MtsQ2HQ6HQsGHDevfu
Df6mqiobL4a0RQvummuPLI5SMK1u2LBh9OjR11133dVXXz1y5Ei+hISDg4Nj
hwZa6DNmzDjiiCP233//7t27V1dXf/TRR9u2bWM+nxE5BNy2FpPDHj/99FMi
kUBcHjBgwKOPPoq/Y8eOnTBhgsnJV61aZTtq9n8Vz7let27d+PHjY7GY7a8V
iFZNTc0333zz+eeff/jhh6CXfr9/+PDh/SiGDBkyffp0yMNHTjk4ODg4OJoL
aI8j6Hfs2BFcrkuXLvvuu685tIpADyK3aNEiBF/zTMa2lpejLH7++efNmzev
Xr162bJlc+fOnTp16ksvvfTss8/ee++9kiT16tULtOrdd9+dOXMmHtN1/ccf
f8RfUMGfS4CPgBBGo1GQQPMmexJ/wfPZu+B7oIuBQEBV1R49etxwww34+/TT
T48cORJEDjxw6dKl3377rW23W1tpiYODg4OD49cEtsRpyZIliN0bNmx4/vnn
d9999zvuuIP9ingdj8fZIdpfffWVpmn8OKR2gqJusVJqhDtgXCBRmUwGbAqc
Cvwc9Oz1118Hu3vmmWf69evXp0+fESNGjB49+s1CgJjdf//9eAbPW++PGTPG
6/WCqvXt27d///4DBw4cNmwYnpk1axbsZ+PGjVu2bGE7z5ejapzCcXC0T/C6
ycGxg2Lt2rUI8TNmzACL27p1K6I8iNzNN99cy+v1bwCgeavKYM2aNeBmtveL
Dn/k4OBot2BuHK25Dz74YPr06bhg0yqWLVs2efJkNO4WLVpkrjNav359OBye
MGHCF198gZs8BHBw7BCIRCKvvPLKvvvue+21144dO7Zbt26HH374q6++2tZy
cbQ42mrLXw4OjlYD6viPP/4Il37ooYeeffbZS5YswZ1p06b99a9/7dixY4cO
HQ477LDBgwdv2rRp/vz5//rXv/bcc8+dd94ZD6uqipvcRXBwtH9ks9nFixff
eOONu1I4HI7q6uo2OaSJozXBRmYbO+mRryfl4NixoGmaLMuHHHLI7373uwsv
vHDp0qXgdT179uzUqZPb7R4yZMjxxx/fpUuXWbNm9e7dGzfPOecchIODDjro
oosuWrRoEa/vHBw7BFBV16xZM2LEiGeffXbcuHHpdLqtJeLg4ODgaAa8/PLL
Rx99dFVV1S677GIlcscdd9ykSZNWrVp19dVXH3vsscOHD7/00kv32muvkSNH
JpPJSy655KijjpoyZcq2bdvaOgccHBz1gK9F5WAoPULLdgFFK0rEwcGxvXj/
/fffffddr9cLOnf++eeDyMHhT58+/fjjjz/mmGNOO+20fffdt0+fPh988MFf
/vIXXAcCAV3Xb7nlls6dO/v9fr5ZEAdH+4d1iI2H6d8OrGVtGMamTZs2btzI
VpuiDf7dd9+tWbOGnRzBnkErfu3atbgDx86ZPwfHjgJWqadNm3bssceaRG7K
lCnHHXdcp06d9ttvv5133tntdoPsnXzyyfgnI3K33Xbb7rvvPmjQoC1btrR1
Djg4ODg4bGASObC4+fPnX3vttb17985kMqBwr732Wrdu3f7xj39cccUVb7zx
Bjuua+TIkeecc85FF13Uv3//ZDLJOT8Hxw6EqVOngshdcMEFIHKapoHRHXHE
EW+++WYkEkGl3n///e++++4jjzyS9cihsSZJEv6Ja7Tg2lp2Dg4ODg4bsJ7Y
bDYbCoWuvPLKDh06XH311Rs2bJg7d+5f//pXOHb4fHjyv/zlL3hg8uTJaL8f
RoGbQ4cObfZjWDk4OFoOViIXj8e7dOmCao7Kjjba7bffvueee6Ipd95556Hi
e73eJUuWgOmdcMIJH3zwAdpxbS07BwcHB4cNfvnlF13XwdCOOuqoXXfddbfd
drvhhhu+/fbbmTNnnnTSSZdeeumKFSt69ux5yCGHeDyehx9+GB5+1KhRr776
KojczTffjF/bOgccHBwNxXvvvWcSubVr115xxRUOh6N3794+n+/ss89GNX/j
jTcef/xx3LzoootQ8Tt37ux0OvFwWwvOwcHBwVEW2Wx24sSJt956a79+/Xbf
fff//Oc/IHKLFy++7LLLDj/88DvvvPPEE08844wzEAKuv/76Qw89dMaMGe+/
//5pp5123XXXffXVV7V8NxIOjh0E06dP79q168UXX8zmyIXDYUEQ0Hzr2LEj
6j48AOq+pmmSJHXq1Ak30V4bMWIEnyDHwcHB0Z4Bf/79999v2rQJDG2PPfa4
4YYb0un0unXrevXq9Yc//AHOfO+9977xxhsXLFhw7bXXgtQhBEydOvXUU0/9
97//vWjRorYWn4ODo36wtWxotS1fvvybb75h5zX873//wzXY3eTJk+fNmwc/
wFpkGzZsmDlz5qRJkxYuXPjjjz/ylhoHBwdHOwdz6aBnaJVff/31YHEgdWi5
X3bZZXDmaJ4fdthh1dXV3bt3P+qoo+bMmYMnrT1yHBwcOxbKcTPO2Tg4ODh2
UDAit9tuu4GerV69etiwYZ07d8bfTZs2vfLKKw6H49xzz7388ssPPPDAiRMn
BoNBRuSWLVvW1oJzcHBwcHBwcPzWYRK5a6+9NpVKjR8/HpztggsuGDVqFO5U
VVU9+uijAwYMOOCAAx544IFbbrnloIMOeuihh/ghbhwcHBwcHBwcbQ4Qudmz
Z59++ukPP/zwpk2bNE3r2bPnPvvs07Fjx06dOt14441ffvnlypUr77zzTpA9
3Ae7mzdvHh+F4eDg4ODg4OBoD9i6deuKFSvWr1//888///LLL6Bzn3766eTJ
k2fNmsV63nATF9OmTZs5c+a6dev4dBoODg4ODg4OjnYCk5WVO1+V0zYODg4O
Dg4OjnaI/8vDeqf0gXIPc3BwcHBwcHBwcHBwcHBwcHBwcHBwcHBwcHBwcHBw
cHBwcHBwcHBwcHBwcHBwcHBw7ND45ZdfGrVWorHPc3BwcHBwcDQj2CLH//3v
f7bh+H8UtSUrJU0gjhuG8dNPP+EvrhuSIh5jzzeNAJgCNzC57QE7z5ppoDJa
R57KYGqpoWAF+gtFLdX51q1bs9nszz//XPQKKwX8RaGkUqmFCxcuX74cXyjN
TtHaWDzw7bfffvnll3gLpVlBKtvr0sfKHTHJ5DdNtCFmY9ptZakgNnLKDh8v
JzOS/uGHH5hKywnMqSwHBwcHR5sAAQiR/euvv/7www+LDnXCT99//30kEpk7
dy6imG2owrsI+uPHjx80aNDEiRNXrlxZb//Mtm3bFixY4PV6p02blslkammg
bJTMiKdgDh999NGKFSsa9aIVuq4jdVCXCs8wDXz22WfgNhWehPwbNmyYPXv2
qlWr2pDLMXocDocffPBBVVXXrl0LLUWjURQQium7776Dzu+8885JkyaBt5hv
mduVgONNmDDhsssuO+qoo7p06dK3b19YRWWuAgrXo0eP448/3u12o+iLPlhB
1NIHbDfKMy+QtS+++GLGjBnQs3nfTMg0OfN58C7oYdasWTC2cvKzf+KzHo9n
xIgRKOjSX9lfqG7w4MH9+/eHvZXu9FLu45zacXBwcHC0AhAElyxZcs0111xw
wQWffvqptbsGkWj16tU9e/Y888wzp06dyrojzB4e893//Oc/Bx100KGHHnrI
IYewU91rLcNt7Hmza8gwDLxy5ZVX7rvvvrfeeis4hrWnxfys9c4veZgPgIeA
Op522mljx461PmAVrOiOtd8JN0Hh3nnnHYTmTZs2mQ9YXzcfhoQgP/fddx+i
eelna/MdWTNnzrzwwguHDBkCBVr7wYpUYdXJ9pedFezjoCVXXXXVySefPGbM
GDDw3r17Q8kPP/wwrkFcwdVRyqBqYOaQGTkCe2GS4N05c+ZcfPHFgiA89thj
3bp1O+aYYxRFARWEiqBwvJ5Op3ENSo8XcQ3aD7K31157de3addy4cbiJO3ge
32TFhyfXUbBWADgV3sIDW7ZsKco+rAIlAua5cePGbRS4ALHEfTyMa9gMMsKO
Htu8eTPS+vbbb/E8LvDM1q1bcQEhWaYAkPyLLroIJBMisa45vIUk8DAeQy7A
9HCNiylTplxyySVQEfsaJITAeJKVIyQHdQRfRerdu3dfvHgx7jNR8TCSg3i4
wE181ioDkmvz7lkODg4Ojt8CEJWef/75qqoq/DW7OMwhJFxEo9Fzzjnn7LPP
Xrp0KSIm/pr9YAi1w4cPP+CAA+6///5FixY98sgjp5xyCigEwhz+iZiIOLhg
wYKFCxeC3eEiFot98sknTz/99C677IJvTps2DZ8Cx0ASK1euRFpgC9988w3u
fPbZZ3gFoRCsAC+CYyxbtoyRTIiHx6ZPn37zzTe/9957SAXBHQQGr+DJ7yk+
//xzXOOzSBGhFlH766+/1jQNL7IUQTxAac4991y8i28i+EKAeDyODCK4z58/
H5/FW8gsyE+fPn2ee+45fAH38UH8RXJ4DOJBA8gpxHvjjTe6dOkCHbK0kE08
xsgGso+HIQbeBUnAA6Al4IcVxiKbBsgzevToE088EcWRTCafffZZt9sNSlNd
Xf3kk08y9jJ48OC//vWvYGjgcuA5gwYNwk1W0MFg8PTTTwfNg1bD4TBy9P77
73u93v/+97+zZ8/GHbB0FPHIkSNvv/12MD0wJRD43/3ud507d8b38U2UKXjg
Qw89BOVDz88888xZZ52Fb8qyjOILBAKXX3456Pfjjz+O7JtEHToPhUI33ngj
BEMSUPjHH3/8wAMPjBgxAoUCa5Ek6Y477jjssMP23nvvm266CWmh6MG+Tj31
1BtuuAFC+ny+Bx98EFwa5QLKfdttt4HNdujQ4fDDDx84cCC4HJQP0o4mCcoC
RY8PTpw4Ede4gy/geVVV33rrLdzHZ2HquMDXYDAvvPDC+eefj8yCrIJGIl/M
8FDW+Cdeeeqpp0ACwfT8fv8tt9yCO7AuMH9oA7bRvOXLwcHBwcFRBIRvhLN/
//vfYDWgH7U0qoK9gJz8+OOP27ZtY51X4CeHHnroq6++unjxYhZJWRRmRG6f
ffYBI0LEHDt27KeffgqWMnToUERDBG4EPkTA8847D4ESF6CLnTp12mOPPRD9
99xzT8R0p9OJf+ImYiWY2NSpU/HiXnvtdeCBB956661IDkkjguOBv/3tbxMm
TGBdPRASEROvI4IjFYfDccQRR+DjRx555IABA8BDEMFxB28dddRREAxigF2A
EoAY9O7de/fddwcl+OMf/wgZwElYHkFpkARoD6gLXsd3ELIhHqI8Yv1dd92F
tE4++WSQFshz9NFHg91BY+BFSBQCnHDCCfgJH8cdsFlkCgLce++9YFNnnnkm
pAV/wJNQHVgKCM+jjz6KXNQ2fli5AkCbQWNA5FAQoC7IQvfu3cFVwCvefvtt
lCaegZLBVXAH3OzFF1+EYCC37HVkB9ro2LHjfvvtd+GFF6IQQaqhjX/9619T
pkwZP3788ccfjw+Clf3lL3+BPVx//fUoWTyPh6Hbq6++GoYEMoPsg9s88cQT
J5100jXXXPOf//wHdA7lC/XinyhWWAJk27hxIzQAmUEgoaJ//OMfvXr1wqeQ
hMfjgUWBI8EAIBKeR77wDJjeK6+8gi8fcsghKBqwSnC5f/7zn7BJZGrSpEnQ
Le5DqrvvvvuYY465+OKLUYgg9iCrQ4YMwTMoZRTlzjvvDOIHcg4TuuKKKyAe
zAMmCtWhaMDiUFK473K5UOLIFGRGaUL4UaNGXXrppcgIREWVwYtIAp+FrpBx
WDWsBT9BVNQL6/g1BwcHBwdHSwCRFPzkgAMO+O9//8uGqEKhEOgHQmT//v0R
stevX49AD7J07LHHPv74499+++3kyZPD4bDZnYJYf8899yD0d+jQ4eCDD77/
/vu//PLLl156Cc+DusybNw+0B3H/mWeeQXBEmAYxQAAFlUJkR1S9+eabR44c
CVL0pz/9Cf9ExEToRHK4RkRGeAUTQ+QF30DQvPbaa5ctWwa+EY/HQZDAJRDW
/X4/iB9enDhxIihEly5dEFXBrMAlEMTxCu688847EBLyr1ixAgwKcoIYgJ9c
fvnl+CAbG3333XchM+RE+N5tt90Qr/EkyAAoB54URRE8FnlBWAdhQEbwMNgL
+BuYJ6gImAN4I6I/2A7iOJIGG4GEf//730ELwT2QOj6LTymKAgFeeOEFNhja
XDOp8J3NmzeDTvz5z38GbcM1JAcnQdLgOa+99hrjjcuXLwcBw30UHKgdMm4O
IuOBRCIxYsQICAkFIjsggSga6BDcGOoFz2FEDqQLuUulUuBaKHpkLZlMQi24
gGaQX+gQ/A0JoVEAEwKRhoHhPsTD69APG/eEck4//XQoGaUMwwDjQoHiGroF
Q0MRo1Fwxx13gL+Bc4JO33jjjV999RWoMlKBPGvXrkVCsF6UAjSPUohEImBW
KFZ8BwQPnIqxKeQOHA/U62wKcHgQNljUlVdeiS/jlerqalxcdtllqA4ffPAB
fgXHg2x4IBaLQS3XXXcdih5GdcYZZ6BpsGHDBhg5coS84DF8Cuzu97///XHH
HYfsgNOiFvA5chwcHBwcLY2amprXX3993333BXP7+eefEX0Q4hFSEX8RzcGy
wAdA8BAEzzvvPEQxNnvNHHgFDUAEnz17NngL4hri4IEHHoiYiGuQN7Cvzz//
HPwNVApBGXdAz/AKeNqee+555513fvHFF7iPiI9nEP5AokCfQMm2bNmCx9as
WfPmm2/uvffel1xyCSIyeB2IBK47UHTs2BG0CuQKdBEXYIOLFy9GVEVaCPR4
8qOPPkK0Bd/Ar6BkIFq4BnsB2WDMCvTmmmuuYastEHPBEEAVwCdPOukkBPo9
9tgDLyL0I6yDP4DAIC2QtOeffx5PQk48CalAIV5++WWwBfDJQw45BP8EBQJT
hTKhE4gBkfARSHX00UeDcILCnU8xZ86c2uZe6gi9mUQO+YI+QZ8WLlwIwons
Qz+1tNsN2UTJ4gLM7YcffmBkEqRu6tSp/fr1mzlzJq5Ba0GfoHPQLTwPjoTS
NIkcjAEfh/HgL4jcY489Bv6Dm2BQKD5QHdBmsDikAotavXo1eCAEA0PDX9hG
3759wWPxHSiWaRJ6GzNmDBv5xT+REHgUbAN2CDsRBAFvQQwUGYg3SBqoF4ic
pmkgcjA5kH8kjSYGiBwoIkjdkCFDGJFDM4QpGdkHv0KxIi1QLwizzz77PPDA
AxMmTMCTjMiBqkF1sBwQOTyDjLD5hChxJI0agZbFueeeO2zYMKhXVVV8ClKB
7MFKYcBdu3aFzeyyyy6Qmc0U5eDg4ODgaFEglIMCHXDAASBpIGyLFi1CLEOc
QrhEjANF+YkCZAaBFfEa8YvN/mLBkTElMB9E6nXr1uF5RFUEcUVRQNtGjx4N
BgiShgCHoIzoDBYEkoDQCSJ31VVX3XfffQh8oD3gD6zvC2EdURhx88MPPwQJ
Ab3EBxEWQSQQ/fv37w/aBkKFsI7AineHDh0KgoGLESNGxONxBF9QJgR6kAGQ
wEQicdddd4HY4FdIBToHYsC6hiA2mAZCM8SupYQqnU6DWuy0005IsVu3bojR
4F2QMBaLge/hSXADlgWIBz6JJKAQUDtwgJUrVyLvoDTIdVVVFe7js2+88QbY
wr333vvggw/+v//3/yAkWAe4AT4LdtTsE6hYlxpyB9ozfvx4RuR69uwJxvjU
U08h6SVLluAxUGtoGHRr2rRpUMJrr73G+qzAPKdMmXLWWWdBQnBdsGtoCZrH
M+Cit99++x133IGsQRXQEsgMyCFIPq5RlNAA8ti5c2c8hguYCggPNA8dgkCK
oggLwUdAt0DkIBUbp4bCkTT0ANIIZgsCBr2BQYE9whrPPvtsGEPv3r0h0qmn
ngqWxSbR4QL07LjjjoP9uN1u3IHFonDxDCSEJPgJzIr1yOFT77//PvgtMghp
oYf9998fn4WlIQt4EmKEQiEkjU8xIgd+CNvDr3gXFgKZr7vuOpQX8gIeCHWh
6NnIOIgrLqBq5KhTp06g60xXKGiYCpt5yMHBwcHB0aJA+AYxQ8hDyEZU/frr
rxH6wawmT56MgIVoNXPmTARckCKEdURtkAFJkvr06cOInK7r4APgTiAnRx99
NKIkAh+4FsgV/gkK9/e//32fffZBUMY3QedAwEDk3n77bQQ+xHewi4MPPvja
a69FTARHAoF88skn8RGkhb8IzUgXDAocD7wCfAyBuKamppbyT9Ak3Pd6vUjr
iCOOGD58+OLFi9lQHW6Cmh566KEQAAkhlXnz5t12220OhwPRFh8/9thjkRCI
AagXfmVMBpEXn8LzSBfED+EeNAxEEZwWqSOagxsgIWQEd0AVGF+64YYbwGSQ
ED6Lv2CeYG4Qnk2cwzPTKCAqCBJIBSgBUke+mr0o2TYyqqqCW4L0gkmivCAA
GC/KFOT5BwoQThQEmPann34K5oPsmJ1y4FQgNsg+6zlEQc+dOzcajaKk8E9w
m8svvxxc6/XXX0ceoSL2/MUXXzx48GD2NWQTpAiPwUJA/hnjQkGAX33xxRfg
wKBD+BT40qxZs8x+XZgEiDqIEyg0ShD2s2rVKggG+geehu+j7AKBAO7AulCC
eB1CnnLKKaBM3bt3B1NFAwQcEqUDS4MxgweClCLXjEijvGrpdFAwNJQXZJs9
ezbIKvgkDAPMFnQdaoEJIcuwfFB3WAWKEuWF1yE/jArioTqgaYA2C64POugg
yIY2xXfffQcqCI6Hz06fPh0MFtwV36zlO8txcHBwcLQ8EGuSySQiGhuLRGhG
hB0wYAAYF+L1wIEDEftWrFiBGA22hrC+cePGd999F0+aQer7779H7EPQvOaa
a/AXv7KFnwj0CJrgSyAtYG6ImH6/f/78+Yiny5cvR9CcMWMGaCHiKaInksOv
+Ozq1atfe+01xj0ikchPP/2EFxEcQfb69++PF1mibBQYXA4x9+OPP0bYRQxF
SGVrCsCvENPxFqIwgi+bDAa+ilwgpxCMLcqAVHjxhRdeWLt2bS1ddKBpGn6a
NGkSLsBD8B3QIeTlPQqoAlLh10wmg794cs2aNfF4HFm45557wB5xB/LgXbAp
5B1JIxXDMNavXx+gwNcgxsSJE6HGlihK/IUAoL4gxkgF5QiKAsnBixhrAsHo
1q3bFVdc8dlnn5WjGZAfBYF8mXP1V65cCTrHNnArStG6RUwqlcJbyJp1M7el
S5eCYLPuR5QCShw6MT9lXSUNM4NUrIO0lg4TL1iwwLq2F6/DVlHuYHSXXXbZ
yJEjkVncYfuEoBBhKqwoGVBMeNj8YGW94S9KE1/AX+vyE2QHLJF91swvnoFC
kF/rFzg4ODg4ONoEbOS0a9eu1113HQtYiKpsYnwt5Wk+n++4444DJbMdLTI3
RtN13RoB2Z16Yxx7rOiDP1MUPVNudSfbGcx8Ho+FQiHwUtbnY/0Oros29W3U
WQx4GFyi6FgEU+DSOw05DKLZAQlBMlGUoKxsHNNkTShK8GcwTNDdHXdBJSzh
5Zdfvuqqq6ZMmdImGubg4ODg4GhXAOv47rvvxowZM3DgwE8++YRtUmH+lE6n
R40aBQJg7esoer21JG1Q6iBm06ZNO/744z/66CPbJ1tT4DZRDsjq5s2bv/32
W7Z/mslUQXvA5fBT5cMs2jnYEDByh7YG7wrj4ODg4ODg4ODg4ODg4ODg4ODg
4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg
4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg
4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg
4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4ODg4KgAXTfaWgQO
Dg4ODg6Odg9D88keWSGQPXnI8rPPvtjX48ndlv2pHK3IxoJeyUkgSi5vMOST
lVi2AYlkkn7ZJQjOam+kIQQlGfSIcij3ZCYZUN0kRVGU3Gow6FMDCdu3MomI
V3YLDqkhIjUZibDf43JK3hj9V1p1OiRfvMFv6yGP6Anay59Hxu9yeoLJhr+r
hX2yLLOCIwWWu5R94aXRoK9adHpjmQZLaEoRV12S6HQKTlcgbv96GYVnIgGf
RxJLEk2HfIokCOx+MuCuEuRki9NVI+p1VTkcVYIYSNiaRbYJKtLCXg+rNFTV
itcfSzZew/WgsabVXtC0ks0kwoobPiXWMkJVTro1/EazpNtcokLbXtkFb6KX
/qYnFVFAlREkVWup6tmUSqdr4Vyk8oZqCn8yUhFFJpVR8UeNplScpsizncjE
/U74JYfD5Y22WqINQyUFFoa/7YKdo2iRgmitWNPGMLJJWYBFiaF4kiIRIrFP
WZeOSsTSPIkMVYGekJ3E8NRQLJ3NprUo/aezXpeihVW8JarhmnoezD8fdFeJ
fuZhMjEfjcKeaDKtZzPxEPlUleS3/VRNWgupEjLSog45nYxWOxxONUfkvKLD
5a9MzIqg+/GKDU9jyPpER3Uo1ah3Y6qzyimHY4lowAP9SN5wIh5VJYegRFNR
okC10fVCQx6VKN7K+Oh3bB8qo3A9GbFN1NAswpDK5VRaLFLkkApDIUqGuiY5
XKjVTDKeIlbWJBXpMR/hh9WBaDIeUV3UITcL6cpL1STTakZkE4lyRlgPGlmy
uYSMTMxVV61aFa3jN5ol3Ya8ko7HUjb8rAB6OkacmLfUYo2QyyH6k0YqKDhc
8fq+03jkirtpfqlGg1SkrvkSBZKFPYR5VolemvFGVZztkqfp0BOiwxHOGHHQ
IiXU/GpuAhrmeQrD33ah0FG0YEG0TqxpByDkocrps5hTxqcEMrU6ve+lrEn3
S6hBQrBAHalqhzNS0QvVxEm5iA0m8HAgeD7CijETJW0Wp2KNKDUxlYZme+gJ
b0O45fZB9zm3z5IzEeQxaGdYCZ9YWBANejequIJUR3oc2Xd44zT/etSjRHAL
HkNtpEc2iBrFhrjCMgonbsqmMjJhWrHZm/CC4vrsanBGFRxKTK+TqpEq0hO+
OlXja6RRI2134LNI1aZI+iVBaQ1OZUkoi2oltAWRq20lv9E86dbzSjoELx2r
P2YZaBLaaTsjoy4kWirm1RV3kyodjEShRK7KFagTMRtlXVuSDS9taXmaCOZg
4+2IWjTc82x3+LNDWxXErwtFRC7jk1mXV9YkcnrCTzrbPaGiN2vA4itZo8b6
+oLRWDRCOtXqk4S0B6vkXP9Pwoe2p0MOpwufyYQCUfqhdFB1i3TA1R/VcvLE
rV6u+AEjo0UCquKPhL1uQZSTheLoKRAiiQ3gxtIkV6l4xCt7fJGo3yMKTtEb
YYwy681bck06GfYrsj9e/uHaTCJYLTqdTkkN1vnXqCJUuYLFmqM2TPvBWDpJ
n8cFeZxOVyhZ57hL3zXyM+po9guZkh7DNz3+oOoSBUH0RStJlXtDC3skJ+li
IsOzgNvlCdTkf/N5yNC6S/Zruo3CA7LLKUqSSPyqTfe4HnNS8Qw9HY8EPS4Z
PEhPJYJ+xeXxhgIKGcdVQ+XSQmPNJUoul6taKR5bsSu+bEhxi7QPGbeCBeOq
epD2oUFUJZhsgopKVE2bPLSfpEQMPazKVJG+pFFraGHF4/Go4RU21lIgVZ1p
6eloOABdhSLBaiKOzIwT0CI+kpLoUgPhaCSSzFjF1EOQw+V2uVWabqhakljb
3y5fmSDRlZMoKpbWQqRft8opujw+WrsbUY+sJVuuRpgoTIhWKyUYwjcFwaWG
9QaUgp5JhgI+1Rem+Qqp3iB0o8WjFDH8rxXoBLpMhHyK7A0iR0hF8uQmjVjN
GN+pJmp1im6a/XL6L7HPIhipqEzmJjiROzqoYcQCCvmu4JQDcYsVmdWnsBTC
Xpi6EoTCNdWNSzlK060kaoaNoTiqBHgM3VZCKEkkVVSwaV/rSUWiFohK5laX
rS8u5VIPWYPK61UC0Tgkh+BqKFHDci26goni6l9Q3DVNqXQkNqH6EOGFYD7w
xL2i0wPBbXwy0blfpir1hJpNnsrVoe+YF23qu9VAkkEVGiL6hyuTgzU2vstI
J2N+BT4xpLqcklLwerm4wIpQI5XOrQYCigRDE5VgXg+Ftlck8/C77DwPkzbs
pVYsKn4WduvCX+XyIn3HLmJI8VRCJReuajUMlYShPUlesrnOUTSkIAqMoMjs
C2Fk4lAmkoYyE3qBRyKhze1m847IFCSV9oXWV5F3HFDC5pBUn9/n96sescqp
Zsz7lMjVxLxFFT+TjEWisXgiAa9ZGEEsSIdz0wAURRLosGyJMy+AHpfqum31
AIlrYrTM/CyYU5Wb1IJkkJhBNR1wtHg5mwdSUS/rmZc8rqrCgQMjhZasQyGj
b2kf8WbOSNqIB2RiYA7BF454iTAS7dE3LVmPBb1iXmDbh/UkCLAbF+mol8qQ
I5xwPqUdOLSz0RnJ5zemwl/JNbkL1VSD7bu5L9gROerbhWA0yqSKl5cqrws9
GVYgSSiZzmRSATfigkqJk0Za69F0bTbuogMZmQKFU2vxkKqRiij23eN5IpeK
gWQ5SeFmSa10UdsQ1FCE6pB2c5WkZZBevlCGNMBFobhL1rb49GwmrDhJTtOZ
miJVayFIIiPugAI3QUUFqjYSIYX2EgR1WzE00smcH55OexyOgKbbWotFqhrT
tIxMwkt05SCj55GAaW96knQJopWTodqucnqiRSNqWZovTzifrhMP2+Urg5RE
bxQ+NugmNS6+MakIDkEOpdJoejWuHllLtkz1sUpoTYh5IUe1P8zMQI1l6y0F
+OiA102SCHqdAgKXnKwhraEqwck8T6jQ0dckAkxyORAOkReJxdZazdhIQmmi
LwG1KMQmy+nfpi4UShZGQmRaJm2doXHKesvDZLZCmAiWrq0t8ldFpaATU2Gd
ZgY1IdbEqyAqaTXIzipBSaTTGd1GQjJrxeEm1YvaRmm/SkYjHlsOJ2uy2aJS
/mKFjW1HfVSHZL5NNCCLlEO6Q7GIApsRvMWtLWtxN6nSkVE/jz9BR3kEmRq2
kZBgbClzXL7AJ8dUUfCEUMNDUItDCKeN7Zan/urw+XKb+m5NFo6JOlhHEI4p
k7XxXetW+2WJKtZZ7XIKroD1/XJxgUKP+SkpcojBSFihdF2Jpkttr0jm6HIb
z1NLBiXxq6wZtekIqZJ0QnwdkauvvNJQL5sllYmqtGlPDT0qV7lCVkdRb0EU
wMbsCxBG9VHipM9ZkpDlglgTUVy+mG5kaVxgk23qq8g7EnJELhCOhMPhIPyb
UEzkUiFSjtaKX5OK+2nNdXr8Wpl+fkb/cl1MRtKDYnWqlRSVJYE+3yVFq4xD
su3upZYp5DkPG/aVUxYvV+6BEEpZCpTyTtLNlaMrub56klmDdZGR7NXA/BxO
emltkuh140E2DzMuKqAB4HHRWCDlqmQmqpSOj1CGVjf7JRXxqYG4rqcCHiE/
wF323ZzC7YicM99TzQZlKkhVqN5cEkQqgZF5OteRtGY8InUyyGudwgmvEKLZ
3PtlhlZzRK42N7iQSyLhzQ8oG7kXbdJKk5aa0+3T4PkSiaIYYV98RHinTUCp
zXVUqiz5JqmIqbpKEKg/dMo+EiXKiUHn8LjIgJXmF0S/UWtrLYVSWUwrpysq
ATFgagzUWtx0umQKwcIVKI16tXEftSidqFhwBfONo4J8bSZjxBIbTDPSMZ8/
UmP11Y2sRwUla199rLBWJXJtrUpqbF29pcDSIx7Y4Wb5R6M7EE1TRYmqTSMw
q9YF2doI8eeEiFoJVVBVwlq2Rgubc/ZK9b/eri5YEfGYFLpWiwQC0ZSRjiqy
P6XrCTrRl9WCuupjVwp1Y1iWClVZVNPgbWpQJumqsxPdfiC7wAILSrmMbbOB
tji7KeTrEU3dVTK93FLcTap0JCi4kbssncngjKKZEXJXuSPIt+go8cmMQotu
Of9BpdgeGi3P5oZVB5v6XqRmi4OtEHrkiE20LBcXcmB1JzflI0nmsylRW9sr
kNnW8xCS7MivZkyHfP446bGp68eot7xSpKuNdk3Q7wsySqo2IAk+2olvCQGV
C6LYBkrN3qpaKpUrlMjo6WSKvmsmZGTSNVQs4rTdZFTLNqjtsCgaWs0G1UBx
jxwNW2Kh0ozcNKGy3ZGMyHnzboEOlYoVFMXmHZluhLpZh7+4GU+/XDAkgYAl
FfGKcg/EVaftzBBKGj35QVzSlCAWYiEe1q6nouhTYIEFD5Nfq+RwJptB0wsw
9xRh+iya6lZE5MggsuJySrLf66qr6WXetf5kQ+QaJpWtes3QQJZUkJUvuddq
CodWaZNNzLFuS6IFsNenhW7lH7BNKxFgjU2HXLxsuUzxVSRydRI2XUVFeSwr
ButR8YQ1FLGHTRWwVUWB3iwj+Ha8mjVyfeQuaaLmXXeRYiJwWZ5QMiKL9AGb
fLFGd2FHuX3StfXXo9raMtkp+k5pQnZVaXW9pcAyqZTM2495RcmXMD/LzIZ2
DhQMDCX8riK/UUt5lCw6XbJltK5E/5/Y2WdBvoTSEEOGwkVBUr1KKZGrXArl
NFkqaqXaSpvJ+VmdBXqoQ2HNtZRyOdsuELKIbVbi7U2qdIzIZUh/p0wnxQVk
p0CYKU262JBoEr5YqibDkC35XqPlaWB1sKnvhSgeOSobemyDpX1cyKHQh5h0
vdT2CmS29TzUYErIpKm0BpQXHWKTAkm66Iy0tuJaWMx1E5UJqfU7DRuzL/g1
FaaUzCHkB16LJjB4xbqOPttAs8Mia1nUYHOf6JQN07BWRh52sawQNI7IkZyR
kpn8DsXGrE3Q+mi2m9iYUenEPD2b2UyJdN4psS+7k5aKVlPmgTIByCDNE4ec
79SgnQNotltqU4OJnPVhqkDLvNxYIEdL0xG7HjmfdT2aHpBI6CHvJpCXugpr
+y5DvkQsv9k5qHJSFX6nmGWliPN0mh2kaN2FElkLkVPoSBb7LS7aeqGyRC5H
TpjrIGOvpWkt/DKezOqpqEwH4AIFExzLFJ/1y/aSWHrkmqKiIuMvK0a+nehg
RlgkQAnzKQ619rqq1VW6rQqdSVVu3rQRdNMFfQKrdzb5+vQjxdouyMRDEW1j
XdKNq0emZoqz0yQit67eUqBfpivZxbolQmhTOC1OI5PS2Gr8pJY2WCp51kez
U9CTz7pEJNpt5c8HwVL9f21XFwryJTry4xqkFGKhyFIyrCnQpWEJsUQtrPrY
lAIT1YiXvmIrKsqFBXebGhSLiGR6DMs77e4rXR1QyB8spVzOtisRuUrF3aRK
h2wpkkotWfMwcs76lLIxsW7mTwEPsfAoLRgqagA2Wp75cxtYHUrqeyEs+qkc
ekpja9m4kP+d9WjlfQilhZqd7dkRuULPQxVYt3xVT4bCSSuRa0j1jNLeGDCH
WIpRCJRIqkQJjSFydmZv/TkWSehGOqi4quwaYmQFKzgG5SQ1KW3pjMoVeccC
m6rtKlmrRNfiOb25NclsKo6omBlld3K8KxPziJK/eMMxI+Rx5MmbZaTA/uHc
KImFY2f9uY0doqam46RbRtYo1a9ys32QyKYcVbTblnI/uhqozANhD6n7pSqg
45W58mUrQ0ltpf6TuQLWGU7jJe15zgdoH5kyQaOG3cNsvYakhrR0KuyVTLOn
nW+uIrMvHMaiynf7U9mUz0U3YEnkpiLavpvXn7d4BIFKxXpNWQ9zBakskqjm
oqoEJXI6aWYG2EyhaDKlxfwC5Zx1CqczPaokLxpBbCaSqIaL504acWdemJqo
YiZBBheYmeUDlk1a6yJizhRjQsn+A/bFx4o7b8AFYI3NcFKLRVN6U1SUZzgN
EqM239tct5GLrWlZpTLqTKtkaI+QFjpBRQonkpqmoTVZrinJlo27Arkta2zy
laYDDQ4pGEvGyU5BHs2gvQSeYDoVjy2f36h6VFCy9tWnQGF1CWmb66pVflyp
cimkk4lkIiSJSoxM0RHJrpa+OLUcsdzmPjmKldu/iEyPEemmMaYZs2KtDsQz
GmnXO+VgOmuU6r/Gri5YQXvYyEyAuJYMyk6nEqF5kcJaJhEkvUlyMIYv11Uf
m1KggVJUU3o2otIpPaFkvaLSdJ0RTfvig9dKJGSdkyKZIW/QLackr1bUjZLT
fI78WEu5jG2T1Y50cDMXYVmNoA6kYnF/M78Jla5Wjwr5gmAaztUvKraz2CfT
OVoOpy+cQIqK02bdXKPlaXBYKa7vhTCTKKtYy7SEIpnLxYV8woTTsulqejLA
Wge2tlcgs73nSdMhbIcciCYTkWp4XaLtuvBXf3nlOydZTA+ZI84UlhBQT0FY
YWv2Vv0ogjNMAyCdLBctSIhO2s/NrkTuXMo39VXkHQZGyucW2dCDIClmP4eR
irCli2RE1aWy+5lE2EP7QwSy/oWMj5sLPZjd5oczrEj73QjTrmrC3n2sIpV/
mNYIT8RyIxtmc5IhHZXH6c4vNEsESQ+q5JElgfAHpBTzsz5V0e3TDJsHoj7W
wStUeyMlgc+I+UlCLkUh0Ycu7YmodMap4A7HImwPPUkJz/Z5qMsVlOCSaP5a
DiZsH9ahXpeQG9mhJIchIqOmhEtEIHMS8l7UCCusXETVS8WGS6/wLt2lVhRY
WoLsZ2uIcoUriHI0EZXpPp+iHConVU6KdIStPpBkfyTsoyoVmELy09eJewwm
s0UKT7I5//n/XPmlbfnval46lUJwut+Z+oYo5F6cN4tNuxW8kUQkt3mvGw2y
orRYo1tweWS3KOQNqWLxGWbpuJRAutjFpBRaRk7Z/1rjVZSKeNlcesEJumqd
nGZjRXmQEUB/voLZW0udVFNNM5MnhZWcVIFoWGU3kahBFztY/vOU2fEyLQuW
+Qx2+UJ2hNxHXGxpZMwr5YZCso2rR8Qk8iUbGGSbxwKYCX3wnsq+6Y0mIyo1
AxJ6VpQvhaxKXRAJzgYNr4IMpbjYw041Y6RUyV0y7yO3pIJ4MDL4QpZjF5ix
TqfykuRkOkfaUT1ptq3+i+2zGNlgbr56LpXclphs5Rd9a/wHY6zVp7QUtHyF
cnnc+AnONj6voqjBpMHm/9D526US6qlc1Wb/OSV3IGapSXWxwOmNaCWlbOch
8xU2oiVZSQmSGouHq5kD8fiLKk6+uO9++v7G+yUI72Rl5yFNVSPuEkmfJ+5X
i7m3JGXGbItP1rWQlM9std+mA7kJ8jS4OhTU98I6EpBYNZfkCFmgVKJYuMpc
QYglm7GXjQs55BYLOESJPKZQ71Rqey8PeqxQZjvPE0yQLpf8zAT2qWhd+EvY
OpPSiqA6Rcas0Jpz5oO71VHA+OspiAIF2Ji9NTk2corfBIcU0nRrQqMfY5RG
dEkSuckmG9dTkX+10LOZdCqdLplyoGdLJyFYXinsMyj7cLpuSZf16VQqnSn+
BvkhndK0dAXl1/tAAYxshvRvlM1HE0EmaWQtopO9nhx2UydYM7Out1zP7yti
6Hq9726vVA2DodvONqn7uYZ+02gOFZamRVailu18amTxQdT6zkFroopsxciE
nSWLbZsmFQVZn+jyJwyDzu7Ipv2SYD9Nzg42+SIFVyAx/mlNrlH1qFEoTMju
gTKlAGMwVZXfgYeYX00qRtbrEe9dsk62bmhVL1+y5nY+tXrFwq+nLlAJa6y/
mx82ytSPklKA62Pzdsq+UCIqUUslCY1cEk2qotvvIZtc3E2FXnnuU5PkaUB1
aGB9z6NRirWJC3W/0ZmQaAnDcgpdZ/22V8bzQEUVfFJzlVe9BWFBxRpq5Oy+
4TZab0XmaALItHnnDr0KuDJIN7I5eFECspmYVHZb8srvcrRHJINqtUepdjo8
ZQ/saDzoCkGXL4L2FLhtEm18wd1i27jukIBabNe7kx45d/G0Ww6O5kKL1PeG
w+Ab6nK0F6QiXtFtdw7gDg8jJEv1bKZHdj2SZJs9lBryLke7Q1QVzfG15oMR
C8j5kTiH6PGWbHfKYYP8LlsOu8kVHBzNgJap7w0DGRyno4eC6I3Y7EfEwcHB
wcGxY8PIQW/Q+DUHxw4GQzcNnFs4BwcHBwcHBwdHcyLXhiLTQTnV5ODg4ODg
4OBopzAyCb9HtJ4joCd8Lm88E/OJTjIELHnt96Lk4ODg4ODg4GiHyCRj4Yjt
JqC/QtRk0jG/y2nZTC+quIOpdNAXIhMI08Eqh8zn9v7GkQypolMURckXtZn/
r2sRj+gUhLqd7rYTaFwEvIrodLXWhoFkM0bJV7L1ugV6MiiQI8zKClTvA20H
IxHyuUj5ubyhhq+2zARkF4pcdCmlm0kDNVpEwUedYrUSSJUpdCMd9/lC5byH
FvaRU/cAWVYUJX8p+6bODqgeyeVrK7eTjAQVpN9CDVg9ybZKEyTV7uS31kJz
iJFJhBV3iygqk4h4ZbI5VWM8QDrkUyRB8FY4/iaPdlxbbaBFQ17ZVV3RQbUn
ZCIBn0cSWUGQ7f0Fucy+iy0IesKCO+iXq+32UG0P0EKKx29Tpk2Op3pMccom
kdPk3MEc5JeoVzI3Km8IalKggUo963H1ZN6De4gHV/IeXPYtWNRSnuHXhWwi
0XoLKtkBNJG0odONo4v9JNtjPBQJ0a0axdKTaJoAPR3xucqdjdUCSHtFy/Eo
mWTcpCb5a0MLOh1CwG7PSYaiB9LxWDl608rQ6P7zihcxjiwhbNg6/Sw59UYk
VCrul8jZN0V5yYTpjpeqnDvB2W+bVy1Adp6MlClEcvSeUw7HElF6rqvkDSfi
UVVyCMqMkCzYnGzYWkgnbE+IbhYYIZdD9CeNFIiEq9hPWg2vZVFRjPqR8z9G
JtZCiqpJayFVqmrc3u+GFmXnR5clcmatrLc6twXKevU03eq/ZQyyJaAnI3UF
QYicU9nONkuj3Sl1UEHwmKRPLHPiQxsjVXcKQwG2I57WWIickfS7VPauEQ+q
ZF9lodw25kXQwwrbJLzSWe21uXMfBG8omkhEySFubj85/YWI7fx0dUt5hl8T
kn5JUFpLRfQEBGeeWpOTDgqPcE0ElECu99rw2RzH1lSQvfRbjchZQc7BUXIH
wlmvGwOyk7AQaxfTSzWPkI/U9FC2Kk+oSK5MIhKOF2yXR894yu+UTjfwLz4n
XRHrjhaSneaxyCXQNa3MHuSk598VTNUllzsASI96lIhue7Jh60GnJ9y1RAdI
RkaAs+8WbaqxNbMY9cPif7LNWeULobOzuhrlAXLnDpchcu2oVtqgslcnh3W2
ms9vBiQqFURj0fiCI3FKJEdi+UWn7YkPrYNS15oHO9HMPLK2DtsTT61ELqa6
/QW8LeVxOCNFBZJNhsP2J0cXnkVuj0xUkbys96PAYQZcrmi2BT1DM0JPg3kq
sjcYVN2CIJjHo2QSoWpJFEWn6PaRO0Y2EQ3JbjkQ9EmC6IutiwUU8rPglOmp
K0Y2FQOFlX2RkFdyii45kNbTQcXtdDo9vmh+P2XN55Fwh3W0aiG6OxMe9tAk
Cn8tSdHGioxMMuBVVV8gEo0m0/UZeSYi1J0LzFIv411pxPfZjsNlkz4PGaeD
mCF6MEcqHvHKHl8k6veIglP05nds01MRDxnPk1zkjLBiQyqn9spKGBGJV1Zy
TToZ9isy6eUmWwSThpIoKcEvLdfLUomoT3b7oQc9qbgkl9vlUcNGrRH2eiTJ
FdJq6h7IRHNH1QiuN8e8Uk37moNEgZqP9EN77fyKgdeDAX8wFEmmmpW8Gul4
wrQBukGrHCl6JKbgZkGjNVeLc3LSg5YK+9zSybouf3ocbelx1chRPBIOBKNl
d1gyt6Wg5ywXuH1yOLugRCM+URCckpy3KSPml8loruQJlW7lpqej4YDHJYci
wWoUrSTHSB9y2ONyVSshUlIqLl3U0nQtjn8p4VhYRm2VPJFUVgt7JVJtWenQ
07Q9Pr/iQmoebzhHKRtZ15JhH3EGoij76LE5sByJnRbkcrnVQjOwGh495TMR
rBZJNtQgIpiRTsb8iscbCqkup6SEltcjP+p4HFaKdCS3WjxJyEaMNCoUrXZu
Py0vI6NFAqrij4S9bkGUraIW+h96doMSDHlJfXSp+UPBihRVWvSpKCQnD3h8
CborfLHnLD7FO4MKS4veHYylyxRrwSHgxR+01MpQ0lJba22yr6cSQZQ99B1Q
4KtdaqikTaGHFDfShW3EoXnJVQ0ZyAHlmuqWXHKwhuw9WODqgVTU54Jno5IX
fbBQqzbvxnJELu2X3dVkAMtHFFukZ7sqUKr70o8XqbfMnRJ7trH/dEB24R2J
Hs3mjWUMPR2PBCEScZxltKrDGOgkjmoYXDQa1wodYEHB6TZi2CBZTY48jse8
YvOMEFVEGpVRUfyhSCyWKCrWUtfKECUnxUT8UsU+qwrxtEy6ZGg1x/bTiqSw
mJo/eyQjC1JRM7EmJlc57E/EoF69vv5ww9xXiPoBMy9kM5YmeoZWBjupvIoc
cRsOsfNJPSFoXiIHQyfY0W+go/BXntzJdC6X4Og7bAA58imT6/gNpVG1A+w8
PlSqaEjNnbMWBONw5btEyGHTajRdm42T7hTRm8kmQeYFOZRKg4QV/5ouTFEO
FYdRdhKcGk4mqeuopgNtNQk/ApezANA+Oe26JlYQZFnnSai4lyUbC6rsQMyA
3bSTmAqR5JrcBTmzL3/mmuALR7yu/Pk+aUoayTQ8PUjO/C02JHu116eER14e
VlHJm2NBr5jvB67RQuRE41CiRjfqrmtWw9WbekiTo7SRInVmmp+cImekLA+Q
E53AQxLpdEZP0aOQPWxkIaYIto4lRmqNQw1FyFG55Exn2xGWrN/lLCoklFK1
3SwLe9DOVU/JkWOljf3CWkyJXPnjP9h50KUBI0mOI69wcEYd7IgcuSO4vNFo
QMwfhx1TRYF0J+oh0gcohAuDlJFJeNn+nE45HAmYBUoGcAWVfjqtCuxTaX9u
J08PuBA7TNDp8UcjqAXsrdwhoR5fEMyRjoBE6zWzorqW8MO6JIQyI0UOj66S
fOQMUC3MzssuPSLHanh60g9ujBqRJifUO6onzfPnzhJ1VsMGXCPfqEd+doY1
OQPXL0ml0a5QDHqIthvcozYZ9LDjFFPR3FGkkge5KBx7LfA/OUVV+6FymRZi
1sZlFSWfDgvMUdAONBLpSjxnbQGRy6B+il60uYygm4z4QB67YrUQOZsPWmpl
jbW22mQfJJB5DAF1kubLW3IiGzugnE5UMOgB5R5W/HhTjmaYn7S6etQ+ZJZM
GM1GxdLzpCxa3Vz6LiNyKrKjEYrij9EDoUoMskwVsMJGMBv12ii81J43F9v/
UmIMHnJYZ4p5yFgmFQvRMzrJIF0ZrdIcBTRIxk4m9RV7P6s7ta9WxUjnzsCV
1OJGayNRr8s1IoqTHNebStGGmLNoLNK2H5WMSDq9Bu1wK0Pk6omn9ulmEyoa
aKIcSWaMpF/KDSiTnrEqyaPIsj9WHFbYwIctn2oQkbMI7C3OS5M8Qxsgq+bj
C8C0CvsPqkpYy9ZodXNsDDZAwJrJ6agi+1O6nqB0gkWuhE+sErzUGvU6bRi5
MQI6DO0QSa+Oh57gjCKrU5rdrwUpFsFIkcNDZdJyJGuTEQ1ZX6uRivl9/oAV
fn8gTIZeioIs+6evyK0hiMbjkYBCq4+rdMQmFfGpgbiupwLwePTwXJZBhdp9
TVRmklPn7GWC06yVdv3ZqD06t34lVFYy6xnO9QPrMTFndYXXhnXUhnaMu0jX
PdpWck6JdQ/Evc58crkyoqwvLdvPOqBHD4s+dp6yLCCU2PZi6bEQKZaiYgqy
6pnVohE0Z62IRGMF/WQJvwSZTb+XjJEXYrGoD67A5YvG8EYklmTyoxbL+Wqf
RcsxV2olMMhMDzFqVyENLUCmqZQdWa1DGSKXKz5CFEEjWdAX3aSY6cQ8pSRV
a6GH3PljmuvKoq7iGMT4c143gczm5uOZZkB75HJ+SfcTV6msbFRdo5zZJO2p
UD5sWS2qCHU/6WSCokPw5HMKnqxT65LzQyP1yc++4AolMnrarovXIgaN7EL+
wzopa1r0RIF2/LzQaVsUVcllFbwfQYF6wuxaiwQCpOFm4zlNIkc9lcS8ipGO
+fyRcsVq6ZGz+aC1VprSlss+0aqTVkmj3HAtfZhW25qoSjug9FoDivWkbF09
1bnT7dOyRipR3HVTYJx2YSKuilUuWbK64voM0qwCVpR+vFS9G0sVXsaercnp
ZDKMkCtryxi3YRkit9Fqlh5XSnuN4xb/b0VdwZWrVoWIkfnVDnIM/faiostl
HjXPdqKKkPfhlVwrNONySHQ4kxI52w7D+uJpmXTpwa4G2aW48OxXo+iwdSOT
jEDAWCzkJfOfw1S+omCx/USuCZ6hLVAgOW0m0HqUjsmi0yUrUok7YtDIaJGk
epUqm6Bv45EIt3F4Ehl6WnfuPOK6x+x+LU7RKrOvjjCwWqPWS4lZkPXmP0fO
Zi0/cSUTVcqUTiakuJyS7Pe6ckHHMgiSF5g2jV0BvS5dGyJXqvY3lPqVUJ/b
t71Z/jq3JMoZTcWrBXeOdVkeKAgZjPVJgbTmF6Sg/YQEL2vYOnJervFgxVT8
n7OufGnBydYmWdAtlL6StyvRMtOV8kynnalQd11uxjghz4UpVhbehshRAYhL
gTKpen2xFDk2OmN/7LLNW2WKvvDJ0gcKzIzWMrEhZlaHLIna5vIZPeE3o7nT
nhUUW2OVHM4nlSEDGLlfs3Y5tWOqqTB1lQ4hP1JZJq2SmkJG1UkVJp0JZboL
iohcA1xW4euCTUdEBc+ZJKt1ig2pvhpt88GCWpl/smz2zYfLFxl1d45wOkPp
n0OQw4mgW8qvkSx19YlA7swyOVDKMQpMzi5MiOxdsxFdr/M3q0ARij5eql4b
hZexZ2ty1MPk52OUMTAbrVIf4lQIsbcyfCvq3ipXrSwIy0xR5WbtNh9ox3K+
0Y1GukPy55aFVnCtcZX0cKqqqijUGERYqK/cJD77eFo+3QaCUvdKwaK2mYhc
Iz1Dm4DKmafTuZhF15tIAaJhv7N0gIBFf4Eu4kuYLeLKHomtGDWb/GhHhRLr
zMfsfs1WCC5OsxbQ3hJzww1GlYv/YzSPNiQ94Vy1puXrKrs1D+muF0qInB4g
TVc/iSfmJHZLYMoLTLsR8txSt+/rsFH7ggYoofFELlvmOm/suYEAy6YlViJH
SbLpQtNhNo5cx4cLdEab8x5/LJVKJrSUFo+VmTxA43sZ/1AZRjIg5Id+yPyn
womRMUUo6v/PrVPOd1OQfh6ldJAipTgFszmcShRJTVtkDVsvlidydcrRS+MR
tV7LuLAWDBVHQ9soRr2HTF/T/WKTiJxCltAubWRdE3MDsgTQfyGRs++Ry/9E
G1yuut6wWMCf2FxgfvXKH4skdCMdpKvPbCzEWvto3TfLkdYpMuOxqUQua+uU
Cl4XHZYmpBELRWoqek42kyGYX/eYiYcimm5brHV10O6DBbXSJHLlsm+yoGx5
7l2reRhb9oSSVEiz+WPj6nUtnsyS+WB0yKmk+VOnSfswoTqdashPBzpZxazX
+dsSudKPl6p3SuDZYoUvnWtrz4VEjnwntyY+1yNnde+FIlm0yta2Sy6p3Lyp
uoIrV60s0HUjY/ZXF8wQbgIquVxKXAXmkMhcOIvGTJS6Vi3soz1SZOK0izSQ
pTKzpins4mlD0m0gyFTkMmvKGkvkSoaJm+AZ2gTUHUl+qgQy8iv64swnVAfi
GY00h51yMJ01WMcyWxmSIM09KaxlEkGZ9v3G0qRz2uxPtiz9oL2R3rjOxqeq
nHI0mdJifoHolvZceYLpVHzenHElv9ZaUywUmYbCUNLIxBgJ8ZuEzMjEY7F4
AWKxRK4pz1aq0tpCFtaJOeqihxSXS42kEyGvP8zWhkcVJ5pUJSlnyDwxtz+V
TZGuZsETTSTZSBmLyyxqQ+Ak6WFz0BkIRoR0Cgn+aAk9KFG7nYqKlVBZyexm
lTtkakkOJ7VYNLXZcs1ck6WZRwd2hTpmYdQ9QJu0zoimxePMr2l0IpPHdsSU
WkXuOywvfo1Mbw/5FI9HURWPK7+mQ08nY0XFhFLS6qsLdOahyxeKRsIBv9cj
OosGI2KlEzkMMltYZH0LdJl8zldkYh5R8pP5txmiMacSwUfD4YDX5SxqSlP+
X+31ejxBveBFG9DCKhgqTYc9bGYO0bNMhuP13Dovpy+cgOUrTpRLsYsuGVci
3ZuMRQcSmQybd+chs6HY0CR70nZotW7aVW2KtnkTDTEzqyx0clFuG7RUCNHT
RYYuciOkdsHFYngfj6ChTQ1p6VTYSwbEDctUhNr65c8ogpNNjaOT5UrotFUM
1iRxB1nt8OeXw7Cpj3bFVed/Ytpmn0nX84O/toqygtYOMsgY15JB2QkjsvWc
GUIMRKLb3JQnKRhLxsnESzLj1LZYIYOT1mjbDxbUSrO2lsk+GbFyei2DgPa1
jPbgOejywNyScHbfxtWvmyWyD9bGkB1fcWO4Tqtvv3BjaZggxUGmzZMZZWQf
Cb22gkEWVQErbARbMbVYvetKFW5vzwX2T+ftVEleOCs2mVlUwxlcR/PlaKtV
OqXfFYilNC2VztTYHctrKTjNvloVgvY4OeNk6YWL9VYhvqkuUXJ7XKLTpQYC
qhv12xtNQ4mKJMmyW5JD8DB+j+R0eSMhxUlzUVvR5eakSuupHIe3GX2wca3W
svCirZTvB8h7yEx98bQh6TYQFYgcbdGIVs+WQkguu+ckGfI2B/so9CZ4hrZA
bi6fIIpOMn5Bpx4ZSTbxuEqS6QxPx0O+Mblp9i7CutlCgyqyAZfCJnaOf28E
GyxWAmFQdVp9RH8kyuY2C6Inmjby6wLIY0G65DPmZTOf3QjIRb8aqbA1xUKk
VJF1tbl9XvsqUAZpnwsV0FUtCYLbnw+3JMCBHS0N5cYLnE5ntTds17Ywwgrr
7hZVL+tPViepEpMkHIvItNUjKXg3HfA42deIKgRR9gYLp7Tbqb22HiWko76K
Sn5sxODH6E2BTqtIKVQeJ6na+et+b77mpllwusN5amlofoF1M9J/+CwPGKnc
bFsysZOCNM3KdZ2hCpNUnNVkYrnDXK2cDJDOgZRBZmvLtrPQGgLYZMUu9Npc
Y794qgYbmxPdblIHg7mue9YnL/kSlMRaPysUr39hU9rynbfmi6UCamGvKLCR
CEH2kz0GjFQk19uphpO5WfeCArVqISmfYrW/RJnwyXTqtSgHomGVvaWGNfDY
3FuiJJClmp6pn85SyJpowiWiET/bXs/ljSYjXvOtmM9tmpnLmyuRxtQ1Io+X
jLiJaHnjbwhmY6RyRuJweiOlpN5ieHjSlR+dQUzRNW/uRRHcxEjH6pN/KWnv
OIgbEhxSqKgxVCJGTSJICkvyyJJAkkME8bFKLVR7I6U5M/3PB++xnnyBJK6y
vackBKFSl1WIbDC3dqOs57x30CA2NCy6fYgdqVzWiEVFmUcoKdbQkriXTikU
UAe/+bLog9XBZF2t/HSBtbaWZj+fnOCNJCJ0SRQ8lX2fXDrkzM9Di3hEs4lU
6upDy+eRZTsuj+wWBZevlMqbWv0kUvzukCH9hLwHC+SHDlGsxXouVwUssBEs
ZZSq10bhJfZcav/JkGJ1Cy63+uFHY0QhV47zZtlqlRA561vektXfBe60tFrZ
QA8ijjidgmjuiJtBDCBLKrJRgUzcra1B+9AT0ZMByR00apMSqFE216hxip6G
7Jti0NVJVNteqFKwHRS2c63WX02aZ3pIrb542pB0Gwi6OUApkTNifoWVmuRR
zYXPpOffbt6UkY56RBYOBHPVvBZummdofZhjfHoma1W2uadCrW5rYubvdGZi
A2HoxZOCrKveSn+t8KWaDHmRNNZc9vO1ykHPliSiZ3PD3Lpek61HAN3Mt71e
rF/NsnZZ2YnWNmpvlBLqg6HXNQyt1437RrageSI6AxWn/RP1ZjKWV4yA6PCS
ea5ky6+S9nvrwMhN0LJAr6+gyz3Z8Bcrf7VJkyuMmmxuOnBjXtJrStJqrJnV
pElPQ0PlLTQ2Mhsw29RyN3KyNlhUnUiabqhrLV11W5x+fYpCBSk8yLt+z1ni
ZCoXq80HC2ulFY3LfoNg5+oNUs/LlmmdVhscJpri92w/XqpeG4U3wJ7JW7TL
rWEyZWJep+RL02wAybDs9NgsNS0quIZUKzgc6wMxVVSiZDUKAgiai/lDELJh
n6J4vS5Byo2J+8VyO3LYwMgS3dMlGPbd7I1BnYesN542a7oNRq5ktxPNGamb
AXRLLneorcVoEvSCFXA7FHYwtRtauNrlUTximQWAFd5EJXVptXRgwmm3xJ6D
g4Njxwad0yJ5Eym0mLJpLe51ieYoRvMiKosK6e+PMyJHusPkGJnCISGaZDxs
cqMe87hV1dW48xTYkoRW2sm7HaT7a0LMn+v/tB16aM/QtZCLHOMmiJI71L5O
qKkfO5za8+uDXI0dGjXITmKuQNArte2JnBwcHBz/v72raXUeyc6/w/d36C9o
lV3qB9Rai1lEXgURhkYwiwhCEGQhQkAhoDAgaEakQZkBMRkltGlQPkwygkHd
QQPqATWoQV7UQgunzinJ1kdZsu/c29dvpx7eF3xlub6eU6dKVUf1vBtORX+4
HEYyXA8ffmOglhz10gJF3Lz0mEBsj5H+69/htq9FtZ1u//yvdAibZOL9l/vm
k2Xs4HA6OvP2B8FH5ftjQ9eDvWrfTeGV+H/T7IVPqZ+dtrahFRQUFBQUFBQU
ngvtEc9vf2B5X0FBQUFBQUFB4SnQMcBbRJYqKCgoKCgoKCgoKLwTfvRxAgoK
Cgo/JjTHQBwCY3h3HXq/iSI0XzT77hPh3h6siDQ4W3j7zf0mTzzbIOKE2B8c
b577m1P5nPhU+JWiSCPHooa3LX7xQWgCQ//z4JeBaxHDn7wQ0+WWThPpkTVd
6duW7QBsa4BtO3DqVO3qI7WRKfIksAydTluja/LQc4huzA7nbPLUs+EYOnH9
XfwMK8S5Z9of8UYPtzrHfGaKP21w85AY58NYM8sVfCy5sy6goNCDgSpK0nRH
7lCd+E3GO3CwuvNGLza2ef7wKdFdGek77Zbg5hiszva7GzLB7483zv0dqHwE
r2Hq3BTHu480u+BT4VeKOr9qpj8f4HTrfVydmVA8Wchigs6ULj0mqmsLG971
I/GxQOQxnLDqNOfaI1cxyhnq4rBftgarUxAZnwuNneoydq/a3G/qZ/pKxMaO
BEVX8ScF43FlzL4LdPhC4rNS/JGoj9nj3X2BW8b5WKZrZrmSzseSO+sCCgoC
KGhCZII+T4EioCt6Im+BLiC7mwIH7463zP1jqXwVUyCv5rzvqUMfy68UI0W2
JwOI4AwKSkKDcslNGcH0TCroBQcqTgSYGt8Jt5ZN2EISEVH4UsXYXu/4vUYx
OOnazV/ZhUZdoB2EyRRGqOOXnZa9hYO6ZZzvmOk1nQ8m9527gMLHozr4BqGG
Yeyd+LsysfBDd+4Sl380vLTij835IbZNO4x8qpG//OufUVSyIPxOOzqduyx0
CCG6ptvhZaBpIsckuk7ocKIOK32L6rouFRTuWH1MI8uwjy1/csqjwDEsLw4d
nqbhxid42s5j37G9KHJNTdMoqnaWicdL6EQlHyhck3+0D3XXK4PoxLD8yX4O
Kxx+C6X+IU9ckxr8B1Zag6qLQY0g+7bKD75tBlCC+pCEvDBxGu15ial9UffI
Y5fwOlGUjxnWyYvEpwRg+ygLuZHRfDRr8ngPv9eJiQV+MPdnoxJRc5qgRagZ
HEBYZ4upv/3qP2Dx3w1Dh/LMiRMdQcIG7sSmw5/vHV5CFhko+0KoM+htPTm/
kgZsC98yoJ11Iy7WyjMCSIFols97Bk/J8pJBM32Di7FJ4E+6LLCxMFacN4MF
RnsCGbsRjDnVkXNh+ekhsAjnAsxmBUxop/ZJwVipO3HEm1GnhpNdBBlQiVIm
0DabyDW+DQLEp7pIAsfu33delnmsd889RmqhtRkg+CVZdrjInW/6GWmTLtpw
XP3CoWiQ/HvTxeXeufF3TZmGrhOkiWdqxB4vCU+dFVbKiWLPnByr9SjFM+vi
1ec19ZzwcOR2yFvRjfNTdbB5zydG1LenxCpGdawzsE/TDzyqcYswRbLzjKa+
xc/quWfjNTlyV+QkWcJz53mlVcs9AxTEvGjDTUvSHHr9Ms3Aw0Kn3y5yXGNK
ZpxM6iTnmY4MaWSW291kks53ryCXm2gah36AZ412Vej6wjOUxwMi4//LmebJ
DbIuXeD8wIizahUKT4UOdtbiBrY/iAaKHpmrv2hCxbIWittddbCIEEw0DG33
WfTbIgEpuiivQXoHtZ5hhGsS/iGGkarxCB8HD12vuE2ODHTh4aTr9giCdMSb
mUWVxagkCKdSczMTJytqbpyiopl3bIV4Mf9sh0kM+qpC1rm2dv1jTleCJDoM
KG3h8GLbcVXXs54hhKGhhAyEoTUUlT53R7qjx1PF3S+o4PHu3eQeyhq+6HaS
hmRYEi8jU8jCntuMDhfzwADt46bjsw2INKMgXrCW0axMXUF7VXeQIuV1eSj3
J6SyV802Qfu7iCyhDrnF1O+/7E9IJlGaODiPcngWdcJJd1AvEFSqsS4nVOiz
+WC0CK1/Rn4lDch54RW0T2fxwa1vlGeKXpzX8qMARSp1F5THN7iQmATRLD5s
sdjmOWpJ3TE4sdnMQcnXQ7LKQUZQ8xM+NwVtwRVdNVR11y/iKkfU2dRMLwpn
QthYfomanqgXdf3ADyCICSV0WRZ5l3ZYlnkykatTDRqhQmFKbX0it+lnJE26
aMM5wSUYhp0UqEslMf6ql9ndUdAgnu69TpxVT/E+SER5UOD+FRRPrKsBwVlT
HFTrxode4VQz4ywFSVzcapS18Ais8IRgLvXSJEDpWCox46lvsb/4zcyzcaoC
YeeaxedyQkNWt4JDCjG6N7g+JfyD5uR13bD5t786/ts0x2SdKalxLp0kr/A4
03FDjM3yjm4yTuc15LI6D6CmoKkqFNtdeAJB9WdNF4HNC21oOVnXidzdI86G
VSg8FVhGULS6bLsqz09CUrYPJLh6y04szA6GykbT+64+8EeUirE8dsVAiSoA
VGw1dHXGHyj+gEdME8u2bUvIvkska0drv7k3bNYI64WhvHV3opcBUOucu8T2
usPCrnd60m2Xs4jVgaGKf4wtkHUuYM5i6WJr45rXpL4g56p7J1xSALVizKxf
J0eRuIsMShUPw8F6RhM0keskZXsqr0FQ9+b+lFRigtowsrOACoe5xdTFTQEK
iIDiXGONBCPXuvQXZZsEz8fvsgFPIOTtu+GRsSrkEw9UKpeUZ1E370o6C2Dg
cP53s1vNTEIMAcSEH6Asu3P4NoSkNGu48kJD1olFNnyQP9jS3noBrHKM5k74
Zz+GVrjc5PXftR6svLmL4bWfyIVJmiRJxJ/R+lF1oEBS5onl4EDc75eJWeXK
RO685WdOyyat591qjpFB3jB+5FSubTd2ViOKV8qzTrHMuib78ii27uJsEhM3
ipO0hScYB2CwzBPOYd2Mb3g2/1IFaPxe6HyN61HHl3w7yXHRFDNIjVPqJEcX
52T7U47Wu8ks8YfJBZTcGVKMyju6hpczViYhijXEJnFlQjtSskZd4L4RR97v
FJ4XedjLRdkhWovMsMeecPlnmfpEo67nCJspQmP0JA4AZ7uz8qZt6mbQCofE
Rb4vJGDTNMejti6bnuE6CTf70cUbd07RCSttmoN4nPGyIiB6JHbDrinMCgOR
FacWvvWOw6gksmjBdVxiX1kevPQprGY0K1Od2UQ3bOeyCnRv7k9J5XfTBHHx
6g6mRo1/jScZXZSZxCfA77IBEU3sGDq1A88QY5mkPPOfTEhHFsjfO0su5piY
BLaAn1UnIewNis/InZ0MaTSwzHmjoaRYTORGI2AVv4w5pfIJ6nRrtY1cESA3
1FdS5nFr4AqYEfYTuRulHV9f9zMy8553qzluN9dg/KCHeSM+aj6Rm3UHaXlm
WBRvbl2zlMm0tHymKmvhmw04SmHNjM/bnm3hnWRczziafTvLcZ0pqXE+OJGT
u6xbhidN/CFyORL+qEjC87m2iV0OFzOPUL+vI6YjPDDJmJysybPMPSOOvN8p
PCtYeSxaVh1sXPgNC4ZWYYtYqIBsj/64IaWl8DkXT6Z1irt1w4thzTH+/B9/
OlkFyuM4b5uqFC+qFWXd3RrL2umgP6yNQHw1rvNcL/aPOe3qRO6iGbpzD0Vs
av0SRP/dxkBProszuL7EP+NF3OTCIhThZeRay2gMXNuhuBAUDI9s9+b+lFR+
LwT++hmRYMosui2mRONf5lHa1bGLi5DOZMyVzy2ejd9lA6bl9yGFGS9cynlb
vWoihxvNv03sJRdrJvFfX/IWsJLLdLOM4gx3PK+LRVkY5N9fW3h7IufT9Ymc
3284ra7I3ViBFHPpRZnzUWswWFHsF/GGiO4FDbcncnM/Uy2b9D//Z9at5qmP
DPIkN/5XT+RaSXnWKS4k1rU+kcu+lbbwzQY8VxHWsV434zs822KSI+P6iFuf
F45m304nLXMHOKuF1DilTvKa6QpfbLubjNJ5FbmIOuW3WZFvOUPd+RUdIot6
dE1VDP53zkJPVnu9ePeIs2kVCk+ENiW62JjINDTsGqxrF+ZNgxFTmhVd1swv
7zaO/8zBk9OkbPIIfmhHWf3NFxgTQqOsOCa8j1tffx2KLfhDUZVZoEnjWA7O
ZUEYAqJEqcaDPu+eNMBOAaEFBA7zwVGAuBVrU3wqseOif0i3oro6ZpLg4NqB
2AyrGrzudXW6391jZ8lSs8/6dSeCYb14ZgL1SsYw8Kk/n6eKTdiq6LYyGtca
v9qHx6aEAA/djuq2uzv36UPSk1DJjhDia4pD2MA3vkAI2RZTv/uSDJuVDOdL
MPlBZ2L4GWtzW1S/bMVFOynK7CA7nOy5+D3X8awBy65xIYwqqFpxHoJ1yIv6
v5flmaEdAnigIDbutnTlFhdzk/g9lln3k5y3uaPzZqyR9B1147KuEo/CpA4b
SvhwsfMuzKNKXbI4J226mSgWB/q3U8WIMHyDBmDGC8YYbq0ai5c+YQ+L3z+0
86TM/Q4XtkYBi/O7PcSfd7yAvDDBYd7tm/TqW9b9jKRJv513q3kN8Le2OF1F
bvy4qELD+Q+xaCNn9f2lUkOazeMU/2FpXU0HL3q/mBjJieO4h72AHV0kV9rC
E+BAr4nLGW5Q1uebZty3s9yz+Rc7l2ytyrjGNW09Lcvj8bj8duLNFg5wVgup
cUqd5CjT2Wr6xSx7jpbdZIxROt+8hlyBOoVl/8En4K9IIbvxNlnXLnD3iCPv
d7FjGG6qVueeDrjmoBmWbRLN8IH8Ou3ftSFUg7exrC/+5RciKlg34N2iOgsp
bqXp1E4r1mT90oThOPhDPa7gDT6tX+w1DhgkOYSGwg1RMbfXOgsIZkFM/6tf
i99qXpqncKgUhOZmTR8sqhGiQ8BqKB6Xytjpc7dM/ivDhrdZMwxq7QPXF+Ce
fwiFKvaa2feIrvRNDAPWzeTr34njPYkdHhJXFMZNSlaloh3EP52aYVbDy5UQ
CUNs28CZBtvIaIauEEG/L9TGMOzd/vPfPJD781HJccojiK+glk01Ph2q7mGq
zkRRCQUWnES0WxuKxa4dcRzjRSN2wD1h5Ygy2/JT756LX5j/zBqwSxwiKuV6
uBP0p5/9haw8s3QyDFkX9m/A2xPnbS4WJsHKmA4V3AciYocPxFqfCCerO6cu
FZ0uyVKcP++oAy/ZwYLGMowHwwjt4ZC4Ux6KaB/Ca0Sc66IIznDmG+I8a0EK
HKU7uvncHXxLtIMd5csyX751opxbeWj1W0twkRuJF43jssG37Hrf8u9fbfqZ
RZMuu5W8CrqXlmeZ8fPS4g3a3kuXFnvpAv/8T664zTsUqYvl4U9VFXuQ4oV1
EffzoXZpWQiuNepmx2SPTUGt4JuvF1YxBc4NkFb9thn/yU/oyLcsPduf/cMv
HHitGMLYDmkgbjagtt61Dy647irxKAQvBcy+7apk7M02mLplnAsnGefNONMx
2WOzvNVNptbRp/PZ3/zsNeQKMJiXRuKpFUN50Y+5vJQuNZfnFi7JGneBkt09
4ix9BT5C3n8Wn8IPjI61zeT9nO4k9DG7+6be3SDO041+0LFTO9lY79gfs9V+
2ZtjzUy7k7WnRWHxDbL3QNdXatoyp7oqy1cfWnlpvjPbSEKe+zStJ6GSQZPU
s22g20zhdoPHx1F+z2zNp11otfLyvJca1HvwK2lAdmnmLcrn6SxiaTa5WJgE
WwbkQCTMtiQuO8nuwWWHyT4Up2yWWhEQ2f7p/ZCUefJ12wqTeBOzWDbpog3X
ITP+29h0Vo9S/CrrWmthnBuQQ8NY85AZ3+/Z1krSTdSaNyxhk6mlcUqdZPdG
EtGb6WySW8UWvQbSQB88VRm82g/zMckb5bfImuR5Ly+L1h58uILCq8DE1sxH
F0PhfTDa91T41ACH+9GV4+5hf1nJA33CwP245z0B/seJrvQdNwxsvQ8omoPP
WKXuUpGl8LTI+nPGdtLtCYVPG7A/JQ6YImJ/SuFTA4ttakcy7thxTyz5S8YK
nwK6qt98JIad3jgBXOHtwfK9tiPWpsrJBIoshadG14O9156awkeiYxd6Fb8K
Ck+Fi+9VvfP5ochSUFBQUFBQUFBQUFBQUFBQUFBQUFBQUFBQUFBQUFBQUFBQ
UFBQUFB4XvwfIN0Qvg==
    "], {{0, 463}, {835, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{835, 463},
  PlotRange->{{0, 835}, {0, 463}}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.9232698845736413`}, \
{-4.917272299787022, -2.916958790055452}, {-4.802082014766363, \
-2.907350210076324}, {-4.687459684935774, -2.8967830308252953`}, \
{-4.555095030441234, -2.883216839566258}, {-4.423597210208034, \
-2.8681635821256526`}, {-4.293020864021, -2.8515303604929025`}, \
{-4.170912371077428, -2.835289156934919}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.150248909108442, -2.832330676950903}, \
{-4.033822103643843, -2.814902011807858}, {-3.9058371536100243`, \
-2.793823074632166}, {-3.778882957192024, -2.7709783772431757`}, \
{-3.6529595143898415`, -2.746367919640887}, {-3.528234011569994, \
-2.719720784462923}, {-3.4048736350989985`, -2.69076605434691}, \
{-3.3312445465187386`, -2.6718979713819926`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.311023103549228, -2.6667160538684658`}, \
{-3.282878384976854, -2.659503729292847}, {-3.162248261203561, \
-2.625933809300734}, {-3.0355850732188814`, -2.5874174405191366`}, \
{-2.910886554027016, -2.5456002388695005`}, {-2.7899970138450723`, \
-2.500692513124415}, {-2.6713913101017632`, -2.451894210788062}, \
{-2.55529464641222, -2.3987210195643054`}, {-2.5268948598598335`, \
-2.3841826252958045`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.5083132649990985`, -2.3746703512607654`}, \
{-2.441932226391573, -2.3406886271570086`}, {-2.32149665384358, \
-2.270757451496446}, {-2.2049759376431, -2.1931145571327453`}, \
{-2.1836090875740726`, -2.1779144726952193`}, {-2.16239330646329, \
-2.1623939143506177`}, {-2.0921897134106664`, -2.1039664181091156`}, \
{-2.0238078284271244`, -2.0406402207628824`}, {-1.8908665698831582`, \
-1.9017408101004456`}, {-1.8598896501590607`, -1.860195557476043}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.847411719298531, -1.8434605562413249`}, \
{-1.7650261980387776`, -1.7329677337200802`}, {-1.7039925878171323`, \
-1.633200907456278}, {-1.642995989114665, -1.5185719141830747`}, \
{-1.5708914557473657`, -1.3655766371195601`}, {-1.4902186562593784`, \
-1.17663913270079}, {-1.4612121086113714`, -1.1066193775465087`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.4532228495188515`, -1.0873338709667282`}, \
{-1.4434129647334821`, -1.0636535026892417`}, {-1.386048011694285, \
-0.9314719147521561}, {-1.309215914941473, -0.7721205114093137}, \
{-1.257049222467466, -0.677365366400712}, {-1.1886100458490425`, \
-0.5677752665166358}, {-1.1101511275746274`, -0.4601244810994211}, \
{-1.031262560038967, -0.3726638092745844}}]}, 
          {Arrowheads[{{0.0022277319044136106`, 1.}}], 
           ArrowBox[{{-1.0172810013216191`, -0.3571630015304853}, \
{-0.9928317410538181, -0.33005706216004904`}, {-0.9898852208174405, \
-0.32711222853519073`}, {-0.9848170473295229, -0.3220877175692126}, \
{-0.9802887161245222, -0.3176533362190035}, {-0.9763854171043386, \
-0.3138841766411199}, {-0.973090241018405, -0.3107499963281398}, \
{-0.9657698348273245, -0.3039607378040966}, {-0.9613697905896375, \
-0.30004315048499475`}, {-0.9584061487440964, -0.29745520894337474`}, \
{-0.9543147945649911, -0.29392472468546343`}, {-0.9515174020169785, \
-0.29154061135242143`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9516084451053033, -0.06523547752049742}, {
            0.9557145704571358, -0.06674977744953513}, {
            0.9601796817075021, -0.06843726908438384}, {
            0.9692881591111173, -0.07207217200866495}, {
            0.9871039244230294, -0.07987462634232631}, {
            1.0098213304778072`, -0.09097110302125604}, {
            1.0334000861709127`, -0.10398857946163592`}, {
            1.053682578680689, -0.11675065099941695`}, {
            1.1164751374408441`, -0.1671558397968645}, {
            1.2035073850865918`, -0.2819800081776856}, {
            1.251297643251618, -0.4022152568161103}, {
            1.2769736671057266`, -0.5249642780161711}, {
            1.2897234130545858`, -0.6868723177563528}, {
            1.2882306445751872`, -0.7654649838419726}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.2878342248049537`, -0.7863360613477445}, {
            1.286782294249278, -0.8417190815872893}, {
            1.275431107875935, -0.9857523460390922}, {
            1.260408274839856, -1.1302867381172301`}, {
            1.2462500709291837`, -1.259189941154288}, {
            1.2307544035336047`, -1.4749752265388445`}, {
            1.2398847475149366`, -1.6184734709550543`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.2430289349615122`, -1.6390003110209548`}, {
            1.2753053213895014`, -1.7557538405392543`}, {
            1.3328646225090561`, -1.8575414030571575`}, {
            1.4119560986371988`, -1.9403353658194444`}, {
            1.5100493469234653`, -2.0071214045877492`}, {
            1.5654727888533422`, -2.035140708537259}, {
            1.6246482194023089`, -2.0599059974083533`}, {
            1.7377494660370862`, -2.0968053819878922`}, {
            1.8532580330277657`, -2.1234192283528}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8737891616999267`, -2.127126042814971}, {
            1.9898608928561354`, -2.145267698268104}, {
            2.1259371380617926`, -2.1585837832739316`}, {
            2.1443796886960507`, -2.159885600122217}, {
            2.1629085552556866`, -2.1610806913839484`}, {
            2.265127244264287, -2.1640615377497676`}, {
            2.3692222644280965`, -2.1644716921254634`}, {
            2.5555097563775733`, -2.162216940336607}, {
            2.7064411840093414`, -2.155710372801467}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.727296655775417, -2.1548113053398232`}, {
            2.746080494881605, -2.154001544777485}, {
            2.9402179305122145`, -2.141145491877457}, {
            3.1372055138414234`, -2.124968768065883}, {
            3.336836203983893, -2.1062707422297504`}, {
            3.5387373273460123`, -2.086490278365637}, {
            3.559234732485802, -2.0843691834632234`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.579998696573013, -2.0822205047363838`}, {
            3.7033369355306607`, -2.0694573228535265`}, {
            3.869510148913121, -2.051973583058255}, {
            4.037184607483303, -2.0345280133429693`}, {
            4.2062879512311175`, -2.017609568070816}, {
            4.37685478384703, -2.0012821111433254`}, {
            4.410742942464092, -1.9981486664670907`}}]}, 
          {Arrowheads[{{0.013693349002390925`, 1.}}], 
           ArrowBox[{{4.431529116282499, -1.9962266875709642`}, {
            4.54898083113611, -1.9853665976268204`}, {
            4.722685416260172, -1.9699876186316336`}, {
            4.897987862381033, -1.9552697652680981`}, {
            5.001099999999999, -1.9470780674228507`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0469913446647572`, 0.13960679780488885`}, {
            1.0678545104268942`, 0.15799517115032766`}, {1.131704077624237, 
            0.23318552360560432`}, {1.173581607902117, 0.3109640402499393}, {
            1.1996650252201015`, 0.3853135851007226}, {1.2168234918020349`, 
            0.4607542397153947}, {1.2269507495166883`, 0.5365682330857322}, {
            1.2311749756771533`, 0.6123766731123109}, {1.2268881637731937`, 
            0.7604238696716898}, {1.210122952562666, 0.9012374500712123}, {
            1.2058876882681784`, 0.922535264502607}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.201816257649622, 0.9430092108150416}, {
            1.1735674475795552`, 1.0850636076476206`}, {1.1308349488320604`, 
            1.2478527375507436`}, {1.088138219954312, 1.3902855797676787`}, {
            1.0496044369420903`, 1.5142067149144531`}, {0.9936208372120959, 
            1.719400553022653}, {0.9886939101406258, 
            1.7496932318129694`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9853427738600705, 1.770297331174876}, {
            0.9674925153999767, 1.8800477167624596`}, {0.9716341097387515, 
            2.009687974798874}, {1.0048541811612395`, 2.117514968566351}, {
            1.0507234453721652`, 2.1918279019349645`}, {1.112609831833985, 
            2.2573683128005726`}, {1.1892714637214634`, 
            2.3151877532298974`}, {1.2327850245853764`, 
            2.3413979663714852`}, {1.2795087986177027`, 
            2.3658929886215003`}, {1.3752163681015823`, 2.407150464973173}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3947612611779936`, 2.4144271491923748`}, {
            1.4981356918275865`, 2.4486647561812136`}, {1.6227568977545068`, 
            2.4802464965002997`}, {1.7557458495300655`, 
            2.5055765883513836`}, {1.773838163746119, 2.508505204770449}, {
            1.7920520870339482`, 2.511330040001087}, {1.8829207299487896`, 
            2.5220769890675636`}, {1.9760650445624155`, 2.530563986902854}, {
            2.140466919991407, 2.542341217650042}, {2.2159638977096385`, 
            2.5449425094717077`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.236826359477328, 2.545661337599883}, {
            2.310028687233835, 2.548183565936368}, {2.483774445795057, 
            2.548810236880661}, {2.66072829518043, 2.5449404356017493`}, {
            2.8404075178217423`, 2.5371770102040863`}, {3.0219432220962106`, 
            2.526605087275688}, {3.0711290334305326`, 2.5230416875243318`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.091949307460017, 2.521533306198759}, {
            3.172278835995083, 2.5157136152301027`}, {3.3238255795586182`, 
            2.5033649763291668`}, {3.4763162937253536`, 2.49002089649119}, {
            3.629483819433828, 2.4761431016344813`}, {3.7833488511633613`, 
            2.4619054172859607`}, {3.923740233901927, 2.448670544488651}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.9445227213701126`, 2.4467091092052295`}, {
            4.09370655188126, 2.4325932673204047`}, {4.250158365959473, 
            2.417948710011891}, {4.407475541442964, 2.403469385634862}, {
            4.565706723856362, 2.389167453825374}, {4.724869161915338, 
            2.3751472535459395`}, {4.776054647279399, 2.370788591107829}}]}, 
          {Arrowheads[{{0.004908918400785792, 1.}}], 
           ArrowBox[{{4.796854213986672, 2.369017419270908}, {
            4.884980104335562, 2.361513123759071}, {5.001099999999999, 
            2.3520979744299115`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.0023562024782328673`, 1.}}], 
           ArrowBox[{{0.7715077259966748, -0.6047804377826475}, {
            0.7724891280459537, -0.6005440212379703}, {
            0.7736384522324323, -0.5956822495157593}, {
            0.7747819306141369, -0.5907128956162866}, {
            0.7791524965407319, -0.5702413449008871}, {
            0.7829679971814123, -0.5497321557950129}, {
            0.7872851889573191, -0.5238557497700511}, {
            0.788826921499597, -0.5139152929829497}, {
            0.7897098684925478, -0.5081426794180949}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.754641308981747}, {-4.987123409942099, 
            3.7537289630626987`}, {-4.8559731929390635`, 
            3.744222842572535}, {-4.725565165640829, 
            3.7337922439393942`}, {-4.595946909062258, 
            3.7224124120866033`}, {-4.467166004218214, 
            3.7100585919374893`}, {-4.339165631029672, 
            3.696696363253014}, {-4.211926933451744, 
            3.6822948203986354`}, {-4.1698083997644035`, 
            3.6771420625948386`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.149088042118113, 
            3.6746071456541887`}, {-4.085554438550508, 
            3.666834480204425}, {-3.960152673392035, 
            3.6502958595004547`}, {-3.8358261650423984`, 
            3.632659475116796}, {-3.712679440567672, 
            3.61390584388352}, {-3.5908170270339292`, 
            3.594015482630699}, {-3.4703434515072433`, 
            3.572968908188404}, {-3.3417147524274875`, 
            3.548859069743164}, {-3.324344808962932, 
            3.5453586567885447`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.3038813508595797`, 
            3.5412348348551315`}, {-3.214982771760357, 
            3.5233198808680246`}, {-3.0902735856492987`, 
            3.4963373806949845`}, {-2.9663684580410035`, 
            3.468046524281396}, {-2.845053467634286, 
            3.438249532663897}, {-2.726013424070531, 
            3.406981308012493}, {-2.60924832734974, 
            3.374241850327184}, {-2.494758177471912, 
            3.3400311596079693`}, {-2.493938748394221, 
            3.3397697515487694`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4740513517821916`, 
            3.3334254248798456`}, {-2.3828614013143974`, 
            3.3043346974217975`}, {-2.2738764257545467`, 
            3.267137925335616}, {-2.1678032507923595`, 
            3.228440843349425}, {-2.0646418764278356`, 
            3.1882434514632245`}, {-1.9688714098322864`, 
            3.1483670582222314`}, {-1.8762809748419973`, 
            3.1070920825764663`}, {-1.7340916163728237`, 
            3.0373468314101304`}, {-1.7017365443601657`, 
            3.0193929634026637`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.6834835810946, 
            3.009264372340128}, {-1.6014943433637459`, 
            2.96376844664178}, {-1.479419265043802, 
            2.8860225513420383`}, {-1.3687964906420305`, 
            2.8037747685815297`}, {-1.3548840696570976`, 
            2.792567717026802}, {-1.341194002254179, 
            2.7812705723149995`}, {-1.293643417711545, 
            2.736857069347606}, {-1.24950037900353, 
            2.6908171392276152`}, {-1.1686714610166167`, 
            2.5949287263315566`}, {-1.1036102397942578`, 
            2.4901099485128486`}, {-1.0866024747009568`, 
            2.448009938737057}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.0787833101524658`, 
            2.428654844042125}, {-1.0562466678030586`, 
            2.372868980466359}, {-1.0297238081148303`, 
            2.245801052471566}, {-1.0235245181768586`, 
            2.094142347462744}, {-1.026054800301557, 
            2.038406679001097}, {-1.0298980683168797`, 
            1.9920577924391443`}, {-1.0352157495393222`, 
            1.942480398960713}, {-1.0502677483359133`, 
            1.83101150663298}, {-1.0707865798760845`, 
            1.6982848082012625`}, {-1.0845658307401418`, 
            1.6050081004589085`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.0876164489569478`, 
            1.5843573679445044`}, {-1.0949791116649537`, 
            1.534516854523591}, {-1.1108612747120052`, 
            1.3987359969735287`}, {-1.1220381556555894`, 
            1.232246993562529}, {-1.1237959385146008`, 
            1.133616517907011}, {-1.119395555186957, 
            1.0199935998320242`}, {-1.1045793894379512`, 
            0.8865533108914763}, {-1.076438818446057, 
            0.7551043063038928}}]}, 
          {Arrowheads[{{0.00973216948252008, 1.}}], 
           ArrowBox[{{-1.0720689514223118`, 
            0.7346919745634728}, {-1.0698314928394836`, 
            0.7242404558788151}, {-1.035003099799661, 
            0.6195203320148397}, {-0.9788057033106877, 
            0.49502835530450934`}, {-0.9771790043007643, 
            0.4918417688936617}, {-0.975117617388063, 
            0.4878371907321426}, {-0.965618956600522, 
            0.4698961309049516}, {-0.9563283004991168, 
            0.4531045191819554}, {-0.9463687120828183, 
            0.4358227782570725}, {-0.9304542150729244, 
            0.40979073744301964`}, {-0.9199012798314067, 
            0.39398912497725896`}, {-0.9132951071998802, 
            0.3846777362212145}, {-0.909488474477975, 
            0.37947537550009436`}, {-0.9068786433609404, 
            0.3759689758748384}, {-0.9032987671659818, 
            0.3712369683376381}, {-0.901178783950706, 
            0.36847863162859235`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.46998134110877565`}, {-4.887458859814655, 
            0.4672890223197789}, {-4.742882681120235, 
            0.46333604536140566`}, {-4.598025005395357, 
            0.4588486358376718}, {-4.452885832640019, 
            0.45382679374857743`}, {-4.292281212271507, 
            0.44756009865049545`}, {-4.166595563519805, 
            0.44195849416257765`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145741423034559, 
            0.4410290591149486}, {-4.130638467907636, 
            0.44035594502388065`}, {-3.9884626520997104`, 
            0.43316543511919386`}, {-3.8449068577440495`, 
            0.42503386194055626`}, {-3.6995405481136845`, 
            0.41580449147241905`}, {-3.551933186481649, 
            0.40532058969923357`}, {-3.376012544887601, 
            0.3911572855653127}, {-3.3126735680733406`, 
            0.3853546657073187}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.291885777630033, 
            0.38345025152671264`}, {-3.194881624919481, 
            0.3745634925176942}, {-3.1623501783879817`, 
            0.37141030770455524`}, {-3.1295969644392314`, 
            0.3681622018825722}, {-2.9946620224070273`, 
            0.3531919772581397}, {-2.8541460083178523`, 
            0.33616479738052724`}, {-2.677646912422522, 
            0.3134352339923675}, {-2.4879376627937138`, 
            0.2864207265839477}, {-2.463129779811078, 
            0.2826081450687708}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.442497175167419, 
            0.27943723817883487`}, {-2.3502234918741984`, 
            0.265256224042834}, {-2.2005483287495453`, 
            0.2408933913318483}, {-2.0853695027456016`, 
            0.2213690733555784}, {-1.9587170209745735`, 
            0.19930404889222308`}, {-1.752266063241651, 
            0.16275797859119032`}, {-1.6193336718958504`, 
            0.13951627309818465`}}]}, 
          {Arrowheads[{{0.015620557508301167`, 1.}}], 
           ArrowBox[{{-1.5987707531234223`, 
            0.13592108235989311`}, {-1.5727894172673247`, 
            0.13137854347851935`}, {-1.418118106857622, 
            0.1054840726316473}, {-1.2771789729566025`, 
            0.08344051120210522}, {-1.155499620795917, 
            0.06596878604513026}, {-1.119779453716507, 
            0.061129997797661456`}, {-1.0807487436138505`, 
            0.05602716144087012}, {-1.0361829923901842`, 
            0.050425571622120025`}, {-1.0166690149744977`, 
            0.04804488997711494}, {-0.9973362286967643, 
            0.045746855349690085`}, {-0.981781472805647, 
            0.043954126826753905`}, {-0.9686666084970234, 
            0.04249105109125593}, {-0.9617042320420328, 
            0.04173633202469884}, {-0.9577088903845296, 
            0.0413095027837578}, {-0.9536857126783964, 
            0.04088366107729198}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.235644788728586, 0.02098370120128395}, {
            1.3204090873293437`, 0.03233087732695833}, {1.412668093943552, 
            0.05059360393540473}, {1.5108540571776243`, 0.0779521957788382}, {
            1.611336369070684, 0.11338997353538231`}, {1.6823312954473226`, 
            0.14112002336542342`}, {1.7491884803574134`, 
            0.1666829326696569}, {1.8144275829661423`, 
            0.18936443052062144`}, {1.8796404438558538`, 0.20875064243704877`}
            , {2.038881068499793, 0.238798246756229}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0593939234600036`, 0.24266888058901712`}, {
            2.0707642077779047`, 0.2448143745855698}, {2.286315726375862, 
            0.2582863376678378}, {2.4064312461964774`, 
            0.25880580111440216`}, {2.5360296285476362`, 
            0.25655259305188416`}, {2.6451031668752063`, 
            0.2532070753936469}, {2.7607094922487443`, 0.2490739685660236}, {
            2.859058317054052, 0.245435284592147}, {2.89353049343656, 
            0.24418358880185317`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.9143915878347135`, 0.2434261157676777}, {
            2.9618640354418115`, 0.24170237595602773`}, {3.069126647412024, 
            0.23787524265766577`}, {3.1808461529646883`, 
            0.23395388469706116`}, {3.1961220511763235`, 
            0.23342187032571599`}, {3.211477482963703, 0.2328911133677078}, {
            3.3506517559091757`, 0.2284647226468018}, {3.4956990499727034`, 
            0.2242330214086656}, {3.6678968315239175`, 
            0.21947488947520255`}, {3.7489758957859944`, 
            0.21746992587107944`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.7698443581552583`, 0.2169538801087709}, {
            3.847159256452321, 0.21504199868101992`}, {4.033486324757914, 
            0.21093434902611774`}, {4.226878036440696, 0.207151940510496}, {
            4.426633110880221, 0.20367230980479703`}, {4.60468024459208, 
            0.2008992742257913}}]}, 
          {Arrowheads[{{0.008995999184526886, 1.}}], 
           ArrowBox[{{4.6255525551379595`, 0.20057419367799967`}, {
            4.632050267456043, 0.20047299357966306`}, {4.843129506168162, 
            0.19755399183509414`}, {5.001099999999999, 
            0.19563080188436943`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.208740020234429}, \
{-4.910730285023766, -4.203017872352114}, {-4.769727727157753, \
-4.193086580156793}, {-4.629593708804084, -4.18220104273436}, \
{-4.490385841363255, -4.170358775152483}, {-4.3521617362357645`, \
-4.157557292478828}, {-4.214979004822108, -4.143794109781065}, \
{-4.169113356589964, -4.138795583127129}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.148361387107226, -4.136533993537113}, \
{-4.078820535360352, -4.128955297619967}, {-3.9436963881476323`, \
-4.112967451831545}, {-3.809704932673042, -4.095888875396315}, \
{-3.6769445384256736`, -4.077777871294796}, {-3.5455135748946223`, \
-4.058692742507503}, {-3.4155104115689814`, -4.038691792014957}, \
{-3.321178829725469, -4.023376891342937}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.3005737766407313`, -4.020031624199448}, \
{-3.287033417937843, -4.017833322797673}, {-3.1601809634903026`, \
-3.9961756378361692`}, {-2.98491527233105, -3.964464134070425}, \
{-2.8134515088581433`, -3.931401886870569}, {-2.6459947632765024`, \
-3.8971773389636737`}, {-2.4811762174364094`, -3.860106913244535}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.460848277503836, -3.8553600217030053`}, \
{-2.320060154414036, -3.822446107243873}, {-2.1639750101906134`, \
-3.7841379219134654`}, {-2.012307064268297, -3.74504432133016}, \
{-1.8650563166470888`, -3.705165305493957}, {-1.7224672378324029`, \
-3.6650940047452467`}, {-1.652898662602839, -3.645049276870135}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6328398469475056`, -3.6392697492604142`}, \
{-1.5847842983296554`, -3.625423549424419}, {-1.4520074981388467`, \
-3.5861539395314743`}, {-1.3241368372599767`, -3.5472851750664125`}, \
{-1.1852560094634024`, -3.5044777074992473`}, {-1.0525376484352427`, \
-3.463593862091134}, {-0.9256587654029687, -3.4251489776735053`}, \
{-0.8334251169381669, -3.398176651233035}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8133894104553943, -3.3923175138714132`}, \
{-0.8042963715940517, -3.389658393077795}, {-0.6878843532328995, \
-3.3575710957490372`}, {-0.5758565965439199, -3.3293360731322674`}, \
{-0.5280896160986367, -3.3182247663552187`}, {-0.48095765440996535`, \
-3.3079468509177263`}, {-0.35610490074095125`, -3.284543843032685}, \
{-0.2338159107252301, -3.2677163946778918`}, {-0.07219453903519037, \
-3.2557508739133274`}, {-0.059611609943063935`, -3.255283459994461}, \
{-0.04701356258279658, -3.2548866877744707`}, {-0.013753472681142812`, \
-3.2545118092185055`}, {0.007209672000359307, -3.2545745955685548`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.02807906858742283, -3.254912706965554}, {
            0.19255101063994787`, -3.2608096073688184`}, {
            0.3744080072584576, -3.2774370390351506`}, {
            0.5686450561955162, -3.3022393109793153`}, {
            0.7525445359748715, -3.3291259868656766`}, {
            0.8575477446872704, -3.3445625109385877`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.8782006052897705, -3.3475986884399647`}, {
            0.9489255341755002, -3.3579959618251025`}, {
            1.158231709807569, -3.3865846077418285`}, {
            1.2673949980442265`, -3.4001857142564407`}, {
            1.3795237849886075`, -3.4129763240882736`}, {
            1.494432580152377, -3.4247969592773475`}, {
            1.6118475991564492`, -3.435546305480958}, {
            1.7075212789728411`, -3.4431390144846206`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.7283306940021033`, -3.4447904596172507`}, {
            1.7316054249851767`, -3.4450503438348066`}, {
            1.8535426406229125`, -3.4531350554745956`}, {
            1.9774516325675182`, -3.459769499641899}, {
            2.103099532181716, -3.4650044944959304`}, {
            2.230285039747151, -3.468788659548853}, {
            2.358806855545471, -3.4710706143128305`}, {
            2.5233301977195683`, -3.471940888480039}, {
            2.5626800385836113`, -3.471663694597516}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.5835543625816095`, -3.4715166486428948`}, {
            2.6894988233579475`, -3.4707703392355493`}, {
            2.856980978635799, -3.4676402682197063`}, {
            3.0254449097283156`, -3.4626319770728546`}, {
            3.194745353425531, -3.4559552146342782`}, {
            3.364843612583103, -3.447893128142656}, {
            3.418041051167311, -3.4450089665546537`}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{3.4388852808620767`, -3.4438788721700906`}, {
            3.5355677824746596`, -3.4386371168374232`}, {
            3.706745958373827, -3.428378579958016}, {
            3.878349011270477, -3.417289586961367}, {
            4.050429398278044, -3.405531161714407}, {
            4.222937593855507, -3.393278135071569}, {
            4.272106218334582, -3.389702452644644}}]}, 
          {Arrowheads[{{0.017008696760942726`, 1.}}], 
           ArrowBox[{{4.2929260787565235`, -3.3881883730902436`}, {
            4.395824072461845, -3.380705337887286}, {
            4.5691053096137475`, -3.3679187836365987`}, {
            4.742835495718026, -3.3549851615777526`}, {
            4.917021677568843, -3.3420203162399873`}, {
            5.001099999999999, -3.3358196151628263`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.1904002266863625`}, {-4.925409034392993, 
            2.184758356833393}, {-4.759033173692319, 
            2.1706261675413687`}, {-4.586534858915601, 
            2.1538942613050405`}, {-4.414877677289737, 
            2.1347630975051555`}, {-4.201480129551561, 
            2.1068829713492567`}, {-4.170961099842287, 
            2.1021831318610618`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.1503294649044005`, 
            2.0990059216577626`}, {-3.989442463059831, 
            2.074229803556713}, {-3.778788387461917, 
            2.035972730411699}, {-3.569541612405188, 
            1.9912808881983883`}, {-3.5419459690236135`, 
            1.984941259704926}, {-3.5143754382366255`, 
            1.9784679909512486`}, {-3.3722602492692304`, 
            1.9402661494004747`}, {-3.3336310304837564`, 
            1.928611410044466}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.313645976819075, 
            1.9225817620525865`}, {-3.230759689961092, 
            1.8975743169141823`}, {-3.028395023267904, 
            1.830206214665336}, {-2.827081093149588, 
            1.750528948898451}, {-2.7266000868702607`, 
            1.7050449355225865`}, {-2.625945629863158, 
            1.6544247429208976`}, {-2.54223014419609, 1.608131292511837}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.5239870562035978`, 
            1.5979867056822357`}, {-2.4241163636656258`, 
            1.537775820040045}, {-2.3056589839829167`, 
            1.4582085791877248`}, {-2.185113944763961, 
            1.3669255991457379`}, {-2.0874822756615776`, 
            1.2847100725082077`}, {-1.985960440151079, 
            1.1909570317895353`}, {-1.905094451568856, 
            1.1105578494119661`}, {-1.8743703369105067`, 
            1.0782134515920883`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8599935542234896`, 
            1.063078487288977}, {-1.8187069531116102`, 
            1.01961457414314}, {-1.7480879863405148`, 
            0.9424218040321122}, {-1.6703813821389883`, 
            0.8556283145673359}, {-1.5348002965243313`, 
            0.704628174446366}, {-1.4128879962981082`, 
            0.5752284353108662}, {-1.2993362056421582`, 
            0.4646293304024014}, {-1.28826520002116, 0.45496547099105866`}}]}, 
          {Arrowheads[{{0.003518470003130224, 1.}}], 
           ArrowBox[{{-1.2725389101107976`, 
            0.44123802292008046`}, {-1.1929262420607145`, 
            0.37174427883429845`}, {-1.160912616093333, 
            0.345781232245087}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.4112858081212725`}, {-4.923782811672688, 
            4.406726274767114}, {-4.774463405443122, 
            4.396800114796619}, {-4.625999997235236, 
            4.3857176085527945`}, {-4.478483632576323, 
            4.373526832997711}, {-4.332005356993671, 
            4.360275865093438}, {-4.186656216014571, 
            4.34601278180205}, {-4.168881355668766, 4.344134880508754}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.148122047586668, 
            4.341941674444861}, {-4.042527255166314, 
            4.330785660085614}, {-3.899709519976189, 
            4.314642576906204}, {-3.7582940559714872`, 
            4.297631609225889}, {-3.557730665782585, 
            4.2717052605103625`}, {-3.360639482227994, 
            4.244155807281638}, {-3.3196872928354186`, 
            4.238017768641167}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.299043048729634, 
            4.234923546576263}, {-3.167225851428198, 
            4.21516638432155}, {-2.9755047608851872`, 
            4.182966688739037}, {-2.7883852806391474`, 
            4.150151129943413}, {-2.60535404538887, 
            4.116261870980093}, {-2.476608057954158, 4.091106704574527}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4561206145910903`, 
            4.087103744503371}, {-2.426411055134354, 
            4.0812989118490774`}, {-2.251556309875599, 
            4.045262252550366}, {-2.0810516541462882`, 
            4.008788195678349}, {-1.9151589324801037`, 
            3.972513043827419}, {-1.7538781448770453`, 
            3.9364367969975746`}, {-1.6400725176098006`, 
            3.9103751817053793`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6197244013294287`, 
            3.9057154404328793`}, {-1.5972092913371128`, 
            3.9005594551888167`}, {-1.4287829188035648`, 
            3.861774681588044}, {-1.2659165963054886`, 
            3.8247840430449838`}, {-1.1082748721953706`, 
            3.7901648877732357`}, {-0.9555222948256974, 
            3.758494563986402}, {-0.807056990549714, 
            3.730271057081102}, {-0.8035818736828121, 3.7296883012348685`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7829944960997549, 
            3.726235923917887}, {-0.6622770857206648, 
            3.7059923524539586`}, {-0.6123850333189776, 
            3.698448878434557}, {-0.5628136554690486, 
            3.6914496719616894`}, {-0.41732148942411174`, 
            3.674023334931656}, {-0.2732327349290672, 
            3.661662937619176}, {-0.15804223140018378`, 
            3.6554323295098032`}, {-0.042447617864973634`, 
            3.6524226717453074`}, {-0.02714195620089388, 
            3.6522377319225074`}, {-0.011818656322184972`, 
            3.6521066299724327`}, {0.020271435238232695`, 
            3.6521745048902288`}, {0.04747532643557486, 
            3.6524224281888307`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.06834665526878583, 3.652791958940499}, {
            0.17081246636659148`, 3.6548828403169717`}, {0.2911178205897927, 
            3.65998837463334}, {0.41380996167550044`, 3.6674316622814813`}, {
            0.5393161735120415, 3.676859846178815}, {0.6679030018864001, 
            3.687841884955093}, {0.79983699258556, 3.6999467372400665`}, {
            0.9011668192140667, 3.7094262179782653`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9219523544348857, 3.7113549507220616`}, {
            1.0335865510789775`, 3.721528075553153}, {1.1542754096489733`, 
            3.73224639424585}, {1.2775069877678278`, 3.7429164792959835`}, {
            1.4030842048628274`, 3.753113550178784}, {1.5308099803612594`, 
            3.762412826369483}, {1.6606843142631236`, 3.77081430786808}, {
            1.7543733026640287`, 3.7761392391273656`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.7752145094189835`, 3.777323775274301}, {
            1.7927072065684202`, 3.7783179946745755`}, {1.927297511648936, 
            3.785156795105473}, {2.062081721397878, 3.790010895367251}, {
            2.1986794060528223`, 3.793780874283724}, {2.3369230238650553`, 
            3.7963735685282907`}, {2.5336758659297285`, 3.798063817648792}, {
            2.6098350875329124`, 3.7978613383598137`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6307098556711117`, 3.797805840048234}, {
            2.732541946661042, 3.7975351060656015`}, {2.932940264830414, 
            3.7947126249366034`}, {3.134289819209262, 3.7895215654196823`}, {
            3.33642982592826, 3.7822398247509974`}, {3.4653616316547655`, 
            3.7765918819030584`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.486216473605736, 3.7756783217866996`}, {
            3.539439625323368, 3.77334684649715}, {3.743098402473937, 
            3.7630701413116876`}, {3.947185342459319, 3.7516372198481593`}, {
            4.15167629083947, 3.739264666317634}, {4.319862852429324, 
            3.7285147390547704`}}]}, 
          {Arrowheads[{{0.015854020307786775`, 1.}}], 
           ArrowBox[{{4.340695184110573, 3.7271832054995784`}, {
            4.356659470591834, 3.726162821249762}, {4.562082632921998, 
            3.712549829775967}, {4.767893529035543, 3.698643837027672}, {
            4.97412290688655, 3.684568373765426}, {5.001099999999999, 
            3.682718520013177}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.2899688384007728`}, \
{-4.873243874800022, -1.28253584067526}, {-4.698453473227645, \
-1.270883373710157}, {-4.52376200331215, -1.257348399474827}, \
{-4.40387380482803, -1.2468234738497257`}, {-4.283900700711727, \
-1.2351945516411322`}, {-4.1689131781182915`, -1.222893771980643}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.14817569293636, -1.2205049919383595`}, \
{-4.043396912169501, -1.2081512156246237`}, {-3.845687646053933, \
-1.1814698410479771`}, {-3.6465352279354075`, -1.1500232087564806`}, \
{-3.6171977105289876`, -1.1450577476810044`}, {-3.587813266463302, \
-1.139967299715387}, {-3.4412632493320867`, -1.1108285060258716`}, \
{-3.3247558731160116`, -1.0848337839561795`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.304381988439472, -1.080288033405035}, \
{-3.2927563963531727`, -1.0776941715827717`}, {-3.103579889067916, \
-1.031732198891325}, {-2.9092514795903153`, -0.9771136198254478}, \
{-2.743727861692737, -0.9239453198117245}, {-2.570907255748292, \
-0.861360912936971}, {-2.506972004383263, -0.8357142143937699}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4875977954744135`, -0.8279425315616907}, \
{-2.4326623915377357`, -0.805905991248914}, {-2.285700559412395, \
-0.7416502518469361}, {-2.166643790595689, -0.685887416341562}, \
{-2.0373788624303812`, -0.6220027741946927}, {-1.9378944686721784`, \
-0.5710450400171623}, {-1.8281272728517233`, -0.5135835132117629}, \
{-1.7360349346345907`, -0.46509791221172186`}}]}, 
          {Arrowheads[{{0.013056919302375392`, 1.}}], 
           ArrowBox[{{-1.7175637252644897`, -0.4553730240739558}, \
{-1.6521971207180681`, -0.4209582272719386}, {-1.4933666466075122`, \
-0.3396011299390921}, {-1.3522287122599497`, -0.2715008187887989}, \
{-1.2278732660424005`, -0.21622694615183585`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1050128773494163`, -0.6481247081428028}, {
            1.0733848596984648`, -0.8288985442636847}, {
            1.0195305400173882`, -0.9962911384748004}, {
            0.9884550227660625, -1.069643698770502}, {
            0.9546896477169438, -1.139209952530531}, {
            0.8865775943444398, -1.2582194809767593`}, {
            0.8132481827837945, -1.364037581149848}, {
            0.7785072738567336, -1.403765392328433}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.764765782770576, -1.4194794130620079`}, {
            0.6758861930615496, -1.521117270753172}, {
            0.5328512732266539, -1.6423643961996839`}, {
            0.38604242403720934`, -1.7312987496247985`}, {
            0.3048057241576425, -1.7668284343141918`}, {
            0.2222560806799676, -1.7936088025196617`}, {
            0.13812126962006968`, -1.8115399991514871`}, {
            0.05917291318739788, -1.8194617167558749`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{
            0.038345526328374326`, -1.8201950782990088`}, \
{-0.04053560560868953, -1.8189415968833498`}, {-0.13401015677943573`, \
-1.8061568590024275`}, {-0.16172104311718388`, -1.8006818631347725`}, \
{-0.18968698010648355`, -1.7941088230075766`}, {-0.22796899528466041`, \
-1.7816172139865945`}, {-0.2669502350314771, -1.7667242521894968`}, \
{-0.37334202336591354`, -1.7171811049722199`}, {-0.48433736962308654`, \
-1.6453342055230142`}, {-0.5995360857751741, -1.54392723369077}, \
{-0.6762088864378333, -1.4519664216856274`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.6895766254810615, -1.435933250515883}, \
{-0.7066797208267157, -1.4154199195537374`}, {-0.8101267304193652, \
-1.2352840108728473`}, {-0.8695356944724534, -1.074365350242342}, \
{-0.9022475619230315, -0.9099055002386545}, {-0.908485513194227, \
-0.7536230657736349}, {-0.906018469043195, -0.7085192357708436}, \
{-0.9008989710043321, -0.6601315920050083}, {-0.8991238136964387, \
-0.6491672997365101}}]}, 
          {Arrowheads[{{0.002923851390254884, 1.}}], 
           ArrowBox[{{-0.8957875471986597, -0.6285607873983688}, \
{-0.8924464655239506, -0.6079245340299806}, {-0.8866580553361907, \
-0.5798946270397918}, {-0.879408441183886, -0.5494692365753883}, \
{-0.8723279169561831, -0.5231411648824201}, {-0.8682149126977485, \
-0.5097560001649929}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6382493608093099, 0.7957079371769847}, {
            0.634294974137646, 0.8010247567488894}, {0.6249977699667706, 
            0.8128030990775915}, {0.6017848928373539, 0.8413833736144237}, {
            0.5878404346649695, 0.8574504958541534}, {0.5382953408643643, 
            0.9078386822193167}, {0.4306762769908282, 0.9926520602108413}, {
            0.31191003235408327`, 1.0570277806127655`}, {0.23040743152565205`,
             1.0870062599680266`}, {0.14581541455265085`, 
            1.1074571205169934`}, {0.05867982920409056, 
            1.1178126948201588`}, {0.02749264529279276, 
            1.1196316178364014`}, {-0.0038637922287569704`, 
            1.1200925323935425`}, {-0.03586015081645325, 
            1.1177076087827085`}, {-0.06808324563332029, 
            1.1138009432990288`}, {-0.0913839976894088, 
            1.1093331619465356`}}]}, 
          {Arrowheads[{{0.013355451244773112`, 1.}}], 
           ArrowBox[{{-0.11188536681976238`, 
            1.1054021457080605`}, {-0.1598307726521023, 
            1.0962088977991602`}, {-0.2518709686533258, 
            1.0647803928045616`}, {-0.3430736791838136, 
            1.0175714204710564`}, {-0.4501397268051339, 
            0.9346558875997721}, {-0.47063541999270675`, 
            0.914773298352576}, {-0.4854865872348771, 
            0.8991687554334324}, {-0.4982874437046553, 
            0.8849281943935774}, {-0.5090300038193428, 
            0.8722366266061623}, {-0.5161631724533523, 
            0.8631153505345006}, {-0.5225278622491947, 
            0.8543518065494137}, {-0.5292882751313216, 
            0.8446942780685893}, {-0.5364413693969241, 
            0.8345508753714594}, {-0.5423129067617275, 
            0.8264717722806992}, {-0.5488762972882629, 
            0.8174294080098704}, {-0.5542304422374478, 
            0.8088729466592302}, {-0.5569101229819848, 
            0.8039939792039859}, {-0.5588415482300755, 0.800389281577556}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.045301355028694}, {-4.882512889556381, 
            4.037396388507155}, {-4.735763586758306, 
            4.026498351707104}, {-4.589953736195469, 
            4.014474161452948}, {-4.445106593540274, 
            4.001269359269415}, {-4.301308918793565, 
            3.986888897642039}, {-4.169368063213557, 3.972506353976944}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.148626478514043, 
            3.970153325764546}, {-4.017209013028969, 
            3.9546208059978927`}, {-3.877080302012764, 
            3.9367430809521906`}, {-3.7383480989084097`, 
            3.917709506404781}, {-3.6010991637167487`, 
            3.897525034841198}, {-3.4653378217624895`, 
            3.876082195608628}, {-3.33109837461621, 
            3.8533143991954755`}, {-3.322204117788011, 
            3.8517026305645228`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.301663810225179, 
            3.8479804282446017`}, {-3.1985125466475495`, 
            3.8292879197990994`}, {-3.067712062226148, 
            3.80406903161686}, {-2.9388286457216464`, 
            3.7777240088461164`}, {-2.8119940215036845`, 
            3.750319125684229}, {-2.6873399139419, 
            3.7219206563285563`}, {-2.564998047405937, 
            3.692594874976459}, {-2.4855494138320307`, 
            3.672350005091753}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.465320977759531, 
            3.6671954538070177`}, {-2.3917095816044487`, 
            3.6484380117950677`}, {-2.2236034852305346`, 
            3.602305523552055}, {-2.0612085830146407`, 
            3.554546231996381}, {-1.9048186664736846`, 
            3.5053539269885796`}, {-1.7547504231252038`, 
            3.4550237001193405`}, {-1.666961324140125, 
            3.4237022174827327`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6473003581841934`, 
            3.416687558363013}, {-1.611320540486738, 
            3.4038506429793536`}, {-1.460308420724649, 
            3.3463023226395645`}, {-1.3183741048710096`, 
            3.2882178162685496`}, {-1.18551759292582, 
            3.2295971238663093`}, {-1.0615029719335651`, 
            3.175345168721886}, {-0.9468778511587264, 
            3.1205175375888516`}, {-0.8805698689858587, 3.087245440406049}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.861912154758479, 
            3.0778833506449113`}, {-0.8415807155614506, 
            3.067681417202476}, {-0.6574388706732258, 
            2.96890899895851}, {-0.5064642503564437, 
            2.8816137667888992`}, {-0.3851439246180932, 
            2.8069110290499584`}, {-0.21408275864701987`, 
            2.694746164435516}, {-0.15443200083429226`, 
            2.654485960440905}, {-0.14618882450648948`, 
            2.6490129488207423`}}]}, 
          {Arrowheads[{{0.0036439984885985174`, 1.}}], 
           ArrowBox[{{-0.12879808764974804`, 
            2.637466464660369}, {-0.10811457042605443`, 
            2.6237337570717543`}, {-0.0716428645824127, 
            2.6010481622116335`}, {-0.05578775414876679, 
            2.5922105979832866`}, {-0.04131759852982615, 
            2.5850398546606583`}, {-0.02183043153919431, 
            2.5771509458434725`}, {-0.013240306155634742`, 
            2.574578548893363}, {-0.004804000568456306, 2.572680914812045}, {
            0.006512806877108075, 2.5711618096487516`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.4065620701601584`, -0.22375595178716187`}, {
            1.4526714106994378`, -0.28212561386633395`}, {
            1.5014777822139678`, -0.357271945237908}, {
            1.543533308349768, -0.4313602689774552}, {
            1.581798117411808, -0.5027287456197471}, {
            1.6183405451609885`, -0.5700954807865731}, {
            1.6936798382556775`, -0.6876953854667326}, {
            1.7760084118812374`, -0.7818717398143615}, {
            1.853941357440662, -0.8442708038412483}, {
            1.9098948439386352`, -0.8745170667673662}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.928258422502293, -0.8844436979795416}, {
            1.9403473437066094`, -0.8909784952213922}, {
            2.035039056742721, -0.9237687059079003}, {
            2.0853368854349084`, -0.935505287319078}, {
            2.1374702175542053`, -0.9445233051453554}, {
            2.3230080013330885`, -0.9588664035073929}, {
            2.525325256204185, -0.9544077456627503}, {
            2.5393919916286207`, -0.9536136868700361}, {
            2.5535252147973866`, -0.9527697127239549}, {
            2.6700062907100377`, -0.9431409099134751}, {
            2.7525397805864484`, -0.9353223162296026}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.773321580521683, -0.9333536069219454}, {
            2.7905235639187564`, -0.9317240221444225}, {
            2.9264674458201307`, -0.9185560571620053}, {
            3.067257152074878, -0.9043496799161673}, {
            3.212871492431007, -0.889610028682609}, {
            3.3632892766365248`, -0.8748422417370307}, {
            3.518465751879312, -0.8603118421046453}, {
            3.6044108175913396`, -0.8527717184474652}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.6252057846634766`, -0.8509473365370915}, {
            3.67835616534725, -0.8462843528106649}, {
            3.8286686860579833`, -0.8339933955233158}, {
            3.9826812470994613`, -0.8223317097061066}, {
            4.140393848471685, -0.8112992953590374}, {
            4.3018064901746556`, -0.8008961524821083}, {
            4.458057421774706, -0.791621185502939}}]}, 
          {Arrowheads[{{0.01252341129885257, 1.}}], 
           ArrowBox[{{4.478898864583108, -0.7904418044831377}, {
            4.634781032031117, -0.7819256275255478}, {
            4.806105216549179, -0.7733452320426358}, {
            4.980654010127128, -0.7653680812233027}, {
            5.001099999999999, -0.7645111014890521}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.447019706935948, 0.5649490582643129}, {
            1.4729124088170822`, 0.6700136709360989}, {1.4959426633985586`, 
            0.7689929113764549}, {1.5186780404878863`, 0.8605390871212062}, {
            1.5726664127462107`, 1.017423431864529}, {1.641596891910065, 
            1.14130948905211}, {1.7155341194150497`, 1.225808500931829}, {
            1.8028312466204695`, 1.2903479079012714`}, {1.8049129725798936`, 
            1.2913394376211522`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8237592290643891`, 1.3003159425872726`}, {
            1.9022035274993103`, 1.3376790992992802`}, {1.9559550070895946`, 
            1.35563278398866}, {2.0120909426177254`, 1.370242456783886}, {
            2.2255364887487077`, 1.4001762493191385`}, {2.3400923624983294`, 
            1.4044586865135325`}, {2.4588188100661554`, 1.403345567913373}, {
            2.4749426184685555`, 1.4028369570136778`}, {2.4911300994024455`, 
            1.4022534826867685`}, {2.604242732340233, 1.3948256636760927`}, {
            2.6429473155620187`, 1.3915695544007913`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6637486775772503`, 1.389819593487672}, {
            2.7198514744652327`, 1.3850998207343903`}, {2.865911660731409, 
            1.3719062290575845`}, {3.0155444556509456`, 
            1.3566001773835736`}, {3.1686598827557964`, 
            1.3398996112342034`}, {3.325167965577913, 1.3225224761313197`}, {
            3.4850539262779736`, 1.3048948501527575`}, {3.494277518627548, 
            1.3039088077791343`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5150340887971043`, 1.3016898396219814`}, {
            3.6483029870166543`, 1.287442811376353}, {3.7879147536956923`, 
            1.2731100761196037`}, {3.9298605596172855`, 
            1.2592633846752734`}, {4.074140404781433, 1.2459027370433622`}, {
            4.220754289188136, 1.2330281332238697`}, {4.346249273546917, 
            1.2226294659320915`}}]}, 
          {Arrowheads[{{0.015224500426690433`, 1.}}], 
           ArrowBox[{{4.367052819250118, 1.220905658790617}, {
            4.369630651152107, 1.2206920564987018`}, {4.520697928988058, 
            1.2089469901497638`}, {4.67395612269599, 1.1977929341770557`}, {
            4.829405232275903, 1.1872298885805774`}, {4.986930541270979, 
            1.17722578067667}, {5.001099999999999, 1.1763837836660036`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.796695876595409}, \
{-4.9661010683245985`, -4.794829288691982}, {-4.802314394196204, \
-4.784985094564366}, {-4.639628454680999, -4.774133891515806}, \
{-4.478131202464676, -4.762323663013382}, {-4.317910590232927, \
-4.749602392524177}, {-4.206568536813325, -4.740162363197045}, \
{-4.168300362139722, -4.736745010467918}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.147508259042649, -4.734888273090996}, \
{-4.095965112722175, -4.730285463752731}, {-3.9861220993600983`, \
-4.719994590281824}, {-3.877061278127722, -4.7093126388749145`}, \
{-3.6613733376545676`, -4.686867086615446}, {-3.4472168629877293`, \
-4.661178175968731}, {-3.317437734378045, -4.644913902070586}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.296724914324007, -4.642318115042496}, \
{-3.2370604128646807`, -4.634840797201587}, {-3.030468359272927, \
-4.607397028502224}, {-2.8274407022124666`, -4.578846869870641}, \
{-2.627977441683302, -4.549190321306838}, {-2.4700634934974204`, \
-4.524878694865459}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.449431727873148, -4.521702333407553}, \
{-2.4322638062163184`, -4.519059247708724}, {-2.2404850243424024`, \
-4.4890855139742065`}, {-2.0526410960615546`, -4.459269120103286}, \
{-1.868732021373775, -4.429610066095964}, {-1.6621910345863036`, \
-4.396554109553783}, {-1.6247705247333153`, -4.3907618878843895`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6041413485482823`, -4.387568752307399}, \
{-1.4605720342381432`, -4.365346038168172}, {-1.2634703086614776`, \
-4.336579551296321}, {-1.0704811461884898`, -4.310848348295416}, \
{-0.8809369171930889, -4.288612972657032}, {-0.776452312143871, \
-4.278386993972062}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7556767342825502, -4.27635367417076}, \
{-0.6941699920491841, -4.270333967872746}, {-0.6436023379351764, \
-4.266041323499699}, {-0.5931626864833638, -4.262070337315564}, \
{-0.43594523527714274`, -4.251764808246702}, {-0.27921538423699876`, \
-4.244659735553907}, {-0.12239337014881538`, -4.240654147291978}, {
            0.03510057020152423, -4.239647071515712}, {
            0.052997300103155426`, -4.239702881097285}, {
            0.0709100464202898, -4.2397941287782785`}, {
            0.07813166338685044, -4.239871033245452}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.09900532173909557, -4.240093321076692}, {
            0.10483958143738484`, -4.240155451294277}, {
            0.13883834672041995`, -4.2406365236447385`}, {
            0.30982711075811303`, -4.244284165883847}, {
            0.4831089718671644, -4.250420659594619}, {
            0.6590547572108227, -4.258506331413231}, {
            0.8380352939523369, -4.268001507975857}, {
            0.9332573037918859, -4.273402568378038}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9540986468314199, -4.274584704239366}, {
            1.0201768043697046`, -4.278332704525544}, {
            1.205605510740924, -4.28892643630534}, {
            1.3938990430840157`, -4.299093673263793}, {
            1.5850430384979488`, -4.308168776709876}, {
            1.779037496982723, -4.316151746643589}, {
            1.78802444734098, -4.316466347621639}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8088865104641987`, -4.317196653810175}, {
            1.9758824185383386`, -4.323042583064932}, {
            2.175013360368079, -4.328458876981666}, {
            2.375865879675228, -4.3320182194015535`}, {
            2.5784399764597863`, -4.333720610324593}, {
            2.643665541516402, -4.333671263705784}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6645403774551495`, -4.333655470779025}, {
            2.782735650721752, -4.333566049750785}, {
            2.9882805100830514`, -4.331688023750752}, {
            3.1946021621656064`, -4.3282200183951165`}, {
            3.401700606969418, -4.323162033683879}, {
            3.499384599141357, -4.320038046057472}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.5202487743062605`, -4.319370798296594}, {
            3.6095758444944854`, -4.316514069617037}, {
            3.734829033526401, -4.311883133146843}, {
            3.860202800545757, -4.306938645118697}, {
            3.9856971455525536`, -4.3016806055326}, {
            4.111312068546789, -4.296109014388553}, {
            4.237047569528466, -4.290223871686555}, {
            4.354500109802444, -4.284439070561522}}]}, 
          {Arrowheads[{{0.015010822453954771`, 1.}}], 
           ArrowBox[{{4.375348148826195, -4.28338187058565}, {
            4.48888030545414, -4.277512931608706}, {
            4.614977540398137, -4.270687134232856}, {
            4.741189715635374, -4.263667086387395}, {
            4.867511193471654, -4.256572089160667}, {
            4.993941973906977, -4.249402142552669}, {
            5.001099999999999, -4.248992318619503}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.829465447663003}, \
{-4.967938835299334, -3.827293353482965}, {-4.851358445312486, \
-3.8189101644825585`}, {-4.735336542044447, -3.809798397194374}, \
{-4.619907113671642, -3.79994333843525}, {-4.409759308638843, \
-3.7798690460826565`}, {-4.201912709412098, -3.75715075479107}, \
{-4.1696960261528675`, -3.7531625841125447`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.148979317139629, -3.7505980193254955`}, \
{-3.996688473782757, -3.7317456169476158`}, {-3.7941164886703715`, \
-3.703475503759093}, {-3.5946572699127115`, -3.672362292660113}, \
{-3.398464996741003, -3.638285582602528}, {-3.323829939614592, \
-3.6239236573267934`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.303331170336043, -3.6199791062812383`}, \
{-3.205936155620334, -3.601237512485618}, {-3.017467233015792, \
-3.5612102212086643`}, {-2.833345351035749, -3.5181404533885794`}, \
{-2.653945123273949, -3.4720092690681708`}, {-2.491476926070413, \
-3.4261713613818925`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4714482545175627`, -3.4202938476722897`}, \
{-2.3114205251776845`, -3.3707970990788643`}, {-2.1491963497478976`, \
-3.3158576701485596`}, {-1.9936184203310094`, -3.2581204720652353`}, \
{-1.84540076359812, -3.1976149176721904`}, {-1.7052574062203294`, \
-3.1343704198127234`}, {-1.6905871389086145`, -3.1269939653853545`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6719371720384058`, -3.117616451822246}, \
{-1.5677511089198894`, -3.06522996627082}, {-1.4403904057903278`, \
-2.993207188267311}, {-1.3239618356705163`, -2.918221740888045}, \
{-1.2700794469308714`, -2.8795652777698733`}, {-1.219248725631191, \
-2.8400699592990364`}, {-1.1098317894642722`, -2.740584301802388}, \
{-1.0208714469354452`, -2.634094987589903}, {-1.0132429064362276`, \
-2.619746884124239}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.0034432439332432`, -2.6013152363489103`}, \
{-0.9430660103485697, -2.487755008867348}, {-0.937900779406751, \
-2.474079520765433}, {-0.9330521923649512, -2.460209022604819}, \
{-0.92291906253696, -2.4186615074391966`}, {-0.9155500496511114, \
-2.374861893063053}, {-0.9068321708477529, -2.28167903696759}, \
{-0.9108640904780488, -2.1749354132411307`}, {-0.9291593689078376, \
-2.048321214977728}, {-0.9547039764910624, -1.9264398591114082`}, \
{-0.9865805389861064, -1.7931794643047998`}}]}, 
          {Arrowheads[{{0.017552266598442303`, 1.}}], 
           ArrowBox[{{-0.9914124223714018, -1.7728716106313545`}, \
{-1.0324112895537263`, -1.5960668325135414`}, {-1.067131164414668, \
-1.4094608334868166`}, {-1.0880167714034086`, -1.227673125181214}, \
{-1.0925971074448106`, -1.0492184768364214`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.4128572862893437}, \
{-4.92261912070448, -0.41124335320589905`}, {-4.81292495260028, \
-0.40877016074502914`}, {-4.703086150952623, -0.40603482103975275`}, \
{-4.592985987995055, -0.40299312923165703`}, {-4.482624463727579, \
-0.39964508532074206`}, {-4.3720015781501935`, -0.3959906893070078}, \
{-4.342586002985824, -0.3949794178320918}, {-4.3131393721280915`, \
-0.3939419734611101}, {-4.1664993833366735`, -0.38786748708479074`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145642428896894, -0.38700349843721815`}, \
{-4.1438091710947225`, -0.3869275566723875}, {-3.972682766401279, \
-0.378805298408098}, {-3.827509731456308, -0.37139107907576946`}, \
{-3.6798519749156045`, -0.3628113284444857}, {-3.529709496779167, \
-0.35306604651424683`}, {-3.3770822970469965`, -0.34215523328505276`}, \
{-3.3121870858277256`, -0.3370509664991916}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2913765164257005`, -0.3354141323445926}, \
{-3.2623202951324544`, -0.3331287448331993}, {-3.1443294524670553`, \
-0.3229528262073624}, {-3.0231097690508006`, -0.31162747740754193`}, \
{-2.8986612448836904`, -0.29915269843373804`}, {-2.7222445935625252`, \
-0.2797234575698216}, {-2.533245838321615, -0.2566570762930906}, \
{-2.46115860690785, -0.2471254787890176}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4404638835543806`, -0.24438915822856752`}, \
{-2.3908703376300626`, -0.23783174564273624`}, {-2.2362488704119547`, \
-0.21607991399740858`}, {-2.1183580769209334`, -0.19874345912779914`}, \
{-1.9888929383854803`, -0.17911461853089117`}, {-1.777892343093933, \
-0.14647207689502215`}, {-1.6145945046684393`, -0.12140558649638064`}}]}, 
          {Arrowheads[{{0.0037916941915917004`, 1.}}], 
           ArrowBox[{{-1.5939605283901872`, -0.11824371745334651`}, \
{-1.437353400556485, -0.09514087404812374}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.3390718649888578`}, {-4.932081113817887, 
            1.335073884723506}, {-4.823082981041727, 
            1.3281173836600961`}, {-4.714197716130386, 
            1.32052473312725}, {-4.6053623310601575`, 
            1.3121791899848965`}, {-4.496513837807339, 
            1.302964011092964}, {-4.387652236371929, 
            1.2928791964514523`}, {-4.278777526753929, 
            1.2819247460603618`}, {-4.249858132468821, 
            1.278899700902186}, {-4.220931112749303, 
            1.275801529275853}, {-4.169160799863473, 
            1.2693158131838282`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.148447867249423, 
            1.266720924474845}, {-4.055414392853758, 
            1.2550658142707476`}, {-3.8892233189413563`, 
            1.231297133499293}, {-3.76810627236512, 
            1.2129287548671754`}, {-3.6462342932270504`, 
            1.1923600170210753`}, {-3.5236073815271483`, 
            1.1695909199609924`}, {-3.4002255372654124`, 
            1.1446214636869272`}, {-3.3254337565966585`, 1.12785823451397}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.3050642775247394`, 
            1.1232927830330297`}, {-3.275450622045646, 
            1.1166554160789837`}, {-3.14864449747165, 
            1.0848965450172665`}, {-3.0198071635434256`, 
            1.0493448505017755`}, {-2.888938620260972, 
            1.0100003325325109`}, {-2.729805246321688, 
            0.9567250622149079}, {-2.5640606314123033`, 
            0.8943557162632676}, {-2.5098664848796246`, 
            0.8717760887839181}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4905972401136096`, 
            0.8637476872597303}, {-2.4268077990982477`, 
            0.8371702447240443}, {-2.2811071838629955`, 
            0.7709294558163079}, {-2.1635939045129158`, 
            0.7136410867639352}, {-2.03621634666941, 
            0.6480587040104384}, {-1.936920217505494, 
            0.5950164602124731}, {-1.8273758385782795`, 
            0.5351501234957072}, {-1.7446458267844194`, 
            0.48963627629517875`}}]}, 
          {Arrowheads[{{0.006312847814868432, 1.}}], 
           ArrowBox[{{-1.7263561103733733`, 
            0.47957420401906764`}, {-1.6525279195681846`, 
            0.4389576862338229}, {-1.494468745652146, 
            0.354314965991838}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.07563994708572}, {-4.956765012330408, 
            3.0724668076890813`}, {-4.834643050410396, 
            3.0627455790417404`}, {-4.713164920548584, 
            3.0520189698836786`}, {-4.592378404946095, 
            3.0402196668279577`}, {-4.453895321244622, 
            3.025170459371796}, {-4.3164690305399365`, 
            3.008483872703406}, {-4.18017362596955, 
            2.990062654470625}, {-4.170810720403388, 2.988738587661208}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.150141532283845, 
            2.985815628994873}, {-4.04429287387085, 
            2.9708469107443665`}, {-3.9098764270252517`, 
            2.949458899868981}, {-3.776739052588975, 
            2.926141752724877}, {-3.644880750562021, 
            2.9008954693120548`}, {-3.5143015209443895`, 
            2.8737200496305135`}, {-3.3852287750026333`, 
            2.8443350206221405`}, {-3.3301145157716507`, 
            2.8305389706455544`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.3098644569728695`, 
            2.825470031552207}, {-3.2578899240033063`, 
            2.812459909228822}, {-3.132284967946408, 
            2.7780947154505586`}, {-3.008413906831939, 
            2.7412394392873494`}, {-2.8859117778305947`, 
            2.7014585102187456`}, {-2.7656578669130747`, 
            2.658543019907746}, {-2.6520175692330046`, 
            2.6138307570570753`}, {-2.5408695435735713`, 
            2.565647988440368}, {-2.5208442423204023`, 
            2.556035838050313}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.502025093137161, 
            2.547002641002475}, {-2.4324538850905566`, 
            2.5136084410297816`}, {-2.3270106889397426`, 
            2.457325841797474}, {-2.2060134361913812`, 
            2.3839810605367653`}, {-2.090101776477361, 
            2.302758935802364}, {-2.070027946552898, 
            2.2876798100495783`}, {-2.050133184556118, 
            2.272305691938594}, {-1.9811347818564282`, 
            2.211104676472916}, {-1.914657212761778, 
            2.144801219358951}, {-1.836296453018562, 2.055374454660885}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8225391063584786`, 
            2.03967431333157}, {-1.787197294673628, 
            1.999341576794797}, {-1.6706253290395814`, 
            1.822194983718313}, {-1.6159245370619328`, 
            1.7170169724650692`}, {-1.5626339076698084`, 
            1.5954805154915914`}, {-1.5031497444559747`, 
            1.4382249712472237`}, {-1.4553489439454543`, 
            1.2961318963455248`}}]}, 
          {Arrowheads[{{0.011573984866239381`, 1.}}], 
           ArrowBox[{{-1.4486930705663505`, 
            1.2763465893110735`}, {-1.4375441545237346`, 
            1.2432052246184988`}, {-1.3993871651348215`, 
            1.1260960322451832`}, {-1.3515796310981099`, 
            0.9884820414366106}, {-1.285372702068217, 0.8217528004627694}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9098383994270532, -1.5707248378374807`}, {
            0.8497491899460575, -1.68437861835335}, {
            0.747319823883, -1.8668599497801084`}, {
            0.670520955253998, -2.006677248661552}, {
            0.6333945507549632, -2.0822068535990508`}, {
            0.6061552995469395, -2.1484142486392237`}, {
            0.5882831374224511, -2.2074297291415292`}, {
            0.5827289645730614, -2.234727916615706}, {
            0.579352617764683, -2.2608187342053254`}, {
            0.587395945879511, -2.3263944744458245`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.5899373467995901, -2.347114037815973}, {
            0.5937926484084969, -2.3785455862055485`}, {
            0.6590448192378056, -2.481217071545838}, {
            0.6650765794379075, -2.4877375776264588`}, {
            0.6713261117889759, -2.4942209514433706`}, {
            0.6943934473251209, -2.5145981854242567`}, {
            0.719740622492213, -2.534645144697694}, {
            0.7748727291382479, -2.5740577954376986`}, {
            0.8387928700603035, -2.612073669521948}, {
            0.9113010701577331, -2.648578589490038}, {
            1.075864784666038, -2.7144919970969297`}, {
            1.2676332706933162`, -2.7716219344572273`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.2879255749331886`, -2.7765088036550343`}, {
            1.3755352262043896`, -2.7972083420599634`}, {
            1.4876401347547543`, -2.819669034251146}, {
            1.6049557746784442`, -2.8392523047019065`}, {
            1.7269908376848122`, -2.8557598527198294`}, {
            1.8532107115035457`, -2.869219914206372}, {
            1.9830560387330927`, -2.8797901745452053`}, {
            2.114180916982426, -2.8873615628826963`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.1350408969862724`, -2.8881379687546147`}, {
            2.2515093494746163`, -2.89224478590336}, {
            2.3892317326938026`, -2.894329923203871}, {
            2.528906226842348, -2.894046282901554}, {
            2.6701511930889352`, -2.8915689150010686`}, {
            2.812584992602246, -2.8870728695070733`}, {
            2.9696885358186726`, -2.8798725363240765`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.9905414878762304`, -2.8789168086581727`}, {
            3.01497397625492, -2.877797024513178}, {
            3.219398867673439, -2.865711406231149}, {
            3.425295056304374, -2.8514231081883703`}, {
            3.6320979315942954`, -2.835539223912225}, {
            3.8234044384337444`, -2.819830475983219}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.8442079356079453`, -2.818106353070281}, {
            4.048683158663877, -2.8005804344537513`}, {
            4.258673901785129, -2.7822773782835184`}, {
            4.469673381907741, -2.7640265134435618`}, {
            4.6761227914906485`, -2.7464706667129932`}}]}, 
          {Arrowheads[{{0.007310552574364843, 1.}}], 
           ArrowBox[{{4.6969244839821656`, -2.7447246939003604`}, {
            4.895016974341873, -2.7281787776706725`}, {
            5.001099999999999, -2.7195798829163853`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.11005090702398}, \
{-4.9905538039409265`, -2.1093082043685514`}, {-4.881958215884132, \
-2.1009400289525746`}, {-4.665672879787938, -2.0817144930282727`}, \
{-4.450598940213381, -2.058909246844625}, {-4.422072756447388, \
-2.05563787959925}, {-4.393568047287816, -2.0522938500852557`}, \
{-4.223768573955984, -2.029007940131527}, {-4.171124804317987, \
-2.0207727316321087`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.150500784441844, -2.017546459939483}, \
{-4.054720488381251, -2.0025632869330856`}, {-3.911730484059784, \
-1.9786453854179729`}, {-3.7692585930479234`, -1.951709363671475}, \
{-3.6273048153456693`, -1.9217552216935927`}, {-3.485869150953021, \
-1.8887829594843253`}, {-3.344855168677094, -1.8517920803470802`}, \
{-3.333372889063589, -1.8483634441029642`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.3133707391873144`, -1.8423907541551094`}, \
{-3.2041664373250045`, -1.8097820875852646`}, {-3.063802956896752, \
-1.762752981198878}, {-2.923764727392337, -1.710704761187921}, \
{-2.751853094134473, -1.6374228233659036`}, {-2.579351008714987, \
-1.551453245231463}, {-2.541236540233696, -1.5295142601954743`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.523144761782313, -1.5191004915523632`}, \
{-2.4426141583266787`, -1.4727464487295034`}, {-2.3037374017035135`, \
-1.381580540446581}, {-2.1952941073974026`, -1.301632295843928}, \
{-2.0831041720077037`, -1.2101216254943017`}, {-1.9937769883286907`, \
-1.1308822871407134`}, {-1.8990731204805449`, -1.0409639467456504`}, \
{-1.8661886207253229`, -1.0081683797243535`}}]}, 
          {Arrowheads[{{0.013332825424609967`, 1.}}], 
           ArrowBox[{{-1.8514079055246744`, -0.9934276374417041}, \
{-1.8221829664153615`, -0.9642817341624368}, {-1.7383486287431649`, \
-0.8778532797728416}, {-1.5935721506534812`, -0.7264165488831864}, \
{-1.4635089478874705`, -0.5942203510591533}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.942615956232424}, {-4.845424151559007, 
            4.933985002214984}, {-4.677487653845142, 
            4.923637066997252}, {-4.510785373437128, 
            4.912361409122239}, {-4.395206862291699, 
            4.903944124548519}, {-4.280345482784956, 
            4.895077859961633}, {-4.1680641798972555`, 
            4.885935590725668}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.1472646371037865`, 
            4.884164302588812}, {-4.052859993564412, 
            4.876090538858862}, {-3.9402788212890547`, 
            4.866015556398226}, {-3.828500655529269, 
            4.855583742034925}, {-3.717546965004277, 
            4.844818132796583}, {-3.6056072210597243`, 
            4.831775939353489}, {-3.4956763100270227`, 
            4.819670827059333}, {-3.386612811667558, 
            4.807277993945387}, {-3.316689206086359, 4.7989566363827}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2959606325983866`, 
            4.796489803182036}, {-3.171088052968338, 
            4.781629165258122}, {-2.959032944962064, 
            4.754829453291692}, {-2.7504474876487355`, 
            4.7268788580460965`}, {-2.545503282843973, 
            4.698416439922702}, {-2.4681302569625285`, 
            4.687516206534582}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4474595320405563`, 
            4.6846041357788595`}, {-2.344371932363396, 
            4.670081259322873}, {-2.147053436207004, 
            4.641873316246609}, {-1.9535477943747972`, 
            4.613792610693911}, {-1.843062118166365, 
            4.597780080670622}, {-1.7337798777733453`, 
            4.582230569089882}, {-1.6208453628960109`, 
            4.566621284784283}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6001671000300686`, 
            4.563763231297526}, {-1.5188257044335423`, 
            4.552520601256041}, {-1.3082591306236944`, 
            4.525262118988134}, {-1.1016540126121077`, 
            4.501054534081904}, {-0.8983235949824342, 
            4.480344183294276}, {-0.7706137674653859, 4.46967736952949}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7498113606281944, 
            4.467939872862978}, {-0.6975811223183266, 
            4.463577403382175}, {-0.6469532689563116, 
            4.459954743908443}, {-0.5964242024254313, 
            4.456606861164661}, {-0.432654660962723, 
            4.447642245602093}, {-0.2692497317462106, 
            4.44159773088797}, {-0.10569864017585281`, 4.438359724158797}, {
            0.058509388348391825`, 4.437814632551076}, {0.07706452068243197, 
            4.437905004301885}, {0.08436995157491296, 4.437952830522963}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10524394796287517`, 4.4381343310416925`}, {
            0.1303382772504191, 4.438415723715703}, {0.16510306634743993`, 
            4.43890717981734}, {0.3539720137588003, 4.442772409083975}, {
            0.545180760502166, 4.449061242179343}, {0.7390812662634895, 
            4.457179464533876}, {0.9360254907287231, 4.46653286157801}, {
            0.939693217963349, 4.466715825772413}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9605421346997625, 4.467755871831139}, {
            1.1360976613145906`, 4.47651344115005}, {1.3393820054378152`, 
            4.486513211088305}, {1.5438984396683795`, 4.495794833599197}, {
            1.7510282990752404`, 4.5037851838537835`}, {1.7946848793188321`, 
            4.505179549526902}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.815549081883596, 4.505845939970015}, {
            1.960771583658398, 4.5104842618520635`}, {2.1731282934178524`, 
            4.515892067594038}, {2.3875189777565287`, 4.5197094668658435`}, {
            2.6033641860773518`, 4.521637325453615}, {2.6503572657919645`, 
            4.521645612055195}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6712321073802596`, 4.521649293054533}, {
            2.8206639183803217`, 4.521675643357356}, {2.929859231025112, 
            4.520986224552714}, {3.0394181746654385`, 4.519824420577064}, {
            3.149234347338827, 4.518240531019072}, {3.2592013470828016`, 
            4.516284855467405}, {3.3693191738973627`, 4.5139573939220625`}, {
            3.4795878277825105`, 4.511258146383045}, {3.5061207486187658`, 
            4.5105202015122385`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.5269875215440085`, 4.509939845955249}, {
            3.5900073087382447`, 4.508187112850353}, {3.700577616764565, 
            4.504744293323985}, {3.8112987518614725`, 4.500929687803942}, {
            3.922170714028966, 4.496743296290224}, {4.063388003090265, 
            4.491037761588815}, {4.204717512851781, 4.485047095908297}, {
            4.346159243313515, 4.478771299248671}, {4.361360940955668, 
            4.478066711087074}}]}, 
          {Arrowheads[{{0.014842447777379995`, 1.}}], 
           ArrowBox[{{4.382213396654135, 4.477100214201578}, {
            4.487713194475467, 4.472210371609936}, {4.629379366337637, 
            4.465364312992094}, {4.771157758900025, 4.458233123395143}, {
            4.91304837216263, 4.450816802819083}, {5.001099999999999, 
            4.446041367518118}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.16452044614479097`, 2.7520189092194043`}, {
            0.2714112791223159, 2.7805419187733533`}, {0.3103759407904115, 
            2.7924558803364317`}, {0.3518304505364696, 2.8055648477552375`}, {
            0.4981073604144274, 2.852609488601591}, {0.6745958995755038, 
            2.9071511677832187`}, {0.687193132099995, 2.9109021912403743`}, {
            0.699932868081353, 2.9146661573123764`}, {0.7562419111362414, 
            2.930564843917467}, {0.8151125493694309, 2.9464949231340483`}, {
            0.9663045571478301, 2.984243411905274}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9866026272694746, 2.989106050292164}, {
            1.1638828820984126`, 3.026996440389082}, {1.3625581221233358`, 
            3.062096842951097}, {1.5753921404016817`, 3.09145616108941}, {
            1.6877962698930893`, 3.104221987531993}, {1.8005780609142474`, 
            3.11443686405118}, {1.811286429157282, 3.115231194955292}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8321040755828626`, 3.1167754171496935`}, {
            1.9163574836930006`, 3.123025210238589}, {2.0348635068264684`, 
            3.1298913964812947`}, {2.1960654937093413`, 3.136415957543566}, {
            2.360464549315684, 3.1400763219217973`}, {2.5272526505783404`, 
            3.140839897298387}, {2.6664815291719064`, 3.1390489351210675`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.68735464423924, 3.1387804350800845`}, {
            2.695621774430154, 3.138674091355733}, {2.865321301964938, 
            3.1339011717397396`}, {3.0364191309399207`, 
            3.1270461832183143`}, {3.2085850132830624`, 
            3.1183806991568592`}, {3.381488700922325, 3.1081762929207777`}, {
            3.5213188698347393`, 3.0989266338814865`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.542148189838208, 3.0975487902476635`}, {
            3.5550592659221, 3.09669473241068}, {3.7293739632818754`, 
            3.0841921824044376`}, {3.904324819332268, 3.070931811583345}, {
            4.079803860403892, 3.057176788628697}, {4.255826611388588, 
            3.043083909612475}, {4.374671874639437, 3.03344004141498}}]}, 
          {Arrowheads[{{0.01455271514443797, 1.}}], 
           ArrowBox[{{4.3954783263896955`, 3.0317516722461266`}, {
            4.432479167784613, 3.0287491862584788`}, {4.609759411832203, 
            3.0143446107257352`}, {4.787665225771596, 3.000042175173269}, {
            4.937994634612829, 2.988096913289249}, {5.001099999999999, 
            2.9831207894760516`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9134434169397964, 1.2738098464778582`}, {
            0.8382959487664714, 1.3894849627505068`}, {0.7994693274851172, 
            1.4417499544965013`}, {0.7601116930065919, 1.4905080191370206`}, {
            0.6278877394806587, 1.6289392092542425`}, {0.4941109554333786, 
            1.73523091052326}, {0.33370106509945285`, 1.8248858429817882`}, {
            0.3120055048691634, 1.8331688633909529`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.29250362240651073`, 1.84061437246012}, {
            0.25404364036848803`, 1.8552977829263912`}, {0.17327337419841976`,
             1.877032775090142}, {0.09096061272340714, 1.8899426858252917`}, {
            0.003015183047641888, 1.8935458178708398`}, {-0.08778464753654083,
             1.8862443914246552`}, {-0.18214291110472175`, 
            1.8666485803299075`}, {-0.208162045501837, 
            1.859580408867885}, {-0.2344637150584455, 
            1.8514657804353891`}, {-0.2743682465095638, 
            1.835344692053055}, {-0.3152019892341307, 
            1.8163472360249169`}, {-0.42471592797267954`, 
            1.7553552896092144`}, {-0.49119401684758207`, 
            1.7048861158424315`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5078203017015825, 
            1.6922636883088782`}, {-0.5403042500388262, 
            1.667602359124933}, {-0.6614092438955067, 
            1.5424857715036544`}, {-0.7727187288127753, 
            1.3817176231781925`}, {-0.8505148751888617, 
            1.2196241977587536`}, {-0.9014301774348433, 
            1.0524323203432377`}, {-0.9114997170616423, 
            0.9831889350677063}}]}, 
          {Arrowheads[{{0.0018001684170756416`, 1.}}], 
           ArrowBox[{{-0.9145037884000434, 
            0.9625313800265122}, {-0.9253194570921068, 
            0.8881572237081932}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAKsrh9A5P4z9jilZxq57pv4ka/VTe
MuM/ymadzaDB6b9fgSmwIRzjP43O9Na43em/gDsoOiAA4z/3kcekPQDqvz1h
cDryE+I/lnlgASMX67+yIrFshpnhP7chKzseluu/iAtwnuor4T9Lb2MyLAPs
v1iDlCZ7v+A/yWz139Np7L/9e3mRqT7eP/Jmo6xUx+2/1+5r33+12j+GN7Sh
nwfvvzDCH0u0CNc/jWOTNqAN8L/XostgszPTP6p7PXspgvC/hhO7ZAf3yz9g
GZkSGfnwvw6He4G5IcE/zpD+NUlI8b+/YfeOKuqnP4r6ETxSbfG/dDmFZ/vU
jj85IHWnzXLxvzZgbKjbKJG/jUfSjW9y8b8lJ21H3Cqpv81KNBnLZfG/Rf+e
AsfutL+5HfsflFLxv53wROSS68G/NVO2Jsge8b/avq1s
            "]]}, 
          {Arrowheads[{{0.00953545703784535, 1.}}], 
           ArrowBox[{{-0.16040103897825259`, -1.0655852427449186`}, \
{-0.17398659387638055`, -1.0626350556080626`}, {-0.26622307135409784`, \
-1.0281315588513196`}, {-0.35800026106129357`, -0.9764806762252135}, \
{-0.38163639266207666`, -0.9599986144572314}, {-0.40418688728152824`, \
-0.9427902057156465}, {-0.4228288406342011, -0.9271671679607694}, \
{-0.4445571120586509, -0.9070345385505542}, {-0.4674051827280967, \
-0.8843151603071621}, {-0.4723373811244332, -0.879230077239413}, \
{-0.47614277316946585`, -0.8752640657226035}, {-0.4791261143232116, \
-0.8721403056046301}, {-0.48340717677659567`, -0.8676580586375235}, \
{-0.48617945956640574`, -0.8647758328700842}, {-0.4900147996131857, \
-0.8608874062235892}, {-0.4933098396197292, -0.8578200553433492}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.0358870665659654`, -3.7883787247343785`}, \
{-2.8256223931193367`, -3.7440738856860785`}, {-2.6205964992304196`, \
-3.6963634785219255`}, {-2.420809384899214, -3.6452475032419205`}, \
{-2.231703300036439, -3.594200846999216}, {-2.2245045249865316`, \
-3.592058223699849}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.2044970887036888`, -3.5861032662462518`}, \
{-2.047720158312127, -3.5394406185692016`}, {-1.871693973645555, \
-3.48272953289299}, {-1.7039678341114741`, -3.4245675031245755`}, \
{-1.5448848277846348`, -3.365454442417949}, {-1.4154791681107521`, \
-3.3140312393175106`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.3960798863250201`, -3.306322355411008}, \
{-1.3951109434043671`, -3.305937317007533}, {-1.2550538491783383`, \
-3.2465254506634045`}, {-1.1246691523838015`, -3.187662292843042}, \
{-1.0039124602980098`, -3.1297912930039224`}, {-0.8930531335205667, \
-3.073599928612021}, {-0.7921095299931947, -3.019580454726514}, \
{-0.6484871802908999, -2.936194296207}}]}, 
          {Arrowheads[{{0.0145311950673868, 1.}}], 
           ArrowBox[{{-0.6304344403595704, -2.925712998297964}, \
{-0.6182859058504043, -2.9186596418638096`}, {-0.5301804097897352, \
-2.86270274425967}, {-0.4544314021685976, -2.811006144694965}, \
{-0.39025731020351107`, -2.7634972808741236`}, {-0.3432622406040275, \
-2.7253801796120394`}, {-0.30398419834630697`, -2.6899465213540337`}, \
{-0.27204073581620414`, -2.6568099325787857`}, {-0.2587321384464016, \
-2.640973674295983}, {-0.24715527148503935`, -2.6255255759009226`}, \
{-0.22047774080218407`, -2.5741407294032346`}, {-0.21496793857484808`, \
-2.5223140120076373`}, {-0.21533658154573443`, -2.5187237507247384`}, \
{-0.21581116142368123`, -2.515108314333565}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.11397739550595469`, -2.8208016061801855`}, {
            0.059467822314660995`, -2.810383982717022}, {
            0.18960470995553147`, -2.8274046119848926`}, {
            0.3412746323071537, -2.8625607349981013`}, {
            0.5238573066719785, -2.9127098883279134`}, {
            0.6669045005221579, -2.951697303045873}, {
            0.7024517148306495, -2.960782866805922}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.7226763982015657, -2.965952122790332}, {
            0.8281798519809738, -2.9929179026655004`}, {
            1.0074946083821896`, -3.0339916808532803`}, {
            1.2046600170595685`, -3.0725386312756973`}, {
            1.3095026244013892`, -3.0903925320237513`}, {
            1.417939711611391, -3.1066706977281773`}, {
            1.5299712786895736`, -3.1213731283889756`}, {
            1.5421386001853554`, -3.1227544497259014`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.56288020681638, -3.1251091852206025`}, {
            1.6455973256359375`, -3.134499824006147}, {
            1.7963823271617376`, -3.148612700204425}, {
            1.9507955187243475`, -3.1596436307193105`}, {
            2.108836900323767, -3.167592615550804}, {
            2.2705064719599957`, -3.1724596546989052`}, {
            2.3960068646867265`, -3.1740543460354154`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.4168800215847965`, -3.1743195742291106`}, {
            2.43486048533817, -3.1745480459426325`}, {
            2.600955192163425, -3.174161087061004}, {
            2.768790592435762, -3.17129877805402}, {
            2.93836668615518, -3.1659611189216808`}, {
            3.0704264554876812`, -3.1603309217118443`}, {
            3.2030686808855977`, -3.1536708733437937`}, {
            3.251399061949912, -3.150936610116199}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.2722405771554484`, -3.1497575135028697`}, {
            3.3815113298048165`, -3.1435755841606787`}, {
            3.5606731530611264`, -3.1324272467385468`}, {
            3.7405541506545275`, -3.120225861077398}, {
            3.9211543225850196`, -3.106971427177231}, {
            3.9452799888478105`, -3.1051341413871776`}, {
            3.969416613543385, -3.103287127763103}, {
            4.105253868822566, -3.0926014098377994`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.1260644193388085`, -3.090964335588693}, {
            4.127024746834836, -3.0908887908589544`}, {
            4.285099441913106, -3.0782896508556927`}, {
            4.4965929930843975`, -3.0615236231557885`}, {
            4.709004611547641, -3.0448660089559914`}, {
            4.922334297302834, -3.0283168082563017`}, {
            4.958490906753076, -3.0255422488344395`}}]}, 
          {Arrowheads[{{0.0005235853140583404, 1.}}], 
           ArrowBox[{{4.979304556901096, -3.0239450661892855`}, {
            5.001099999999999, -3.0222725434355424`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4532779683174017`, -0.8577154485458964}, {
            1.47467444172489, -0.9824121997298577}, {
            1.5002674113290457`, -1.092127707446646}, {
            1.5761830752717847`, -1.2672076108668926`}, {
            1.6847572637890174`, -1.391475246777544}, {
            1.7767097772901743`, -1.4553452667146023`}, {
            1.8821912049066956`, -1.5017129803720952`}, {
            1.8945027190349912`, -1.5051593487915311`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.9146048033715046`, -1.510786535496615}, {
            1.9982395254370016`, -1.5341984458344653`}, {
            2.1232091715468813`, -1.5548128064819582`}, {
            2.255590987514726, -1.5655042212362316`}, {
            2.3938758176189268`, -1.568220849018943}, {
            2.5045529152301587`, -1.565524480470613}, {
            2.617766209648179, -1.5597280511130063`}, {
            2.743734749941558, -1.5507291176257336`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.764537630038398, -1.5490049162080795`}, {
            2.8856672957366296`, -1.5383172075334122`}, {
            3.0235343756234614`, -1.5245449698040217`}, {
            3.1638161917418204`, -1.509571256839451}, {
            3.182712631701278, -1.507491227387586}, {
            3.2016508786862974`, -1.5053989849658551`}, {
            3.336570345533874, -1.4902961309343674`}, {
            3.4735383607772192`, -1.4750812541333709`}, {
            3.592373007918621, -1.462063837252272}, {
            3.5949377846360036`, -1.4617906420024869`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.615695200681524, -1.4595796006190322`}, {
            3.7127224169408586`, -1.4492444418497354`}, {
            3.8345865878439325`, -1.4366230679257612`}, {
            3.957965520627842, -1.4241997154803496`}, {
            4.082848385015031, -1.4120752120631392`}, {
            4.209224350727943, -1.4003503852237684`}, {
            4.337093417766579, -1.3890252349622374`}, {
            4.446843061339888, -1.3797561661315618`}}]}, 
          {Arrowheads[{{0.012812687350123433`, 1.}}], 
           ArrowBox[{{4.467644249818596, -1.3780042552346508`}, {
            4.597272574579756, -1.3675889555975451`}, {
            4.729506101871771, -1.3575078093440847`}, {
            4.8631561680069835`, -1.347856322518165}, {
            4.998222772985391, -1.3386344951197857`}, {
            5.001099999999999, -1.338449539682098}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.6363079548121393`, -0.1722267295008683}, {
            1.7352516772596576`, -0.2249771542008129}, {
            1.8216947288120724`, -0.2658717193066915}, {
            1.9092221002034935`, -0.2986406570132914}, {
            2.000428877530597, -0.32303647417061465`}, {
            2.047928097544291, -0.33220068398474434`}, {
            2.0969438441296364`, -0.3394995809424956}, {
            2.236251684889401, -0.3511433935675083}, {
            2.3892705629847955`, -0.3534377772569784}, {
            2.4000347806518034`, -0.35332893138959726`}, {
            2.4108679342152977`, -0.3531919417333596}, {
            2.4378598320938827`, -0.3523494131520817}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.4587245120246415`, -0.3516981403419979}, {
            2.5031349548355006`, -0.3503119070528951}, {
            2.600288689448857, -0.3462732449267715}, {
            2.8045470848753857`, -0.3368663200316754}, {
            2.914203882751179, -0.3313914333153601}, {
            3.0289649547522153`, -0.32570329870435927`}, {
            3.1488231453992697`, -0.31994040890373415`}, {
            3.2737712992131165`, -0.31424125661854624`}, {
            3.2928329704059887`, -0.3134279198746627}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.3136888356701126`, -0.3125380272008692}, {
            3.4053526747973395`, -0.3086268502797458}, {
            3.5418659864573705`, -0.3032624237496977}, {
            3.6833112341932095`, -0.2981479770284019}, {
            3.8296884180048565`, -0.29328351011585846`}, {
            3.9806712736136682`, -0.28868785132644936`}, {
            4.1359335367410015`, -0.28437982897455677`}, {
            4.148186935267437, -0.28407104826140833`}}]}, 
          {Arrowheads[{{0.01993363606846655, 1.}}], 
           ArrowBox[{{4.1690551523671076`, -0.2835451775860793}, {
            4.295475207386857, -0.28035944306018057`}, {
            4.4592962855512335`, -0.2766266935833208}, {
            4.627864973575895, -0.2732148183736827}, {
            4.798528124857517, -0.26993546972960347`}, {
            4.973096121784251, -0.26691716725927644`}, {
            5.001099999999999, -0.2664819879655558}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3149254307321874`, 1.273701107020185}, {
            1.320065772801906, 1.3877035665056465`}, {1.325849578270303, 
            1.4389075180180562`}, {1.3339637095010906`, 
            1.4866207694594193`}, {1.3725535251799155`, 1.611147273561496}, {
            1.4321341322152408`, 1.7116950593089073`}, {1.572045438078119, 
            1.8369994137342456`}, {1.5841075400282731`, 
            1.8444796614911572`}, {1.5963980382504117`, 
            1.8517384819212797`}, {1.6519517596866733`, 
            1.8772774452961967`}, {1.7108600279381878`, 1.899417957663987}, {
            1.7427117892776551`, 1.9092754376418297`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.7626534785327916`, 1.9154469896782094`}, {
            1.8344204022471138`, 1.9376574101961077`}, {1.9683726062158227`, 
            1.964608159028778}, {2.110678652662919, 1.981801288320347}, {
            2.320518911743469, 1.9916815026669619`}, {2.429276684201431, 
            1.991609389243821}, {2.5397514262858714`, 1.9889354837914126`}, {
            2.590256080188857, 1.9867148844340665`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6111107736493326`, 1.985797940839424}, {
            2.6517546587268805`, 1.9840109018616572`}, {2.765350825094021, 
            1.9770703871639863`}, {2.880288215407515, 1.968494148210942}, {
            2.9963151196875852`, 1.9586623935150658`}, {3.113380197561867, 
            1.94781433249659}, {3.2315466055765176`, 1.9361086036658546`}, {
            3.350734379129542, 1.9238045591705646`}, {3.44289567755168, 
            1.9141050333117307`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.463655860670178, 1.9119201255853913`}, {
            3.4708635536189454`, 1.9111615511584243`}, {3.591938591419266, 
            1.8983093294127442`}, {3.7140121988916324`, 
            1.8853035852228948`}, {3.837076777413935, 1.8722925829956714`}, {
            3.9611247283640654`, 1.859424587137869}, {4.14597481381337, 
            1.840741857142516}, {4.294239877636713, 1.8262607241744624`}}]}, 
          {Arrowheads[{{0.016494374974803307`, 1.}}], 
           ArrowBox[{{4.3150158581165945`, 1.8242315223644572`}, {
            4.3330358022268385`, 1.8224715041915434`}, {4.522320314464364, 
            1.8048571100634063`}, {4.713840971385845, 1.7881422565365606`}, {
            4.907581205529978, 1.7723311263705908`}, {5.001099999999999, 
            1.7651522894115705`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1923817213845442`, 1.7663585962152935`}, {
            1.2384934657633053`, 1.8875136827551098`}, {1.3080685692603111`, 
            1.9823861585132205`}, {1.4001974590559534`, 
            2.0596846468987344`}, {1.5119498472920225`, 2.121930420931451}, {
            1.574351569898045, 2.1479299725748238`}, {1.640559427715861, 
            2.170787765604437}, {1.760391472103043, 2.2031195519279243`}, {
            1.8367799296688427`, 2.2177102528716106`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8572840901771586`, 2.2216266832278655`}, {
            1.8885959395100884`, 2.2276074536762938`}, {2.023814783576289, 
            2.24498671954931}, {2.1646899579409355`, 2.255992598246739}, {
            2.1837198433265126`, 2.257028052237915}, {2.202828332026931, 
            2.2579657312774635`}, {2.3060442606980636`, 
            2.2598596824617783`}, {2.410914554672932, 2.2594666395831524`}, {
            2.6084286956585285`, 2.2557995146175895`}, {2.689975749403551, 
            2.251943502787653}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.7108272929313664`, 2.2509575223650238`}, {
            2.810105888450851, 2.2462630616677735`}, {3.0152410219615025`, 
            2.23219524054788}, {3.223128985102086, 2.214934011072087}, {
            3.4335818617810543`, 2.195283080051404}, {3.5430852283623206`, 
            2.1846797659223642`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.5638628894628215`, 2.182667845427191}, {
            3.646261403033621, 2.1746891197456497`}, {3.8192368578040234`, 
            2.1571231869113427`}, {3.993762763212919, 2.1391847857436277`}, {
            4.16978017871708, 2.121358466302698}, {4.347230163773279, 
            2.1041287786487457`}, {4.394723765071647, 2.0997283916159586`}}]}, 
          {Arrowheads[{{0.014079383985466475`, 1.}}], 
           ArrowBox[{{4.415509580430934, 2.0978025399249423`}, {
            4.526148488400565, 2.087551600795422}, {4.706625042939288, 
            2.0714378553012103`}, {4.888682067328171, 2.0559046590435535`}, {
            5.001099999999999, 2.04682384644025}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.446802972017779}, \
{-4.954081234155503, -3.4434800770636884`}, {-4.839445048471924, \
-3.434593816722293}, {-4.725371692197479, -3.4249331678302517`}, \
{-4.6118930097495845`, -3.414470945283891}, {-4.499040845545661, \
-3.403179963979539}, {-4.386766034474816, -3.3910675201994978`}, \
{-4.275048869436449, -3.37812837154026}, {-4.170225977878457, \
-3.3650949519256734`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.149527359545121, -3.3623896194369727`}, \
{-4.0535916031885995`, -3.349585987054652}, {-3.9440035648448366`, \
-3.3338907649635097`}, {-3.8352772982649954`, -3.3171848654636267`}, \
{-3.7274888348819366`, -3.2994222954226173`}, {-3.6207142061285205`, \
-3.2805570617080955`}, {-3.5018668076663304`, -3.2579412411844038`}, \
{-3.3845137316095926`, -3.233789352345341}, {-3.326886602639873, \
-3.2209711359019946`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.306509765111053, -3.2164386402086453`}, \
{-3.268761077123996, -3.208042059262808}, {-3.1535832189412103`, \
-3.1812729425751063`}, {-3.0404832285751686`, -3.1526414099674827`}, \
{-2.9291958581116466`, -3.122295801260188}, {-2.819721107550645, \
-3.090236116453221}, {-2.712058976892164, -3.056462355546583}, \
{-2.6065029453994377`, -3.020807629945603}, {-2.50531610993888, \
-2.9838249251968922`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4859696059873393`, -2.975988215561556}, \
{-2.304232321495199, -2.901556333408589}, {-2.200847169369214, \
-2.8538738071806513`}, {-2.1009652640413687`, -2.8033413756750187`}, \
{-2.004096540324619, -2.7491460668432213`}, {-1.9114146291250007`, \
-2.6915269281881677`}, {-1.7567030943205046`, -2.576670399062604}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7399558863740079`, -2.5642106983872193`}, \
{-1.654848755087902, -2.486175074485294}, {-1.5767241329432824`, \
-2.400971497469022}, {-1.56275289100854, -2.38434670360298}, \
{-1.5490601867936318`, -2.3674220243083965`}, {-1.5058008786298454`, \
-2.303014963886334}, {-1.4662421404744324`, -2.23348179836381}, \
{-1.3952884912689314`, -2.08112586490303}, {-1.3410812904387346`, \
-1.8948464964108838`}, {-1.3335685273934421`, -1.8547620036460373`}}]}, 
          {Arrowheads[{{0.013642150737315343`, 1.}}], 
           ArrowBox[{{-1.3297230560279214`, -1.8342444166811154`}, \
{-1.3200032745570691`, -1.7823843343524983`}, {-1.30239380647229, \
-1.6519110492851232`}, {-1.2831396609926895`, -1.46281242279194}, \
{-1.262950432531922, -1.268800249919591}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.6409802371463114`, 0.4896666825967174}, {
            1.6947957521849333`, 0.5630952656742745}, {1.7502155993031152`, 
            0.6274034267035312}, {1.8089059054046281`, 0.6820042898066373}, {
            1.8397826131967663`, 0.7056406244808735}, {1.8717992105698642`, 
            0.7268914185734772}, {2.013517062927886, 0.7907325884869972}, {
            2.174337971733911, 0.8236181435538621}, {2.1857410330679397`, 
            0.8249135531667178}, {2.19722276750175, 0.826106697839703}, {
            2.2603571930193853`, 0.8292471144748644}, {2.3255484475892896`, 
            0.830111867170976}, {2.3561226970177147`, 0.829698547628617}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.376995631740606, 0.8294163758013886}, {
            2.4598851404415703`, 0.8282958297718664}, {2.6019969969241425`, 
            0.8204617116938335}, {2.75168962015701, 0.8085583606305246}, {
            2.934553042018892, 0.7912254440354753}, {3.1274422848442796`, 
            0.7723280548683602}, {3.2091977669562364`, 0.7647271539469651}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.229982972293738, 0.7627947295722319}, {
            3.330274988486472, 0.7534704658214046}, {3.543016658259606, 
            0.7351371656396791}, {3.653057081098145, 0.7263956616525391}, {
            3.7654807946123463`, 0.7179253067203867}, {3.8802564818498513`, 
            0.7097727931227819}, {3.9973528258583024`, 0.7019848131392847}, {
            4.062417163571638, 0.6979447112925768}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{4.083251878350254, 0.6966510015183596}, {
            4.1164762043665615`, 0.6945879718217305}, {4.238197661579582, 
            0.6874806530517827}, {4.361954671825462, 0.680727585485307}, {
            4.487747235104201, 0.6743287691223034}, {4.615901342459402, 
            0.6682228028867482}, {4.745825601730784, 0.6623932952390115}, {
            4.877520012918346, 0.6568402461790934}, {4.917203372390749, 
            0.6552713440553872}}]}, 
          {Arrowheads[{{0.0015110851609671872`, 1.}}], 
           ArrowBox[{{4.93806191911905, 0.6544466906315204}, {
            5.001099999999999, 0.6519544475280286}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.7487765503834113, 1.9246328429525958`}, {
            0.7135003396348895, 2.0022891953098574`}, {0.6868259728204297, 
            2.0708311184538926`}, {0.6684976428234451, 2.1321198753433146`}, {
            0.6567237307796068, 2.2583765337949235`}, {0.686856877448563, 
            2.36448692598114}, {0.8091235556771913, 2.504620496089209}, {
            0.9029792708202689, 2.5666022353343303`}, {0.9715453481527909, 
            2.600798351216407}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9902258374289851, 2.610114914171068}, {
            1.0172911356151801`, 2.623613251966733}, {1.150536850804248, 
            2.675048702181418}, {1.3011941171297954`, 2.720303742173388}, {
            1.4027824017991772`, 2.745094337515154}, {1.509300914334058, 
            2.767013408315069}, {1.6207496547344369`, 2.7860609545731316`}, {
            1.737128623000314, 2.8022369762893433`}, {1.797489518401862, 
            2.8089293410371767`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8182372269771636`, 2.8112296918279323`}, {
            1.8574540432423834`, 2.8155777591809703`}, {1.9807421395713387`, 
            2.82611958896528}, {2.10699291198718, 2.8338624656422713`}, {
            2.2362063604899065`, 2.8388063892119453`}, {2.4006378624185607`, 
            2.841662653544268}, {2.5673088492905296`, 2.841373405699905}, {
            2.6521663709421257`, 2.839647845290762}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.673036898278339, 2.8392234473707147`}, {
            2.7362193211058132`, 2.837938645678857}, {2.907369277864411, 
            2.8313583734811227`}, {3.080172407067292, 2.822445142457783}, {
            3.254042396215424, 2.8120115059599167`}, {3.428979245308808, 
            2.8000574639875238`}, {3.5067131462197474`, 
            2.7941063316597465`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.5275270810889645`, 2.7925128636976746`}, {
            3.604982954347443, 2.7865830165406043`}, {3.75944291259074, 
            2.773882345704724}, {3.914538896214356, 2.760723465660164}, {
            4.0910502669597975`, 2.745585962037995}, {4.268408611310172, 
            2.730414503824096}, {4.359588670831884, 2.7226345427063405`}}]}, 
          {Arrowheads[{{0.014918810385432366`, 1.}}], 
           ArrowBox[{{4.38038793658698, 2.720859840214356}, {
            4.446613929265481, 2.7152090910184663`}, {4.625666220825722, 
            2.6999697236211064`}, {4.649668031657965, 2.697929448868386}, {
            4.673685881700376, 2.69589335973372}, {4.854021712307752, 
            2.6810197640169973`}, {5.001099999999999, 
            2.6692456363746797`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.013679554796381723`, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAJF6dORgn3T/xckWusV8BQMfAv6d6
39s/4fHSOSGXAUBtIjJYybfaP/xCvFG1ygFAb8SRYBR82T+qtlqoUwQCQPCt
7DU/atg/rbK2Ka85AkDVd16BS9vWP/xxNLYxkgJA4UifTvIg1T8zpOju1TED
QHquy9GdFNU/wl9rM547A0CnaZbghgrVP5ER2YRPRQNAR6e0PfEE1T8xX/cC
Ck0DQJk1ubB0/tQ/oJe5r/daA0BqBs5uw/zUP+trwp6+aANAi7uhV9v/1D9X
s2BKYnYDQJXIr7coYtU/wUV3QMu9A0DvIQ2QYk/WP3SAuFpUAwRAH3skRtzK
1z/euaCYaEgEQM+tkNcR19k/laGJJseNBECXDySM4HvcP+Z0JBh41ARAKvhP
AVfA3z9v0Soe2hwFQMjakOA=
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.009888968241540784, 1.}}], ArrowBox[CompressedData["

1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAACMCmwVHd7D8uvk5O7TzUP7N6bHXk
5Ow/CUeb9d2C1D8j8+Mj/+7sPya/KKIf19Q/LcqxDVT47D/aXYU9qiLVP2TU
OnsaBu0/AtZ9c7uR1T/1hUAsoA7tP7asnoc019U/hsj8MywZ7T/OajKUEC/W
P93EJOCuIO0/Q5EoGI5v1j9696X4qyjtP3sv7mbSttY/jDzWVQkx7T8BSNMD
7ATXP0T3q/WNOe0/SauR/5dY1z9FYTYQTkLtP0p7bvqQs9c/fpXYqTFL7T/A
SETmGBbYP9vEDnVLVO0/eZhFYaqC2D8HhKhrSF3tPwJKmlhW99g/CpesHwFm
7T+i0cryCXTZP6USWfUfbu0/h6FTMpP42T/mH9rGG3btP6LrydLvoto/vgiW
JQR+7T+Rux4FW6TbPyMvIqLZge0/uJRz4YBd3D/+fQ0YX4TtP13s9gITKd0/
jcnGmeaE7T+qyJxsGffdP+Bxptx9g+0/EGmNRiQQ4D9MEnxgPnTtPwVzgDoC
IeE/M44pYsVV7T/+jr7G8VHiP4pL2GPmGO0/ZukySvXl4z8JqSh3BqXsP11n
n+HYguU/INzSEvkY7D9A/rbrFhfnP5sR5Aw=
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.8922138896482619, 0.8911907777853723}, {
            0.8653621766029798, 0.9476353588498323}, {0.836008897665562, 
            1.0015179399040066`}, {0.7935832169005284, 1.0614961951219621`}, {
            0.7478984015795553, 1.1179092915214797`}, {0.6008714503152978, 
            1.2683197486962858`}, {0.4359156609165056, 1.3816060002260677`}, {
            0.2933149839698257, 1.4413917751962102`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.2740636235522805, 1.4494629676087316`}, {
            0.2573765888789066, 1.4564590585198172`}, {0.11510642173715196`, 
            1.4853581105208817`}, {-0.03326239911389339, 
            1.4887111776797044`}, {-0.13715706713692621`, 
            1.475256930287162}, {-0.24332653077608626`, 
            1.446603171332455}, {-0.3512272317521788, 
            1.4002007868469017`}, {-0.4478359014497394, 
            1.341211431414356}, {-0.5078110402395963, 1.2914402930009223`}}]}, 
          {Arrowheads[{{0.008706304201027346, 1.}}], 
           ArrowBox[{{-0.5238749221655112, 
            1.2781094744830503`}, {-0.5438286640733033, 
            1.2615506057518187`}, {-0.6367866181271361, 
            1.1554506839009364`}, {-0.7340050734877596, 
            0.9846919855641755}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.20407580781700302`, 2.1419650428678354`}, {
            0.15320734557073046`, 2.1581155297061496`}, {0.1410723457767833, 
            2.1613715595513656`}, {0.12893596361984863`, 2.16434165812343}, {
            0.09280582556885128, 2.1697790621784514`}, {0.05603318060403171, 
            2.1726649465058623`}, {0.005182043971630856, 
            2.1741152265043517`}, {-0.04726994060680189, 
            2.170424644503501}, {-0.10191334302682964`, 
            2.161154531654995}, {-0.17783110051926831`, 
            2.139391462963732}, {-0.26036814927132074`, 
            2.1045847310635115`}, {-0.3515585264384574, 
            2.0530958170930402`}, {-0.44197762436811505`, 
            1.9886091803092436`}, {-0.5430196684189461, 
            1.8995759833816237`}, {-0.5465519946653384, 
            1.8956797375706154`}}]}, 
          {Arrowheads[{{0.003417065429696052, 1.}}], 
           ArrowBox[{{-0.5605728059942497, 
            1.8802144255929913`}, {-0.6563928653708769, 
            1.7745224597565843`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.924650128786994, 
            2.9016301394629895`}, {-0.8537956603335997, 
            2.8452430908811968`}, {-0.7916428904933864, 
            2.7885314289077474`}, {-0.7384762933853569, 
            2.731218572632917}, {-0.7153558885468742, 
            2.7022224650744024`}, {-0.694617074208592, 
            2.6728948157034083`}, {-0.6483186343827081, 
            2.5839193522885555`}, {-0.6252487521878127, 
            2.487495804359738}, {-0.6290341052002489, 
            2.3764315606027266`}, {-0.6308782402315891, 
            2.3644082193874167`}, {-0.633043956338419, 
            2.352143648033617}, {-0.6398642262977898, 
            2.3243047953044673`}, {-0.6483136374550211, 
            2.29492825414278}, {-0.6686965455843817, 
            2.2325208946760893`}, {-0.6865634142200018, 
            2.1868424487168943`}}]}, 
          {Arrowheads[{{0.008296962662537207, 1.}}], 
           ArrowBox[{{-0.6941674964681388, 
            2.167401847953293}, {-0.6964352893992283, 
            2.161604007326486}, {-0.7323669477997099, 
            2.0792345764593683`}, {-0.7788802561872784, 
            1.9774756221466598`}, {-0.8360134378549928, 
            1.8513978369830177`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5483551286726602`, 
            3.5663308874371134`}, {-1.4169718255495238`, 
            3.525213840751548}, {-1.2908301998461964`, 
            3.484476068179591}, {-1.1555046644869027`, 
            3.439932266637226}, {-1.0266997436957053`, 
            3.397287936570834}, {-0.9041048523777946, 
            3.357057873901919}, {-0.7874094054383615, 
            3.319756874551983}, {-0.7538497952436555, 3.3095333318287494`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7338809956404977, 
            3.3034500705903103`}, {-0.676057738086881, 
            3.285834891493587}, {-0.5694941855328283, 
            3.25574187769929}, {-0.521689991800156, 
            3.2431547513542065`}, {-0.4746800284765965, 
            3.231497009156853}, {-0.35388509533102924`, 
            3.2054666742405713`}, {-0.23630989358312568`, 
            3.186464685040031}, {-0.09468803389527095, 
            3.173094154888805}, {-0.08291272501050687, 
            3.1724307913675807`}, {-0.07112713811571647, 
            3.171841492125956}, {-0.03710691733626685, 
            3.1709683837785994`}, {-0.0028902773220007005`, 
            3.1706953377083282`}, {0.08626374031452116, 3.173031629949155}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10713141844984345`, 3.1735784700782266`}, {
            0.14192360886013725`, 3.1744902038020877`}, {0.29358655030998626`,
             3.1875473904598794`}, {0.4549833783973698, 
            3.2084158896830726`}, {0.629064494877358, 3.2356107706686092`}, {
            0.8168571572918929, 3.2664386984459317`}, {0.9341309482064215, 
            3.2849546637972327`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.954750369659319, 3.288210195064777}, {
            1.0193664396271016`, 3.2984122095415898`}, {1.1259060157752905`, 
            3.3140841794471383`}, {1.236003574093598, 3.329139703605906}, {
            1.3494693780369509`, 3.343358001595688}, {1.4659904020989236`, 
            3.3565663850324166`}, {1.5854077319747817`, 
            3.3685320504843523`}, {1.7075624533597913`, 3.379022194519756}, {
            1.7838949859776412`, 3.3845001689510883`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8047162802560524`, 3.385994401014046}, {
            1.832206768776524, 3.387967245200599}, {1.9590420903631542`, 
            3.3953909057281173`}, {2.0878333182383533`, 
            3.4012002853794665`}, {2.2183453525207923`, 
            3.4053024934318024`}, {2.362490216165746, 3.407909861042494}, {
            2.508210802776069, 3.4087367691763766`}, {2.6391983296738784`, 
            3.407923333340296}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6600721100554607`, 3.40773844543925}, {
            2.8033068081952073`, 3.4052112164767214`}, {2.9522695038961855`, 
            3.4010491498536215`}, {3.102053016484552, 3.395549920448264}, {
            3.2524950719924486`, 3.3888477930369167`}, {3.4034333964520176`, 
            3.381077032395846}, {3.494385377692838, 3.3758521530303573`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.515225860004404, 3.3746549388024647`}, {
            3.5548180579315347`, 3.37238050282909}, {3.7066633199484964`, 
            3.3629059826565575`}, {3.858903201708875, 3.3527951076783196`}, {
            4.011471722418643, 3.342189513694447}, {4.164368197321466, 
            3.3311914804542475`}, {4.317629253682552, 3.3198807985351646`}, {
            4.348257632547655, 3.317584815242674}}]}, 
          {Arrowheads[{{0.015181686494424937`, 1.}}], 
           ArrowBox[{{4.369074068527072, 3.3160243608213533`}, {
            4.47124487874018, 3.3083653699794713`}, {4.625205059732634, 
            3.2967530968294416`}, {4.780000667955173, 3.2850309101329427`}, {
            4.93520853394337, 3.2732296438433552`}, {5.001099999999999, 
            3.268228827869245}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9732737590971002, -1.8048463744668697`}, {
            0.9663307155617719, -1.850734726589871}, {
            0.9613802673869628, -1.96694837741143}, {
            0.97771591605577, -2.0656332229977936`}, {
            1.0589100259216393`, -2.2150984951391637`}, {
            1.066802101936044, -2.224227663941272}, {
            1.074980794379583, -2.2332059125838213`}, {
            1.1050727946852505`, -2.2600878021813426`}, {
            1.137975792962691, -2.2855496666133566`}, {
            1.2090032219050333`, -2.333777011548684}, {
            1.2900343707996011`, -2.376741625913781}, {
            1.380185743608087, -2.4146558725556164`}, {
            1.3999141479365542`, -2.4205986112268483`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4199018546113125`, -2.426619458905539}, {
            1.576909956859498, -2.473914623045128}, {
            1.6848465580942993`, -2.496973902030767}, {
            1.7979765043023876`, -2.5158464363866915`}, {
            1.9156575932754696`, -2.5307352985760376`}, {
            2.0373905007288453`, -2.5418767512367215`}, {
            2.1624973049733227`, -2.5494655692881847`}, {
            2.2422072939163566`, -2.5521043980050018`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.263070706169363, -2.552795088997612}, {
            2.29030008431971, -2.553696527649869}, {
            2.4204140135679886`, -2.5548814115668903`}, {
            2.552621751226239, -2.553398869327605}, {
            2.686496601167417, -2.5495439704163183`}, {
            2.8216118672644797`, -2.543611784317335}, {
            2.9578184101255727`, -2.535889206796544}, {
            3.0951256942075216`, -2.5266584629235966`}, {
            3.0973151798251832`, -2.5264929144835624`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.1181306059424796`, -2.5249190464962292`}, {
            3.233344929156302, -2.516207616138442}, {
            3.372287324617889, -2.5048247298810287`}, {
            3.5547927075712455`, -2.488831332222629}, {
            3.738655051829365, -2.471847219601308}, {
            3.9237430259603845`, -2.454335341325209}, {
            3.9499047993331318`, -2.4518655170234136`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.970687235329996, -2.449903533607984}, {
            4.109925298532441, -2.4367586467024753`}, {
            4.297248584484939, -2.419293932330694}, {
            4.485861339540866, -2.4019544789728475`}, {
            4.675784843443734, -2.384957962185173}, {
            4.802229034741499, -2.3740917422852936`}}]}, 
          {Arrowheads[{{0.004279968666052756, 1.}}], 
           ArrowBox[{{4.823027219089353, -2.372304411113158}, {
            4.867040375937049, -2.368522057523908}, {
            5.001099999999999, -2.3575000671132385`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.6333308706733747`}, {-4.95765804386779, 
            2.630179867744427}, {-4.741093630279822, 
            2.611435540866129}, {-4.52622486352189, 
            2.5893445836503597`}, {-4.313185378794607, 
            2.563509550442065}, {-4.171148731629666, 2.543337868687932}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.150481269827594, 
            2.5404027285641795`}, {-4.102108811298592, 
            2.53353299558619}, {-4.074203016354841, 
            2.5292763242880323`}, {-4.046335062942789, 
            2.5249373799186907`}, {-3.888055064252354, 
            2.4966895708610144`}, {-3.731168888886239, 
            2.465268395361579}, {-3.5839632693646517`, 
            2.433809766369561}, {-3.438278711952679, 
            2.3987032238642607`}, {-3.3334633629772057`, 
            2.370526452598949}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.3133042242987703`, 
            2.365107213479868}, {-3.294115216650321, 
            2.359948767845678}, {-3.151472783457577, 
            2.317546398313813}, {-3.010644857143701, 
            2.270365843777485}, {-2.871924882477946, 
            2.217276832745514}, {-2.7353128594603127`, 
            2.1582793652178984`}, {-2.6008087880908004`, 
            2.093373441194639}, {-2.5387593793587686`, 
            2.0586458514757644`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.520543441806564, 
            2.048450821118754}, {-2.4415746466856914`, 
            2.004253850130764}, {-2.2860867130612754`, 
            1.9007430255380282`}, {-2.1677414791946634`, 
            1.8078263820271128`}, {-2.0512370575067833`, 
            1.7009800964558408`}, {-1.9640032316969769`, 
            1.608814532967257}, {-1.8857171317858645`, 
            1.5149047164870038`}}]}, 
          {Arrowheads[{{0.010765709185796526`, 1.}}], 
           ArrowBox[{{-1.872617822784002, 
            1.4986594765747312`}, {-1.8089023407363394`, 
            1.413460219860388}, {-1.7390165137455635`, 
            1.3111828158092977`}, {-1.6831206207862124`, 
            1.2236943326917378`}, {-1.6230457978006676`, 
            1.1251847773288561`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.4449338102235092`, -1.5040400301205328`}, {
            1.5121092652520614`, -1.608110235044596}, {
            1.5992319660588374`, -1.689734504316694}, {
            1.7036741444111205`, -1.7521350137488318`}, {
            1.8228080320761946`, -1.7985339391530133`}, {
            1.9915096082766623`, -1.8384773238178653`}, {
            2.159180638598007, -1.8584893965182472`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.179939228473138, -1.860569945635957}, {
            2.370167836921589, -1.867762767817623}, {
            2.5734824509863303`, -1.8641114560699936`}, {
            2.783448241777106, -1.8521368412966919`}, {
            2.9984997259217154`, -1.83454387148414}, {
            3.013633016125486, -1.833070473914423}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.034409617184714, -1.8310476359792847`}, {
            3.1311083973284117`, -1.8216329121657666`}, {
            3.265239850733566, -1.8077935136043286`}, {
            3.417370686712321, -1.7917835537006102`}, {
            3.5713507619479845`, -1.7756304272383758`}, {
            3.727180076440557, -1.7593341342176256`}, {
            3.8649523676111777`, -1.7449700881378984`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.8857146851333435`, -1.7428055568763556`}, {
            3.9060611522445585`, -1.7406874315996799`}, {
            3.9272968843130314`, -1.738485796402303}, {
            4.08491983720508, -1.7227903244751805`}, {
            4.2443603196283926`, -1.7075811024555925`}, {
            4.444289430693521, -1.6891080395994942`}, {
            4.646981864014017, -1.6715682176967406`}, {
            4.7171433738366595`, -1.6658972021092884`}}]}, 
          {Arrowheads[{{0.00632204993081534, 1.}}], 
           ArrowBox[{{4.7379503586353735`, -1.6642154148242132`}, {
            4.852437619589878, -1.6549616367473312`}, {
            5.001099999999999, -1.6437713267283771`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.6923914004800298`, -1.0260548171587391`}, {
            1.752120949261967, -1.0896297666799302`}, {
            1.7848523846954512`, -1.116668762732774}, {
            1.8194477290764177`, -1.1407706602361078`}, {
            1.9022280935403986`, -1.1845766351969171`}, {
            1.9929294091610015`, -1.2165175453952801`}, {
            2.1862031924449714`, -1.2513964250294216`}, {
            2.2001267630415207`, -1.2526758764069368`}, {
            2.214139558634836, -1.2538326210598045`}, {
            2.2918747349569477`, -1.2561806581324737`}, {
            2.371736908375242, -1.2557923831319906`}, {
            2.4629479912330616`, -1.253011865717074}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.4838131404039347`, -1.2523758036419763`}, {
            2.5352586309624865`, -1.250807517443248}, {
            2.705947371882686, -1.238742224494939}, {
            2.8831392201540553`, -1.2219983879983474`}, {
            3.0904175555185973`, -1.199285636750346}, {
            3.3053031392715266`, -1.1749996559598543`}, {
            3.3149016692047044`, -1.1739492127980438`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.335652617460197, -1.1716782721594443`}, {
            3.4155049998569336`, -1.1629393934325054`}, {
            3.5275897264404885`, -1.1509141757542949`}, {
            3.641551003655874, -1.139066787003477}, {
            3.757382516136774, -1.1275400112583056`}, {
            3.8750678977055366`, -1.1163701447444119`}, {
            3.9945850388637467`, -1.1055326334859286`}, {
            4.115919009263944, -1.0950789862588621`}, {
            4.166703474845126, -1.0909471868460565`}}]}, 
          {Arrowheads[{{0.01953224998343365, 1.}}], 
           ArrowBox[{{4.187509568716179, -1.0892544131709692`}, {
            4.239054878558667, -1.085060711839218}, {
            4.3638183362976015`, -1.0755095946684228`}, {
            4.490544222324512, -1.0663090962746922`}, {
            4.618899738819993, -1.0575352058108307`}, {
            4.7488848857840456`, -1.0491879232768386`}, {
            4.908771988439866, -1.0395438097269285`}, {
            5.001099999999999, -1.0343131083799812`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01452428604957812, 1.}}], 
           ArrowBox[{{0.34462535980660797`, -2.297449419155071}, {
            0.319566469477701, -2.3375226120938644`}, {
            0.30169260855643765`, -2.3732213504569724`}, {
            0.29057080842150446`, -2.4057137707542346`}, {
            0.28905737135424725`, -2.412258850108467}, {
            0.28783129291756765`, -2.418712288606273}, {
            0.2868913033660104, -2.4250817815889927`}, {
            0.286495916549141, -2.4285515913451268`}, {
            0.29337347810193576`, -2.4865931522134233`}, {
            0.32712853761542104`, -2.5430557196233714`}, {
            0.33032555152853166`, -2.5468752434029223`}, {
            0.33365141440711876`, -2.5507047804991725`}, {
            0.3474358941976673, -2.564359653579825}, {
            0.3629380719918736, -2.578227988804291}, {
            0.39743982463372746`, -2.606406358473292}, {
            0.4391118444876612, -2.6355116523484323`}, {
            0.48830880840724755`, -2.665583164192618}, {
            0.6076431023644613, -2.7267876831234212`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.4208077015375652, -2.0297723720471468`}, {
            0.3766702416892877, -2.061690563484655}, {
            0.2583810812972734, -2.1313814710063426`}, {
            0.14573315534516545`, -2.173576745289152}, {
            0.09890984133404297, -2.1836128881949897`}, {
            0.05155765389646861, -2.18925144153465}, {
            0.0031931564439111465`, -2.190354633297802}, \
{-0.008707869497283518, -2.1900597639182915`}, {-0.020695294666096452`, \
-2.189482253275015}, {-0.05393650851644091, -2.1850039953069627`}, \
{-0.08833320791283554, -2.178169029587434}, {-0.13917524539429424`, \
-2.16565732917128}, {-0.19287949836953136`, -2.147446731058308}, \
{-0.2500793019646576, -2.122638469674129}, {-0.31418831451739254`, \
-2.088397137263007}, {-0.3498329897586962, -2.0654752787971207`}}]}, 
          {Arrowheads[{{0.010640111580182169`, 1.}}], 
           ArrowBox[{{-0.36739079374734523`, -2.0541844619983967`}, \
{-0.38381667479634524`, -2.0436215457133193`}, {-0.4600117745725957, \
-1.9854247765622972`}, {-0.5658016961931897, -1.8871514447990465`}, \
{-0.6854032197305343, -1.7467699625442097`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01823477852508449, 1.}}], 
           ArrowBox[{{-0.5333949207702029, -2.567325404937698}, \
{-0.5222701480344527, -2.4864301363117107`}, {-0.5359434616791331, \
-2.386490003356757}, {-0.5386316402795652, -2.3761109898602726`}, \
{-0.541610400610179, -2.3655245953159048`}, {-0.5515826432895728, \
-2.3373385153957535`}, {-0.563596126937068, -2.3073007356473103`}, \
{-0.5920449589262634, -2.242723088965814}, {-0.6299576914960414, \
-2.167427207412986}, {-0.6787088012439764, -2.077081062615036}, \
{-0.7297317463651227, -1.9835755530701924`}, {-0.7906437318053474, \
-1.8678794106991992`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.5544884497207483`, 1.420151062141866}, {
            1.709677709595147, 1.5637158247831813`}, {1.8290057072899062`, 
            1.6215127399802176`}, {1.9632830186736407`, 
            1.6610726730460637`}, {2.1097012690362673`, 
            1.6853633231384542`}, {2.2654520836677032`, 
            1.6973523894151241`}, {2.3118301261001535`, 
            1.6977765024156168`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.3327040952339613`, 1.6979673884732684`}, {
            2.4629217684617357`, 1.699158189231844}, {2.6685178975340325`, 
            1.6904977875442793`}, {2.7740437304342143`, 
            1.6829716780122324`}, {2.8809618779233315`, 
            1.6742868518557985`}, {2.989272340001384, 1.6644433090749775`}, {
            3.0989751166683717`, 1.6534410496697693`}, {3.1655135866058184`, 
            1.6463243155942808`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.1862700419882763`, 1.6441042739635436`}, {
            3.234468571957815, 1.6389491190442145`}, {3.3718030435772697`, 
            1.6238705370801314`}, {3.521133045905841, 1.6075470626937203`}, {
            3.672574026600242, 1.5913747899433321`}, {3.8261259856604726`, 
            1.5753537188289672`}, {3.9817889230865324`, 
            1.5594838493506253`}, {4.002751948855415, 1.5573711707837758`}, {
            4.016597027924306, 1.5559840909408782`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{4.037375027806099, 1.5539763807564446`}, {
            4.184797685291561, 1.5400070290646248`}, {4.348013539130209, 
            1.5253706559549913`}, {4.462355871017698, 1.5153231185147589`}, {
            4.577696469180747, 1.5055982719160375`}, {4.6940353336193565`, 
            1.4961961161588269`}, {4.811372464333527, 1.487116651243127}, {
            4.869315050246995, 1.4828289220680388`}}]}, 
          {Arrowheads[{{0.0026647703967048117`, 1.}}], 
           ArrowBox[{{4.890132971100048, 1.4812884038947627`}, {
            4.929707861323257, 1.4783598771689386`}, {5.001099999999999, 
            1.473314132126989}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.7541347937433951}, {-4.995894009091528, 
            0.7539594282334187}, {-4.966731421292757, 
            0.7529318186421221}, {-4.937569048861758, 
            0.7518762883073083}, {-4.749653203193509, 
            0.7436208113555609}, {-4.5613168012227305`, 
            0.7338924073405534}, {-4.401567506832511, 
            0.724908049743376}, {-4.240857778257263, 
            0.7144088744972574}, {-4.167376457690647, 
            0.7089483488929385}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.146559016058886, 
            0.7074013683518962}, {-4.079187615496987, 
            0.7023948816021981}, {-3.916557018551684, 
            0.6888660710581977}, {-3.78284594528197, 
            0.6763537596685596}, {-3.6472838821882596`, 
            0.6620771336843347}, {-3.5098708292705534`, 
            0.6460361931055231}, {-3.3706067865288505`, 
            0.6282309379321246}, {-3.3162432109803577`, 
            0.6206227582749513}}]}, 
          {Arrowheads[{{0.01805943328047658, 1.}}], 
           ArrowBox[{{-3.2955698415289114`, 
            0.6177295212625068}, {-3.263490393951586, 
            0.6132400041914036}, {-3.1539483867257356`, 
            0.5965013210478105}, {-3.041980764851299, 
            0.5780148885013455}, {-2.927587528328276, 
            0.5577807065520084}, {-2.746914384157348, 
            0.5224635655924039}, {-2.554446064445993, 
            0.48033531705470156`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.0387328838112957`}, {-4.998628272537758, 
            1.0386223201918139`}, {-4.889389716494517, 
            1.033259669821924}, {-4.860294423192416, 
            1.0317678439274272`}, {-4.831200915756593, 
            1.0302367902606901`}, {-4.646731188017827, 
            1.018544628080776}, {-4.461958600428739, 
            1.0048579522023826`}, {-4.312167020235078, 
            0.9928708513952156}, {-4.1682797128157505`, 
            0.9796551866954428}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.147508445735979, 
            0.9775813544249424}, {-4.010508384476247, 
            0.9633934562042685}, {-3.8586413289110766`, 
            0.9459031618204886}, {-3.73164415960086, 
            0.929559415922927}, {-3.603252772263733, 
            0.9110757398996291}, {-3.473467166899695, 
            0.8904521337505948}, {-3.342287343508746, 
            0.8676885974758243}, {-3.320631365008163, 
            0.8634016887764174}}]}, 
          {Arrowheads[{{0.017933840020983572`, 1.}}], 
           ArrowBox[{{-3.3001538847667553`, 
            0.8593480696713535}, {-3.136793889217393, 
            0.8270101457102286}, {-3.031260618242991, 
            0.8035118852977943}, {-2.9238696513827716`, 
            0.7779076018656023}, {-2.75334691891788, 
            0.7329769615742139}, {-2.5736917629424245`, 
            0.6798681921743478}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.691846544987607}, \
{-4.98530901948275, -0.6913410500637018}, {-4.9561357695944475`, \
-0.6903816435074898}, {-4.767619017732239, -0.6828461068427225}, \
{-4.578661641763023, -0.6739553557854897}, {-4.416004540115201, \
-0.6656042872432618}, {-4.252314969243706, -0.6558090632394358}, \
{-4.167194743355495, -0.6500011062812321}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.146368325505418, -0.648580069891765}, \
{-4.087592929148537, -0.6445696837740114}, {-3.9218384198296947`, \
-0.6318861488469888}, {-3.7862909865152057`, -0.6201972716902361}, \
{-3.648765608740439, -0.6068282469845379}, {-3.509262286505394, \
-0.5917790747298942}, {-3.3677810198100717`, -0.5750497549263052}, \
{-3.3153799944834073`, -0.5682622715283342}}]}, 
          {Arrowheads[{{0.018355383491567265`, 1.}}], 
           ArrowBox[{{-3.294678097508481, -0.5655807632725728}, \
{-3.25931711632034, -0.5610004698288042}, {-3.1482655727135023`, \
-0.5452849893227466}, {-3.0346263889895586`, -0.5279033134081322}, \
{-2.918399565148509, -0.5088554420849613}, {-2.7352753468035313`, \
-0.4756929673640385}, {-2.5395767221986407`, -0.4360365840420584}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.9845563953350729}, \
{-4.908471145591034, -0.9802822648920446}, {-4.87936107105393, \
-0.9788789715661385}, {-4.850252326082435, -0.9774385473949404}, \
{-4.665157445824224, -0.966391771015572}, {-4.479728840944039, \
-0.9534443657464985}, {-4.328540877373408, -0.9420265942749028}, \
{-4.176611051668815, -0.928834639217972}, {-4.168098103587306, \
-0.9280001298007644}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.14732284334075, -0.9259635673602685}, \
{-4.023939363830261, -0.9138685005757063}, {-3.870525813857745, \
-0.8971281783481058}, {-3.7425527687124704`, -0.8815091500125081}, \
{-3.613105670438302, -0.8638207036440799}, {-3.4821845190352407`, \
-0.8440628392428211}, {-3.349789314503286, -0.8222355568087318}, \
{-3.3197801059151115`, -0.816588856549266}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.299265281871169, -0.812728672702316}, \
{-3.142540006755352, -0.7832383697820956}, {-3.0359847404376423`, \
-0.7606808806625639}, {-2.92747573249077, -0.7360841278055563}, \
{-2.7552520429520877`, -0.6929460093362052}, {-2.5734570859920693`, \
-0.6418825372446464}, {-2.4884604623525446`, -0.6156082081679987}}]}, 
          {Arrowheads[{{0.001041231434933418, 1.}}], 
           ArrowBox[{{-2.468516758394978, -0.6094431698599984}, \
{-2.4269847354157292`, -0.5966047064922813}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.4689849788357074`}, \
{-4.901871651810826, -4.46295688811566}, {-4.749441135952808, \
-4.4525824563286}, {-4.5980085504339865`, -4.441183040617782}, \
{-4.447664820594799, -4.428792883027}, {-4.298500871775685, \
-4.415446225600048}, {-4.168778315041485, -4.402930439663495}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.148001584697266, -4.4009093940035955`}, \
{-4.0386883759486825`, -4.389671367364576}, {-3.9276416003292227`, \
-4.377631450470894}, {-3.817498454172888, -4.365080345261895}, \
{-3.7082900891938624`, -4.352040837299797}, {-3.4928023096244667`, \
-4.32458775536518}, {-3.3192846812495906`, -4.29939297461597}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.298626472750743, -4.2963934002287765`}, \
{-3.278769195724216, -4.2935101211888}, {-3.0697212751005183`, \
-4.261390298488771}, {-2.865035513469714, -4.227772576020721}, \
{-2.664711910831803, -4.192656953784649}, {-2.4753676320817384`, \
-4.157279785769277}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.454870201670796, -4.153329134105339}, \
{-2.277513942001402, -4.118646967344815}, {-2.0913650947423954`, \
-4.081182517813803}, {-1.9103039254097656`, -4.043650083187518}, \
{-1.7343304340035122`, -4.006049663465961}, {-1.6370345098920922`, \
-3.9850296561826606`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6166304097788982`, -3.980621513324617}, \
{-1.5528128286659872`, -3.966834234648278}, {-1.377055104131929, \
-3.9292168608986877`}, {-1.2067472407734756`, -3.8938272744974047`}, \
{-1.0415792189627655`, -3.861295207724644}, {-0.8809498889083125, \
-3.8321769279188582`}, {-0.7975857555398601, -3.818797413585971}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7769746820274844, -3.8154894423718253`}, \
{-0.7242581008186304, -3.8070287024185014`}, {-0.6725218701115367, \
-3.799509689724815}, {-0.621106291343369, -3.7925002094005986`}, \
{-0.47261413172876926`, -3.7750908764317934`}, {-0.325610935539528, \
-3.7623056661549126`}, {-0.20221876396684696`, -3.755163728411792}, \
{-0.07858426299094097, -3.7513044577663583`}, {-0.06268706794877334, \
-3.751019549771054}, {-0.04677557794432283, -3.7507866704886594`}, \
{-0.013596195590314254`, -3.7506309064420185`}, {
            0.019671448467025357`, -3.7506921206639325`}, {
            0.05447903726326099, -3.75113274923053}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.07535220678277432, -3.751396982263722}, {
            0.14406198156545474`, -3.7522667779209553`}, {
            0.2702314347776337, -3.756536252699164}, {
            0.3986081434674784, -3.763153797011603}, {
            0.529620442998905, -3.771772662871317}, {
            0.6635382774191122, -3.7819649554303534`}, {
            0.8006315907752986, -3.79330277984076}, {
            0.9085707186097607, -3.8024686381918578`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9293722083289199, -3.804216972682718}, {
            1.0412776205944678`, -3.813509432618654}, {
            1.165197856809162, -3.8235758234096844`}, {
            1.2915162405605962`, -3.833617590468771}, {
            1.4200496977510109`, -3.8432191648821163`}, {
            1.5506151542826467`, -3.851964977735923}, {
            1.6832126101555036`, -3.8598550290301916`}, {
            1.7621810666883202`, -3.8639810726383526`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.7830274728028541`, -3.865070281981912}, {
            1.8178420653695817`, -3.8668893187649216`}, {
            1.9548997411203748`, -3.8732973104738955`}, {
            2.0921403839667514`, -3.8777787107990136`}, {
            2.2310960491979546`, -3.881220778737567}, {
            2.3716082483357863`, -3.883531728876044}, {
            2.573739666014187, -3.8849052589107167`}, {
            2.6176841537101336`, -3.884730642432673}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6385588308258274`, -3.884647695451394}, {
            2.777910568584812, -3.8840939716299885`}, {
            2.9835535000489894`, -3.8810183798595763`}, {
            3.1901010044080493`, -3.8755989964251985`}, {
            3.39739795473301, -3.868113081500594}, {
            3.473250188790928, -3.864807018039806}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.4941052309138034`, -3.8638980389755506`}, {
            3.6055248407061424`, -3.8590417508869437`}, {
            3.814267631245651, -3.848611300851126}, {
            4.023412295269741, -3.8370480276600194`}, {
            4.232938843907581, -3.8245670887340997`}, {
            4.327854846285062, -3.818605525517916}}]}, 
          {Arrowheads[{{0.01566019702826467, 1.}}], 
           ArrowBox[{{4.3486886345271705`, -3.8172969796191545`}, {
            4.44293816955175, -3.811377276438753}, {
            4.653362563015564, -3.797695339458226}, {
            4.8641643151123395`, -3.7837380264767657`}, {
            5.001099999999999, -3.7745889782080724`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.969123305215241, -5.001099999999999}, \
{-2.866048856225865, -4.989166173861233}, {-2.739031194512066, \
-4.97401376152741}, {-2.613196003810171, -4.958551782103334}, \
{-2.4739797444052494`, -4.941168652072975}, {-2.336322957178858, \
-4.923931673919865}, {-2.200225642130997, -4.906840847644004}, \
{-2.1403630511292198`, -4.899301317564221}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.119651830994563, -4.896692795871773}, \
{-2.065687799261667, -4.88989617324539}, {-1.9326432296764313`, \
-4.87332079148056}, {-1.8010257344808545`, -4.8573378431060465`}, \
{-1.6708353136749359`, -4.841947328121852}, {-1.5420719672586765`, \
-4.8271492465279735`}, {-1.414569961385624, -4.813144177000798}, \
{-1.2902576991442005`, -4.800348255486569}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.2694796499127674`, -4.798340824095536}, \
{-1.1628527697297866`, -4.788114810175711}, {-1.038637583947002, \
-4.777090512877799}, {-0.9777287978123395, -4.772038591929639}, \
{-0.9170143621294402, -4.767273502272369}, {-0.7434723378173653, \
-4.755267799421683}, {-0.5709825373028177, -4.745782503046138}, \
{-0.436644697616552, -4.740345207009695}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.41578693339816, -4.739500993354194}, \
{-0.39911119257304356`, -4.738826046223103}, {-0.2274245356152894, \
-4.734406862029949}, {-0.20784479406338519`, -4.734047369269973}, \
{-0.18826152676917157`, -4.733719661111905}, {-0.15066627184764111`, \
-4.733266636312028}, {-0.11304755767556571`, -4.732926968896598}, {
            0.08529140580864311, -4.732524269603582}, {
            0.2849000915152489, -4.734886396967538}, {
            0.4190754384071754, -4.737998933685756}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.4399446659442368, -4.738483048230601}, {
            0.4862313598417992, -4.739556785229673}, {
            0.6897380711858412, -4.746078868631193}, {
            0.8956519992999122, -4.7539064012496315`}, {
            1.1042049179365494`, -4.7624931371625205`}, {
            1.274352366703888, -4.769485554443639}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.2952096031595675`, -4.77034270805767}, {
            1.2993834853021933`, -4.770514238843672}, {
            1.4967194121100682`, -4.7779925617956005`}, {
            1.6962126983601746`, -4.784928106018306}, {
            1.8978633440525121`, -4.791320871511788}, {
            2.101316931367097, -4.796743553984769}, {
            2.129758535608374, -4.7973022883545875`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.150629350627989, -4.797712294821826}, {
            2.306219042483945, -4.800768849145974}, {
            2.5125696774030555`, -4.803396756995403}, {
            2.7203688361244294`, -4.804627277533053}, {
            2.929244620824022, -4.8044540312941555`}, {
            2.9855709516623494`, -4.804028482718702}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0064451978445117`, -4.803870776622916}, {
            3.138825133677792, -4.802870638813938}, {
            3.3491103746857385`, -4.7998771000924}, {
            3.5601003438478607`, -4.795473415129542}, {
            3.6969826839306394`, -4.7919769200342754`}, {
            3.833975293109157, -4.788102456751954}, {
            3.8412649056935595`, -4.787876359544195}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.8621297138976227`, -4.787229209257299}, {
            3.9710781713834122`, -4.783850025282576}, {
            4.108291318753405, -4.779219625626142}, {
            4.245614735219137, -4.774211257782653}, {
            4.383048420780606, -4.768824921752108}, {
            4.520592375437815, -4.763060617534507}, {
            4.65824659919076, -4.756918345129851}, {
            4.696497178449302, -4.755142567891645}}]}, 
          {Arrowheads[{{0.006804064835390642, 1.}}], 
           ArrowBox[{{4.717349561238094, -4.754174499239183}, {
            4.795995167357066, -4.7505233891138445`}, {
            4.933822155254359, -4.7440010340621965`}, {
            5.001099999999999, -4.7407569181803355`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.026891031491877986`}, {-4.937058063933162, 
            0.026805171503267132`}, {-4.827299181144211, 
            0.0266437677041105}, {-4.798061132468836, 
            0.02659887512124196}, {-4.768812434761268, 
            0.02655277773803892}, {-4.585743782315841, 
            0.026205766931871356`}, {-4.40165825299635, 
            0.025798375779007437`}, {-4.215000054783508, 
            0.025340223090346194`}, {-4.166108121904957, 
            0.02519710850708333}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145233369422226, 
            0.025136004735430397`}, {-4.025666964461416, 
            0.024786014558917817`}, {-3.833658982030073, 
            0.024135750184722304`}, {-3.6389761074894795`, 
            0.023389429967759657`}, {-3.5118797216657573`, 
            0.02284243351386734}, {-3.381728123014855, 
            0.022219148090802124`}, {-3.3102463920339478`, 
            0.021843740947937475`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289371837992928, 
            0.02173411214371607}, {-3.248521311536774, 
            0.021519573698564012`}, {-3.1122592872315127`, 
            0.02074371033715301}, {-2.9139981171241565`, 
            0.019480340171757562`}, {-2.7027179121117157`, 
            0.017955818877453632`}, {-2.5455379255898634`, 
            0.01670425517688736}, {-2.454398817999123, 
            0.015919766595325596`}}]}, 
          {Arrowheads[{{0.010462970603037667`, 1.}}], 
           ArrowBox[{{-2.433524749359157, 
            0.015740091053928776`}, {-2.375695077641901, 
            0.015242316626057791`}, {-2.2465661774958003`, 
            0.014063922164506498`}, {-2.10538932704018, 
            0.012718853332203288`}, {-1.9967181773849059`, 
            0.011654096412002258`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.451018321549633}, {-4.891944675283365, 
            3.4429064017593007`}, {-4.778465945684358, 
            3.4336846760664237`}, {-4.665555682401823, 
            3.4236875895833188`}, {-4.553246060766556, 
            3.4128884372613797`}, {-4.441569256109347, 
            3.401260514052}, {-4.330476171913804, 
            3.3888112396698493`}, {-4.219947265062508, 
            3.37553562482477}, {-4.170244828575403, 3.3691368137912394`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.149540861573567, 
            3.366471335358938}, {-4.110059040984719, 
            3.3613883509609135`}, {-4.000888005109696, 
            3.346324099522433}, {-3.892510662866701, 
            3.330297551953479}, {-3.785003519684992, 
            3.3132633896982053`}, {-3.572905852222473, 
            3.2759909469053023`}, {-3.4556370671216188`, 
            3.2530567492819285`}, {-3.339871618542845, 
            3.228599127150598}, {-3.3267902165523413`, 
            3.2256152126379884`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.3064381329866075`, 
            3.220972829691747}, {-3.2257156029788066`, 
            3.2025597323066415`}, {-3.112143421000513, 
            3.1755025973951905`}, {-3.000658106253898, 
            3.1466011228501047`}, {-2.890994417507326, 
            3.116001179183056}, {-2.783152354760797, 
            3.083702766394045}, {-2.6771319180143105`, 
            3.0497058844830702`}, {-2.5732252914747304`, 
            3.0138451029254036`}, {-2.505219224091602, 
            2.9884584877148828`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-2.4856625872954896`, 
            2.981158009503758}, {-2.471724659348921, 
            2.9759549911963163`}, {-2.275941378338612, 
            2.8940867772238783`}, {-2.173278017020992, 
            2.845725923894449}, {-2.074199859176527, 
            2.7944728798940908`}, {-1.9772345575058554`, 
            2.7388864368982535`}, {-1.8846505434855676`, 
            2.6797312789384886`}, {-1.7567569834218881`, 
            2.5815479848324965`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7401988042653467`, 
            2.568836347333494}, {-1.714215555137798, 
            2.5488891272416523`}, {-1.6326597781955121`, 
            2.4711473597687785`}, {-1.558071005691425, 
            2.386456530685673}, {-1.5444365502798476`, 
            2.3695507983338553`}, {-1.5310862155138916`, 
            2.3523341005835645`}, {-1.4900481411350284`, 
            2.288407485463316}, {-1.4525928166643285`, 
            2.2194092170175566`}, {-1.3855524388911258`, 
            2.0682780432969072`}, {-1.3345860015388398`, 
            1.8836746890333873`}, {-1.330759348251473, 
            1.8621240441524847`}}]}, 
          {Arrowheads[{{0.004797346899032398, 1.}}], 
           ArrowBox[{{-1.3271097824020075`, 
            1.8415707063701052`}, {-1.3148231435698203`, 
            1.7723757805777618`}, {-1.2982973377623277`, 
            1.6434199531881457`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.7061724072327384`}, \
{-4.9758746416807345`, -1.7045359257751302`}, {-4.867144465865558, \
-1.696811090562555}, {-4.838200314506682, -1.6946651411811675`}, \
{-4.809270243418251, -1.6924655189624884`}, {-4.626080252884316, \
-1.6757878162633344`}, {-4.443322153436413, -1.6564443238479536`}, \
{-4.290063695480955, -1.638942293478542}, {-4.1703923370688525`, \
-1.6232734247298453`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.149694158932362, -1.6205633607608128`}, \
{-4.136916824543357, -1.6188903925739715`}, {-3.9838815406236208`, \
-1.5962886211342415`}, {-3.8309578437217464`, -1.5711369791593524`}, \
{-3.6778259011774557`, -1.5425307450471462`}, {-3.524165880330471, \
-1.5095651971954653`}, {-3.369977781180793, -1.47224033560431}, \
{-3.3305295573096214`, -1.4616120567300204`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.310373456563626, -1.4561815293519988`}, \
{-3.2152616037284214`, -1.4305561602736796`}, {-3.023688485499153, \
-1.3711566280868652`}, {-2.8291987355435886`, -1.3005738804720546`}, \
{-2.6723230605780186`, -1.2348756679415647`}, {-2.5288329091746284`, \
-1.1665173597208576`}}]}, 
          {Arrowheads[{{0.013560829361512478`, 1.}}], 
           ArrowBox[{{-2.5100103640246205`, -1.1574937750531766`}, \
{-2.382966276192129, -1.0897420234765691`}, {-2.249049282417458, \
-1.0110024743078387`}, {-2.1413886292889046`, -0.9423655056819218}, \
{-2.0263688106775124`, -0.864049989837853}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.511320145121236}, \
{-4.788501326275013, -2.4936670314718916`}, {-4.5732262481234125`, \
-2.4723537909628233`}, {-4.544678655150184, -2.4692969807036387`}, \
{-4.516160841688934, -2.4661744373919667`}, {-4.342878628386084, \
-2.444015139347545}, {-4.171442955463259, -2.419053328553714}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.150818954551045, -2.4158271728851126`}, \
{-4.005723414958225, -2.3930809231709356`}, {-3.8419672884336467`, \
-2.363708621020117}, {-3.6795461330807306`, -2.330844917980672}, \
{-3.5184599488994763`, -2.2944898140526004`}, {-3.358938227550767, \
-2.253563509104664}, {-3.3337933761090897`, -2.246138187198671}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.3137732027350624`, -2.24022619236105}, \
{-3.201210460695486, -2.2069862030056235`}, {-3.045276648333633, \
-2.15475789575548}, {-2.891136790465208, -2.096878587354233}, \
{-2.7011357950897943`, -2.0135971344475148`}, {-2.5408128658347815`, \
-1.9294210128621552`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.5223306369608185`, -1.919717083723058}, \
{-2.5145939538026805`, -1.915655007354986}, {-2.3718299893619115`, \
-1.8267470380871336`}, {-2.230858874940734, -1.7236863294251443`}, \
{-2.124821523188715, -1.6338483617857535`}, {-2.0186180630005546`, \
-1.5309526654688281`}, {-1.936956919980272, -1.4419108707468513`}, \
{-1.8886255904479508`, -1.383551009863364}}]}, 
          {Arrowheads[{{0.006336716026535528, 1.}}], 
           ArrowBox[{{-1.8753109864033284`, -1.3674736859560375`}, \
{-1.8531850668872683`, -1.3407567386390185`}, {-1.7869134521456198`, \
-1.2539025488078024`}, {-1.7166768030318114`, -1.1558457045204038`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.2357567922222796`, 
            5.001099999999999}, {-2.2314441987581493`, 
            5.0005837710494045`}, {-2.0937419700528093`, 
            4.984061523756061}, {-1.957516070286892, 
            4.967909859542685}, {-1.8226967680395383`, 
            4.952353216842946}, {-1.6892840633107487`, 
            4.937391595656845}, {-1.5572779561005228`, 
            4.923024995984381}, {-1.4265094367145936`, 
            4.909452135556985}, {-1.4060446455052706`, 
            4.9074671282589195`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.3852673141065504`, 
            4.905451805745294}, {-1.2968094954586937`, 
            4.896871732106086}, {-1.168178132332823, 
            4.8852837856316835`}, {-1.040615347336982, 
            4.874688296133778}, {-0.9796709957877453, 
            4.8699692830788806`}, {-0.918904650922355, 
            4.865520605690506}, {-0.7429112676525609, 
            4.854191599907354}, {-0.5678992907460214, 
            4.845286762427304}, {-0.5525952296683866, 4.844718204054751}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.531734778414047, 
            4.843943221247526}, {-0.39345750860422873`, 
            4.838806107700651}, {-0.21917470962867433`, 
            4.834749650177688}, {-0.19942440773457365`, 
            4.834427170953682}, {-0.17967063498260782`, 
            4.834134573200671}, {-0.14234837305402143`, 
            4.833742870339118}, {-0.10500451176343242`, 4.833454294335811}, {
            0.10019881856580676`, 4.833231516248329}, {0.3030934207543901, 
            4.835681761862893}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3239635145390718, 4.836118956016949}, {
            0.5148297534311597, 4.8404666805907635`}, {0.725140513046014, 
            4.846989271404567}, {0.9378119648577357, 4.854741067265169}, {
            1.1530607470952834`, 4.863170492726998}, {1.1584962696558936`, 
            4.863380858976773}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1793554953754373`, 4.864188155246614}, {
            1.3603993557039877`, 4.8711949365665905`}, {1.569927497114914, 
            4.878565424467162}, {1.7816451713280625`, 4.88528195642871}, {
            1.9955523783434337`, 4.891344532451238}, {2.0138867471389097`, 
            4.891767835022993}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.034756027582969, 4.892249663450313}, {
            2.2112544853686895`, 4.896324646992143}, {2.428356859611492, 
            4.899793794508826}, {2.537433146939474, 4.900961755633084}, {
            2.6468595010718428`, 4.901751975001286}, {2.7566359220085985`, 
            4.902164452613433}, {2.866762409749741, 4.902199188469524}, {
            2.869665053452678, 4.902190388500357}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.8905397994331787`, 4.902127102358554}, {
            2.977143119876973, 4.901864546348368}, {3.0876822079719988`, 
            4.9011688900287735`}, {3.198379674034818, 4.90011221951074}, {
            3.30923551806543, 4.898694534794268}, {3.420249740063835, 
            4.896915835879358}, {3.5314223400300335`, 4.894776122766008}, {
            3.6427533179640252`, 4.892275395454221}, {3.725426630411068, 
            4.8901533126051095`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.746294598907543, 4.889617667464841}, {
            3.75424267386581, 4.889413653943994}, {3.899149374291319, 
            4.8852832621727575`}, {4.0441525810334085`, 4.880792080718726}, {
            4.189252294092078, 4.8759401095819}, {4.334448513467329, 
            4.87072734876228}, {4.47974123915916, 4.865153798259865}, {
            4.580791620479677, 4.861029233253797}}]}, 
          {Arrowheads[{{0.009577400262034887, 1.}}], 
           ArrowBox[{{4.601649095130843, 4.860177895446488}, {
            4.625130471167572, 4.859219458074656}, {4.770616209492564, 
            4.852924328206653}, {4.916198454134136, 4.846268408655855}, {
            5.001099999999999, 4.842255720203014}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.661046260404497}, {-4.983372621329209, 
            4.660115861404156}, {-4.858331838957641, 
            4.65281817808824}, {-4.734038958035915, 
            4.644892716745152}, {-4.610526521556953, 
            4.6363537217454445`}, {-4.487827072513678, 
            4.6272154374596735`}, {-4.365973153899011, 
            4.617492108258393}, {-4.244997308705871, 
            4.607197978512157}, {-4.168367366665305, 4.60027268097467}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.147577251925869, 
            4.598393810567423}, {-4.124932079927183, 
            4.596347292591519}, {-4.003033008493223, 
            4.583738775246403}, {-3.883839841916557, 
            4.571359516169131}, {-3.7656223777401836`, 
            4.558452189658565}, {-3.6483806159641046`, 
            4.545016795714707}, {-3.5321145565883194`, 
            4.531053334337556}, {-3.416824199612828, 
            4.516561805527112}, {-3.3180289636978775`, 
            4.503581277704486}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2973359546317185`, 
            4.500832504084145}, {-3.1891705928627294`, 
            4.485994545606346}, {-3.076807343088121, 
            4.469918814496024}, {-2.96553601978949, 
            4.453467344576402}, {-2.855472847042521, 
            4.436792464471472}, {-2.7466178248472133`, 
            4.419894174181234}, {-2.6389709532035672`, 
            4.402772473705688}, {-2.4718796700527244`, 
            4.375211728153156}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4512831289069323`, 
            4.371814447223372}, {-2.42730166157126, 
            4.3678588421986735`}, {-2.220464972145599, 
            4.332051569950426}, {-2.1058007006439277`, 
            4.3116640316661}, {-1.9927812245620296`, 
            4.291464692895328}, {-1.8814065438999046`, 
            4.271453553638108}, {-1.771676658657553, 
            4.2516306138944415`}, {-1.6635428960399463`, 
            4.232201368955336}, {-1.6291038528450414`, 
            4.2261172005930305`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6085473355221405`, 
            4.222485586566259}, {-1.5569565832520564`, 
            4.213371314111801}, {-1.3484263071654279`, 
            4.177508774711441}, {-1.14550860603023, 
            4.14483437593637}, {-0.947626255479025, 
            4.1161394980295976`}, {-0.8892031197952671, 
            4.108341740158599}, {-0.8311297819825043, 
            4.100977735999143}, {-0.7833849765020775, 4.095577195725712}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7626424078859577, 
            4.093230949342288}, {-0.6790927525696, 
            4.083780428519614}, {-0.5287172284747457, 
            4.069907013701624}, {-0.3793725837164683, 
            4.0594344340863096`}, {-0.23042819231329456`, 
            4.052439632214808}, {-0.21280133594917106`, 
            4.0518167831679754`}, {-0.1951704514154421, 
            4.0512418528457275`}, {-0.1573428479226796, 
            4.050329523732515}, {-0.11947170396928479`, 4.049631982744445}, {
            0.02944473694083602, 4.048409250622591}, {0.07060322637595794, 
            4.0489004908663375`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.0914765816145317, 4.049149621294979}, {
            0.17968424083598414`, 4.050202409009276}, {0.3317551021464129, 
            4.054648499385306}, {0.48616561530237584`, 4.061384563231488}, {
            0.6431903113960712, 4.070013252315294}, {0.8033233463934564, 
            4.07981933981817}, {0.9254410448479862, 4.088007774306377}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9462676106776615, 4.089426537215626}, {
            1.0649873295168413`, 4.097589262999855}, {1.1988330335405646`, 
            4.1066776905405264`}, {1.334845854437326, 4.115465393723514}, {
            1.4729176857214732`, 4.12377840136968}, {1.6128109421019743`, 
            4.131530345193629}, {1.7544498867945217`, 4.13852535329279}, {
            1.7797294771071783`, 4.139591193282788}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8005857897369952`, 4.140470538706105}, {
            1.8977587830148084`, 4.144567553764592}, {2.042589925553228, 
            4.1495865443436015`}, {2.188754484385717, 4.153583619699891}, {
            2.3361150355062836`, 4.15647045333415}, {2.4845341549089346`, 
            4.158158718747069}, {2.6338864039561325`, 4.158673694105335}, {
            2.6353127805512666`, 4.158668297755882}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.656187473074545, 4.15858932342612}, {
            2.784053192792312, 4.158105574527637}, {2.934907370584442, 
            4.156463408942662}, {3.08632178649949, 4.153756246279101}, {
            3.2199398828956367`, 4.150569460227207}, {3.3539566527014975`, 
            4.146728265536273}, {3.488315572573915, 4.142270120754859}, {
            3.490978258587063, 4.142170498125376}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5118385051798064`, 4.141390025847767}, {
            3.622960119169735, 4.137232484431529}, {3.757833769145802, 
            4.131652815114842}, {3.89287999915896, 4.125568571353362}, {
            4.028042285866056, 4.11901721169565}, {4.163264105923932, 
            4.112036194690267}, {4.298587084117919, 4.1046840214820755`}, {
            4.345888247196943, 4.102010517179018}}]}, 
          {Arrowheads[{{0.015221903575971238`, 1.}}], 
           ArrowBox[{{4.366729825275853, 4.100832532430875}, {
            4.434083044657501, 4.097025667860953}, {4.569740763335743, 
            4.089108304342983}, {4.705549015945717, 4.080979101444251}, {
            4.84149657828049, 4.072685229680842}, {4.977572226133134, 
            4.06427385956884}, {5.001099999999999, 4.062808613994975}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7111846090359961, -1.1191782937847574`}, {
            0.606791149437289, -1.223126054797882}, {
            0.49286656255109607`, -1.3087190105856503`}, {
            0.37115490305421006`, -1.3754177928544078`}, {
            0.2862126842535032, -1.409095277442609}, {
            0.1985932024046581, -1.433753060176694}, {
            0.10849203866458533`, -1.4489484480355812`}, {
            0.07750857130540263, -1.4524554364126323`}, {
            0.04631198975563024, -1.4547944158328505`}, {
            0.012893022248756797`, -1.4546418833748083`}, \
{-0.020853750406954946`, -1.4530683933279174`}, {-0.023786542268891833`, \
-1.452753714205122}}]}, 
          {Arrowheads[{{0.019826307100181687`, 1.}}], 
           ArrowBox[{{-0.04454225001665445, -1.4505266936}, \
{-0.11461165407943436`, -1.4430084721771126`}, {-0.21012657799525192`, \
-1.420783088474463}, {-0.3070266199194142, -1.3847185998199554`}, \
{-0.40709756555200904`, -1.3309462635471998`}, {-0.5067741652411623, \
-1.2565590187216131`}, {-0.6037801736231796, -1.1560677639581163`}, \
{-0.7004486685178007, -1.0064146577772084`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8353210981169266`, -0.03230933608645553}, {
            1.9271686960086571`, -0.03651136697080034}, {
            2.046456336282234, -0.040217915742508714`}, {
            2.174027024853159, -0.042323452818463544`}, {
            2.1829415270135266`, -0.042415317390463544`}, {
            2.1919084807459885`, -0.04250132511915592}, {
            2.2736573727761846`, -0.042793031629950386`}, {
            2.3602260663411347`, -0.0427617077440696}, {
            2.543875325060858, -0.04226482206768904}, {
            2.670139681732266, -0.041555715545970186`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6910141944568435`, -0.04143848330798221}, {
            2.7495747299514592`, -0.0411096046067455}, {
            2.861208886161981, -0.0404005824309562}, {
            2.9788736753218905`, -0.039652827244475816`}, {
            3.160654517828001, -0.038562012167853224`}, {
            3.3547629593666612`, -0.03752224054103535}, {
            3.525994298342946, -0.03670212575310837}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5468689008313334`, -0.03660214656533133}, {
            3.561198999937872, -0.03653351236402219}, {
            3.669039869860684, -0.03605828956919239}, {
            3.7799626395416333`, -0.035595827636813765`}, {
            3.8936712522329637`, -0.035149940521446675`}, {
            4.00986965118692, -0.03472444217765147}, {
            4.1285578364035, -0.034319332605428146`}, {
            4.249735807882706, -0.033934611804776714`}, {
            4.373403565624537, -0.03357027977569717}, {
            4.381856878419259, -0.03354723351269093}}]}, 
          {Arrowheads[{{0.014332322311353495`, 1.}}], 
           ArrowBox[{{4.402731642754218, -0.033490322651737445`}, {
            4.499561109628994, -0.03322633651818951}, {
            4.628208439896075, -0.03290278203225373}, {
            4.759345556425782, -0.032599616317889844`}, {
            4.897429168850308, -0.03236202673824356}, {
            5.001099999999999, -0.03213609926552408}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.827015673672383, -0.5330002780378601}, {
            1.9004644727064335`, -0.5770972720336719}, {
            1.9788841109156086`, -0.6108029474222284}, {
            2.0201165097292644`, -0.6239738101734533}, {
            2.062745976673123, -0.6348881958712052}, {
            2.2162186809609694`, -0.6575452779412427}, {
            2.3855229445918438`, -0.6625447269640944}, {
            2.3974052638395666`, -0.6623896891492677}, {
            2.4093578051328963`, -0.6621826499393525}, {
            2.5003974175561434`, -0.6579440226072069}, {
            2.5952097741211047`, -0.6518965060837559}, {
            2.637282170807349, -0.6488402610243369}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.658102152142299, -0.647327845043696}, {
            2.7923576254389686`, -0.6375751886874901}, {
            3.0046291265911345`, -0.6201156140416847}, {
            3.1164650585136213`, -0.6109159213927522}, {
            3.2321008414825565`, -0.6016883909919354}, {
            3.3437812587251545`, -0.5931584209115971}, {
            3.458692889589604, -0.5848765845454804}, {
            3.4905829284587475`, -0.5827080648103576}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.511409674598099, -0.5812918479720246}, {
            3.576835734075905, -0.5768428818935851}, {
            3.6982097921840573`, -0.5690573129559114}, {
            3.822677428896487, -0.5615743583707214}, {
            3.9501010091956195`, -0.5544484987762773}, {
            4.080480533081455, -0.5476797341725792}, {
            4.213816000553993, -0.541268064559627}, {
            4.345118953588284, -0.5354152475003466}}]}, 
          {Arrowheads[{{0.015222597189970427`, 1.}}], 
           ArrowBox[{{4.365975309789481, -0.5345373926669637}, {
            4.48861280890332, -0.5294666730073263}, {
            4.629888660441145, -0.5240646167433194}, {
            4.773749476887743, -0.5189949868207414}, {
            4.907216183465467, -0.5146163696273761}, {
            5.001099999999999, -0.5117157685257099}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8386802379483171`, 0.9976694358256302}, {
            1.9660910069248458`, 1.060569214300905}, {2.1104785294951864`, 
            1.0970932699508602`}, {2.2691208454141205`, 1.113116468467272}, {
            2.3530727650014267`, 1.114992415224425}, {2.4397315409719567`, 
            1.1137097426400977`}, {2.5501477485129818`, 1.108609888402506}, {
            2.6532379704122357`, 1.101391787435302}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.674047933202222, 1.0997571130447499`}, {
            2.7808612760753166`, 1.0904270851390248`}, {2.901248620513456, 
            1.0785367895040965`}, {3.0248782205768934`, 
            1.0655838685058565`}, {3.0416344013296333`, 1.063779932826728}, {
            3.058447816167468, 1.061965675543335}, {3.190135723064839, 
            1.0477501637928612`}, {3.3251650675772817`, 1.033501183513}, {
            3.5047380543982087`, 1.0152493014585426`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.5255058978894476`, 1.0131384481690915`}, {
            3.5364147934051124`, 1.0120296629457612`}, {3.644921530871323, 
            1.0016052579357866`}, {3.755349518039064, 0.9913884231082415}, {
            3.867655748409241, 0.9814533485400945}, {3.9817972154827603`, 
            0.9718742243083139}, {4.097773919259623, 0.9626510504128999}, {
            4.215585859739828, 0.9537838268538523}, {4.335161007687219, 
            0.9452786406051582}, {4.357580402611783, 0.9437742822935518}}]}, 
          {Arrowheads[{{0.01494062790200801, 1.}}], 
           ArrowBox[{{4.378408408021706, 0.9423767074188493}, {
            4.456427333865642, 0.9371415786408044}, {4.5793848382750975`, 
            0.9293726409607909}, {4.704033520915583, 0.9219718275651178}, {
            4.86228095985992, 0.9131535181863667}, {5.001099999999999, 
            0.9059025260422472}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.2070135624004275`}, \
{-4.904717693664135, -3.1998945497446987`}, {-4.7717950385533205`, \
-3.1888860652801583`}, {-4.639707783216443, -3.17666936177322}, \
{-4.489028046261548, -3.1610273524361436`}, {-4.339627131239963, \
-3.1435555358364784`}, {-4.191602536181458, -3.124149418223322}, \
{-4.17067981315514, -3.1212673576790344`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.150000241326389, -3.1184187906944483`}, \
{-4.044011780131623, -3.1038191058553886`}, {-3.8982360851788154`, \
-3.081084270594908}, {-3.7540317062486186`, -3.056206146819134}, \
{-3.611398643341033, -3.0291847345280662`}, {-3.470336896456059, \
-3.0000200337217047`}, {-3.3311487963169615`, -2.968417620487816}, \
{-3.3290283075121385`, -2.96788623664695}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.3087795740706656`, -2.962812005778893}, \
{-3.194136673647007, -2.9340830709141654`}, {-3.0593005284461943`, \
-2.897016385000754}, {-2.9266403607145244`, -2.8572175627475818`}, \
{-2.806350888517889, -2.8178469911938473`}, {-2.6884607711825366`, \
-2.7756212035120646`}, {-2.5844229278880886`, -2.734863115118689}, \
{-2.5155074144673906`, -2.7054323935882922`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4963098832945465`, -2.6972339899782076`}, \
{-2.482684405042769, -2.691415159989979}, {-2.3834446350662137`, \
-2.6450383884463893`}, {-2.2869030503780587`, -2.5954938508083734`}, \
{-2.1549845602160307`, -2.518753785174883}, {-2.0296989532526513`, \
-2.433804466974382}, {-2.010302430678257, -2.419642388883849}, \
{-1.99109675136438, -2.405233115863307}, {-1.9171507676379556`, \
-2.341047654445401}, {-1.8466889776749906`, -2.2714767544110055`}, \
{-1.811769544949315, -2.2313749834432093`}}]}, 
          {Arrowheads[{{0.011334500701906421`, 1.}}], 
           ArrowBox[{{-1.7980611179643586`, -2.215632110310128}, \
{-1.7136176239051553`, -2.1186564897413342`}, {-1.6531235253649703`, \
-2.030285553779671}, {-1.596860357358157, -1.9316714751652329`}, \
{-1.5445114133107167`, -1.8192690419426818`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.762607717772731, -3.5250191998010014`}, \
{-3.550543502379209, -3.4894741327201704`}, {-3.3420986878795595`, \
-3.4501871159603317`}, {-3.1380529450529155`, -3.4069795294407603`}, \
{-2.9441769235260864`, -3.360860014515359}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.9239806396909898`, -3.35558730431819}, \
{-2.7332031505643, -3.304328111719409}, {-2.5338402318764985`, \
-3.2440937312159805`}, {-2.342441520740645, -3.1786909111985464`}, \
{-2.1597538683376496`, -3.1079648181271624`}, {-2.1313773847168087`, \
-3.0954313607585373`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.1122822055875914`, -3.086997313159118}, \
{-1.986898943065588, -3.031617450151549}, {-1.8249984133225325`, \
-2.949350805421427}, {-1.7342103533032331`, -2.897499436927017}, \
{-1.648069062453781, -2.843238788964822}, {-1.495483036910446, \
-2.730070843001193}, {-1.4088080419417583`, -2.647092299778935}}]}, 
          {Arrowheads[{{0.01589321396810475, 1.}}], 
           ArrowBox[{{-1.393729267824889, -2.632656594184174}, \
{-1.3644623156471556`, -2.604637797561906}, {-1.2486592943923227`, \
-2.4458768221398444`}, {-1.2393857015737602`, -2.4298994989545477`}, \
{-1.2304322704800963`, -2.4136579523392125`}, {-1.2072612009255927`, \
-2.3604743168097926`}, {-1.1873394017982064`, -2.303810226613405}, \
{-1.1546234421709485`, -2.1816911298276223`}, {-1.1368731874739997`, \
-2.037791042494734}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8674458126562945`, 0.44574763210307244`}, {
            1.9930265903851103`, 0.49690807705727486`}, {2.1312230654535655`, 
            0.5265819838257141}, {2.1409673365703465`, 0.5279125025588799}, {
            2.150776528869169, 0.5291654713502747}, {2.207057764461238, 
            0.5334283938449077}, {2.2653827062748855`, 0.5357483992409147}, {
            2.386192689284649, 0.5373015975130502}, {2.515444782296259, 
            0.533551920806054}, {2.6533741926927914`, 0.5261087156497429}, {
            2.6885394623006817`, 0.5236436197534788}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.709363202446384, 0.5221838693534272}, {
            2.8346583945331743`, 0.5134006389878204}, {3.0295565222376215`, 
            0.49898895352300643`}, {3.238192729110889, 0.484491090886172}, {
            3.3476063968563423`, 0.477330816631087}, {3.4604147661676254`, 
            0.47040601323383974`}, {3.542433037526713, 0.4657023944926078}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.563273636852599, 0.46450721893058494`}, {
            3.576553478894775, 0.4637456408958967}, {3.6959224042192975`, 
            0.45731962301287}, {3.818466127158362, 0.45117167898768984`}, {
            3.9441292327291375`, 0.4453455282232865}, {4.072413494333487, 
            0.43985127362366133`}, {4.204290463787704, 0.4346207721409304}, {
            4.338804917696759, 0.4296867568972705}, {4.3974382863353, 
            0.42770418230925017`}}]}, 
          {Arrowheads[{{0.013965279188173982`, 1.}}], 
           ArrowBox[{{4.418301205115703, 0.42699874283738654`}, {
            4.4759568560606535`, 0.4250492278926816}, {4.592827739592062, 
            0.42136621664957435`}, {4.711299409716744, 0.4178433048582258}, {
            4.831371866434701, 0.4144804925186359}, {4.95304510974593, 
            0.41127777963080475`}, {5.001099999999999, 
            0.4100917029294161}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.98724746451766, -5.001099999999999}, \
{-3.9362652630058466`, -4.996722683868583}, {-3.72349819077791, \
-4.976820184823883}, {-3.513398590822552, -4.955512330422714}, \
{-3.305966463139771, -4.9327991206650745`}, {-3.2787464416009278`, \
-4.929706515450774}, {-3.2515778700130293`, -4.9265954160817165`}, \
{-3.1567159813682344`, -4.915253863101951}}]}, 
          {Arrowheads[{{0.0004239088951763178, 1.}}], 
           ArrowBox[{{-3.135988753951805, -4.9127757451641205`}, \
{-3.1184158418034715`, -4.910674752689837}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.006768904552305051, 1.}}], 
           ArrowBox[{{-0.9088501675023511, -2.848116528005087}, \
{-0.7781138792550445, -2.7156810852765063`}, {-0.7708829118116177, \
-2.70663799974524}, {-0.7638676086145024, -2.697560532568054}, \
{-0.7435540071254091, -2.6665128909304445`}, {-0.7257721235462259, \
-2.6348071740775842`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.007569139196395214, 1.}}], 
           ArrowBox[{{-0.2317771630909277, 
            2.9369069536818158`}, {-0.15407194965983306`, 
            2.920569894638385}, {-0.07762102223140596, 
            2.9103105883061864`}, {-0.0692409058435203, 
            2.909518005473441}, {-0.06085665052952562, 
            2.9087989779468177`}, {-0.027073821164218456`, 
            2.9073938695687436`}, {0.0070846186389719595`, 
            2.907161468572766}, {0.0817188590761041, 2.9093079274617692`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.011538955305676887`, 1.}}], 
           ArrowBox[{{-2.86349924414355, 
            5.001099999999999}, {-2.7434618004868963`, 
            4.9869607428675895`}, {-2.546148695094986, 
            4.9628129415222}, {-2.5204713366450955`, 
            4.959610152068111}, {-2.494847131673526, 
            4.9564071544609165`}, {-2.3853178917849673`, 
            4.942606758644019}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.765194232595994}, {-4.905596031787203, 
            1.7584745780875601`}, {-4.7970390850245455`, 
            1.7501254705789073`}, {-4.768150062480306, 
            1.7478087091261751`}, {-4.739275750202002, 
            1.745435142366187}, {-4.558317557813883, 
            1.7277025002513342`}, {-4.377818561223395, 
            1.707210063447162}, {-4.226811694755401, 
            1.6887476118739315`}, {-4.170550645671728, 
            1.6808851812155097`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.149876706647243, 
            1.67799601695953}, {-4.075956737970846, 
            1.6676657682802614`}, {-3.925253690869728, 
            1.6439645326661516`}, {-3.774702553452049, 
            1.617643905031602}, {-3.6240144006144437`, 
            1.5877856246343052`}, {-3.472900307253548, 
            1.553471430731953}, {-3.331081637922198, 
            1.5171884439764263`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.3109335137678313`, 
            1.5117354796194513`}, {-3.169394298961886, 
            1.4714753024120835`}, {-2.9812203641993555`, 
            1.4099524711685816`}, {-2.790427142383957, 
            1.3370121049520018`}, {-2.6368360656426932`, 
            1.2692984475612936`}, {-2.5315741193234262`, 
            1.2165293657164196`}}]}, 
          {Arrowheads[{{0.017060528034169808`, 1.}}], 
           ArrowBox[{{-2.512912897148061, 
            1.2071742702167558`}, {-2.4791101854205317`, 
            1.1902285635858099`}, {-2.3541464606059894`, 
            1.120119563839528}, {-2.2235985799142135`, 
            1.039382523183234}, {-2.1187496121633447`, 
            0.9690875149581866}, {-2.0068223769128477`, 
            0.8889632735673033}, {-1.915834137757873, 0.8206268776179207}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7167285564551946`, -4.768140428725832}, \
{-2.512755736868169, -4.739927698819577}, {-2.312406395221109, \
-4.711602511103157}, {-2.115964795164052, -4.683466931470312}, \
{-1.9234759903337024`, -4.655872656688628}, {-1.889972502687777, \
-4.6511525366535516`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8693017933358722`, -4.648240355379103}, \
{-1.7345664168434327`, -4.629258237554931}, {-1.548862510806613, \
-4.604062224866043}, {-1.3497014245406906`, -4.57887546771466}, \
{-1.1541722591646753`, -4.556127102110528}, {-1.0408390250029855`, \
-4.544511365954266}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.0200729675636193`, -4.5423830137016745`}, \
{-0.9614760407503441, -4.536377304551437}, {-0.7711688948931288, \
-4.519937284202826}, {-0.5825697785201926, -4.506983964949679}, \
{-0.39499764855869873`, -4.497694270676979}, {-0.3535008535045343, \
-4.496129730831045}, {-0.31201032883263025`, -4.494744826347707}, \
{-0.18685524188659083`, -4.4918527012018545`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.16598597127265205`, -4.49137044719372}, \
{-0.14744730825500332`, -4.4909420496368}, {
            0.01762888823578504, -4.489792962022903}, {
            0.18365303106899689`, -4.491054492450407}, {
            0.3510598906738939, -4.4944835698637045`}, {
            0.37110295071234617`, -4.49502165612505}, {
            0.3911710846445634, -4.495585571410837}, {
            0.4352912019036665, -4.49699158863873}, {
            0.4795437681083219, -4.49850704166306}, {
            0.5992463550257169, -4.502831035043572}, {
            0.6687621862892301, -4.505599566725434}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.6896204930382351, -4.50643026790551}, {
            0.720051999982298, -4.50764223055589}, {
            0.8419607029780651, -4.5129406282000115`}, {
            0.9649724640130182, -4.518726227975938}, {
            1.0891205426089179`, -4.524724356250188}, {
            1.214438198287525, -4.530660339389284}, {
            1.3409254310488388`, -4.536534177393224}, {
            1.4685822408928602`, -4.542345870262008}, {
            1.5237340740952607`, -4.544719371167926}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5445896119173994`, -4.545616905031082}, {
            1.597325470727513, -4.547886432649516}, {
            1.7270719634607223`, -4.552946879209628}, {
            1.8578217190924877`, -4.557527209942342}, {
            1.9895747376228095`, -4.56162742484766}, {
            2.108328126506271, -4.564803057254282}, {
            2.227579137603283, -4.567412295631693}, {
            2.3473277709138443`, -4.569455139979894}, {
            2.3792010192580686`, -4.569846497427824}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.400074287772709, -4.570102791013205}, {
            2.4675740264379553`, -4.570931590298883}, {
            2.5883179041756166`, -4.571841646588663}, {
            2.709559404126828, -4.572185308849231}, {
            2.8312985262915893`, -4.571962577080589}, {
            2.9535352706699003`, -4.571173451282736}, {
            3.0761176479786205`, -4.569868505464601}, {
            3.198893668934607, -4.568098313635113}, {
            3.235030531821141, -4.5674413897424895`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.2559019253565444`, -4.567061973379514}, {
            3.3218633335378596`, -4.565862875794272}, {
            3.4450266417883793`, -4.5631621919420775`}, {
            3.568383593686165, -4.55999626207853}, {
            3.691934189231218, -4.556365086203629}, {
            3.815678428423538, -4.552268664317374}, {
            3.939616311263124, -4.547706996419767}, {
            4.063692569351431, -4.542795984018197}, {
            4.090489278446609, -4.541685681345294}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.1113462244287735`, -4.540821488552428}, {
            4.187851934289918, -4.537651528620056}, {
            4.3120944060785815`, -4.532273630225343}, {
            4.436419984717422, -4.526662288834059}, {
            4.560828670206441, -4.520817504446203}, {
            4.685320462545637, -4.514739277061776}, {
            4.809895361735011, -4.508427606680778}, {
            4.934553367774562, -4.501882493303208}, {
            4.945398797396314, -4.501301634662845}}]}, 
          {Arrowheads[{{0.0008360827762450592, 1.}}], 
           ArrowBox[{{4.966243764337745, -4.5001852216134495`}, {
            5.001099999999999, -4.4983183941699005`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.006126189557149998, 1.}}], 
           ArrowBox[{{-0.4569826242753165, -3.062068588791683}, \
{-0.30975454168906214`, -3.01823197806502}, {-0.2997954202671806, \
-3.0156579467853066`}, {-0.289879763770645, -3.0131585666793823`}, \
{-0.24965998329041228`, -3.0044273404023705`}, {-0.20986520714932833`, \
-2.9969993919418}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.9022174490989145, -5.001099999999999}, \
{-0.7943286640822299, -4.9946934237358045`}, {-0.6854408035822644, \
-4.989025802111993}, {-0.4683531704415312, -4.980224728686243}, \
{-0.25172923001900904`, -4.974841248395932}, {-0.21451597111681675`, \
-4.974257736542747}, {-0.17729260663435573`, -4.97377033313221}, \
{-0.06781633648706847, -4.973086671531564}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.04694190160091483, -4.97295631406188}, \
{-0.000032445683634751976`, -4.972663372096697}, {
            0.1778688407870595, -4.973521134022977}, {
            0.35669590218196895`, -4.976102084174147}, {
            0.5367333879053355, -4.980164687813307}, {
            0.5585264091870855, -4.980744181265241}, {
            0.5803404160737342, -4.981340725797122}, {
            0.6304297660648739, -4.982825665733537}, {
            0.6806369835005397, -4.984385790938768}, {
            0.7878678151652688, -4.987802623372747}}]}, 
          {Arrowheads[{{0.008902761909634911, 1.}}], 
           ArrowBox[{{0.80873206769522, -4.988467447599588}, {
            0.8440849420164225, -4.989593941218445}, {
            1.008887607680453, -4.99510261442985}, {
            1.1750449804926308`, -5.000911810572984}, {
            1.1802046289084687`, -5.001099999999999}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8957600807828997, -3.616496134565729}, \
{-0.7663583556085289, -3.5884876049043175`}, {-0.6404318906300175, \
-3.5639741518949033`}, {-0.5173731405266314, -3.543314407761993}, \
{-0.4718799334354757, -3.5365775800410053`}, {-0.426646269695022, \
-3.5304287975313065`}, {-0.2929257919307784, -3.5156786342538098`}, \
{-0.15993278725123602`, -3.506308991479442}, {-0.06991765723827396, \
-3.50461081168265}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.04904652908347591, -3.5042170675624824`}, {
            0.055472474521152025`, -3.5022452650413216`}, {
            0.07022987538554705, -3.5024211399993166`}, {
            0.08501658279752779, -3.502654677580197}, {
            0.11951020663458709`, -3.5036290047592966`}, {
            0.1542038478655987, -3.5048964476172757`}, {
            0.26873915238297197`, -3.510386774816093}, {
            0.3860028405714517, -3.5185889259635856`}, {
            0.5064255044915179, -3.529067346311531}, {
            0.6304377362036507, -3.5413864811117057`}, {
            0.758268199125373, -3.5550431073244213`}, {
            0.7835258863884175, -3.557818462323997}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.8042758370616726, -3.5600985000306253`}, {
            0.8901455566742076, -3.5695340019099886`}, {
            1.0147329355268693`, -3.583001590729917}, {
            1.1426467508358207`, -3.5960324989660464`}, {
            1.273887002601062, -3.6086267266183762`}, {
            1.4084536908225935`, -3.620784273686907}, {
            1.5459615424999937`, -3.6320101658994735`}, {
            1.6355374371225062`, -3.638277153658499}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.6563613766880847`, -3.63973405648824}, {
            1.686025284632842, -3.641809428983911}, {
            1.8286449172211374`, -3.6501820629402197`}, {
            1.9738204402648805`, -3.657128067768399}, {
            2.1221725112998397`, -3.6627967731672917`}, {
            2.2701840709566605`, -3.6663419775101254`}, {
            2.4202549950403136`, -3.668341088965757}, {
            2.4907066519587637`, -3.6685235180503435`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.5115814238879306`, -3.6685775716482367`}, {
            2.5721370205364926`, -3.668734375654649}, {
            2.763672938259852, -3.6671144887576403`}, {
            2.956938209873048, -3.6633812007222475`}, {
            3.1513774161967656`, -3.657616641937723}, {
            3.3462942084618437`, -3.649908515956208}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.36714507026114, -3.6489083271644627`}, {
            3.5420227901904466`, -3.640509646202046}, {
            3.7383185496124876`, -3.6298133879476344`}, {
            3.9351671405087325`, -3.6180569377254153`}, {
            4.132413287070102, -3.6054830652307195`}, {
            4.200742477779184, -3.600917205636541}}]}, 
          {Arrowheads[{{0.01871675907248353, 1.}}], 
           ArrowBox[{{4.2215708709092645`, -3.5995254209890515`}, {
            4.330058332126651, -3.5922761251828645`}, {
            4.528193114873653, -3.578587092314874}, {
            4.726796604049859, -3.564608666342639}, {
            4.9258477683940205`, -3.5505335469820496`}, {
            5.001099999999999, -3.5452243112771225`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.00525284142392086, 1.}}], 
           ArrowBox[{{-0.2967669856017359, 
            2.4725967524227537`}, {-0.32193878221832567`, 
            2.416265414700927}, {-0.36615484690828076`, 
            2.3474020313592927`}, {-0.3716884617011167, 
            2.3396505560039937`}, {-0.3774635009261287, 
            2.331692669926547}, {-0.39378839824999473`, 
            2.3102141121838065`}, {-0.4118651474876426, 
            2.2869857248429306`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.622774249001661, -4.512212829833505}, \
{-3.4088201084400107`, -4.485006671206564}, {-3.1983379960063574`, \
-4.456101575815405}, {-2.991611601351938, -4.425586240282894}, \
{-2.796129181728622, -4.394794527026863}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7755265835902705`, -4.391435202941346}, \
{-2.590177291060556, -4.360653620093132}, {-2.395669992797624, \
-4.326962757628237}, {-2.2056474658848892`, -4.292869302349299}, \
{-2.020252243378501, -4.258722364146709}, {-1.9532760565881158`, \
-4.246227290695227}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.932755269354598, -4.242398933841058}, \
{-1.8393312877506713`, -4.224969761351374}, {-1.6627315614736111`, \
-4.1920593122942}, {-1.49071541149154, -4.1604849289300745`}, \
{-1.3232128771710703`, -4.130703648314698}, {-1.1595724596180057`, \
-4.1031079764302065`}, {-1.1108143265696928`, -4.095504592373475}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.0901887598869773`, -4.092288224250416}, \
{-0.9991426599381495, -4.078090419258732}, {-0.8504085131816301, \
-4.0573744750070375`}, {-0.7041329012263812, -4.039556357530148}, \
{-0.5594950407977599, -4.024900521676185}, {-0.41603894118763174`, \
-4.013553886805215}, {-0.2731519844429173, -4.005528158060148}, \
{-0.26023325954754367`, -4.005103972022226}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.23936966150017414`, -4.004418916255177}, \
{-0.13022155261053692`, -4.000835040583892}, {-0.09667229914907344, \
-4.000213057417011}, {-0.06307883417575774, -3.999765727104509}, {
            0.08472245390732092, -3.9996904337866135`}, {
            0.23411713295790887`, -4.002616257544908}, {
            0.3856064844681615, -4.0081423097922215`}, {
            0.5396917899302339, -4.015867701941384}, {
            0.5589335649811179, -4.016960547047213}, {
            0.5782211908273444, -4.018079142672151}, {
            0.5951377664122369, -4.019124980778988}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.6159728292712692, -4.020413072602713}, {
            0.6284467435805365, -4.021184250839147}, {
            0.6789980485811546, -4.024425766389934}, {
            0.8018900071346433, -4.03237356075372}, {
            0.9267701526194317, -4.040583961658561}, {
            1.0536384850355194`, -4.0490569691044564`}, {
            1.1824950043829068`, -4.057792583091406}, {
            1.313254501550068, -4.066380366380664}, {
            1.445831767425478, -4.074409881733481}, {
            1.449204289167096, -4.074597365924595}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.4700469494680024`, -4.0757560446838665`}, {
            1.5802268020091366`, -4.081881129149858}, {
            1.7164396053010438`, -4.088794108629795}, {
            1.8547726353635903`, -4.095432221049415}, {
            1.993511963176562, -4.1001895281106835`}, {
            2.13382709324787, -4.1041618465346135`}, {
            2.2755970423525573`, -4.107235815970754}, {
            2.304362214140327, -4.1076318728055865`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.325235077660304, -4.107919263415335}, {
            2.4698382226618243`, -4.1099102497490385`}, {
            2.6658761417763377`, -4.110809907627671}, {
            2.8632907283814637`, -4.109774965386364}, {
            3.061661911162569, -4.106645598804829}, {
            3.1601541933955746`, -4.104158534722542}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.181022383264317, -4.103631584546262}, {
            3.260830536660397, -4.101616320128736}, {
            3.4607865473330497`, -4.0950841195843015`}, {
            3.6613335157419318`, -4.087192889922061}, {
            3.8622750144484455`, -4.078086523892548}, {
            4.015328426843647, -4.070376103112805}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.036176830205694, -4.069325816418823}, {
            4.0635675021083575`, -4.06794594776706}, {
            4.265254800859926, -4.056973249828761}, {
            4.4672715284882925`, -4.045344065845984}, {
            4.6695523027786, -4.033234031587059}, {
            4.869761974370846, -4.020910477362508}}]}, 
          {Arrowheads[{{0.0026520299355290477`, 1.}}], 
           ArrowBox[{{4.890596002003508, -4.019605772629137}, {
            5.001099999999999, -4.0126705474654045`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.001971567046440888, 1.}}], 
           ArrowBox[{{1.4444094634352234`, 0.2908699599457619}, {
            1.4540395699672861`, 0.30512619738464025`}, {1.4633048071537198`, 
            0.31940161311361387`}, {1.4870862827805895`, 
            0.3611994352889263}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(tot\\)]\\)}\"", 
          TraditionalForm]}}], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAVqf8e5ak6D9UlMAXWcjjv9DDnjE7
oug/cK+mwvEM5L9la8mbT6DoP6PEvGpej+S/k7gcQTyf6D+0q9mj29Xkv5yy
3fhlnOg/XwYMEOwi5b9j4O3xM5ToP6XN7anSheW/uDb8hrKM6D/oJ30NMcbl
v7PY8sMcgug/zdKRd6sT5r+fJOV+8XToPx2oftbkaea/8X8TgZdQ6D/9SXSO
qzrnvwhr989iKug/Iau6Rv715796wIdUyAHoP95QdBpzoui/57mUUF9K5z9V
BCgOffnqv+a4qVp8e+Y//XObmITc7L95XBAVrCXkP29LMmCuUPC/FABlEMGx
4T8CBaqa4ZXxv/08VZgsxt8/oysYAVlC8r+cp/ZG0RncP5djWl+myfK/oY0B
JS5e2D9uUAgT7TLzv/ypaV7Tu9I/dCqtc8+b879m+LUi
            "]]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.2726698313220535, -1.2313698691690043`}, {
            0.2640446245140613, -1.2338786798935437`}, {
            0.14380871601905681`, -1.2509965852502904`}, {
            0.020640291098867142`, -1.2564195513133374`}, \
{-0.08278973981572954, -1.2552700916254165`}, {-0.18566240196805958`, \
-1.2517064641834734`}, {-0.28602210770227904`, -1.2477900682429233`}, \
{-0.42430379937347995`, -1.2448908782720247`}, {-0.5487242065085126, \
-1.2469204316638232`}, {-0.5603892075853228, -1.2480442635575522`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5811678404666734, -1.2500461228104047`}, \
{-0.7560333553724675, -1.2668930516251096`}, {-0.9167493609157216, \
-1.304759711619387}, {-1.0768220719296626`, -1.3658095256129588`}, \
{-1.2453305587756438`, -1.4539666064593533`}, {-1.3569161326267947`, \
-1.5257978811068755`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.3744686069464187`, -1.5370969815199662`}, \
{-1.4271512357648124`, -1.5710105085934167`}, {-1.5332565719200044`, \
-1.647181310882384}, {-1.6279661665684784`, -1.7187190524186673`}, \
{-1.732144337871041, -1.800780728799217}, {-1.8262239556638733`, \
-1.8770812547409537`}, {-1.9913367958690937`, -2.01521846898676}, \
{-2.0323875838346503`, -2.0503142799151575`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.0482542315067107`, -2.063879253801489}, \
{-2.064965522242684, -2.0781663437480034`}, {-2.1340451012210995`, \
-2.137785231633444}, {-2.16239330646329, -2.1623939143506177`}, \
{-2.234470527404774, -2.2255099929050832`}, {-2.3026090817293237`, \
-2.2855274248654744`}, {-2.432237591290629, -2.4001978063599125`}, \
{-2.5499852684022386`, -2.505178483527264}, {-2.658251812382497, \
-2.602259757597257}, {-2.6741345736682556`, -2.6165619236099706`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.6896469907563514`, -2.6305306007474494`}, \
{-2.774755517037891, -2.7071694326278624`}, {-2.882636995466647, \
-2.804684494237028}, {-2.9831682886678195`, -2.895847904260428}, \
{-3.0776214376404627`, -2.981702624533736}, {-3.1667548828435086`, \
-3.0628878865872804`}, {-3.251327064735889, -3.1400429219513883`}, \
{-3.307907600857854, -3.191747607466693}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.3233173738021087`, -3.205829436988906}, \
{-3.3841728845673082`, -3.261440699476862}, {-3.507670669156043, \
-3.37449695096649}, {-3.623147208265747, -3.48037091316804}, \
{-3.731929291660075, -3.5802218228292793`}, {-3.8348240890646847`, \
-3.6747634904089943`}, {-3.9326387702052354`, -3.764709726365972}, \
{-3.9386578690056964`, -3.7702493541613107`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.954017696921682, -3.784385644738314}, \
{-4.09097109660411, -3.9104295733557928`}, {-4.238215103272317, \
-4.046070597554306}, {-4.3759403150902, -4.173044423131614}, \
{-4.505716256938104, -4.292762674257822}, {-4.568016436600242, \
-4.350265338331399}}]}, 
          {Arrowheads[{{0.013621147681248388`, 1.}}], 
           ArrowBox[{{-4.5833559797277745`, -4.364423637718145}, \
{-4.628498771400125, -4.406090143319832}, {-4.745243701060358, \
-4.513891622704549}, {-4.840847274480075, -4.602201850760643}, \
{-4.93318869313481, -4.6875189366522125`}, {-5.001099999999999, \
-4.75028019399398}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7704865558203087, 0.6194277214413905}, {
            0.7702815855786775, 0.6242278466318192}, {0.7701274702069525, 
            0.6329700484404829}, {0.7700138772185873, 0.6458140862418338}, {
            0.7697080846765545, 0.6601493952497806}, {0.7669420268101611, 
            0.6853045025312762}, {0.7617698964673886, 0.7176166165946167}, {
            0.7558301437884338, 0.7477351756695959}, {0.749404288752241, 
            0.7747558049131725}, {0.7345937570146108, 0.8247708655595725}, {
            0.7183338944315184, 0.8679345425285133}, {0.7010766706291095, 
            0.9056534402007343}, {0.6278288642115464, 1.0224558625587494`}, {
            0.5509886119153931, 1.1012804427841085`}, {0.49525677235169513`, 
            1.1425146441068252`}, {0.43863612832083687`, 
            1.1749708445812836`}, {0.38111038167054545`, 
            1.2003096013902093`}, {0.2922293103707982, 
            1.2262657571340323`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.27219143337144064`, 1.2321174671614334`}, {
            0.26535570619102455`, 1.2341137212200597`}, {0.14612335681710584`,
             1.2512966524754476`}, {0.023981365639886926`, 
            1.2568803831675397`}, {-0.08023108918157162, 
            1.255832213781232}, {-0.18391974033340994`, 
            1.252277849655603}, {-0.2850915497249836, 
            1.2483379997734776`}, {-0.42332002103046895`, 
            1.2454420578781074`}, {-0.5477372522928671, 
            1.247466661360114}, {-0.5609068664466698, 1.2487341134207708`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.5816857006735844, 
            1.2507338816714864`}, {-0.755112837968916, 
            1.2674246199096542`}, {-0.915909226972474, 
            1.30528999951395}, {-1.0759915568473717`, 
            1.3663341138495242`}, {-1.2444689848188848`, 
            1.4544834541486549`}, {-1.3572160833012685`, 
            1.5270837737077578`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.3747670460071169`, 
            1.5383852219770768`}, {-1.4262334871848583`, 
            1.5715255876837617`}, {-1.5322996083745128`, 
            1.6476998138155785`}, {-1.6269739008662232`, 
            1.7192451327487717`}, {-1.7311096592526587`, 
            1.8013170372134737`}, {-1.8251508180593983`, 
            1.8776299550044089`}, {-1.990195701221874, 
            2.015795083968234}, {-2.0324342710764434`, 
            2.051929639037046}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.048296602342611, 
            2.065499660101456}, {-2.0637939000524446`, 
            2.078757399637663}, {-2.1328447108773507`, 
            2.138390655153614}, {-2.1611700523834116`, 
            2.1629958524523993`}, {-2.233216725941985, 
            2.2261279189780354`}, {-2.3013262731765622`, 
            2.286160946324222}, {-2.4308994389035856`, 
            2.4008616952588437`}, {-2.5485965562740662`, 
            2.5058711025078138`}, {-2.6568163838042027`, 
            2.602979535373202}, {-2.673959932355006, 
            2.6184280970172478`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.6894673657576544`, 
            2.6324023066245417`}, {-2.7732695970143677`, 
            2.7079189904453624`}, {-2.881104142283105, 
            2.8054620964829433`}, {-2.9815915471052667`, 
            2.8966519984903862`}, {-3.0760033389757035`, 
            2.9825318414721322`}, {-3.1650976511496802`, 
            3.063740995696283}, {-3.249632616882461, 
            3.1409188314309398`}, {-3.3075158039858503`, 
            3.1938529583366453`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.322920401093671, 
            3.2079404496971358`}, {-3.382420183891487, 
            3.262352952033191}, {-3.505863638925101, 
            3.375443163755215}, {-3.62128922945636, 
            3.4813490127566094`}, {-3.7300232029583222`, 
            3.581230045196971}, {-3.8328723959735447`, 
            3.67580027138852}, {-3.9306436450445856`, 
            3.7657737016434747`}, {-3.938047525874829, 
            3.7725928979194925`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.953402086914633, 
            3.7867349090975786`}, {-4.088906036550513, 
            3.911538110273945}, {-4.236084823476719, 
            4.047220613052781}, {-4.373748880356459, 
            4.174233260981301}, {-4.5034670817229925`, 
            4.293988105060819}, {-4.567187567720748, 
            4.3528459078911155`}}]}, 
          {Arrowheads[{{0.013653112436245583`, 1.}}], 
           ArrowBox[{{-4.58252180785052, 
            4.367009950553036}, {-4.626194869310797, 
            4.407350202203266}, {-4.7428876848543515`, 
            4.515184609320567}, {-4.838448870524113, 
            4.603522116726724}, {-4.9307493026905584`, 
            4.688865538561718}, {-5.001099999999999, 4.753930162739533}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.31324298851927235`, -3.233182774384524}, \
{-0.35429536540416706`, -3.2487797876285116`}, {-0.39480793980370776`, \
-3.267640624173827}, {-0.5194190863783343, -3.3433393920593106`}, \
{-0.6378409227687073, -3.4494247784583636`}, {-0.7492093271452931, \
-3.5794968873142157`}, {-0.8576783501455761, -3.7320847834513877`}, \
{-0.9016372991515981, -3.8026646351291777`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.9126732257301706, -3.8203837589630054`}, \
{-0.9585505232570823, -3.8940436832342544`}, {-1.0524177697257733`, \
-4.059450243958205}, {-1.1368562483514368`, -4.217727561763688}, \
{-1.2161457971865808`, -4.3736045797080765`}, {-1.2907994972991939`, \
-4.5261495316558165`}, {-1.3053699241679193`, -4.556781754100477}}]}, 
          {Arrowheads[{{0.011229179835719796`, 1.}}], 
           ArrowBox[{{-1.3143365190894363`, -4.575632727560742}, \
{-1.3613304297572648`, -4.674430651471351}, {-1.4281501981198412`, \
-4.81828637067763}, {-1.491670405945971, -4.957555120797609}, \
{-1.5111958961992982`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9906781692748894, -0.8979459549657215}, {
            1.016833856512234, -1.0045905234917898`}, {
            1.0444489234415943`, -1.1169959345058387`}, {
            1.075972336170522, -1.2406546567128578`}, {
            1.1110146403137593`, -1.3697932438887535`}, {
            1.153139894729896, -1.5135989154413052`}, {
            1.2015620631592392`, -1.6659823760728567`}, {
            1.2139984290240369`, -1.7021837657465901`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.220780583315278, -1.7219261416941798`}, {
            1.2605175688419776`, -1.837597722375436}, {
            1.328569056130803, -2.0221136895931124`}, {
            1.3712552086867928`, -2.132473054282037}, {
            1.4101614236908466`, -2.230328691669828}, {
            1.4601741728613895`, -2.352919723930622}, {
            1.5056280382512341`, -2.4618787849164105`}, {
            1.5220551285482007`, -2.5004551337232233`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.5302336798582383`, -2.5196611307906824`}, {
            1.5628064861635145`, -2.5961530666681587`}, {
            1.6147179568983427`, -2.715966915320562}, {
            1.6623052328179984`, -2.824185333772383}, {
            1.7065110962847603`, -2.923673324922384}, {
            1.7477395809979848`, -3.01557817949018}, {
            1.7865776722691045`, -3.1015491264324044`}, {
            1.7920490372016853`, -3.1136157972353558`}, {
            1.8332845193620482`, -3.203976764033772}, {
            1.8693688219476878`, -3.2826492974770596`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8780898655957978`, -3.3016151143478965`}, {
            1.9468977123667501`, -3.4510527633153862`}, {
            2.0148643983946455`, -3.5975988104650742`}, {
            2.0775786429139425`, -3.732072822662788}, {
            2.1447489956551458`, -3.875486513707142}, {
            2.2071623545485815`, -4.008216840269001}, {
            2.2308540198902085`, -4.058427860824058}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.2397618383286746`, -4.077306679525277}, {
            2.2655047600385196`, -4.1318650380231565`}, {
            2.3204622525692318`, -4.248032342644403}, {
            2.372446885763973, -4.357660581604432}, {
            2.421870713245999, -4.46169158237494}, {
            2.500583656482928, -4.6270386933308325`}, {
            2.5738840270284142`, -4.780675530093696}, {
            2.598164242708878, -4.831468947885668}}]}, 
          {Arrowheads[{{0.004003963641082503, 1.}}], 
           ArrowBox[{{2.60716709958876, -4.85030263028945}, {
            2.6425312789436224`, -4.92428333789441}, {
            2.6793060353693323`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9004740160971186, 0.37163644708033655`}, {
            0.9036352603153301, 0.37510360987200086`}, {0.9075764405678973, 
            0.3794924587786393}, {0.9115652867890968, 0.3839971896501715}, {
            0.917482315683054, 0.3908089448481455}, {0.9262173403514151, 
            0.4011584605910765}, {0.9288623758485207, 0.40435855211697985`}, {
            0.9317901422167124, 0.4079577844926979}, {0.9369487552806269, 
            0.414442125897985}, {1.0134504596127096`, 0.5142699068158244}, {
            1.0733245508527027`, 0.594064157322774}, {1.1406065383914281`, 
            0.6822494896940263}, {1.2133897613469502`, 0.7742279974593738}, {
            1.2978841467287234`, 0.8759100895889367}, {1.3951035628008217`, 
            0.9866426247734286}, {1.425994846773884, 1.01996545833731}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.4401864839541887`, 1.0352741636721436`}, {
            1.507775073477348, 1.1081828624967605`}, {1.638573136080738, 
            1.242485539790257}, {1.7900505022468, 1.3916486346846602`}, {
            1.8817476642393287`, 1.479555853651939}, {1.96430984287371, 
            1.5575764073826186`}, {2.033704110283483, 1.622297574342975}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0489699096517517`, 1.6365353548769603`}, {
            2.0696031336997467`, 1.6557791107142423`}, {2.1642651392714356`, 
            1.7431168590344401`}, {2.281017846707993, 1.8497934697927998`}, {
            2.3861559659882596`, 1.9451177900747538`}, {2.4818517687982475`, 
            2.031317351026636}, {2.5702775268239697`, 2.1106196837947784`}, {
            2.652339484147804, 2.183922245735376}, {2.667505067930559, 
            2.197430655622165}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6830928761968456`, 2.211315152672461}, {
            2.729349420609239, 2.2525171512779885`}, {2.753963787434224, 
            2.2744050329173544`}, {2.835440533885766, 2.346663075519284}, {
            2.912462166589994, 2.4148388980278903`}, {3.058972759798696, 
            2.5443363303568254`}, {3.192047518857251, 2.6616443784574844`}, {
            3.3087308833255933`, 2.7642973060971006`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.3244103998668932`, 2.7780781525439617`}, {
            3.4453711937524365`, 2.8843328057091693`}, {3.5667189715440366`, 
            2.9907795921381997`}, {3.6798920795157724`, 
            3.0899372818625492`}, {3.786303884888141, 3.183086925293423}, {
            3.8867945941351913`, 3.270984004007409}, {3.952429108949044, 
            3.3283566965473117`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.9681458509899388`, 3.342095075072674}, {
            3.982204413730971, 3.3543839995810933`}, {4.133618810007291, 
            3.486650171782396}, {4.274407037161587, 3.6095443365213398`}, {
            4.406080618463475, 3.7244099328180953`}, {4.530151077182571, 
            3.8325903996928337`}, {4.5972806643713415`, 
            3.8910975466190334`}}]}, 
          {Arrowheads[{{0.012327277608334297`, 1.}}], 
           ArrowBox[{{4.6130174183044765`, 3.904812997779463}, {
            4.647535187696408, 3.9348971423415233`}, {4.759149724382521, 
            4.032141565960131}, {4.851563632730602, 4.112634945073738}, {
            4.940796896436521, 4.190343022884015}, {5.001099999999999, 
            4.242846665424102}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.0230440865451196`, 
            0.0731575326148006}, {-1.0406878593397426`, 
            0.05979684947600065}, {-1.1385455865467153`, 
            0.034897284996436725`}, {-1.2275629678008366`, 
            0.029182616314292944`}, {-1.321112997256027, 
            0.0270363227086796}, {-1.4128955232900748`, 
            0.026391955962557206`}, {-1.5825085376864734`, 
            0.026421941276054982`}, {-1.7319336579825477`, 
            0.027234558196977104`}, {-1.850214480645892, 
            0.028314260381654674`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.8710883776108627`, 
            0.028512565418704058`}, {-1.9828089955148158`, 
            0.029660468683958396`}, {-2.15442607316964, 
            0.03158309364956874}, {-2.3046698924609137`, 
            0.033356656926907924`}, {-2.4380582726551645`, 
            0.03499404123955661}, {-2.559109033018921, 
            0.03650812931109545}, {-2.706023454607759, 
            0.03838180845402993}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.726896599051766, 
            0.038648014963705665`}, {-2.7726790152699756`, 
            0.03923190289964484}, {-2.8682686502984835`, 
            0.040467004328990794`}, {-2.9581014216564334`, 
            0.0416341739198272}, {-3.028161670570453, 
            0.042548201363233895`}, {-3.0327809441621656`, 
            0.04260857048638662}, {-3.127317843191945, 
            0.04384906340032666}, {-3.2168193422151385`, 
            0.04502720615971535}, {-3.3872572741446296`, 
            0.04727593332001656}, {-3.542361077412751, 
            0.04933096886486148}, {-3.561818576983883, 
            0.04958955735986874}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.5826915756646778`, 
            0.049866957716241514`}, {-3.685180026898467, 
            0.05122902041413771}, {-3.839229658695942, 
            0.053280931310531465`}, {-3.9820086377164308`, 
            0.05518655804766356}, {-4.115166968145939, 
            0.0569668103913783}, {-4.2403546541704715`, 
            0.05864259810752}, {-4.358558928661199, 
            0.060226617576910425`}, {-4.417610780771006, 
            0.06101862766011098}}]}, 
          {Arrowheads[{{0.013477156698507192`, 1.}}], 
           ArrowBox[{{-4.438483745404136, 
            0.06129857820975653}, {-4.470767024489292, 
            0.061731565180371366`}, {-4.646384637875665, 
            0.06408904530700538}, {-4.809779316148984, 
            0.06628449822715232}, {-4.962672065645309, 
            0.06834047787039435}, {-5.001099999999999, 
            0.06885753523677364}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9514843559006614, -0.08028194743187561}, {
            0.9554561091398142, -0.08098892354052102}, {
            0.9594142041376144, -0.08169876368836058}, {
            0.9666326678357626, -0.08301080215268741}, {
            0.9807654612332084, -0.08564692840606605}, {
            1.0026739673541059`, -0.08985500197688376}, {
            1.0282007943254472`, -0.09484395166986151}, {
            1.0515880130115383`, -0.09940465688857679}, {
            1.0926103047227316`, -0.1073161089703591}, {
            1.1293750868832895`, -0.11435346831713004`}, {
            1.1628410283259276`, -0.12070372548704415`}, {
            1.2761995359718075`, -0.14178786571883034`}, {
            1.404967266833067, -0.16484035841637112`}, {
            1.551612133220491, -0.1900071106586511}, {
            1.7166033312998858`, -0.2171843920729369}, {
            1.773573167969486, -0.22623382783117485`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7941895333099942`, -0.229508656839362}, {
            1.906828954916984, -0.24740098845317993`}, {
            2.12010152009022, -0.2802734108461014}, {
            2.2473416734049154`, -0.29952164586920643`}, {
            2.360855767889246, -0.31652668720441834`}, {
            2.4945656875801236`, -0.33638246883683304`}, {
            2.6147597152394937`, -0.35411031506031815`}, {
            2.619718770031011, -0.3548361788853081}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6403735247049744`, -0.3578594443788688}, {
            2.8248202840284216`, -0.3848571759745191}, {
            2.9182998929939927`, -0.3984634558681174}, {
            3.005961740932287, -0.4111904111247851}, {
            3.0751241224398216`, -0.42121179427730004`}, {
            3.0796800934827866`, -0.4218713747600335}, {
            3.1727583113217523`, -0.4353191623845082}, {
            3.260751335670567, -0.4480113808005497}, {
            3.4281464392562335`, -0.4721268250198171}, {
            3.4667262646010815`, -0.4776720126556909}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.4873887630196045`, -0.48064189211295905`}, {
            3.580213913414367, -0.4939839140548989}, {
            3.720083654032539, -0.5140531298281878}, {
            3.870394480220919, -0.5355922159535115}, {
            4.009666468306588, -0.5555254785570983}, {
            4.139529907762784, -0.5740929595660892}, {
            4.261615088062744, -0.5915347009076247}, {
            4.313950437661883, -0.5990065036869734}}]}, 
          {Arrowheads[{{0.016125221850474724`, 1.}}], 
           ArrowBox[{{4.334615735243059, -0.6019568427806409}, {
            4.376890446324029, -0.6079923103216115}, {
            4.4863244196642, -0.6236073955479561}, {
            4.65891271932856, -0.6482197286086181}, {
            4.819433895185392, -0.6710969047552858}, {
            4.969598482693308, -0.6924864482508982}, {
            5.001099999999999, -0.6969716401056182}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9283713414096387, 0.9768685713357058}, {
            0.9347227467286146, 1.085390551645146}, {0.9386310955665943, 
            1.1993644660554617`}, {0.9404293497741224, 1.3180197725206055`}, {
            0.9404176374256017, 1.4467645332997587`}, {0.9387489590501802, 
            1.578221721597235}, {0.9353642847180115, 1.7212482166083103`}, {
            0.9322521485166906, 1.8114916457378085`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{0.9315326861126301, 1.8323540856415041`}, {
            0.9303202747904971, 1.8675106945258704`}, {0.922961976925157, 
            2.026586167052467}, {0.9131560905745237, 2.1889291429427997`}, {
            0.8994358620213002, 2.3645586214466814`}, {0.8814873037832784, 
            2.5420093867745264`}, {0.8654136348911766, 
            2.6643691463200474`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.8626947904464436, 2.685066172912568}, {
            0.8564320678761973, 2.732740741359862}, {0.8256039581144125, 
            2.912813030344587}, {0.7958055549777453, 3.050309596938632}, {
            0.7812132504629974, 3.1080421806043224`}, {0.7667887273773685, 
            3.1603112612309325`}, {0.7657332321847454, 3.1639623557104546`}, {
            0.7474699911699435, 3.2209233514958258`}, {0.7293632647607254, 
            3.272246165963484}, {0.6935173869880527, 3.365596394367532}, {
            0.6583320416541912, 3.442637860407787}, {0.6360753043930825, 
            3.484062289355971}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6261953173087434, 3.5024510054639397`}, {
            0.6236782840333011, 3.507135729233446}, {0.5494407733478966, 
            3.616441060869984}, {0.47665860542423605`, 3.692963732200382}, {
            0.4048120129285578, 3.746318025975166}, {0.286855029639156, 
            3.7998130726825785`}, {0.1696490644387074, 3.8232366666239064`}, {
            0.05263182217320482, 3.8299081063939453`}, {-0.07626618144272417, 
            3.8318726252829665`}, {-0.08352333683023348, 
            3.8324578892255516`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-0.10433062463864945`, 
            3.8341359234754746`}, {-0.20466224983170916`, 
            3.8422273145772166`}, {-0.3316906186464243, 
            3.874199613564424}, {-0.44368867441450954`, 
            3.9290928265861718`}, {-0.5527084859143823, 
            4.011729566754042}, {-0.6579335665947326, 
            4.120601935718501}, {-0.7725594391778214, 4.272641392528583}}]}, 
          {Arrowheads[{{0.019407332428329815`, 1.}}], 
           ArrowBox[{{-0.785126142827273, 
            4.289309835295471}, {-0.7875958653393271, 
            4.2925856687590915`}, {-0.849497879150668, 
            4.3884166679136305`}, {-0.9094040610601055, 
            4.488748794933528}, {-0.9673406068693879, 
            4.592558948510245}, {-1.0233546690216624`, 
            4.698005546288409}, {-1.1127974759193116`, 
            4.878211515830099}, {-1.170450668385243, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.907021396918473, -0.3165317033724338}, {
            0.9101327452050795, -0.319945854781871}, {
            0.9136658638582923, -0.3235586062845393}, {
            0.9164359017351001, -0.32631583131592173`}, {
            0.9209091773700585, -0.3306996657396116}, {
            0.9272484795548335, -0.3368557830812852}, {
            0.9383829436907417, -0.3477589488315796}, {
            0.9561159092509123, -0.36564406612178024`}, {
            1.0267979378202492`, -0.43835791780220285`}, {
            1.0547502187931475`, -0.4671749215024101}, {
            1.0799214875400969`, -0.4930296133890217}, {
            1.1029210153813416`, -0.5165096987185722}, {
            1.1813503684138609`, -0.5951280003779515}, {
            1.2685117180662815`, -0.6791660100389667}, {
            1.3699245005604204`, -0.7723474663517}, {
            1.4864738138768032`, -0.8740678870745744}, {
            1.5099253403174648`, -0.8935604234490575}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5259787934956874`, -0.9069037988069191}, {
            1.621101077352655, -0.9859679306363496}, {
            1.7766597773425508`, -1.1098501775274017`}, {
            1.8710473605557916`, -1.1829409551603378`}, {
            1.9557699415144554`, -1.2475571947514228`}, {
            2.063931128987311, -1.3289043328315513`}, {
            2.1609238670108506`, -1.4010137397423597`}, {
            2.1853422049548725`, -1.418978297314625}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.2021567892094605`, -1.4313487775490998`}, {
            2.2836480012758402`, -1.491301816701732}, {
            2.3936490418844825`, -1.5715478615921608`}, {
            2.533889718737368, -1.6730766817918679`}, {
            2.6594250621203512`, -1.763406720917911}, {
            2.8061691252302046`, -1.8684313566399409`}, {
            2.8789829738201402`, -1.9203328097610648`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.8959814965320536`, -1.9324492964836562`}, {
            2.938456799172484, -1.9627255416140719`}, {
            3.058959639584847, -2.0483265911729163`}, {
            3.170349202104951, -2.1272718206490873`}, {
            3.273751759025671, -2.2004034606781344`}, {
            3.3708003625356286`, -2.268939053917741}, {
            3.394508751348678, -2.285667861098613}, {
            3.4957469617094388`, -2.35700545855804}, {
            3.577656367718495, -2.4146647932873195`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.594726441227351, -2.426680267196534}, {
            3.6849431290363603`, -2.490163926280913}, {
            3.773741409002078, -2.5525995800315084`}, {
            3.93940499554655, -2.6689642214086797`}, {
            4.091853838043727, -2.7759330205199237`}, {
            4.255898932134135, -2.89094541647984}, {
            4.278094453009478, -2.9064951657360174`}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{4.295191125918612, -2.918472761501623}, {
            4.407930951931788, -2.997456085909095}, {
            4.549718505381625, -3.0967260835540187`}, {
            4.683030200428585, -3.190016464160939}, {
            4.808918825477318, -3.278074683930606}, {
            4.92843716893247, -3.361648199063769}, {
            4.979312386595405, -3.397213262507535}}]}, 
          {Arrowheads[{{0.0001367351075354502, 1.}}], 
           ArrowBox[{{4.996421238570699, -3.409173455188827}, {
            5.001099999999999, -3.412444211653669}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAApt44zTTY2b/bLkGLs6Tsv5r1a/zk
Idq/xFk6KfWc7L/I4rL2b2zavyS4H7gZley/DqkbMWHt2r/FuQPnc4fsv/3S
eW6fStu/yubJxYx97L9XpqUk1cHbvx7PdRzXcOy/8BkTMr1W3L8bO5oc4mDs
v8Q3bUMMBd2/wGT8yg9O7L/OTSjG2z3fv0grH3uMD+y/y3VGj9Qj4L9x/Iw2
p/Drv4UwhYXaqOC/6UiijaPP679EeGaiuGHhv5C/qyKHnuu/spkWZuUi4r/j
qhET8Gjrv5YXm4zw7OK/luSaLKou679UAO8K6NPjvw7HyFZV5uq/oeRMNCf1
5L/lhAc3F4jqvyxHHAENmOW/ZPBeCglT6r+tZC1AgzHmv7TjIzXKH+q/nOfm
K0vb5r8FBIQvQ+Xpv1GjGb7XK+i/xLL50jpu6b9ly4b04mDpv7P4HaLL/ui/
stnj1a196r9mf3RJyZfov22XahxZQ+6/Blz6M29R57+YS0q29RTxv3UmbLDo
Uua/K3khOj8l879NP2gES9blv8fN+jO3VfO/JziUpB7Z5b/WsvKb
            "]]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.229292641919007, -0.6833623149490932}, \
{-1.335174345385292, -0.686449793474332}, {-1.4998586581350204`, \
-0.7114764949117848}, {-1.7105127302775063`, -0.7627501087784002}, \
{-1.831855654690734, -0.7983889838910789}, {-1.940420310580922, \
-0.8325211395837614}, {-2.0404744575971443`, -0.865711431331006}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.0602876206191154`, -0.8722839191363173}, \
{-2.073896265000002, -0.8767982235480365}, {-2.193262643238854, \
-0.9178120438537372}, {-2.3273654251167875`, -0.965216923078626}, \
{-2.4482819086835517`, -1.0087611801365028`}, {-2.651068352739034, \
-1.0830003377401207`}, {-2.8280570075956404`, -1.1486979322124369`}, \
{-2.8457982266081747`, -1.1553564743092593`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.865341926720049, -1.162691514242572}, \
{-2.9849182227742737`, -1.207570268092384}, {-3.1273223477958356`, \
-1.2613336499188954`}, {-3.257784229865134, -1.310828263516931}, \
{-3.3788187161869745`, -1.356894294711451}, {-3.491534765692848, \
-1.3999178505246086`}, {-3.5975523682339845`, -1.4404663735642802`}, \
{-3.6337667416420625`, -1.4543339223332183`}, {-3.645982847626262, \
-1.4590204693956395`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.665472673171117, -1.4664974825103325`}, \
{-3.743879292651302, -1.496577142319645}, {-3.8482130625676576`, \
-1.5366553696191108`}, {-4.047042251682337, -1.6131064605578662`}, \
{-4.228239770539534, -1.6829020853275647`}, {-4.395280984314539, \
-1.7473299074665718`}, {-4.44473995571022, -1.7664252486742407`}}]}, 
          {Arrowheads[{{0.013786954300028105`, 1.}}], 
           ArrowBox[{{-4.46421379629009, -1.7739437962704174`}, \
{-4.576129045927565, -1.8171525371290203`}, {-4.743874883012187, \
-1.881975494865932}, {-4.9004251608917295`, -1.9425189993974803`}, \
{-5.001099999999999, -1.981476138484979}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9513500237398255, 0.15489809742265628`}, {
            0.9552376168039531, 0.15625624044937964`}, {0.9592520836864208, 
            0.15767065533871583`}, {0.9662553408501164, 0.1601686610221418}, {
            0.978443230317983, 0.1646015424137789}, {1.0056097239549748`, 
            0.17487522819092385`}, {1.0384658077356417`, 
            0.1875309697262876}, {1.0675773678838723`, 
            0.19869297768653482`}, {1.1634840101245063`, 
            0.23484899786288366`}, {1.2744111156588716`, 
            0.2754667251824018}, {1.4009714998848692`, 
            0.31998701405792707`}, {1.54518649796726, 0.36852103472545256`}, {
            1.7093715793827942`, 0.4214600936398055}, {1.7392861173171388`, 
            0.43075043573982985`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7592216998027443`, 0.4369416856819489}, {
            1.8939325316807805`, 0.4787778562914562}, {2.005907409002342, 
            0.5127145301981043}, {2.1056649174344266`, 0.542550271586918}, {
            2.2309874646499614`, 0.5795784040202853}, {2.3428408949953226`, 
            0.6123010481849476}, {2.482129117306519, 0.6526853649160658}, {
            2.5595485529144515`, 0.674971553088135}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.579608788064509, 0.6807461518283554}, {
            2.6066804672300985`, 0.6885390856217967}, {2.763582040209677, 
            0.7334144000808214}, {2.903913982867299, 0.7733447935452891}, {
            3.0621237456460664`, 0.8181595390765112}, {3.2051167188266003`, 
            0.8585281899448756}, {3.3356532773623053`, 0.8952760863078693}, {
            3.382923431220483, 0.90855755070467}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.4030200867403, 0.9142040949402152}, {
            3.4564937962065865`, 0.9292285683229791}, {3.568817250170415, 
            0.9607325109852157}, {3.674337052713706, 0.9902907601309321}, {
            3.717692602205794, 1.0024258512870845`}, {3.827940909971999, 
            1.0332462377760092`}, {3.932308534682795, 1.0623979181518037`}, {
            4.131065683536689, 1.1178786261286737`}, {4.207158650204045, 
            1.1390937928792633`}}]}, 
          {Arrowheads[{{0.019239648476232246`, 1.}}], 
           ArrowBox[{{4.227266593924611, 1.1447000058806325`}, {
            4.311976403865708, 1.1683175992275623`}, {4.478614546903943, 
            1.214735474986576}, {4.658490367130601, 1.2648062366212247`}, {
            4.825280325284022, 1.3112048674620136`}, {4.980900132107593, 
            1.3544722606875064`}, {5.001099999999999, 
            1.3600860956602883`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAq8dhsf7X2b9Cj1to9M7sP5sNDtTu
Htq/lIz7UZrH7D9iGbPlxlbav84COEDMwew/kFUDh8Ct2r/lFGAwubjsPzvC
bKBnONu/kTAybyyq7D+gnlb0bZjbvxQjH/oLoOw/lMpMmz4P3L85WRlVdJPs
P0s6SI+vnty/I7/ZSyiE7D92W3Sr77bev8WW/2mKSew/p/OdGz814L+3Lpn+
bxfsPzDBGefpBeG/oTLoHkzj6z9jUnokZBHivySbxIJ6m+s/VS6/mY4y479G
dsSKYUnrPzNKHEN/VuS/gPfzx6Tv6j+ya4RKqrTnv2+OlSEB0ek/RoAz0SkH
6b8H2QFbTFvpP1yGE8yUPeq/uK/rrcbu6D//GsCRh1vrvySuYZ8EjOg/jIAu
VyUn77978dJJAV7nP2FY+rAZl/G/TOXgcNqD5j+hPCrNy13zvy6+GH/tReY/
75C2MQ==
            "]]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.2312260252682088`, 
            0.6946267107530745}, {-1.3760188075580861`, 
            0.7052851241442947}, {-1.5583685454926817`, 
            0.7397076063613255}, {-1.6723528412559827`, 
            0.7690360994708223}, {-1.774303738504803, 
            0.7984666184831838}, {-1.8983581325174261`, 
            0.8375213528560367}, {-2.0093665878302494`, 
            0.874430114384141}, {-2.040905964059445, 0.8853851270677767}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.0606251333292547`, 
            0.8922344619402132}, {-2.1460401115268604`, 
            0.9219028410079342}, {-2.2682937998892125`, 
            0.9656245445480625}, {-2.405689255588445, 
            1.015943848816375}, {-2.5296136332463606`, 
            1.0620489174993608`}, {-2.636839063561381, 
            1.1024025934270545`}, {-2.7374748411447674`, 
            1.1404750894971272`}, {-2.844002589568334, 
            1.1811495912819108`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.8635042341859527`, 
            1.1885957233042608`}, {-2.9189774381166385`, 
            1.20977654206441}, {-3.0799070781980986`, 
            1.2718110496095612`}, {-3.2260494154252735`, 
            1.3284363865409325`}, {-3.3599724799979054`, 
            1.380547769002565}, {-3.4842443021157363`, 
            1.4290404131384988`}, {-3.599998162721215, 
            1.4743234963828897`}, {-3.6419092202923933`, 
            1.4907483624729057`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.661344847154944, 
            1.4983651487601704`}, {-3.708889862033647, 
            1.5169979523181396`}, {-3.742519026792937, 
            1.5301908416060261`}, {-3.8554887528864197`, 
            1.57458098896128}, {-3.962544423691922, 
            1.6166958251503543`}, {-4.067082101116039, 
            1.6578374014814001`}, {-4.166583791777389, 
            1.6970324580963898`}, {-4.352569122646215, 
            1.770376921279475}, {-4.438302401416502, 
            1.8042263419435598`}}]}, 
          {Arrowheads[{{0.013995529790555862`, 1.}}], 
           ArrowBox[{{-4.457718677083812, 
            1.8118923229047403`}, {-4.524052942458544, 
            1.8380825781395664`}, {-4.7098069784710255`, 
            1.911487951724145}, {-4.882121084570478, 
            1.9796378186720174`}, {-5.001099999999999, 
            2.0267263439767893`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1574924371317068`, 1.4852592991797913`}, {
            1.208717445837847, 1.640214579635751}, {1.267892585807549, 
            1.8058282223670954`}, {1.3393312921152036`, 
            1.9922772253152912`}, {1.3833262703603943`, 2.101722262972519}, {
            1.423418264184862, 2.1987764563416166`}, {1.452013967388382, 
            2.2662583950882222`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4601586679631944`, 2.285478771708695}, {
            1.4748824306128823`, 2.3202248327575976`}, {1.521650637356818, 
            2.4281860509312683`}, {1.5811771963033403`, 2.562827283569106}, {
            1.6351438418793849`, 2.6828029312502757`}, {1.7041522257745905`, 
            2.833803002649043}, {1.7665384540959266`, 2.968506768017157}, {
            1.8031915428901188`, 3.046705721453925}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8120510037212918`, 3.0656072816717237`}, {
            1.8405680480587054`, 3.1264480756036392`}, {1.9077641296765167`, 
            3.2684482052049466`}, {1.9693379078740432`, 
            3.3975148012697027`}, {2.026500591575968, 3.5166555082465316`}, {
            2.079776644644166, 3.6271191768216156`}, {2.1299295977760004`, 
            3.7307119970827483`}, {2.1339087026662096`, 
            3.7389153813763105`}, {2.1727273612528615`, 
            3.8186772158753777`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.1818623581295573`, 3.8374471614519883`}, {
            2.186411235707916, 3.846793873414012}, {2.2361739693458675`, 
            3.948764424756822}, {2.33102698408386, 4.14272687308755}, {
            2.417512352762506, 4.318892933971921}, {2.4972871202748332`, 
            4.480907748760559}, {2.5496776836077175`, 4.5870635061955625`}}]}, 
          {Arrowheads[{{0.010565032012879783`, 1.}}], 
           ArrowBox[{{2.558916111184292, 4.605782760475543}, {
            2.5831541934395497`, 4.654894887104724}, {2.66288367224665, 
            4.8161015461226855`}, {2.7373639622590007`, 4.966417373096348}, {
            2.754573280800098, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7346019231962003, 1.487667089865871}, {
            0.6756558544910434, 1.596623154778286}, {0.5955347902707082, 
            1.7037062712736653`}, {0.4969242625977484, 1.7931481788295172`}, {
            0.4247056411230641, 1.8373539701692743`}, {0.353354558485847, 
            1.868192168657428}, {0.28234447926221745`, 1.8889699970392733`}, {
            0.18356773703392137`, 1.9056977947113722`}, {0.08434409868608739, 
            1.9125097260190407`}, {0.07613258893626666, 
            1.9126158917034928`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.05525949148360119, 
            1.9128857576289087`}, {-0.01536701451451919, 
            1.9137988797682224`}, {-0.1322577667574104, 
            1.914091055341695}, {-0.24760340341829554`, 
            1.9188896295544098`}, {-0.3593622833466708, 
            1.9331328804065424`}, {-0.4982151126775898, 
            1.9705271690357535`}, {-0.6244732507208102, 
            2.028029320477495}, {-0.7377629569421693, 
            2.100537492256075}, {-0.7395812281570092, 2.1019778452970015`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.7559441695889024, 
            2.114939834827263}, {-0.8409560965982722, 
            2.182282476883967}, {-0.9336120841742983, 
            2.2686252033016134`}, {-1.03549576579939, 
            2.376503057870538}, {-1.1267614374685326`, 
            2.482674385456414}, {-1.230236650058302, 
            2.6126384729003584`}, {-1.3176836140073118`, 
            2.728770730305016}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.3300591349212638`, 
            2.745580460554681}, {-1.3919552213014077`, 
            2.831110560206475}, {-1.4567923977067916`, 
            2.922296857745612}, {-1.574399471004321, 
            3.0927707805145177`}, {-1.679233512254, 
            3.249529889119755}, {-1.7746111954256303`, 
            3.3947242658101486`}, {-1.800760427663946, 
            3.435120683512387}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.8121038840433394`, 
            3.4526445250505593`}, {-1.8621218883595207`, 
            3.5299144110867613`}, {-1.9433549588959818`, 
            3.656660825450658}, {-2.019030363832021, 
            3.775788633806599}, {-2.0902058230528984`, 
            3.888538421706312}, {-2.0945262550578496`, 
            3.8954032646847727`}, {-2.1675779009695137`, 
            4.012078681516942}, {-2.236777013603329, 
            4.123061601547712}, {-2.2586459016014975`, 
            4.158188611172994}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-2.2696785136725306`, 
            4.175909798937257}, {-2.304340584191008, 
            4.231585921327968}, {-2.368633070686413, 
            4.335193040607198}, {-2.4299916259603678`, 
            4.434356569292896}, {-2.488753402883694, 
            4.529550117292557}, {-2.599436232459507, 
            4.70939829496707}, {-2.6605159308460107`, 
            4.808898081238157}, {-2.708110442142254, 4.88653544340002}}]}, 
          {Arrowheads[{{0.0027175561839434827`, 1.}}], 
           ArrowBox[{{-2.719020562370965, 
            4.904332305524599}, {-2.7194048281777823`, 
            4.904959129559509}, {-2.7761029244548214`, 
            4.997581439931127}, {-2.778253401131447, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.954639348899598, -1.5715538476750275`}, {
            0.9554542608789913, -1.7113508515846063`}, {
            0.9554939563393341, -1.8641462534133368`}, {
            0.9546497904926902, -2.0213128851283755`}, {
            0.9525897714526294, -2.1931147280462575`}, {
            0.9489517805375383, -2.3697610599565073`}, {
            0.9477770234454371, -2.406474278698807}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9471094076722725, -2.427338442091227}, {
            0.9427996295792096, -2.5620265635124757`}, {
            0.9335092978460043, -2.7587163715305474`}, {
            0.91924436792778, -2.9707131178348196`}, {
            0.8992181814587279, -3.184175908679139}, {
            0.8901503104407078, -3.260087505799833}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.8876743493335697, -3.2808149909700632`}, {
            0.8844904916870038, -3.307468625376139}, {
            0.8697166492058039, -3.4128778137489224`}, {
            0.8340739342569574, -3.616542341569848}, {
            0.7987292016649542, -3.7723067898588023`}, {
            0.7811936199693393, -3.8375204854241347`}, {
            0.7632440464303157, -3.897980615446664}, {
            0.7410653751969973, -3.9615047465430746`}, {
            0.7189653671823001, -4.018340613778335}, {
            0.6889062616739792, -4.08853821007983}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6806891662585267, -4.107727748058101}, {
            0.6750294558584279, -4.120944976552792}, {
            0.6315779258386084, -4.204057414386}, {
            0.5885295964706858, -4.272064957238469}, {
            0.4957744441256376, -4.382312826808019}, {
            0.404122356647492, -4.453079835074522}, {
            0.3131116527663663, -4.496413292511459}, {
            0.16834243509264984`, -4.529189102831733}, {
            0.03128715035625715, -4.536296873529148}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{
            0.01042715300384907, -4.537044294164042}, {-0.12024668986886256`, \
-4.54058377577805}, {-0.24401599251073497`, -4.556329998916063}, \
{-0.3666965662830943, -4.596022090300542}, {-0.48749428669841766`, \
-4.667618590464717}, {-0.6179420221006777, -4.78727632314731}, \
{-0.7007300659696347, -4.891529371901751}}]}, 
          {Arrowheads[{{0.0027517771549935115`, 1.}}], 
           ArrowBox[{{-0.7137116475966659, -4.90787677424423}, \
{-0.7439328170693825, -4.9459335866438865`}, {-0.7806875989509316, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.2440266429359084`, -1.054848996131513}, {
            1.3232974350708941`, -1.179700522679685}, {
            1.4158573467463949`, -1.3167421890409667`}, {
            1.5241041747970143`, -1.4681700172171155`}, {
            1.6503050102983954`, -1.6363120029033287`}, {
            1.727075697491292, -1.7354122294134842`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.7399967252977107`, -1.7518075340461259`}, {
            1.796529165172989, -1.823538640545206}, {
            1.8848934698803739`, -1.9339041876962844`}, {
            1.9646438361428655`, -2.0322115705018042`}, {
            2.065481736969508, -2.1550397007517246`}, {
            2.156357788763065, -2.2646603138685992`}, {
            2.2682316480271574`, -2.398429487181775}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.281669445142943, -2.4144039623744837`}, {
            2.373478154245965, -2.523406085903601}, {
            2.5016909451439218`, -2.6746658087188724`}, {
            2.617079445790175, -2.8101076423932745`}, {
            2.691748635030591, -2.897425300515338}, {
            2.7627282422105837`, -2.9802926573792936`}, {
            2.822843769790002, -3.05027967215117}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.8364454496339198`, -3.066114864928959}, {
            2.8936187103893007`, -3.1326764673328804`}, {
            2.968088817687649, -3.219144919295032}, {
            3.0392082937724205`, -3.301633844844314}, {
            3.1713953523012353`, -3.4546731167042664`}, {
            3.292529244839009, -3.594634116691057}, {
            3.382185853442693, -3.6980804933099196`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.3958576932998588`, -3.7138551508277926`}, {
            3.4049593302490067`, -3.7243566785830042`}, {
            3.5097130434195596`, -3.8450680484810467`}, {
            3.6082893540625647`, -3.958555363105874}, {
            3.615480503739766, -3.9668304585277485`}, {
            3.7174937293904042`, -4.0841262573923895`}, {
            3.814186414679117, -4.195231606889061}, {
            3.9086131420472108`, -4.303706720065124}, {
            3.9437039172688095`, -4.343996940257692}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.957413954440535, -4.3597384111430975`}, {
            3.9985079535740673`, -4.406921360599971}, {
            4.0843415169979504`, -4.505426685810189}, {
            4.166584500057125, -4.599773853012364}, {
            4.245565793379949, -4.6903467500168015`}, {
            4.321614287594779, -4.777529264633805}, {
            4.407023001265403, -4.875415176409482}, {
            4.489413861178097, -4.969819820692573}, {
            4.506206626676556, -4.989056271707088}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.8179019271765934, -1.130091247203292}, {
            0.7857591176923203, -1.2445994674785361`}, {
            0.7298076874722375, -1.381829691146244}, {
            0.7026243896022882, -1.4330570447704625`}, {
            0.67597066652518, -1.4766544599692284`}, {
            0.6497853906706735, -1.514184610554313}, {
            0.548597945505554, -1.6261518939551594`}, {
            0.4729481652592695, -1.682144969832255}, {
            0.39847593558761657`, -1.721302368776197}, {
            0.3244989117637659, -1.748184254899917}, {
            0.3195143361208419, -1.7493738125551364`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.29920969064132186`, -1.7542194700788556`}, {
            0.25170143351083313`, -1.7655572077327997`}, {
            0.1786502427817493, -1.7760447273943405`}, {
            0.10519134536516893`, -1.7814044481421873`}, \
{-0.01756883914332965, -1.7837496927532266`}, {-0.14029158120499324`, \
-1.783671474211328}, {-0.2610485879721464, -1.7877601840696913`}, \
{-0.4144161402079514, -1.8080702370358264`}, {-0.5274561650820994, \
-1.8407132567557494`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.547511536046713, -1.8465047263756218`}, \
{-0.554941341294884, -1.848650260928549}, {-0.6802859675822153, \
-1.9069551095554602`}, {-0.8074452160244966, -1.9866457834767515`}, \
{-0.9190690722892714, -2.074629649462458}, {-1.017729832138432, \
-2.1663786496146797`}, {-1.105999791333871, -2.2573647260355165`}, \
{-1.1960555089927916`, -2.3583737643209597`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.20987183577858, -2.3740202749884842`}, \
{-1.2989404724029114`, -2.4804137026712314`}, {-1.4040049620411887`, \
-2.612663236239964}, {-1.4983520411653686`, -2.736055457578396}, \
{-1.5731350404960367`, -2.836614284967969}, {-1.6434104585170437`, \
-2.9323184408254837`}, {-1.7091782952283896`, -3.02316792515094}, \
{-1.7183443303568868`, -3.0360348560797186`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7304560259128274`, -3.053036792900163}, \
{-1.7704385506300742`, -3.1091627379443367`}, {-1.8832844869863392`, \
-3.269886059786007}, {-1.985796437067718, -3.417786117201546}, \
{-2.079745812173433, -3.554780685705645}, {-2.166904023602706, \
-3.682787540812996}, {-2.2054388495371593`, -3.739747199239445}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.217135904614865, -3.757037020736363}, \
{-2.2480614774096783`, -3.8027491790326304`}, {-2.3243760497278827`, \
-3.916066550984583}, {-2.3292927635698595`, -3.9233833807755154`}, \
{-2.4077692015183105`, -4.040609598628231}, {-2.482100480118102, \
-4.151981240297529}, {-2.5546717040401825`, -4.26083639199196}, \
{-2.6237228186068404`, -4.364658563736661}, {-2.6811694543991877`, \
-4.451214729850223}}]}, 
          {Arrowheads[{{0.01528470941935801, 1.}}], 
           ArrowBox[{{-2.692709130183039, -4.4686099835736135`}, \
{-2.7527244343709776`, -4.559194870965351}, {-2.8715892029203762`, \
-4.7390044939214535`}, {-2.937128895905105, -4.838333312136131}, \
{-3.000321388768438, -4.9342009810823315`}, {-3.0443712069456614`, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3137012481063652`, -0.4136971415560808}, {
            1.4422473506827271`, -0.4779880836835116}, {
            1.5895353581830327`, -0.548290908718774}, {
            1.7585253968368633`, -0.6255315853726602}, {
            1.9485937790404635`, -0.7092740967337423}, {
            2.0638829401418537`, -0.758901881893351}, {
            2.0722014429680558`, -0.7624386571725417}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.091412031715456, -0.7706064172611108}, {
            2.166644348731724, -0.8025929182671878}, {
            2.2955098275203216`, -0.856768221531041}, {
            2.410577787231008, -0.9047071351003179}, {
            2.554151699878385, -0.9640357241627431}, {
            2.6825437834848995`, -1.0167489333873128`}, {
            2.841546586270319, -1.0816531196218786`}, {
            2.8627791324045786`, -1.090280891763321}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.882118324493004, -1.0981393059960494`}, {
            2.983965950679312, -1.1395247388276046`}, {
            3.162881943507818, -1.211931972954463}, {
            3.32311937640201, -1.276572475066843}, {
            3.5001327382671255`, -1.3477814425818357`}, {
            3.6564677088431834`, -1.4105431162829982`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.6758434325318223`, -1.4183110201605906`}, {
            3.8072925056484257`, -1.470991005570454}, {
            3.9433418351864034`, -1.5254496305949767`}, {
            4.069966970312799, -1.5760809751365312`}, {
            4.189031199047438, -1.6236517641511872`}, {
            4.216982514087826, -1.6348144930776287`}, {
            4.340519653175895, -1.684115450768251}, {
            4.451181599758842, -1.7282544783262348`}}]}, 
          {Arrowheads[{{0.013679022541075236`, 1.}}], 
           ArrowBox[{{4.470571348260989, -1.7359873094673866`}, {
            4.571822864553293, -1.7763648109465706`}, {
            4.680562427821306, -1.8197098231140156`}, {
            4.784350470620755, -1.8610652789630182`}, {
            4.883765106419625, -1.9006653565125076`}, {
            5.001099999999999, -1.9473842925084153`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3181096496675253`, 0.5585820628506037}, {
            1.437652365284825, 0.6397564789669373}, {1.574879074236765, 
            0.7285402496226266}, {1.7330005718522419`, 0.826393607584031}, {
            1.9151189073570993`, 0.9349144224382911}, {2.0254380168442006`, 
            0.9990801575082993}, {2.026720571934263, 0.9998166377648346}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.044823132591419, 1.0102116520765216`}, {
            2.1239567324444097`, 1.0556524556504627`}, {2.250000404561713, 
            1.127187921172521}, {2.3625032870266875`, 1.1904349681394584`}, {
            2.5030159390194524`, 1.2687565986718965`}, {2.6286235604281534`, 
            1.3383009755152426`}, {2.7734486561248772`, 
            1.4180049645046853`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.791744952452759, 1.428055046760129}, {
            2.923661141680652, 1.5003148340005983`}, {3.0987968421834013`, 
            1.5958476460300048`}, {3.2556028366456093`, 
            1.6811004337103959`}, {3.4294360768433663`, 
            1.7753397189145856`}, {3.5251905725856956`, 
            1.8271413071620208`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.5435509049209433`, 1.8370739413254957`}, {
            3.5868800173799964`, 1.8605142699004649`}, {3.7308586411539775`, 
            1.9382661699919086`}, {3.864295931063787, 2.010237502512792}, {
            3.988455834995829, 2.0771306238638045`}, {4.105178839006834, 
            2.1399665773069327`}, {4.127723591748744, 2.1520978921997513`}, {
            4.248767298057806, 2.2171845696000374`}, {4.278593379764125, 
            2.233213573157816}}]}, 
          {Arrowheads[{{0.019141956999967534`, 1.}}], 
           ArrowBox[{{4.296981096444473, 2.2430954201597393`}, {
            4.363418658103519, 2.278800006591464}, {4.475353477228205, 
            2.338943235233726}, {4.581855214510836, 2.3961420471776576`}, {
            4.683493404219751, 2.450707387216694}, {4.780837580623289, 
            2.502950200144267}, {4.964230324690522, 2.6013319778461574`}, {
            5.001099999999999, 2.621103687490715}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.1572345131273412`, 1.0032046631676845`}, {
            1.2190861558508734`, 1.122193212240904}, {1.2909508035938098`, 
            1.2517368846718853`}, {1.3751261421709167`, 1.393860311321854}, {
            1.473884676535096, 1.550823655205894}, {1.5855714327190742`, 
            1.7192826793348805`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5972897650437252`, 1.7365573867276274`}, {
            1.6598294651511782`, 1.8277189062896657`}, {1.723623526153936, 
            1.918985416543515}, {1.8049145270650557`, 2.033299694521826}, {
            1.878385846788745, 2.135139849847632}, {1.9713941022126145`, 
            2.2623807419940523`}, {2.0553145072540144`, 
            2.3759581630461684`}, {2.084267088328625, 2.4147626113113105`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.0967503546472113`, 2.4314936330047225`}, {
            2.1609383015442143`, 2.5175231948662966`}, {2.256120847791236, 
            2.644090597100028}, {2.37486221007432, 2.8008683560848455`}, {
            2.4818115967757746`, 2.9412755298944084`}, {2.5510657192002175`, 
            3.0318124956565446`}, {2.6010269448613696`, 3.097006913130282}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.613724469738923, 3.1135759169286423`}, {
            2.6169165740156584`, 3.1177412947007697`}, {2.7384084808195333`, 
            3.2757743926354865`}, {2.8074903196527248`, 3.365364408930587}, {
            2.873480336674278, 3.450840057585823}, {2.99618490528247, 
            3.6094482519767017`}, {3.1086821991331433`, 
            3.7545312958076105`}, {3.1241231661612954`, 
            3.7744131370790877`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.136927354164056, 3.7908998527761613`}, {
            3.2131322307153316`, 3.889021509078038}, {3.310481751262475, 
            4.014187033506911}, {3.4021125284821454`, 4.131874793156226}, {
            3.4081112042831645`, 4.139575282778384}, {3.5029155649780197`, 
            4.261164215010406}, {3.592792822860546, 4.376347603415385}, {
            3.6500109111803134`, 4.449655667431227}}]}, 
          {Arrowheads[{{0.016264540780437996`, 1.}}], 
           ArrowBox[{{3.662854877363993, 4.46611141285824}, {
            3.680570431366145, 4.488808657820498}, {3.764148741117889, 
            4.595825044225877}, {3.8439627992379077`, 4.697966540074121}, {
            3.92044765284833, 4.795802922807831}, {3.993907561976908, 
            4.8897312088192155`}, {4.0646467866513945`, 4.980148414500482}, {
            4.081043484287051, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.15009030627529, 
            2.874150289064245}, {-0.1863041227028413, 
            2.8775979722860954`}, {-0.22231371769132874`, 
            2.8825493984433543`}, {-0.3264874046394799, 
            2.905135758332819}, {-0.4278715024594675, 
            2.945283006098275}, {-0.5254182570678861, 
            3.0041404524546538`}, {-0.627710270298646, 
            3.088828348250043}, {-0.7239068441019729, 
            3.1899551534987354`}, {-0.8139667690093911, 
            3.3024019385863905`}, {-0.8234239426731129, 3.315633770802649}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.835562182064146, 
            3.33261676728066}, {-0.8892293340301243, 
            3.4077041851063794`}, {-0.9602316388228929, 
            3.5158121263765247`}, {-1.0273059247959815`, 
            3.6251285636954975`}, {-1.0907844333576753`, 
            3.73405629836197}, {-1.1509840132365359`, 
            3.8418579178136816`}, {-1.2082215131611256`, 
            3.94779600948837}, {-1.261646737782761, 4.04980033840124}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.2713320117664961`, 
            4.068292349993983}, {-1.2851235297941168`, 
            4.0946243785640135`}, {-1.3573036895575532`, 
            4.2365571458853}, {-1.4252912329152296`, 
            4.373556443225433}, {-1.4896154003309405`, 
            4.505584402357618}, {-1.5506579225034205`, 
            4.632855641908001}, {-1.6088005301314046`, 
            4.755584780502727}, {-1.638154834897522, 4.818330952542707}}]}, 
          {Arrowheads[{{0.004329982060633797, 1.}}], 
           ArrowBox[{{-1.6470005021930803`, 
            4.837238971872676}, {-1.699975515530505, 
            4.95047549125797}, {-1.7233492132739896`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7108539826605232, 2.072232074587267}, {
            0.6777968020686324, 2.1400162102569924`}, {0.6458441161093328, 
            2.196267968597028}, {0.614758766337568, 2.24353125935777}, {
            0.4959075702081605, 2.3778177897098405`}, {0.38270784734315516`, 
            2.4522414728267474`}, {0.3413440126577689, 2.469910873240075}, {
            0.3001595975394987, 2.4836972981584946`}, {0.2940190165341085, 
            2.4854545952923077`}, {0.2530506557233991, 2.4940359450503107`}, {
            0.21200569972067207`, 2.500158033981755}, {0.10432137610536099`, 
            2.5103366240430285`}, {0.0671324670126219, 
            2.511056022088499}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.04626152975743637, 
            2.5114597583591993`}, {-0.003513014028589098, 
            2.512422618265215}, {-0.11129150707222733`, 
            2.5136153686314935`}, {-0.19533144983027761`, 
            2.5182202536064744`}, {-0.27835451260970334`, 
            2.5294170620007073`}, {-0.3596978814083403, 
            2.549413097763458}, {-0.44831132273032054`, 
            2.5838513204713895`}, {-0.5331969118342006, 
            2.6309444918765865`}, {-0.6138567500686635, 
            2.6893610952946534`}, {-0.7109847752765254, 
            2.7816522969170037`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.7261175006399673, 
            2.7960314362501073`}, {-0.7625584389287474, 
            2.8306576728663666`}, {-0.8947812217246668, 
            2.991302857811599}, {-1.0126666010328946`, 
            3.1581761518320386`}, {-1.0780721664572792`, 
            3.2586727488502727`}, {-1.1396337566189703`, 
            3.3576257626457586`}, {-1.197749962024868, 
            3.454615013653172}, {-1.209238497561494, 3.474351495805241}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.2197400714292497`, 
            3.492392448418289}, {-1.2528193731818722`, 
            3.549220322307189}, {-1.355024490335933, 
            3.7309243469654776`}, {-1.4239271293391393`, 
            3.8570522833452277`}, {-1.4887703133520123`, 
            3.978026194654026}, {-1.5500179360457056`, 
            4.094146799725291}, {-1.6081338910913725`, 
            4.205714817392438}, {-1.6185304319467164`, 
            4.225900016923489}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-1.6280888262974818`, 
            4.2444579295841685`}, {-1.6633871197579986`, 
            4.312990637387637}, {-1.7162617163297578`, 
            4.416442961228796}, {-1.812454565999051, 
            4.607261510407167}, {-1.9015740773357943`, 
            4.786065835389958}, {-1.985081466468547, 
            4.954681118661204}, {-2.002774263755466, 4.990651327560686}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3082986765547737`, 0.0680536292495235}, {
            1.4420645892790882`, 0.07895018961646853}, {1.594100740130624, 
            0.09082756529347528}, {1.764949665457019, 0.1036567767288858}, {
            1.9613233219698156`, 0.11790425296707574`}, {2.0777934264972786`, 
            0.12616638448294562`}, {2.1409412483557584`, 
            0.13059260006217782`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.1617649992108685`, 0.13205219768154627`}, {
            2.1816247204112775`, 0.133444223642053}, {2.311661520274294, 
            0.14245921174621132`}, {2.4277964364127613`, 
            0.1504386698779035}, {2.5726153225033643`, 0.1603085017876922}, {
            2.702145076618054, 0.16907912436100625`}, {2.8625152691581013`, 
            0.17987470902498512`}, {2.994831838888626, 0.1887407292383876}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0156601508292447`, 0.19013372541527712`}, {
            3.186672862214549, 0.2015451827165801}, {3.348344239074588, 
            0.2122978297957631}, {3.526651789975385, 0.22412292783264362`}, {
            3.688276642769876, 0.23481900076657128`}, {3.836178351138998, 
            0.2445894475801469}, {3.848821256940119, 0.24542361236970867`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.8696508103471277`, 0.24679792301535805`}, {
            3.9733164687636875`, 0.25363766725597126`}, {4.100974964704541, 
            0.26205098030418617`}, {4.221024776738641, 
            0.26995641372678103`}, {4.259916629208263, 0.2725162490401335}, {
            4.384720437234382, 0.2807244631442702}, {4.5029682713339, 
            0.28849720039992793`}, {4.618428234926666, 0.2960851273381025}, {
            4.702842172186079, 0.3016302878815892}}]}, 
          {Arrowheads[{{0.00665933150266332, 1.}}], 
           ArrowBox[{{4.723672119886345, 0.3029986093680689}, {
            4.728312457505927, 0.3033034336413105}, {4.933681374159617, 
            0.31678664921374555`}, {5.001099999999999, 
            0.32121023869888243`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.625090468471167, -1.264056925142784}, {
            1.773638483365216, -1.4150674190654062`}, {
            1.8636885511101342`, -1.5041415881879012`}, {
            1.9448005559648103`, -1.5832047175483732`}, {
            2.0478868641001244`, -1.6823469898053838`}, {
            2.1406202183655827`, -1.7705521988747697`}, {
            2.2223225274273424`, -1.8474917802355997`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.2375195678199975`, -1.861802929322594}, {
            2.2577481437764395`, -1.8808523072837224`}, {
            2.36301044816429, -1.9791806923423847`}, {
            2.495169376936211, -2.101740877664578}, {
            2.6138733267103893`, -2.2111875128424496`}, {
            2.7622136340548775`, -2.3472523312565405`}, {
            2.85093807542936, -2.428301327868503}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.866350406903918, -2.4423803570752525`}, {
            2.895419881337651, -2.468935066221821}, {
            2.9801321803311103`, -2.5460848659897435`}, {
            3.060643868767649, -2.619314208289925}, {
            3.2090654139699644`, -2.7540115204870634`}, {
            3.3048038634524426`, -2.840712231961561}, {
            3.395755516772937, -2.9230022848951402`}, {
            3.4819203739314473`, -3.000881679287802}, {
            3.484754938193331, -3.003440745582341}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.5002494360016674`, -3.0174292967065153`}, {
            3.563298434927974, -3.0743504151395467`}, {
            3.657916093738375, -3.1596946511585524`}, {
            3.7482569321534505`, -3.2411322712476127`}, {
            3.8343209501731996`, -3.3186632754067276`}, {
            3.9161081477976234`, -3.3922876636358974`}, {
            4.06985743046291, -3.530588912987088}, {
            4.120670120527241, -3.5762604921606065`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{4.1361953565297975`, -3.5902149205599025`}, {
            4.212510128751726, -3.658808339983872}, {
            4.345379257445958, -3.7781491023961227`}, {
            4.470380164193532, -3.890364461332928}, {
            4.47876351907585, -3.8978884089436447`}, {
            4.607964190376912, -4.0137923669918765`}, {
            4.730404261474181, -4.123591200416555}, {
            4.757588147906817, -4.147965162833737}}]}, 
          {Arrowheads[{{0.007333141830355249, 1.}}], 
           ArrowBox[{{4.773130291457958, -4.1619007575007}, {
            4.849966773045905, -4.230794862070115}, {
            4.963774165566541, -4.332808180181441}, {
            5.001099999999999, -4.366257121538869}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.4202489667317426`, -1.7042273311491947`}, {
            1.5234334457120313`, -1.890146306034615}, {
            1.5864891045146607`, -1.9996630700890914`}, {
            1.6436985859009006`, -2.0970385770112943`}, {
            1.7166566639577048`, -2.2189284462034067`}, {
            1.7826992834259374`, -2.327548887295208}, {
            1.8424769123473985`, -2.4244688422223613`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.85343525208796, -2.4422360540187182`}, {
            1.8663647257004532`, -2.463199147108293}, {
            1.9419552334858476`, -2.584315918814667}, {
            2.0371604001976205`, -2.735234094632596}, {
            2.1230498381434146`, -2.8701989442273512`}, {
            2.2302610553521145`, -3.0373451270809344`}, {
            2.301092569135722, -3.1470733625393335`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.3124137946579184`, -3.1646115744653462`}, {
            2.3269148424000132`, -3.187075789841276}, {
            2.3895353006175926`, -3.283627017443278}, {
            2.449098771495244, -3.375273274231782}, {
            2.559054751230763, -3.5438508753682956`}, {
            2.621485607902644, -3.639241591517975}, {
            2.681141671221909, -3.7302658378700535`}, {
            2.7688641434738486`, -3.8637997794930317`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.780325553073597, -3.88124670228397}, {
            2.7921294178025917`, -3.899214921181406}, {
            2.893947119353134, -4.053803306836821}, {
            2.9885239042538587`, -4.197136176370768}, {
            3.076707881999004, -4.3305582966254}, {
            3.159737465369304, -4.456028629169527}, {
            3.1640125396656535`, -4.462485078517067}, {
            3.240551541140193, -4.577957301425641}}]}, 
          {Arrowheads[{{0.01166477122805819, 1.}}], 
           ArrowBox[{{3.252085948787154, -4.595356050069438}, {
            3.3313045692008108`, -4.714767343497929}, {
            3.4108352081879048`, -4.83461005605425}, {
            3.486577021335972, -4.948663816237742}, {
            3.5214209231284754`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.5901243722956715`, -0.7413943345625562}, {
            1.750404731098417, -0.8406019531532123}, {
            1.9349481795630528`, -0.9506723828040027}, {
            2.046706356251277, -1.0157765538856802`}, {
            2.146511607092922, -1.0731981782984978`}, {
            2.2739470392974703`, -1.1456887787581007`}, {
            2.309249797062698, -1.1655869580339422`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.327434904144808, -1.175836880243323}, {
            2.387709861893804, -1.2098104843200739`}, {
            2.529647641456275, -1.2891553845772623`}, {
            2.656552885535463, -1.3596382751097764`}, {
            2.8142712193025763`, -1.4467283274540317`}, {
            2.9554697703225887`, -1.5243437604571013`}, {
            3.0578667861658015`, -1.5804036413493245`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0761771375230023`, -1.5904281143061452`}, {
            3.129802481314272, -1.6197866884890704`}, {
            3.2861054086326655`, -1.7050899883929163`}, {
            3.3866699256361033`, -1.7598462510766038`}, {
            3.482152970555115, -1.811784206101236}, {
            3.6578746441398597`, -1.9072051931733336`}, {
            3.75605621540445, -1.960434326730593}, {
            3.809647450357264, -1.9894702884951674`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.8280014730968452`, -1.9994145770147702`}, {
            3.8498013165901495`, -2.0112258260502256`}, {
            4.023982108724875, -2.1054959219766096`}, {
            4.183534011795195, -2.191746214103809}, {
            4.331574017052271, -2.2717074355831484`}, {
            4.469463925853917, -2.3461303607176647`}, {
            4.56260256907418, -2.396372364400077}}]}, 
          {Arrowheads[{{0.01143116745833942, 1.}}], 
           ArrowBox[{{4.580974813060296, -2.4062829484293258`}, {
            4.599190347158732, -2.4161089980646686`}, {
            4.617022324133486, -2.4257254034403304`}, {
            4.751100940799314, -2.4979963398973974`}, {
            4.878177694035832, -2.566467081436883}, {
            5.001099999999999, -2.6326899280467098`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8449944623942511`, 1.7220483032072487`}, {
            1.9383473862989058`, 1.8276708422380215`}, {2.022504457917634, 
            1.9217097583099683`}, {2.1288937124364264`, 2.039255086901507}, {
            2.2246788835352813`, 2.144114819137112}, {2.3450343405612286`, 
            2.2747849997467564`}, {2.405965940224753, 2.3404995487896483`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.420159106526897, 2.3558068364398443`}, {
            2.453299925268778, 2.3915491109010656`}, {2.588597346043646, 
            2.5365986936696454`}, {2.7102495103431257`, 
            2.6664010019849425`}, {2.7878703569748966`, 2.748931690035018}, {
            2.861668051098933, 2.8272786963388055`}, {2.991483016605742, 
            2.9647390188312044`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.005826212978205, 2.979905810746935}, {
            3.084044982081765, 3.062525387494679}, {3.166062731299937, 
            3.1490650347823452`}, {3.243847229478318, 3.2310406055705148`}, {
            3.317398476616907, 3.3084520998591875`}, {3.414840090559596, 
            3.410897291230954}, {3.5074547716694155`, 3.5081930359159554`}, {
            3.5809083278263256`, 3.585293467439861}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.595307328640511, 3.6004072955452116`}, {
            3.678203335390444, 3.6873361852256634`}, {3.772947259652286, 
            3.786614596784906}, {3.863500548374201, 3.881454326785354}, {
            3.9498632015561888`, 3.971855375227008}, {4.032035219198249, 
            4.057817742109868}, {4.110740318746793, 4.140114412560275}, {
            4.1720557257030535`, 4.204208203517081}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.186485909508149, 4.219292261997388}, {
            4.186702217648231, 4.219518371704571}, {4.330396413509791, 
            4.36964815607483}, {4.464396694140605, 4.509565537911523}, {
            4.590572272586842, 4.641254270679185}, {4.596147929291874, 
            4.647072300860169}, {4.726172542557229, 4.782697476129237}, {
            4.764109553847806, 4.822256018189179}}]}, 
          {Arrowheads[{{0.005435400562620767, 1.}}], 
           ArrowBox[{{4.778558277085847, 4.83732231905159}, {
            4.8494883671732945`, 4.911284153592224}, {4.935632770135761, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.729216175477196, -0.4100595495793919}, {
            1.916372974102345, -0.46556913909807235`}, {
            2.0298084994610344`, -0.4984241355463324}, {
            2.130889540795885, -0.5273271258344037}, {
            2.257722285123884, -0.563168669813463}, {
            2.3709500285429113`, -0.5948608366130033}, {
            2.5122411659961457`, -0.634066439444544}, {
            2.53204293085623, -0.6395231486691076}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.5521676468496675`, -0.6450688525080859}, {
            2.6385763190351748`, -0.6688802148754579}, {
            2.7956327268909096`, -0.711891303501743}, {
            2.9362503968932105`, -0.7502116094415529}, {
            3.1099124038877397`, -0.7973294264342756}, {
            3.265628278978944, -0.8394326438640975}, {
            3.357867295780983, -0.8642958640202117}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.37802274537146, -0.8697288076690909}, {
            3.4609882418388045`, -0.8920923309973587}, {
            3.6361090280065107`, -0.9391814423453103}, {
            3.8272969915645323`, -0.9904820276932854}, {
            4.000828814211779, -1.0369727445914443`}, {
            4.1598036302762464`, -1.0795077194894416`}, {
            4.184493095807387, -1.08610756179395}}]}, 
          {Arrowheads[{{0.01974404653456189, 1.}}], 
           ArrowBox[{{4.204659843117376, -1.0914984177390867`}, {
            4.307320574085929, -1.1189410788369312`}, {
            4.444734041269053, -1.1556431763088024`}, {
            4.574020024528626, -1.1901536663616288`}, {
            4.602353974600109, -1.1977143558697645`}, {
            4.736234411710213, -1.2334197257890247`}, {
            4.863131846017724, -1.2672486858338232`}, {
            4.9870561701796055`, -1.300279855611782}, {
            5.001099999999999, -1.3040218725722734`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.7611261356117491`, 0.6321851892076916}, {
            1.9515060178506283`, 0.7167590925816959}, {2.066973484593915, 
            0.7668787438629582}, {2.1698966382820455`, 0.8110062574191371}, {
            2.2989665695171246`, 0.8657261705852874}, {2.414218663374272, 
            0.9141497726517687}, {2.528318453654569, 0.96170147021522}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.547586931798327, 0.9697317114886623}, {
            2.5579376942865415`, 0.9740454470895917}, {2.6864675647619776`, 
            1.0272678122027896`}, {2.8461517630261484`, 
            1.0930111876155613`}, {2.9891436311725235`, 
            1.1516165330495791`}, {3.1656458169919657`, 
            1.2236649446270056`}, {3.3201460784063936`, 
            1.2865335697286804`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.3394876385588237`, 1.2943861495329363`}, {
            3.5224454011320665`, 1.3686251660402635`}, {3.700414020076609, 
            1.4406792662740229`}, {3.894396343449039, 1.5190652701244054`}, {
            4.0704982528039295`, 1.5901255104176752`}, {4.113558688561292, 
            1.6074804492591044`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.13292015185241, 1.6152838308410122`}, {
            4.231853097993262, 1.6551574456681293`}, {4.381594228869015, 
            1.7154585343900643`}, {4.521092606305768, 1.7715924046959834`}, {
            4.652348756324477, 1.8243805810677514`}, {4.6748458995624995`, 
            1.83342574408649}, {4.81057910575066, 1.8879716184796744`}, {
            4.90757354481726, 1.9269350227973787`}}]}, 
          {Arrowheads[{{0.0019141289875332465`, 1.}}], 
           ArrowBox[{{4.926943922103219, 1.9347162507651086`}, {
            4.939238706667193, 1.9396551592899185`}, {5.001099999999999, 
            1.964501620689337}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.5570504166924266, 3.0893983422093325`}, {
            0.43810485057560605`, 3.205681845547317}, {0.3221397507879902, 
            3.2682714893374287`}, {0.20741697026233563`, 3.298247689161475}, {
            0.1715082204619442, 3.302874609990173}, {0.1338782821397732, 
            3.3060653067121724`}, {0.09798355058868177, 
            3.3073398475597404`}, {0.06205496540466163, 
            3.3078760772009916`}, {-0.048671272198655906`, 
            3.3090512907106766`}, {-0.15912175775935727`, 
            3.3137654172973887`}, {-0.20972995021539903`, 
            3.3214931324724604`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.23036560427771108`, 
            3.3246441333145347`}, {-0.2686491591111473, 
            3.3304899142698416`}, {-0.3718948583182619, 
            3.3640183959979026`}, {-0.4725260544702742, 
            3.4181473242090505`}, {-0.5697074097454183, 
            3.4931853373389523`}, {-0.6847800911392072, 
            3.611747726166557}, {-0.7930199594980908, 
            3.751574457587995}, {-0.8529223976272389, 3.8421816424674065`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-0.8644347522848949, 
            3.8595949912298506`}, {-0.8943664659827745, 
            3.9048690802566504`}, {-0.9740113523998295, 
            4.039648748508911}, {-1.049261543533401, 
            4.176284472667252}, {-1.1204381454198376`, 
            4.312143934565792}, {-1.187949394174024, 
            4.4466175940962085`}, {-1.2521327001861589`, 
            4.578712510640938}, {-1.259602224994958, 4.594508865657997}}]}, 
          {Arrowheads[{{0.010225880998485981`, 1.}}], 
           ArrowBox[{{-1.2685258130781343`, 
            4.613380235523695}, {-1.3132982131610234`, 
            4.7080637321019525`}, {-1.3717679831944554`, 
            4.834272370966}, {-1.4276482070172996`, 
            4.95739217062502}, {-1.4472193711546764`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6950448799747136, 2.4906852518044786`}, {
            0.6201839882016065, 2.6339971006649585`}, {0.5214493320981868, 
            2.7624220778062174`}, {0.4043891948407444, 2.8555234737279807`}, {
            0.29005780145653115`, 2.904912891844068}, {0.25162829744891096`, 
            2.9146568338583108`}, {0.21029132453546925`, 
            2.9223165271501452`}, {0.17196516765961614`, 
            2.9262920834486774`}, {0.1335789976978512, 2.928745130027492}, {
            0.055101952355745415`, 2.9313526929205906`}}]}, 
          {Arrowheads[{{0.0002533205105151725, 1.}}], 
           ArrowBox[{{0.034238624226704935`, 2.9320459203480334`}, {
            0.02366840636131675, 2.932397137799679}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.9546931570212108, 
            0.9860926580116974}, {-1.098993329579987, 
            0.9989753307591598}, {-1.2560621977381987`, 
            1.0336902461668858`}, {-1.4315302485468686`, 
            1.0942114700697652`}, {-1.6272038996938, 
            1.1808106373770626`}, {-1.741255241916567, 
            1.23761117785107}, {-1.7432526692636998`, 1.2386576076165712`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.7617436601504681`, 
            1.2483448301757787`}, {-1.843229452413724, 
            1.291034322042456}, {-1.9684827294549523`, 
            1.3594470717009626`}, {-2.0805671709725484`, 
            1.4224952069778625`}, {-2.2177593258569486`, 
            1.501592401376064}, {-2.3406653749365414`, 
            1.573710290198834}, {-2.4874261394983392`, 
            1.6611236132625273`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.505326014591039, 
            1.6718637842566322`}, {-2.6299967931157457`, 
            1.7469353728872261`}, {-2.78447479399777, 
            1.840818223865187}, {-2.9239783035160194`, 
            1.9261531999047512`}, {-3.0438675117558898`, 
            1.9998460859820266`}, {-3.156516571684047, 
            2.0692496336912862`}, {-3.217876179845684, 
            2.1071532825352444`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2356357977805947`, 
            2.1181239249818917`}, {-3.2619254833004927`, 
            2.1343638430325305`}, {-3.3600942466052257`, 
            2.1951887140057598`}, {-3.5410100714956743`, 
            2.3075910086397062`}, {-3.7055627895715126`, 
            2.4100770853846605`}, {-3.8565672785772165`, 
            2.5043168371254185`}, {-3.9445578754929014`, 
            2.559307107744654}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.9622600543581443`, 
            2.5703701944888278`}, {-3.996838416257262, 
            2.5919801567467764`}, {-4.12762440151242, 
            2.673818559876675}, {-4.250750804959458, 
            2.7509336831370788`}, {-4.266738965088836, 
            2.760951870859691}, {-4.393689964147762, 
            2.84056155312409}, {-4.514075180103087, 
            2.916100294454661}, {-4.631660565874748, 
            2.9898989780536933`}, {-4.669764074825072, 3.01382510060787}}]}, 
          {Arrowheads[{{0.008872584357639669, 1.}}], 
           ArrowBox[{{-4.6874426308351556`, 
            3.0249258970785977`}, {-4.743646291279082, 
            3.0602175461896497`}, {-4.850608134225267, 
            3.127410646220887}, {-4.953121872622484, 
            3.191832925505761}, {-5.001099999999999, 3.2219935297199953`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.0876647195082025`, 2.4782274651150966`}, {
            1.1012423434233731`, 2.5955704987170383`}, {1.113411998108876, 
            2.6985726311610576`}, {1.1283129567759769`, 
            2.8223937007648656`}, {1.1416329753566492`, 2.931554576628139}, {
            1.1585508446208668`, 3.068607779107356}, {1.173562359185195, 
            3.1892824432607427`}, {1.1883010380430574`, 3.307130344982363}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.1908915745464161`, 3.32784382237055}, {
            1.1922190900311571`, 3.338458404307535}, {1.208687097673871, 
            3.4699162712603657`}, {1.2284415948637535`, 
            3.6277038870369887`}, {1.2458541835410792`, 3.767322137094399}, {
            1.2613716484131918`, 3.8923766420251105`}, {1.2754407741874347`, 
            4.006473022421635}, {1.2882482486922011`, 4.111066570655623}, {
            1.2937684938812728`, 4.156475163427594}}]}, 
          {Arrowheads[{{0.01986860138729158, 1.}}], 
           ArrowBox[{{1.2962876658568554`, 4.17719744123298}, {
            1.3004297999078769`, 4.211269927488137}, {1.3127897490563512`, 
            4.314205321177704}, {1.3242599577584757`, 4.410554754878347}, {
            1.3457198541840505`, 4.592274147942992}, {1.364564609536893, 
            4.754594403152754}, {1.3813730927228538`, 4.901787943349132}, {
            1.3925330627390948`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.9164167861576986, -0.9812115286154524}, \
{-1.0583161315511582`, -0.9883489840346203}, {-1.2108922783697598`, \
-1.0157327314068358`}, {-1.3808004014586115`, -1.0680905681049593`}, \
{-1.5708199424360023`, -1.1468169974249078`}, {-1.681888232030177, \
-1.1997126708309078`}, {-1.7099155871223004`, -1.2138816808693755`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.728545131358744, -1.2232997011724198`}, \
{-1.781174827704718, -1.2499062323058971`}, {-1.9032564069903546`, \
-1.3147130905944728`}, {-2.012474793815162, -1.3747184362968967`}, \
{-2.1461701848321444`, -1.450306213374172}, {-2.2659117239559357`, \
-1.5193961507177653`}, {-2.4146091515524395`, -1.6066858059952318`}, \
{-2.456673243510833, -1.6316899384277619`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4746172214115076`, -1.6423563662265277`}, \
{-2.5477506927066296`, -1.6858290507985039`}, {-2.6980752215751003`, \
-1.7761348710577358`}, {-2.8338030727719787`, -1.8582773587142212`}, \
{-2.9508484997293998`, -1.9295043802543}, {-3.0607965602205414`, \
-1.9965886834448527`}, {-3.1636472542454035`, -2.05953026828588}, \
{-3.188793068058419, -2.0749714585495505`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.20658176217016, -2.085894891466224}, \
{-3.2594005818039857`, -2.118329134777381}, {-3.4358061336465644`, \
-2.22699000980672}, {-3.5962042118725286`, -2.3260626056277847`}, \
{-3.7433547837194747`, -2.4171607723718758`}, {-3.8800178164249974`, \
-2.5018983601702955`}, {-3.916912239094087, -2.524806852706397}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.9346465110016213`, -2.5358184204783276`}, \
{-4.007415500264657, -2.5810021563059258`}, {-4.127334934071654, \
-2.655537613724673}, {-4.144433540602229, -2.666170758451336}, \
{-4.268155458571655, -2.743177157759416}, {-4.3854639526221195`, \
-2.8162415397151737`}, {-4.5000385243458805`, -2.8876210865105154`}, \
{-4.609145251416233, -2.9556309629850257`}, {-4.643525703525231, \
-2.977071744025204}}]}, 
          {Arrowheads[{{0.00959540476950521, 1.}}], 
           ArrowBox[{{-4.66123840866562, -2.988117969692636}, \
{-4.713347327318173, -3.020614805729806}, {-4.813207945536697, \
-3.0829162513359574`}, {-4.909122265709538, -3.1427773327753576`}, \
{-5.001099999999999, -3.2001994464261063`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.9430629391233164, -0.5033770907590674}, \
{-1.0253982251449003`, -0.44287861264966866`}, {-1.1073238737314297`, \
-0.3957287758113116}, {-1.192385705649136, -0.36435019829226}, \
{-1.290266880312318, -0.3462940998214004}, {-1.4124501564391492`, \
-0.34057913653556293`}, {-1.5588685878049102`, -0.3471674393094387}, \
{-1.6869214684177187`, -0.3589959532893866}, {-1.737195049805714, \
-0.36488814207341624`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7579279792540161`, -0.3673180929737222}, \
{-1.8013667703396905`, -0.3724092273341625}, {-1.9329266148941247`, \
-0.3903732141883693}, {-2.050620898166966, -0.40771090718872005`}, \
{-2.1905337080438945`, -0.42954546034508306`}, {-2.315842636920681, \
-0.44979396814280853`}, {-2.4691032368930976`, -0.47526642956314125`}, \
{-2.5830892141319217`, -0.4945692988183126}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.6036710248793278`, -0.49805471001989793`}, \
{-2.6063449003961074`, -0.4985075154504893}, {-2.7607394262174014`, \
-0.5250585588936008}, {-2.900109319088598, -0.5492726658919475}, \
{-3.0189407197793914`, -0.5700742608995076}, {-3.130593712168283, \
-0.5896864948223282}, {-3.332364472040362, -0.6253428794137506}, \
{-3.4261582882841704`, -0.6420222493937361}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-3.446710689408745, -0.6456770863122252}, \
{-3.5116527580992534`, -0.6572257452146305}, {-3.6746897297393772`, \
-0.6863190177733841}, {-3.8242708359525106`, -0.7130875090524518}, \
{-3.96319152573043, -0.7379960310142741}, {-4.092692673652742, \
-0.7612556671135425}, {-4.214589097077495, -0.7831761854958131}, \
{-4.249619290402141, -0.7894800682645541}, {-4.26862221266929, \
-0.7929035334495016}}]}, 
          {Arrowheads[{{0.017327843967371324`, 1.}}], 
           ArrowBox[{{-4.289166329730313, -0.7966046520735297}, \
{-4.375859762344464, -0.8122228787939126}, {-4.495553989023074, \
-0.8338036319129081}, {-4.612456826221401, -0.8548872878725989}, \
{-4.723776884459163, -0.8749767495136808}, {-4.931969177316558, \
-0.9125778816226872}, {-5.001099999999999, -0.925073722210046}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.138027568988313, -2.5420645623754243`}, {
            1.156612420545231, -2.6618496045788786`}, {
            1.1734122568431042`, -2.767634059592746}, {
            1.1950666488640367`, -2.9010730831477423`}, {
            1.2145251159625983`, -3.0188069112476477`}, {
            1.2389654164282762`, -3.1642581544429227`}, {
            1.2608538147853876`, -3.292806253041223}, {
            1.2734615043512412`, -3.365989268869137}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.2770055348876324`, -3.3865610668567534`}, {
            1.2883461826523557`, -3.452389369538979}, {
            1.3128863292593056`, -3.5935743737057737`}, {
            1.3424292635685793`, -3.762277407040084}, {
            1.3688333328029383`, -3.912300066930287}, {
            1.3926843596688654`, -4.047301851255424}, {
            1.4145681668728425`, -4.170942257894537}, {
            1.421311563741487, -4.208989686992916}}]}, 
          {Arrowheads[{{0.01876792425920994, 1.}}], 
           ArrowBox[{{1.424954573528284, -4.229544187828}, {
            1.4347319418405584`, -4.284709816497988}, {
            1.4540803621385, -4.393831050749708}, {
            1.4738764941590552`, -4.505495428411703}, {
            1.4924602397624294`, -4.610380428640593}, {
            1.5275879949366094`, -4.808805200580838}, {
            1.5590937384277963`, -4.987131006287903}, {
            1.5615557364311934`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.4852125570901163, 1.3977656388585558`}, {
            0.42284227601326063`, 1.4313601605477593`}, {0.3603508394963014, 
            1.4564612737847316`}, {0.26601101310954206`, 
            1.4819224081447857`}, {0.1705753929880579, 1.4960802126015014`}, {
            0.07391966606697768, 1.5021756922321448`}, {-0.05320719287001094, 
            1.5030947555607952`}, {-0.17988815472407793`, 
            1.5015182753822454`}, {-0.3032265854185235, 
            1.5027790763971782`}, {-0.33173982224626397`, 
            1.5049815860930975`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.3525526633162361, 
            1.5065892774447731`}, {-0.45146600123475833`, 
            1.514229854596271}, {-0.5847475394495218, 
            1.5386572198223216`}, {-0.7034001081266168, 
            1.5737522773356103`}, {-0.8077526153298451, 
            1.6172061323964169`}, {-0.9822308816392373, 
            1.717752321725957}, {-1.0749973877905314`, 
            1.784436017010768}, {-1.1124042406923778`, 
            1.8143374972094293`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.1287098560567117`, 
            1.8273715269959754`}, {-1.157798460103196, 
            1.8506237455182055`}, {-1.2553776321582857`, 
            1.9358526939691736`}, {-1.3425522839451198`, 
            2.0173548907969483`}, {-1.447422104220141, 
            2.1211880947275685`}, {-1.5411971547819034`, 
            2.2181399579593624`}, {-1.654930167771486, 
            2.340122529984351}, {-1.721863234833494, 2.413901307194992}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.7358892695757104`, 
            2.4293618820321807`}, {-1.7567404397052602`, 
            2.452345646307379}, {-1.8822423191005877`, 
            2.593961978554547}, {-1.9945804876524817`, 
            2.722963752232592}, {-2.1225600008561503`, 
            2.872128942366658}, {-2.2379584803998873`, 
            3.008074441485712}, {-2.282285165361233, 
            3.0607108673523578`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.2957316232886593`, 
            3.0766780773181637`}, {-2.3364440002335094`, 
            3.1250226357434387`}, {-2.428934449021099, 
            3.2352729123158825`}, {-2.515429826762655, 
            3.3388252712030435`}, {-2.5959301334581775`, 
            3.435679712404921}, {-2.6717431642195093`, 
            3.5272252639890755`}, {-2.7441767141584923`, 
            3.614850954023066}, {-2.829691772862648, 3.718622569887483}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.842967248328694, 
            3.734732218426063}, {-2.8789053715694117`, 
            3.778342749440557}, {-3.0024508388111357`, 
            3.928769071408705}, {-3.117147849003864, 
            4.068743892678821}, {-3.2240295947567734`, 
            4.199452738925644}, {-3.324606872206107, 
            4.322635723838553}, {-3.3300980501401565`, 
            4.329365971762299}, {-3.3719810159230574`, 
            4.380764244284414}}]}, 
          {Arrowheads[{{0.01865259447243206, 1.}}], 
           ArrowBox[{{-3.385167636107082, 
            4.396946706180196}, {-3.4336437758391507`, 
            4.456436042577338}, {-3.5317921169346835`, 
            4.5770061858237865`}, {-3.6276422667327486`, 
            4.69479784397813}, {-3.718896033935879, 
            4.807032531948267}, {-3.8060281395385385`, 
            4.9142757122001015`}, {-3.8765274779292755`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.9182409939775533, 
            0.5408268457064273}, {-1.0313522810232707`, 
            0.46360760311755383`}, {-1.1174998862098036`, 
            0.418864848051347}, {-1.207250845224958, 
            0.38990396048867404`}, {-1.310615899529294, 
            0.37450948785102606`}, {-1.4390609752544965`, 
            0.37206047231389533`}, {-1.5980863470833213`, 
            0.3829572325327596}, {-1.7116324807425072`, 
            0.39592376854109246`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7323520918585595`, 
            0.39845510163304476`}, {-1.8384905399160212`, 
            0.4129680836147241}, {-1.9706054185761956`, 
            0.4333842328470055}, {-2.0888184433552763`, 
            0.45287422317645276`}, {-2.2300597817130554`, 
            0.47735565560477144`}, {-2.3565776167793184`, 
            0.499974778735624}, {-2.5116785052483594`, 
            0.5284125033987578}, {-2.5557369432338928`, 
            0.5366289998599723}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.5762579859567234`, 
            0.5404559869848434}, {-2.6505852271753496`, 
            0.5543173389157766}, {-2.8069719418578867`, 
            0.5838935104488607}, {-2.9481592587844943`, 
            0.610847351433608}, {-3.068529111330555, 
            0.633986384426027}, {-3.181638675032805, 
            0.655798896139747}, {-3.386076935905874, 
            0.6954443557310902}, {-3.3963579383300413`, 
            0.6974497130715215}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.4168466584191313`, 
            0.7014461332192412}, {-3.567771909312818, 
            0.7308848053690146}, {-3.733021463162753, 
            0.7632213202148969}, {-3.8846521055180414`, 
            0.7929719052919325}, {-4.025490344441045, 
            0.8206545656233173}, {-4.156791313294189, 
            0.8465042036495629}, {-4.236227454142678, 
            0.8621609454031258}}]}, 
          {Arrowheads[{{0.018174792458375246`, 1.}}], 
           ArrowBox[{{-4.256708269000087, 
            0.8661976826577289}, {-4.280390844517595, 
            0.870865482036907}, {-4.313839785834878, 
            0.8774625164542393}, {-4.441770259422882, 
            0.9027198642907005}, {-4.563074618896194, 
            0.9266870603217225}, {-4.681553124633875, 
            0.950102396955639}, {-4.794379922900295, 
            0.9724140147953444}, {-5.001099999999999, 
            1.0133234150189598`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7412883862359739, -2.032935734476347}, {
            0.6814001424990701, -2.169203930153757}, {
            0.6073059300360826, -2.292561051682315}, {
            0.5033412834554103, -2.4102572097232957`}, {
            0.40372751951174135`, -2.4805484999063494`}, {
            0.3124319595855857, -2.5196236595815042`}, {
            0.2218780891292483, -2.5414168788332088`}, {
            0.15147322756574993`, -2.549309659111088}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.1307244981884948, -2.551587415770212}, {
            0.09787768491335741, -2.553178165461533}, {
            0.06424002921747, -2.554063064671503}, {
            0.05855163450514955, -2.5541519974995377`}, {
            0.025037502228016123`, -2.5542608901579618`}, \
{-0.00849978423202246, -2.5542135098899994`}, {-0.09576847672254063, \
-2.554876419308798}, {-0.1826503435080683, -2.5589257369168044`}, \
{-0.2685647302491305, -2.569713840834299}, {-0.35158022539989525`, \
-2.58945294401691}, {-0.43228348289451357`, -2.6196683369626745`}, \
{-0.51007948081854, -2.66059342665099}, {-0.6073083899210378, \
-2.7291701506670547`}, {-0.6492535027721313, -2.7670143170605943`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.6647524479635705, -2.7809979404407823`}, \
{-0.6983779803812067, -2.8113359263797375`}, {-0.7833197877612748, \
-2.903054189310273}, {-0.9150275960485003, -3.0703729796304526`}, \
{-1.0326013996873582`, -3.2426321048856956`}, {-1.1384317007907263`, \
-3.4126444105949214`}, {-1.1602545589469953`, -3.4496237108935968`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.1708639147739601`, -3.4676014914524704`}, \
{-1.2091123871732887`, -3.532414346702325}, {-1.275413261174231, \
-3.6486224875605684`}, {-1.3378311789106847`, -3.761146843763051}, \
{-1.3968629964997803`, -3.8698654259031717`}, {-1.4528646942304606`, \
-3.9748981130883485`}, {-1.5061922523916693`, -4.0763647844260005`}, \
{-1.5705301456467553`, -4.200593459474683}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-1.5801301406060426`, -4.219129886359815}, \
{-1.5898795140672215`, -4.237954745029573}, {-1.6679460677452427`, \
-4.391033216498218}, {-1.7411211398044173`, -4.536387792356151}, \
{-1.81013395662343, -4.674806066127589}, {-1.8754608597512026`, \
-4.806923192606512}, {-1.937578190736657, -4.933374326586902}, \
{-1.9535096896268886`, -4.96597496433027}}]}, 
          {Arrowheads[{{0.0004364115478441454, 1.}}], 
           ArrowBox[{{-1.962675071389248, -4.984730091683513}, \
{-1.9706748282722355`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3222458553406427, -1.4291648971223179`}, {
            0.22776288788560795`, -1.449579976892015}, {
            0.13196608987815114`, -1.4601918147056387`}, {
            0.034939154787236366`, -1.463960695650532}, \
{-0.06615248328345928, -1.4636365105820202`}, {-0.16691849952338722`, \
-1.4619179853223254`}, {-0.2658291438803408, -1.4614185738264698`}, \
{-0.41006195811126567`, -1.46780938139919}, {-0.5089227075437018, \
-1.480628281523024}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.529624244001007, -1.4833125715954707`}, \
{-0.541185125865146, -1.4848116274979462`}, {-0.6588733370821988, \
-1.5112674412612905`}, {-0.7628012817026342, -1.546018951827774}, \
{-0.936914712092445, -1.6306520349555405`}, {-1.109318727359729, \
-1.7458157818375746`}, {-1.2044811841356267`, -1.820968081458351}, \
{-1.2583826990139466`, -1.8670954773115078`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.2742428003235298`, -1.880668104593502}, \
{-1.2894497952571875`, -1.893681821863328}, {-1.3913942306068916`, \
-1.987018927416656}, {-1.4825073201691648`, -2.074830649604866}, \
{-1.593073826529768, -2.1861230510841247`}, {-1.6919877181036918`, \
-2.288975882736355}, {-1.812462468537949, -2.417767081214208}, \
{-1.8626511875059546`, -2.472535739525429}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.876754406624334, -2.48792593885439}, \
{-1.9203599036107537`, -2.535510627486563}, {-2.0537822442709315`, \
-2.683706763452743}, {-2.1732603392755854`, -2.818183627637211}, \
{-2.3091001512604064`, -2.972810535935074}, {-2.4308602311727165`, \
-3.112539349739757}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4445298108998617`, -3.128315958902391}, \
{-2.536270074459612, -3.2342350246766967`}, {-2.634540386557298, \
-3.348026837338872}, {-2.726481537547306, -3.4548447481067037`}, \
{-2.8120935274296364`, -3.5546887569801915`}, {-2.8927527145950873`, \
-3.649018860076993}, {-2.9698354574344576`, -3.739295053514766}, \
{-2.9888025672662253`, -3.761543317397645}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.0023453599085355`, -3.7774289018166574`}, \
{-3.043341755947747, -3.825517337293512}, {-3.113271610134956, \
-3.9076857114132295`}, {-3.244864862331087, -4.062577967668215}, \
{-3.367078090822805, -4.206689059272355}, {-3.481003122209475, \
-4.341246180950312}, {-3.5426033176106935`, -4.414088020632747}}]}, 
          {Arrowheads[{{0.01789631319833358, 1.}}], 
           ArrowBox[{{-3.556082769596759, -4.430027386963988}, \
{-3.588236935243824, -4.46804948354876}, {-3.593587735160158, \
-4.474380372146045}, {-3.70392729060119, -4.60505985867887}, \
{-3.8085409149044493`, -4.729058711960256}, {-3.910714618634581, \
-4.850202097391869}, {-4.008008481218455, -4.965634547123933}, \
{-4.037883670933371, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9002437377811451, 3.4001588045881146`}, {
            0.8867017308905673, 3.507808258012394}, {0.8678021704804637, 
            3.6352322415840916`}, {0.8488699958011013, 3.7437685238295617`}, {
            0.8223288818872273, 3.8726624534313787`}, {0.7959290521250018, 
            3.981008105803107}, {0.7311510358886222, 4.188323774369254}, {
            0.7204368246691291, 4.213312345218915}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7122106928426246, 4.2324980112240125`}, {
            0.667393411406788, 4.337024587143206}, {0.6358465282420129, 
            4.395835412627323}, {0.6040673452505271, 4.447434785239321}, {
            0.5682294250781577, 4.493850987128613}, {0.5324654228593416, 
            4.5334067015527575`}, {0.4612171245579692, 4.601155711704945}, {
            0.3904348925059902, 4.648890378755792}, {0.31995454936151757`, 
            4.681291203213954}, {0.16472341657601994`, 4.713474104491168}, {
            0.10259681418132117`, 4.715619788556476}}]}, 
          {Arrowheads[{{0.019551696559896966`, 1.}}], 
           ArrowBox[{{0.08173441114708115, 4.716340319279696}, {
            0.009427855181574086, 4.718837591285122}, {-0.1458322697765795, 
            4.722527756508177}, {-0.300442494225337, 
            4.749559453662213}, {-0.44339553409212895`, 
            4.815871444012165}, {-0.5832661218458819, 
            4.929436112361655}, {-0.6439646632191394, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6706513066585248, -3.423592779445496}, {
            0.5764906001177376, -3.5888947398790556`}, {
            0.4509011639726265, -3.724485791382572}, {
            0.3345945725709569, -3.7931020666113104`}, {
            0.21934405666924578`, -3.82654154602437}, {
            0.10445054646337867`, -3.838771393231619}, {
            0.07159837981262873, -3.8400888737869883`}, {
            0.037835517496494844`, -3.840731860964766}, {
            0.01513134205089051, -3.8407453675781373`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-0.0057434586288114126`, -3.8407805123259684`}, \
{-0.027818564067744432`, -3.8408403070805046`}, {-0.13877947656626058`, \
-3.8446057129508264`}, {-0.2491455858385248, -3.859698034041841}, \
{-0.35824825334162297`, -3.8938939002032567`}, {-0.46794517423280746`, \
-3.954097503003137}, {-0.574580019557314, -4.041270931192111}, \
{-0.6774122081321096, -4.1532342107949125`}, {-0.7148188790412657, \
-4.2017726462404035`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-0.727561344869411, -4.218307112954051}, \
{-0.7427617662908392, -4.238030992571675}, {-0.806161340138447, \
-4.329984075085166}, {-0.86758896416645, -4.427574632383165}, \
{-0.9270226728663657, -4.529283838513455}, {-0.9844940545165884, \
-4.6341324049268415`}, {-1.0400599680182276`, -4.7403576122347815`}, \
{-1.1299176017470778`, -4.923702382204547}, {-1.1390373130670552`, \
-4.9433471192075755`}}]}, 
          {Arrowheads[{{0.0010251056673511126`, 1.}}], 
           ArrowBox[{{-1.1478271049808288`, -4.962281178016999}, \
{-1.1658480359921213`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.6140104710089676`, 0.9667002125771209}, {
            1.7689449123235705`, 1.0886170564309219`}, {1.8629878607884165`, 
            1.1605519802401032`}, {1.9473846584410106`, 
            1.2241209652118963`}, {2.0551308339308285`, 1.30413426418019}, {
            2.1517393702262617`, 1.3750397817784608`}, {2.27435410023576, 
            1.4640785147765247`}, {2.2810147651693002`, 
            1.4688737577380693`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.297955941831912, 1.481070296516442}, {
            2.384216599995501, 1.543172326575668}, {2.5227747393718434`, 
            1.6421543448125075`}, {2.6468797210264507`, 
            1.7302659651549945`}, {2.802714563745633, 1.8402957343921602`}, {
            2.9422793289945086`, 1.9384098834564014`}, {2.9790202161077053`, 
            1.9641388668572213`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.996119286966124, 1.976113039090196}, {
            3.1154466081814194`, 2.059675819089318}, {3.2706735815523227`, 
            2.168050147937558}, {3.370546097864448, 2.2376221538485774`}, {
            3.4653647425583065`, 2.303610808451797}, {3.6398404170912197`, 
            2.424838063734834}, {3.681175353625851, 2.453513599827179}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.698327012169044, 2.465412323880786}, {
            3.7375057484960035`, 2.4925920261322925`}, {3.8307457747703832`, 
            2.557236386644426}, {4.003949911927934, 2.67719630201272}, {
            4.1625683789193895`, 2.7869291515839247`}, {4.3097167261002705`, 
            2.888646277102249}, {4.384923520075557, 2.9405958940831707`}}]}, 
          {Arrowheads[{{0.01743075352988946, 1.}}], 
           ArrowBox[{{4.402099107647192, 2.952460050878126}, {
            4.446754382227737, 2.9833059929535115`}, {4.575664007323207, 
            3.072304456486981}, {4.58867330975663, 3.081283613659818}, {
            4.721823380450148, 3.173143201190377}, {4.848006566943779, 
            3.2601643532728346`}, {4.971224560240684, 3.345128943692613}, {
            5.001099999999999, 3.365723388394855}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.265995350656746, 2.44426583578739}, {
            1.2937467512730987`, 2.5480124024089066`}, {1.3298777373923427`, 
            2.679593086466185}, {1.3626659691075524`, 2.7962744698798936`}, {
            1.4043810676480575`, 2.9415672029113007`}, {1.4421345790897222`, 
            3.0706677346190823`}, {1.489783605334331, 3.230865737538752}, {
            1.4947356109219612`, 3.24727835980644}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5007654690316572`, 3.267263350075717}, {
            1.532820417899255, 3.3735042979632004`}, {1.5874640255983294`, 
            3.552247898491069}, {1.636697855377467, 3.7115344240225685`}, {
            1.694525094205837, 3.896781974708407}, {1.7468873203103752`, 
            4.0632102135421455`}, {1.747447811489582, 4.0649797919244275`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7537510275518098`, 4.084880256546115}, {
            1.794761859588495, 4.214359335796269}, {1.83912603793761, 
            4.353769536743263}, {1.8804016307642415`, 4.482917581003715}, {
            1.9192021993375092`, 4.603940329866373}, {1.920443109706685, 
            4.607805024719056}, {1.961017162694275, 4.733826660183206}, {
            1.9994237662116419`, 4.8528471679365435`}, {2.0082400865669428`, 
            4.880145781366273}}]}, 
          {Arrowheads[{{0.0025446088592554583`, 1.}}], 
           ArrowBox[{{2.01465551990699, 4.900010353849606}, {
            2.036908304625868, 4.968913268364319}, {2.0473220348325203`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.222922646463632, -1.2142449128679924`}, \
{-1.39840544498094, -1.2957789535343938`}, {-1.5005164823774015`, \
-1.3513094877695038`}, {-1.5917168293819564`, -1.404596775686575}, \
{-1.703985961628926, -1.47420218820263}, {-1.804352542202457, \
-1.539172229574376}, {-1.9276017237112262`, -1.621889165437998}, \
{-1.9436968231602116`, -1.6329771548995047`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.960887287262341, -1.6448197462054464`}, \
{-2.037891367552917, -1.6978682180997127`}, {-2.173256787173407, \
-1.793207925247363}, {-2.2945050656462675`, -1.879989320126957}, \
{-2.443040020573121, -1.9877714319005713`}, {-2.5762339858160916`, \
-2.0854004141027382`}, {-2.6390713432752038`, -2.1318615028364145`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.655856339066816, -2.144272100773731}, \
{-2.741668241326725, -2.207720255924072}, {-2.8899814940631376`, \
-2.3180961270766733`}, {-3.0582846358766402`, -2.444046551106975}, \
{-3.210356978871603, -2.5583068590671574`}, {-3.3245334077785844`, \
-2.6443515808342273`}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-3.3412033375595804`, -2.656916311012971}, \
{-3.46061292816857, -2.747036359309156}, {-3.5742274384978923`, \
-2.832924862762141}, {-3.6801663059477745`, -2.913162535103117}, \
{-3.7800828207204464`, -2.988944166410295}, {-3.8756302730181384`, \
-3.061464546761885}, {-3.966808662840851, -3.130723676157887}, \
{-4.006783589746367, -3.161115115041022}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-4.023401247817699, -3.1737488977330934`}, \
{-4.053617990188584, -3.1967215545983017`}, {-4.217111371675006, \
-3.321129493261405}, {-4.369092331693304, -3.4368842974002325`}, \
{-4.510889572823454, -3.5449734294767463`}, {-4.6444481524538705`, \
-3.6468444775881563`}, {-4.65417325684431, -3.654264479671892}, \
{-4.687593002169473, -3.679776137682806}}]}, 
          {Arrowheads[{{0.00894821786951335, 1.}}], 
           ArrowBox[{{-4.704185779809927, -3.692442579766542}, \
{-4.791530241828616, -3.7591187923614435`}, {-4.92183898785807, \
-3.8586348177935075`}, {-5.001099999999999, -3.9191756733884096`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.2064347641710036`, 
            1.2110476120845013`}, {-1.3803458019033799`, 
            1.290338583206633}, {-1.4815135751488129`, 
            1.3446877169544227`}, {-1.5718629767338799`, 
            1.3970085964206733`}, {-1.6831094871060137`, 
            1.4655495302131694`}, {-1.7825528130767778`, 
            1.529649529212843}, {-1.9046843954545927`, 
            1.611404809461452}, {-1.9282999600850343`, 
            1.627651282573207}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.9454980417503929`, 
            1.6394828087603828`}, {-2.0139637655530502`, 
            1.6865842250611758`}, {-2.148092174891669, 
            1.7810172318902935`}, {-2.2682213901133776`, 
            1.8670273901469796`}, {-2.415382597535491, 
            1.9739142609165523`}, {-2.547333202482086, 
            2.0707660303254625`}, {-2.6233080962975586`, 2.12703957028451}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.6400826648910978`, 
            2.13946425834445}, {-2.7112305506536685`, 
            2.192162501032173}, {-2.8581530866833718`, 
            2.301725180104963}, {-3.024827314466675, 
            2.42673807003184}, {-3.17542020469204, 
            2.5401601645103455`}, {-3.3032879160802167`, 
            2.636767071910223}, {-3.3081077428901726`, 
            2.6404140890000565`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.3247541721310068`, 
            2.6530099382535237`}, {-3.4235352934045737`, 
            2.7277546234138796`}, {-3.5361623366651127`, 
            2.813122819021316}, {-3.641169045861832, 
            2.892871658732532}, {-3.7401982718820634`, 
            2.9681894698750084`}, {-3.8348928656131376`, 
            3.0402645797762267`}, {-3.925252827055054, 
            3.1090969884361868`}, {-3.98960887267269, 3.1581650273993356`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.006209048256548, 
            3.170821772457653}, {-4.011278156207814, 
            3.174686695854888}, {-4.173285529686539, 
            3.298321957090003}, {-4.323875598089994, 
            3.413354313603058}, {-4.464366979963804, 
            3.520765754658707}, {-4.596689816422302, 
            3.62199580843538}, {-4.606553625349633, 
            3.629544205462228}, {-4.669639168681977, 
            3.6778471375612685`}}]}, 
          {Arrowheads[{{0.009500719363478296, 1.}}], 
           ArrowBox[{{-4.6862135206719415`, 
            3.6905376805362136`}, {-4.74265823871955, 
            3.733755908345394}, {-4.87177395860835, 
            3.8326596596069287`}, {-4.997906364798618, 
            3.9292939965771634`}, {-5.001099999999999, 
            3.93174161070183}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7651765845908715, -2.46143901848966}, {
            0.7102338041054285, -2.6209100457104713`}, {
            0.6380530955496823, -2.7740814632556825`}, {
            0.5469858734513154, -2.9073900290251284`}, {
            0.42350339819199445`, -3.019489483907492}, {
            0.30328826381698504`, -3.0778193383947254`}, {
            0.26946233913997547`, -3.0874008613950394`}}]}, 
          {Arrowheads[{{0.01078575278652153, 1.}}], 
           ArrowBox[{{0.2491174639942479, -3.092032307006481}, {
            0.2234029487038612, -3.097418379543304}, {
            0.18467078787351404`, -3.102082496396871}, {
            0.14588568230773008`, -3.105036613946372}, {
            0.030418144872386067`, -3.109663743290405}, \
{-0.08499392834130784, -3.111032780022051}, {-0.1998548522213967, \
-3.1190360037430422`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7038745886063241, -2.983116236448083}, {
            0.6260946764297822, -3.1464065535105528`}, {
            0.5222736215953372, -3.2913947228486142`}, {
            0.4044267911323498, -3.3901330205963376`}, {
            0.2887439829550292, -3.442199046417547}, {
            0.17392210539473468`, -3.4655507211507444`}, {
            0.13901826705788042`, -3.4686643518984277`}, {
            0.10270985228771856`, -3.470635750853643}, {
            0.09609249620583646, -3.4707520187346246`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.075220875681952, -3.4711187360550984`}, {
            0.06781017832035716, -3.4712489430544147`}, {
            0.03288852655002709, -3.471410373352115}, {-0.07800936713420664, \
-3.472711766590436}, {-0.1885216996173194, -3.480110703207512}, \
{-0.2979757666914744, -3.501969907051176}, {-0.40186683494365255`, \
-3.5427267705762535`}, {-0.5030532164255779, -3.6056533233117274`}, \
{-0.6007584483206432, -3.690359708133321}, {-0.6663989619593871, \
-3.764884410506828}}]}, 
          {Arrowheads[{{0.006143300640804327, 1.}}], 
           ArrowBox[{{-0.6801964260838594, -3.780549307845147}, \
{-0.7209439503585762, -3.826811851367325}, {-0.833868502276967, \
-3.9855807025374945`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.4168366197126507`, -0.8827457631093427}, \
{-1.6120948612622952`, -0.9434243656177664}, {-1.726400430223994, \
-0.9858550654803444}, {-1.828616146495635, -1.0265763663838694`}, \
{-1.953866099145224, -1.0793692219237951`}, {-2.065942804332934, \
-1.1284448235231583`}, {-2.1937956594576455`, -1.1862116860190475`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.2127822615009887`, -1.1948869737823404`}, \
{-2.3258330014338253`, -1.2470886739150782`}, {-2.475891503402646, \
-1.317654412209269}, {-2.610429035098003, -1.381745885780351}, \
{-2.7773100627752427`, -1.4621277500744956`}, {-2.9268918157723065`, \
-1.5347601416849588`}, {-2.9665213207216836`, -1.5541349288260007`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.985274884545114, -1.5633035093489986`}, \
{-3.0962847055926175`, -1.617575992846029}, {-3.249330450378595, \
-1.692762064405764}, {-3.3794021791605706`, -1.756892433204257}, \
{-3.5017121896139947`, -1.817300228358014}, {-3.6162604817388657`, \
-1.873985449867034}, {-3.7230470555351847`, -1.9269480977313178`}, \
{-3.734213719004247, -1.9324954642825354`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.752908768014862, -1.9417827764543572`}, \
{-3.8237462857267768`, -1.9769733844112527`}, {-3.920032547037468, \
-2.024846522367226}, {-4.099366163016148, -2.1141363521072876`}, \
{-4.2640641691379, -2.196265210243513}, {-4.417142831069401, \
-2.272680720067912}, {-4.500247604812204, -2.3142055718987775`}}]}, 
          {Arrowheads[{{0.01291431960952581, 1.}}], 
           ArrowBox[{{-4.518921105201389, -2.3235361350169}, \
{-4.55994518905912, -2.344034584467727}, {-4.6944369304083855`, \
-2.4112822627864725`}, {-4.711848320801245, -2.419991291876622}, \
{-4.850404473466465, -2.489337328972864}, {-4.981839942915418, \
-2.555150551171305}, {-5.001099999999999, -2.564796248818783}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.419828330788002, 
            0.8947076345938167}, {-1.6152863752613855`, 
            0.9570286191703207}, {-1.7296618868381997`, 
            1.0003386304471111`}, {-1.8319393740340784`, 
            1.0418248024115684`}, {-1.9572868338441198`, 
            1.0955449714997518`}, {-2.0694519224945767`, 
            1.1454429468170757`}, {-2.194911709313909, 
            1.2029975275666236`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.2138581643915916`, 
            1.2117601782864893`}, {-2.3296060594613843`, 
            1.2660059893214253`}, {-2.479840530711221, 
            1.3376884906687592`}, {-2.614538071351551, 
            1.4027826084094157`}, {-2.7816315584369806`, 
            1.4844156951536713`}, {-2.9314063325196837`, 
            1.558171934164215}, {-2.9656175644417804`, 
            1.5751331332268312`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.9843200635975173`, 
            1.5844054333846043`}, {-3.101036202615031, 
            1.6422708055583968`}, {-3.2542977079697564`, 
            1.7186179897243183`}, {-3.384529400084601, 
            1.7837242050780628`}, {-3.506991722811888, 
            1.8450509436884757`}, {-3.621684676151616, 
            1.902598205555557}, {-3.728608260103786, 
            1.9563659906793065`}, {-3.7312294122375076`, 
            1.9576862015775642`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.7498729460003304`, 
            1.9670764983631113`}, {-3.8294382540364933`, 
            2.0071516185521237`}, {-3.925850437317833, 
            2.0557524086664083`}, {-4.105421371926411, 
            2.146399475619378}, {-4.270340230911412, 
            2.229776870962031}, {-4.423626181254728, 
            2.307354274118183}, {-4.495158771836758, 
            2.3435909257862813`}}]}, 
          {Arrowheads[{{0.01308816485918871, 1.}}], 
           ArrowBox[{{-4.51378056269492, 
            2.353024267194343}, {-4.566623653920733, 
            2.3797932779939655`}, {-4.70130040007312, 
            2.4480638372131787`}, {-4.718417860041226, 
            2.4567441035353195`}, {-4.8571533006945655`, 
            2.5271384986263388`}, {-4.988759893065342, 
            2.5939469281190735`}, {-5.001099999999999, 2.600212309685548}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.413472691795047, -2.2781413175728855`}, {
            2.532257210436616, -2.401751547794765}, {
            2.6406238060438008`, -2.5140491664350386`}, {
            2.7406683790968964`, -2.6174060561968244`}, {
            2.8333808496171713`, -2.7129052349537357`}, {
            2.919751137625893, -2.801629720579387}, {
            2.9942768032693228`, -2.8780383762811867`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0088531440440835`, -2.8929812439333}, {
            3.0906641441911615`, -2.9767135315480453`}, {
            3.1690814237049896`, -3.056863602527194}, {
            3.2436305742568807`, -3.132972689429308}, {
            3.382611792497203, -3.2746558893916613`}, {
            3.511443914564895, -3.405822433410245}, {
            3.59342092407189, -3.4892146130646204`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.608054813378324, -3.504101127386422}, {
            3.632475752090377, -3.5289436450709712`}, {
            3.745707305073649, -3.6440195243738396`}, {
            3.85113857351471, -3.7510500713188493`}, {
            3.9504766909107993`, -3.851812480459999}, {
            4.045428790759154, -3.9480839463512876`}, {
            4.135994873059774, -4.039864468992714}, {
            4.194182631530235, -4.0988013585992435`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.208848663874167, -4.113656206971843}, {
            4.22217493781266, -4.127154048384278}, {
            4.304725251183317, -4.210732711323576}, {
            4.384402079337251, -4.291380484608204}, {
            4.535135279994948, -4.443883362213452}, {
            4.675712361552957, -4.586035936135749}, {
            4.795860812590972, -4.707483721168097}}]}, 
          {Arrowheads[{{0.006487947232966542, 1.}}], 
           ArrowBox[{{4.8105421905101995`, -4.7223234033325925`}, {
            4.813570549772779, -4.725383937081413}, {
            4.949924923597754, -4.863141080180295}, {
            5.001099999999999, -4.9148283124402266`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.114712753184768, -2.5115120108306286`}, {
            2.2239596613190025`, -2.660582762399053}, {
            2.3223923467422622`, -2.7939534572672087`}, {
            2.445345712409116, -2.95949636707598}, {
            2.5560534651998377`, -3.10779664345989}, {
            2.611906546708146, -3.1823350768329846`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6244241722750763`, -3.1990404075705756`}, {
            2.6263733321362186`, -3.2016416485141335`}, {
            2.6932764470014248`, -3.290781287551426}, {
            2.8168324205183137`, -3.4549444675751584`}, {
            2.896533030609213, -3.5605550611283303`}, {
            2.9723147060716184`, -3.660854464616567}, {
            3.0441774469055294`, -3.755842678039869}, {
            3.1121212531109457`, -3.8455197013982354`}, {
            3.127343322169234, -3.865587608653616}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.139958815677114, -3.8822191554379297`}, {
            3.1899581127762695`, -3.9481353757085063`}, {
            3.2643656622352264`, -4.046154231623437}, {
            3.335343901487817, -4.13957626914303}, {
            3.40289283053404, -4.228401488267283}, {
            3.5300664710721157`, -4.395471007089299}, {
            3.645412147964454, -4.546847612484092}}]}, 
          {Arrowheads[{{0.01318786341666409, 1.}}], 
           ArrowBox[{{3.6580697569727803`, -4.563447128856464}, {
            3.7584897650254647`, -4.69511302645268}, {
            3.862313179058576, -4.831148027843667}, {
            3.8665970844119437`, -4.836759170884908}, {
            3.9736345497068157`, -4.9768766535973565`}, {
            3.992148067327879, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0398972475576116`, -3.1391543701428266`}, {
            2.138916058411275, -3.318697977728905}, {
            2.228223058799502, -3.479569158616258}, {
            2.2860726780787033`, -3.5832669547891993`}, {
            2.3411076186939677`, -3.6817046925314703`}, {
            2.4427334639326843`, -3.8627999927239998`}, {
            2.4460582289029826`, -3.868703705401093}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{2.4563015432506803`, -3.8868925353816173`}, {
            2.5003047973461183`, -3.96502815439751}, {
            2.5553291718722027`, -4.062591140087499}, {
            2.6577370442623236`, -4.243721583516915}, {
            2.751721707861973, -4.409500790769241}, {
            2.839047789430077, -4.563238229601471}, {
            2.8676623792917795`, -4.613525475940338}}]}, 
          {Arrowheads[{{0.010185500621413745`, 1.}}], 
           ArrowBox[{{2.877986279976707, -4.631668686778939}, {
            2.9204928052281875`, -4.706369603921607}, {
            2.9971924912227075`, -4.840986905282526}, {
            3.000111277490207, -4.846106531274291}, {
            3.079391709445381, -4.985011992865614}, {
            3.088582405709609, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.9940997195218677`, 2.216010928980815}, {
            3.1418053758159465`, 2.3320828326044203`}, {3.235669151113101, 
            2.405663259078993}, {3.3248390055124357`, 2.4754913556792943`}, {
            3.4890969516176478`, 2.6038905592570796`}, {3.5951861918035735`, 
            2.6866775661056788`}, {3.651616530510996, 2.7306806569507334`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.6680781700765612`, 2.7435170679639254`}, {
            3.6959286838739853`, 2.7652342633021183`}, {3.791324427828883, 
            2.839560650846398}, {3.8813734236682667`, 2.909656728738518}, {
            3.9844997900551133`, 2.9898743928528493`}, {4.082991992926131, 
            3.066450889029396}, {4.176850032281322, 3.1393862172681595`}, {
            4.266073908120684, 3.208680377569138}, {4.327202748603802, 
            3.2561270195900742`}}]}, 
          {Arrowheads[{{0.01992430120018376, 1.}}], 
           ArrowBox[{{4.343693156399303, 3.2689264522190715`}, {
            4.43385966665991, 3.338911390601693}, {4.589589765951799, 
            3.4597101243710116`}, {4.734684638466959, 3.5721955126452962`}, {
            4.871217550717943, 3.677999395374719}, {4.880623642722955, 
            3.6852869969267266`}, {5.001099999999999, 
            3.778595719295087}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.6425352103687625`, -1.9862761352435359`}, {
            2.771090937595777, -2.090804462793426}, {
            2.9316615283054492`, -2.220779611786239}, {
            3.075697597364524, -2.336959366563102}, {
            3.1672612948660164`, -2.410622349947117}, {
            3.254251614997465, -2.4805285374395347`}, {
            3.2921286543309085`, -2.5109090096186217`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.308412620069896, -2.5239700771361586`}, {
            3.4145121231502302`, -2.609070524749576}, {
            3.5180252509489844`, -2.6919450065163675`}, {
            3.6163265559284086`, -2.7705850219806605`}, {
            3.709416038088502, -2.8449905711424543`}, {
            3.7972936974292653`, -2.9151616540017495`}, {
            3.8984775831138894`, -2.995895535058921}, {
            3.960570670232688, -3.0454139729909695`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.9768911694996283`, -3.05842936113593}, {
            3.9950983377712586`, -3.0729493435335216`}, {
            4.087155961401374, -3.146323079425551}, {
            4.174650454004233, -3.2160167427350093`}, {
            4.339150017056674, -3.346966201663108}, {
            4.49179699785707, -3.4684000703747135`}, {
            4.630197565839825, -3.5784342276120045`}}]}, 
          {Arrowheads[{{0.010845708034537148`, 1.}}], 
           ArrowBox[{{4.646539669720651, -3.5914224785356264`}, {
            4.7677760839373855`, -3.687767959429258}, {
            4.777159515694404, -3.695223262780595}, {
            4.91517251368752, -3.80483539412495}, {
            5.001099999999999, -3.8730591707506807`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.141390808371828, -2.7591420158981017`}, \
{-3.227798962124968, -2.8306644378470547`}, {-3.3878418985441785`, \
-2.963451190442565}, {-3.522421852147466, -3.0753709860335854`}, \
{-3.649060532796559, -3.1808066386977427`}, {-3.767757940491458, \
-3.2797581484350378`}, {-3.7835049772350846`, -3.2929049328200213`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7995293302427, -3.3062832412173297`}, \
{-3.878514075232163, -3.3722255152454697`}, {-3.9830293110442256`, \
-3.4595773623537487`}, {-4.083004021953197, -3.543182312984585}, \
{-4.1784382079590765`, -3.6230403671379787`}, {-4.269331869061865, \
-3.6991515248139297`}, {-4.356455977745616, -3.772145289104524}, \
{-4.439928193624884, -3.84210361950191}}]}, 
          {Arrowheads[{{0.01704795050779498, 1.}}], 
           ArrowBox[{{-4.455923507251998, -3.8555166342833425`}, \
{-4.599836824186969, -3.976199240216686}, {-4.7484760117317455`, \
-4.100929030538862}, {-4.888517647917854, -4.218502242443091}, \
{-4.895790330552089, -4.224609553988783}, {-5.001099999999999, \
-4.3130815839598675`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.231997006031069, -0.8188364401711162}, \
{-3.3911366942559766`, -0.85688346281393}, {-3.525555423752777, \
-0.8891393627660974}, {-3.65198976920712, -0.9195324118635665}, \
{-3.770439730619006, -0.9480626101063372}, {-3.8809053079884333`, \
-0.9747299574944096}, {-4.04382798089782, -1.0141421103686925`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.064117598226202, -1.0190503130493078`}, \
{-4.084747097516399, -1.0240407355928745`}, {-4.270378924707498, \
-1.0690293820453756`}, {-4.440904142615816, -1.1104205296825962`}, \
{-4.599426104295435, -1.1489388113352188`}, {-4.747329227463182, \
-1.1849111564725823`}, {-4.875524512065568, -1.216111633341685}}]}, 
          {Arrowheads[{{0.0025957538968547334`, 1.}}], 
           ArrowBox[{{-4.895807083233577, -1.2210488725433468`}, \
{-4.911227200872875, -1.224803234274529}, {-5.001099999999999, \
-1.2466978750976878`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.5688138031822576`, -0.8532854522380371}, \
{-2.708102440648214, -0.8948273918161591}, {-2.880441242014796, \
-0.9468211240591381}, {-3.0349492280323145`, -0.9938224416039011}, \
{-3.2099115956470756`, -1.047418582092442}, {-3.367747522772977, \
-1.096005316557021}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.387692265386435, -1.1021669933740101`}, \
{-3.5017225299210324`, -1.137396843379441}, {-3.627492387828484, \
-1.1763207575269854`}, {-3.745312517914114, -1.2128556855384713`}, \
{-3.8551829201779215`, -1.2470016274138986`}, {-4.057913846097525, \
-1.3101355627183628`}, {-4.185114128221157, -1.3498203253590855`}}]}, 
          {Arrowheads[{{0.019979412017601363`, 1.}}], 
           ArrowBox[{{-4.205041658303803, -1.3560374444420213`}, \
{-4.2425244704447485`, -1.3677315734021636`}, {-4.412104443050104, \
-1.420718839364008}, {-4.569743413744104, -1.4700265405026038`}, \
{-4.716819157436699, -1.51607364893555}, {-4.855348647610072, \
-1.5594745603472702`}, {-4.878054583298364, -1.5665908312861103`}, \
{-5.001099999999999, -1.6051774837657615`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.949857794132753, 1.7256120822941534`}, {
            3.09758396043444, 1.8174310428532225`}, {3.2797561939860076`, 
            1.9302809528659017`}, {3.443156186440635, 2.0312381609973063`}, {
            3.5482127932837098`, 2.096022671743561}, {3.64797657374345, 
            2.1574926379906803`}, {3.659972278720014, 2.1648734005469072`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.6777513116936174`, 2.175812550943976}, {
            3.831625655512926, 2.2704889369875128`}, {3.9337398035029842`, 
            2.33323419938678}, {4.031267683721541, 2.393129627900446}, {
            4.21256464084415, 2.504370983270975}, {4.378722663217442, 
            2.606222833677168}, {4.3893205166827345`, 2.612714652928874}}]}, 
          {Arrowheads[{{0.016679853277455782`, 1.}}], 
           ArrowBox[{{4.4071211559544805`, 2.6236186093852867`}, {
            4.532947887178106, 2.7006950096970925`}, {4.676645814975599, 
            2.7886633736980757`}, {4.811867995016391, 2.8714051894285824`}, {
            4.825834636747196, 2.87994932315995}, {4.965388714333375, 
            2.965287854851862}, {5.001099999999999, 
            2.9871186046201585`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2281171288249144`, -2.3305403202017416`}, \
{-3.3874809023605876`, -2.439441260094973}, {-3.521989139757659, \
-2.531596813072438}, {-3.648533258745749, -2.618405911505014}, \
{-3.7671132593248573`, -2.6998685553927015`}, {-3.8777291414949846`, \
-2.775984744735501}, {-3.916703078801015, -2.802835585214306}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.933893231259378, -2.8146786288832457`}, \
{-3.982090266662475, -2.847883662775462}, {-4.081905996233674, \
-2.916694492754635}, {-4.177176330208581, -2.9824172346730196`}, \
{-4.267901268587196, -3.045051888530616}, {-4.438808183718014, \
-3.163133789932044}, {-4.597719966788592, -3.2730170548275175`}, \
{-4.620998912695109, -3.289125657688523}}]}, 
          {Arrowheads[{{0.010573524618138354`, 1.}}], 
           ArrowBox[{{-4.638164663770317, -3.3010040420445774`}, \
{-4.746017372569895, -3.3756361349457316`}, {-4.885722279734914, \
-3.4723610744994904`}, {-4.896195876453205, -3.479614408053832}, \
{-5.001099999999999, -3.552297419688313}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.0012767621082931725`, 1.}}], 
           ArrowBox[{{0.35221964476248857`, -0.8866729798550318}, {
            0.35675797761408284`, -0.8839224937431878}, {
            0.3615107300251268, -0.8810398396981012}, {
            0.3652761398207426, -0.8787545251377572}, {
            0.3693122076651078, -0.8763036499110786}, {
            0.37245096630170377`, -0.8743964511493603}, {
            0.3805561072152651, -0.8694692430579328}, {
            0.3845267349159446, -0.8670541819389516}, {
            0.39116247988588515`, -0.8630162922496208}, {
            0.3947781271608978, -0.8608152345327427}, {
            0.39777296496363307`, -0.858991679192681}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.015078363614409753`, 1.}}], 
           ArrowBox[{{-0.4524385394696003, -2.9751640359565292`}, \
{-0.49728939605856287`, -3.004506929444883}, {-0.5410176769944275, \
-3.037515508948426}, {-0.6648923186776967, -3.147901818937256}, \
{-0.7796322502214851, -3.2803983173563216`}, {-0.8854155455898931, \
-3.4259572022279183`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.006799489435114291, 1.}}], ArrowBox[CompressedData["

1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAA8JAVAuljpL9TipjXxbTvP+EmbRjA
waa/23Gw2eOx7z87Js0gyt6pv/YFQwoksO8/OH0/OChtrL+IqqIM767vP1/L
OJCaQ6+/XfWoXp+t7z9xmw+7OrO1vzSdFQvxp+8/Rdm5z8qatr8gxQlu0abv
P8udHwGrK7i/y0SYU7Wk7z+qkaqWk6C5v2VojyWFou8/Eh8LlGYDu78JhWVA
QqDvPwqOg4R2e7+/WZh8C86X7z+zKJtl2uTBvyHV0vXNju8/xnHwu7cCyr/+
LCHa3mfvP5OEZZruO9C/TI41Z0lB7z9lUnX9dKDSv8I1X/HeIO8/kBOo7e3u
0r8SWcjPdhzvP4diUyVfPNO/xMsgtQYY7z9xxKYo7YzTv5IcEZhHE+8/hLlv
49an1L9DP5/YcwHvPwnhpYM=
            "]]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.004324280642050402, 1.}}], 
           ArrowBox[{{-0.16159564076096972`, -2.839891821989127}, \
{-0.19815047681852782`, -2.8437935388526383`}, {-0.2344749340096906, \
-2.849291037512582}, {-0.3387233963693941, -2.873562988169092}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.3516723126558383`, -0.6503097481091441}, {
            3.5191743450581883`, -0.6843104232077588}, {
            3.7291218100338916`, -0.7268236847065398}, {
            3.9174423713922946`, -0.7648843746836793}, {
            4.121310425906398, -0.8060186312351444}, {
            4.170092110903638, -0.815849266252761}}]}, 
          {Arrowheads[{{0.019803272817483526`, 1.}}], 
           ArrowBox[{{4.190555561840276, -0.8199731237490813}, {
            4.306566198991793, -0.8433519437316679}, {
            4.476446932646233, -0.877551579022441}, {
            4.634189868867473, -0.9092848039566547}, {
            4.7812183920964815`, -0.9388431947725487}, {
            4.919611346683418, -0.9666521774057364}, {
            4.945881380648905, -0.971929560254245}, {
            5.001099999999999, -0.9830175338599152}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.6896811294053666`, -2.1362566485009236`}, \
{-3.8092789732343526`, -2.2026238807033534`}, {-3.920838421480003, \
-2.2646384997355895`}, {-4.026085385347957, -2.3232190132167156`}, \
{-4.126745776043855, -2.379283928765816}, {-4.31430683791948, \
-2.4838669660679376`}, {-4.4192221326848165`, -2.5424387264427426`}}]}, 
          {Arrowheads[{{0.01546779817677233, 1.}}], 
           ArrowBox[{{-4.4374489329293745`, -2.552614323611025}, \
{-4.486643983845585, -2.5800787723392635`}, {-4.646879590560879, \
-2.6696105082771027`}, {-4.796407208003932, -2.753223399594674}, \
{-4.937267348786684, -2.8320335519119153`}, {-4.9511910268116415`, \
-2.8398259337732457`}, {-5.001099999999999, -2.867770887065822}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.01408176880956563, 1.}}], 
           ArrowBox[{{0.4989602037968354, -2.6847392492600006`}, {
            0.3941779700957896, -2.7600832266881237`}, {
            0.2914266676633947, -2.8024441266432976`}, {
            0.1894705849672178, -2.823468232540322}, {
            0.1541167991071851, -2.8271343197678926`}, {
            0.11874880685063663`, -2.8295102671743853`}, {
            0.11526712024176075`, -2.829682812517258}, {
            0.07994904062321513, -2.830545857530764}, {
            0.044588845794795946`, -2.830845053434672}, \
{-0.05385098855871312, -2.831507457599599}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.0217364704023282`, -3.712379025168234}, {
            1.0178487133167704`, -3.8642714381684833`}, {
            1.013002948197001, -3.9958905359434227`}, {
            1.0059281609308108`, -4.1396990354762515`}, {
            0.9981030380637325, -4.265426352637628}, {
            0.9809068221795924, -4.476405005183466}, {
            0.9738830683866971, -4.545762202182897}}]}, 
          {Arrowheads[{{0.010524817348065232`, 1.}}], 
           ArrowBox[{{0.9717798453175385, -4.566530819797161}, {
            0.971779467959049, -4.566534546084823}, {
            0.9622686800181263, -4.650232033935825}, {
            0.9503787546800302, -4.738403346573025}, {
            0.9382867667632714, -4.819140708727965}, {
            0.9138701095018762, -4.968270836359405}, {
            0.9074817472984573, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.6429342927594766`, 2.186517231959563}, {
            1.7152566641302498`, 2.3127678303650523`}, {1.7807240965291387`, 
            2.425315174394129}, {1.8635853274700953`, 2.565788640102825}, {
            1.9384512309997035`, 2.6912509901048915`}, {2.0326662609733677`, 
            2.847495988669051}, {2.067816558987336, 2.9052930994813404`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.078663489332963, 2.9231285452835425`}, {
            2.117667548345907, 2.98726233783359}, {2.223695020716211, 
            3.1602647696480193`}, {2.31929037004422, 3.31527835213034}, {
            2.381200662731749, 3.4152075028280944`}, {2.4400912149197946`, 
            3.510068383681709}, {2.5171305249891076`, 3.633729464920319}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.5281685166029173`, 3.651447302430005}, {
            2.548813097797439, 3.684585335856524}, {2.6103752220481504`, 
            3.7830751174157062`}, {2.669208939582794, 3.8770716585877407`}, {
            2.778691154503877, 4.051585019770367}, {2.879152287835144, 
            4.211312063707261}, {2.9720200638086407`, 4.358701721177858}}]}, 
          {Arrowheads[{{0.017706635548364373`, 1.}}], 
           ArrowBox[{{2.983160689393598, 4.376355204600429}, {
            3.0595222302064093`, 4.497349762751616}, {3.1414814016164825`, 
            4.627057792740499}, {3.145202706704416, 4.63294367581995}, {
            3.2299199151652203`, 4.766800412959071}, {3.310262724114312, 
            4.893636780125579}, {3.3783555619620707`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.3308808138441972`, 
            1.7366927458836312`}, {-1.4182316129523949`, 
            1.8077195725325053`}, {-1.524346416854461, 
            1.8990411813870867`}, {-1.6191982260294844`, 
            1.9842317719110734`}, {-1.7350113585012057`, 
            2.0920856323357455`}, {-1.8386373016177553`, 
            2.1912229836998693`}, {-1.9481499646846618`, 
            2.2984279569172}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.9630670391379785`, 
            2.3130306934634906`}, {-1.9654925854916752`, 
            2.3154051278403314`}, {-2.0791087280170686`, 
            2.4285376044494433`}, {-2.2181214841829315`, 
            2.5689987669765446`}, {-2.3427644166625154`, 
            2.696317011691099}, {-2.4220754932493356`, 
            2.7779698286849377`}, {-2.4973838907333894`, 
            2.8557500343360203`}, {-2.5482791251419705`, 
            2.908603774138743}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.5627586440707475`, 
            2.9236404811079355`}, {-2.635992648393198, 
            2.999692611609916}, {-2.7166725603662596`, 
            3.0839067506554017`}, {-2.793544924574128, 
            3.164307410032155}, {-2.935867009694289, 
            3.3136682897794647`}, {-3.0563179770437667`, 
            3.440496771943572}, {-3.13911140709004, 3.527815730601086}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.153474385196594, 
            3.542963795982409}, {-3.169594590047225, 
            3.5599651389647713`}, {-3.2756968487046634`, 
            3.672073390843063}, {-3.374624753016083, 
            3.776821527578447}, {-3.4679235999592697`, 
            3.8757626743820053`}, {-3.5571386865120096`, 
            3.9704499564648192`}, {-3.642270012674303, 
            4.060883373826889}, {-3.72331757844615, 
            4.147062926468215}, {-3.7264247100379415`, 
            4.150369306133573}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.7407199845310237`, 
            4.165581280103233}, {-3.800978388726575, 
            4.229703817695605}, {-3.8759494484146035`, 
            4.309521250815869}, {-4.017822316013469, 
            4.460685742735013}, {-4.150178370684848, 
            4.601843970301022}, {-4.274836058021158, 
            4.7348838000822076`}, {-4.280063473351071, 
            4.740464571406904}, {-4.311989419870885, 4.774568523731844}}]}, 
          {Arrowheads[{{0.006931539061580715, 1.}}], 
           ArrowBox[{{-4.326255518126702, 
            4.789807863134901}, {-4.40816636755378, 
            4.877306716207986}, {-4.523997652250886, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3849606990595427`, -2.800110878798029}, {
            1.4289100118959706`, -2.946595497168036}, {
            1.468688589275403, -3.076828407531725}, {
            1.518876401028874, -3.238451956117813}, {
            1.564212957810852, -3.3824403978929407`}, {
            1.6217883322193094`, -3.562982379546373}, {
            1.632891245597711, -3.597428962463224}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.639295236858717, -3.6172972266253276`}, {
            1.67367245623901, -3.7239519124249694`}, {
            1.7343783693535604`, -3.9104948452756756`}, {
            1.7893764061740485`, -4.078219779267762}, {
            1.8396843321416076`, -4.230651597126708}, {
            1.8863199126973704`, -4.371315181577991}, {
            1.8994414411554155`, -4.410728162670983}}]}, 
          {Arrowheads[{{0.014413269903996287`, 1.}}], 
           ArrowBox[{{1.9060353493005426`, -4.430534207209452}, {
            1.929723156999777, -4.501684997299912}, {
            1.9705343729396292`, -4.623895640393343}, {
            1.971851505246819, -4.627834074226864}, {
            2.0144874141785944`, -4.754986775655842}, {
            2.0548565625235957`, -4.875115257195799}, {
            2.094260912162855, -4.992277484446766}, {
            2.097233333457519, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.812072790273744, -0.17172298454048338`}, \
{-1.946477308328861, -0.18002925836534805`}, {-2.0666979256984006`, \
-0.18809281031717462`}, {-2.208517647184074, -0.19820675059692583`}, \
{-2.3355209911112387`, -0.2075954991638974}, {-2.4884431847847677`, \
-0.21923120799138057`}, {-2.6255399041982734`, -0.22986108603791844`}, \
{-2.6449196537470443`, -0.23138741825526066`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.6657300519852063`, -0.23302642711895585`}, \
{-2.7942897387413583`, -0.24315167622258954`}, {-2.9455441261272894`, \
-0.25519474679588544`}, {-3.116440246873497, -0.2689259792371398}, \
{-3.2708206028752045`, -0.28140782292244626`}, {-3.4013821715869317`, \
-0.292012706224183}, {-3.49804272373961, -0.29988088324258444`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.51884874936972, -0.30157449546661275`}, \
{-3.524160131935276, -0.3020068424510603}, {-3.639154483920238, \
-0.311390231603078}, {-3.7463652275418178`, -0.3201628736802362}, \
{-3.9441393470214283`, -0.33638680927731657`}, {-4.124185947700707, \
-0.35118954190964385`}, {-4.289532169309033, -0.3648089276874005}, \
{-4.351043723703806, -0.3698819793861397}}]}, 
          {Arrowheads[{{0.015123409981210402`, 1.}}], 
           ArrowBox[{{-4.3718479322747665`, -0.3715977680159391}, \
{-4.443205151575786, -0.3774828227207688}, {-4.586554048315622, \
-0.38931873481773027`}, {-4.721553601900788, -0.4004743586768272}, \
{-4.751488953250561, -0.4029491661612701}, {-4.8909167609187385`, \
-0.4144842769291888}, {-5.001099999999999, -0.42360490195800515`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.9110952033669704`, 
            0.6277903401587511}, {-2.024980415035556, 
            0.6554290350940868}, {-2.162301911912408, 
            0.6905045521397638}, {-2.2852653438988697`, 
            0.7229487131161703}, {-2.434433510385391, 
            0.7633625803642793}, {-2.5681458504219092`, 
            0.8002415743603967}, {-2.71803242729334, 0.8422047178740162}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.738130590802007, 
            0.8478458387226936}, {-2.881346788215778, 
            0.8883679531222209}, {-3.048626221122796, 
            0.9361203051443778}, {-3.199734141177369, 
            0.9795219105541572}, {-3.3281298744971823`, 
            1.0165683202569}, {-3.448846705093143, 
            1.051473792615138}, {-3.540744604465439, 
            1.0781107984268399`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.5607941918977297`, 
            1.0839222585429473`}, {-3.5618846329652523`, 
            1.0842383276288712`}, {-3.6672436581135095`, 
            1.1148619252980994`}, {-3.8615560449497073`, 
            1.1714829242164206`}, {-4.038414910312976, 
            1.2231334049834817`}, {-4.200806122863187, 
            1.270646943398517}, {-4.351715551260214, 
            1.3148571152607615`}, {-4.362316189846449, 
            1.3179662136632142`}}]}, 
          {Arrowheads[{{0.015446752333225091`, 1.}}], 
           ArrowBox[{{-4.3823472561332295`, 
            1.3238411952206957`}, {-4.492472192813023, 
            1.356140123432997}, {-4.625020907025992, 
            1.3950476716460796`}, {-4.65069334170664, 
            1.4025867449865965`}, {-4.787512006604816, 
            1.442794547628912}, {-4.917285508294359, 
            1.4809529623052}, {-5.001099999999999, 1.505602539612127}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-0.07868264928540315, 
            4.279728235734364}, {-0.11276128298570016`, 
            4.2812383024360905`}, {-0.14679204745681904`, 
            4.283779412356818}, {-0.2731428658271059, 
            4.304479926770533}, {-0.3979788166579693, 
            4.352503164276416}, {-0.5203036966857594, 
            4.4346876718013535`}, {-0.648304558437977, 
            4.562501184552699}, {-0.75468707445166, 4.703599934484623}}]}, 
          {Arrowheads[{{0.007853192179483248, 1.}}], 
           ArrowBox[{{-0.7672541608487065, 
            4.720268088682833}, {-0.7711738715342552, 
            4.725466934306626}, {-0.8304676306302523, 
            4.817533903344322}, {-0.8882265369180987, 
            4.914431752066089}, {-0.9361645823901507, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.04430566838114, 
            0.23600552805044842`}, {-2.1850964371365498`, 
            0.24862613655049065`}, {-2.3111680841033966`, 
            0.26036222509723184`}, {-2.462890726317627, 
            0.2749197449599365}, {-2.59890128305851, 
            0.2882288534302874}, {-2.766273622141396, 
            0.30487635976110466`}, {-2.875466346855248, 0.315860783402991}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.8962363602760286`, 
            0.3179501774268089}, {-2.916281677840173, 
            0.3199666694663448}, {-3.0857120673689153`, 
            0.3371725747488104}, {-3.2387605325340956`, 
            0.3528157767827362}, {-3.3683116478493136`, 
            0.3661207973913493}, {-3.4901306713463924`, 
            0.3786596329070673}, {-3.604217603025332, 
            0.39043228332989005`}, {-3.7105724428861326`, 
            0.40143874865981766`}, {-3.726873732890264, 
            0.40313014564218574`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.747637106628841, 
            0.4052845216257005}, {-3.9067497648334646`, 
            0.42179380830642715`}, {-4.085326554868535, 
            0.44036549611233555`}, {-4.249310167465415, 
            0.4574522614775797}, {-4.401707957098173, 
            0.47335255380219665`}, {-4.543859770492157, 
            0.488201288194495}, {-4.578138207012082, 0.4917849189428918}}]}, 
          {Arrowheads[{{0.009686231375229587, 1.}}], 
           ArrowBox[{{-4.598899898703573, 
            0.49395544491455073`}, {-4.677726592769022, 
            0.5021963623345506}, {-4.707897664769633, 
            0.5053520579704092}, {-4.84618025618567, 
            0.5198263493806842}, {-4.977345985293116, 
            0.533563422248962}, {-5.001099999999999, 
            0.5360516451595843}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{0.9957206861472627, 4.09299559239383}, {
            0.9858892499884959, 4.234899564654805}, {0.9754232457567956, 
            4.358796423216637}, {0.95321236085806, 4.566126393488365}, {
            0.9416822329564365, 4.654374042552518}, {0.9298045435956506, 
            4.735979589130479}, {0.9150332267997813, 4.822088858567529}, {
            0.900106983141823, 4.900596496156205}, {0.8958050873807097, 
            4.92130541338646}}]}, 
          {Arrowheads[{{0.0014520643027025636`, 1.}}], 
           ArrowBox[{{0.8915593629345203, 4.941743927246651}, {
            0.8792292331196736, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.5162838531748949, 
            1.7185438782605738`}, {-0.6288267759565864, 
            1.7571440833193444`}, {-0.7524381235397047, 
            1.816348885747918}, {-0.8611877193724886, 
            1.8847583199733133`}, {-0.9573916535864554, 
            1.9583132058047608`}, {-1.043366016313118, 
            2.0329543630514877`}, {-1.1412445267068663`, 
            2.127232508818202}, {-1.1963813370993501`, 
            2.184678546234119}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.2108362761218123`, 
            2.199738883638808}, {-1.2287647639976653`, 
            2.218418248259208}, {-1.3321725879277944`, 
            2.3334558964139966`}, {-1.4247043487860716`, 
            2.4415816759711486`}, {-1.535863066871495, 
            2.5769805369694443`}, {-1.6354200554567973`, 
            2.702051451512158}, {-1.7439111625693169`, 
            2.8419862157922826`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.7567015678331417`, 
            2.8584836264398144`}, {-1.757209356209207, 
            2.859138585621263}, {-1.8662880932607855`, 
            3.002625666284345}, {-1.991284473014368, 
            3.169819995905911}, {-2.1039522931607038`, 
            3.322350003392546}, {-2.198447082525334, 
            3.4514276364879595`}, {-2.254744726016179, 
            3.5286574202820407`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-2.2670413569172445`, 
            3.5455260863042586`}, {-2.2872380927563905`, 
            3.5732322112055086`}, {-2.3703253238538733`, 
            3.6877637275451933`}, {-2.447708775817782, 
            3.795022185507014}, {-2.520622865955826, 
            3.8964929918871407`}, {-2.590302011575715, 
            3.9936615534817435`}, {-2.656746212677448, 
            4.086527870290823}, {-2.7199554692610253`, 
            4.175091942314379}, {-2.754426639698372, 
            4.2235109809799765`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7665334016586547`, 
            4.240516431274609}, {-2.8388925629850057`, 
            4.342153857147302}, {-2.9493367068589484`, 
            4.497687803122898}, {-3.0522754934261798`, 
            4.642991013265197}, {-3.1491540278975223`, 
            4.779969834062866}, {-3.152870358379948, 
            4.785228662632958}, {-3.2492661401024203`, 
            4.921825632522311}}]}, 
          {Arrowheads[{{0.0018231574547981236`, 1.}}], 
           ArrowBox[{{-3.2612952500277723`, 
            4.938886098952558}, {-3.3051485693985843`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7717500993294394, -4.374963515445799}, {
            0.7322306838895045, -4.489145456161526}, {
            0.6930045339446587, -4.583658478635399}, {
            0.6153356563018338, -4.728160930553611}, {
            0.57684072108161, -4.783314854884425}, {
            0.5381963337558785, -4.830198924190406}, {
            0.48957943618556227`, -4.8737009342536375`}, {
            0.44097849270633743`, -4.90819315389433}, {
            0.3175345988575869, -4.973944386155652}, {
            0.26402956734432714`, -4.986972462078075}}]}, 
          {Arrowheads[{{0.0009303251884661856, 1.}}], 
           ArrowBox[{{0.2437473214942631, -4.99191103759777}, {
            0.2060091531083063, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.014331571967015452`, 1.}}], 
           ArrowBox[{{0.5853741050012409, 3.962317767906401}, {
            0.5179875584588569, 4.048574294835063}, {0.3855999326616589, 
            4.155018875585264}, {0.3442613090774238, 4.1752814234724775`}, {
            0.3023938748642713, 4.191242023093817}, {0.26119212647856543`, 
            4.201361868319392}, {0.21996396680653663`, 4.20852947730402}, {
            0.07675916407409386, 4.222555051634155}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.015327652587560877`, 1.}}], 
           ArrowBox[{{-0.0714787303028114, -4.191049382030284}, \
{-0.10533207647796534`, -4.1923549082391585`}, {-0.13914011823497602`, \
-4.1946190527797365`}, {-0.26318936340812243`, -4.213356083854768}, \
{-0.3857882901431334, -4.257623965521866}, {-0.5059617829260303, \
-4.3342314794934484`}, {-0.6316638057297065, -4.454319744901596}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.3516697844088998`, -2.261355939562999}, \
{-1.4589821961305438`, -2.3827313323100436`}, {-1.5550232714355796`, \
-2.4955588224174683`}, {-1.6712218068672688`, -2.63653834259084}, \
{-1.7753174979236663`, -2.765895668483796}, {-1.8843280069650228`, \
-2.9041719615536548`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.8972516611962853`, -2.9205651975428344`}, \
{-1.9033216214793118`, -2.928264745177272}, {-2.0179856415846698`, \
-3.0759643452492296`}, {-2.148932927241, -3.2468597061406994`}, \
{-2.2670458323819163`, -3.402467593397931}, {-2.3666723333094972`, \
-3.5346480112035166`}, {-2.4039281028596946`, -3.5842450685595164`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-2.4164654911509595`, -3.6009355724380763`}, \
{-2.4602980830315535`, -3.659288079977474}, {-2.547923081548086, \
-3.776387799719804}, {-2.6295473288590943`, -3.885947170430505}, \
{-2.7064695226935367`, -3.9895266367919033`}, {-2.779988360780372, \
-4.088686643486324}, {-2.8501038431195997`, -4.1834271905137665`}, \
{-2.914750620035042, -4.27095201521461}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.927139380975925, -4.28775313338288}, \
{-3.0423670700474323`, -4.44407230876625}, {-3.158978576184799, \
-4.602598971334402}, {-3.267688743008631, -4.7506632126633885`}, \
{-3.370016821511023, -4.890225004014276}, {-3.3737732875012214`, \
-4.895351657705552}, {-3.4215532487845497`, -4.960633899856607}}]}, 
          {Arrowheads[{{0.0007011239671912197, 1.}}], 
           ArrowBox[{{-3.4338821466485507`, -4.977478997135791}, \
{-3.4511703182115587`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.008458210675169203, 1.}}], 
           ArrowBox[{{-0.13932979727398837`, -4.8848878648597704`}, \
{-0.1753047891357456, -4.888679025820387}, {-0.2112095780405799, \
-4.894133458066804}, {-0.35411924794643296`, -4.934401578321924}, \
{-0.4682163522410351, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.44698014853880064`, 2.0802803863106294`}, {
            0.3679389322959532, 2.120524883609987}, {0.28969408502788246`, 
            2.1464294829768007`}, {0.15717643427632882`, 2.168724007958382}, {
            0.024434788155641415`, 
            2.1744150435815257`}, {-0.10833800034160694`, 
            2.1754452865735803`}, {-0.26064338935128534`, 
            2.1855605939780265`}, {-0.36935745285030236`, 
            2.2090088083060895`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.38976304690174446`, 
            2.2134100304424877`}, {-0.40684349590149793`, 
            2.2170940618922863`}, {-0.5431132799628892, 
            2.275041415636592}, {-0.6335834961302464, 
            2.3316097003105076`}, {-0.717553206609306, 
            2.3974198503996504`}, {-0.7952783667819054, 
            2.469391362293554}, {-0.9360666995314204, 
            2.6198015175312945`}, {-1.0262374419886577`, 
            2.7322097672152896`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.0392994056045988`, 
            2.748493014169813}, {-1.0596665667390823`, 
            2.773883033945296}, {-1.169084615020026, 
            2.9264611098765743`}, {-1.2673274909893866`, 
            3.072360943666145}, {-1.3800793445062713`, 
            3.248672166780671}, {-1.481487094672027, 
            3.4131885133542528`}, {-1.5001483330032153`, 
            3.4442710654571607`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5108933066402508`, 
            3.4621681201429344`}, {-1.555948073381879, 
            3.5372122897675484`}, {-1.6261857919120184`, 
            3.6555462189512755`}, {-1.6922002502624456`, 
            3.7681903009054336`}, {-1.7539914484331605`, 
            3.875144535630023}, {-1.812414800432205, 
            3.9773234905690282`}, {-1.8683257202676207`, 
            4.075641733166434}, {-1.9296766262815028`, 
            4.184509754982939}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.9399250429684456`, 
            4.202695710561268}, {-1.9726102634475677`, 
            4.260696081336447}, {-2.0685047479844387`, 
            4.432535644560511}, {-2.1576688438896716`, 
            4.593388487259076}, {-2.240861805417315, 
            4.7443735407678025`}, {-2.3192007800891776`, 
            4.8871607753037445`}, {-2.321324540860085, 
            4.891039559293428}, {-2.3443357001510905`, 4.9332141590669}}]}, 
          {Arrowheads[{{0.001352305986723328, 1.}}], 
           ArrowBox[{{-2.354333950453681, 
            4.951538842304896}, {-2.3813753379355846`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.8281911907502275`, -1.6605604706196249`}, {
            2.9955869170678957`, -1.7655580092446912`}, {
            3.1455456643000104`, -1.859283156556375}, {
            3.240353334069334, -1.918382620554923}, {
            3.330404932819492, -1.9744551378045714`}, {
            3.4962399172623124`, -2.077519332057169}, {
            3.536604458090433, -2.1025595673986746`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.5543432431594773`, -2.1135638633398246`}, {
            3.6028400405134784`, -2.14364896264083}, {
            3.70407531798045, -2.206401468748614}, {
            3.7999457496632263`, -2.265776850380522}, {
            3.890451335561808, -2.321775107536553}, {
            3.993909614735963, -2.3857385233491826`}, {
            4.092731258352962, -2.4468046348002392`}, {
            4.264455344438122, -2.552830189160405}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.282218919805088, -2.5637944218472417`}, {
            4.444887157156814, -2.664134884111487}, {
            4.601234492984337, -2.760513300404543}, {
            4.746926748611157, -2.8502700089773123`}, {
            4.884037204702354, -2.934702946965878}, {
            4.897471204835697, -2.942973812475034}, {
            4.993094873328713, -3.001823800150231}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.90850511537229, 
            2.5676553311416175`}, {-3.064788724048498, 
            2.6964542819523345`}, {-3.155829058835781, 
            2.7717469122728913`}, {-3.2425947995752855`, 
            2.8436031501230787`}, {-3.40330249891096, 
            2.977006448412348}, {-3.538368840872744, 
            3.0893811964834597`}, {-3.5515183321219346`, 
            3.1003337942836597`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.5675580158407296`, 
            3.1136937183510787`}, {-3.6654696607490993`, 
            3.1952472055784544`}, {-3.7846049585400254`, 
            3.2946044756973314`}, {-3.895774734245523, 
            3.387453006840091}, {-4.000683896117496, 
            3.475166407885857}, {-4.10103735240785, 
            3.5591182877137517`}, {-4.196835103116585, 
            3.6393086463237765`}, {-4.208394021690066, 
            3.6489909666493565`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-4.224396500501443, 
            3.662395432202954}, {-4.2880771482437, 
            3.715737483715931}, {-4.375536793158177, 
            3.7890366651332044`}, {-4.459987343228995, 
            3.8598380558185856`}, {-4.619861158839659, 
            3.993947464993673}, {-4.769081219444428, 
            4.119203322832801}, {-4.864121994037933, 4.199019716136523}}]}, 
          {Arrowheads[{{0.003785190977374549, 1.}}], 
           ArrowBox[{{-4.880107441169658, 
            4.2124444881973435`}, {-4.909672668369444, 
            4.2372737239899285`}, {-4.916880651335016, 
            4.243328507102316}, {-5.001099999999999, 4.314102973024306}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.01008348673623452, 1.}}], 
           ArrowBox[{{0.7156554312872144, 4.6580416708485535`}, {
            0.6413573390565178, 4.8096007907263125`}, {0.6045063555545768, 
            4.868170283486798}, {0.5675186251733263, 4.918412363074662}, {
            0.5265198431171332, 4.961373347155347}, {0.48555431295007184`, 
            4.997043062467733}, {0.47997136837702375`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.6530019181954525`, 3.1667323282169697`}, {
            1.7196529161620335`, 3.339070724167242}, {1.7798457268549588`, 
            3.493051308769613}, {1.85621513042735, 3.686511188349314}, {
            1.9250311680393954`, 3.859428375825802}, {1.9588127740804793`, 
            3.9437024568810273`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.9665797591547531`, 3.9630785495661427`}, {
            2.003566311365663, 4.055347925249015}, {2.0748733142352433`, 
            4.2322406282272995`}, {2.1402222035841563`, 4.393580596153499}, {
            2.2008830063484224`, 4.542841940420461}, {2.257409983952633, 
            4.681502778883373}, {2.2800791264770393`, 4.736984091991991}}]}, 
          {Arrowheads[{{0.006336287644669923, 1.}}], 
           ArrowBox[{{2.2879747444439027`, 4.7563081247441765`}, {
            2.31061121653021, 4.811709478992259}, {2.312317693774679, 
            4.815881427835146}, {2.3675997991561046`, 4.950769645046138}, {
            2.3882606970266647`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0916579722722335`, -1.3869907680333011`}, {
            3.273841508699377, -1.4732462291982096`}, {
            3.43726803227333, -1.5504077872743567`}, {
            3.5423498444200985`, -1.599920877229932}, {
            3.642141550414739, -1.6469003337876196`}, {
            3.8258546439476366`, -1.733258346709332}, {
            3.8468907199111273`, -1.7431327886311994`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.865787271740119, -1.7520029269537065`}, {
            3.927922823000723, -1.7811696733217508`}, {
            4.025412989071252, -1.8269063990695176`}, {
            4.20665928226464, -1.9118560479710967`}, {
            4.372790844572097, -1.9896402969556828`}, {
            4.527004997037917, -2.0617921495648894`}, {
            4.621943318784876, -2.1061812967292917`}}]}, 
          {Arrowheads[{{0.009523905751003627, 1.}}], 
           ArrowBox[{{4.64085328633396, -2.1150227984218075`}, {
            4.670704148058638, -2.1289797998696804`}, {
            4.805935569590773, -2.1921777275840535`}, {
            4.824700336973262, -2.2009448814470347`}, {
            4.964368893623812, -2.2661720703683197`}, {
            5.001099999999999, -2.283320178336725}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.5037813381892446`, 3.2099987139990267`}, {
            3.607826257285423, 3.3098640639561787`}, {3.7067008456163086`, 
            3.4047035255287343`}, {3.800405103181901, 3.494517098716694}, {
            3.8889390299822004`, 3.5793047835200578`}, {3.9901569521504023`, 
            3.676176291045054}, {4.0868820909520736`, 3.768707689576722}, {
            4.106705982403895, 3.7876630175910178`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.121793546735932, 3.8020895357923306`}, {
            4.179114446387214, 3.8568989791150607`}, {4.266854018455822, 
            3.9407501596600714`}, {4.350878676558571, 4.021018121249372}, {
            4.431966290096131, 4.098459753920583}, {4.585330383475684, 
            4.244864032508732}, {4.72566705020504, 4.378762016476934}}]}, 
          {Arrowheads[{{0.008615647641334798, 1.}}], 
           ArrowBox[{{4.740772477834072, 4.393169829589908}, {
            4.862936748879463, 4.509684307954755}, {4.869084546667597, 
            4.515546690116751}, {5.001099999999999, 4.641391656874335}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.007178771900839601, 1.}}], 
           ArrowBox[{{0.30903438102739883`, -4.184801974783528}, {
            0.27004727638459003`, -4.196655446430495}, {
            0.23047633592702285`, -4.205620277748784}, {
            0.1915390998862574, -4.210755584295259}, {
            0.15257248327450135`, -4.21403100887324}, {
            0.01269033082912735, -4.220014201817768}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.016197011890512, 1.3506138620435042`}, {
            3.1674698064936013`, 1.4223410018907099`}, {3.3539241951623504`, 
            1.5104623146416225`}, {3.521221947308972, 1.5893290973806766`}, {
            3.628757148116901, 1.6399277358446218`}, {3.7308880034521232`, 
            1.687944817563592}, {3.7713433551729, 1.7069387430192136`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.790239192618241, 1.7158104030738717`}, {
            3.9189366777044445`, 1.7762343107666065`}, {4.023136219300688, 
            1.8250925855354942`}, {4.12267823823425, 1.8717428669244014`}, {
            4.30778970811333, 1.9584194495622735`}, {4.477514831604142, 
            2.0378151682281636`}, {4.546385112851737, 2.0700103357617516`}}]}, 
          {Arrowheads[{{0.011521040028513296`, 1.}}], 
           ArrowBox[{{4.565295677232631, 2.078850560854035}, {
            4.635097352969143, 2.1114811324700127`}, {4.781962688886399, 
            2.1800950178806637`}, {4.920192374384825, 2.2446455274313553`}, {
            4.938095156493397, 2.253003828174768}, {5.001099999999999, 
            2.2824073598584826`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.4041360640473504`, 3.6118193711277486`}, {
            1.4377851157816686`, 3.7648607117857003`}, {1.4778629912848218`, 
            3.9455202803222464`}, {1.513920030693885, 4.106947560700003}, {
            1.546693559437306, 4.252842479172149}, {1.5769209029435327`, 
            4.386904961991866}, {1.5859410727208627`, 4.426778727823031}}]}, 
          {Arrowheads[{{0.013606969010434103`, 1.}}], 
           ArrowBox[{{1.590546959019857, 4.447139101991668}, {
            1.6049160020286464`, 4.510657624402449}, {1.6318255934869483`, 
            4.629343659394153}, {1.6593616791601038`, 4.750458732751739}, {
            1.6853299192730171`, 4.864523136629852}, {1.710634990618716, 
            4.975626073635937}, {1.7164424871053818`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.8385787865396312`, 1.2630391327579926`}, {
            4.038822583255696, 1.3312380844378304`}, {4.220718594058318, 
            1.3931096068328026`}, {4.3874669890480495`, 
            1.4497679719805527`}, {4.542267938325444, 1.5023274519187237`}, {
            4.629136194075694, 1.5318016956866225`}}]}, 
          {Arrowheads[{{0.00890752554694122, 1.}}], 
           ArrowBox[{{4.6489041495755075`, 1.538508927622643}, {
            4.686525994511413, 1.5512739523035466`}, {4.822291824885098, 
            1.5973161785384105`}, {4.845406363620103, 1.6051529198576882`}, {
            4.985717151043869, 1.6527027189128998`}, {5.001099999999999, 
            1.6579139381898402`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7998049391627378`, 
            2.224132777150411}, {-3.911136013172009, 
            2.2867675852599603`}, {-4.016166034029904, 
            2.3459334276977013`}, {-4.116618151481339, 
            2.402558253336261}, {-4.303788676164831, 
            2.508184854215834}, {-4.475764472827367, 
            2.6053557785189927`}, {-4.527072860904816, 2.634371103634}}]}, 
          {Arrowheads[{{0.012546830896244601`, 1.}}], 
           ArrowBox[{{-4.545243456876855, 
            2.64464672852532}, {-4.635662427073833, 
            2.695779416866051}, {-4.784873521701238, 
            2.7802247118027648`}, {-4.925434481673947, 
            2.859819073686261}, {-4.9392177410731755`, 
            2.8676262172810083`}, {-5.001099999999999, 
            2.9026945972295697`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.001965627041300152, 1.}}], 
           ArrowBox[{{-0.9502041271526682, -0.14331328029188278`}, \
{-0.9477028666248428, -0.14762713776018616`}, {-0.9441173027784582, \
-0.1537675857781242}, {-0.9403336213986678, -0.16019584769873735`}, \
{-0.9353673730436431, -0.1685367803349487}, {-0.9298851209717555, \
-0.17760472688285653`}, {-0.9233517183415146, -0.18820445412387576`}, \
{-0.918157538082084, -0.1963839417830998}, {-0.9138497733564334, \
-0.20306274272781846`}, {-0.9072402907286795, -0.21321689875894975`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.678146020191494, 
            3.818226151384127}, {-3.7868646542560462`, 
            3.9260619192294515`}, {-3.8894690108140204`, 
            4.027942302580645}, {-3.9876216666460595`, 
            4.125458043564378}, {-4.081322621752164, 
            4.21860914218065}, {-4.170571876132334, 
            4.307395598429461}, {-4.256124445781233, 
            4.392549954846777}, {-4.270430826904432, 4.406794667014942}}]}, 
          {Arrowheads[{{0.019662717606255768`, 1.}}], 
           ArrowBox[{{-4.28522341714683, 
            4.421523492453743}, {-4.338735346693528, 
            4.474804753968561}, {-4.418404578869217, 
            4.554159995794815}, {-4.495132142308301, 
            4.630615680325539}, {-4.641112922234419, 
            4.776147938288173}, {-4.778656228839565, 
            4.913336631483862}, {-4.783728120717936, 
            4.918396652057132}, {-4.8665906796881595`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.39589652993238816`, 3.490332714743026}, {
            0.2882851307840179, 3.537454451142664}, {0.18135563393669324`, 
            3.5597045641827703`}, {0.07460593828961627, 3.567119094158092}, {
            0.042649948674655165`, 3.5677905724893693`}, {
            0.009446775585200311, 3.5680275151653915`}, {-0.02247647404511753,
             3.5680717978822396`}, {-0.05438966699570846, 
            3.568361818040988}, {-0.1608119463415281, 
            3.5733522563989992`}, {-0.26648772841338736`, 
            3.5900675164018923`}, {-0.37068945126451774`, 
            3.624843174503696}, {-0.413328893114699, 
            3.6487936950420843`}}]}, 
          {Arrowheads[{{0.004466863304122578, 1.}}], 
           ArrowBox[{{-0.4315291226964704, 
            3.6590167409706216`}, {-0.47756114893432317`, 
            3.684872871867153}, {-0.5809888823442753, 
            3.7695879766105658`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.761348227844604, -0.05936150686351649}, {
            1.9573042302773054`, -0.06752914674220152}, {
            2.0735291266174243`, -0.07226528383102657}, {
            2.177138097617085, -0.07643679752690459}, {
            2.3069181870577466`, -0.08160457436324912}, {
            2.4228193826855584`, -0.08617831836032247}, {
            2.567282817149905, -0.0918328133009759}, {
            2.595666229142744, -0.09293653245090497}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.6165253062375293`, -0.09374765983915449}, {
            2.6964969654738344`, -0.09685744282694264}, {
            2.8570086140084876`, -0.10306246706063735`}, {
            3.000762697285516, -0.10859379993258565`}, {
            3.178199401636549, -0.11539271605306166`}, {
            3.337342901011032, -0.12147068406379956`}, {
            3.4509037357446695`, -0.12579503760696498`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.4717634592365805`, -0.1265893679709789}, {
            3.5369543550896294`, -0.12907181257545447`}, {
            3.715927503617695, -0.135871174017182}, {
            3.91077711390647, -0.1432587193426682}, {
            4.087703408845341, -0.14995677187543718`}, {
            4.249842820625768, -0.15608734038235542`}, {
            4.3061580107991135`, -0.15821478618090468`}}]}, 
          {Arrowheads[{{0.01615727986082551, 1.}}], 
           ArrowBox[{{4.327017972999003, -0.1590028229220299}, {
            4.400331781439215, -0.1617724336302895}, {
            4.540543719379533, -0.16706507909997947`}, {
            4.672483121733188, -0.17204257734136996`}, {
            4.70443795537474, -0.17324770013179716`}, {
            4.8410918859017995`, -0.1783986422877036}, {
            4.970635852307504, -0.18327964218948842`}, {
            5.001099999999999, -0.18442726918498523`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.738888250392955, 0.26304338160177654`}, {
            1.9317622929732783`, 0.2993984216370754}, {2.046295744259102, 
            0.32048630498925573`}, {2.1483714494321395`, 
            0.3390469332082189}, {2.276350180315322, 0.3620518396712137}, {
            2.3906176950381264`, 0.3824007952054067}, {2.5331372435857786`, 
            0.40756644853900226`}, {2.560416542697358, 
            0.41235073508034803`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.580977564379706, 0.41595675952066874`}, {
            2.66058799519681, 0.42991896255056}, {2.818982540577628, 
            0.4575292279289081}, {2.9608159839705435`, 0.4821333151657663}, {
            3.135942429255833, 0.5123815989482674}, {3.2929893969095003`, 
            0.5394150232385363}, {3.403727857212193, 0.5584191486154731}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.424301934783971, 0.5619499214709034}, {
            3.490003031873621, 0.5732250636670393}, {3.666623592606408, 
            0.6034623824636188}, {3.859227943238721, 0.6363670816985147}, {
            4.034074990093096, 0.6661922736556795}, {4.194277673065567, 
            0.693484057143987}, {4.24737778121157, 0.7025219189743143}}]}, 
          {Arrowheads[{{0.01781211805202859, 1.}}], 
           ArrowBox[{{4.267956671418489, 0.706024532675217}, {
            4.342948932052172, 0.7187885309723115}, {4.4814503057663435`, 
            0.7423427005756044}, {4.61176851267501, 0.7644919737941631}, {
            4.642494795777943, 0.7697125526593643}, {4.777478118579731, 
            0.7926345113585478}, {4.905428565609921, 0.8143532616064658}, {
            5.001099999999999, 0.8305902207989625}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.8220393343711443`, 3.0713166082870833`}, {
            2.9588095948833573`, 3.231408321960345}, {3.0831395945285744`, 
            3.3765606185692425`}, {3.198430695721149, 3.51093781217748}, {
            3.3067679676168993`, 3.6370743212663985`}, {3.3654366591072202`, 
            3.705298417650989}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.3790473381315325`, 3.721125876113525}, {
            3.4081514102158263`, 3.754970145835997}, {3.5025810235179295`, 
            3.8646252858862757`}, {3.5915752247282966`, 3.96786064160209}, {
            3.6766524310520152`, 4.066497113168296}, {3.757812642489086, 
            4.160534700584893}, {3.8350558590395085`, 4.249973403851882}, {
            3.909056082219928, 4.335611991192177}, {3.924431630560418, 
            4.353399629024406}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.938082704744443, 4.369192260170242}, {
            3.9804873135469894`, 4.418249230828693}, {4.11564280064104, 
            4.574519666990389}, {4.241716051531326, 4.720190771836343}, {
            4.360452501442442, 4.857316434417287}, {4.365209738444844, 
            4.862809126170391}, {4.484545043253126, 5.000534682723747}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.744911322302314, -1.7129376552263615`}, \
{-3.9428138011377762`, -1.7998975323876614`}, {-4.1229857098008775`, \
-1.8792150644078742`}, {-4.288456037732671, -1.9521745786312268`}, \
{-4.44225377437421, -2.020060402401945}, {-4.509040702072668, \
-2.049568609124273}}]}, 
          {Arrowheads[{{0.012387673769055467`, 1.}}], 
           ArrowBox[{{-4.5281348830149675`, -2.0580049163157463`}, \
{-4.585727908129227, -2.083451017063319}, {-4.720852873352378, \
-2.1431945863044564`}, {-4.740156946250142, -2.1517327237294794`}, \
{-4.879413313671542, -2.2133629690831755`}, {-5.001099999999999, \
-2.26724316391217}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.142643835729585, 0.9056373717295829}, {
            4.328736424194389, 0.9475473449940535}, {4.499394016583594, 
            0.9859424725451769}, {4.657864347959646, 1.0215705215636888`}, {
            4.805575938746035, 1.0547584060876176`}, {4.944615262677391, 
            1.0859831508838405`}, {4.957294039170684, 1.088829763654365}}]}, 
          {Arrowheads[{{0.0005753568926757318, 1.}}], 
           ArrowBox[{{4.977661999654209, 1.0934019851859522`}, {
            5.001099999999999, 1.098661933907891}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.013211319909843654`, 1.}}], 
           ArrowBox[{{0.3033619745477262, 4.944146203408922}, {
            0.26456464687751713`, 4.955194611750312}, {0.2254616273188066, 
            4.963477209326573}, {0.186687730103163, 4.968228741334372}, {
            0.14789186862500436`, 4.971236293408795}, {-0.004050753407313368, 
            4.97725249424011}, {-0.15566531278879142`, 
            4.983722369153274}, {-0.24342902918262607`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.9468692077472296`, 
            1.83679438713619}, {-4.1272093833622625`, 
            1.91773604932314}, {-4.292836463501325, 
            1.9921893776618307`}, {-4.446781471355886, 
            2.0614651570199007`}, {-4.590394361171187, 
            2.126153734749525}, {-4.708369592819216, 
            2.1793310700301958`}}]}, 
          {Arrowheads[{{0.007192310973953247, 1.}}], 
           ArrowBox[{{-4.72740035832747, 
            2.187909472468261}, {-4.744603699225916, 
            2.195666680521044}, {-4.883983620312246, 
            2.2585528269475432`}, {-5.001099999999999, 
            2.31141901476199}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.8748832176356744`, -0.3362169037289804}, {
            4.076872397383686, -0.3543384441783246}, {
            4.2603965303901346`, -0.3707822716902443}, {
            4.428670780519499, -0.38584337319248996`}, {
            4.58491031163626, -0.3998167356128121}, {
            4.70654930089979, -0.41068807758832543`}}]}, 
          {Arrowheads[{{0.006583239023281485, 1.}}], 
           ArrowBox[{{4.727341268177123, -0.4125463352734979}, {
            4.7305277336274445`, -0.41283112188520305`}, {
            4.867585901114369, -0.4250743720112464}, {
            4.896563988071357, -0.42766223185051794`}, {
            5.001099999999999, -0.43699344163705794`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.0028389509340232483`, 1.}}], 
           ArrowBox[{{0.41370639088662414`, 0.9133593295341803}, {
            0.40115949395950123`, 0.919797348849931}, {0.38560052153609586`, 
            0.9267594369605958}, {0.3685989207562488, 0.9336913047665327}, {
            0.3467187719693699, 0.9420423697329362}, {0.32755797439123313`, 
            0.9490624723659029}, {0.32097831773067176`, 0.9514280260254374}, {
            0.3160078069421937, 0.9532006185125956}, {0.30897892810154487`, 
            0.9556715542183979}, {0.3038053230663659, 0.9574520495264083}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.003592017884761338, 1.}}], 
           ArrowBox[{{0.24687422599984327`, 4.446896844058684}, {
            0.2097738132118419, 4.453850585239605}, {0.17218605422926753`, 
            4.458796561007434}, {0.13509501676110344`, 4.4612397823007806`}, {
            0.09798217314003846, 4.462549976555663}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.4939825577568575`, 0.045023377513732595`}, {
            3.7025695986702813`, 0.047823760181114436`}, {3.8896630368602114`,
             0.050330558341971116`}, {4.092324581327252, 
            0.05304123461454008}, {4.27647104453565, 0.05550113606135036}, {
            4.328901419203345, 0.05620077034560027}}]}, 
          {Arrowheads[{{0.015602116376748788`, 1.}}], 
           ArrowBox[{{4.34977440283492, 0.056479300778689755`}, {
            4.445324751547143, 0.057754330763785285`}, {4.60210802742347, 
            0.05984488680322818}, {4.74823707019215, 0.06179204719066916}, {
            4.885780088581808, 0.06362388547158741}, {4.915089530696552, 
            0.06401412950487019}, {5.001099999999999, 
            0.06515880280824816}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.0060021782979489124`, 1.}}], 
           ArrowBox[{{-0.04724834528914637, -1.0057038530010767`}, \
{-0.06155558295077915, -1.0052805618049843`}, {-0.0744167228480398, \
-1.0047797347542107`}, {-0.1278569595789718, -1.0020326628629184`}, \
{-0.1506392449967609, -1.0006691312684286`}, {-0.17332612834558028`, \
-0.9991270741624598}, {-0.2093195356914612, -0.9959798615243106}, \
{-0.24317878500739049`, -0.9926648921856368}, {-0.29706246485861737`, \
-0.9870089764781574}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.1545061613549312`, -1.0056243689030206`}, {
            3.3404491800248706`, -1.06801944332829}, {
            3.507294123612263, -1.1238563083877697`}, {
            3.614549490955844, -1.1596797986087581`}, {
            3.7164161588223825`, -1.1936746012886015`}, {
            3.903983396124329, -1.2561781440248534`}, {
            3.9464400249596765`, -1.2703028738642972`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.966247481544165, -1.2768925391471302`}, {
            4.107172232019645, -1.3237762433591795`}, {
            4.291790265112321, -1.3851224275231326`}, {
            4.461070086522513, -1.441314933718018}, {
            4.618244287370375, -1.4934519991451407`}, {
            4.758700490547413, -1.540013379084468}}]}, 
          {Arrowheads[{{0.005616306958185073, 1.}}], 
           ArrowBox[{{4.778515611848052, -1.546579960455319}, {
            4.902612484834011, -1.5876988253287985`}, {
            4.925225349727918, -1.5951896001599213`}, {
            5.001099999999999, -1.6203133299179113`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.006639755520651138, 1.}}], 
           ArrowBox[{{0.29401498192339304`, -4.748463271817171}, {
            0.15767025312857072`, -4.7753792643801}, {
            0.1232418293076098, -4.777841211216308}, {
            0.08842709693176315, -4.779294750422621}, {
            0.05399657786153917, -4.7797000675540415`}, {
            0.019559422803531533`, -4.779797035177764}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2650420358602332`, 
            2.354380229984012}, {-3.426058497108193, 
            2.464423035121695}, {-3.5617802057896917`, 
            2.5574106321567136`}, {-3.6894771281844374`, 
            2.645006710701807}, {-3.8091492642924294`, 
            2.7272112707569764`}, {-3.920796614113668, 
            2.804024312322221}, {-3.9536453218501286`, 
            2.8266503220545682`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.9708366707553413`, 
            2.8384916288956825`}, {-4.026139914027239, 
            2.87658419955445}, {-4.126899900412228, 
            2.9460292966105732`}, {-4.223076573268634, 
            3.01235960349059}, {-4.314669932596458, 
            3.0755751201945003`}, {-4.487223285547172, 
            3.1947559149532516`}, {-4.64767653414518, 
            3.3056658127660774`}, {-4.6580226305225105`, 
            3.3128223983835174`}}]}, 
          {Arrowheads[{{0.009493207002103954, 1.}}], 
           ArrowBox[{{-4.675190495588513, 
            3.324697727177353}, {-4.797421516828873, 
            3.40924717816937}, {-4.938496516403389, 
            3.5068817062836786`}, {-4.9487617830967645`, 
            3.513987856135087}, {-5.001099999999999, 3.5502351054035763`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.015606380130741846`, 1.}}], 
           ArrowBox[{{1.2065418073051803`, -4.35046061145496}, {
            1.214750106569242, -4.4842611754195225`}, {
            1.2217754908902656`, -4.606006905001635}, {
            1.2277796782172683`, -4.717273193001594}, {
            1.2330784673462396`, -4.822017304710949}, {
            1.238015680917684, -4.931239028459691}, {
            1.240926531943683, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.139304795928921, -3.302021478423848}, \
{-3.2199659985424054`, -3.3818498172924696`}, {-3.296445709724824, \
-3.457667520879127}, {-3.4282174361368867`, -3.5884855258007717`}, \
{-3.5522275057000803`, -3.7117372826968125`}, {-3.6684759184144045`, \
-3.82742279156725}, {-3.731722835122693, -3.8904554615983797`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.7465085992759826`, -3.9051911395023473`}, \
{-3.7769626742798597`, -3.9355420524120843`}, {-3.8793472534824667`, \
-4.037690048559782}, {-3.9772891362082454`, -4.135461763338813}, \
{-4.070788322457197, -4.228857196749175}, {-4.159844812229322, \
-4.317876348790869}, {-4.245212155285593, -4.403253725782715}, \
{-4.3276439013869865`, -4.485723834043531}, {-4.337235402014592, \
-4.495323381109359}}]}, 
          {Arrowheads[{{0.016616860802222105`, 1.}}], 
           ArrowBox[{{-4.351989954094331, -4.510090310980272}, \
{-4.407140050533501, -4.5652866735733175`}, {-4.483700602725139, \
-4.641942244372075}, {-4.6293628898627786`, -4.787854675531369}, \
{-4.766605355252163, -4.925401413439726}, {-4.771639105483682, \
-4.930447532705083}, {-4.842088595306336, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.8232185190470056`, 3.73469848921282}, {
            2.890428825867573, 3.83104970113232}, {2.9539845178099733`, 
            3.922011264581695}, {3.026893507589235, 4.026222631204926}, {
            3.09659411648072, 4.1257607461494805`}, {3.1630863444844275`, 
            4.220625609415359}, {3.226370191600358, 4.310817221002562}, {
            3.3021431741243084`, 4.418690331660788}}]}, 
          {Arrowheads[{{0.01655959547260577, 1.}}], 
           ArrowBox[{{3.314141917651632, 4.435772169344471}, {
            3.3455228473654333`, 4.480447176066095}, {3.4562621879724915`, 
            4.637917098265232}, {3.5595660205903163`, 4.784658407097611}, {
            3.656863807887009, 4.92276051725965}, {3.6606331387254363`, 
            4.9281086020730065`}, {3.7121117896794207`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7364097927403264`, -2.0535022464377195`}, \
{-1.8576365563167316`, -2.1674352367279206`}, {-1.9661803471783394`, \
-2.2716488581299683`}, {-2.1010453131814613`, -2.403527738367423}, \
{-2.221766299709522, -2.5232020038462157`}, {-2.3344210675645436`, \
-2.6361739920600633`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.349161042375911, -2.650955472616707}, \
{-2.352721299970217, -2.6545257554075765`}, {-2.4714369889464516`, \
-2.7745335345424893`}, {-2.5800635544522663`, -2.8850715125505104`}, \
{-2.6807511843017005`, -2.9879858607311975`}, {-2.774441479923886, \
-3.0841293425849816`}, {-2.862508932250698, -3.174756762555886}, \
{-2.874337949014529, -3.1869472109457613`}, {-2.9331732878061145`, \
-3.247725903154265}}]}, 
          {Arrowheads[{{0.0006092357872555106, 1.}}], 
           ArrowBox[{{-2.947692298144265, -3.2627244818764924`}, \
{-2.9653832995313327`, -3.2809998237075924`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.0302890400306515`, -3.485331407224334}, \
{-3.1428260147226106`, -3.606428193990797}, {-3.2482351359375907`, \
-3.720067772926614}, {-3.346516403675592, -3.826250144031786}, \
{-3.439205026260897, -3.9265482757814554`}, {-3.527836212017789, \
-4.022535136650765}, {-3.5975253671926946`, -4.098076241277614}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.6116798497557596`, -4.1134193064295985`}, \
{-3.612409960946267, -4.114210726639715}, {-3.6929262730463326`, \
-4.2015750457483065`}, {-3.770077665831076, -4.285352764372149}, \
{-3.844556656813589, -4.366268552906855}, {-3.9854974333719246`, \
-4.519514339708855}, {-4.116982810115012, -4.662617263521426}, \
{-4.176975055169844, -4.727956143445357}}]}, 
          {Arrowheads[{{0.00837867935444755, 1.}}], 
           ArrowBox[{{-4.191093262213855, -4.7433325947507985`}, \
{-4.240819557386931, -4.797490601779974}, {-4.245833807192462, \
-4.8029535804334005`}, {-4.37308860084316, -4.941678903180573}, \
{-4.427569570746733, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8950883652655108`, -3.7918942070213166`}, {
            1.9660803457751055`, -3.9699981368533135`}, {
            2.046681244559481, -4.1708690002096045`}, {
            2.1198763369617106`, -4.352346913199552}, {
            2.186964483843719, -4.517956215646835}, {
            2.2067133034127164`, -4.566556094159583}}]}, 
          {Arrowheads[{{0.010740243016548984`, 1.}}], 
           ArrowBox[{{2.214571863131993, -4.585895227129412}, {
            2.249244546067432, -4.67122124737513}, {
            2.307284142052012, -4.813646468009971}, {
            2.3619110418676583`, -4.9474177316137204`}, {
            2.3635132795610025`, -4.951337401873023}, {
            2.38389106162606, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.4206583323918087`, 3.855507014614182}, {
            2.477557636261996, 3.957531547836629}, {2.531938651127856, 
            4.054894730957574}, {2.633145813846594, 4.235637046894956}, {
            2.726025319936994, 4.4010439227651155`}, {2.8123226687880267`, 
            4.554425318906837}, {2.8289260890050967`, 4.583882298471371}}]}, 
          {Arrowheads[{{0.010976254717712894`, 1.}}], 
           ArrowBox[{{2.8391760943132796`, 4.602067358715109}, {
            2.892806722618589, 4.697216207649166}, {2.968600507845407, 
            4.831507269066271}, {2.971489515233249, 4.836622720897674}, {
            3.0498465520107243`, 4.975208461114757}, {3.06449959145264, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.014166183001621615`, 1.}}], 
           ArrowBox[{{-1.9311291126101309`, -0.6032045028320524}, \
{-2.1036771439093283`, -0.644153808559613}, {-2.180803151749295, \
-0.6632919095511096}, {-2.2532093350363134`, -0.6815829704876708}, \
{-2.348446604020465, -0.706026113167659}, {-2.3546186281002646`, \
-0.7076240866447557}, {-2.4317862745914334`, -0.7278341560036946}, \
{-2.504760580518171, -0.7471114619125606}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.01326268842049693, 1.}}], 
           ArrowBox[{{-4.452090546466633, -0.6002068244859576}, \
{-4.610936255950364, -0.6210199748578499}, {-4.759141870520936, \
-0.6404580449123346}, {-4.898737875537334, -0.6587798234121331}, \
{-4.9258689709057695`, -0.6623421014878653}, {-5.001099999999999, \
-0.6722259572897847}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.018933121978844607`, 1.}}], 
           ArrowBox[{{-4.253817083751346, 
            1.5104229671006126`}, {-4.4238140734505365`, 
            1.5689352740091926`}, {-4.581844555279818, 
            1.6233841602225316`}, {-4.729288960489478, 
            1.674232390622578}, {-4.86816819373501, 
            1.7221585572185978`}, {-4.889694184270302, 
            1.7295896047470232`}, {-5.001099999999999, 
            1.7680705826206067`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.004908961887775524, 1.}}], 
           ArrowBox[{{1.1333756447205916`, 2.0773203083205685`}, {
            1.145357731369951, 2.1377145649390563`}, {1.1567085936765165`, 
            2.193608250749118}, {1.1615588384416868`, 2.2171269833864877`}, {
            1.174467996250713, 2.278103430914914}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.01464927753281567, 1.}}], 
           ArrowBox[{{-3.3402418613307434`, -4.519576912768116}, \
{-3.465871752158086, -4.679777281710982}, {-3.5830248291765234`, \
-4.829381382559252}, {-3.6933270048217404`, -4.970382692601692}, \
{-3.697298699731786, -4.975462296860464}, {-3.7173270892785446`, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.9231342289929083`, -0.14230527226508125`}, \
{-4.128808469761423, -0.1494952429876473}, {-4.316127105008989, \
-0.1560558557038525}, {-4.488215335928847, -0.16209248187685807`}, \
{-4.648198363714234, -0.16771049296982524`}, {-4.757615385483814, \
-0.17155653052253006`}}]}, 
          {Arrowheads[{{0.0053356182320370696`, 1.}}], 
           ArrowBox[{{-4.778477343469895, -0.17228983392029923`}, \
{-4.797471348037026, -0.17295747825625338`}, {-4.9380770227789865`, \
-0.1779032399386128}, {-4.965888302280116, -0.1788818624406179}, \
{-5.001099999999999, -0.1801216346398398}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.9553412443184612`, 0.45972325842706663`}, {
            4.160940040765104, 0.48440000741723893`}, {4.347798496855949, 
            0.5068007187298997}, {4.519172090253152, 0.5273243905360999}, {
            4.678316298618866, 0.5463700210068902}, {4.78440518538464, 
            0.5590580782199034}}]}, 
          {Arrowheads[{{0.0047272911071401915`, 1.}}], 
           ArrowBox[{{4.805132315594589, 0.5615370090672601}, {
            4.826663672195163, 0.5641121240745938}, {4.966306748125102, 
            0.5808053686758559}, {4.993722817289589, 0.5840819059154977}, {
            5.001099999999999, 0.5849631593889852}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6854003727487711, -1.746834832815952}, {
            0.6130900508281593, -1.8549628904761573`}, {
            0.5076828527218997, -1.9628959312698224`}, {
            0.4300856781322069, -2.014944692491}, {
            0.35378346178647097`, -2.050100369216454}, {
            0.2780707200589946, -2.0729429692994357`}, {
            0.19118617855478634`, -2.088143388191753}, {
            0.1041067855345901, -2.0950169937188683`}, {
            0.016711842985823323`, -2.0968820266258055`}, \
{-0.01783686138547482, -2.0970527854358663`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.038711448328982274`, -2.0971559591927944`}, \
{-0.10530373182165245`, -2.0974850950980444`}, {-0.22611827917033575`, \
-2.1027719165565615`}, {-0.34366034176855753`, -2.1194861160267564`}, \
{-0.4493305943835931, -2.148954132016889}, {-0.5487612573705549, \
-2.1923845614852038`}, {-0.7276569715387523, -2.3115890160724972`}, \
{-0.7971302464331914, -2.3772158456835637`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.8123050937784917, -2.391550525063759}, \
{-0.8809717861743059, -2.456415429282868}, {-0.9922841244078212, \
-2.58214528758394}, {-1.0917356017343027`, -2.707266627691499}, \
{-1.1999283534753606`, -2.855486220878583}, {-1.2970116440663837`, \
-2.996520753497732}, {-1.3288507307430204`, -3.0450647448859485`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.3402993460001136`, -3.062520065953784}, \
{-1.4088264475775245`, -3.167001047541559}, {-1.5093708876989378`, \
-3.325709162149376}, {-1.584746460304329, -3.447694627889242}, \
{-1.6557859576994298`, -3.563930993025531}, {-1.72248937988424, \
-3.674418257558244}, {-1.7805521856210966`, -3.7719274825047053`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.7911852517774236`, -3.789891193506374}, \
{-1.8437781107449953`, -3.879101927144946}, {-1.900143643664954, \
-3.97521121686295}, {-2.0052071566060397`, -4.155921148480273}, \
{-2.101750772454817, -4.32354206899747}, {-2.191477997984086, \
-4.4803298310726625`}, {-2.2097272142304822`, -4.5124020186778075`}}]}, 
          {Arrowheads[{{0.01294759669019971, 1.}}], 
           ArrowBox[{{-2.220050862853845, -4.530545372942869}, \
{-2.275163388420401, -4.627403190588215}, {-2.3539453351626887`, \
-4.766428356855876}, {-2.3563481457528357`, -4.77067678916942}, \
{-2.436854854439703, -4.913500415028821}, {-2.486096634890109, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.004919324232348806, 1.}}], 
           ArrowBox[{{-2.6411198056351233`, -4.825518137962269}, \
{-2.7284900962336205`, -4.96942038302817}, {-2.731106909241767, \
-4.97373561959171}, {-2.747665743750737, -5.001099999999999}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sca\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(sca\\)]\\)}\"", 
          TraditionalForm]}}], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.162305389879444}, \
{-4.821889415864387, -2.1623192044171278`}, {-4.621279449026206, \
-2.162334668536951}, {-4.420669482188025, -2.162350132656774}, \
{-4.220059515349844, -2.1623655967765973`}, {-4.166106325967133, \
-2.162369755785238}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231484116311, -2.162371364932883}, \
{-4.019449548511663, -2.1623810608964202`}, {-3.818839581673482, \
-2.1623965250162436`}, {-3.65834669931489, -2.1623965107894807`}, \
{-3.497853466924774, -2.1623963336212273`}, {-3.4818041140551097`, \
-2.1623963068646836`}, {-3.465754758509956, -2.1623962795258542`}, \
{-3.457730079425167, -2.162396265590936}, {-3.449705399693793, \
-2.1623962515326123`}, {-3.4416807193221555`, -2.1623962373569636`}, \
{-3.4336560383165646`, -2.1623962230699387`}, {-3.4256313566832937`, \
-2.1623962086774178`}, {-3.3102378085727406`, -2.1623960002815372`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362966659933, -2.1623959620632918`}, \
{-3.162379754193911, -2.1623957185371854`}, {-3.044919182689947, \
-2.162395496536761}, {-2.9274586111859824`, -2.1623952745363364`}, \
{-2.8099980396820183`, -2.162395052535912}, {-2.692537468178054, \
-2.1623948305354874`}, {-2.57507689667409, -2.162394608535063}, \
{-2.4576163251701257`, -2.1623943865346384`}, {-2.454369290147727, \
-2.162394380397744}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944482349217`, -2.1623943409443025`}, \
{-2.3401557536661617`, -2.162394164534214}, {-2.222695182162197, \
-2.1623939425337895`}, {-2.192544244599234, -2.1623939278758044`}, \
{-2.16239330646329, -2.1623939143506177`}, {-2.0623896454525257`, \
-2.162393883935158}, {-1.9623859824551415`, -2.162393862651155}, \
{-1.9582478920952897`, -2.1623938617786473`}, {-1.9490521357294892`, \
-2.16239385992178}, {-1.9398563793560137`, -2.1623938581324964`}, \
{-1.8478988153993312`, -2.1623938463083614`}, {-1.7559412520178936`, \
-2.1623938393575473`}, {-1.6409943140125853`, -2.1623938419253856`}, \
{-1.5985007717216086`, -2.162393842874663}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625929808766, -2.1623938433409933`}, \
{-1.5260473760072775`, -2.1623938444932245`}, {-1.4111004380019692`, \
-2.162393847061063}, {-1.296153499996661, -2.1623938496289017`}, \
{-1.181206561991353, -2.16239385219674}, {-1.066259623986045, \
-2.162393854764579}, {-0.9513126859807366, -2.1623938573324173`}, \
{-0.8363657479754286, -2.162393859900256}, {-0.7426322532950618, \
-2.162393859976792}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574113822192, -2.1623938599938364`}, \
{-0.7214188110231199, -2.162393859994113}, {-0.6064718740708108, \
-2.1623938600879704`}, {-0.49152493711850176`, -2.1623938601818273`}, \
{-0.3765780001661927, -2.1623938602756847`}, {-0.2616310632138837, \
-2.1623938603695416`}, {-0.14668412626157462`, -2.162393860463399}, \
{-0.031737189309265584`, -2.162393860557256}, {
            0.08320974764304301, -2.1623938606511133`}, {
            0.11323626512922923`, -2.162393492585655}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110704050352`, -2.16239323670156}, {
            0.2205743305290575, -2.162392176834195}, {
            0.35793891341507145`, -2.162390493017276}, {
            0.49530349630108494`, -2.1623888092003574`}, {
            0.6326680791870984, -2.1623871253834386`}, {
            0.7700326620731124, -2.16238544156652}, {
            0.9073972449591263, -2.162383757749601}, {
            0.9691047834914751, -2.1623830013377576`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899796254027494, -2.1623827454536624`}, {
            1.0447618278451407`, -2.1623820739326827`}, {
            1.1821264107311542`, -2.162380390115764}, {
            1.3194909936171682`, -2.162378706298845}, {
            1.456855576503182, -2.1623770224819263`}, {
            1.5942201593891956`, -2.1623753386650075`}, {
            1.73158474227521, -2.162373654848089}, {
            1.824973301853721, -2.16237251008986}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481437649954`, -2.162372254205765}, {
            1.868949325161224, -2.1623719710311704`}, {
            2.006313908047238, -2.1623702872142516`}, {
            2.1436784909332514`, -2.162368603397333}, {
            2.2810430738192653`, -2.162366919580414}, {
            2.4184076567052792`, -2.1623652357634953`}, {
            2.5557722395912927`, -2.162363551946577}, {
            2.680841820215967, -2.1623620188419626`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.7017166621272413`, -2.1623617629578673`}, {
            2.83050140536332, -2.1623601843127394`}, {
            2.967865988249334, -2.1623585004958206`}, {
            3.1052305711353476`, -2.162356816678902}, {
            3.2425951540213624`, -2.162355132861983}, {
            3.3799597369073764`, -2.1623534490450647`}, {
            3.51732431979339, -2.162351765228146}, {
            3.536710338578213, -2.162351527594065}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.557585180489487, -2.1623512717099698`}, {
            3.6546889026794043`, -2.162350081411227}, {
            3.792053485565418, -2.1623483975943083`}, {
            3.929418068451432, -2.1623467137773895`}, {
            4.066782651337446, -2.1623450299604707`}, {
            4.204147234223459, -2.1623433461435524`}, {
            4.341511817109473, -2.1623416623266336`}, {
            4.3925788569404585`, -2.162341036346167}}]}, 
          {Arrowheads[{{0.014075472171732962`, 1.}}], 
           ArrowBox[{{4.4134536988517326`, -2.162340780462072}, {
            4.478876399995487, -2.162339978509715}, {
            4.6918932994858356`, -2.162148166612845}, {
            4.904910198976184, -2.1619563547159752`}, {
            5.001099999999999, -2.1618697402349736`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.1629074895829916`}, {-4.820335472182759, 
            2.1629213845688433`}, {-4.6197619061877075`, 
            2.1629368022334443`}, {-4.419188340192656, 
            2.1629522198980458`}, {-4.218614774197604, 
            2.162967637562647}, {-4.166106325953146, 2.162971673775693}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231484101975, 
            2.1629732783805107`}, {-4.018041208202552, 
            2.162983055227248}, {-3.8174676422075007`, 
            2.1629984728918497`}, {-3.6570038707367942`, 
            2.1629984554973034`}, {-3.4965397495390467`, 
            2.162998276173531}, {-3.4804933078218347`, 
            2.162998249278524}, {-3.464446863432505, 
            2.162998221807781}, {-3.4564236399273143`, 
            2.162998207810083}, {-3.4484004157763812`, 
            2.1629981936905316`}, {-3.4403771909860303`, 
            2.162998179455177}, {-3.4323539655625686`, 
            2.1629981651099506`}, {-3.424330739512268, 
            2.1629981506607097`}, {-3.3102378085569932`, 
            2.162997943790478}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629666441857`, 
            2.1629979055714443`}, {-3.161156501579246, 
            2.1629976591048496`}, {-3.0436956646796487`, 
            2.1629974367864397`}, {-2.9262348277800516`, 
            2.16299721446803}, {-2.8087739908804545`, 
            2.16299699214962}, {-2.691313153980857, 
            2.16299676983121}, {-2.57385231708126, 
            2.1629965475128}, {-2.4563914801816624`, 
            2.1629963251943907`}, {-2.454369290131984, 
            2.1629963213669865`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4334944482191787`, 
            2.1629962818571227`}, {-2.3389306432820653`, 
            2.1629961028759808`}, {-2.221469806382468, 
            2.162995880557571}, {-2.1913199296676416`, 
            2.1629958659389628`}, {-2.1611700523834116`, 
            2.1629958524523993`}, {-2.0612050740986168`, 
            2.1629958221580097`}, {-1.961240093854657, 
            2.162995800976082}, {-1.9571024299074549`, 
            2.1629958001075353`}, {-1.947907621125548, 
            2.1629957982593266`}, {-1.9387128123361543`, 
            2.1629957964785818`}, {-1.8467647242368443`, 
            2.1629957847276455`}, {-1.7548166367256313`, 
            2.162995777837942}, {-1.6398815435822107`, 
            2.1629957804011837`}, {-1.598500771705869, 
            2.1629957813240432`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259297930264`, 
            2.1629957817895864`}, {-1.5249464504387902`, 
            2.1629957829644257`}, {-1.4100113572953699`, 
            2.1629957855276674`}, {-1.2950762641519493`, 
            2.162995788090909}, {-1.180141171008529, 
            2.162995790654151}, {-1.0652060778651085`, 
            2.1629957932173927`}, {-0.950270984721688, 
            2.1629957957806347`}, {-0.8353358915782675, 
            2.1629957983438763`}, {-0.7426322532793221, 
            2.1629957984204777`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574113664795, 
            2.162995798437727}, {-0.7204007994808119, 
            2.162995798438848}, {-0.6054657073833565, 
            2.1629957985338195`}, {-0.49053061528590103`, 
            2.1629957986287915`}, {-0.37559552318844536`, 
            2.162995798723763}, {-0.26066043109098974`, 
            2.1629957988187347`}, {-0.14572533899353407`, 
            2.1629957989137063`}, {-0.03079024689607887, 
            2.1629957990086783`}, {0.08414484520137677, 2.16299579910365}, {
            0.1132362651450341, 2.1629954420917947`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1341111070563048, 2.162995185914336}, {
            0.22150923381436982`, 2.1629941133586668`}, {0.35887362242736387`,
             2.1629924276136836`}, {0.4962380110403575, 
            2.1629907418687004`}, {0.6336023996533511, 2.1629890561237173`}, {
            0.7709667882663447, 2.162987370378734}, {0.9083311768793383, 
            2.1629856846337505`}, {0.9691047835071328, 
            2.1629849388159768`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796254184035, 2.162984682638518}, {
            1.045695565492332, 2.1629839988887674`}, {1.1830599541053255`, 
            2.162982313143784}, {1.320424342718319, 2.162980627398801}, {
            1.4577887313313127`, 2.162978941653818}, {1.5951531199443063`, 
            2.1629772559088343`}, {1.7325175085573004`, 2.162975570163851}, {
            1.8249733018692313`, 2.1629744355401592`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.845848143780502, 2.1629741793627004`}, {
            1.869881897170294, 2.162973884418868}, {2.0072462857832876`, 
            2.162972198673885}, {2.144610674396281, 2.1629705129289016`}, {
            2.2819750630092748`, 2.162968827183918}, {2.4193394516222693`, 
            2.162967141438935}, {2.556703840235263, 2.1629654556939517`}, {
            2.68084182023133, 2.1629639322643417`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.7017166621426005`, 2.1629636760868824`}, {
            2.83143261746125, 2.162962084203985}, {2.9687970060742437`, 
            2.162960398459002}, {3.1061613946872377`, 2.1629587127140186`}, {
            3.243525783300231, 2.1629570269690355`}, {3.380890171913225, 
            2.1629553412240523`}, {3.518254560526218, 2.1629536554790687`}, {
            3.5367103385934286`, 2.1629534289885233`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.557585180504699, 2.1629531728110645`}, {
            3.655618949139212, 2.1629519697340855`}, {3.7929833377522058`, 
            2.1629502839891024`}, {3.9303477263651994`, 
            2.1629485982441192`}, {4.0677121149781925`, 2.162946912499136}, {
            4.205076503591187, 2.1629452267541525`}, {4.34244089220418, 
            2.1629435410091693`}, {4.392578856955527, 2.1629429257127057`}}]}, 
          {Arrowheads[{{0.01407547216432203, 1.}}], 
           ArrowBox[{{4.413453698866798, 2.162942669535247}, {
            4.479805280817174, 2.162941855264186}, {4.692777738659196, 
            2.162750046113403}, {4.9057501965012165`, 2.162558236962619}, {
            5.001099999999999, 2.1624723621738235`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.6916798037135163`}, \
{-4.89963506942341, -3.6916739007811583`}, {-4.781322997504322, \
-3.691667017731481}, {-4.663010925585233, -3.691660134681803}, \
{-4.544698853666144, -3.691653251632126}, {-4.4263867817470555`, \
-3.6916463685824485`}, {-4.264999382476973, -3.6916367218567707`}, \
{-4.166106324877753, -3.6916316400579006`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231482992472, -3.6916305673663437`}, \
{-4.103610335749629, -3.6916284285883125`}, {-3.9862956347535325`, \
-3.6916233555518607`}, {-3.8689809337574363`, -3.691618282515409}, \
{-3.7516662327613406`, -3.691613209478957}, {-3.6343515317652444`, \
-3.691608136442505}, {-3.517036830769148, -3.691603063406053}, \
{-3.3997221297730524`, -3.6915979903696012`}, {-3.310237807275505, \
-3.691594120801456}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.28936296538218, -3.6915932181112314`}, \
{-3.2824074287769562`, -3.6915929173331494`}, {-3.1650927277808596`, \
-3.6915878442966976`}, {-3.134369652305425, -3.691587592540305}, \
{-3.1036465782702396`, -3.6915873625028306`}, {-2.973877939765894, \
-3.691586811654772}, {-2.8441093927479812`, -3.6915865325435604`}, \
{-2.687146858605531, -3.691586120324888}, {-2.5301843244630806`, \
-3.691585708106216}, {-2.454369288989372, -3.6915855089989993`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494447076601, -3.691585454177002}, \
{-2.373221790320631, -3.6915852958875432`}, {-2.216259256178181, \
-3.6915848836688707`}, {-2.0592967220357306`, -3.6915844714501986`}, \
{-1.9023341878932811`, -3.691584059231526}, {-1.7453716537508304`, \
-3.691583647012854}, {-1.598500770565776, -3.6915832612971107`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259286530054`, -3.6915832064751135`}, \
{-1.4314465854659306`, -3.6915828225755094`}, {-1.2744840513234803`, \
-3.691582410356837}, {-1.1175215171810304`, -3.691581998138165}, \
{-0.9605589830385806, -3.6915815859194923`}, {-0.8035964488961302, \
-3.69158117370082}, {-0.7426322521421805, -3.691581013595223}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574102294099, -3.691580958773226}, \
{-0.6466339147536799, -3.6915807614821476`}, {-0.4896713806112296, \
-3.691580349263475}, {-0.3327088464687802, -3.691579937044803}, \
{-0.1757463123263303, -3.6915795248261305`}, {-0.018783778183879996`, \
-3.6915791126074584`}, {0.11323626628141506`, -3.691578765893335}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110819418567`, -3.6915787110713376`}, {
            0.13817875595856988`, -3.691578700388786}, {
            0.2951412901010202, -3.691578288170114}, {
            0.4521038242434705, -3.6915778759514413`}, {
            0.6090663583859202, -3.691577463732769}, {
            0.76602889252837, -3.6915770515140967`}, {
            0.9229914266708201, -3.691576639295424}, {
            0.9691047847050106, -3.6915765181914466`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796266177813, -3.6915764633694494`}, {
            1.0799539608132696`, -3.691576227076752}, {
            1.2369164949557196`, -3.6915758148580795`}, {
            1.3938790290981697`, -3.6915754026394074`}, {
            1.55084156324062, -3.691574990420735}, {
            1.7078040973830704`, -3.691574578202063}, {
            1.8249733031286062`, -3.6915742704895584`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458481450413768`, -3.6915742156675613`}, {
            1.8647666315255205`, -3.6915741659833903`}, {
            2.0217291656679706`, -3.691573753764718}, {
            2.178691699810421, -3.6915733415460457`}, {
            2.333603890575591, -3.6912718900759414`}, {
            2.4905604237130357`, -3.691270596766777}, {
            2.647512956180474, -3.6912687160639517`}, {
            2.6808415282286595`, -3.691268191954993}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.701716370138921, -3.691267863687354}, {
            2.8044614879779077`, -3.6912662479674645`}, {
            2.961406019105337, -3.6912631924773165`}, {
            3.118346549562763, -3.6912595495935068`}, {
            3.275283079350184, -3.691255319316036}, {
            3.4322156084676014`, -3.6912505016449035`}, {
            3.536710046374955, -3.6912469025593}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5575848882754153`, -3.691246183570381}, {
            3.5891441369150137`, -3.6912450965801096`}, {
            3.7460686646924217`, -3.691239104121655}, {
            3.9029891917998247`, -3.6912325242695383`}, {
            4.059905718237224, -3.691225357023761}, {
            4.216818244004619, -3.691217602384322}, {
            4.373726769102008, -3.6912092603512217`}, {
            4.392578563910452, -3.6912081874967475`}}]}, 
          {Arrowheads[{{0.014075474148057964`, 1.}}], 
           ArrowBox[{{4.4134534057894905`, -3.69120699951079}, {
            4.530631293529394, -3.69120033092446}, {
            4.687531817286775, -3.6911908141040373`}, {
            4.844428340374151, -3.6911807098899527`}, {
            5.001099999999999, -3.691170033333137}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.456476187209355}, \
{-4.923652593445322, -4.45645440292092}, {-4.809928363400284, \
-4.456422414742883}, {-4.696204133355247, -4.456390426564846}, \
{-4.58247990331021, -4.456358438386809}, {-4.468755673265172, \
-4.456326450208773}, {-4.355031443220135, -4.456294462030736}, \
{-4.241307213175098, -4.4562624738527}, {-4.166106356517632, \
-4.456241321470395}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231515430574, -4.45623544982692}, \
{-4.12758298313006, -4.456230485674663}, {-4.013858753085023, \
-4.456198497496626}, {-3.900134523039985, -4.45616650931859}, \
{-3.7543956306273594`, -4.456160746889638}, {-3.608656838228404, \
-4.456156649832176}, {-3.491276063364802, -4.456154499687375}, \
{-3.3738952885011995`, -4.456152349542574}, {-3.3102378488341855`, \
-4.456151183485244}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.289363006924845, -4.456150801106333}, \
{-3.2565145136375975`, -4.456150199397773}, {-3.139133738773995, \
-4.456148049252971}, {-3.021752963910393, -4.45614589910817}, \
{-2.904372189046791, -4.4561437489633695`}, {-2.7869914141831886`, \
-4.456141598818569}, {-2.6696106393195866`, -4.456139448673768}, \
{-2.639137099634201, -4.4561397862123036`}, {-2.6086635836441743`, \
-4.456140129484718}, {-2.494547936237851, -4.4561414663610375`}, \
{-2.4543693305294627`, -4.456141933297695}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944886180296`, -4.456142175895185}, \
{-2.3804325812457225`, -4.456142792555451}, {-2.2364973348953545`, \
-4.45614277552336}, {-2.0925620885449865`, -4.45614275849127}, \
{-1.948626842194618, -4.456142741459179}, {-1.8046915958442495`, \
-4.456142724427089}, {-1.6607563494938815`, -4.456142707394998}, \
{-1.5985008121079138`, -4.4561427000282}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259701950714`, -4.456142697558046}, \
{-1.5168211031435133`, -4.456142690362908}, {-1.3728858567931452`, \
-4.456142673330818}, {-1.2289506104427768`, -4.456142656298727}, \
{-1.0850153640924085`, -4.456142639266637}, {-0.9410801177420403, \
-4.456142622234546}, {-0.7971448713916721, -4.456142605202456}, \
{-0.7426322936813728, -4.456142598751894}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574517685303, -4.45614259628174}, \
{-0.653209625041304, -4.456142588170366}, {-0.5092743786909358, \
-4.456142571138275}, {-0.3653391323405677, -4.456142554106185}, \
{-0.2214038859901991, -4.456142537074094}, {-0.07746863963983097, \
-4.456142520042004}, {0.06646800546797449, -4.456140937963652}, {
            0.11323622473364978`, -4.456140423911187}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411106664523142`, -4.456140194465548}, {
            0.2104046505757804, -4.4561393558853}, {
            0.35434129568358563`, -4.456137773806948}, {
            0.4982779407913911, -4.456136191728596}, {
            0.6422145858991966, -4.4561346096502445`}, {
            0.7861512310070018, -4.456133027571894}, {
            0.9300878761148073, -4.456131445493542}, {
            0.9691047431084967, -4.456131016639996}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899795850200783, -4.456130787194358}, {
            1.0740245212226127`, -4.45612986341519}, {
            1.2179611663304186`, -4.456128281336838}, {
            1.361897811438224, -4.456126699258486}, {
            1.5058344565460293`, -4.456125117180134}, {
            1.6497711016538352`, -4.456123535101782}, {
            1.7937077467616411`, -4.45612195302343}, {
            1.8249732614833436`, -4.456121609368804}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481033949252`, -4.456121379923165}, {
            1.937644391869446, -4.4561203709450785`}, {
            2.081581036977251, -4.456118788866727}, {
            2.225517682085057, -4.456117206788375}, {
            2.369347316968266, -4.456172440811955}, {
            2.5131769518514737`, -4.456227674835537}, {
            2.6570065867346813`, -4.456282908859118}, {
            2.680841746311377, -4.456292062131093}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7017165866849675`, -4.456300078569613}, {
            2.8008362216178897`, -4.456338142882698}, {
            2.944665856501098, -4.45639337690628}, {
            3.088495491384306, -4.45644861092986}, {
            3.2323251262675137`, -4.456503844953441}, {
            3.376154761150722, -4.456559078977023}, {
            3.5199843960339305`, -4.456614313000603}, {
            3.5367102016285874`, -4.456620736110426}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.5575850420021777`, -4.456628752548946}, {
            3.663814030917138, -4.456669547024184}, {
            3.8076436658003456`, -4.456724781047765}, {
            3.951473300683554, -4.456780015071346}, {
            4.095302935566763, -4.456835249094927}, {
            4.239132570449971, -4.456890483118507}, {
            4.38296220533318, -4.456945717142089}, {
            4.392578656945798, -4.45694941008976}}]}, 
          {Arrowheads[{{0.014075472965629564`, 1.}}], 
           ArrowBox[{{4.413453497319388, -4.45695742652828}, {
            4.526791840216387, -4.45700095116567}, {
            4.670621475099595, -4.45705618518925}, {
            4.814451109982803, -4.457111419212832}, {
            4.958280744866012, -4.4571666532364125`}, {
            5.001099999999999, -4.457183096855627}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQ3WShpKbF9sH+0X+hLXfXm9gbzPl9/YDYB3vGqRB+
iOzPE0rqH+zZtSH81TtunPnm/MFeIV8QzN9ytvZzbfQH+/YrAmA+h1hs6uzq
D/Y6//nB/FWhJ+rUl3+wX3eDD8y3LhO+r3bgg72kHoQfsNcgPu3OB/veLF4w
/8emqf/LJD7aM+7jBvNPvoxonhP20d7kNieYLzHzQsMdr0/2ETMZwfxfjeKf
OjM/2wfJfd4M4tdnnF09z+ur/Uu+c2A+s39z6mbt7/YN/1eA+R2mlvIneH7a
S3xoBvN5Zd7fuPP2l/36B3Fg/iSmpZM+nvtj73bREsxvkimq8kn6a+9Rrgfm
AwDy9Jrt
            "]]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8573735585568447`, 0.00031565821259917174`}, {
            1.917974756490883, 0.00031565821253123715`}, {2.0354261624279166`,
             0.00031565821239957294`}, {2.15287756836495, 
            0.0003156582122679087}, {2.1830719482339087`, 
            0.0003156582104500702}, {2.213266328467798, 
            0.00031565820845020357`}, {2.3148787373129522`, 
            0.00031565819840031654`}, {2.416491153684432, 
            0.00031565818492869244`}, {2.4200335703152165`, 
            0.00031565818445553333`}, {2.4469070763942717`, 
            0.00031565818059917984`}, {2.4713375370789348`, 
            0.0003156581768255307}, {2.593489881616822, 
            0.00031565814106488256`}, {2.692367235070549, 
            0.00031565811211809266`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.713242076983392, 0.00031565810600688883`}, {
            2.7156422261547095`, 0.0003156581053042344}, {2.837794646061308, 
            0.00031565804141291234`}, {2.959947065967907, 
            0.00031565797752159037`}, {3.1126554094460643`, 
            0.0003156541962353897}, {3.265363752924222, 
            0.00031565041494918905`}, {3.41807209640238, 
            0.0003156466336629884}, {3.548235753497096, 
            0.0003156434106168261}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5691105954099385`, 0.00031564289372462576`}, {
            3.5707804398805374`, 0.00031564285237678773`}, {3.723488783358695,
             0.0003156390710905871}, {3.8761971268368525`, 
            0.0003156352898043864}, {4.02890547031501, 
            0.00031563150851818576`}, {4.181613813793168, 
            0.0003156277272319851}, {4.334322157271325, 
            0.00031562394594578444`}, {4.404104271923643, 
            0.00031562221803661344`}}]}, 
          {Arrowheads[{{0.013799407166026803`, 1.}}], 
           ArrowBox[{{4.424979113836486, 0.0003156217011444131}, {
            4.4870305007494835`, 0.0003156201646595838}, {4.639738844227641, 
            0.0003156163833733832}, {4.792447187705799, 
            0.0003156126020871825}, {4.945155531183956, 
            0.00031560882080098186`}, {5.001099999999999, 
            0.0003156074355325471}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.000317273199926499}, {-4.978332273873804, 
            0.0003172776223227946}, {-4.865320418856539, 
            0.00031729957371162546`}, {-4.752308563839275, 
            0.00031732152510045625`}, {-4.639296708822009, 
            0.0003173434764892871}, {-4.526284853804745, 
            0.0003173654278781179}, {-4.4132729987874795`, 
            0.00031738737926694866`}, {-4.300261143770215, 
            0.00031740933065577945`}, {-4.166106323486308, 
            0.00031741014869596484`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481573465, 
            0.00031741027598516334`}, {-4.142620684308732, 
            0.0003174102919051062}, {-3.98498107509814, 
            0.00031741104920075564`}, {-3.8676475647414064`, 
            0.00031741148834585364`}, {-3.7503140543846727`, 
            0.00031741192749095164`}, {-3.632980544027939, 
            0.0003174123666360497}, {-3.5156470336712053`, 
            0.0003174128057811477}, {-3.3983135233144717`, 
            0.0003174132449262457}, {-3.310237805059761, 
            0.00031741357456796363`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629631469183`, 
            0.0003174136526964068}, {-3.280980012957738, 
            0.0003174136840713437}, {-3.1636465026010043`, 
            0.00031741412321644174`}, {-3.0463129922442707`, 
            0.00031741456236153973`}, {-3.015641164063997, 
            0.0003174145819238297}, {-2.984969339539346, 
            0.00031741460020417387`}, {-2.858953592745447, 
            0.00031741465268728553`}, {-2.732937881929087, 
            0.00031741469141060864`}, {-2.724254989841877, 
            0.0003174146940220078}, {-2.7155720978960045`, 
            0.0003174146965776632}, {-2.706889206088441, 
            0.00031741469907858}, {-2.698206314416224, 
            0.0003174147015257468}, {-2.6895234228764537`, 
            0.0003174147039201362}, {-2.672157640309609, 
            0.00031741470850354746`}, {-2.654791858233359, 
            0.000317414712889062}, {-2.481134076056245, 
            0.00031741474059814365`}, {-2.454369286633214, 
            0.00031741474320243045`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944447203712`, 
            0.0003174147452336093}, {-2.307476317872987, 
            0.0003174147574955159}, {-2.0904041516453993`, 
            0.0003174147625455935}, {-1.8733319854178112`, 
            0.000317414767595671}, {-1.6562598257858703`, 
            0.0003174147684071606}, {-1.5985007682066668`, 
            0.00031741476862308366`}}]}, 
          {Arrowheads[{{0.014940810726197169`, 1.}}], 
           ArrowBox[{{-1.5776259262938241`, 
            0.0003174147687011209}, {-1.439187666153929, 
            0.0003174147692186502}, {-1.2221155071931462`, 
            0.00031741476947624853`}, {-1.1678474674718027`, 
            0.0003174147695229176}, {-1.1135794277640099`, 
            0.0003174147695561465}, {-1.086445407912718, 
            0.00031741476957006205`}, {-1.0593113880636007`, 
            0.00031741476958165374`}, {-1.0041500062801363`, 
            0.0003174147695974726}, {-0.9924999258527796, 
            0.00031741476960069943`}, {-0.9833190634614062, 
            0.00031741476960319326`}, {-0.9694447478753098, 
            0.00031741476960692877`}, {-0.9621506732657462, 
            0.0003174147696088517}, {-0.9580388974002424, 
            0.00031741476960992594`}, {-0.953851802375686, 
            0.00031741476961101437`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.6923476975263503`}, {-4.907500243178262, 
            3.6923556958205994`}, {-4.690951811142647, 
            3.692374200335328}, {-4.474403379107033, 
            3.692392704850056}, {-4.257854947071417, 
            3.692411209364784}, {-4.166106326534881, 3.692419049475581}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231484698253, 
            3.692420833274312}, {-4.041306515035802, 
            3.6924297138795126`}, {-3.824758083000187, 
            3.6924482183942406`}, {-3.6082096509645716`, 
            3.6924667229089687`}, {-3.4348407705493784`, 
            3.692462976161467}, {-3.3102378102148156`, 
            3.692460283314693}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629683068477`, 
            3.6924598321797397`}, {-3.2614718901341853`, 
            3.6924592294139655`}, {-3.088103009718992, 
            3.6924554826664644`}, {-2.914734129303799, 
            3.692451735918963}, {-2.7413652488886053`, 
            3.692447989171461}, {-2.567996368473412, 
            3.6924442424239596`}, {-2.4543692919881366`, 
            3.6924417867816097`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944500801687`, 
            3.6924413356466563`}, {-2.394627488058219, 
            3.6924404956764585`}, {-2.2212586076430254`, 
            3.6924367489289565`}, {-2.047890355821234, 
            3.6924371924440105`}, {-1.8745221039994424`, 
            3.6924376359590645`}, {-1.7011538521776508`, 
            3.692438079474118}, {-1.598500773618065, 
            3.6924383420838245`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259317052908`, 
            3.692438395486374}, {-1.5277856003558594`, 
            3.692438522989172}, {-1.354417348534068, 
            3.692438966504226}, {-1.1810490967122764`, 
            3.69243941001928}, {-1.007680844890485, 
            3.692439853534334}, {-0.834312593068694, 
            3.692440297049388}, {-0.7426322551940208, 3.692440316097926}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574132811786, 
            3.692440320435118}, {-0.6956186532236447, 
            3.6924403258660004`}, {-0.5569247141973306, 
            3.6924403319209436`}, {-0.5430553200018424, 
            3.6924403311370053`}, {-0.5257879241650617, 
            3.692440330022813}, {-0.48040833193448107`, 
            3.6924403268110852`}, {-0.43502873921244267`, 
            3.692440322884502}, {-0.3166943774771064, 
            3.692440311447675}, {-0.19836001574176992`, 
            3.692440300010848}, {-0.08002565400643347, 3.692440288574021}, {
            0.038308707728902824`, 3.6924402771371936`}, {
            0.11323626323252221`, 3.692440269895565}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110514536473`, 3.692440267878045}, {
            0.15664306946423912`, 3.6924402657003665`}, {0.27497743119957563`,
             3.6924402542635395`}, {0.3933117929349119, 
            3.6924402428267125`}, {0.5116461546702483, 3.6924402313898854`}, {
            0.5382925648486991, 3.6924402334232895`}, {0.5649389748638829, 
            3.6924402351658627`}, {0.6144266899985473, 3.6924402362768216`}, {
            0.6639144047834462, 3.6924402355210426`}, {0.6675373427958098, 
            3.6924402354582653`}, {0.6823248448629182, 3.6924402349946908`}, {
            0.6971123469121123, 3.692440234328125}, {0.8449873685948924, 
            3.692440201333886}, {0.9691047816590496, 
            3.6924401423762707`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796235718898, 3.6924401324604106`}, {
            0.9928623990174681, 3.6924401310910495`}, {1.1777074112391739`, 
            3.6924398391521027`}, {1.3625524234608795`, 3.692439547213155}, {
            1.5473974356825853`, 3.692439255274208}, {1.7322424479042908`, 
            3.6924389633352606`}, {1.824973300084556, 3.692438816878794}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8458481419973727`, 3.6924387839096635`}, {
            1.9170874601259964`, 3.6924386713963133`}, {2.1019324723477024`, 
            3.692438379457366}, {2.286777484569408, 3.692438087518419}, {
            2.4716224967911136`, 3.6924377955794716`}, {2.6564664331548844`, 
            3.692444438109841}, {2.680841818375205, 3.6924453140608717`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.701716660274569, 3.6924460642167816`}, {
            2.841310369518656, 3.6924510806402107`}, {3.0261543058824274`, 
            3.6924577231705804`}, {3.2109982422461987`, 3.69246436570095}, {
            3.3958421786099704`, 3.69247100823132}, {3.536710336249123, 
            3.692476070453179}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.557585178148487, 3.6924768206090888`}, {
            3.5806861149737412`, 3.692477650761689}, {3.7655300513375125`, 
            3.692484293292059}, {3.9503739877012842`, 3.6924909358224287`}, {
            4.065774989377758, 3.6924575545850638`}, {4.181175991054232, 
            3.6924241733476992`}, {4.2965769927307065`, 
            3.6923907921103343`}, {4.392578835908252, 3.69236302233132}}]}, 
          {Arrowheads[{{0.014075468214103914`, 1.}}], 
           ArrowBox[{{4.413453676947764, 3.6923569840126436`}, {
            4.527378996083655, 3.692324029635605}, {4.64277999776013, 
            3.69229064839824}, {4.758180999436604, 3.692257267160875}, {
            4.873582001113078, 3.6922238859235104`}, {4.988983002789553, 
            3.6921905046861454`}, {5.001099999999999, 
            3.6921869996874523`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5943513594427685, 
            1.023622227422012}, {-0.5469325701368665, 
            1.023622227425118}, {-0.49951378083285874`, 
            1.023622227428378}, {-0.3810926623538634, 
            1.0236222274357856`}, {-0.262671543874868, 
            1.023622227443193}, {-0.14425042539587268`, 
            1.0236222274506006`}, {-0.025829306916877348`, 
            1.023622227458008}, {0.09259181156211799, 1.0236222274654156`}, {
            0.21101293004111338`, 1.023622227472823}, {0.2406423170709358, 
            1.0236222274746765`}}]}, 
          {Arrowheads[{{0.007996840139707508, 1.}}], 
           ArrowBox[{{0.2615171589837784, 1.0236222274759823`}, {
            0.32943404852010855`, 1.0236222274802307`}, {0.44785516699910405`,
             1.023622227487638}, {0.47416947334759896`, 
            1.0236222274863385`}, {0.500483779696446, 1.0236222274848465`}, {
            0.5479332430578292, 1.0236222274815825`}, {0.5953827064211152, 
            1.023622227478484}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5938505644023719, -1.0231186718333385`}, \
{-0.5464466696141624, -1.0231186718364285`}, {-0.4990427748278379, \
-1.0231186718396694`}, {-0.3806222909651602, -1.0231186718470318`}, \
{-0.26220180710248236`, -1.023118671854394}, {-0.14378132323980458`, \
-1.0231186718617566`}, {-0.025360839377126854`, -1.023118671869119}, {
            0.09305964448555082, -1.0231186718764813`}, {
            0.2114801283482285, -1.0231186718838436`}, {
            0.24114311211133244`, -1.0231186718856877`}}]}, 
          {Arrowheads[{{0.007996840200808663, 1.}}], 
           ArrowBox[{{0.26201795402417505`, -1.0231186718869856`}, {
            0.3299006122109063, -1.023118671891206}, {
            0.44832109607358395`, -1.0231186718985685`}, {
            0.47463794208696897`, -1.023118671897271}, {
            0.5009547881007064, -1.0231186718957823`}, {
            0.5484191460556352, -1.0231186718925334`}, {
            0.5958835040124658, -1.023118671889459}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.643178838052145, -1.2155199804459147`}, {
            0.7608279745343665, -1.2155199804155905`}, {
            0.8784771110165879, -1.2155199803852665`}, {
            0.9961262474988093, -1.2155199803549424`}, {
            1.1137753839810307`, -1.2155199803246182`}, {
            1.2314245204632521`, -1.215519980294294}, {
            1.3490736569454738`, -1.2155199802639698`}, {
            1.466722793427695, -1.2155199802336456`}, {
            1.4781725145658493`, -1.215519980369215}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.499047356478692, -1.2155199806193844`}, {
            1.5255262613700595`, -1.2155199809601107`}, {
            1.6053904137083523`, -1.2155199822926495`}, {
            1.6852545654793785`, -1.2155199838240638`}, {
            1.69311827321191, -1.2155199839762605`}, {
            1.6994345043173236`, -1.215519984099803}, {
            1.7625968149056273`, -1.215519985423097}, {
            1.8257591249348377`, -1.2155199867885815`}, {
            1.983664869563411, -1.215519968370407}, {
            2.1415706141919846`, -1.2155199499522322`}, {
            2.299476358820558, -1.2155199315340575`}, {
            2.334041032992393, -1.215519927502423}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.3549158749052355`, -1.2155199250675752`}, {
            2.4573821034491314`, -1.2155199131158827`}, {
            2.6152878076293606`, -1.2155197143499246`}, {
            2.77319351180959, -1.2155195155839664`}, {
            2.931099215989819, -1.2155193168180085`}, {
            3.0890049201700482`, -1.2155191180520504`}, {
            3.189909547842068, -1.2154922527441254`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.210784389015042, -1.2154866949312784`}, {
            3.3114617755997613`, -1.215459890125056}, {
            3.4226902033146174`, -1.2154302761615585`}, {
            3.5339186310294735`, -1.215400662198061}, {
            3.6451470587443295`, -1.2153710482345639`}, {
            3.7563754864591856`, -1.2153414342710664`}, {
            3.8676039141740417`, -1.215311820307569}, {
            3.9788323418888982`, -1.2152822063440718`}, {
            4.045778035933998, -1.2152643824173968`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.066652877106972, -1.2152588246045497`}, {
            4.090060769603754, -1.2152525923805744`}, {
            4.20128919731861, -1.215222978417077}, {
            4.3125176250334665`, -1.2151933644535797`}, {
            4.4237460527483226`, -1.2151637504900823`}, {
            4.534974480463179, -1.2151341365265849`}, {
            4.646202908178035, -1.2151045225630877`}, {
            4.757431335892892, -1.2150749085995902`}, {
            4.868659763607748, -1.2150452946360928`}, {
            4.901646524025929, -1.215036512090668}}]}, 
          {Arrowheads[{{0.001882137309452443, 1.}}], 
           ArrowBox[{{4.922521365198903, -1.215030954277821}, {
            4.979888191322604, -1.2150156806725956`}, {
            5.001099999999999, -1.2150100331439846`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.5196297050109981`}, {-4.9858608438214045`, 
            1.5196306200373506`}, {-4.835643657171011, 
            1.5196396397417722`}, {-4.685426470520618, 
            1.519648659446194}, {-4.535209283870223, 
            1.5196576791506156`}, {-4.384992097219829, 
            1.5196666988550374`}, {-4.234774910569435, 
            1.519675718559459}, {-4.16610632499151, 1.5196798417251152`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231483116298, 
            1.519681095142968}, {-4.084557723919041, 
            1.5196847382638807`}, {-3.934340537268647, 
            1.5196937579683023`}, {-3.7841233506182537`, 
            1.519702777672724}, {-3.6339061639678594`, 
            1.5197117973771457`}, {-3.4836889773174655`, 
            1.5197208170815675`}, {-3.3334717906670717`, 
            1.519729836785989}, {-3.3102378081078085`, 
            1.519731231857085}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629662325963`, 
            1.5197324852749379`}, {-3.1832546040166774`, 
            1.5197388564904108`}, {-3.033037417366284, 
            1.5197478761948324`}, {-2.8828202307158897`, 
            1.5197568958992542`}, {-2.732603044065496, 
            1.5197659156036758`}, {-2.6124312866149255`, 
            1.519765920565816}, {-2.4922595291643557`, 
            1.519765925527956}, {-2.4543692907225445`, 
            1.5197659217395931`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494448809702, 
            1.519765919652473}, {-2.3720877350144045`, 
            1.5197659135128727`}, {-2.2519159408644533`, 
            1.5197659014977893`}, {-2.2278815771401006`, 
            1.5197658985192308`}, {-2.2014437765999832`, 
            1.5197658952787836`}, {-2.1979587937483975`, 
            1.519765894857743}, {-2.1028459314176775`, 
            1.5197658833862644`}, {-2.007733064357321, 
            1.5197658728827208`}, {-1.8898102299372412`, 
            1.5197658614702023`}, {-1.7718873955171617`, 
            1.5197658500576838`}, {-1.6539645610970823`, 
            1.5197658386451653`}, {-1.598500772296002, 
            1.5197658332774049`}}]}, 
          {Arrowheads[{{0.016691574224503705`, 1.}}], 
           ArrowBox[{{-1.5776259303831595`, 
            1.5197658312571471`}, {-1.5360417266770028`, 
            1.5197658272326469`}, {-1.4181188922569232`, 
            1.5197658158201282`}, {-1.3001960578368439`, 
            1.5197658044076097`}, {-1.182273223416764, 
            1.5197657929950912`}, {-1.0643503889966845`, 
            1.5197657815825727`}, {-1.0360444529656556`, 
            1.5197657815974923`}, {-1.007738516948307, 
            1.5197657816264019`}, {-0.9442482504206307, 
            1.5197657817557158`}, {-0.8807579839571753, 
            1.5197657819025656`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.675873029665423, 1.0823755117931497`}, {
            0.793467238821905, 1.0823755117819247`}, {0.9110614479783871, 
            1.0823755117706997`}, {1.028655657134869, 1.0823755117594747`}, {
            1.1462498662913512`, 1.0823755117482496`}, {1.263844075447833, 
            1.0823755117370246`}, {1.3814382846043152`, 
            1.0823755117257996`}, {1.4990324937607973`, 
            1.0823755117145748`}, {1.5108667061791272`, 
            1.0823755117134453`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5317415480919698`, 1.0823755117114526`}, {
            1.6166267029172792`, 1.0823755117033498`}, {1.6462485021762798`, 
            1.082375511960226}, {1.6758703013739893`, 1.0823755122177878`}, {
            1.7604887494910078`, 1.0823755128414352`}, {1.8451071968209203`, 
            1.0823755132034678`}, {1.8531635842444265`, 
            1.0823755132351376`}, {1.8596345781526167`, 
            1.0823755132578152`}, {1.9243445166761213`, 
            1.0823755131920416`}, {1.9890544545680509`, 
            1.0823755126981687`}, {2.150829278334058, 1.0823754558291294`}, {
            2.3126041021000647`, 1.08237539896009}, {2.366735224605651, 
            1.082375379931264}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.387610066518492, 1.0823753725930876`}, {
            2.474378925866071, 1.0823753420910507`}, {2.636153749632078, 
            1.0823752852220112`}, {2.797928625275274, 1.0823749269480087`}, {
            2.95970350091847, 1.0823745686740063`}, {3.121478376561666, 
            1.0823742104000036`}, {3.222603743030743, 1.0823739864431645`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.2434785849435346`, 1.0823739402127894`}, {
            3.2832532522048616`, 1.0823738521260011`}, {3.4944432935496463`, 
            1.0823216453658875`}, {3.705633334894432, 1.0822694386057736`}, {
            3.916823376239217, 1.08221723184566}, {4.078472237159543, 
            1.0821772718018483`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.099347078434564, 1.0821721114835685`}, {
            4.128013417584002, 1.0821650250855464`}, {4.339203458928788, 
            1.0821128183254327`}, {4.550393500273573, 1.0820606115653189`}, {
            4.761583541618359, 1.0820084048052052`}, {4.9343407294353705`, 
            1.081965698752378}}]}, 
          {Arrowheads[{{0.001099036603083441, 1.}}], 
           ArrowBox[{{4.955215570710391, 1.0819605384340982`}, {
            4.9727735829631445`, 1.0819561980450916`}, {5.001099999999999, 
            1.0819491956767522`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.006491469464451509, 1.}}], 
           ArrowBox[{{-0.7423226425881997, 
            1.368046977351826}, {-0.6239919342653705, 
            1.3680469745162274`}, {-0.5973169495374188, 
            1.36804697453743}, {-0.5706419648123795, 
            1.368046974556836}, {-0.5209739048451609, 
            1.368046974582593}, {-0.4713058448832591, 
            1.3680469746016717`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.0198343045551424, 1.}}], 
           ArrowBox[{{-0.7082034307060625, 
            1.5930487180923287`}, {-0.5889373934342557, 
            1.593048718486099}, {-0.4696713561624486, 
            1.5930487188798697`}, {-0.35040531889064164`, 
            1.5930487192736402`}, {-0.23113928161883468`, 
            1.5930487196674108`}, {-0.11187324434702772`, 
            1.5930487200611814`}, {0.007392792924778971, 
            1.5930487204549517`}, {0.030325692019334546`, 
            1.5930487204551729`}, {0.05325859111382857, 
            1.5930487204560704`}, {0.08656555224396992, 
            1.5930487204594757`}, {0.11987251337348084`, 
            1.5930487204637385`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.7561305999502189}, {-4.934614018951054, 
            0.7561357915528912}, {-4.8208862133838455`, 
            0.7561446720652937}, {-4.707158407816637, 
            0.7561535525776961}, {-4.593430602249429, 
            0.7561624330900986}, {-4.479702796682221, 
            0.756171313602501}, {-4.365974991115013, 
            0.7561801941149034}, {-4.252247185547804, 
            0.7561890746273059}, {-4.166106326031929, 
            0.7561958009944196}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231484182727, 
            0.7561974310205246}, {-4.138519379980597, 
            0.7561979551397083}, {-4.024791574413388, 
            0.7562068356521108}, {-3.9110637688461805`, 
            0.7562157161645131}, {-3.729124665252799, 
            0.7562169560584775}, {-3.547185988170764, 
            0.7562178517179532}, {-3.5289921502982176`, 
            0.7562179150975004}, {-3.510798314837831, 
            0.7562179762478424}, {-3.501701398267821, 
            0.7562180057407761}, {-3.492604482261138, 
            0.7562180347044996}, {-3.483507566806894, 
            0.7562180631468123}, {-3.4744106518943214`, 
            0.7562180910754422}, {-3.465313737512814, 
            0.7562181184980304}, {-3.332507363344688, 
            0.7562185115645301}, {-3.310237808390429, 
            0.7562185616333925}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629664776394`, 
            0.7562186085665077}, {-3.199701084268981, 
            0.7562188101542114}, {-3.0822468759034436`, 
            0.7562190079425506}, {-2.9647926675379064`, 
            0.7562192057308897}, {-2.8473384591723687`, 
            0.756219403519229}, {-2.7298842508068315`, 
            0.7562196013075682}, {-2.6124300424412943`, 
            0.7562197990959073}, {-2.494975834075757, 
            0.7562199968842465}, {-2.4543692899652183`, 
            0.7562200652640946}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4334944480524054`, 
            0.7562201004165201}, {-2.3775216257102194`, 
            0.7562201946725857}, {-2.260067417344682, 
            0.7562203924609249}, {-2.229884397329776, 
            0.7562203961619826}, {-2.1997013774224503`, 
            0.7562203994826314}, {-2.098517936233143, 
            0.7562204062365594}, {-1.9973344953110348`, 
            0.7562204106703764}, {-1.9937439867945188`, 
            0.7562204108262668}, {-1.9824595314582594`, 
            0.756220411291571}, {-1.972200935698925, 
            0.7562204116941519}, {-1.8696149780834272`, 
            0.7562204141888705}, {-1.7670290203250185`, 
            0.7562204156496946}, {-1.6387965725176725`, 
            0.7562204159458332}, {-1.5985007715389479`, 
            0.7562204160388919}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259296261053`, 
            0.7562204160871}, {-1.5105641247103265`, 
            0.7562204162419719}, {-1.3823316764669007`, 
            0.7562204161881297}, {-1.2540992282234749`, 
            0.7562204161342875}, {-1.1258667798600883`, 
            0.7562204160641295}, {-0.9976343314277313, 
            0.7562204160095085}, {-0.9335181072013944, 
            0.7562204159877444}, {-0.8694018829683439, 
            0.7562204159713695}, {-0.7824219462023838, 
            0.7562204159575782}, {-0.7606769620106402, 
            0.7562204159545689}, {-0.7426322531124009, 
            0.756220415952454}}]}, 
          {Arrowheads[{{0.0017310542109199704`, 1.}}], 
           ArrowBox[{{-0.7217574111995583, 
            0.756220415950213}, {-0.6950445126941674, 
            0.7562204159474185}, {-0.6859119408531057, 
            0.7562204159466035}, {-0.6786742341280048, 
            0.7562204159459781}, {-0.6728772471506833, 
            0.7562204159454886}, {-0.6644874772808002, 
            0.7562204159447983}, {-0.6591766023875828, 
            0.7562204159443768}, {-0.6529492146549237, 
            0.75622041594391}, {-0.6494864452085285, 
            0.7562204159436892}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.009874752227413994, 1.}}], 
           ArrowBox[{{0.750236751661951, -0.6244979514621382}, {
            0.7540425720281513, -0.624497951462541}, {
            0.7602700375159247, -0.6244979514632031}, {
            0.7652868670759249, -0.6244979514637392}, {
            0.7728953860237461, -0.6244979514645573}, {
            0.7847340032583788, -0.6244979514658451}, {
            0.8062544351566497, -0.6244979514682656}, {
            0.8426089586205233, -0.6244979514725789}, {
            0.8993028881786201, -0.6244979514799327}, {
            0.9224957524201696, -0.6244979514831743}, {
            0.9456886166609146, -0.6244979514864918}, {
            0.968881480900756, -0.6244979514898251}, {
            0.9735200537486086, -0.6244979514904889}, {
            0.977114947705666, -0.6244979514910015}, {
            1.0054930860158446`, -0.6244979514950384}, {
            1.033871224324352, -0.6244979514988532}, {
            1.0981878796761289`, -0.6244979515018622}, {
            1.1625045350134662`, -0.6244979514953674}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.013133367257400358`, 1.}}], 
           ArrowBox[{{0.7616933072725054, -0.9228501562492654}, {
            0.8795115817389574, -0.9228501562519567}, {
            0.9973298562055681, -0.9228501562997984}, {
            1.1151481306721789`, -0.9228501563476401}, {
            1.1438740414124728`, -0.9228501563874699}, {
            1.1725999521467054`, -0.9228501564316359}, {
            1.2413035950264333`, -0.9228501565719681}, {
            1.310007237835577, -0.9228501567324201}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3001972241914852`, -0.6072519808776866}, {
            1.4177430985173622`, -0.607251980764954}, {
            1.5352889728432393`, -0.6072519806522214}, {
            1.6528348470745167`, -0.6072519800377594}, {
            1.770380721305794, -0.6072519794232973}, {
            1.8001967940890191`, -0.6072519788922688}, {
            1.830012866892723, -0.6072519782834787}, {
            1.9195057319024353`, -0.6072519752250681}, {
            2.0089985974767512`, -0.6072519708522348}, {
            2.012542702143268, -0.6072519706772807}, {
            2.0394290134721946`, -0.6072519692130037}, {
            2.063871114750328, -0.6072519677416207}, {
            2.135190900705189, -0.6072519577160203}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.1560657426180314`, -0.6072519547815916}, {
            2.186081627194873, -0.6072519505621836}, {
            2.3082921396394185`, -0.6072519333827465}, {
            2.4305026670464693`, -0.6072518973222931}, {
            2.55271319445352, -0.6072518612618397}, {
            2.7054850408622126`, -0.6072475665921897}, {
            2.8582568872709055`, -0.6072432719225396}, {
            2.991059418958519, -0.6072395386234031}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.011934260863113, -0.6072389517970206}, {
            3.1638005800882905`, -0.6072346825832394}, {
            3.316572426496983, -0.6072303879135894}, {
            3.4693442729056754`, -0.6072260932439393}, {
            3.6221161193143674`, -0.6072217985742893}, {
            3.7748879657230603`, -0.6072175039046391}, {
            3.846927937046884, -0.60721547874172}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{3.867802778951478, -0.6072148919153375}, {
            3.9276598121317527`, -0.6072132092349891}, {
            4.080431658540445, -0.607208914565339}, {
            4.233203504949137, -0.607204619895689}, {
            4.38597535135783, -0.6072003252260388}, {
            4.538747197766522, -0.6071960305563888}, {
            4.691519044175215, -0.6071917358867387}, {
            4.70279645513525, -0.607191418860037}}]}, 
          {Arrowheads[{{0.006645049379978203, 1.}}], 
           ArrowBox[{{4.723671297039844, -0.6071908320336545}, {
            4.844290890583908, -0.6071874412170887}, {
            4.9970627369926, -0.6071831465474385}, {
            5.001099999999999, -0.6071753376634204}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.01230740493079905, 1.}}], 
           ArrowBox[{{0.2509369302897384, 1.6228800206749217`}, {
            0.36916455220384814`, 1.6228800206932696`}, {0.4873921741179581, 
            1.6228800207116174`}, {0.605619796032068, 1.6228800207299654`}, {
            0.6327062420156875, 1.622880020675306}, {0.659792688005567, 
            1.6228800206138347`}, {0.712279941415678, 1.6228800204565972`}, {
            0.764767194865278, 1.6228800202769618`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.7769778290727765, 1.621952746210147}, {
            0.8947240349141719, 1.6219527462058736`}, {1.0124702407555675`, 
            1.6219527462016}, {1.1302164465969629`, 1.6219527461973264`}, {
            1.2479626524383582`, 1.6219527461930527`}, {1.2769747666045952`, 
            1.6219527462996322`}, {1.3059868807876696`, 
            1.6219527464539498`}, {1.3789085888199644`, 
            1.6219527473878943`}, {1.451830296835917, 1.6219527488437082`}, {
            1.4590911791729633`, 1.6219527489934846`}, {1.4649232131780545`, 
            1.6219527491184071`}, {1.5232435531496376`, 
            1.6219527507842102`}, {1.5815638929750693`, 1.621952752930816}, {
            1.6119715055864805`, 1.621952757992566}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.632846347499323, 1.6219527614674603`}, {
            1.7273647196836877`, 1.6219527772012958`}, {1.873165546392306, 
            1.6219528014717757`}, {2.018966373100924, 1.6219528257422555`}, {
            2.1647671998095426`, 1.6219528500127354`}, {2.310567927005915, 
            1.6219528667833525`}, {2.456368654202287, 1.6219528835539698`}, {
            2.467840024013018, 1.6219528848734555`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4887148659258607`, 1.621952887274568}, {
            2.602169381398659, 1.621952900324587}, {2.7479701085950308`, 
            1.6219529170952043`}, {2.8777993096278003`, 
            1.6219022035177093`}, {3.0076285106605694`, 1.621851489940214}, {
            3.137457711693339, 1.6218007763627191`}, {3.267286912726108, 
            1.621750062785224}, {3.3237084985158645`, 1.6217280235179359`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.3445833388361432`, 1.621719869436852}, {
            3.3971161137588775`, 1.6216993492077287`}, {3.526945314791647, 
            1.6216486356302338`}, {3.656774515824416, 1.6215979220527386`}, {
            3.786603716857185, 1.6215472084752436`}, {3.916432917889954, 
            1.6214964948977484`}, {4.046262118922723, 1.6214457813202534`}, {
            4.176091319955493, 1.6213950677427582`}, {4.17957695164729, 
            1.6213937061934958`}}]}, 
          {Arrowheads[{{0.01917734928143735, 1.}}], 
           ArrowBox[{{4.200451791967568, 1.6213855521124119`}, {
            4.305920520988263, 1.621344354165263}, {4.435749722021032, 
            1.621293640587768}, {4.565578923053801, 1.6212429270102728`}, {
            4.69540812408657, 1.6211922134327779`}, {4.825237325119339, 
            1.6211414998552827`}, {4.955066526152109, 1.6210907862777877`}, {
            5.001099999999999, 1.6210728047903813`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.5979433427692727}, \
{-4.965188439545129, -0.59794449167659}, {-4.816502825729585, \
-0.5979492485289108}, {-4.66781721191404, -0.5979540053812318}, \
{-4.519131598098497, -0.5979587622335526}, {-4.370445984282952, \
-0.5979635190858734}, {-4.2217603704674085`, -0.5979682759381942}, \
{-4.166106323913616, -0.5979700564606921}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231482011456, -0.5979707243029776}, \
{-4.073074756651864, -0.5979730327905151}, {-3.9243891428363202`, \
-0.597977789642836}, {-3.7757035290207757`, -0.5979825464951568}, \
{-3.6270179152052315`, -0.5979873033474776}, {-3.4783323013896874`, \
-0.5979920601997984}, {-3.3296466875741433`, -0.5979968170521193}, \
{-3.310237805925073, -0.5979974379943971}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629640229136`, -0.5979981058366826}, \
{-3.180961073758599, -0.5980015739044402}, {-3.032275459943055, \
-0.598006330756761}, {-2.8835898461275105`, -0.5980110876090818}, \
{-2.734904232311966, -0.5980158444614028}, {-2.615963826900645, \
-0.5980159017049834}, {-2.4970234214893243`, -0.598015958948564}, \
{-2.454369287792991, -0.5980159695831844}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494445880149, -0.5980159747877449}, \
{-2.3780830421363714`, -0.5980159886030354}, {-2.2591426627834186`, \
-0.5980160182575067}, {-2.235354589332602, -0.5980160210891882}, \
{-2.2115665160279763`, -0.5980160237051136}, {-2.2057384381034844`, \
-0.5980160242926927}, {-2.110394184881466, -0.5980160337781067}, \
{-2.0150499333091187`, -0.5980160405662326}, {-1.8971316460214709`, \
-0.598016046453416}, {-1.7792133587338228`, -0.5980160523405995}, \
{-1.661295071446175, -0.5980160582277829}, {-1.5985007693664512`, \
-0.5980160613628487}}]}, 
          {Arrowheads[{{0.01973848008685587, 1.}}], 
           ArrowBox[{{-1.5776259274536086`, -0.5980160624050451}, \
{-1.543376784158527, -0.5980160641149664}, {-1.4254584968708792`, \
-0.5980160700021498}, {-1.3075402095832314`, -0.5980160758893334}, \
{-1.1896219222955835`, -0.5980160817765168}, {-1.0717036350079352`, \
-0.5980160876637002}, {-1.0433771942894465`, -0.5980160876632818}, \
{-1.0150507535690276`, -0.5980160876618328}, {-0.9513292537404998, \
-0.5980160876550864}, {-0.8875992711668, -0.59801608764819}, \
{-0.8839417831920346, -0.5980160876477948}, {-0.8792223126455122, \
-0.5980160876472872}, {-0.8556271221797279, -0.598016087644847}, \
{-0.8307342470416695, -0.5980160876424347}, {-0.7910849552675095, \
-0.598016087638715}, {-0.7678677183467972, -0.5980160876366422}, \
{-0.7580116994810548, -0.5980160876357706}, {-0.7535506246277931, \
-0.5980160876353773}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.3802012475769017`}, \
{-4.944452079001034, -1.3802053317184948`}, {-4.827216762137846, \
-1.380213784025752}, {-4.709981445274659, -1.3802222363330094`}, \
{-4.592746128411471, -1.3802306886402667`}, {-4.475510811548284, \
-1.380239140947524}, {-4.358275494685096, -1.3802475932547813`}, \
{-4.3272018437780595`, -1.3802481692886668`}, {-4.296128204704615, \
-1.3802487156878804`}, {-4.166106325177061, -1.3802503228723788`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231483265814, -1.3802505809037382`}, \
{-4.128650173130425, -1.3802507858632782`}, {-3.9611722921979036`, \
-1.3802522897388}, {-3.781325156535381, -1.3802522974723894`}, \
{-3.6014780208728583`, -1.3802523052059787`}, {-3.421630885210334, \
-1.3802523129395683`}, {-3.310237806760129, -1.3802523177295714`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362964847286, -1.3802523186272084`}, \
{-3.241783749547812, -1.3802523206731576`}, {-3.0619366138852877`, \
-1.380252328406747}, {-2.882089478222766, -1.3802523361403363`}, \
{-2.7022423425602415`, -1.3802523438739258`}, {-2.52239520689772, \
-1.3802523516075151`}, {-2.4543692883335826`, -1.380252354532691}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.43349444642074, -1.380252355430328}, \
{-2.3425480712351963`, -1.3802523593411045`}, {-2.1627009355726736`, \
-1.3802523670746938`}, {-1.98285379991015, -1.3802523748082833`}, \
{-1.803006664247627, -1.3802523825418727`}, {-1.623159528585104, \
-1.380252390275462}, {-1.5985007699070364`, -1.380252391335811}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259279941938`, -1.380252392233448}, \
{-1.4433123929225808`, -1.3802523980090513`}, {-1.2634652572600578`, \
-1.3802524057426409`}, {-1.0836181215975347`, -1.3802524134762302`}, \
{-0.9037709859350116, -1.3802524212098195`}, {-0.7426322514804902, \
-1.3802524281389306`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574095676476, -1.3802524290365676`}, \
{-0.5440767146099654, -1.3802524366769984`}, {-0.36422957894744235`, \
-1.3802524444105877`}, {-0.18438244328491926`, -1.380252452144177}, \
{-0.0045353076223959565`, -1.3802524598777663`}, {
            0.11323626694605604`, -1.3802524649420507`}}]}, 
          {Arrowheads[{{0.009602347940648036, 1.}}], 
           ArrowBox[{{0.13411110885889863`, -1.3802524658396877`}, {
            0.17531182804012713`, -1.380252467611356}, {
            0.3551589637026502, -1.3802524753449452`}, {
            0.5350060993651733, -1.3802524830785345`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHXrt27Z/y17aq3xq0/EQfmj/WfPkcacTL+0df0P4
+nnFZ02fv7TfwtwO5lec8pJbL/XKfqMghO/cket9peyVfZUWhL9FeWat6NpX
9h8sIHxtW3a3mI+v7D96Qfh7LnFzCbm+tl+QAOHzHi17eazotX14DoTPU19f
I734tX19BYR/fp6wyrWjr+2/N0D4JrWNpyY6v7EPmAfhv8/fccZn0xt7q20Q
fnVI1R8Olbf2689A+CIGARMvT3tr/+0BhP9FQkfm5OT39u94OsD8pxO6/9gc
/mCftAMiz710i8GLPR/t3zdB/H/X7W7K5G2f7OXvNIP5TY890verfbV//98L
zH+2+2Dm62nf7b/nb9IG8TkvuOeIs/+yt9DZpQXia/mfXr9Q/5f9vyuLwXwA
2HOuUw==
            "]]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.657503647737125, 0.5336037472931862}, {
            1.7791170435248156`, 0.5336037452958831}, {1.9315027671987928`, 
            0.5336037395651978}, {2.0838884954998034`, 0.533603728074845}, {
            2.2362742284278476`, 0.5336037108248247}, {2.3886599659829257`, 
            0.533603687815137}, {2.4924973242508126`, 
            0.5336037410349487}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.5133721661636526`, 0.5336037517339416}, {
            2.541045577063908, 0.5336037659174083}, {2.693431445720116, 
            0.5336036360360941}, {2.8458173143763235`, 0.5336035061547798}, {
            2.998203183032531, 0.5336033762734655}, {3.111026358711551, 
            0.5335890641023471}, {3.22384953439057, 0.5335747519312285}, {
            3.336672710069589, 0.53356043976011}, {3.34836583985975, 
            0.5335589564294604}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.369240681604632, 0.5335563083537851}, {
            3.4494958857486075`, 0.5335461275889914}, {3.5623190614276266`, 
            0.533531815417873}, {3.675142237106646, 0.5335175032467545}, {
            3.787965412785665, 0.5335031910756359}, {3.900788588464684, 
            0.5334888789045175}, {4.013611764143703, 0.533474566733399}, {
            4.1264349398227225`, 0.5334602545622804}, {4.20423435139991, 
            0.5334503853267736}}]}, 
          {Arrowheads[{{0.018586747059901997`, 1.}}], 
           ArrowBox[{{4.2251091931447915`, 0.5334477372510983}, {
            4.239258115501741, 0.5334459423911619}, {4.35208129118076, 
            0.5334316302200434}, {4.46490446685978, 0.5334173180489249}, {
            4.5777276425387985`, 0.5334030058778064}, {4.690550818217817, 
            0.5333886937066878}, {4.803373993896836, 0.5333743815355694}, {
            4.916197169575855, 0.5333600693644509}, {5.001099999999999, 
            0.5333492990255541}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.1333455540098651`}, {-4.82011670998741, 
            1.1333537737790194`}, {-4.702855073411717, 
            1.133357933523696}, {-4.5855934368360245`, 
            1.133362093268373}, {-4.468331800260332, 
            1.1333662530130497`}, {-4.351070163684639, 
            1.1333704127577267`}, {-4.233808527108947, 
            1.1333745725024034`}, {-4.166106324084461, 
            1.1333769741734603`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.1452314821847525`, 
            1.1333777146885597`}, {-4.116546890533255, 
            1.1333787322470803`}, {-3.999285253957562, 
            1.133382891991757}, {-3.8820236173818694`, 
            1.1333870517364337`}, {-3.851060198690264, 
            1.1333872944655183`}, {-3.8200967874275418`, 
            1.1333875233724746`}, {-3.6676720768069253`, 
            1.1333883080344151`}, {-3.5152474538722216`, 
            1.1333888767583529`}, {-3.3663466878181203`, 
            1.1333888763740858`}, {-3.310237805841538, 
            1.133388876229286}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289362963928695, 
            1.1333888761754145`}, {-3.2174459217640186`, 
            1.1333888759898187`}, {-3.0685451557099173`, 
            1.1333888756055517`}, {-2.919644389655816, 
            1.1333888752212846`}, {-2.7707436236017147`, 
            1.1333888748370176`}, {-2.621842857547613, 
            1.1333888744527505`}, {-2.472942091493512, 
            1.1333888740684834`}, {-2.4543692874149907`, 
            1.1333888740205527`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494445502148, 
            1.133388873966681}, {-2.3240413254394103`, 
            1.1333888736842164`}, {-2.1751405593853086`, 
            1.1333888732999493`}, {-2.0262397933312073`, 
            1.133388872915682}, {-1.877339027277106, 
            1.133388872531415}, {-1.7284382612230047`, 
            1.133388872147148}, {-1.5985007689884436`, 
            1.1333888718118192`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625927075601, 
            1.1333888717579477`}, {-1.4306367291148017`, 
            1.1333888713786138`}, {-1.2817359630607004`, 
            1.1333888709943467`}, {-1.132835197006599, 
            1.1333888706100796`}, {-0.9839344311269635, 
            1.1333888712747422`}, {-0.835033665247328, 
            1.1333888719394045`}, {-0.7426322505618966, 
            1.1333888723518655`}}]}, 
          {Arrowheads[{{0.0008532881214167333, 1.}}], 
           ArrowBox[{{-0.721757408649054, 
            1.1333888724450465`}, {-0.6861328993676925, 
            1.1333888726040668`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.37892055381723944`}, {-4.938645842822022, 
            0.3789256275317007}, {-4.829475566954109, 
            0.3789344964178156}, {-4.720305291086195, 
            0.3789433653039305}, {-4.591355071244856, 
            0.37894501112315093`}, {-4.462404851403519, 
            0.37894665694237134`}, {-4.333454631562181, 
            0.37894830276159175`}, {-4.204504411720842, 
            0.37894994858081216`}, {-4.166106324458026, 
            0.3789504386638079}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231482546883, 
            0.37895070509387746`}, {-4.075554191879505, 
            0.37895159440003257`}, {-3.9466039720381665`, 
            0.378953240219253}, {-3.8176537521968283`, 
            0.3789548860384734}, {-3.6887035323554898`, 
            0.37895653185769385`}, {-3.5597578315497884`, 
            0.37895686687266184`}, {-3.430812130744088, 
            0.3789572018876298}, {-3.3102378060716404`, 
            0.3789575151528513}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629641588684`, 
            0.37895756938796304`}, {-3.172920729132686, 
            0.3789578719175658}, {-3.0439750283269853`, 
            0.3789582069325338}, {-2.9150293275212844`, 
            0.3789585419475018}, {-2.7860836267155835`, 
            0.3789588769624698}, {-2.657137925909882, 
            0.3789592119774378}, {-2.5539819566775948`, 
            0.37895924093634414`}, {-2.454369287647304, 
            0.3789592621777012}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494445734462, 
            0.3789592656696155}, {-2.4291632513049737`, 
            0.3789592663403826}, {-2.425552793218218, 
            0.37895926688072706`}, {-2.3236708699630633`, 
            0.37895928203467233`}, {-2.2217889530414503`, 
            0.3789592932469938}, {-2.103998117370376, 
            0.3789593026942001}, {-1.986207281699302, 
            0.3789593121414064}, {-1.8684164460282275`, 
            0.3789593215886127}, {-1.7506256103571536`, 
            0.3789593310358189}, {-1.6328347746860792`, 
            0.3789593404830252}, {-1.5985007692207613`, 
            0.3789593432367236}}]}, 
          {Arrowheads[{{0.011888832968008085`, 1.}}], 
           ArrowBox[{{-1.5776259273079187`, 
            0.37895934491095346`}, {-1.515043939015005, 
            0.3789593499302315}, {-1.3972531033439308`, 
            0.3789593593774378}, {-1.2794622676728564`, 
            0.3789593688246441}, {-1.2506257321647665`, 
            0.3789593688634403}, {-1.221789196659647, 
            0.37895936889578047`}, {-1.1515300532464585`, 
            0.3789593689357792}, {-1.0812709098371993`, 
            0.3789593689589901}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3188611402764815, -1.6883869024809623`}, {
            0.3633830012065064, -1.688386902478285}, {
            0.40790486213655086`, -1.6883869024661307`}, {
            0.525602972171285, -1.6883869024012632`}, {
            0.6433010822060191, -1.6883869023363955`}, {
            0.7609991922407533, -1.688386902271528}, {
            0.8786973022754874, -1.6883869022066607`}, {
            0.9963954123102214, -1.6883869021417932`}, {
            1.1140935223449555`, -1.6883869020769255`}, {
            1.1538548167901859`, -1.6883869020550117`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1747296587030285`, -1.688386902043507}, {
            1.2317916323796898`, -1.688386902012058}, {
            1.3494897424144239`, -1.6883869019471907`}, {
            1.3786939838530408`, -1.6883869022082916`}, {
            1.4078982253084664`, -1.688386902546689}, {
            1.4840426529852477`, -1.688386904343741}, {
            1.5601870805527012`, -1.6883869070003794`}, {
            1.565915494082204, -1.6883869072038504`}, {
            1.5892967737714496`, -1.688386908134853}, {
            1.6126780534336744`, -1.6883869091643036`}, {
            1.7295844483302034`, -1.6883869206754918`}, {
            1.8464908432267322`, -1.6883869321866798`}, {
            1.9633972288761739`, -1.6883869522173016`}, {
            2.009723335216729, -1.6883869601547699`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.0305981771295714`, -1.6883869637314441`}, {
            2.0803036145256155`, -1.6883869722479234`}, {
            2.2264356976814366`, -1.6883842042274169`}, {
            2.3725677808372576`, -1.6883814362069105`}, {
            2.5186998639930787`, -1.688378668186404}, {
            2.6648319471489, -1.6883759001658976`}, {
            2.8109640303047208`, -1.688373132145391}, {
            2.865591853502396, -1.688372097390178}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.8864666954114937`, -1.6883717019808384`}, {
            2.9570961134605422`, -1.6883703641248846`}, {
            3.1032281966163633`, -1.6883675961043783`}, {
            3.2493602797721843`, -1.6883648280838717`}, {
            3.395492362928005, -1.6883620600633653`}, {
            3.541624446083826, -1.6883592920428587`}, {
            3.687756529239647, -1.6883565240223524`}, {
            3.721460371775402, -1.6883558856072605`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.7423352136844996`, -1.688355490197921}, {
            3.8338886123954685`, -1.688353756001846}, {
            3.98002069555129, -1.6883509879813394`}, {
            4.126152778707111, -1.688348219960833}, {
            4.272284861862932, -1.6883454519403265`}, {
            4.418416945018753, -1.6883426839198201`}, {
            4.564769228677605, -1.6879491183655166`}, {
            4.577328360880562, -1.6879484884213436`}}]}, 
          {Arrowheads[{{0.009650295797006476, 1.}}], 
           ArrowBox[{{4.598203202767146, -1.687947441375672}, {
            4.7109038822673135`, -1.6879417885060943`}, {
            4.857040249479614, -1.687931417420728}, {
            5.001099999999999, -1.687918195855136}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.006824251028681758, 1.}}], 
           ArrowBox[{{0.5940894524157376, 0.8075383372247835}, {
            0.6257886367745258, 0.807538337225974}, {0.6460947189714896, 
            0.8075383372269054}, {0.6664345270500549, 0.8075383372281988}, {
            0.6849723843877167, 0.8075383372296829}, {0.7068964440908867, 
            0.8075383372317081}, {0.7121862437868853, 0.8075383372322421}, {
            0.7397082800082884, 0.8075383372350826}, {0.7672303162295453, 
            0.8075383372386229}, {0.8231150457215713, 0.8075383372514702}, {
            0.8789997752103081, 0.8075383372692665}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.9928736743045009}, \
{-4.903103130784327, -0.9928955577752504}, {-4.7885384001134454`, \
-0.9929211409796183}, {-4.663617231888585, -0.9929250757982844}, \
{-4.538696063663726, -0.9929290106169504}, {-4.413774895438865, \
-0.9929329454356165}, {-4.288853727214005, -0.9929368802542825}, \
{-4.166106329094909, -0.992940746602638}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231487192421, -0.9929414041270491}, \
{-4.039011390764285, -0.9929447498916147}, {-3.9140902225394245`, \
-0.9929486847102807}, {-3.7891690543145646`, -0.9929526195289468}, \
{-3.6642510717630756`, -0.9929534130158894}, {-3.5393330892115866`, \
-0.9929542065028318}, {-3.4144151066600976`, -0.9929549999897744}, \
{-3.310237810865013, -0.99295566173056}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289362968952591, -0.9929557943288789}, \
{-3.1645791415571187`, -0.9929565869636595}, {-3.0396611590056297`, \
-0.992957380450602}, {-2.9147431764541407`, -0.9929581739375446}, \
{-2.7898251939026517`, -0.9929589674244872}, {-2.68989112255523, \
-0.9929590292892906}, {-2.5899570536319168`, -0.9929590749986329}, \
{-2.579963646836979, -0.9929590783093121}, {-2.568970899366782, \
-0.9929590818205283}, {-2.565473206990922, -0.9929590828950866}, \
{-2.4594298182545584`, -0.9929591152453594}, {-2.4543692924490004`, \
-0.9929591163063811}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494450536158, -0.9929591206831317}, \
{-2.3533864292604916`, -0.9929591374790832}, {-2.2356627789536114`, \
-0.9929591538706121}, {-2.117939128646731, -0.9929591702621409}, \
{-2.0002154783398507`, -0.9929591866536698}, {-1.8824918280329703`, \
-0.9929592030451987}, {-1.76476817772609, -0.9929592194367275}, \
{-1.6470445274192098`, -0.9929592358282564}, {-1.5985007740224628`, \
-0.9929592425873599}}]}, 
          {Arrowheads[{{0.008936079674678401, 1.}}], 
           ArrowBox[{{-1.5776259321096204`, -0.9929592454939175}, \
{-1.5293208771123294`, -0.9929592522197852}, {-1.411597226805449, \
-0.9929592686113141}, {-1.382493017632914, -0.9929592684907435}, \
{-1.3533888084373642`, -0.9929592683754797}, {-1.2789681197825584`, \
-0.9929592681422239}, {-1.2045474310506668`, -0.99295926795742}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.004374282607618338, 1.}}], 
           ArrowBox[{{-1.0502271449439873`, -1.139648270375236}, \
{-1.0219608441826953`, -1.1396482703305828`}, {-0.9936945434200773, \
-1.1396482702940431`}, {-0.930648386263017, -1.1396482702581034`}, \
{-0.8676022291117278, -1.139648270243332}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.768153365445022}, \
{-4.800384506142651, -1.7682086334909521`}, {-4.674799405987704, \
-1.7682130828590232`}, {-4.549214305832757, -1.7682175322270943`}, \
{-4.42362920567781, -1.7682219815951654`}, {-4.298044105522863, \
-1.7682264309632365`}, {-4.172459005367917, -1.7682308803313076`}, \
{-4.166106331493545, -1.7682311054008761`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231489593804, -1.7682318449779033`}, \
{-4.04687390521297, -1.7682353296993787`}, {-3.9212888050580235`, \
-1.7682397790674498`}, {-3.7957037049030764`, -1.768244228435521}, \
{-3.6701182687722618`, -1.768244759628853}, {-3.544532832641447, \
-1.768245290822185}, {-3.4189473965106325`, -1.768245822015517}, \
{-3.3102378133038095`, -1.768246281828434}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2893629713911534`, -1.7682463701235194`}, \
{-3.167776524249003, -1.7682468844021808`}, {-3.042191088118188, \
-1.7682474155955128`}, {-2.9166056519873735`, -1.7682479467888448`}, \
{-2.7910202158565585`, -1.7682484779821768`}, {-2.6905514098100194`, \
-1.7682484391285889`}, {-2.590082580745725, -1.768248398313687}, \
{-2.5800356959067416`, -1.7682483942964542`}, {-2.568984122375178, \
-1.7682483898988046`}, {-2.565467712546434, -1.7682483885074503`}, \
{-2.4594245150360066`, -1.7682483465941932`}, {-2.4543692948819333`, \
-1.7682483447471575`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.433494452969092, -1.7682483371200757`}, \
{-2.353381300701149, -1.768248307848976}, {-2.235658265133204, \
-1.7682482696807436`}, {-2.1179352295652594`, -1.7682482315125112`}, \
{-2.0002121939973145`, -1.7682481933442789`}, {-1.88248915842937, \
-1.7682481551760465`}, {-1.764766122861425, -1.7682481170078141`}, \
{-1.6470430872934803`, -1.7682480788395818`}, {-1.5985007764554329`, \
-1.768248063101165}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259345425914`, -1.7682480563331113`}, \
{-1.5293200517255354`, -1.7682480406713494`}, {-1.4115970161575908`, \
-1.768248002503117}, {-1.3824929289524606`, -1.768248002135499}, \
{-1.3533888417754811`, -1.7682480018621973`}, {-1.2789681524170928`, \
-1.7682480018244897`}, {-1.2045474633269895`, -1.7682480020958333`}, \
{-1.1973533492248523`, -1.768248002123945}, {-1.1915749443255421`, \
-1.7682480021482387`}, {-1.133790895497221, -1.7682480025043215`}, \
{-1.076006846828761, -1.768248002929443}, {-0.9315467272524565, \
-1.7682480031609809`}, {-0.7870866076761519, -1.7682480033925188`}, \
{-0.7426322580288957, -1.7682480034637693`}}]}, 
          {Arrowheads[{{0.019196110065376623`, 1.}}], 
           ArrowBox[{{-0.721757416116053, -1.7682480034972272`}, \
{-0.6426264880998473, -1.7682480036240567`}, {-0.4981663685235428, \
-1.7682480038555946`}, {-0.35370624894353847`, -1.7682480038836315`}, \
{-0.20924612936353404`, -1.7682480039116684`}, {-0.06478600978352983, \
-1.768248003939705}, {0.0796741097964746, -1.768248003967742}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.007014867496273642, 1.}}], 
           ArrowBox[{{-1.055448850414376, -0.8690074496775916}, \
{-0.9374300764224761, -0.8690074519607969}, {-0.9095060621567512, \
-0.8690074519462684}, {-0.8815820478896204, -0.8690074519338257}, \
{-0.8220811991283696, -0.8690074519187624}, {-0.7625803503658753, \
-0.8690074519093657}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.8757711113204611`}, {-4.881891052493567, 
            1.875781952481187}, {-4.740372588184983, 
            1.8757918658436086`}, {-4.598855155491005, 
            1.8757988224304867`}, {-4.457206707742239, 
            1.8761812895114183`}, {-4.315690822470167, 
            1.8761838109349807`}, {-4.174174937198095, 
            1.876186332358543}, {-4.166106840895246, 
            1.8761864761098124`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231998985717, 
            1.8761868480420385`}, {-4.032659051926022, 
            1.8761888537821056`}, {-3.8911431666539498`, 
            1.876191375205668}, {-3.7496272813818776`, 
            1.8761938966292304`}, {-3.6081113961098055`, 
            1.8761964180527928`}, {-3.466595510837733, 
            1.8761989394763552`}, {-3.325079625565661, 
            1.8762014608999178`}, {-3.310238322604549, 
            1.8762017253310868`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893634806950196`, 
            1.8762020972633129`}, {-3.1835637402935886`, 
            1.8762039823234802`}, {-3.042047855021516, 
            1.8762065037470426`}, {-2.9005319697494443`, 
            1.876209025170605}, {-2.7590160844773717`, 
            1.8762115465941673`}, {-2.617500199205299, 
            1.87621406801773}, {-2.4759843139332274`, 
            1.8762165894412923`}, {-2.4543698043138513`, 
            1.8762169745523611`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494962404322, 
            1.8762173464845873`}, {-2.3344684286611552`, 
            1.8762191108648547`}, {-2.192952543389082, 
            1.876221632288417}, {-2.079738439702335, 
            1.8762215969892562`}, {-1.9665243360155877`, 
            1.8762215616900952`}, {-1.8533102197314206`, 
            1.8762215414247914`}, {-1.7400961034472535`, 
            1.8762215211594873`}, {-1.7174532792855788`, 
            1.8762215192994207`}, {-1.694810455091759, 
            1.876221517610298}, {-1.6892629631579499`, 
            1.8762215172393664`}, {-1.6092795936483097`, 
            1.8762215119821708`}, {-1.5985012859288135`, 
            1.8762215115115035`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776264440159709`, 
            1.8762215105999407`}, {-1.5292962240499832`, 
            1.8762215084894562`}, {-1.4109138916453308`, 
            1.8762215054167724`}, {-1.292531559240678, 
            1.8762215023440882`}, {-1.1741492268360256`, 
            1.8762214992714044`}, {-1.0557668944313732`, 
            1.8762214961987203`}, {-0.9373845620267206, 
            1.8762214931260364`}, {-0.8190022296220681, 
            1.8762214900533523`}, {-0.7426327675022667, 
            1.8762214880711374`}}]}, 
          {Arrowheads[{{0.006926405773245782, 1.}}], 
           ArrowBox[{{-0.7217579255894241, 
            1.8762214875293184`}, {-0.7006198972174157, 
            1.8762214869806684`}, {-0.582237564812763, 
            1.8762214839079843`}, {-0.5557709702694881, 
            1.8762214840057645`}, {-0.5293043757332813, 
            1.8762214840887175`}, {-0.48094352511698113`, 
            1.876221484173427}, {-0.432582674508012, 1.8762214842233558`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.009880349956902264, 1.}}], ArrowBox[CompressedData["

1:eJxTTMoPSmViYGCQBGIQnXZDLEM79619Zrv8g6kMV/Z7rl558mH3W/sNiyD8
HMFUsZqDb+3nr4XwU23+7K9/+NbebRmEn7fdu19P8539lloIn3Wq4YXTHu/s
F6dA+CGWiY38xe/sBW0h/CsyxmJHVr2zl2SA8P/OM+StYntvX9InB+afnb3Q
pHH+e/u0PbJg/txUsaCvrB/si2Ug/Lry3+ExTh/sfaJkwHzfyyvvL63/YC9W
Kw3m7wif/GHPzA/2nGIQvlrcIo3SzR/so1ZJgfmRyVaui259sP/wUxLMZw+P
1HKz/2i//IM4mL80vIL/1eKP9jNqRMH87ozpX3o5Ptm/6BEC8/exs+xZJ/PJ
vvCZIJjvPTdO2UPnk31BIoQv/TTCRHnRJ/sPabxgfqFfsOs/8c/233s5wHyZ
jRwTxU2+2K/d9uk+iG/ve+COQcBXe+XfF8F8ANs8y0E=
            "]]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.4624988803046497`}, {-4.973096215031099, 
            2.462502456628464}, {-4.941918512900958, 
            2.462503153345991}, {-4.91074076488981, 
            2.462503793910271}, {-4.723825168883478, 
            2.462505692933974}, {-4.536908151647904, 
            2.462506426666506}, {-4.3903432086674465`, 
            2.4625041704063784`}, {-4.2437782656869905`, 
            2.462501914146251}, {-4.166106323784048, 2.4625007184435}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231481873679, 
            2.462500397090573}, {-4.097213322706533, 
            2.4624996578861236`}, {-3.9506483797260747`, 
            2.4624974016259964`}, {-3.8040834367456187`, 
            2.4624951453658688`}, {-3.6575184937651626`, 
            2.462492889105741}, {-3.5109535507847065`, 
            2.462490632845614}, {-3.3643886078042486`, 
            2.4624883765854864`}, {-3.310237805458914, 2.46248754297348}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362963548545, 
            2.4624872216205524`}, {-3.2178236648237926`, 
            2.462486120325359}, {-3.0712587218433347`, 
            2.4624838640652316`}, {-2.9246937788628786`, 
            2.462481607805104}, {-2.7781288358824217`, 
            2.4624793515449768`}, {-2.631563892901964, 
            2.462477095284849}, {-2.4849989499215077`, 
            2.462474839024722}, {-2.4543692871337806`, 2.46247436750346}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944452234115`, 
            2.4624740461505326`}, {-2.3384340069410507`, 
            2.4624725827645944`}, {-2.1918690639605938`, 
            2.462470326504467}, {-2.0453041209801377`, 
            2.4624680702443396`}, {-1.8987391779996807`, 
            2.462465813984212}, {-1.7521742350192238`, 
            2.4624635577240848`}, {-1.6056092920387668`, 
            2.462461301463957}, {-1.598500768808647, 2.46246119203344}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625926898278, 
            2.4624608706805127`}, {-1.4590443490583098`, 
            2.46245904520383}, {-1.3124794060778529`, 
            2.4624567889437023`}, {-1.1659144630973968`, 
            2.4624545326835747`}, {-1.0193495201169398`, 
            2.4624522764234476`}, {-0.8727845771364828, 
            2.46245002016332}, {-0.7426322504835134, 2.46244801656342}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574085731443, 
            2.462447695210493}, {-0.5796546911755698, 
            2.462445507643065}, {-0.4330897481951128, 
            2.4624432513829375`}, {-0.28652480521465673`, 
            2.4624409951228103`}, {-0.13995986223419976`, 
            2.4624387388626827`}, {0.006605080746258096, 
            2.4624364826025555`}, {0.11323626784162033`, 
            2.4624348410934}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110975198945`, 2.4624345197404724`}, {
            0.15317002372671418`, 2.462434226342428}, {0.29973496670717115`, 
            2.4624319700823003`}, {0.446299909687629, 2.462429713822173}, {
            0.5928648526680851, 2.4624274575620455`}, {0.739429795648542, 
            2.4624252013019183`}, {0.885994738628999, 2.4624229450417907`}, {
            0.969104786166754, 2.4624216656233795`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899796280771231, 2.462421344270452}, {
            1.0325596816094555`, 2.462420688781663}, {1.179124624589912, 
            2.462418432521536}, {1.325689567570369, 2.4624161762614083`}, {
            1.4722545105508256`, 2.462413920001281}, {1.618819453531282, 
            2.4624116637411535`}, {1.76538439651174, 2.462409407481026}, {
            1.8249733044918877`, 2.4624084901533596`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458481464022567`, 2.4624081688004322`}, {
            1.9119493394921965`, 2.4624071512208987`}, {2.058514282472653, 
            2.462404894960771}, {2.205079225453111, 2.462402638700644}, {
            2.3516441684335674`, 2.4624003824405163`}, {2.498209111414024, 
            2.462398126180389}, {2.644774054394481, 2.4623958699202615`}, {
            2.680841822817021, 2.4623953146833397`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.7017166647273902`, 2.4623949933304123`}, {
            2.7913389973749374`, 2.462393613660134}, {2.937903940355394, 
            2.4623913574000067`}, {3.084468883335851, 2.462389101139879}, {
            3.2310338263163065`, 2.462386844879752}, {3.377598769296764, 
            2.4623845886196243`}, {3.524163712277222, 2.4623823323594967`}, {
            3.5367103411421548`, 2.4623821392133194`}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{3.557585183052524, 2.462381817860392}, {
            3.6707286552576774`, 2.4623800760993695`}, {3.817293598238133, 
            2.462377819839242}, {3.963858541218591, 2.4623755635791147`}, {
            4.110423484199049, 2.462373307318987}, {4.256988427179504, 
            2.4623710510588595`}, {4.392578859467289, 2.4623689637432995`}}]}, 
          {Arrowheads[{{0.014075467206021507`, 1.}}], 
           ArrowBox[{{4.413453701377658, 2.4623686423903726`}, {
            4.55011831314042, 2.4623665385386047`}, {4.696683256120875, 
            2.4623642822784775`}, {4.843248199101333, 2.46236202601835}, {
            4.953488847762335, 2.4623294851376354`}, {5.001099999999999, 
            2.4623154312578324`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.078909925655838}, {-4.9119335405086355`, 
            3.078908114188808}, {-4.730715279641265, 
            3.0789036310462987`}, {-4.613459357267729, 
            3.078900488736436}, {-4.496203434894193, 
            3.078897346426574}, {-4.378947512520657, 
            3.0788942041167116`}, {-4.261691590147121, 
            3.0788910618068495`}, {-4.166106323762893, 
            3.0788885002430564`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231481857547, 
            3.078887940823794}, {-4.144435667773585, 
            3.078887919496987}, {-4.0271797454000495`, 
            3.0788847771871244`}, {-3.9099238230265136`, 
            3.0788816348772623`}, {-3.792667900652978, 
            3.0788784925673998`}, {-3.7617297010018684`, 
            3.078877953677111}, {-3.730791476483436, 
            3.078877431325717}, {-3.5811902389438, 
            3.0788753684758743`}, {-3.4315886414935086`, 
            3.0788736727266834`}, {-3.310237805503388, 
            3.0788736256859637`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.289362963590547, 
            3.0788736175939917`}, {-3.2864197009199696`, 
            3.0788736164530586`}, {-3.1412507603464297`, 
            3.0788735601794337`}, {-2.9960818197728907`, 
            3.0788735039058084`}, {-2.8509128791993517`, 
            3.0788734476321835`}, {-2.7057439386258113`, 
            3.0788733913585586`}, {-2.5605749980522723`, 
            3.0788733350849333`}, {-2.454369287076905, 
            3.0788732939151053`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944451640643`, 
            3.078873285823133}, {-2.415406057478733, 
            3.0788732788113085`}, {-2.270237116905194, 
            3.0788732225376836`}, {-2.125068176331654, 
            3.0788731662640583`}, {-1.9798992357581149`, 
            3.0788731099904334`}, {-1.834730295184575, 
            3.0788730537168085`}, {-1.689561354611036, 
            3.078872997443183}, {-1.5985007686504227`, 
            3.0788729621442466`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5776259267375816`, 
            3.0788729540522746`}, {-1.5443924140374965`, 
            3.0788729411695583`}, {-1.399223473463957, 
            3.0788728848959335`}, {-1.2540545328904171`, 
            3.078872828622308}, {-1.108885592316878, 
            3.0788727723486833`}, {-0.9637166517433386, 
            3.0788727160750584`}, {-0.8185477111697992, 
            3.078872659801433}, {-0.74263225022394, 3.0788726303733878`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574083110989, 
            3.078872622281416}, {-0.6733787705962595, 
            3.0788726035278082`}, {-0.5282098300227203, 
            3.0788725472541834`}, {-0.383040889449181, 
            3.0788724909805585`}, {-0.23787194887564178`, 
            3.078872434706933}, {-0.09270300830210254, 3.0788723784333083`}, {
            0.05246593227143714, 3.0788723221596834`}, {0.11323626820254283`, 
            3.0788722986025294`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411111011538387`, 3.078872290510557}, {
            0.19763487284497683`, 3.078872265886058}, {0.34280381341851607`, 
            3.0788722096124332`}, {0.4879727539920553, 3.0788721533388084`}, {
            0.6331416945655945, 3.078872097065183}, {0.7783106351391338, 
            3.078872040791558}, {0.923479575712673, 3.0788719845179333`}, {
            0.9691047866290255, 3.0788719668316706`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899796285418666, 3.078871958739698}, {
            1.0686485162862132`, 3.078871928244308}, {1.2138174568597524`, 
            3.078871871970683}, {1.3585294838028243`, 3.0787866252354537`}, {
            1.5036970870681774`, 3.0787863196238923`}, {1.6488637987947383`, 
            3.07878584778704}, {1.794029618982509, 3.0787852097248964`}, {
            1.8249732799440836`, 3.0787850382812985`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481218566059`, 3.078784922624072}, {
            1.9391945476314878`, 3.0787844054374625`}, {2.0843585847416755`, 
            3.078783434924737}, {2.2295217303130728`, 3.078782298186721}, {
            2.374683984345678, 3.078780995223414}, {2.519845346839493, 
            3.078779526034816}, {2.665005817794516, 3.0787778906209273`}, {
            2.6808417983374677`, 3.0787776940736302`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.7017166402487027`, 3.0787774349868156`}, {
            2.8101653972107488`, 3.0787760889817473`}, {2.95532408508819, 
            3.0787741211172763`}, {3.1004818814268393`, 3.078771987027515}, {
            3.245638786226699, 3.0787696867124623`}, {3.3907947994877663`, 
            3.078767220172119}, {3.5359499212100425`, 3.078764587406484}, {
            3.5367103166618277`, 3.0787645727438733`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.5575851585707894`, 3.078764170216899}, {
            3.681104151393528, 3.0787617884155587`}, {3.826257490038222, 
            3.078758823199342}, {3.9714099371441254`, 3.0787556917578347`}, {
            4.116561492711237, 3.0787523940910364`}, {4.2617121567395575`, 
            3.0787489301989472`}, {4.392578834877747, 3.0787456572940393`}}]}, 
          {Arrowheads[{{0.014075467634674585`, 1.}}], 
           ArrowBox[{{4.413453676783868, 3.078745127675605}, {
            4.552010810179826, 3.0787415037388963`}, {4.697158799591773, 
            3.078737541170934}, {4.8423058974649305`, 3.078733412377681}, {
            4.987452103799294, 3.0787291173591376`}, {5.001099999999999, 
            3.0787286978719988`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.7708709954181314`}, {-5.000849124559718, 
            2.770871015185076}, {-4.8836598524844295`, 
            2.770880248746801}, {-4.852495975067702, 
            2.7708802009315625`}, {-4.821332030296799, 
            2.770880118817759}, {-4.637243213653665, 
            2.770878576926067}, {-4.453152548827477, 
            2.7708765301400176`}, {-4.266011785581627, 
            2.7707580467369985`}, {-4.166106381399559, 
            2.7706947941774698`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.14523154367052, 
            2.770681577806174}, {-4.078871022335774, 
            2.7706395633339795`}, {-3.891730259089922, 
            2.77052107993096}, {-3.70458949584407, 
            2.770402596527941}, {-3.51744873259822, 
            2.7702841131249216`}, {-3.3303079693523685`, 2.7701656297219026`},
             {-3.3102380345089695`, 2.7701529229543476`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289363196779931, 
            2.770139706583052}, {-3.143167206106517, 
            2.770047146318883}, {-2.9560264428606633`, 
            2.769928662915864}, {-2.7688856796148134`, 
            2.7698101795128447`}, {-2.5817449163689616`, 
            2.7696916961098257`}, {-2.4543696876183803`, 
            2.7696110517312253`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334948498893416`, 
            2.7695978353599298`}, {-2.39460415312311, 
            2.7695732127068062`}, {-2.20746338987726, 
            2.769454729303787}, {-2.0203226266314083`, 
            2.7693362459007678`}, {-1.8331818633855548`, 
            2.7692177624977488`}, {-1.6460411001397048`, 
            2.7690992790947293`}, {-1.598501340727791, 
            2.769069180508103}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5776265029987522`, 
            2.7690559641368075`}, {-1.4589003368938531`, 
            2.7689807956917103`}, {-1.2717595736480014`, 
            2.768862312288691}, {-1.0846188104021515`, 
            2.7687438288856714`}, {-0.8974780471562998, 
            2.7686253454826524`}, {-0.7426329938372017, 2.768527309284981}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.721758156108163, 
            2.7685140929136853`}, {-0.7103372839104463, 
            2.768506862079633}, {-0.5231965206645945, 
            2.768388378676614}, {-0.3360557574187437, 
            2.7682698952735945`}, {-0.1489149941728929, 
            2.7681514118705755`}, {0.038225769072959714`, 
            2.768032928467556}, {0.11323535305338753`, 
            2.7679854380618587`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1341101907824263, 2.767972221690563}, {
            0.22536653231881143`, 2.767914445064537}, {0.41250729556466226`, 
            2.7677959616615175`}, {0.599648058810514, 2.7676774782584985`}, {
            0.7867888220563657, 2.767558994855479}, {0.9691036999439768, 
            2.767443566838737}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899785376730156, 2.767430350467441}, {
            1.1610703485480691`, 2.7673220280494406`}, {1.34821111179392, 
            2.7672035446464216`}, {1.5353518750397717`, 2.767085061243402}, {
            1.7224926382856243`, 2.766966577840383}, {1.8249720468345663`, 
            2.7669016956156143`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458468845636051`, 2.7668884792443187`}, {
            1.909633401531475, 2.7668480944373637`}, {2.096774164777326, 
            2.7667296110343447`}, {2.2839149280231785`, 2.766611127631325}, {
            2.4710556912690294`, 2.766492644228306}, {2.65819645451488, 
            2.7663741608252868`}, {2.6808403937251555`, 2.766359824392492}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.701715231454194, 2.7663466080211965`}, {
            2.845337217760733, 2.7662556774222677`}, {3.0324779810065836`, 
            2.7661371940192483`}, {3.2196187442524344`, 
            2.7660187106162293`}, {3.406759507498287, 2.76590022721321}, {
            3.5367087406157447`, 2.7658179531693703`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.5575835783447833`, 2.7658047367980747`}, {
            3.593900270744137, 2.765781743810191}, {3.781041033989989, 
            2.7656632604071714`}, {3.968181797235841, 2.7655447770041524`}, {
            4.155322560481691, 2.765426293601133}, {4.342463323727543, 
            2.765307810198114}, {4.392577087506334, 2.765276081946248}}]}, 
          {Arrowheads[{{0.014075512403795966`, 1.}}], 
           ArrowBox[{{4.413451925235373, 2.7652628655749525`}, {
            4.529604086973395, 2.7651893267950944`}, {4.716744850219247, 
            2.7650708433920754`}, {4.9038856134651, 2.764952359989056}, {
            5.001099999999999, 2.764890811178742}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.3849993070635205`}, {-5.000822371348418, 
            3.384999299987365}, {-4.8836434485284075`, 
            3.3849963133493803`}, {-4.852480195727973, 
            3.3849946759051655`}, {-4.821316837811359, 
            3.3849930505446335`}, {-4.637227426219185, 
            3.384984173868872}, {-4.453135373296201, 
            3.3849761555306466`}, {-4.296560724685522, 
            3.3849827755981545`}, {-4.1661063242550425`, 
            3.384988291286328}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231482360859, 
            3.384989173886824}, {-4.139986076074843, 
            3.3849893956656625`}, {-3.983411427464162, 
            3.3849960157331704`}, {-3.826836778853483, 
            3.3850026358006784`}, {-3.6702621302428042`, 
            3.3850092558681864`}, {-3.5136874816321235`, 
            3.3850158759356943`}, {-3.3571128330214446`, 
            3.3850224960032023`}, {-3.3102378065934914`, 
            3.385024477906672}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629646993072`, 
            3.3850253605071683`}, {-3.2005381844107657`, 
            3.38502911607071}, {-3.0439635358000867`, 
            3.385035736138218}, {-2.887388887189408, 
            3.385042356205726}, {-2.730814238578729, 
            3.385048976273234}, {-2.574239589968048, 
            3.3850555963407416`}, {-2.45436928893194, 3.3850606645270163`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944470377557`, 
            3.3850615471275125`}, {-2.417664941357369, 
            3.3850622164082496`}, {-2.2610902927466894`, 
            3.3850688364757575`}, {-2.1045156441360104`, 
            3.3850754565432655`}, {-1.9479409955253315`, 
            3.3850820766107734`}, {-1.7913663469146517`, 
            3.3850886966782814`}, {-1.6347916983039719`, 
            3.3850953167457893`}, {-1.5985007712703887`, 
            3.385096851147361}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259293762045`, 
            3.385097733747857}, {-1.4782170496932938`, 
            3.3851019368132973`}, {-1.321642401082614, 
            3.3851085568808053`}, {-1.1650677524719342`, 
            3.385115176948313}, {-1.0084931038612552`, 
            3.385121797015821}, {-0.8519184552505754, 
            3.385128417083329}, {-0.7426322536088374, 3.3851330377677056`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574117146532, 
            3.385133920368202}, {-0.6953438066398965, 
            3.385135037150837}, {-0.5387691580292167, 
            3.385141657218345}, {-0.38219450941853683`, 
            3.385148277285853}, {-0.2256198608078579, 
            3.3851548973533605`}, {-0.06904521219717896, 
            3.3851615174208685`}, {0.08752943641350086, 
            3.3851681374883764`}, {0.11323626405271384`, 
            3.3851692243880493`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.134111105946898, 3.3851701069885456`}, {
            0.2441040850241798, 3.3851747575558844`}, {0.4006787336348596, 
            3.3851813776233923`}, {0.5572533822455386, 3.3851879976909003`}, {
            0.7138280308562184, 3.3851946177584082`}, {0.8704026794668982, 
            3.385201237825916}, {0.9691047817142651, 3.385205411008394}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796236084493, 3.3852062936088902`}, {
            1.0269773280775771`, 3.385207857893424}, {1.183551976688257, 
            3.385214477960932}, {1.340126625298936, 3.38522109802844}, {
            1.4967012739096148`, 3.385227718095948}, {1.6532759225202946`, 
            3.385234338163456}, {1.809850571130974, 3.385240958230964}, {
            1.8249732993758163`, 3.3852415976287387`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481412700005`, 3.385242480229235}, {
            1.966425219741653, 3.385247578298472}, {2.1229998683523323`, 
            3.3852541983659794`}, {2.279574516963012, 3.3852608184334874`}, {
            2.4361491655736907`, 3.3852674385009953`}, {2.5927238141843705`, 
            3.3852740585685033`}, {2.6808418170373676`, 3.385277784249083}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.7017166589315518`, 3.385278666849579}, {
            2.74929846279505, 3.3852806786360112`}, {2.905873111405729, 
            3.385287298703519}, {3.062447760016408, 3.385293918771027}, {
            3.219022408627088, 3.385300538838535}, {3.375597057237767, 
            3.385307158906043}, {3.532171705848447, 3.385313778973551}, {
            3.536710334698919, 3.385313970869427}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5575851765931032`, 3.3853148534699233`}, {
            3.688746354459126, 3.385320399041059}, {3.8453210030698046`, 
            3.385327019108567}, {4.001895651680485, 3.385333639176075}, {
            4.158470300291164, 3.385340259243583}, {4.315044948901843, 
            3.385346879311091}, {4.3925788523604705`, 3.3853501574897713`}}]}, 
          {Arrowheads[{{0.01407546722327669, 1.}}], 
           ArrowBox[{{4.413453694254654, 3.3853510400902675`}, {
            4.4716195975125235`, 3.3853534993785983`}, {4.6281942461232015`, 
            3.3853601194461063`}, {4.7847688947338805`, 3.385366739513614}, {
            4.941343543344561, 3.385373359581122}, {5.001099999999999, 
            3.385375886118979}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.3693994381759471`, -0.9123354386518312}, {
            1.4868202621331426`, -0.9123354389205931}, {
            1.604241086090338, -0.912335439189355}, {
            1.7216619100475334`, -0.9123354394581168}, {
            1.839082734004729, -0.9123354397268787}, {
            1.9565035579619245`, -0.9123354399956406}, {
            2.07392438191912, -0.9123354402644025}, {
            2.191345205876315, -0.9123354405331644}, {
            2.2043931146896516`, -0.9123354405630295}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.225267956602494, -0.9123354406108095}, {
            2.308766029833511, -0.9123354408019263}, {
            2.3390817616013546`, -0.9123354368220123}, {
            2.369397493363421, -0.912335432354448}, {
            2.47594719818844, -0.9123354067333161}, {
            2.5824969047275403`, -0.9123353703670153}, {
            2.585966977140315, -0.9123353691748992}, {
            2.596872919037019, -0.9123353652904082}, {
            2.6067874116960192`, -0.9123353616372089}, {
            2.7059323414998904`, -0.9123353122602228}, {
            2.8050772764462755`, -0.912335246606166}, {
            2.9290089253702014`, -0.9123344769235703}, {
            3.0529405742941274`, -0.9123337072409745}, {
            3.0602616331112316`, -0.912333661773238}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0811364750236714`, -0.912333532129175}, {
            3.176872223218053, -0.9123329375583787}, {
            3.300803872141979, -0.9123321678757831}, {
            3.4247355210659047`, -0.9123313981931873}, {
            3.5486671699898307`, -0.9123306285105915}, {
            3.6725988189137566`, -0.9123298588279959}, {
            3.7965304678376826`, -0.9123290891454001}, {
            3.916130151470629, -0.9123255302618952}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.9370049933742295`, -0.9123249090969535}, {
            4.0444006216507455`, -0.9123217133650053}, {
            4.168335698557278, -0.9123180254748078}, {
            4.292270775463809, -0.9123143375846103}, {
            4.416205852370341, -0.9123106496944129}, {
            4.540140929276872, -0.9123069618042154}, {
            4.664076006183404, -0.912303273914018}, {
            4.771998669518259, -0.9123000624992827}}]}, 
          {Arrowheads[{{0.0049874986940664475`, 1.}}], 
           ArrowBox[{{4.792873511310322, -0.9122985345391681}, {
            4.9054781431378425`, -0.9122741841453328}, {
            5.001099999999999, -0.9122535062226215}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.6059222111466545`, -0.30569218095170614`}, {
            1.6938924314458876`, -0.30569218036171264`}, {
            1.7818626521022727`, -0.3056921794948896}, {
            1.8992196126169056`, -0.305692177832602}, {
            2.0165765731315384`, -0.3056921761703144}, {
            2.133933533646171, -0.3056921745080268}, {
            2.2512904941608043`, -0.30569217284573924`}, {
            2.368647454675437, -0.30569217118345166`}, {
            2.440915887660359, -0.30569217015981476`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4617907295732016`, -0.3056921698641358}, {
            2.4860044151900698`, -0.3056921695211641}, {
            2.603361375704703, -0.30569216785887654`}, {
            2.7207183362193357`, -0.30569216619658895`}, {
            2.751290410733502, -0.30569215782630854`}, {
            2.781862486904641, -0.30569214879009804`}, {
            2.9014555125323893`, -0.30569209798084646`}, {
            3.0210485820903172`, -0.3056920311319723}, {
            3.027068195236331, -0.3056920277215006}, {
            3.0330878085123216`, -0.3056920242648198}, {
            3.0391074219200713`, -0.30569202076140767`}, {
            3.045127035461383, -0.3056920172107377}, {
            3.0511466491380737`, -0.30569201361227966`}, {
            3.063185877044026, -0.30569200622099313`}, {
            3.0752251055176387`, -0.3056919986309713}, {
            3.195617456089572, -0.30569190028335885`}, {
            3.2967844060867684`, -0.3056917943471235}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.317659247999549, -0.30569176117102936`}, {
            3.466504604665947, -0.30569058399750465`}, {
            3.6169993176146704`, -0.3056893937797131}, {
            3.7674940305633933`, -0.3056882035619216}, {
            3.917988743512116, -0.30568701334413007`}, {
            4.068483456460839, -0.3056858231263385}, {
            4.15265292448714, -0.305685157455124}}]}, 
          {Arrowheads[{{0.01982223954874403, 1.}}], 
           ArrowBox[{{4.17352776639933, -0.30568499236222635`}, {
            4.218978169409562, -0.30568463290854697`}, {
            4.369472882358285, -0.3056834426907554}, {
            4.519967595307008, -0.3056822524729639}, {
            4.670483551135896, -0.30567725165981535`}, {
            4.820999506964784, -0.3056722508466668}, {
            4.971515462793672, -0.3056672500335183}, {
            5.001099999999999, -0.3056662671028925}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.017340695408330088`, 1.}}], 
           ArrowBox[{{-0.37340907408225665`, 
            1.3206362899195727`}, {-0.2546212818025415, 
            1.320636290006774}, {-0.13583348952282637`, 
            1.3206362900939754`}, {-0.017045697243111335`, 
            1.3206362901811768`}, {0.1017420950366037, 1.3206362902683784`}, {
            0.22052988731631873`, 1.3206362903555797`}, {0.24537668828921405`,
             1.3206362903561524`}, {0.2702234892620317, 
            1.3206362903563866`}, {0.3103914828972976, 1.3206362903544584`}, {
            0.3505594765330359, 1.320636290350466}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.30007673855162376`}, \
{-4.996642950587454, -0.3000768312710928}, {-4.843496393448644, \
-0.30008001716071425`}, {-4.690349836309835, -0.30008320305033576`}, \
{-4.537203279171026, -0.3000863889399572}, {-4.384056722032216, \
-0.30008957482957865`}, {-4.230910164893406, -0.3000927607192001}, \
{-4.166106323666971, -0.300094108825805}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481758645, -0.30009454308265954`}, \
{-4.077763607754598, -0.30009594660882155`}, {-3.9246170506157885`, \
-0.300099132498443}, {-3.7714704934769787`, -0.30010231838806445`}, \
{-3.618323936338169, -0.30010550427768595`}, {-3.4651773791993596`, \
-0.3001086901673074}, {-3.3120308220605508`, -0.30011187605692885`}, \
{-3.3102378054256167`, -0.30011191335684073`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362963517291, -0.30011234761369526`}, \
{-3.158884264921741, -0.3001150619465503}, {-3.005737707782932, \
-0.30011824783617175`}, {-2.8525911506441224`, -0.30012143372579325`}, \
{-2.7300860208354063`, -0.3001214793113983}, {-2.60758089102669, \
-0.3001215248970034}, {-2.485075814525179, -0.30012154954010606`}, \
{-2.4543692870981153`, -0.3001215557170265}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494445185273, -0.3001215599162065}, \
{-2.362570738023668, -0.3001215741832087}, {-2.338069728265934, \
-0.3001215766748492}, {-2.3111186179711027`, -0.3001215792077693}, \
{-2.3075659716655488`, -0.30012157951693624`}, {-2.209193185265595, \
-0.3001215880096411}, {-2.110820403344288, -0.3001215942770758}, \
{-1.992964914599031, -0.30012159973500163`}, {-1.8751094258537737`, \
-0.30012160519292747`}, {-1.7572539371085165`, -0.3001216106508533}, \
{-1.639398448363259, -0.30012161610877913`}, {-1.5985007686715715`, \
-0.30012161800276393`}}]}, 
          {Arrowheads[{{0.014920007190883895`, 1.}}], 
           ArrowBox[{{-1.577625926758729, -0.30012161896948464`}, \
{-1.5215429596180017`, -0.30012162156670497`}, {-1.4036874708727445`, \
-0.30012162702463074`}, {-1.2858319821274873`, -0.3001216324825566}, \
{-1.1679764933822299`, -0.3001216379404824}, {-1.1393985194452365`, \
-0.30012163795814617`}, {-1.1108205455103346`, -0.3001216379727023}, \
{-1.0422206919116421`, -0.300121637989553}, {-1.024471880058239, \
-0.3001216379932702}, {-1.007220361268013, -0.3001216379964522}, \
{-0.9991416651936739, -0.3001216379978762}, {-0.9921296333934418, \
-0.3001216379990871}, {-0.9802070285865339, -0.3001216380011211}, \
{-0.9719055001622332, -0.3001216380025032}, {-0.9661411562781677, \
-0.3001216380034493}, {-0.9602144124954286, -0.300121638004413}, \
{-0.9547203438623769, -0.3001216380052979}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.014244006002823613`, 1.}}], 
           ArrowBox[{{-0.3999892819010807, 
            1.8793775403915345`}, {-0.28089588981036584`, 
            1.879377541696053}, {-0.16180249771965105`, 
            1.8793775430005712`}, {-0.04270910562893626, 
            1.8793775443050897`}, {0.07638428646177865, 1.879377545609608}, {
            0.10000660910717692`, 1.8793775456163362`}, {0.12362893175181666`,
             1.8793775456247732`}, {0.159161198441301, 1.879377545641724}, {
            0.19469346512796737`, 1.8793775456592616`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9534776582762998, 0.8143924224104522}, {
            1.0785331797742232`, 0.8143924224694047}, {1.203588701272147, 
            0.8143924225283572}, {1.3286442227700703`, 0.8143924225873097}, {
            1.4536997442679933`, 0.8143924226462622}, {1.578755265765917, 
            0.8143924227052147}, {1.7038107872638402`, 0.8143924227641672}, {
            1.788471334790004, 0.8143924228040771}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8093461767028467`, 0.8143924228139177}, {
            1.8288663087617638`, 0.8143924228231196}, {1.953921830259687, 
            0.8143924228820721}, {2.0539662455580188`, 0.814392419580751}, {
            2.1540106606924305`, 0.8143924143514821}, {2.164015102211471, 
            0.814392413556794}, {2.1750199878852112`, 0.81439241264369}, {
            2.178521542418868, 0.8143924123396264}, {2.2858214596243425`, 
            0.8143924029458798}, {2.3931213774784417`, 0.8143923888635772}, {
            2.5104126876711947`, 0.8143923664577262}, {2.627703997863948, 
            0.8143923440518751}, {2.644339853216545, 0.8143923408739714}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.665214695129387, 0.8143923368863052}, {
            2.744995308056701, 0.8143923216460242}, {2.862286618249454, 
            0.8143922992401731}, {2.979577928442207, 0.814392276834322}, {
            3.09686923863496, 0.814392254428471}, {3.214160548827713, 
            0.8143922320226199}, {3.331451859020466, 0.814392209616769}, {
            3.3622858892793834`, 0.8143921377744123}, {3.393119923680259, 
            0.8143920610433085}, {3.5002083716422336`, 0.8143916832245396}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.521083213554946, 0.8143916095760068}, {
            3.53204268395833, 0.8143915709098977}, {3.670965593797429, 
            0.8143909288110159}, {3.810892269305689, 0.8143143009050968}, {
            3.9508189448139497`, 0.8142376729991776}, {4.090745620322209, 
            0.8141610450932584}, {4.23067229583047, 0.8140844171873391}, {
            4.35607678733553, 0.8140157420505791}}]}, 
          {Arrowheads[{{0.014949777106768498`, 1.}}], 
           ArrowBox[{{4.376951626118217, 0.8140043103834113}, {
            4.51052564684699, 0.8139311613755007}, {4.65045232235525, 
            0.8138545334695815}, {4.79037899786351, 0.8137779055636623}, {
            4.93030567337177, 0.813701277657743}, {5.001099999999999, 
            0.8136625086311741}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.41691330046839337`, 1.3465278014623523`}, {
            0.5447019027031033, 1.346535950921713}, {0.6724905049378131, 
            1.3465441003810736`}, {0.800279107172523, 1.3465522498404345`}, {
            0.9280677094072329, 1.3465603992997952`}, {1.0558563116419428`, 
            1.3465685487591559`}, {1.1836449138766518`, 
            1.3465766982185168`}, {1.2519069752841412`, 
            1.3465810514932657`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.2727818171545349`, 1.3465823827440386`}, {
            1.3114335161113617`, 1.3465848476778775`}, {1.4392221183460725`, 
            1.3465929971372383`}, {1.5670107205807824`, 1.346601146596599}, {
            1.6947993228154914`, 1.3466092960559597`}, {1.8225879250502013`, 
            1.3466174455153206`}, {1.9503765272849112`, 
            1.3466255949746813`}, {2.078165129519621, 1.346633744434042}, {
            2.107775491970283, 1.346635632774952}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.128650333840677, 1.346636964025725}, {
            2.20595373175433, 1.3466418938934028`}, {2.33374233398904, 
            1.3466500433527635`}, {2.46153093622375, 1.3466581928121242`}, {
            2.5893195384584597`, 1.346666342271485}, {2.7171081406931687`, 
            1.3466744917308457`}, {2.8448967429278786`, 
            1.3466826411902064`}, {2.963644008656425, 1.3466902140566386`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.9845188505508786`, 1.3466907820546141`}, {
            3.1067945274939466`, 1.346690693242914}, {3.2409036924753765`, 
            1.346690541090397}, {3.3581374838437084`, 1.346690342759954}, {
            3.4753712752120403`, 1.346690144429511}, {3.592605066580372, 
            1.3466899460990678`}, {3.7098388579487036`, 
            1.3466897477686246`}, {3.8195125270636363`, 
            1.3466895622280297`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.840387368976449, 1.3466895269129844`}, {
            3.9443064406853674`, 1.3466893511077385`}, {4.0615402320537, 
            1.3466891527772953`}, {4.178774023422031, 1.346688954446852}, {
            4.209836319655349, 1.3466885321973077`}, {4.240898624980842, 
            1.3466880859631574`}, {4.4066307482386655`, 1.346684755461526}, {
            4.572363385147334, 1.3466804141981328`}, {4.6753810424914874`, 
            1.346655962819285}}]}, 
          {Arrowheads[{{0.007301710979255822, 1.}}], 
           ArrowBox[{{4.696255883816331, 1.3466510081477578`}, {
            4.80551926823156, 1.3466250743372303`}, {4.922097209773672, 
            1.3465974044067792`}, {5.001099999999999, 
            1.3465786529887829`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3264717166413037, 1.8917944016871746`}, {
            0.451027883327312, 1.891794401724723}, {0.5755840500133201, 
            1.8917944017622712`}, {0.6254065167049326, 1.8917944015785582`}, {
            0.675228983428611, 1.8917944013360235`}, {0.6802112301053171, 
            1.891794401305404}, {0.6864141272185769, 1.8917944012662904`}, {
            0.7433437710647411, 1.89179440089953}, {0.8002734149892954, 
            1.8917944004450957`}, {0.91782722558577, 1.891794399326128}, {
            1.0353810361822444`, 1.8917943982071603`}, {1.152934846778719, 
            1.8917943970881925`}, {1.161465393155008, 1.8917943970069921`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1823402350678507`, 1.8917943968082893`}, {
            1.2704886573751937`, 1.8917943959692247`}, {1.388042467971668, 
            1.8917943948502571`}, {1.5055962785681427`, 
            1.8917943937312893`}, {1.6231500891646173`, 
            1.8917943926123215`}, {1.740703899761092, 1.891794391493354}, {
            1.770484493973809, 1.8917943939571318`}, {1.8002650881192863`, 
            1.8917943967425213`}, {1.8888172442033895`, 1.891794409441809}, {
            1.97736939826943, 1.8917944260921102`}, {1.9829270638146588`, 
            1.8917944271482727`}, {2.0056114127900813`, 
            1.8917944317652784`}, {2.0173339115815514`, 
            1.8917944343022222`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.038208753494393, 1.8917944402745315`}, {
            2.141717489872971, 1.8917944778645583`}, {2.2551392181735497`, 
            1.8917945190545677`}, {2.36856091625686, 1.8917945785494568`}, {
            2.481982614340171, 1.891794638044346}, {2.6237577073690703`, 
            1.8917903034927737`}, {2.7655328003979696`, 
            1.8917859689412015`}, {2.8732024298252083`, 
            1.8917826771107993`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.8940772717282948`, 1.89178203889518}, {
            2.907307893426869, 1.8917816343896292`}, {3.049082986455768, 
            1.8917772998380569`}, {3.1908580794846673`, 
            1.8917729652864845`}, {3.3326331725135665`, 
            1.8917686307349124`}, {3.4744082655424657`, 1.89176429618334}, {
            3.616183358571365, 1.8917599616317677`}, {3.72907094785175, 
            1.8917565102704097`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.7499457897548365`, 1.8917558720547905`}, {
            3.757958451600264, 1.8917556270801954`}, {3.899733544629164, 
            1.8917512925286233`}, {4.041508637658063, 1.891746957977051}, {
            4.183283730686963, 1.8917426234254786`}, {4.325058823715862, 
            1.8917382888739063`}, {4.466833916744761, 1.8917339543223342`}, {
            4.584939465878292, 1.8917303434300203`}}]}, 
          {Arrowheads[{{0.009468012528419478, 1.}}], 
           ArrowBox[{{4.605814307781378, 1.891729705214401}, {
            4.6086090097736605`, 1.8917296197707618`}, {4.75038410280256, 
            1.8917252852191895`}, {4.89234876285526, 1.8912378026363454`}, {
            5.001099999999999, 1.8912301516965648`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9530884210893966, 0.26958847591853724`}, {
            0.9573828501279324, 0.2695884759178683}, {0.9630559143911538, 
            0.26958847591697727`}, {0.9751872750789653, 
            0.26958847591502977`}, {0.9981717215639159, 0.2695884759111763}, {
            1.012762837008622, 0.26958847590868135`}, {1.0283004850969122`, 
            0.2695884759057705}, {1.0903873564381374`, 0.2695884758926145}, {
            1.2079260038275381`, 0.2695884758519431}, {1.3254646512580792`, 
            0.26958847576272}, {1.4430032987798993`, 0.2695884755844786}, {
            1.5605419463017196`, 0.26958847540623726`}, {1.6780805943466248`, 
            0.2695884748216107}, {1.7880820976031009`, 0.2695884742744732}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8089569395159435`, 0.2695884740564155}, {
            1.825464568869004, 0.2695884738329316}, {1.8553098954331284`, 
            0.2695884733788633}, {1.9456027235165798`, 0.2695884712252306}, {
            2.035895553180321, 0.26958846826387234`}, {2.0395851597075683`, 
            0.26958846814171167`}, {2.067575278369539, 
            0.26958846712660856`}, {2.0930208409751865`, 
            0.26958846611370657`}, {2.2202486679296065`, 
            0.26958845486195343`}, {2.3474764948840265`, 
            0.2695884436102003}, {2.474704351568155, 0.2695884207378544}, {
            2.601932208252284, 0.2695883978655085}, {2.6439506160245014`, 
            0.26958774054056506`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6648254579347896`, 0.26958741398001684`}, {
            2.7609798083915607`, 0.26958590976659413`}, {2.920027408530838, 
            0.2695834216676798}, {3.0790750086701153`, 0.2695809335687655}, {
            3.238122608809392, 0.26957844546985116`}, {3.397170208948669, 
            0.2695759573709368}, {3.4998191343463216`, 0.2695743515580883}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.52069397625661, 0.2695740249975401}, {
            3.556217809087946, 0.2695734692720225}, {3.7152654092272237`, 
            0.2695709811731082}, {3.874313009366501, 0.2695684930741939}, {
            4.0333606095057775`, 0.26956600497527955`}, {4.192408209645055, 
            0.2695635168763652}, {4.351455809784332, 0.2695610287774509}, {
            4.355687652668141, 0.2695609625756115}}]}, 
          {Arrowheads[{{0.014959095453407059`, 1.}}], 
           ArrowBox[{{4.37656249457843, 0.2695606360150633}, {
            4.51050340992361, 0.2695585406785366}, {4.669551010062887, 
            0.2695560525796223}, {4.828598610202164, 0.26955356448070794`}, {
            4.987646210341441, 0.26955107638179365`}, {5.001099999999999, 
            0.2695508659142392}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.200899939099535}, \
{-4.993632597229871, -4.200898828389233}, {-4.9624481833434455`, \
-4.20089429662513}, {-4.773894565838077, -4.200871432922597}, \
{-4.585337536059042, -4.2008523537102365`}, {-4.456624697036034, \
-4.200855476906032}, {-4.327911858013026, -4.200858600101827}, \
{-4.1991990189900195`, -4.200861723297622}, {-4.166106326373074, \
-4.200862526286347}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231484466377, -4.200863032810941}, \
{-4.070486179967012, -4.200864846493418}, {-3.941773340944005, \
-4.200867969689213}, {-3.813060501920998, -4.200871092885008}, \
{-3.6843476628979905`, -4.200874216080804}, {-3.5556348238749838`, \
-4.200877339276599}, {-3.426921984851976, -4.200880462472394}, \
{-3.3102378081984876`, -4.200883293794683}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2893629662917903`, -4.200883800319276}, \
{-3.1694963068059616`, -4.200886708863985}, {-3.040783467782955, \
-4.20088983205978}, {-2.912070628759947, -4.200892955255576}, \
{-2.7833577897369404`, -4.200896078451371}, {-2.6546449507139336`, \
-4.200899201647166}, {-2.525932111690926, -4.2009023248429616`}, \
{-2.4543692900239007`, -4.200904061303018}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4334944481172034`, -4.200904567827612}, \
{-2.3972192726679173`, -4.200905448038757}, {-2.2685064336449106`, \
-4.200908571234552}, {-2.1397935946219038`, -4.2009116944303475`}, \
{-2.011080755598896, -4.200914817626143}, {-1.8823679165758893`, \
-4.200917940821938}, {-1.7536550775528825`, -4.2009210640177335`}, \
{-1.6249422385298748`, -4.200924187213529}, {-1.5985007718493138`, \
-4.200924828811353}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259299426165`, -4.200925335335947}, \
{-1.496229399506868, -4.200927310409324}, {-1.3675165604838613`, \
-4.200930433605119}, {-1.2388037214608527`, -4.200933556800915}, \
{-1.110090882437846, -4.20093667999671}, {-0.9813780434148391, \
-4.200939803192505}, {-0.8526652043918315, -4.200942926388301}, \
{-0.742632253674727, -4.20094559631969}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574117680298, -4.2009461028442825`}, \
{-0.5952395263458179, -4.200949172779891}, {-0.4665266873228102, \
-4.200952295975687}, {-0.3378138482998021, -4.200955419171482}, \
{-0.2091010092767953, -4.200958542367277}, {-0.08038817025378853, \
-4.200961665563073}, {0.04832466876921915, -4.200964788758868}, {
            0.11323626449985988`, -4.200966363828025}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110640655713`, -4.200966870352619}, {
            0.17703750779222638`, -4.200967911954663}, {
            0.30575034681523316`, -4.2009710351504586`}, {
            0.43446318583824084`, -4.200974158346254}, {
            0.5631760248612476, -4.200977281542049}, {
            0.6918888638842549, -4.200980404737844}, {
            0.8206017029072625, -4.200983527933639}, {
            0.9493145419302693, -4.200986651129434}, {
            0.9691047826744467, -4.20098713133636}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899796245811439, -4.200987637860954}, {
            1.078027380953276, -4.20098977432523}, {
            1.2067402199762842`, -4.200992897521025}, {
            1.335453058999291, -4.20099602071682}, {
            1.4641658980222978`, -4.2009991439126155`}, {
            1.5928787370453055`, -4.201002267108411}, {
            1.7215915760683134`, -4.201005390304206}, {
            1.8249733008490334`, -4.201007898844695}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8458481427557307`, -4.201008405369289}, {
            1.8503044150913202`, -4.2010085135000015`}, {
            1.9790172541143272`, -4.201011636695797}, {
            2.107730093137335, -4.201014759891592}, {
            2.236442932160342, -4.201017883087387}, {
            2.365155771183349, -4.201021006283183}, {
            2.4938686102063565`, -4.201024129478978}, {
            2.6225814492293633`, -4.201027252674773}, {
            2.6808418190236205`, -4.2010286663530305`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716660930318, -4.201029172877624}, {
            2.75129428825237, -4.201030375870569}, {
            2.8800071272753778`, -4.201033499066364}, {
            3.008719966298385, -4.201036622262159}, {
            3.137432805321392, -4.201039745457955}, {
            3.2661456443443995`, -4.20104286865375}, {
            3.3948584833674076`, -4.201045991849545}, {
            3.5235713223904135`, -4.201049115045341}, {
            3.5367103371982074`, -4.201049433861367}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.5575851791049047`, -4.2010499403859605`}, {
            3.652284161413421, -4.201052238241136}, {
            3.7947906168203787`, -4.201085339413729}, {
            3.937297072227336, -4.201118440586322}, {
            4.079803527634293, -4.201151541758916}, {
            4.22230998304125, -4.20118464293151}, {
            4.364816438448207, -4.201217744104103}, {
            4.392578835620076, -4.201224192709521}}]}, 
          {Arrowheads[{{0.014075468004416336`, 1.}}], 
           ArrowBox[{{4.413453676969786, -4.201229041484438}, {
            4.507322893855164, -4.2012508452766975`}, {
            4.649829349262121, -4.201283946449291}, {
            4.7923358046690785`, -4.201317047621885}, {
            4.934842260076035, -4.201350148794478}, {
            5.001099999999999, -4.201365539036826}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.9456737741411874`}, \
{-4.938869694725646, -3.9456668456807282`}, {-4.801630221410768, \
-3.9456515660149756`}, {-4.66439074809589, -3.9456362863492225`}, \
{-4.527151274781009, -3.94562100668347}, {-4.38991180146613, \
-3.9456057270177167`}, {-4.252672328151251, -3.9455904473519636`}, \
{-4.166106328661443, -3.9455808094576623`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231486877979, -3.945578485340574}, \
{-4.115432854836373, -3.945575167686211}, {-3.9781933815214927`, \
-3.945559888020458}, {-3.840953908206613, -3.945544608354705}, \
{-3.7037144348917344`, -3.945529328688952}, {-3.5664749615768554`, \
-3.9455140490231995`}, {-3.429235488261976, -3.9454987693574464`}, \
{-3.3102378155394225`, -3.9454855206570496`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629737559587`, -3.9454831965399615`}, \
{-3.1547565416322176`, -3.9454682100259406`}, {-3.0175170683173387`, \
-3.945452930360188}, {-2.8802775950024593`, -3.945437650694435}, \
{-2.7430381216875803`, -3.945422371028682}, {-2.6057986483727014`, \
-3.945407091362929}, {-2.4685591750578224`, -3.9453918116971765`}, \
{-2.4543693024174025`, -3.945390231856437}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944606339386`, -3.9453879077393488`}, \
{-2.331319701742943, -3.9453765320314234`}, {-2.164025034900372, \
-3.945377268377422}, {-1.9967303680577997`, -3.945378004723421}, \
{-1.8294357012152285`, -3.9453787410694203`}, {-1.6621410343726573`, \
-3.945379477415419}, {-1.5985007847605943`, -3.945379757527416}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625942847954, -3.945379849407848}, \
{-1.4948463675300854`, -3.945380213761418}, {-1.327551700687514, \
-3.945380950107417}, {-1.1602570338449427`, -3.9453816864534157`}, \
{-0.9929623670023708, -3.9453824227994145`}, {-0.8256677001597987, \
-3.945383159145414}, {-0.7426322663423378, -3.9453835246251425`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574244296974, -3.9453836165055747`}, \
{-0.6583730333172275, -3.9453838954914127`}, {-0.4910783664746563, \
-3.9453846318374115`}, {-0.323783699632084, -3.9453853681834103`}, \
{-0.1564890327895121, -3.945386104529409}, {
            0.010805634053059343`, -3.945386840875408}, {
            0.11323625207591882`, -3.945387291722869}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411109398855922`, -3.9453873836033013`}, {
            0.17810030089563034`, -3.9453875772214073`}, {
            0.3453949677382018, -3.945388313567406}, {
            0.5126883980051942, -3.9453883418796885`}, {
            0.6799818282721861, -3.9453883701919708`}, {
            0.8472752585391786, -3.945388398504253}, {
            0.969104770500208, -3.945388419122346}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899796124130503, -3.945388422655147}, {
            1.014568688806171, -3.945388426816535}, {
            1.1818621190731635`, -3.945388455128817}, {
            1.349155549340156, -3.9453884834410995`}, {
            1.5164489796071483`, -3.945388511753382}, {
            1.6837424098741407`, -3.945388540065664}, {
            1.8249732889267427`, -3.9453885639671915`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.845848130839585, -3.9453885674999927`}, {
            1.851035840141133, -3.9453885683779464`}, {
            2.0183292704081257`, -3.9453885966902287`}, {
            2.1856227006751174`, -3.945388625002511}, {
            2.35291613094211, -3.945388653314793}, {
            2.5202095612091027`, -3.945388681627075}, {
            2.6808418073532776`, -3.945388708812037}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.7017166492661198`, -3.945388712344838}, {
            2.854796421743087, -3.9453887382516397`}, {
            3.022089852010079, -3.945388766563922}, {
            3.157866497564858, -3.945389193618675}, {
            3.293643306233755, -3.945390066768723}, {
            3.410872693471874, -3.9453912908180078`}, {
            3.528102080709993, -3.9453925148672924`}, {
            3.5367103257630905`, -3.9453926047501833`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.5575851676747954`, -3.9453928227146027`}, {
            3.645331467948112, -3.945393738916577}, {
            3.762560855186231, -3.945394962965862}, {
            3.8797902424243498`, -3.9453961870151466`}, {
            3.9970196296624683`, -3.945397411064431}, {
            4.114249016900587, -3.945398635113716}, {
            4.231478404138706, -3.9453998591630004`}, {
            4.2625505400446295`, -3.9454016959765528`}, {
            4.293622627002417, -3.9454036004709265`}, {
            4.392578843755034, -3.9454110985749495`}}]}, 
          {Arrowheads[{{0.014075467480279201`, 1.}}], 
           ArrowBox[{{4.413453685607951, -3.9454126803021095`}, {
            4.461019884979317, -3.9454162844850758`}, {
            4.628414827881272, -3.945431100349181}, {
            4.765039211859017, -3.945444588216852}, {
            4.901663595836762, -3.9454580760845226`}, {
            5.001099999999999, -3.9454678926708593`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.0009016647914490518, 1.}}], 
           ArrowBox[{{0.5006832096204847, -0.7676098807523131}, {
            0.5044176354621229, -0.7676098807524461}, {
            0.5100436356993031, -0.7676098807526464}, {
            0.519771808078554, -0.7676098807529925}, {
            0.53200706242452, -0.767609880753428}, {
            0.538327429580235, -0.7676098807536529}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.20058752917443728`, -1.9243650659837193`}, {
            0.32054107472148907`, -1.9243650659155596`}, {
            0.4404946202685408, -1.9243650658474}, {
            0.560448165815593, -1.9243650657792404`}, {
            0.6804017113626448, -1.9243650657110807`}, {
            0.8003552569096964, -1.9243650656429212`}, {
            0.9203088031314725, -1.9243650643830479`}, {
            1.0355812056881417`, -1.9243650631723408`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0564560476009843`, -1.9243650629530922`}, {
            1.160215895575025, -1.9243650618633015`}, {
            1.280169441796801, -1.9243650606034282`}, {
            1.4001229880185773`, -1.9243650593435548`}, {
            1.5200765342403533`, -1.9243650580836817`}, {
            1.6400300804621293`, -1.9243650568238084`}, {
            1.7599836266839057`, -1.9243650555639351`}, {
            1.8559464688201315`, -1.924365064242559}, {
            1.891449724114688, -1.9243650689079792`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.9123245660275303`, -1.9243650716511054`}, {
            1.9519093099824938`, -1.924365076852867}, {
            1.9615055939076622`, -1.9243650785848379`}, {
            1.97110187780756, -1.9243650803681767`}, {
            1.975420205548264, -1.9243650811986122`}, {
            2.0758638790816204`, -1.9243651006585285`}, {
            2.1763075487866277`, -1.924365126335202}, {
            2.2936181625846617`, -1.9243651645038804`}, {
            2.410928776382695, -1.9243652026725588`}, {
            2.528239390180729, -1.9243652408412373`}, {
            2.645550003978763, -1.9243652790099157`}, {
            2.7473182425411986`, -1.924365312121661}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7681930844540403`, -1.924365318913588}, {
            2.8801712315748307`, -1.9243653553472728`}, {
            2.9974818453728647`, -1.9243653935159513`}, {
            3.114792459170898, -1.9243654316846297`}, {
            3.145545586166866, -1.9243654525413187`}, {
            3.176298708470599, -1.924365472253152}, {
            3.308364769727708, -1.9243655140508074`}, {
            3.440430715049998, -1.9243654948552098`}, {
            3.447854309233636, -1.9243654935358923`}, {
            3.455277903020964, -1.924365491970753}, {
            3.4627014964091067`, -1.924365490154181}, {
            3.4701250893951965`, -1.9243654880804844`}, {
            3.4775486819763683`, -1.9243654857438945`}, {
            3.492395865501893, -1.924365479983916}, {
            3.507243047367741, -1.9243654730892186`}, {
            3.6031867609676036`, -1.9243653363051627`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.624061602880425, -1.9243653065445308`}, {
            3.6557146877644526`, -1.9243652614176834`}, {
            3.8041861289501036`, -1.9243648439021632`}, {
            3.9897739740454377`, -1.9243517497002423`}, {
            4.175361819140773, -1.924338655498321}, {
            4.360949664236108, -1.9243255612963999`}, {
            4.459055277763525, -1.924318639427608}}]}, 
          {Arrowheads[{{0.012483205474053414`, 1.}}], 
           ArrowBox[{{4.47993011962441, -1.9243171665973466`}, {
            4.546537509331442, -1.9243124670944787`}, {
            4.732125354426776, -1.9242993728925575`}, {
            4.917713199522111, -1.9242862786906363`}, {
            5.001099999999999, -1.9242803953117844`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.456150605837897}, {-4.897218074578924, 
            4.456126782498008}, {-4.780005744987659, 
            4.456099902083963}, {-4.662793415396394, 
            4.456073021669917}, {-4.5455810858051295`, 
            4.4560461412558725`}, {-4.428368756213865, 
            4.456019260841827}, {-4.397281609279529, 
            4.456016321723857}, {-4.366194415286717, 
            4.456013500627534}, {-4.196499483312455, 
            4.456001987241842}, {-4.166106339243788, 4.4560004428873}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231497357893, 
            4.455999382182399}, {-4.026804071856608, 
            4.455993364577507}, {-3.89106035918922, 
            4.456010318629865}, {-3.755316646521832, 
            4.456027272682222}, {-3.6195729338544425`, 
            4.45604422673458}, {-3.4838292211870545`, 
            4.4560611807869375`}, {-3.348085508519665, 
            4.456078134839295}, {-3.310237826586072, 
            4.4560828619207085`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629848360466`, 
            4.456085469136564}, {-3.212341795852277, 
            4.456095088891653}, {-3.076598083184889, 
            4.45611204294401}, {-2.9408543705175, 
            4.456128996996368}, {-2.8051106578501113`, 
            4.456145951048725}, {-2.6693669451827224`, 
            4.456162905101083}, {-2.5336232325153345`, 
            4.45617985915344}, {-2.454369314835038, 4.456189757770794}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944730850125`, 
            4.4561923649866495`}, {-2.3978795198479466`, 
            4.456196813205797}, {-2.2621358071805577`, 
            4.456213767258155}, {-2.126392094513169, 
            4.456230721310512}, {-1.99064838184578, 
            4.45624767536287}, {-1.8549046691783913`, 
            4.4562646294152275`}, {-1.7191609565110033`, 
            4.456281583467585}, {-1.5985008030840038`, 
            4.456296653620879}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259613339785`, 
            4.456299260836736}, {-1.4476735311762257`, 
            4.4563154915723}, {-1.3119298185088368`, 
            4.456332445624658}, {-1.176186105841449, 
            4.456349399677015}, {-1.04044239317406, 
            4.456366353729373}, {-0.9046986805066721, 
            4.45638330778173}, {-0.7689549678392833, 
            4.456400261834087}, {-0.7426322913329698, 4.456403549470965}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574495829446, 
            4.45640615668682}, {-0.6332112551718945, 
            4.456417215886445}, {-0.49746754250450653`, 
            4.456434169938802}, {-0.3617238298371177, 
            4.45645112399116}, {-0.22598011716972888`, 
            4.4564680780435175`}, {-0.09023640450234005, 4.456485032095875}, {
            0.045507308165048777`, 4.456501986148233}, {0.11323622041806408`, 
            4.456510445321051}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1341110621680893, 4.4565130525369065`}, {
            0.1812510208324376, 4.45651894020059}, {0.31699473349982554`, 
            4.456535894252948}, {0.4527384461672135, 4.456552848305305}, {
            0.5884821588346023, 4.456569802357663}, {0.7242258715019916, 
            4.45658675641002}, {0.8599695841693804, 4.456603710462377}, {
            0.969104732169098, 4.456617341171136}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899795739191232, 4.456619948386992}, {
            0.9957132968367692, 4.456620664514735}, {1.1314570095041572`, 
            4.456637618567092}, {1.2672007221715451`, 4.45665457261945}, {
            1.4029444348389344`, 4.4566715266718075`}, {1.5386881475063232`, 
            4.456688480724165}, {1.6744318601737112`, 4.456705434776523}, {
            1.810175572841099, 4.45672238882888}, {1.8249732439201318`, 
            4.456724237021223}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458480856701571`, 4.456726844237078}, {
            1.945919285508488, 4.456739342881238}, {2.0816629981758767`, 
            4.456756296933595}, {2.217406710843265, 4.456773250985953}, {
            2.353150423510653, 4.45679020503831}, {2.488894136178042, 
            4.456807159090667}, {2.6246378488454307`, 4.456824113143025}, {
            2.6808417556711657`, 4.456831132871308}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.701716597421191, 4.456833740087164}, {
            2.760381561512819, 4.456841067195382}, {2.896125274180207, 
            4.45685802124774}, {3.031868986847596, 4.456874975300098}, {
            3.1676126995149847`, 4.456891929352455}, {3.3033564121823735`, 
            4.456908883404813}, {3.4391001248497624`, 4.45692583745717}, {
            3.5367102674221997`, 4.456938028721394}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.557585109172225, 4.45694063593725}, {
            3.5748438375171503`, 4.456942791509528}, {3.7105875501845387`, 
            4.4569597455618855`}, {3.8463312628519275`, 4.456976699614243}, {
            3.9820749755193163`, 4.4569936536666}, {4.117818688186706, 
            4.457010607718957}, {4.253562400854094, 4.457027561771315}, {
            4.389306113521483, 4.4570445158236724`}, {4.392578779173234, 
            4.457044924571479}}]}, 
          {Arrowheads[{{0.014075469583426314`, 1.}}], 
           ArrowBox[{{4.413453620923259, 4.457047531787334}, {
            4.525049826188872, 4.45706146987603}, {4.660793538856259, 
            4.457078423928388}, {4.781435797237687, 4.457123543971392}, {
            4.902078055619112, 4.457168664014396}, {5.001099999999999, 
            4.457205698088929}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.927930908679255}, \
{-4.981002195359007, -2.927933500408691}, {-4.770752591445119, \
-2.927960613324608}, {-4.5605029875312315`, -2.927987726240526}, \
{-4.350253383617344, -2.928014839156443}, {-4.166106330429105, \
-2.9280385859958025`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.1452314886898325`, -2.928041277928716}, \
{-4.140003779703456, -2.9280419520723604`}, {-3.929754175789568, \
-2.928069064988278}, {-3.71950457187568, -2.9280961779041954`}, \
{-3.509254967961792, -2.9281232908201127`}, {-3.310237819118938, \
-2.928148955245264}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2893629773796653`, -2.928151647178178}, \
{-3.088755760134016, -2.9281775166519477`}, {-2.878506156220129, \
-2.9282046295678654`}, {-2.6932265884313855`, -2.9282039104895334`}, \
{-2.507947020642642, -2.928203191411202}, {-2.4543693042853496`, \
-2.928202983473676}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494462372664, -2.928202902457476}, \
{-2.3226674528538984`, -2.92820247233287}, {-2.1373878850651553`, \
-2.9282017532545384`}, {-1.9521082980859117`, -2.9282017431371}, \
{-1.766828711106668, -2.9282017330196615`}, {-1.5985007858611908`, \
-2.928201723827891}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259439483482`, -2.9282017226879926`}, \
{-1.396269537148181, -2.9282017127847846`}, {-1.3221577803244997`, \
-2.9282017413630363`}, {-1.2480460284771229`, -2.928201767395135}, \
{-1.2406348537216907`, -2.9282017697121474`}, {-1.2298886504037936`, \
-2.9282017730125776`}, {-1.1635678690229376`, -2.9282017930911834`}, \
{-1.0972470904476543`, -2.9282018107222316`}, {-0.978092671576665, \
-2.9282018379580803`}, {-0.8589382527056757, -2.928201865193929}, \
{-0.7426322674346697, -2.928201891778694}}]}, 
          {Arrowheads[{{0.01662018902975848, 1.}}], 
           ArrowBox[{{-0.7217574255218276, -2.928201896550183}, \
{-0.620629414963697, -2.9282019196656264`}, {-0.5014749960927076, \
-2.928201946901475}, {-0.3823205772217182, -2.9282019741373237`}, \
{-0.2631661583507289, -2.9282020013731724`}, {-0.14401173947973955`, \
-2.928202028609021}, {-0.12063939477488511`, -2.9282020283485997`}, \
{-0.09726705005436981, -2.9282020281244603`}, {-0.0625684192365261, \
-2.9282020279439163`}, {-0.02786978840630431, -2.928202027862447}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.24630354200686072`, -2.927701048910254}, \
{-0.23204388340705534`, -2.9277010486863437`}, {-0.22855026704767328`, \
-2.927701048632929}, {-0.1920110401341049, -2.9277010480768935`}, \
{-0.1554718131649948, -2.9277010475733016`}, {-0.037424215928939075`, \
-2.9277010461765824`}, {0.08062338130711655, -2.9277010447798633`}, {
            0.19867097854317217`, -2.9277010433831436`}, {
            0.3167185757792279, -2.9277010419864244`}, {
            0.43476617301528364`, -2.9277010405897053`}, {
            0.5528137702513394, -2.927701039192986}, {
            0.5886901345068437, -2.927701038768503}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6095649764196863, -2.927701038521515}, {
            0.670861367487395, -2.927701037796267}, {
            0.7889089647234507, -2.9277010363995477`}, {
            0.8167085590534127, -2.927701034274006}, {
            0.8445081534910954, -2.927701031835934}, {
            0.9028366234738741, -2.927701024475622}, {
            0.961165094377701, -2.9277010154335357`}, {
            0.9653320341484083, -2.92770101478163}, {
            0.9823399516797278, -2.9277010119591256`}, {
            0.9993478693098191, -2.927701008984638}, {
            1.1694270591918259`, -2.927700963252955}, {
            1.3395062702282703`, -2.9277009021302787`}, {
            1.4445586529318635`, -2.927701465035609}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4654334948444063`, -2.9277015768899}, {
            1.552105346737812, -2.9277020413062815`}, {
            1.7647044232473537`, -2.9277031804822844`}, {
            1.9773034997568955`, -2.9277043196582873`}, {
            2.1899025762664373`, -2.92770545883429}, {
            2.3004271713461235`, -2.92770605106154}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.3213020132586664`, -2.9277061629158307`}, {
            2.4025016527759786`, -2.9277065980102925`}, {
            2.6151007292855204`, -2.9277077371862954`}, {
            2.8276998057950617`, -2.9277088763622983`}, {
            3.0402988823046035`, -2.927710015538301}, {
            3.1562956897469916`, -2.9277118845462113`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.1771705316571244`, -2.9277122208937842`}, {
            3.252886050489425, -2.927713440866185}, {
            3.465473218674246, -2.927716866194069}, {
            3.678060386859067, -2.927720291521953}, {
            3.890647555043888, -2.9277237168498367`}, {
            4.0121642080624405`, -2.927725674796704}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.033039049972573, -2.927726011144277}, {
            4.103234723228709, -2.9277271421777207`}, {
            4.31582189141353, -2.9277305675056047`}, {
            4.528409059598351, -2.9277339928334882`}, {
            4.740996227783173, -2.9277374181613722`}, {
            4.868032676659393, -2.9276250067977605`}}]}, 
          {Arrowheads[{{0.0026872666627196077`, 1.}}], 
           ArrowBox[{{4.888907510399703, -2.9276065351815697`}, {
            4.944828148414155, -2.9275570524132077`}, {
            5.001099999999999, -2.927507258864776}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.841079400609472}, {-4.974086492440059, 
            4.841068422942863}, {-4.8499992772335805`, 
            4.84101799675974}, {-4.725912062027101, 
            4.840967570576618}, {-4.601824846820621, 
            4.8409171443934955`}, {-4.477737631614142, 
            4.840866718210373}, {-4.353650416407662, 
            4.840816292027251}, {-4.229563201201183, 
            4.840765865844128}, {-4.16610639243264, 4.840740078460198}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231552243456, 
            4.840731595406465}, {-4.105475985994702, 
            4.840715439661005}, {-3.9813887707882225`, 
            4.840665013477882}, {-3.857301555581743, 
            4.84061458729476}, {-3.733214340375264, 
            4.8405641611116375`}, {-3.6091271251687838`, 
            4.840513734928515}, {-3.485039909962304, 
            4.8404633087453925`}, {-3.3609526947558246`, 
            4.84041288256227}, {-3.3102379446760977`, 4.840392273257192}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2893631044869136`, 
            4.84038379020346}, {-3.2368654795493454`, 
            4.840362456379148}, {-3.1127782643428654`, 
            4.840312030196025}, {-2.988691049136386, 
            4.840261604012903}, {-2.8646038339299063`, 
            4.84021117782978}, {-2.7405166187234267`, 
            4.840160751646658}, {-2.616429403516947, 
            4.840110325463535}, {-2.492342188310467, 
            4.840059899280413}, {-2.454369496919555, 4.840044468054186}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.433494656730371, 
            4.840035985000454}, {-2.368254973103988, 
            4.8400094730972905`}, {-2.2441677578975083`, 
            4.839959046914168}, {-2.1200805426910287`, 
            4.8399086207310456`}, {-1.9959933274845487`, 
            4.839858194547923}, {-1.8719061122780687`, 
            4.839807768364801}, {-1.7864904187059634`, 
            4.8398088606480565`}, {-1.7010748369744788`, 
            4.839809827988525}, {-1.5985010266051243`, 
            4.8398108416388945`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776261846933008`, 
            4.839811047927333}, {-1.4647189809184618`, 
            4.839812163693907}, {-1.3465410528904531`, 
            4.8398133315465985`}, {-1.2283631248624445`, 
            4.8398144993992895`}, {-1.1101851968344358`, 
            4.8398156672519805`}, {-0.9920072688064274, 
            4.8398168351046715`}, {-0.8738293407784189, 
            4.839818002957363}, {-0.7556514127504104, 
            4.839819170810054}, {-0.7426325082197331, 4.839819165685149}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217576663068924, 
            4.839819156850724}, {-0.7011309985126785, 
            4.839819146812417}, {-0.6473365086076092, 
            4.839819109174264}, {-0.5935420140985348, 
            4.839819066619019}, {-0.589297210934999, 
            4.839819063237318}, {-0.5850524077423006, 
            4.8398190598328314`}, {-0.5808076045204033, 
            4.83981905640653}, {-0.5765628012692756, 
            4.839819052959381}, {-0.5723179979888915, 
            4.839819049492344}, {-0.5638283913109816, 
            4.839819042484438}, {-0.555338784515844, 
            4.839819035410257}, {-0.47044270497039004`, 
            4.839818962005424}, {-0.3855466145654599, 
            4.839818892470787}, {-0.1733064133650185, 4.839819075768348}, {
            0.038933787835422784`, 4.8398192590659095`}, {
            0.11323601020652056`, 4.839819323235732}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1341108521193554, 4.839819341263926}, {
            0.25117398903586413`, 4.83981944236347}, {0.4634141902363055, 
            4.839819625661031}, {0.6756543893165091, 4.839818755896503}, {
            0.8878945883967131, 4.839817886131974}, {0.9691045286286908, 
            4.839817553332035}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899793705413581, 4.839817467786521}, {
            1.1001347874769172`, 4.839817016367446}, {1.312374986557121, 
            4.839816146602918}, {1.448021341234762, 4.8398159232790805`}, {
            1.5836676959124034`, 4.839815699955243}, {1.7193140505900448`, 
            4.839815476631405}, {1.8249730470516607`, 4.839815302677798}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8458478889644752`, 4.839815268310123}, {
            1.8549604052676862`, 4.839815253307567}, {1.9906067599453277`, 
            4.839815029983729}, {2.126253114622969, 4.839814806659891}, {
            2.2618994693006105`, 4.839814583336054}, {2.397545823978252, 
            4.839814360012216}, {2.5331921786558933`, 4.8398141366883785`}, {
            2.6688385333335347`, 4.839813913364541}, {2.680841565477048, 
            4.839813893603131}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.701716407389862, 4.8398138592354565`}, {
            2.804484888011176, 4.839813690040703}, {2.9401312426888175`, 
            4.8398134667168655`}, {3.075777597366459, 4.839813243393028}, {
            3.2114239520441004`, 4.83981302006919}, {3.3470703067217418`, 
            4.839812796745353}, {3.482716661399383, 4.839812573421515}, {
            3.5367100804000313`, 4.839832021336846}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.5575849209587527`, 4.839839540255619}, {
            3.6183426271657275`, 4.839861424602786}, {3.7539685929320696`, 
            4.8399102757840575`}, {3.8895945586984126`, 4.839959126965328}, {
            4.025220524464756, 4.8400079781466}, {4.1608464902310995`, 
            4.840056829327871}, {4.296472455997442, 4.840105680509143}, {
            4.3925785433076, 4.840140297006551}}]}, 
          {Arrowheads[{{0.01407547555825925, 1.}}], 
           ArrowBox[{{4.4134533838663215`, 4.840147815925324}, {
            4.4320984217637855`, 4.8401545316904135`}, {4.567724387530129, 
            4.840203382871685}, {4.703350353296472, 4.840252234052956}, {
            4.838976319062816, 4.840301085234228}, {4.9746022848291584`, 
            4.840349936415499}, {5.001099999999999, 4.840359480640159}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.5489724918471746`}, \
{-4.974871919439763, -2.548974053387846}, {-4.846221154404888, \
-2.548981712865693}, {-4.717570389370012, -2.5489893723435397`}, \
{-4.588919624335136, -2.548997031821387}, {-4.460268859300261, \
-2.5490046912992335`}, {-4.3316180942653855`, -2.5490123507770805`}, \
{-4.20296732923051, -2.549020010254927}, {-4.166106324966176, \
-2.5490222048477498`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.14523148309033, -2.5490234476727642`}, \
{-4.074316564195635, -2.5490276697327743`}, {-3.945665799160758, \
-2.549035329210621}, {-3.8170150341258817`, -2.549042988688468}, \
{-3.6883642690910063`, -2.5490506481663147`}, {-3.5597135040561305`, \
-2.5490583076441617`}, {-3.431062739021255, -2.549065967122009}, \
{-3.310237808056507, -2.54907316067334}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2893629661806614`, -2.5490744034983543`}, \
{-3.173761208951504, -2.5490812860777026`}, {-3.0451104439166286`, \
-2.549088945555549}, {-2.916459678881752, -2.5490966050333963`}, \
{-2.7878089138468756`, -2.549104264511243}, {-2.659158148812, \
-2.54911192398909}, {-2.530507383777125, -2.5491195834669367`}, \
{-2.454369291146838, -2.5491241164989296`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944492709925`, -2.549125359323944}, \
{-2.401856618742249, -2.5491272429447838`}, {-2.2732058537073736`, \
-2.5491349024226304`}, {-2.144555088672498, -2.5491425619004775`}, \
{-2.0159043236376224`, -2.549150221378324}, {-1.887253558602747, \
-2.5491578808561712`}, {-1.7586027935678716`, -2.5491655403340183`}, \
{-1.6299520285329958`, -2.549173199811865}, {-1.5985007742371689`, \
-2.5491750723245197`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.5776259323613233`, -2.549176315149534}, \
{-1.5013012634981204`, -2.549180859289712}, {-1.3726504984632442`, \
-2.5491885187675587`}, {-1.2439997334283674`, -2.549196178245406}, \
{-1.1153489683934916`, -2.5492038377232524`}, {-0.9866982033586167, \
-2.5492114972010995`}, {-0.8580474383237409, -2.549219156678946}, \
{-0.7426322573274997, -2.5492260281501093`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574154516542, -2.549227270975124}, \
{-0.6007459082539901, -2.54923447563464}, {-0.4720951432191143, \
-2.549242135112487}, {-0.34344437818423756`, -2.5492497945903336`}, \
{-0.21479361314936174`, -2.5492574540681807`}, {-0.08614284811448591, \
-2.5492651135460274`}, {0.04250791692038902, -2.5492727730238744`}, {
            0.11323625958216937`, -2.549276983975699}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110145801497`, -2.5492782268007135`}, {
            0.17115868195526485`, -2.5492804325017215`}, {
            0.29980944699014067`, -2.549288091979568}, {
            0.4284602120250156, -2.5492957514574153`}, {
            0.5571109770598923, -2.549303410935262}, {
            0.6857617420947681, -2.549311070413109}, {
            0.8144125071296431, -2.5493187298909556`}, {
            0.9430632721645198, -2.5493263893688027`}, {
            0.9691047764918385, -2.549327939801289}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.989979618367684, -2.5493291826263036`}, {
            1.0717140371993956`, -2.5493340488466494`}, {
            1.2003648022342706`, -2.5493417083244965`}, {
            1.3290155672691464`, -2.549349367802343}, {
            1.4576663323040222`, -2.54935702728019}, {
            1.586317097338898, -2.549364686758037}, {
            1.7149678623737739`, -2.549372346235884}, {
            1.8249732934015075`, -2.549378895626879}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.845848135277353, -2.5493801384518933`}, {
            1.9722693924435255`, -2.5493876651915777`}, {
            2.1009201574784013`, -2.5493953246694248`}, {
            2.229570922513277, -2.5494029841472714`}, {
            2.358221687548152, -2.5494106436251185`}, {
            2.486872452583028, -2.549418303102965}, {
            2.6155232176179037`, -2.549425962580812}, {
            2.6808418103111764`, -2.5494298514524685`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716652187022, -2.549431094277483}, {
            2.7441739826527787`, -2.549433622058659}, {
            2.8705692341701825`, -2.549433906690934}, {
            2.996964427463189, -2.5494342638729623`}, {
            3.1142105134949665`, -2.5494346679098716`}, {
            3.2314565995267435`, -2.5494350719467804`}, {
            3.348702685558521, -2.5494354759836897`}, {
            3.4659487715902983`, -2.5494358800205985`}, {
            3.536710328621448, -2.5494361238690866`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.557585170534167, -2.54943619580502}, {
            3.5831948576220753`, -2.5494362840575078`}, {
            3.700440943653853, -2.5494366880944166`}, {
            3.8176870296856302`, -2.549437092131326}, {
            3.9349331157174077`, -2.549437496168235}, {
            3.965940187280601, -2.5494377012618386`}, {
            3.9969472343245447`, -2.549437904148395}, {
            4.154963853810903, -2.5494387853069904`}, {
            4.312979629163128, -2.549439400696213}, {
            4.39257881246565, -2.5493652098473247`}}]}, 
          {Arrowheads[{{0.01407547449687257, 1.}}], 
           ArrowBox[{{4.413453645311226, -2.54934575334658}, {
            4.426638312777182, -2.5493334645060286`}, {
            4.540296996391236, -2.5492275283158445`}, {
            4.65395568000529, -2.5491215921256605`}, {
            4.767614363619344, -2.5490156559354764`}, {
            4.881273047233398, -2.5489097197452923`}, {
            4.994931730847453, -2.5488037835551083`}, {
            5.001099999999999, -2.5487980343865164`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.3056400000054045`}, \
{-4.9911923340527276`, -3.305640078665439}, {-4.867186038835182, \
-3.305641063189899}, {-4.743179743617636, -3.305642047714359}, \
{-4.61917344840009, -3.305643032238819}, {-4.495167153182544, \
-3.3056440167632792`}, {-4.371160857964999, -3.3056450012877394`}, \
{-4.247154562747453, -3.305645985812199}, {-4.166106323512611, \
-3.305646629279322}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481600426, -3.3056467950111696`}, \
{-4.123148267529908, -3.3056469703366593`}, {-3.999141972312361, \
-3.3056479548611195`}, {-3.875135677094814, -3.3056489393855797`}, \
{-3.7511293818772686`, -3.3056499239100394`}, {-3.6271230866597226`, \
-3.3056509084344996`}, {-3.503116791442177, -3.30565189295896}, \
{-3.379110496224631, -3.3056528774834195`}, {-3.3102378051130374`, \
-3.3056534242850875`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629632008525`, -3.3056535900169353`}, \
{-3.2551042010070854`, -3.3056538620078797`}, {-3.13109790578954, \
-3.30565484653234}, {-3.007091610571994, -3.3056558310568}, \
{-2.8830853153544482`, -3.30565681558126}, {-2.759079020136902, \
-3.30565780010572}, {-2.6350727249193566`, -3.30565878463018}, \
{-2.5110664297018097`, -3.3056597691546403`}, {-2.454369286713464, \
-3.305660219290853}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.433494444801279, -3.305660385022701}, \
{-2.3870601344842632`, -3.3056607536791}, {-2.2630538392667177`, \
-3.3056617382035602`}, {-2.1390475440491716`, -3.3056627227280204`}, \
{-2.0150412488316274`, -3.30566370725248}, {-1.8165807821228133`, \
-3.3056639154375707`}, {-1.618120315413998, -3.305664123622661}, \
{-1.5985007683009917`, -3.305664144203572}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259263881607`, -3.3056641661012875`}, \
{-1.419659848705183, -3.3056643318077517`}, {-1.2211993819963682`, \
-3.305664539992842}, {-1.0227389152875537`, -3.3056647481779327`}, \
{-0.8242784485787387, -3.305664956363023}, {-0.7426322498749158, \
-3.3056650420099105`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574079620848, -3.305665063907626}, \
{-0.6258179818699241, -3.3056651645481137`}, {-0.4273575151611093, \
-3.3056653727332046`}, {-0.22889746249399828`, -3.3056653655181423`}, \
{-0.03043740982688725, -3.30566535830308}, {
            0.11323626855145719`, -3.305665353079789}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411111046429977`, -3.305665352320879}, {
            0.16802264284022428`, -3.305665351088017}, {
            0.36648269550733525`, -3.305665343872955}, {
            0.5649427481744463, -3.3056653366578925`}, {
            0.7634028008415576, -3.30566532944283}, {
            0.9618628535086688, -3.305665322227768}, {
            0.9691047869780036, -3.3056653219644856`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899796288908462, -3.3056653212055758`}, {
            1.16032290617578, -3.3056653150127056`}, {
            1.3190909748053063`, -3.3056652362104244`}, {
            1.477859071809777, -3.3056651251051687`}, {
            1.4937358856032599`, -3.305665110863287}, {
            1.5096126998796187`, -3.3056650963318557`}, {
            1.5175511072660743`, -3.3056650889245662`}, {
            1.5254895147792356`, -3.305665081447782}, {
            1.5334279224208123`, -3.3056650739024165`}, {
            1.5413663301925156`, -3.3056650662894196`}, {
            1.5493047380960578`, -3.3056650586097778`}, {
            1.6353636397683442`, -3.3056649746447175`}, {
            1.721422558328713, -3.305664883791607}, {
            1.824973305404308, -3.305664768467681}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458481473171378`, -3.3056647452194787`}, {
            1.956147087699148, -3.3056646223801254`}, {
            2.0735093523843657`, -3.3056644916743845`}, {
            2.190871617069583, -3.3056643609686436`}, {
            2.3082338817548007`, -3.3056642302629027`}, {
            2.425596146440018, -3.3056640995571622`}, {
            2.5429584111252357`, -3.3056639688514213`}, {
            2.660320675810453, -3.30566383814568}, {
            2.680841823830303, -3.3056638753867684`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7017166657431058`, -3.30566391619922}, {
            2.7213982423292022`, -3.3056639572271656`}, {
            2.8390792027495975`, -3.305664381489356}, {
            2.9567601587501997`, -3.3056649784775503`}, {
            3.1275790738807245`, -3.3054888857184554`}, {
            3.2983979890112494`, -3.3053127929593606`}, {
            3.469216904141775, -3.3051367002002654`}, {
            3.536710034097922, -3.3050671232950095`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.557584864918916, -3.305045603977011}, {
            3.640035819272301, -3.3049606074411706`}, {
            3.8108547344028256`, -3.3047845146820753`}, {
            3.9816736495333513`, -3.3046084219229805`}, {
            4.152492564663876, -3.3044323291638857`}, {
            4.323311479794402, -3.3042562364047905`}, {
            4.392578097758678, -3.3041848312570576`}}]}, 
          {Arrowheads[{{0.014075493029369217`, 1.}}], 
           ArrowBox[{{4.413452928579672, -3.304163311939059}, {
            4.494130394924927, -3.3040801436456957`}, {
            4.664949310055452, -3.3039040508866004`}, {
            4.835768225185977, -3.3037279581275056`}, {
            5.001099999999999, -3.30355752191808}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.844303278278376}, \
{-4.877752324149532, -4.844264488475657}, {-4.683817328790809, \
-4.844203500701395}, {-4.489882333432087, -4.844142512927134}, \
{-4.295947338073365, -4.844081525152872}, {-4.166106364774533, \
-4.844040693368208}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231523893897, -4.844034128745454}, \
{-4.102012342714643, -4.844020537378611}, {-3.9080773473559196`, \
-4.84395954960435}, {-3.7141423519971966`, -4.8438985618300885`}, \
{-3.5202073566384744`, -4.8438375740558275`}, {-3.3262723612797522`, \
-4.843776586281566}, {-3.3102378886684316`, -4.843771543835285}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289363047787795, -4.843764979212531}, \
{-3.132337365921029, -4.843715598507305}, {-2.9384023705623066`, \
-4.843654610733044}, {-2.7444673752035844`, -4.843593622958782}, \
{-2.5505323798448623`, -4.843532635184521}, {-2.4543694125623294`, \
-4.843502394302363}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334945716816927`, -4.843495829679609}, \
{-2.356597384486139, -4.84347164741026}, {-2.2567657951593967`, \
-4.8434736696433065`}, {-2.1569344983451813`, -4.843475566982523}, \
{-2.0391125868568, -4.843477636016637}, {-1.9212906753684182`, \
-4.843479705050751}, {-1.8034687638800366`, -4.843481774084865}, \
{-1.6856468523916552`, -4.84348384311898}, {-1.5985008990949676`, \
-4.843485373462088}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.5776260571853438`, -4.843485740038725}, \
{-1.5678249409032736`, -4.843485912153094}, {-1.450003029414892, \
-4.8434879811872085`}, {-1.3321811179265106`, -4.843490050221322}, \
{-1.2143592064381288`, -4.843492119255437}, {-1.1856710729488014`, \
-4.843492203972892}, {-1.1569829414318848`, -4.843492279788569}, \
{-1.0887731584125067`, -4.843492395264728}, {-1.0205633786358614`, \
-4.843492471451564}, {-1.013102718304893, -4.843492479349584}, \
{-1.0056420579885819`, -4.843492486819325}, {-0.99818139768325, \
-4.843492493867682}, {-0.990720737385293, -4.84349250050156}, \
{-0.9832600770911701, -4.843492506727824}, {-0.968338756497578, \
-4.843492517591045}, {-0.9534174358719978, -4.843492526919733}, \
{-0.804204214186047, -4.843492496464193}, {-0.7426323807280582, \
-4.843492454061036}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217575388152205, -4.843492439684995}, \
{-0.6549909620991634, -4.843492393704335}, {-0.46847444130238447`, \
-4.843492403347682}, {-0.28195792050560553`, -4.843492412991028}, \
{-0.09544139970882648, -4.843492422634375}, {
            0.09107512108795246, -4.8434924322777215`}, {
            0.11323613769846705`, -4.843492433423498}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411097961130963`, -4.843492434502777}, {
            0.2775916418847315, -4.843492441921067}, {
            0.4641081626815105, -4.843492451564414}, {
            0.6506246834782895, -4.84349246120776}, {
            0.8371412042750686, -4.843492470851107}, {
            0.9691046560987874, -4.843489839946918}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899794980074814, -4.843489423773287}, {
            1.0236608200140986`, -4.843488752281825}, {
            1.2101804357531283`, -4.843485033712542}, {
            1.3967000514921581`, -4.8434813151432605`}, {
            1.5832196672311882`, -4.843477596573978}, {
            1.7697392829702183`, -4.843473878004695}, {
            1.8249731743552438`, -4.843472776828012}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.845848016263938, -4.84347236065438}, {
            1.9562588987092482`, -4.843470159435412}, {
            2.142778514448278, -4.8434664408661305`}, {
            2.329298130187308, -4.843462722296848}, {
            2.445843882917644, -4.843516302823017}, {
            2.562389635647979, -4.843569883349186}, {
            2.678935388378314, -4.843623463875355}, {
            2.6808416555305965`, -4.843624340259047}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716495237395, -4.8436339372187724`}, {
            2.795481141108649, -4.843677044401524}, {
            2.912026893838984, -4.8437306249276935`}, {
            3.028572646569318, -4.843784205453862}, {
            3.1451183992996525`, -4.843837785980031}, {
            3.261664152029988, -4.8438913665062}, {
            3.378209904760323, -4.843944947032369}, {
            3.4947556574906575`, -4.843998527558538}, {
            3.536710083509338, -4.844017815607811}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5575849232161363`, -4.844027412567536}, {
            3.611301410220992, -4.844052108084707}, {
            3.7278471629513272`, -4.844105688610877}, {
            3.8443929156816625`, -4.844159269137045}, {
            3.9609386684119965`, -4.844212849663214}, {
            4.077484421142331, -4.844266430189384}, {
            4.194030173872666, -4.844320010715553}, {
            4.3105759266030015`, -4.844373591241721}, {
            4.39257851148808, -4.844411290956575}}]}, 
          {Arrowheads[{{0.014075476915248714`, 1.}}], 
           ArrowBox[{{4.413453351194878, -4.844420887916302}, {
            4.427121679333336, -4.844427171767891}, {
            4.54366743206367, -4.84448075229406}, {
            4.660213184794006, -4.844534332820229}, {
            4.776758937524341, -4.844587913346398}, {
            4.893304690254675, -4.844641493872567}, {
            5.001099999999999, -4.84469105148646}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.072916372947976}, {-4.914854305982432, 
            4.072906422826221}, {-4.7504667921218715`, 
            4.072889260631039}, {-4.586074963565528, 
            4.072873901046569}, {-4.4216788203133985`, 
            4.072860344072811}, {-4.2572783623654855`, 
            4.072848589709764}, {-4.166106326819914, 4.072843070882646}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231484945316, 
            4.072841807286383}, {-4.092873589721789, 
            4.072838637957429}, {-3.9284645023823055`, 
            4.072830488815805}, {-3.7640511003470385`, 
            4.072824142284894}, {-3.6001856646763875`, 
            4.072588864193598}, {-3.435765790597445, 
            4.072585221578754}, {-3.310237977829268, 4.072582440592108}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893631359215485`, 
            4.07258197812363}, {-3.2713459165185013`, 
            4.07258157896391}, {-3.1069260424395573`, 
            4.072577936349066}, {-2.9425061683606146`, 
            4.072574293734221}, {-2.778086294281672, 
            4.072570651119378}, {-2.613666420202728, 
            4.072567008504533}, {-2.454369459612758, 4.07256347938449}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334946177050383`, 
            4.072563016916011}, {-2.284826672044842, 
            4.072559723274845}, {-2.1204067979658987`, 
            4.072556080660001}, {-1.9559869238869554`, 
            4.072552438045157}, {-1.7915670498080125`, 
            4.072548795430313}, {-1.6271471757290694`, 
            4.072545152815469}, {-1.5985009413962477`, 4.07254451817687}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776260994885278`, 
            4.072544055708391}, {-1.4627273016501259`, 
            4.072541510200625}, {-1.2983074275711832`, 
            4.072537867585781}, {-1.1338875534922401`, 
            4.072534224970937}, {-0.969467679413297, 
            4.072530582356093}, {-0.7627886873430203, 
            4.072530705060196}, {-0.7426324231241102, 4.072530717026852}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217575812112712, 
            4.072530729420123}, {-0.556109695272743, 
            4.072530827764299}, {-0.34943070320246583`, 
            4.072530950468403}, {-0.1427517111321891, 4.072531073172506}, {
            0.06392732441521506, 4.072531049741192}, {0.11323609530232946`, 
            4.07253104415103}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411093721517192`, 4.072531041784438}, {
            0.2706063599626192, 4.072531026309878}, {0.4772853955100236, 
            4.072531002878564}, {0.6839644310574275, 4.07253097944725}, {
            0.7666360266766988, 4.072530982798143}, {0.8493076206562252, 
            4.072530975110942}, {0.857574780030089, 4.072530972903378}, {
            0.8658419394109785, 4.0725309705331565`}, {0.8699755191058877, 
            4.0725309692650065`}, {0.8741090988033934, 4.072530967954694}, {
            0.8782426785037425, 4.072530966601792}, {0.8823762582071848, 
            4.072530965205874}, {0.8865098379139731, 4.07253096376651}, {
            0.950194270392944, 4.072530940914873}, {0.9691046137288637, 
            4.072530930789739}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899794556417033, 4.072530919612757}, {
            1.0138787042582997`, 4.0725309068164215`}, {1.1313705590132308`, 
            4.0725308203005826`}, {1.248862413768162, 4.072530733784743}, {
            1.3663542685230932`, 4.072530647268904}, {1.4838461232780242`, 
            4.072530560753065}, {1.6013379780329555`, 4.072530474237225}, {
            1.7188298327878866`, 4.072530387721386}, {1.8249731321551843`, 
            4.072530309562125}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458479740680214`, 4.072530294190808}, {
            1.9538135422977487`, 4.072530214689708}, {1.983826331721027, 
            4.072530059103717}, {2.0138391297054916`, 4.072529900149527}, {
            2.109145186949955, 4.072529360128469}, {2.2044513492173428`, 
            4.07252880582268}, {2.3552693831195803`, 4.072549338985542}, {
            2.506087417021819, 4.072569872148405}, {2.6569054509240564`, 
            4.072590405311267}, {2.6808416461626554`, 4.072593664111176}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716487882035, 4.072596506122265}, {
            2.807723484826294, 4.0726109384741305`}, {2.9585415187285324`, 
            4.072631471636993}, {3.10935955263077, 4.072652004799855}, {
            3.2601775865330076`, 4.072672537962718}, {3.4109956204352456`, 
            4.07269307112558}, {3.5367101566572114`, 4.07271018656582}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.557584998376591, 4.072713028576909}, {
            3.561813654337483, 4.072713604288443}, {3.7126316882397212`, 
            4.072734137451305}, {3.863449722141959, 4.0727546706141675`}, {
            4.014267756044196, 4.072775203777031}, {4.165085789946435, 
            4.072795736939893}, {4.315903823848672, 4.072816270102756}, {
            4.392578667151768, 4.0728267090204655`}}]}, 
          {Arrowheads[{{0.01407547178150105, 1.}}], 
           ArrowBox[{{4.4134535088711475`, 4.072829551031554}, {
            4.46672185775091, 4.072836803265618}, {4.6175398916531485`, 
            4.072857336428481}, {4.768357925555386, 4.072877869591343}, {
            4.919175959457624, 4.0728984027542054`}, {5.001099999999999, 
            4.072909556325322}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(inc\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(inc\\)]\\)}\"", 
          TraditionalForm]}}], {972., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[{
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAuEHjN8H077+zCKjPWogYPwfhc1Hu
1O+/Eyo/p9CFGD8R/YAu1bfvv9SO7HN+gxg/9OsTtd2H779uncGQq38YP+Xf
wSxJNO+/vs2+4gN5GD9rlwqWd/buv2j8FysZdBg/DMDL1jGm7r8C9xzAuG0Y
P8g27jNpRO6/NjAv4vdlGD/KKpCinYnsv6Gtrt0qQxg/28dUgfOj678eao12
UDEYPxrslIajw+q/8br+4QIgGD/FvJSviejpv8zW8gw9Dxg/3y2dkIMS6b9x
ygUm+v4XP4B604RO6Oi//R0v3cj7Fz/xJuS6SL7ovz16hUic+Bc/jwEg++Ke
6L+foTLjPfYXP4OexJZB4+K/8lq4bzSKFz/Nw3ycvS3cv9Ci03RQNBc/ToBl
7zon1L/WXtn5ze8WPwC+b1W04cq/bFUtjOC4Fj8j57nA1vfEv6dZmEJ7oRY/
lEe3KQ==
            "]]}, 
          {Arrowheads[{{0.010544751140548652`, 1.}}], 
           ArrowBox[{{-0.14294309613999187`, 
            0.00008617305633332191}, {-0.09320758936136224, 
            0.00008580709304530586}, {-0.04494082593545723, 
            0.00008546042625388307}, {-0.02233517802052129, 
            0.00008530011482249258}, {-0.0011664340775211282`, 
            0.00008515178673044452}, {0.01928040775078355, 
            0.00008501192395059804}, {0.03837139436152705, 
            0.0000848829279680771}, {0.07400155148148078, 
            0.00008464503051113323}, {0.10486065974293479`, 
            0.00008444432444823799}, {0.1315687952905157, 
            0.00008427531455846843}, {0.19075016310119494`, 
            0.00008392356830052029}, {0.22938762690191394`, 
            0.00008371952722490505}, {0.25443971915243546`, 
            0.00008361072965879746}, {0.2704353806975794, 
            0.00008356436011305346}, {0.28249315895259386`, 
            0.00008355974190555156}, {0.2895412155452714, 
            0.00008358901687155401}, {0.2935760034693382, 
            0.00008363862843683801}, {0.2972021174418051, 
            0.00008377081614759256}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.005547204802606794, 1.}}], ArrowBox[CompressedData["

1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAADriiEd5R4j/ZjwkTV7PpP5ZeDkuR
NeI/M6FKUbW16T+cKYzOUxHiP5XMSj1DuOk/GEvKyxfs4T/JDltexLrpP7Rn
sp4xq+E/SfE4bAq/6T9LD7zYkE3hPw/Fndwpxek/HDAUgCLk4D/YKRMeE8zp
PxKywiXVCt8/0enT/pnj6T8bjBt5xhzdP3ZynV759Ok/0UuNgueT2z95veks
VwPqP4f9uwTi5do/UEhvhtkJ6j8U/nING0vaP44KURHGD+o/0Os8WCar2T/H
SeFFPBbqPy/PlEWUH9k/wRN0NRAc6j9fM8SCXCzYP4uc6GSXJuo/GRbH6V53
1z9iz/RSKC/qP53qmjMl8NY/8MOed0Q26j+61et4DT/WP6XPjQh2Qeo/abbA
C/ve1T+m+moTCkrqPxaxmBM=
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAxUXA/DpE5L8jD4SR6CjpP44IvPBh
0eO/9H4s/u8f6T/A48LurRjjv1SLUCOCEek/l6WQEplN4r8dtNTOrwHpP+5z
a7l7C+K/YqghZpH86D+MVkcnX9nhv7hFi/+1+Og/1W5M4/6y4b/X3Nl6x/Xo
P19YrNeGk+G/pUGhZmTz6D9DAebn11rhvwPUgvAc7+g/OHCthIq74L+WJVEn
LePoP3y5baMbJ+C/BrnlLyrY6D8vlTsjcmTevyrTeR7yxeg/N7k8ABhY27+E
xj58I6noPxb4WGeynNi/LSKjJRWQ6D+ZC+w5YwfWv4ptVeS3eOg/Uis3msXd
yr9k5cPBpCzoP18LyCCkBLq/Kgx53CPy5z+ImrbjHNqNv2zvzGMNxec/zXR1
ZIFutz+dyc4iJ5HnP2ZJEHdeM8U/8OctrPtu5z+3/cgskozJP0VQnDdhYOc/
s++4EQ==
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.6446632710822897, -0.7644713419388707}, \
{-0.6342628361378083, -0.763681751848828}, {-0.6119755699014964, \
-0.7619805212777215}, {-0.5886929646641323, -0.760206802590113}, \
{-0.5696334475078023, -0.7587699700979571}, {-0.5562480713229501, \
-0.7577696248150718}, {-0.5449372809157681, -0.7569347456497513}, \
{-0.5194664158478185, -0.7550767236997066}, {-0.494563775130317, \
-0.7532739121473483}, {-0.4702359490957891, -0.7515258223496424}, \
{-0.3734790721251421, -0.7447103167530152}, {-0.288056499017214, \
-0.7388784550108604}, {-0.2128035193210984, -0.733891295564182}, \
{-0.08762556691619336, -0.7258811199130771}, {
            0.009240519355984751, -0.7199790505176284}, {
            0.14124253407460535`, -0.7124519249650735}, {
            0.18835405564019897`, -0.7100189988812361}}]}, 
          {Arrowheads[{{0.0025161050902047484`, 1.}}], 
           ArrowBox[{{0.20919662801014757`, -0.7089426499056991}, {
            0.2185060646708417, -0.7084618933831975}, {
            0.24487726849462957`, -0.7072309138878251}, {
            0.2647422917116045, -0.7063873411283961}, {
            0.27967439580381664`, -0.7058332984527949}, {
            0.28607516486145773`, -0.7056183730408997}, {
            0.2915672847900212, -0.7054560270043159}, {
            0.29930008277982706`, -0.7053430315107679}, {
            0.30544922325737156`, -0.7053205054426561}, {
            0.3141437090234057, -0.7054320966984547}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.014394215670873019`, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAA/aBT0Uk17T+lySQ4CnvWP7nJILc9
2Ow/vnibk4B/1j+EOhaatWvsP+ai42y5hNY/nw4vVBbQ6j9p4xuo1ZjWP53m
6AwVZOk/wwsIYBGr1j8OPbpNz/TmPz7leBo2y9Y/+jhP/QLt5D9Y+FQSCufW
P3AR2v2jOeM/8kPLbyP/1j9PzGdy/3LiP01whsVSCtc/T8nRHW+94T8OQLTc
tBTXP0t3Klt8BOE/VPzEn54f1z9RN9ro2VzgPzS5t3OsKdc/kY4w3L9Z3j+B
ilD2MDzXP94g/Lh6atw/jf9mXM9L1z/moZU2zNXaPzE2GwkKWdc/KFS6SidH
2D/iPH7i6m/XP6IxUudInNY/m65t2XGA1z86YBirN4fVP1vUQ1i4jNc/FGzr
IrXW1D+sMSipGpbXP3LEn78QSdQ/o4u/iryf1z83VCgMsvvTP0ijj6B+p9c/
cR2siA==
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8413891972903748, 
            0.39874798332104083`}, {-0.6386762952866458, 
            0.3907037905714039}, {-0.5845995362238049, 
            0.3886273071159184}, {-0.5335180237084138, 
            0.3866983554515391}, {-0.4875688944002232, 
            0.38501600233935235`}, {-0.44403999004762734`, 
            0.3834450063226597}, {-0.29679210692647334`, 
            0.3782506197767377}, {-0.17749722183419697`, 
            0.37424486222332937`}, {-0.08105067623834716, 
            0.3711472119543089}, {-0.007112711648700185, 
            0.3689089612782729}}]}, 
          {Arrowheads[{{0.005797238146372498, 1.}}], 
           ArrowBox[{{0.013748078374193923`, 0.36827746327003685`}, {
            0.03731811679516421, 0.36756395087187005`}, {0.12066323674374307`,
             0.36518721810122434`}, {0.17865756214388773`, 
            0.3636432907562911}, {0.21855961446360553`, 
            0.36267077041865753`}, {0.2556437857763331, 
            0.36190281719886513`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.013909873208092246`, 1.}}], 
           ArrowBox[{{0.9957230498094756, -0.06404769717966234}, {
            0.9911378908096979, -0.06406725233534036}, {
            0.9859220625181948, -0.06408950694262268}, {
            0.9751393762257109, -0.06413557019119356}, {
            0.950982347537652, -0.06423911798215254}, {
            0.8674974267399862, -0.06460440730668777}, {
            0.7947957759137215, -0.06493500455599362}, {
            0.7611911993720478, -0.06509082948105611}, {
            0.7300639102148417, -0.06523767173799526}, {
            0.6991575062003857, -0.0653882921553554}, {
            0.6706050867040105, -0.06552963769957523}, {
            0.6178030752605064, -0.06579475244559448}, {
            0.5728839582669455, -0.06602703755405837}, {
            0.5345518458803, -0.06623079959372241}, {
            0.4643101954595227, -0.06662204436582862}, {
            0.4151224544975666, -0.06691311174758353}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.013791529461355853`, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAALZd7cViS7D9Xas2NTiTdvzvDfh0i
few/ZGcYsaYl3b/eMSbOg0HsP5HXiXpuKd2/SkEk2Ub+6z/WZp8rsy3dv960
mpFokus/BZNkNI803b/1Tij/ZfnqP1RxiRZSPt2/LAMXjmKE6D84U6mVQWfd
vz/TAshJeuY/tGblSoeK3b/dWlg4corlP5EmrOYGm92/pVe9RK+t5D8244BH
dardvzmGyYwS0OM/aapbrG+63b+75uq4HgXjP6Hw5ZhLyd2/XuhDcieR4T/r
QXV46uTdv/uJCAfjWuA/OpkwlKn83b/JOd9lmq7eP5GVpnYfEd6/Y5dVLo0v
2z8OiwkbRTbev+0e6a4J0dg/+DCihFdR3r9zlhuNxzbXP7hoF6lgZd6/0hKl
AKoj1j8wA+T7eHTev4XuT4ViNdU/Qd/zfQiE3r9HOfBppafUPyhQSBH5j96/
vW/8ofVU1D+tc3VCr5nev14NvF0=
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8713524325309688, -0.39057752466682694`}, \
{-0.8598649065482852, -0.3901170769104415}, {-0.8542307294548004, \
-0.3898916487391286}, {-0.8487283298869616, -0.3896718999263962}, \
{-0.8433126803580868, -0.38945598799183173`}, {-0.8379221587509009, \
-0.3892414036757535}, {-0.8325566330775482, -0.38902813737533426`}, \
{-0.6443749752602681, -0.3817397186382621}, {-0.48656778995670685`, \
-0.37594121365907146`}, {-0.35427129425395165`, -0.3713097310688711}, \
{-0.24329776720835894`, -0.36758902481650263`}, {-0.17831680442214265`, \
-0.3654832050989669}, {-0.12074813337410009`, -0.36366395692906156`}, \
{-0.06979657973906794, -0.3620920020235169}, {-0.04588179458466263, \
-0.3613633671297532}, {-0.037062686799826175`, -0.3610978129776248}}]}, 
          {Arrowheads[{{0.004774360774010577, 1.}}], 
           ArrowBox[{{-0.01620164617063835, -0.36047468660025805`}, \
{-0.0018074742799781829`, -0.36005125564435403`}, {
            0.018441130152722106`, -0.35946255829928014`}, {
            0.05633038841644622, -0.35837334772159224`}, {
            0.08933009825366783, -0.3574477053815225}, {
            0.11805053703981504`, -0.35666211653758173`}, {
            0.18300761355498837`, -0.3549826475525546}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.003009940200994794, 1.}}], 
           ArrowBox[{{0.8042910239826777, 0.6063134826858487}, {
            0.7949200667793637, 0.606719000116601}, {0.7736186126751806, 
            0.607645136304323}, {0.7584217912073324, 0.6083127363952832}, {
            0.7440421957014082, 0.608950484079763}, {0.7398552474201399, 
            0.6091372363478593}, {0.7363922398116558, 0.6092919825004178}, {
            0.7063947958488098, 0.61065520685749}, {0.6787796769025405, 
            0.6119293154283839}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \\(sp\\)]\\),\\!\\(\
\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(sp\\)]\\)}\"", 
          TraditionalForm]}}], {1360.8000000000002`, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ContentSelectable->True,
  ImageSize->1050,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5545303903022203`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.9617002367949916`}, \
{-4.86226166915416, -1.9720362218749938`}, {-4.716529280903489, \
-1.9832708960071663`}, {-4.5704193264487, -1.9948408340974726`}, \
{-4.42372421485875, -2.006683193363454}, {-4.276443946133638, \
-2.018797973805111}, {-4.168732257132335, -2.0278213570635026`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.147930281692347, -2.029564010982191}, \
{-4.128578520273362, -2.0311851754224435`}, {-3.97978861423869, \
-2.043720049572621}, {-3.829734904990386, -2.0562778476128134`}, \
{-3.6784173925284507`, -2.068858569543021}, {-3.525836076852883, \
-2.081462215363243}, {-3.393377322547653, -2.092230940109711}, \
{-3.315775783744268, -2.098351496414931}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2949655688114365`, -2.099992831035148}, \
{-3.2594589584608986`, -2.1027932936446407`}, {-3.1233696269871007`, \
-2.1130576764173647`}, {-2.9853801173448833`, -2.1229072961823636`}, \
{-2.8452236135858953`, -2.1321997294769717`}, {-2.702633299761785, \
-2.1407925528385228`}, {-2.588112696503447, -2.146906343833485}, \
{-2.471517140777974, -2.1522380291124685`}, {-2.461678316509702, \
-2.1526152290966656`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.440818798581325, -2.153414939470426}, \
{-2.352846632585366, -2.156787608675473}, {-2.232101171925622, \
-2.160555082522499}, {-2.1973485982496372`, -2.161518594506821}, \
{-2.16239330646329, -2.1623939143506177`}, {-2.060597066051263, \
-2.163796653870119}, {-1.9568748964131835`, -2.1642619438424138`}, \
{-1.834827001355869, -2.163899988236524}, {-1.7096997629132835`, \
-2.1617329394862694`}, {-1.6060525648251434`, -2.158521705149341}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.5851877346518006`, -2.157875263563628}, \
{-1.5814931810854274`, -2.15776079759165}, {-1.4502072558723005`, \
-2.1519835625526658`}, {-1.3155624697888106`, -2.14375364262153}, \
{-1.177279305349866, -2.132423446050457}, {-1.0353577625554664`, \
-2.1179929728394464`}, {-0.8897978414056121, -2.1004622229884986`}, \
{-0.7542185755569608, -2.0809464075895785`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7335901295071904, -2.0777606914923266`}, \
{-0.5903355369528587, -2.0530895483088836`}, {-0.43707632187828926`, \
-2.0224950372157395`}, {-0.28146506490492496`, -1.9872950769537048`}, \
{-0.13662190337483981`, -1.9503942382835615`}, {
            0.007092519052162127, -1.9092531418564915`}, {
            0.07840974250795739, -1.8865380930311588`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.09830004673646583, -1.8802028880160429`}, {
            0.14821737789954512`, -1.8643038588663388`}, {
            0.2852918486907734, -1.8159784605069473`}, {
            0.4172484932582297, -1.7648963677546328`}, {
            0.5421659229002029, -1.712172538366763}, {
            0.7212801962551265, -1.628384727718836}, {
            0.8653103412204333, -1.553288822268289}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.8837694735251787, -1.5435450886125548`}, {
            1.022308878620321, -1.46394696456804}, {
            1.1463998622702047`, -1.3868710938233004`}, {
            1.255685661810188, -1.3145387138901432`}, {
            1.3528534972717956`, -1.2470260751790305`}, {
            1.5186698452927925`, -1.1266060430285665`}, {
            1.5788078641979975`, -1.082072144250474}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.59558369883367, -1.0696491656558398`}, {
            1.690747087386167, -0.9991779930045175}, {
            1.837283851776094, -0.8955445084036016}, {
            1.9700235813998677`, -0.8109896589729311}, {
            2.0965235022588766`, -0.7416772266986711}, {
            2.209663330037423, -0.6896347758246553}, {
            2.313305130787197, -0.6500726013677003}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.332988461441004, -0.6431500176113049}, {
            2.4429669659498185`, -0.608744017903127}, {
            2.5665216190866995`, -0.5773226821182643}, {
            2.696243218654565, -0.5505692877367241}, {
            2.832777210100849, -0.5277687467198403}, {
            2.976700477591842, -0.5082455184028039}, {
            3.1282588497491735`, -0.4915064660771644}, {
            3.151833810971061, -0.48934549170756575`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.17262150353591, -0.4874400094285947}, {
            3.262026574569935, -0.4792447863188616}, {
            3.4011882774005135`, -0.468494482279503}, {
            3.545800371952088, -0.45900497157378684`}, {
            3.6959192719358374`, -0.4505256718164113}, {
            3.8513647777879805`, -0.4429421268025982}, {
            4.005954878538459, -0.43646352583051273`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.026814702218283, -0.4356735844863657}, {
            4.177142987981679, -0.43021838875594126`}, {
            4.3471828969885165`, -0.4248103901191059}, {
            4.521720576090337, -0.41992935283727795`}, {
            4.700492971642565, -0.4155507217037098}, {
            4.861464016019885, -0.41207192726774833`}}]}, 
          {Arrowheads[{{0.0028452459026137903`, 1.}}], 
           ArrowBox[{{4.882333984857512, -0.4116208999929246}, {
            4.883290055444815, -0.41160023805926843`}, {
            5.001099999999999, -0.40932967015752975`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.9622378501309785`}, {-4.860921622409716, 
            1.972678881305289}, {-4.7152118958291105`, 
            1.983917017532874}, {-4.569123823596297, 
            1.9954900417210468`}, {-4.422449740070423, 
            2.0073350202678184`}, {-4.275189645251488, 
            2.0194519531731885`}, {-4.168733327757365, 2.02837254872119}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.147931390996602, 
            2.030115664290335}, {-4.127343539139492, 
            2.0318408404371575`}, {-3.9785720670444817`, 
            2.044376797210047}, {-3.8285358742765045`, 
            2.056934938642179}, {-3.677234960835561, 
            2.069515264733554}, {-3.5246693267216496`, 
            2.0821177754841713`}, {-3.39224538007649, 
            2.0928830846240127`}, {-3.3157777469381466`, 
            2.0989134398243086`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2949675156199656`, 
            2.1005545666841123`}, {-3.2583617262343956`, 
            2.1034413555557236`}, {-3.122282363572501, 
            2.1137027608292946`}, {-2.9843023585292956`, 
            2.1235485095546975`}, {-2.8441550347363957`, 
            2.132836084529984}, {-2.7015737158254196`, 
            2.141422968553204}, {-2.5870154291469034`, 
            2.14753339049626}, {-2.4703807893050427`, 
            2.152860154108067}, {-2.4616812007807765`, 
            2.153193089968199}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4408216289084783`, 
            2.1539913920354645`}, {-2.351669796299838, 
            2.157403259388625}, {-2.2308824501312885`, 
            2.1611627063379344`}, {-2.1961276085265427`, 
            2.162123432957571}, {-2.1611700523834116`, 
            2.1629958524523993`}, {-2.0594143221840997`, 
            2.1643887732367637`}, {-1.955734868546005, 
            2.1648441066064277`}, {-1.833637779625448, 
            2.164469568661759}, {-1.7084608700764374`, 
            2.162287042874694}, {-1.6060555547219253`, 
            2.1591008568079983`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5851908094124358`, 
            2.1584516819037454`}, {-1.5802041398989732`, 
            2.1582965292452334`}, {-1.4488675890930556`, 
            2.1524980277733765`}, {-1.3141736375795017`, 
            2.1442435501720802`}, {-1.1758447052791294`, 
            2.1328851081543023`}, {-1.0338807921919384`, 
            2.118422701720042}, {-0.8882818983179289, 
            2.1008563308692993`}, {-0.7542223857465445, 
            2.0815290549874166`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7335878972240092, 
            2.0783814132700567`}, {-0.5887714688758197, 
            2.053406950744754}, {-0.4355080084743113, 
            2.022772755177548}, {-0.27990571761916716`, 
            1.9875322226070524`}, {-0.13518319769556236`, 
            1.950622120789154}, {0.008395739328808716, 1.909482002621254}, {
            0.07841434324162551, 1.8871633664661438`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.09830323359842233, 1.8808237241054515`}, {
            0.14937494785696676`, 1.8645444648135425`}, {0.28629828229193244`,
             1.8162421040762102`}, {0.4181034627078657, 1.765193014458038}, {
            0.5428783852382547, 1.7125097652468306`}, {0.7214645675375531, 
            1.6289560297090504`}, {0.8653336932450684, 
            1.5539566061368417`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.8837879929734426, 1.544204076726949}, {
            1.021775452849735, 1.4649598895020524`}, {1.145653298789524, 
            1.3880646875054579`}, {1.2547950779832389`, 
            1.3158792420399221`}, {1.351863373984498, 1.2484846267038532`}, {
            1.5175584701992753`, 1.1282244852546754`}, {1.5788855362728322`, 
            1.0828201133548168`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.5956626857014755`, 1.070398910436615}, {
            1.6899798147394063`, 1.0005698728265529`}, {1.836754077606912, 
            0.8967518913848747}, {1.969668001238966, 0.8120497579939745}, {
            2.0963055011660705`, 0.7426205295550468}, {2.2094364471159342`, 
            0.6905419055621478}, {2.31339372655786, 0.6508194293830134}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.3330819805946152`, 0.6439111016646133}, {
            2.4426812964065463`, 0.6095823763559296}, {2.566186863882953, 
            0.578129698012941}, {2.6958468622079486`, 0.5513473368986186}, {
            2.832307281941463, 0.5285201592927712}, {2.9761456351102464`, 
            0.508972621144669}, {3.127608494830892, 0.4922114562842054}, {
            3.1519008588526574`, 0.4899802203689643}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.1726882009140276`, 0.4880709181640338}, {
            3.261328369943707, 0.47992938329756885`}, {3.400438953507501, 
            0.4691609255764606}, {3.5449972107455334`, 0.4596552002332043}, {
            3.695060106881061, 0.4511613243801236}, {3.850447773399919, 
            0.44356467447692743`}, {4.006017493247302, 
            0.43703123008244577`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.026877482164902, 0.43624545871084114`}, {
            4.176105776229284, 0.4308186801906302}, {4.3460840422935805`, 
            0.42540115748483676`}, {4.520559355656564, 0.4205115016677816}, {
            4.699268742337123, 0.4161251041879175}, {4.861525831720191, 
            0.41261105874711507`}}]}, 
          {Arrowheads[{{0.002843766194651634, 1.}}], 
           ArrowBox[{{4.882395798691276, 0.4121599941191571}, {
            5.001099999999999, 0.409867335632662}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.3703489004665297`}, \
{-4.8254042328638995`, -3.387909401831648}, {-4.6197078544572845`, \
-3.409211201610846}, {-4.413321130366544, -3.431126439411515}, \
{-4.206086128915855, -3.4535692074317916`}, {-4.170665548943286, \
-3.45744858055621}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.149914791995282, -3.459721268605863}, \
{-3.997862123106563, -3.4763745542844093`}, {-3.7885384941250626`, \
-3.499239202307652}, {-3.5780046231577445`, -3.521859873839802}, \
{-3.3660228819702476`, -3.5440199542506967`}, {-3.3196746947541795`, \
-3.548667139040419}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.298904000127732, -3.5507497502909953`}, \
{-3.152457249864813, -3.5654334984849307`}, {-2.9373495193327406`, \
-3.58569323324292}, {-2.720741482865331, -3.6043918852250822`}, \
{-2.611774754192065, -3.6130352233443754`}, {-2.5022634570726408`, \
-3.621146512314624}, {-2.4671265506746964`, -3.62355033636365}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4463003887294685`, -3.6249751182828627`}, \
{-2.3922745369506604`, -3.6286711932959608`}, {-2.281874939269722, \
-3.6355547074485197`}, {-2.1711316094734254`, -3.641742495932435}, \
{-2.0601114930053694`, -3.6471799999078387`}, {-1.948881535309154, \
-3.6518126605348655`}, {-1.8375086818283788`, -3.6555859189736486`}, \
{-1.7050163119761372`, -3.6588154046298946`}, {-1.6121609736301248`, \
-3.660041191083525}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5912879503806665`, -3.660316736567514}, \
{-1.5725077982309419`, -3.6605646539895202`}, {-1.4401045679113302`, \
-3.6607831486582367`}, {-1.3066328236047764`, -3.6599592331141726`}, \
{-1.1738127856572231`, -3.6573772301048972`}, {-1.0413408857723279`, \
-3.653163435616134}, {-0.9092171239500915, -3.647317849647883}, \
{-0.7774415001905117, -3.6398404722001434`}, {-0.7567817083598479, \
-3.6384058039794303`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7359570171496902, -3.6369596847285557`}, \
{-0.6463130575417593, -3.6307345813450107`}, {-0.5161308390520025, \
-3.6200034551545794`}, {-0.3868948447212416, -3.60764709362885}, \
{-0.25860507454947695`, -3.5936654967678217`}, {-0.08998601694958241, \
-3.5728289839819385`}, {0.07585208048752246, -3.549675154182443}, {
            0.0939200648098539, -3.5468527553044544`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11454478580498252`, -3.5436309687256644`}, {
            0.2389092177618386, -3.524204007369335}, {
            0.3991853948733652, -3.4964155435426143`}, {
            0.5521218930948887, -3.4676586419658686`}, {
            0.7018505323821749, -3.4376988670348094`}, {
            0.8483713127352233, -3.406536218749437}, {
            0.9345436128009932, -3.387075227968503}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.954905650934593, -3.3824767034299152`}, {
            0.9916842341540336, -3.374170697109751}, {
            1.1318934914738557`, -3.34109748799679}, {
            1.2691032795299397`, -3.3078117772915907`}, {
            1.4033135983222853`, -3.274313564994153}, {
            1.5345244478508924`, -3.240602851104477}, {
            1.6630910438160948`, -3.2070331470712325`}, {
            1.765018133251041, -3.180335947991075}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.7852117779301464`, -3.175046738271257}, {
            1.7893686019182269`, -3.1739579643430877`}, {
            1.9133571221572878`, -3.1413773029200436`}, {
            2.0350566045332785`, -3.109291162802099}, {
            2.13946808941004, -3.0818294235016133`}, {
            2.2426084273419105`, -3.05497419901618}, {
            2.41265524028312, -3.011617749190788}, {
            2.580173268872884, -2.9702267202259067`}, {
            2.593848230513732, -2.9669755184375535`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.614156991983107, -2.962147140607868}, {
            2.7457284252771426`, -2.9308662280571522`}, {
            2.909886621661837, -2.8936013886201395`}, {
            2.931601949262198, -2.888790023954961}, {
            2.953301884214129, -2.884015671790978}, {
            3.077964967688179, -2.8579234770430295`}, {
            3.2024567131272943`, -2.8330290132557105`}, {
            3.34662679853119, -2.8049685682611294`}, {
            3.4309738545021102`, -2.7894488849826646`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.451504061553056, -2.7856713694854807`}, {
            3.491090972163864, -2.778387460075952}, {
            3.6358492340253155`, -2.753285688700178}, {
            3.7809015841155444`, -2.729663254133808}, {
            3.9265297520391598`, -2.707388861867248}, {
            4.073015467400771, -2.686331217390905}, {
            4.220358730200378, -2.666490320704778}, {
            4.27678888060571, -2.659398837725147}}]}, 
          {Arrowheads[{{0.016951629980556958`, 1.}}], 
           ArrowBox[{{4.297500816240862, -2.6567960032833304`}, {
            4.368559540437981, -2.647866171808868}, {
            4.517742022817568, -2.6303280989272553`}, {
            4.668030302043128, -2.6137454302840206`}, {
            4.819424378114661, -2.5981181658791637`}, {
            4.971924251032167, -2.583446305712685}, {
            5.001099999999999, -2.5808074569597417`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.3704875624231803`}, {-4.825537599966426, 
            3.38803451305711}, {-4.619906378731537, 
            3.409329181805961}, {-4.413585392400367, 
            3.431237093057516}, {-4.206416912641411, 
            3.4536724118144244`}, {-4.170665630552662, 
            3.4575880041615172`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.1499148735851, 
            3.4598606920325947`}, {-3.9982603695321113`, 
            3.47647036812751}, {-3.789005220365552, 
            3.499328055881903}, {-3.57854092243482, 
            3.5219425689627317`}, {-3.3666301963316254`, 
            3.5440975854539487`}, {-3.319674768234247, 
            3.5488064623229403`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2989041090022653`, 
            3.5508894265461253`}, {-3.1531371520087816`, 
            3.565507516080447}, {-2.9381033308010247`, 
            3.58576555368877}, {-2.7215702740430916`, 
            3.60446489112546}, {-2.6126415401335445`, 
            3.6131096949556296`}, {-2.5031687090101937`, 
            3.621223357279395}, {-2.4671267681463798`, 
            3.623691047430605}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.44630068295411, 
            3.6251169508110976`}, {-2.39321859544881, 
            3.628751331796224}, {-2.2828580142251647`, 
            3.6356390722055845`}, {-2.172153780115029, 
            3.6418320322069433`}, {-2.061172707894172, 
            3.6472756654997682`}, {-1.9499816123383669`, 
            3.6519154257835273`}, {-1.8386473082233845`, 
            3.6556967667576874`}, {-1.7061431665076463`, 
            3.6589383128125235`}, {-1.6121614220704785`, 
            3.6601875842606373`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5912884241634055`, 
            3.660465042829618}, {-1.5736220550782178`, 
            3.66069987663295}, {-1.441205345658787, 
            3.660930844475367}, {-1.3077197782537135`, 
            3.6601204825279017`}, {-1.1748847856152271`, 
            3.6575517627562304`}, {-1.0423969384341105`, 
            3.6533512195193514`}, {-0.9102562367103637, 
            3.6475188528172646`}, {-0.7784626804439869, 
            3.640054662649971}, {-0.7567822751143112, 3.638551475805168}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.735957427672241, 
            3.63710760811709}, {-0.6473153247760487, 
            3.630961706278859}, {-0.5171132248476185, 
            3.620243040965318}, {-0.38785638065869643`, 
            3.6078986667093482`}, {-0.2595447922092828, 
            3.5939285835109493`}, {-0.09119122674270153, 
            3.5731447561495684`}, {0.0743930011480502, 3.550049377615655}, {
            0.09391933404011207, 3.547002333415621}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11454456428122028`, 3.543783808538065}, {
            0.2372078914629719, 3.524642447909209}, {0.3972534442020647, 
            3.49692396703023}, {0.5501878257985384, 3.468197370588634}, {
            0.6999168938384099, 3.438265119639919}, {0.8464406483216795, 
            3.4071272141840847`}, {0.9345462785769753, 
            3.3872438710719863`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9549090250163373, 3.382648484000975}, {
            0.9897590892483479, 3.3747836542211314`}, {1.1299751585497109`, 
            3.3417294820562367`}, {1.2671917981570648`, 3.30845973999458}, {
            1.4014090080704098`, 3.2749744280361606`}, {1.5326267882897466`, 
            3.2412735461809783`}, {1.6611994526107807`, 
            3.2077109277567786`}, {1.7650249711427166`, 
            3.18052124271634}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.7852188426838944`, 3.1752328992077756`}, {
            1.7874813148292188`, 3.174640406091305}, {1.9114723749450604`, 
            3.142061981184559}, {2.033172632958306, 3.10997565303654}, {
            2.1375212682724856`, 3.0825281707417425`}, {2.240598336893627, 
            3.0556851083155703`}, {2.410682964113066, 3.0123081934164078`}, {
            2.5782316394414475`, 2.9708949928860138`}, {2.593859314963619, 
            2.967177880087706}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6141675920168743`, 2.962347465197204}, {
            2.743810793583271, 2.931511247547797}, {2.9079868572430345`, 
            2.8942226982251666`}, {2.929703760382658, 2.889408240063705}, {
            2.951405174558707, 2.884630793665463}, {3.0760056220368077`, 
            2.8585343872704954`}, {3.20043205517327, 2.8336346565007977`}, {
            3.3445069759791686`, 2.805571087540635}, {3.4309839160474485`, 
            2.7896460408653323`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.451513553784392, 2.785865432544435}, {
            3.4888724724813205`, 2.778985650217289}, {3.6335285446797245`, 
            2.7538783445307606`}, {3.778475192574382, 2.7302491704810494`}, {
            3.9239943765844307`, 2.7079672001147523`}, {4.0703680571290075`, 
            2.686901505478466}, {4.217596234208112, 2.6670520865721903`}, {
            4.276799949764161, 2.6596025228818356`}}]}, 
          {Arrowheads[{{0.016951365217482785`, 1.}}], 
           ArrowBox[{{4.297511472623395, 2.656996405897201}, {
            4.365678907821746, 2.6484189433959253`}, {4.514740557132807, 
            2.630871617862247}, {4.6649056613041955`, 2.614279651883731}, {
            4.8161742203359115`, 2.598643045460377}, {4.968546234227953, 
            2.5839617985921848`}, {5.001099999999999, 
            2.5810129817876235`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.00026854223454873485`}, {-4.995205294108059, 
            0.00026860971043174366`}, {-4.785215271277176, 
            0.00027116607166291707`}, {-4.574599524511057, 
            0.0002738727260774818}, {-4.362767318416875, 
            0.00027672019028060865`}, {-4.166106323557887, 
            0.00027946224965739053`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481647089, 
            0.0002797544320903894}, {-4.041365838112835, 
            0.00028123257159575745`}, {-3.9326225978214406`, 
            0.0002827888899568988}, {-3.8228981967276217`, 
            0.0002843679359608921}, {-3.712192634831377, 
            0.00028596970960773765`}, {-3.5758549454017636`, 
            0.0002879391756833721}, {-3.43696331996683, 
            0.0002899184721301835}, {-3.310237805218541, 
            0.0002916786066322642}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289362963307691, 
            0.00029196701989771587`}, {-3.1428869546921643`, 
            0.0002939178084704526}, {-3.002256046673285, 
            0.00029566648167503437`}, {-2.855903445815972, 
            0.000297335505025687}, {-2.6883745914785, 
            0.0002990148805089511}, {-2.5086173171497816`, 
            0.00030044419054575547`}, {-2.4543692868421676`, 
            0.00030072017539482093`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494444929595, 
            0.00030082637538147186`}, {-2.3110156933369113`, 
            0.0003014494815031201}, {-2.2681301816795245`, 
            0.00030160122195601}, {-2.2240788896126267`, 
            0.00030172146837606045`}, {-2.144934940749152, 
            0.00030173794127224467`}, {-2.0604988559733175`, 
            0.00030159434737197897`}, {-1.8766443184052781`, 
            0.0003008154348173161}, {-1.7701568255726083`, 
            0.00029991616382789413`}, {-1.649531252659009, 
            0.0002984889881684224}, {-1.5985007684372694`, 
            0.00029775021268283705`}}]}, 
          {Arrowheads[{{0.014932368461920866`, 1.}}], 
           ArrowBox[{{-1.5776259265268193`, 
            0.0002974349884609165}, {-1.5091380319060965`, 
            0.00029626830045328457`}, {-1.426573614568547, 
            0.0002946098823460938}, {-1.2262237960732532`, 
            0.00028924941525982815`}, {-1.1620542161346499`, 
            0.00028710804478920425`}, {-1.0870306082798016`, 
            0.0002842396241837985}, {-0.9974532859001146, 
            0.0002802100237784225}, {-0.9742437726615817, 
            0.00027907009359968277`}, {-0.9638532000005624, 
            0.0002785572403361922}, {-0.9587447350918538, 
            0.0002783048662745927}, {-0.9542042648049208, 
            0.0002780805016005465}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.248077177052075}, \
{-4.927311163019673, -4.25563440355551}, {-4.7918274603039706`, \
-4.269888738103327}, {-4.656063888273723, -4.284543052585419}, \
{-4.520013397427483, -4.299529772846183}, {-4.383668938263813, \
-4.3147813247300135`}, {-4.247023461281268, -4.330230134081308}, \
{-4.1710624028498815`, -4.338870719452664}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.150321315241852, -4.3412300222569264`}, \
{-4.110069916978405, -4.345808626744461}, {-3.9728012558537857`, \
-4.361449228563868}, {-3.8352104284059623`, -4.377084365383926}, \
{-3.697178444346258, -4.392704446557283}, {-3.558627019126808, \
-4.408278796524497}, {-3.4196101618573866`, -4.4237082137618255`}, \
{-3.3205538681797795`, -4.434496540552844}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2998017403785522`, -4.436756676966359}, \
{-3.280181881647774, -4.438893496745526}, {-3.140396187607747, \
-4.453735443951856}, {-3.000307088847085, -4.468134853857072}, \
{-2.859968594475565, -4.481992524937435}, {-2.719434713602963, \
-4.495209255669199}, {-2.5394755505190463`, -4.510923002862473}, \
{-2.46865342217661, -4.516485668786439}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.447842674272411, -4.518120231894444}, \
{-2.359346824019479, -4.525071065795314}, {-2.1791856158347427`, \
-4.537515339315934}, {-1.9976668025701703`, -4.549590839891622}, \
{-1.8167323754076028`, -4.559341077872041}, {-1.6360396300208333`, \
-4.567111316136663}, {-1.6143926935411461`, -4.56780591401578}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5935285898412368`, -4.5684753926828074`}, \
{-1.4555885664098618`, -4.572901554685487}, {-1.275379184574689, \
-4.5767117935185135`}, {-1.0957834923007534`, -4.578423605739292}, \
{-0.9171734973734961, -4.577918564451375}, {-0.7586736640681719, \
-4.575489730798465}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7378017503340476, -4.575147811630284}, \
{-0.5629105995590148, -4.570257921349447}, {-0.42573806278301674`, \
-4.564949471017914}, {-0.2896849575540353, -4.558480959432148}, \
{-0.15475128387206938`, -4.55085238659215}, {-0.02093704173711819, \
-4.54206375249792}, {0.09603515141004959, -4.533293848771418}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11684775664735052`, -4.531685315385045}, {
            0.24333314789173643`, -4.5210063005467624`}, {
            0.37378909538563987`, -4.508737482689835}, {
            0.5031256113325284, -4.495308603578675}, {
            0.7190610645488936, -4.470696338036279}, {
            0.9311897461740418, -4.4442544856708075`}, {
            0.9469363917913904, -4.442117502892942}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9676216197519556, -4.439310303379972}, {
            1.1395116562079735`, -4.415983046482259}, {
            1.344026794650688, -4.385882020470634}, {
            1.545034226591804, -4.354658613058953}, {
            1.7428330171209403`, -4.323020029670236}, {
            1.793232196715448, -4.314718051475126}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8138294642743928`, -4.311325177473427}, {
            1.9374231662380965`, -4.290966270304483}, {
            2.1288046739432724`, -4.258497334961693}, {
            2.317541643703148, -4.226085391295312}, {
            2.504198178984403, -4.19420260695878}, {
            2.63705346328341, -4.1716347081574}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6576334959507717`, -4.168138813379735}, {
            2.688774279787037, -4.162848981952099}, {
            2.8712699461110502`, -4.132024516275267}, {
            3.002996100640435, -4.110004650257019}, {
            3.1340404577465404`, -4.088455036701564}, {
            3.3166126730368095`, -4.059185321123826}, {
            3.4817063359884135`, -4.033600736374891}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5023379745686145`, -4.03042383431368}, {
            3.679861112376291, -4.003869144387894}, {
            3.8605373364255042`, -3.9778226832297032`}, {
            3.884578297167707, -3.974422449468151}, {
            3.90861607217719, -3.9710420117843865`}, {
            4.063796662799096, -3.950161948378886}, {
            4.219039933001143, -3.9300982336559653`}, {
            4.329432007003848, -3.9160413844708244`}}]}, 
          {Arrowheads[{{0.01569354039980741, 1.}}], 
           ArrowBox[{{4.350147117799903, -3.913464152335558}, {
            4.449578043977393, -3.9011809437326592`}, {
            4.56512049242258, -3.8873451399435197`}, {
            4.680845202839143, -3.8739245636027233`}, {
            4.796752175227082, -3.860919214710269}, {
            4.912841409586396, -3.8483290932661576`}, {
            5.001099999999999, -3.8390874560944344`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.248045389337973}, {-4.928183619941312, 
            4.255511938376242}, {-4.7927460288428065`, 
            4.269759115520168}, {-4.657028967565207, 
            4.284406281429172}, {-4.52102536260711, 
            4.299385956233566}, {-4.384728140467111, 
            4.314630660063663}, {-4.248130227643803, 
            4.330072913049775}, {-4.1710624076203, 4.33883898438055}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.1503213076700725`, 
            4.341198178679637}, {-4.111224550635783, 
            4.345645235322215}, {-3.974004035941645, 
            4.361280147011295}, {-3.836461610059984, 
            4.376910168247329}, {-3.6984784686307397`, 
            4.392525877416441}, {-3.5599764366969975`, 
            4.408096740811735}, {-3.4210093848620753`, 
            4.423523610423989}, {-3.320554126087385, 
            4.4344671101601385`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.299802060778377, 
            4.4367278202912335`}, {-3.2816311837292873`, 
            4.43870733824398}, {-3.1418957039019517`, 
            4.453548776262488}, {-3.001856815983386, 
            4.467948776470288}, {-2.861568390576905, 
            4.481808190858159}, {-2.7210842982858265`, 
            4.4950278714168785`}, {-2.541107096580785, 
            4.510754112228116}, {-2.4686531086289922`, 
            4.516449739903662}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4478424681394078`, 
            4.51808567000591}, {-2.3609592423406838`, 
            4.5249155839884105`}, {-2.180777722982107, 
            4.537374006652777}, {-1.99923832681141, 
            4.549466087322733}, {-1.8182817088968648`, 
            4.5592328586943305`}, {-1.6375654006970115`, 
            4.567020020880031}, {-1.614392371300795, 4.567765707827404}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.59352832888512, 
            4.568437093680018}, {-1.4570894022118503`, 
            4.572827573879835}, {-1.2768537134413807`, 
            4.576655517693742}, {-1.097230381315034, 
            4.57838498248828}, {-0.9185914527622407, 
            4.577897098429979}, {-0.7586734517848495, 4.575461948301501}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7378018828104381, 
            4.575104513367335}, {-0.5642668063773135, 
            4.5702692837548575`}, {-0.42710687619254695`, 
            4.564974477793751}, {-0.2910654205855089, 
            4.5585193866178715`}, {-0.15614243955619944`, 
            4.550904010227221}, {-0.022337933104618624`, 4.542128348621797}, {
            0.09603558610159667, 4.533264167704317}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11684728209261142`, 4.53164426936169}, {
            0.24191565606535748`, 4.5210961697666345`}, {0.37236473878375276`,
             4.508839652516895}, {0.5016953469244196, 4.495422850052384}, {
            0.7175659008948001, 4.470836380071678}, {0.9296325388547313, 
            4.444419013133823}, {0.9469352034076961, 4.44207212056561}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9676206317387567, 4.439266397905274}, {
            1.137895260804213, 4.416170749238816}, {1.342354066743245, 
            4.386091588386659}, {1.543306801937188, 4.35488820708257}, {
            1.7410513116514035`, 4.323267281831766}, {1.7932310809630163`, 
            4.314673718227927}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8138284574783028`, 4.31128150573846}, {
            1.9355875958858904`, 4.291228812634249}, {2.126915654640649, 
            4.2587727994900195`}, {2.3155986452258714`, 4.226371495278797}, {
            2.5021997249517485`, 4.194497152880304}, {2.6370518679576307`, 
            4.171587546926742}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6576318375239927`, 4.16809128069921}, {
            2.686718893818281, 4.163149772294541}, {2.869156151825468, 
            4.1323293535215075`}, {3.0008123942919913`, 4.11031551366148}, {
            3.1317859380768334`, 4.088770806908892}, {3.3143700969227736`, 
            4.0594885635897855`}, {3.481703571646959, 4.0335463059219325`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.5023367991682193`, 4.030379847604964}, {
            3.6776338189031996`, 4.004146218821004}, {3.8583133820376854`, 
            3.97808611737133}, {3.8823543139842225`, 3.9746840807308477`}, {
            3.9063920192580994`, 3.971301840223965}, {4.061500710201878, 
            3.950419203134424}, {4.2166705346782765`, 3.9303523298295477`}, {
            4.329429139913859, 3.915984871774568}}]}, 
          {Arrowheads[{{0.015693601680760262`, 1.}}], 
           ArrowBox[{{4.350145188823795, 3.913415099090858}, {
            4.447046728284332, 3.901436276448731}, {4.56250693781332, 
            3.8876005535480895`}, {4.678148555826282, 3.874179699840626}, {
            4.793971582323218, 3.8611737153263412`}, {4.909976017304128, 
            3.848582600005234}, {5.001099999999999, 
            3.8390328303571146`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.6471824140936913`}, \
{-4.942956278216662, -2.6524028177278014`}, {-4.8104256596054045`, \
-2.664658244984232}, {-4.677649822679904, -2.677232924917692}, \
{-4.544559557321285, -2.6900740723847165`}, {-4.4110856534106695`, \
-2.7031289022418434`}, {-4.277158900829183, -2.71634462934561}, \
{-4.169935429586426, -2.727021024605477}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.149163306013947, -2.7290893348278207`}, \
{-4.129289459225059, -2.731068202338758}, {-3.9807572463357435`, \
-2.7459563671982843`}, {-3.831447096292707, -2.760899435043452}, \
{-3.6812438432274206`, -2.775787716993523}, {-3.5300358730775323`, \
-2.7905635686204366`}, {-3.3777087303357476`, -2.8051277099339913`}, \
{-3.3181623739727972`, -2.8106262313507586`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.297375963790819, -2.8125456522615306`}, \
{-3.2241429869661222`, -2.8193079987102343`}, {-3.0692192149327093`, \
-2.832932292725214}, {-2.912772396828673, -2.8458939824173264`}, \
{-2.7546739867438905`, -2.858034032095089}, {-2.5948592638874803`, \
-2.869101660339732}, {-2.4649120238373583`, -2.876937640774638}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.444075031702435, -2.878194137354547}, \
{-2.4332635074685625`, -2.8788460857324845`}, {-2.2696550719460147`, \
-2.8870568554260236`}, {-2.1039358515789077`, -2.893491253715868}, \
{-1.9362414352766504`, -2.8978501048975107`}, {-1.7667074119486545`, \
-2.899834233266445}, {-1.6364793851675605`, -2.8995509316145798`}, \
{-1.6095034095633338`, -2.899142701725707}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5886309575183641`, -2.8988268370132007`}, \
{-1.5051416423550394`, -2.8975633856240384`}, {-1.3728664894097644`, \
-2.8937556795001975`}, {-1.2398262322304099`, -2.8880118974484352`}, \
{-1.1060801968210423`, -2.880143457907168}, {-0.9717780931014144, \
-2.8700199119283814`}, {-0.8372278028437296, -2.8576125426378054`}, \
{-0.7554967610678575, -2.848667132468705}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7347458384819667, -2.846395957283797}, \
{-0.70273720782019, -2.84289263316117}, {-0.568572773965176, \
-2.825712552301447}, {-0.4350340998833251, -2.8060198003198136`}, \
{-0.3024787663522301, -2.783928357529312}, {-0.17126435414948343`, \
-2.759552204242983}, {-0.041816595246506216`, -2.732908414236369}, {
            0.08549329934034439, -2.704091586515011}, {
            0.08745100818859741, -2.703609439573397}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10772019088752219`, -2.6986175203429026`}, {
            0.21038953026606683`, -2.67333198923695}, {
            0.3325962981856594, -2.640859890560228}, {
            0.5062769242149372, -2.590419289056932}, {
            0.672193713964363, -2.537480868787763}, {
            0.8307634804108772, -2.482840232257787}, {
            0.9059524335653639, -2.455297685270423}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9255535800035728, -2.4481175680573086`}, {
            0.9824030365314209, -2.4272929819720725`}, {
            1.0971177549336302`, -2.3836646162967106`}, {
            1.2078576163413537`, -2.340682739862207}, {
            1.314916404889706, -2.2985237048233413`}, {
            1.415454207272577, -2.2554827736839074`}, {
            1.6087182189464695`, -2.173809309294533}, {
            1.699531699048465, -2.135166873530321}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.7187399034024513`, -2.126993507615248}, {
            1.789608212263796, -2.0968380277259504`}, {
            1.96057852358868, -2.02500189567483}, {
            2.1240834892852445`, -1.9587338798378426`}, {
            2.2323602299382976`, -1.9165701717183257`}, {
            2.338744952369093, -1.8769545862051509`}, {
            2.4740396943890848`, -1.8295133515064288`}, {
            2.495927508744931, -1.8224004571842716`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.5157803666391962`, -1.8159488637131767`}, {
            2.608069782988357, -1.785957524474235}, {
            2.7416059764641805`, -1.746038234164402}, {
            2.875419033113827, -1.709506609632763}, {
            2.893303133420706, -1.7048553544029212`}, {
            2.9112032314559437`, -1.7002594933119775`}, {
            3.0359530153275256`, -1.6714087927211183`}, {
            3.1620776324089652`, -1.6448640370829568`}, {
            3.2844668148685185`, -1.6201586739193055`}, {
            3.3249010347596597`, -1.6126783284189363`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.345427570082698, -1.6088809118605054`}, {
            3.4085490671319008`, -1.597203411770241}, {
            3.5343243891991105`, -1.5759982506357628`}, {
            3.661792781070149, -1.5565431905158715`}, {
            3.7911053751041712`, -1.5385821222014697`}, {
            3.9224133036603313`, -1.5218589364834607`}, {
            4.05571656673863, -1.5063736333618438`}, {
            4.17225618382367, -1.4941015997864284`}}]}, 
          {Arrowheads[{{0.019416295561009305`, 1.}}], 
           ArrowBox[{{4.193018646645914, -1.491939750653333}, {
            4.328323882153459, -1.4793470217150115`}, {
            4.467558934594843, -1.4667307614227527`}, {
            4.608777493004911, -1.4551681062811075`}, {
            4.751973643106936, -1.4445669175671865`}, {
            4.8663963371117935`, -1.4368123004345683`}, {
            4.981962140740779, -1.4295477445420535`}, {
            5.001099999999999, -1.4284290268346074`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.647368635163422}, {-4.944587004544531, 
            2.6524408978132104`}, {-4.812027790749868, 
            2.6646953779140023`}, {-4.67922386897013, 
            2.677269626021578}, {-4.546106036381731, 
            2.6901108863128487`}, {-4.412605090161082, 
            2.7031664029647247`}, {-4.278651827484595, 
            2.7163834201541173`}, {-4.169935492406117, 
            2.727207943931596}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.1491633590742065`, 
            2.729276156137222}, {-4.1307665551045405`, 
            2.7311078647011238`}, {-3.9822193582787517`, 
            2.7459976672864057`}, {-3.8328950870484593`, 
            2.760943213436939}, {-3.682678591454893, 
            2.7758348886796993`}, {-3.531458323489711, 
            2.7906151058570114`}, {-3.379119853584229, 
            2.8051846559589206`}, {-3.3181626854286868`, 2.81081566941319}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.297376344491828, 
            2.8127358400678015`}, {-3.225543709439164, 
            2.8193714917339854`}, {-3.070610418755235, 
            2.8330035659307646`}, {-2.91415504259324, 
            2.8459743704150386`}, {-2.756049015325912, 
            2.858124965758811}, {-2.5962274246218766`, 
            2.8692046577699726`}, {-2.4649127931294075`, 
            2.877133891656206}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.444075904011686, 
            2.878392095448107}, {-2.4346253581497557`, 
            2.8789627522564163`}, {-2.271011204995199, 
            2.887189001183805}, {-2.105286713110236, 
            2.8936407995915845`}, {-1.9375870084630606`, 
            2.8980189178983227`}, {-1.768047217021866, 
            2.900024126522586}, {-1.6378658146640452`, 
            2.8997586196011955`}, {-1.6095041027042092`, 
            2.8993336693093394`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5886316035711257`, 
            2.899020931678729}, {-1.506574981328792, 
            2.8977914577449972`}, {-1.3743464761268378`, 
            2.8940067093873996`}, {-1.2413520581689161`, 
            2.888288442961811}, {-1.1076506074875174`, 
            2.8804483346386083`}, {-0.9733913073777257, 
            2.870355974398594}, {-0.8388813718441677, 
            2.857982301390813}, {-0.7554963721336347, 2.848875580283574}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7347449195102725, 
            2.8466092530992237`}, {-0.7044280148914666, 
            2.8432982547643117`}, {-0.5702967190836785, 
            2.82615608573408}, {-0.4367863521373156, 
            2.8065029958623526`}, {-0.30425420578568607`, 
            2.7844523498190417`}, {-0.17305757176210126`, 
            2.7601175122740584`}, {-0.043621318561863465`, 
            2.7335149060543262`}, {0.08368374672931886, 2.704738507461159}, {
            0.0874495764902255, 2.7038122439749284`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10772024525549723`, 2.6988263626391156`}, {
            0.20858142449252523`, 2.6740180113760563`}, {0.33079551510883487`,
             2.641583112680518}, {0.5044653839177482, 2.5912011682731677`}, {
            0.6703855142955275, 2.5383141361497166`}, {0.8289694064708384, 
            2.4837178082668303`}, {0.9059615599130353, 
            2.4555377413196013`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9255645980290808, 2.4483627903436687`}, {
            0.9806305606723477, 2.428207976581174}, {1.0953100541057426`, 
            2.384624910737742}, {1.2060182059165094`, 2.3416830212881394`}, {
            1.313047503625818, 2.299558849606133}, {1.4135705678623638`, 
            2.256545829078644}, {1.606797496763943, 2.1749148964378895`}, {
            1.6995571025121339`, 2.1354480156065074`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7187655798587036`, 2.1272752912802813`}, {
            1.7876489094290426`, 2.097967165857655}, {1.958573477535719, 
            2.0261386893722078`}, {2.1220198727620287`, 
            1.9598655190158163`}, {2.2302389645441383`, 
            1.9176953650987156`}, {2.3365584620315856`, 
            1.8780691062978099`}, {2.4718936020950673`, 
            1.8305634446088506`}, {2.4959708428565417`, 1.822729528922693}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.5158213919213246`, 1.8162708350367114`}, {
            2.6059487744118854`, 1.7869464484743247`}, {2.73949697721092, 
            1.746969573425729}, {2.873311208721051, 1.7103842749945595`}, {
            2.8911945463888697`, 1.7057261658520217`}, {2.909093724582081, 
            1.7011235203571844`}, {3.0337691527667916`, 
            1.6722424017875117`}, {3.1598125123506504`, 
            1.6456683055426378`}, {3.2819995264004884`, 
            1.6209589248593492`}, {3.32494199894297, 
            1.6129989804426708`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.345467201687278, 1.6091943678222835`}, {
            3.4058712341085355`, 1.597997696737711}, {3.5314276354747918`, 
            1.5767846211777228`}, {3.658668730499257, 1.557319698179385}, {
            3.7877463980372967`, 1.5393474971929986`}, {3.918812516944275, 
            1.5226125876688645`}, {4.051867087220192, 1.5071149696069828`}, {
            4.172293967471927, 1.4943980841074822`}}]}, 
          {Arrowheads[{{0.019415344011466006`, 1.}}], 
           ArrowBox[{{4.193060801985577, 1.492280478539017}, {
            4.32395522142118, 1.4800615426775239`}, {4.462925134148675, 
            1.467432704708058}, {4.603872586611239, 1.455857210354806}, {
            4.746792122991935, 1.4452430856947494`}, {4.861000222776603, 
            1.4374777561085486`}, {4.9763488445183865`, 
            1.4302025347359641`}, {5.001099999999999, 
            1.428750713821198}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAl4tRkTty7j9gwQ04y/ilP54xnwM8
lO4/efXeokXopT9LFdeIs7buP6SBJ0uI16U/zwtWE1b07j8lc0OanbmlP6Ey
q+lcNu8/9//ntZSZpT+zN69EqJfvP5UaqFBfaqU/wIQzNxgN8D9Orger2iql
Py5IQOjOEPE/w7J7J7MjpD/AfdQ2A4PxPx4+4wh3qqM/zmG45BDn8T/rRAzZ
OzqjP1Ce5AKkV/I/2tDG9m6xoj8VVurK77zyP7s7k8RYMqI/OszK6jB28z8s
aBk1lkShP8c4VtNkEvQ/plbLxLBzoD/i3f87XZr0P0otqhxNcp8/IO47K5CS
9T8QFIptlr2cPyWXWLCPX/Y/4gKAebp+mj8ZbLrd2hD3P2ooV+sFlZg/k5X1
Muos+D+AAuJFsKWVP8cQa91wIfk/E07l+ohQkz9rsloRBP75P8A7sn0CaJE/
KqT7Q457+z8FAdzULSyNP8syuL7vkvw/5HyLKabqiT9Ds7kL
            "]]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8067425358228761`, 0.012177442755944859`}, {
            1.8908654003934244`, 0.010654575120888155`}, {2.0515297056439525`,
             0.00862440162079433}, {2.2272999249436976`, 
            0.007270339146813388}, {2.425781999326858, 
            0.006334165442617513}, {2.6143478252906025`, 
            0.0057844702355924205`}, {2.6417013263013724`, 
            0.005731006486935155}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.6625761283406626`, 0.0056902056706499065`}, {
            2.8251135363290545`, 0.005372518398198995}, {2.9395584616758814`, 
            0.005196576005671081}, {3.059832310183024, 
            0.005043463117803713}, {3.186028065814359, 
            0.004909310955347768}, {3.3182387125337667`, 
            0.004790250739054123}, {3.456320767850261, 0.00468452004688809}, {
            3.497569087657862, 0.004657831716641943}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.518443925201289, 0.004644325359030475}, {
            3.599995625584363, 0.004591560089508946}, {3.7491535841672095`, 
            0.004509307536708512}, {3.903684942029938, 
            0.004435699058278611}, {4.063367010082958, 
            0.0043697493020261585`}, {4.227912534939118, 
            0.0043110889031952706`}, {4.3534375143152095`, 
            0.0042721334015646}}]}, 
          {Arrowheads[{{0.015012991841463815`, 1.}}], 
           ArrowBox[{{4.374312355222811, 0.004265655090211291}, {
            4.397114968583216, 0.0042585785127335655`}, {4.570767763000049, 
            0.00421107878158866}, {4.725256268657776, 0.004173619571359988}, {
            4.882801063127326, 0.0041398776483320765`}, {5.001099999999999, 
            0.004117416361704414}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.9666983588879583}, \
{-4.933610000560303, -0.969413763071973}, {-4.735823516242296, \
-0.9778293306893164}, {-4.530874159543721, -0.9869716299084271}, \
{-4.324801846620998, -0.9965329450067673}, {-4.1669451900640455`, \
-1.004069528400381}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.146094098759615, -1.0050650264166907`}, \
{-4.1169695201081336`, -1.0064555272710627`}, {-3.906740122639137, \
-1.016681627988039}, {-3.8004538458909276`, -1.021880618627101}, \
{-3.693022948593361, -1.0270997306009695`}, {-3.5844474307464385`, \
-1.032338963909645}, {-3.4747272923501593`, -1.0375983185531272`}, \
{-3.345373049761546, -1.0436967187640216`}, {-3.312066577689261, \
-1.0452163471204186`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2912134294601727`, -1.0461677848860365`}, \
{-3.213504241233279, -1.0497133145874675`}, {-3.082254563977532, \
-1.0554033138651673`}, {-2.9475323969724077`, -1.060882582427867}, \
{-2.808459452407389, -1.066036207718456}, {-2.6641574424719607`, \
-1.0707492771798242`}, {-2.4766205618407606`, -1.0757268943489111`}, \
{-2.4567766850139954`, -1.076071049875669}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4359049818147747`, -1.0764330311594457`}, \
{-2.2754136351448273`, -1.0792164582304482`}, {-2.1679732913637464`, \
-1.0801396239228793`}, {-2.0547832770462473`, -1.0803259575565094`}, \
{-2.0121643821987347`, -1.080259097085776}, {-1.9685761642146191`, \
-1.0800599581668249`}, {-1.869131466653149, -1.0785324143168211`}, \
{-1.7897408293590245`, -1.0767955218091285`}, {-1.7057825764484646`, \
-1.0743488253725748`}, {-1.6010826652374783`, -1.070352875208102}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.580223010134753, -1.0695567509203687`}, \
{-1.5259823085051025`, -1.0674866141065815`}, {-1.3156895009893999`, \
-1.0552701860415845`}, {-1.108280269147851, -1.0383565661544703`}, \
{-0.9187088824154493, -1.0182478514767692`}, {-0.7488300455408196, \
-0.9959689434937122}}]}, 
          {Arrowheads[{{0.010347203396635528`, 1.}}], 
           ArrowBox[{{-0.7281748166471185, -0.9929604225346852}, \
{-0.5650027033585027, -0.9673277018011023}, {-0.5153102827517692, \
-0.958736812213407}, {-0.46253493016458347`, -0.949199298207009}, \
{-0.4095122934964169, -0.9392139558059313}, {-0.3564575696556248, \
-0.9288288057041248}, {-0.34636424451277714`, -0.9268018237386975}, \
{-0.3383500289494687, -0.9251892321062398}, {-0.3322370987153907, \
-0.9239577274031393}, {-0.32373134595842035`, -0.9222425665479808}, \
{-0.31824086587387085`, -0.9211344233118457}, {-0.3144108130605278, \
-0.9203610216162847}, {-0.3107459206753801, -0.9196207170257615}, \
{-0.3065130766177201, -0.9187653763093948}, {-0.30279331986915775`, \
-0.9180134718100266}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.9672389465784317}, {-4.933656940483486, 
            0.9699538147050563}, {-4.735858783379433, 
            0.978374094386499}, {-4.530890836331497, 
            0.9875218156460788}, {-4.324799834495353, 
            0.9970888069146787}, {-4.16694603947423, 1.004629031350366}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.146094971945189, 
            1.0056250272266236`}, {-4.116948660124022, 
            1.0070172632040655`}, {-3.906700195470521, 
            1.0172493795260054`}, {-3.8004042850296726`, 
            1.0224514047576323`}, {-3.6929636635017142`, 
            1.0276735341142964`}, {-3.5843783308866453`, 
            1.0329157675959975`}, {-3.474648287184466, 
            1.038178105202736}, {-3.3452957577972042`, 
            1.0442792944010773`}, {-3.312068398194456, 
            1.0457960154633057`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2912152700368753`, 
            1.0467478930445546`}, {-3.2134290796561644`, 
            1.050298580029962}, {-3.0822328824599308`, 
            1.0559889487243377`}, {-2.9475679276903435`, 
            1.0614686228267378`}, {-2.8085575782661762`, 
            1.0666228097877406`}, {-2.6643251971062027`, 
            1.0713367170579238`}, {-2.476728611777635, 
            1.076319610434263}, {-2.456779078742229, 1.07666588453872}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.435907380736016, 
            1.0770281651255775`}, {-2.2754598484027713`, 
            1.0798131338500294`}, {-2.16798756588369, 
            1.0807375351810107`}, {-2.0547648076511105`, 
            1.0809244320862315`}, {-2.012150250060657, 
            1.0808576808610386`}, {-1.9685670101797925`, 
            1.0806586352639478`}, {-1.8691255662987436`, 
            1.0791309821943165`}, {-1.7897132130001512`, 
            1.0773931655286226`}, {-1.7057331410846732`, 
            1.0749449786306002`}, {-1.6010851827035193`, 
            1.0709493858679604`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.580225539950899, 
            1.0701529380547117`}, {-1.5258897172571495`, 
            1.0680783269178513`}, {-1.3155576302010161`, 
            1.0558539678270076`}, {-1.1080664093774513`, 
            1.038924836097807}, {-0.9184117281789931, 
            1.018795761770519}, {-0.7488349087306005, 0.996542998472498}}]}, 
          {Arrowheads[{{0.010314607984247073`, 1.}}], 
           ArrowBox[{{-0.7281784920857943, 
            0.9935427512932972}, {-0.5644827067599221, 
            0.9678115974615187}, {-0.514756348997649, 
            0.9592093731329786}, {-0.46194728395093215`, 
            0.9496597959548109}, {-0.40873383292763976`, 
            0.9396307045904065}, {-0.3545082103033825, 
            0.9290084625176046}, {-0.3443707140118432, 
            0.9269713399808864}, {-0.33648485443810877`, 
            0.9253839800182234}, {-0.3305164258998804, 
            0.9241812231449437}, {-0.3249418990643168, 
            0.9230569742813215}, {-0.32075451915340336`, 
            0.9222119746637746}, {-0.3127758492368228, 
            0.9206008974335135}, {-0.3075350542016907, 
            0.9195419864235895}, {-0.304132559953216, 0.9188542582245517}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.3083453919029273`}, \
{-4.883135708388509, -1.3146990521369852`}, {-4.717075088663338, \
-1.3240035017916212`}, {-4.550315546774672, -1.3336465556125947`}, \
{-4.38285708272251, -1.3436282135999058`}, {-4.214699696506852, \
-1.3539484757535545`}, {-4.167522155152202, -1.3568992984968893`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.146688026590011, -1.3582024147389318`}, \
{-4.0237607058431815`, -1.3658911734877215`}, {-3.830720616371187, \
-1.3780781264710928`}, {-3.634829344596364, -1.3903794106828238`}, \
{-3.435336807024207, -1.4026651021020697`}, {-3.31329404340566, \
-1.4098507841970467`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.292455290734475, -1.4110777365169647`}, \
{-3.230998396202371, -1.4146962198547601`}, {-3.0205695046785124`, \
-1.426233783066824}, {-2.8930477296332295`, -1.43268960675401}, \
{-2.7622932114060665`, -1.4387386401498188`}, {-2.6276359190721803`, \
-1.4442271786983405`}, {-2.4884058217067286`, -1.4490015178436655`}, \
{-2.4583911850419886`, -1.449787178835104}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4375234909604284`, -1.4503334101090084`}, \
{-2.343526367204409, -1.4527938721251716`}, {-2.191921003459919, \
-1.4553364560822362`}, {-2.0072965176177746`, -1.4562444831823174`}, \
{-1.8082741933727626`, -1.45397360926313}, {-1.701860869666325, \
-1.4511918824216425`}, {-1.6027043819756255`, -1.4474784218107652`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5818477307312273`, -1.44661363053344}, \
{-1.516716418855261, -1.4434921858666692`}, {-1.4406763760210572`, \
-1.439186373809533}, {-1.2458351693475747`, -1.4251254865360232`}, \
{-1.0991322903756167`, -1.4112740542754436`}, {-0.937971746750802, \
-1.3925527414749492`}, {-0.7586198712139034, -1.3671194785547987`}, \
{-0.7511966621089408, -1.3658438296977176`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.730623385252725, -1.3623083941823013`}, \
{-0.5569628467464236, -1.3324655237561456`}, {-0.44627304397575424`, \
-1.3105586201377781`}, {-0.3285638951680689, -1.2849058370289856`}, \
{-0.2126836609131262, -1.257241961591912}, {-0.0920665401577234, \
-1.2259372924017327`}, {0.03129947104198476, -1.1912808342316652`}, {
            0.08259122719353537, -1.1757641112167445`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10257179441539403`, -1.1697196130259138`}, {
            0.15448276721947604`, -1.1540155653022197`}, {
            0.16665711943038855`, -1.1501873301945813`}, {
            0.1787913061714764, -1.146345237358552}, {
            0.19088181893663275`, -1.1424905443089974`}, {
            0.19691572071959454`, -1.1405602053027313`}, {
            0.20293756903275953`, -1.1386271170836137`}, {
            0.20894693438357556`, -1.1366914387558267`}, {
            0.214943392249827, -1.134753328880838}, {
            0.2209265233994421, -1.1328129453941675`}, {
            0.40374075710683455`, -1.0698354161842856`}, {
            0.5630652514651058, -1.0089445743057754`}, {
            0.6765446040014099, -0.9621772504987867}, {
            0.7729717049730811, -0.9190423473257807}, {
            0.879489141143341, -0.8666185724657768}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.8982185224962629, -0.8574006931531044}, {
            0.9278254930356793, -0.842829283873555}, {
            1.045176150102859, -0.7783668936409939}, {
            1.0794421140479515`, -0.7585509139304907}, {
            1.1110946595343627`, -0.7397550739043807}, {
            1.1469563863314982`, -0.7173917067633842}, {
            1.1800201919411835`, -0.6963054124516593}, {
            1.2414223120182586`, -0.6564479408464328}, {
            1.2945379343800258`, -0.6208213518092346}, {
            1.3413337309340794`, -0.5887252541707452}, {
            1.426973314983994, -0.529130799306741}, {
            1.4978687096398688`, -0.47983955520733157`}, {
            1.5592075518320487`, -0.4382978589788855}, {
            1.6027429427890627`, -0.41067182168778765`}}]}, 
          {Arrowheads[{{0.017851426801557754`, 1.}}], 
           ArrowBox[{{1.620368587363071, -0.39948720375792973`}, {
            1.6481416749187145`, -0.3818633732229356}, {
            1.726965531171072, -0.33731385439417627`}, {
            1.800423208782251, -0.3013807584186956}, {
            1.9099006214100613`, -0.2579372280307926}, {
            2.0196819268215602`, -0.22523389453920173`}, {
            2.1339932783982776`, -0.20009832602560895`}, {
            2.322603939201327, -0.17189410112317527`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.0007525719102613069, 1.}}], 
           ArrowBox[{{0.4997696874801582, 0.7857920367929448}, {
            0.5035293174116451, 0.7845901154377575}, {0.5070299900479538, 
            0.7834709805027307}, {0.5127507988222554, 0.7816420871382029}, {
            0.519776482567165, 0.7793960364678755}, {0.5245882021947572, 
            0.7778577710851202}, {0.5296971903634027, 
            0.776224471506386}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.53351076111958}, {-4.9052182766698476`, 
            1.539395322284766}, {-4.738144010157267, 
            1.5501038155516074`}, {-4.57060968346883, 
            1.5612266235772285`}, {-4.402355941802098, 
            1.5727111200834396`}, {-4.233350810264103, 
            1.5845699999885539`}, {-4.167973442629376, 
            1.5892601818635186`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.147152111988968, 
            1.5907539071558539`}, {-4.0633804100342985`, 
            1.5967637012536824`}, {-3.8919125304188835`, 
            1.6091612121648309`}, {-3.718414960724053, 
            1.621631521008006}, {-3.558037660314131, 
            1.633007167913158}, {-3.3953096697438614`, 
            1.644292632889121}, {-3.3142440460192772`, 
            1.649717882151033}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.293415795239128, 
            1.6511117954644718`}, {-3.2297622315738646`, 
            1.6553717571279547`}, {-3.0607429637494086`, 
            1.6660647030744304`}, {-2.887574049196464, 
            1.6761892035053043`}, {-2.709261291648889, 
            1.685440493038785}, {-2.5251175494853952`, 
            1.6936515175509188`}, {-2.4596582759365577`, 
            1.6958629396852587`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4387953360961614`, 
            1.6965677560458625`}, {-2.333208813410755, 
            1.7001348040849809`}, {-2.2176622331121822`, 
            1.7026226002681333`}, {-2.0986404574960873`, 
            1.7042235642115144`}, {-1.975250278135751, 
            1.7045795247907691`}, {-1.8469954681274403`, 
            1.703491498047922}, {-1.7130120858387394`, 
            1.7005722929940468`}, {-1.60400913826952, 1.6965886033071549`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5831482232078142`, 
            1.695826207298206}, {-1.5724361896372334`, 
            1.6954347186402166`}, {-1.4988557951170314`, 
            1.6918596565084967`}, {-1.4231464547223087`, 
            1.687489947515093}, {-1.2142849665133655`, 
            1.671819086167846}, {-1.0331014858779626`, 
            1.6532840872509627`}, {-0.837180673509332, 
            1.6276302404743679`}, {-0.7527165804641809, 
            1.6137246617056287`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7321190108996266, 
            1.6103336216115691`}, {-0.6243332363943613, 
            1.592588523979001}, {-0.5108949754493582, 
            1.57065817233104}, {-0.3930626117365198, 
            1.5453545036951157`}, {-0.20377579395009002`, 
            1.4988977875695422`}, {-0.008949038185670305, 
            1.4434073628837734`}, {0.07869270896173786, 1.414710811586612}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.09853117532581766, 1.4082150993695073`}, {
            0.18492770721989743`, 1.3799262691020628`}, {0.3040895001760678, 
            1.3365714099752077`}, {0.4174625225827737, 1.2919466667498907`}, {
            0.545411884659789, 1.2375010500944057`}, {0.6610738792430726, 
            1.18403175840068}, {0.703364634005861, 1.1635729700438842`}, {
            0.743733401454049, 1.1434571892313292`}, {0.7954518095432608, 
            1.1159647144394151`}, {0.8439030231233409, 1.089305765897873}, {
            0.8638120243357059, 1.0777678233471364`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.8818730655348209, 1.0673008364029368`}, {
            1.0030692430870904`, 0.9970635342373977}, {1.1283836298173422`, 
            0.9166170391662075}, {1.229488775244188, 0.8465757466170905}, {
            1.3468266696654465`, 0.7592327372246991}, {1.4416510512524132`, 
            0.6862840651044388}, {1.5210111036014473`, 0.6247737124547542}, {
            1.5661195992149823`, 0.5904468046809713}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5827314698659682`, 0.5778054132084678}, {
            1.5898767583291566`, 0.5723679528197567}, {1.7043321392028337`, 
            0.49061084354267914`}, {1.805626503388662, 
            0.42762919905389374`}, {1.9010501344272, 0.378178380590969}, {
            1.9950829006187303`, 0.3387458072940299}, {2.174009005984456, 
            0.2848914009069501}, {2.340779217585187, 0.25304780584836045`}}]}, 
          {Arrowheads[{{0.011579332117122672`, 1.}}], 
           ArrowBox[{{2.3612836186577058`, 0.24913263515687395`}, {
            2.370312575647143, 0.24740861953433932`}, {2.4774450557387397`, 
            0.23299388515762823`}, {2.5914757463623497`, 
            0.22081749165642586`}, {2.712949368434856, 
            0.21046584052786046`}, {2.8422000444268747`, 
            0.20165496906368593`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.564718956875586}, \
{-4.934070538121404, -4.5712697001376705`}, {-4.814344782620072, \
-4.583115892108186}, {-4.69439745317188, -4.595095802584443}, \
{-4.575010440300749, -4.609950754622343}, {-4.454890379642013, \
-4.623146188147204}, {-4.334530202178141, -4.636410328563832}, \
{-4.213929907909136, -4.649743175872228}, {-4.170977066104643, \
-4.65450677136464}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.15022942660916, -4.656807745126254}, \
{-4.093089496834995, -4.663144730072392}, {-3.97200896895572, \
-4.676614991164324}, {-3.8506883242713106`, -4.690153959148024}, \
{-3.7291275627817666`, -4.703761634023492}, {-3.6073266844870884`, \
-4.7174380157907265`}, {-3.4852947666039773`, -4.730995421328212}, \
{-3.3630408863491357`, -4.744246167514432}, {-3.3203155918541087`, \
-4.74876166959331}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2995563652781756`, -4.750955646998672}, \
{-3.2405650437225635`, -4.757190254349385}, {-3.1178672387242607`, \
-4.769827681833071}, {-2.9949474713542275`, -4.782158449965491}, \
{-2.871805741612463, -4.794182558746645}, {-2.7484420494989688`, \
-4.805900008176532}, {-2.624856395013743, -4.817310798255153}, \
{-2.517189752520114, -4.826902059607824}, {-2.4684263915988036`, \
-4.831051465851912}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.447626716678085, -4.832821366436294}, \
{-2.4094209393711923`, -4.836072399341373}, {-2.287254507600793, \
-4.845879207500325}, {-2.165047707463083, -4.855016579640967}, \
{-2.0428005389580637`, -4.8634845157633}, {-1.920513002085734, \
-4.871283015867323}, {-1.7982663206395826`, -4.878338899905967}, \
{-1.6761417184130982`, -4.884578987832166}, {-1.6144702599089766`, \
-4.88732093102532}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5936160194744435`, -4.888248120749624}, \
{-1.554139195406281, -4.890003279645919}, {-1.432258751619131, \
-4.894611775347226}, {-1.4022667854480313`, -4.895645963482692}, \
{-1.3722882548838855`, -4.896627183962264}, {-1.2973666674717137`, \
-4.898612990688454}, {-1.222553518337284, -4.900257354220243}, \
{-1.0451830265458013`, -4.903180787721809}, {-0.8687727616193555, \
-4.904132915813754}, {-0.7588552123528626, -4.903494412258755}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7379807226281985, -4.903373153770125}, \
{-0.6933227235579463, -4.903113738496079}, {-0.5188329123615738, \
-4.900123255768782}, {-0.3455797189561119, -4.895238668050096}, \
{-0.1738395342674341, -4.888537175758254}, {-0.0036123582955405187`, \
-4.880018778893253}, {0.0963865735863821, -4.873892920458788}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11722235694566165`, -4.872616536233196}, {
            0.16510180895956877`, -4.869683477455095}, {
            0.33250362535412015`, -4.857270350666345}, {
            0.49745602970283037`, -4.844257949599136}, {
            0.6607348990497751, -4.82963738058072}, {
            0.8222599702524638, -4.813513011922068}, {
            0.9489360512929459, -4.799596999786584}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9696860616766437, -4.797317505552636}, {
            1.0111536716494371`, -4.79276207757546}, {
            1.19753479418531, -4.770572611632646}, {
            1.3813336548893815`, -4.747234097995936}, {
            1.5624805707909513`, -4.723036020567639}, {
            1.741113997084788, -4.698166577894417}, {
            1.7977218325024515`, -4.690011149606089}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8183833519891714`, -4.687034467327768}, {
            1.9174913250602152`, -4.672756091176853}, {
            2.0917212758883634`, -4.647007228298132}, {
            2.263912570740364, -4.621122657141438}, {
            2.4342384858409596`, -4.5952355177461515`}, {
            2.6029091860169604`, -4.569439219955193}, {
            2.6441303922772548`, -4.563136341678018}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6647654089751858`, -4.55998116961262}, {
            2.770088725342593, -4.543876836357057}, {
            2.935941157892086, -4.518691439540239}, {
            3.1006314907216765`, -4.493952832801285}, {
            3.2643252754487517`, -4.469688951269912}, {
            3.4271873829892607`, -4.445980065284373}, {
            3.490641916513216, -4.436953134240235}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.511308684933627, -4.43401311588259}, {
            3.589382684259155, -4.422906445182921}, {
            3.75073340436235, -4.400491929227404}, {
            3.911591037868524, -4.378653908637308}, {
            4.072088238282373, -4.357428950783062}, {
            4.232357659108594, -4.3368536230350925`}, {
            4.338959884415955, -4.323616632981583}}]}, 
          {Arrowheads[{{0.015461969510107457`, 1.}}], 
           ArrowBox[{{4.359675632945105, -4.321044321226919}, {
            4.392531953851882, -4.3169644927638275`}, {
            4.552743776016932, -4.2977981273396955`}, {
            4.7131257791084415`, -4.279391094133125}, {
            4.873810616631105, -4.261779960514542}, {
            5.001099999999999, -4.248429334182008}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0932278339534751`, 5.001099999999999}, {
            1.1717340849633229`, 4.993456334344306}, {1.2957080174949733`, 
            4.98097180212389}, {1.4187653300691254`, 4.968219286644007}, {
            1.5387879245204994`, 4.950620598330004}, {1.6592794533477893`, 
            4.935748750371572}, {1.7789045937946226`, 4.920717492819475}, {
            1.897663345861, 4.905526825673711}, {1.922250753046287, 
            4.902325442858762}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.9429508665935924`, 4.89963020186493}, {
            2.015555709546921, 4.890176748934282}, {2.132581684852386, 
            4.874667262601187}, {2.2487412717773947`, 4.858998366674426}, {
            2.3640344703219474`, 4.843170061153999}, {2.478461280486043, 
            4.827182346039907}, {2.5921946319967244`, 4.81117730987293}, {
            2.7054074545810316`, 4.795297041193851}, {2.770204267975106, 
            4.7862378035345845`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.790878034579511, 4.7833474057639025`}, {
            2.8180997482389647`, 4.77954154000267}, {2.930271512970524, 
            4.7639108062993865`}, {3.0419227487757095`, 4.748404840084001}, {
            3.153053455654521, 4.733023641356514}, {3.2636636336069587`, 
            4.717767210116924}, {3.3737532826330225`, 4.702635546365232}, {
            3.522222507412836, 4.682425361339339}, {3.618086446874066, 
            4.66959902040783}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.638776912717518, 4.666830690935545}, {
            3.6701516941257344`, 4.662632828368504}, {3.8583078343784116`, 
            4.63806372652082}, {4.046078270048617, 4.614289292993377}, {
            4.233463001136351, 4.591309527786175}, {4.420462027641613, 
            4.569124430899211}, {4.445405545703752, 4.566215193796117}, {
            4.467362956369291, 4.563667118885277}}]}, 
          {Arrowheads[{{0.012358258929723377`, 1.}}], 
           ArrowBox[{{4.488108036927973, 4.5613434375427175`}, {
            4.643342070649064, 4.544060752832172}, {4.816433163708085, 
            4.525510198928855}, {4.957169052898897, 4.510655514104542}, {
            5.001099999999999, 4.506160791636552}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.7961674677906916`}, \
{-4.9940498518757295`, -3.7968743191715886`}, {-4.875199732897269, \
-3.8091046764246053`}, {-4.756170807396775, -3.8216262961122305`}, \
{-4.636945752362976, -3.8343998654345803`}, {-4.5175072447846025`, \
-3.8473860715917705`}, {-4.397837961650381, -3.8605456017839184`}, \
{-4.277920579949043, -3.873839143211139}, {-4.170933369537173, \
-3.8857870453750882`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           
           ArrowBox[{{-4.150188033524423, -3.888108686425392}, \
{-4.037169843418245, -3.900803508523191}, {-3.9162992829317016`, \
-3.9143990193070524`}, {-3.795095974025705, -3.927991165119241}, \
{-3.673557951496238, -3.941520758167085}, {-3.551683250139284, \
-3.954928610657911}, {-3.429469904750823, -3.9681555347990485`}, \
{-3.3202383603995034`, -3.9797305924808075`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.299477763634615, -3.9819114175810126`}, \
{-3.1839092219449068`, -3.9938606811866477`}, {-3.060377628289284, \
-4.006270984016083}, {-2.936379312566002, -4.018297244770684}, \
{-2.8119724181810852`, -4.029863456935008}, {-2.687215088540558, \
-4.040893613993608}, {-2.5621654670504506`, -4.051311709431039}, \
{-2.4680436594636044`, -4.058621576925508}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.447231489392309, -4.06023793140694}, \
{-2.436881697116787, -4.061041736731859}, {-2.311421922145594, \
-4.0700076893806205`}, {-2.154843875363443, -4.079919902543569}, \
{-1.998158611104621, -4.088257310245755}, {-1.8414953755803274`, \
-4.094927962384662}, {-1.6836047887489558`, -4.100820709951274}, \
{-1.613396541534419, -4.102522370776714}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5925278283679194`, -4.103028172774081}, \
{-1.526317838602516, -4.104632926493288}, {-1.3693114096130063`, \
-4.1065944872669915`}, {-1.2125855017804263`, -4.106705392272385}, \
{-1.0561401151047756`, -4.1049656415094695`}, {-0.9003128146549885, \
-4.101322073814867}, {-0.7577113644329078, -4.096165249076455}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7368548873215035, -4.095299927910095}, \
{-0.5915251676398018, -4.088164004140476}, {-0.43856482107440165`, \
-4.0786495021606886`}, {-0.32935009745318244`, -4.0706808166190065`}, \
{-0.2210152346592571, -4.061866395336355}, {-0.006985091553283418, \
-4.041700345548138}, {0.09543299098651054, -4.030243242960282}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.11617843219408289`, -4.02792253315737}, {
            0.2035256082435185, -4.01815135279604}, {
            0.41051686473114857`, -3.991219417080059}, {
            0.6136104560362103, -3.9616927199411385`}, {
            0.8124281602853072, -3.930359442920221}, {
            0.9424209126800074, -3.908215405844122}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9629993123975714, -3.9047099115921893`}, {
            1.006969977478439, -3.8972195860173064`}, {
            1.197235907615605, -3.8622731492323954`}, {
            1.3835220487086193`, -3.826312822193116}, {
            1.5661244987692957`, -3.790131294527098}, {
            1.7450432577976338`, -3.7537285662343405`}, {
            1.7827081733407455`, -3.7458566419363954`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8031415154333623`, -3.7415860967941135`}, {
            1.920278325793633, -3.7171046373148444`}, {
            2.127668180655894, -3.6734400709860715`}, {
            2.331790787144838, -3.631012453091775}, {
            2.5326461452604647`, -3.5898217836319546`}, {
            2.62073180421744, -3.5720102369306352`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.641192540299998, -3.5678729305791452`}, {
            2.730234255002774, -3.5498680626066106`}, {
            2.925640608934247, -3.511442801198593}, {
            3.1199506996173656`, -3.474837510590752}, {
            3.3131645270521295`, -3.4400521907830877`}, {
            3.4619433256689778`, -3.4145233171369473`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.4825174829206373`, -3.41099300861358}, {
            3.5052820912385396`, -3.4070868417756}, {
            3.657309149260908, -3.38221893831208}, {
            3.809348273716467, -3.3584929344011942`}, {
            3.982205942095549, -3.332879205550799}, {
            4.1556115525769775`, -3.3086025118252183`}, {
            4.308416444026574, -3.288451776239102}}]}, 
          {Arrowheads[{{0.016195846436805557`, 1.}}], 
           ArrowBox[{{4.329112109557227, -3.285722590805765}, {
            4.329565105160751, -3.28566285322445}, {
            4.504066599846871, -3.264060229748496}, {
            4.527441924823803, -3.261260400111273}, {
            4.550831914434078, -3.258482297482226}, {
            4.727263406851506, -3.2389884602810732`}, {
            4.904671094466738, -3.220610659997653}, {
            5.001099999999999, -3.21084654419588}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.7962214532590397`}, {-4.994789407613086, 
            3.796854055494118}, {-4.8759913717791825`, 
            3.8090771651485773`}, {-4.7570148149332185`, 
            3.8215914560062085`}, {-4.6378424302412045`, 
            3.8343576895472897`}, {-4.518456910869147, 
            3.847336627252099}, {-4.398840949983057, 
            3.860489030600915}, {-4.278977240748948, 
            3.8737756610740153`}, {-4.17093335969171, 3.885841009347393}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.150188094693728, 
            3.888163284321624}, {-4.038335334783394, 
            3.900726979504814}, {-3.9175199740060362`, 
            3.9143164986778345`}, {-3.796372335277101, 
            3.927903140424847}, {-3.6748904140301932`, 
            3.941427816697536}, {-3.5530722056989155`, 
            3.9548314394475836`}, {-3.430915705716876, 
            3.968054920626675}, {-3.320238541172504, 3.979786330679511}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2994776129966756`, 
            3.9819639896641323`}, {-3.1854698708446367`, 
            3.993756054973761}, {-3.061996622237515, 
            4.006166175691553}, {-2.9380571273246345`, 
            4.018193565076077}, {-2.8137093497343124`, 
            4.029762253863538}, {-2.689011253094862, 
            4.040796272790144}, {-2.564020801034599, 
            4.051219652592102}, {-2.4680442310091957`, 
            4.058682244635654}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.44723220626608, 
            4.060300469273366}, {-2.4387959571818376`, 
            4.060956424005618}, {-2.313394685164898, 
            4.0699306177669}, {-2.156791541855882, 
            4.0798610749625555`}, {-2.000079806368172, 
            4.088217389225055}, {-1.8433886325362066`, 
            4.094907414214257}, {-1.6854695332937486`, 
            4.10082189788487}, {-1.6133967324494474`, 4.102578180171897}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.592528085598929, 
            4.103086710912876}, {-1.5281521879620068`, 
            4.104655433751544}, {-1.371113711954886, 
            4.106638387664636}, {-1.2143541052723867`, 
            4.106770759624144}, {-1.057873367914507, 
            4.105052549630069}, {-0.9020091316760959, 
            4.101430137603043}, {-0.7577112069652683, 4.096232179636265}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7368555191986699, 
            4.095348356508379}, {-0.5931430579422199, 
            4.088311847212033}, {-0.4401412204467554, 
            4.0788159688480485`}, {-0.33091809273350076`, 
            4.070861643910623}, {-0.2225741213738604, 
            4.062061058553148}, {-0.008523647715427074, 4.041921106578047}, {
            0.09543313628095455, 4.030305004443694}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11617886679460225`, 4.027986882285291}, {
            0.20201020052854557`, 4.018396112922746}, {0.40902742335805736`, 
            3.9914860775872447`}, {0.6121485369157731, 3.961978678054663}, {
            0.8109940573443573, 3.93066159180812}, {0.9424223157074298, 
            3.9082850913087026`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9630010282685605, 3.9047814340462788`}, {
            1.0055639846438096`, 3.897534818847617}, {1.195858318814131, 
            3.8625983591731528`}, {1.3821721233584918`, 
            3.8266451991438584`}, {1.5648004617800648`, 
            3.7904683251188644`}, {1.7437433340788493`, 
            3.7540677370981705`}, {1.7827093444226751`, 3.745924840530518}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8031427868004342`, 3.741654775252215}, {
            1.9190007402548455`, 3.7174434350817775`}, {2.126238741795378, 
            3.6738124882221426`}, {2.330210509650844, 3.631414150220101}, {
            2.530916043821244, 3.590248421075654}, {2.620733803415315, 
            3.5720823143838802`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.641194348437152, 3.567944063268306}, {
            2.728355344306577, 3.5503153007888004`}, {2.923611755938672, 
            3.5119066440444}, {3.1177686235493556`, 3.47531430552731}, {
            3.3108259471386283`, 3.4405382852375315`}, {3.461944577128465, 
            3.4145907824493347`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.4825183453327586`, 3.4110582073599462`}, {
            3.5027837267064896`, 3.4075785831750647`}, {3.6547307511000815`, 
            3.3827049349766987`}, {3.8066870836333155`, 
            3.3589722920075684`}, {3.9795413614688804`, 
            3.3333367623801937`}, {4.152941202817396, 3.309039094031274}, {
            4.308417640668147, 3.288517085876479}}]}, 
          {Arrowheads[{{0.016195795099294027`, 1.}}], 
           ArrowBox[{{4.329115244557478, 3.2858031267318406`}, {
            4.501377576053281, 3.264457341168803}, {4.524751149928043, 
            3.2616550046018333`}, {4.548139359457213, 3.258874411575182}, {
            4.724483546628069, 3.2393704514361885`}, {4.901801964036345, 
            3.2209826020589016`}, {5.001099999999999, 
            3.210917420081985}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.858319442873306, 
            3.6000379852705473`}, {-4.734885484835505, 
            3.612841108465631}, {-4.611220374978161, 
            3.6259323964013115`}, {-4.487294073827668, 
            3.639310747867591}, {-4.363088237633876, 
            3.6529172683754805`}, {-4.23858452264664, 
            3.6666930634359924`}, {-4.11376458511581, 
            3.680579238560138}, {-4.028200857452806, 3.690107926444693}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.007454267274379, 
            3.692418342176668}, {-3.9886100812912333`, 
            3.6945168992589297`}, {-3.8631026674227655`, 
            3.7084471510433787`}, {-3.7372239997602574`, 
            3.7223110994244966`}, {-3.6108878144535623`, 
            3.7360847775075587`}, {-3.484032545870719, 
            3.7497315174544714`}, {-3.3566768975888475`, 
            3.763173373361194}, {-3.228839573185068, 
            3.7763323993236853`}, {-3.1772285205513664`, 
            3.7814807206913983`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.156456767717368, 
            3.7835527508768534`}, {-3.1005392762365016`, 
            3.7891306494379045`}, {-2.9717947103202684`, 
            3.8014901777998102`}, {-2.842624579013487, 
            3.813333038505362}, {-2.713047585893281, 
            3.8245812856505186`}, {-2.541328885727639, 
            3.8383746191401364`}, {-2.3687873341012105`, 
            3.8508043639260663`}, {-2.3244493724272677`, 
            3.853592564500396}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.303615683753929, 
            3.8549026947033043`}, {-2.1955593835138343`, 
            3.8616978342860624`}, {-2.021781486465347, 
            3.870882344497878}, {-1.8475037670799734`, 
            3.878119383474089}, {-1.6728454121824279`, 
            3.883223100419413}, {-1.4980464683232864`, 
            3.8860998000498186`}, {-1.4693265587433488`, 
            3.8861912021346896`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.4484518225453489`, 
            3.886257636689587}, {-1.3233469820531283`, 
            3.886655787081274}, {-1.148956263422116, 
            3.884684325699039}, {-0.9751082116807431, 
            3.8800691125129396`}, {-0.8020797571800848, 
            3.8728521008757957`}, {-0.6301478302712135, 
            3.863075244140427}, {-0.6140019649712967, 3.8619017076867235`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5931820451576454, 
            3.8603884450395594`}, {-0.45961050897557787`, 
            3.850680011086029}, {-0.29074895317832666`, 
            3.835688258150697}, {-0.12381471602608152`, 
            3.8182625201755993`}, {0.04094064933453617, 3.798565332001904}, {
            0.1726124040491228, 3.780968763131885}, {0.23685930601261088`, 
            3.771562828827801}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.25751396739023785`, 3.768538926008308}, {
            0.3022596717592152, 3.761988024053164}, {0.42994651251098714`, 
            3.741766552055406}, {0.5557369863506132, 3.7204477844282744`}, {
            0.6796951533242659, 3.698175158461434}, {0.8018850734781182, 
            3.6750921114445494`}, {0.9223708068583449, 3.6513420806672836`}, {
            1.0412164135111195`, 3.6270685034193013`}, {1.0789028568317731`, 
            3.6191425643301725`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0993308080040511`, 3.614846305982587}, {
            1.242026838724146, 3.5848355130264866`}, {1.438305509389426, 
            3.5426955133213274`}, {1.6305207701342996`, 
            3.5010119326326126`}, {1.8141452895611438`, 3.456271630448723}, {
            1.9141710627430017`, 3.432789623439602}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.934493411635873, 3.4280187576520755`}, {
            1.9958139498906136`, 3.4136231747608243`}, {2.1743558895543575`, 
            3.3721579947469453`}, {2.349771108552376, 3.331876090407087}, {
            2.522059606884669, 3.292777461741249}, {2.692163453874538, 
            3.2551112694094253`}, {2.7487312616374844`, 
            3.2430565825524393`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.7691476726239386`, 3.238705813963057}, {
            2.8610247188452846`, 3.2191266740716107`}, {3.0286434017969093`, 
            3.1848236757278054`}, {3.195019502729411, 3.1522022743780087`}, {
            3.3368262091555962`, 3.125612682264256}, {3.4784787260452656`, 
            3.1002584643866404`}, {3.589130914363688, 3.081474600093084}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.60971132869388, 3.0779809528750914`}, {
            3.6465882511729197`, 3.071720876884394}, {3.8151848951688683`, 
            3.044761771421834}, {3.9842686580331113`, 3.0193811479989594`}, {
            4.153839539765649, 2.9955790066157713`}, {4.176534971844474, 
            2.9925033687987233`}, {4.199245664259108, 2.9894532198261268`}, {
            4.364549800114485, 2.9688560973599363`}, {4.436303596444901, 
            2.9604929766000416`}}]}, 
          {Arrowheads[{{0.013108110166445088`, 1.}}], 
           ArrowBox[{{4.457038078572995, 2.958076310349623}, {
            4.530838606082178, 2.949474636915355}, {4.661382549771328, 
            2.9345989197145212`}, {4.7926318894267155`, 
            2.9203201305793343`}, {4.924586625048342, 2.906638269509793}, {
            5.001099999999999, 2.89909137223809}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.9978759570027336`}, \
{-4.828321182916664, -3.0144443883489345`}, {-4.641475218465633, \
-3.0329761860454947`}, {-4.454035134429814, -3.052037328515979}, \
{-4.265877504410184, -3.071577948699727}, {-4.17032283961539, \
-3.0816420313548236`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.149562824396133, -3.0838285338090614`}, \
{-4.076867981186944, -3.091484956572175}, {-3.8868531061039375`, \
-3.1115346219219373`}, {-3.6956794205050025`, -3.1315032145376254`}, \
{-3.503139212177029, -3.1512659532226097`}, {-3.318991076987546, \
-3.1696293762450076`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2982143718209023`, -3.1716505692728147`}, \
{-3.113377944843506, -3.1892195785460626`}, {-2.915980177062337, \
-3.206725527126338}, {-2.7165727062745857`, -3.2228528624312185`}, \
{-2.5150244165431275`, -3.2372708330618147`}, {-2.466083901652872, \
-3.2402276022472734`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.445247052782051, -3.2414864723838352`}, \
{-2.3115035227760323`, -3.249566664207788}, {-2.1061782398813693`, \
-3.259327581058801}, {-1.9565482575606845`, -3.2645507931922215`}, \
{-1.8059272599340315`, -3.268044794504721}, {-1.6544916209690606`, \
-3.2696716829276915`}, {-1.6108696495447488`, -3.2695632183967986`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5899948721610782`, -3.2695113139811456`}, \
{-1.5024177146334232`, -3.269293556392527}, {-1.3497788298969018`, \
-3.266693118099938}, {-1.1967307237275726`, -3.2617165870351807`}, \
{-1.0435734720905314`, -3.254321334806469}, {-0.8906071509508747, \
-3.2444647330220153`}, {-0.7560503586343617, -3.2334486746184607`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.7352498100954575, -3.231693848710366}, \
{-0.5863619209432895, -3.21679809974975}, {-0.43570993996830093`, \
-3.1990274575624227`}, {-0.28648132450637337`, -3.178774527553075}, \
{-0.13907301883098794`, -3.1560453239936597`}, {
            0.0061698225068432255`, -3.1309266072658324`}, {
            0.09115358262848898, -3.1146941148745664`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.11165774172403142`, -3.110777677121856}, {
            0.14899267697042817`, -3.1036464434432327`}, {
            0.2891410220230746, -3.074432898599501}, {
            0.4950806373848151, -3.026943144824668}, {
            0.692957501734799, -2.9762929483803426`}, {
            0.8833119100424203, -2.923399742660572}, {
            0.9222993169596528, -2.9118721002134773`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9423174546979126, -2.905953216334043}, {
            1.0666841572770744`, -2.869180961059402}, {
            1.2114573176959793`, -2.824873397924947}, {
            1.3521124044214223`, -2.781186687628478}, {
            1.4890264426830957`, -2.738347991256985}, {
            1.61855485526064, -2.6941614183029055`}, {
            1.7384260335256554`, -2.654372035146328}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7582470284974614`, -2.6478232443471557`}, {
            1.870535812551036, -2.6108310861265527`}, {
            1.9920457941896572`, -2.5711194241868065`}, {
            2.1105687778238935`, -2.532710098346014}, {
            2.226854029622139, -2.4957374291089596`}, {
            2.3416508157527858`, -2.4603357369804297`}, {
            2.4549591362158356`, -2.426505021960424}, {
            2.55482493179008, -2.3976939991108592`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.574906878618476, -2.3919964672495913`}, {
            2.6881643088141676`, -2.3606605010078696`}, {
            2.808868691523998, -2.3289138111500405`}, {
            2.95935852079163, -2.2916864497118086`}, {
            3.1102173769519625`, -2.256972514165997}, {
            3.261445260004995, -2.2247720045126065`}, {
            3.387281422224596, -2.200129624339359}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.4077671555310833`, -2.1961179219847904`}, {
            3.4130421699507276`, -2.1950849207516363`}, {
            3.433308928211426, -2.191288728571541}, {
            3.4535955066949273`, -2.187531602447074}, {
            3.5955471791728257`, -2.1635367952036657`}, {
            3.7387793042841455`, -2.1412151122639513`}, {
            3.9139768589314725`, -2.1150854390359757`}, {
            4.091443710250649, -2.090949290392378}, {
            4.233574477270657, -2.0734394673737513`}}]}, 
          {Arrowheads[{{0.017972966347770267`, 1.}}], 
           ArrowBox[{{4.2542926905745695`, -2.0708870837074995`}, {
            4.271179858241678, -2.068806666333158}, {
            4.453185302904556, -2.0486575668583153`}, {
            4.637541388587028, -2.0301827117652884`}, {
            4.824329459636837, -2.0130628208515144`}, {
            5.001099999999999, -1.998335129345582}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.9980317838514834`}, {-4.829242324726744, 
            3.0145091253772516`}, {-4.642391827876302, 
            3.033038923372652}, {-4.454947803069432, 
            3.052098648740731}, {-4.2667869001566245`, 
            3.071638488497087}, {-4.170322881268784, 
            3.0817981736153723`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.149562862166001, 
            3.0839846391966903`}, {-4.07777482091502, 
            3.09154542613857}, {-3.8877581079934083`, 
            3.1115958390042238`}, {-3.6965833040405762`, 
            3.1315661044330905`}, {-3.50404279952156, 
            3.1513315397541786`}, {-3.31899144250056, 3.1697887333483985`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2982143773664045`, 
            3.1718062331428047`}, {-3.1142833506903727`, 
            3.189294065435212}, {-2.9168874569167746`, 
            3.206806454497326}, {-2.7174825435981953`, 
            3.222941808258596}, {-2.5159374146041813`, 
            3.2373695123534363`}, {-2.4660840592744564`, 
            3.2403842876587277`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4452472823018647`, 
            3.2416443472924947`}, {-2.312419923602452, 
            3.249676798432956}, {-2.10709792426073, 
            3.2594508981482653`}, {-1.9575065081606302`, 
            3.2646837686851997`}, {-1.8069242936964618`, 
            3.2681893673419413`}, {-1.655527295579309, 
            3.2698298043375305`}, {-1.6108700791626047`, 
            3.269723294191086}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5899952966229014`, 
            3.2696735065795037`}, {-1.503491528520255, 
            3.2694671898910066`}, {-1.3508899778409074`, 
            3.2668844323819086`}, {-1.1978780523744543`, 
            3.2619278016613764`}, {-1.0447554020993488`, 
            3.25455445015585}, {-0.8918216769940447, 
            3.2447215302917702`}, {-0.7560497675555663, 
            3.2336264331696642`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7352509900583861, 
            3.231852321801351}, {-0.5876332772952808, 
            3.2171072575452935`}, {-0.4370048791935298, 
            3.1993646900309076`}, {-0.2877963780171552, 
            3.1791405404818858`}, {-0.1404041939211974, 
            3.1564404160469195`}, {0.004826771607162439, 
            3.1313506613914246`}, {0.09115563569576504, 
            3.1148775140899367`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1116605065803809, 3.1109648046844987`}, {
            0.1476417747494959, 3.1040989118350826`}, {0.287786071687374, 
            3.0749128026975767`}, {0.4937044271924361, 3.0274664213336733`}, {
            0.6915697164693517, 2.976854902360105}, {0.88191975969502, 
            2.923995654244987}, {0.9223027941210181, 
            2.9120618156297833`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9423218020499207, 2.906145875600616}, {
            1.0652923770463412`, 2.8698060854564322`}, {1.2099818816662193`, 
            2.8255446477013346`}, {1.3505572316493557`, 
            2.7818994093582075`}, {1.4873940737230296`, 2.739097518868859}, {
            1.6168611561902155`, 2.694943207962468}, {1.7384390750862997`, 
            2.6545929908939385`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.7582615166246502`, 2.648048574152544}, {
            1.8687119113962611`, 2.611663262570924}, {1.9901564673169247`, 
            2.5719697569812485`}, {2.1086138087826822`, 
            2.5335738961289707`}, {2.2248315993131818`, 2.49661067029049}, {
            2.3395575024280713`, 2.461215069742207}, {2.452791518127351, 
            2.427387094484121}, {2.5548414483262687`, 2.3979249165841425`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.5749292363046843`, 2.392248048241003}, {
            2.6858518726673, 2.3615318903892675`}, {2.8064836132923765`, 
            2.329773138295933}, {2.956985425114626, 2.2925025982619807`}, {
            3.107849328240961, 2.257747634708776}, {3.2590753226713813`, 
            2.225508247636319}, {3.387300183909108, 2.200365562641578}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.4077849365484707`, 2.1963488557577873`}, {
            3.410663408405887, 2.195784437044609}, {3.430928324993792, 
            2.1919835220412147`}, {3.4512129787051533`, 2.188221714613945}, {
            3.5930848201567027`, 2.1642064349041292`}, {3.736233074539156, 
            2.141864848995463}, {3.911401570147766, 2.1157007780013677`}, {
            4.088837136036095, 2.0915329022203677`}, {4.233594163801335, 
            2.0736728048505726`}}]}, 
          {Arrowheads[{{0.017972493025987912`, 1.}}], 
           ArrowBox[{{4.25431191248049, 2.0711166525558964`}, {
            4.268539772204145, 2.069361221652463}, {4.450509478651915, 
            2.0491857362976527`}, {4.6348286696686305`, 2.030686808887918}, {
            4.82157975954352, 2.0135448021552396`}, {5.001099999999999, 
            1.998565958320977}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.3149429442965594`}, \
{-4.837670068147928, -2.3286065935773834`}, {-4.62809578546133, \
-2.346975578045569}, {-4.417689708835356, -2.366032046251684}, \
{-4.2060836388163825`, -2.385577311489001}, {-4.1694040691702545`, \
-2.389029914871777}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.148621095162427, -2.3909861909964927`}, \
{-3.993088576840436, -2.4056262782186417`}, {-3.778372163631821, \
-2.4260229779674503`}, {-3.6701861876523862`, -2.436209541440247}, \
{-3.5613511586693325`, -2.4463124146272817`}, {-3.451794171617509, \
-2.4562747230150364`}, {-3.3414423214317654`, -2.4660395920899925`}, \
{-3.317200497288171, -2.468122671927384}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2964022992538125`, -2.469909843830077}, \
{-3.2283487889481908`, -2.4757576255127454`}, {-3.114321336204424, \
-2.4852315585654154`}, {-2.9992695405631418`, -2.4943747154005838`}, \
{-2.883102979387019, -2.5031004201708313`}, {-2.7657304896384027`, \
-2.511357293966425}, {-2.647061500599902, -2.519065720327482}, \
{-2.52700647811459, -2.526096667081361}, {-2.463571296051752, \
-2.529345628232035}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.442723779660144, -2.5304133759493395`}, \
{-2.4054758880255402`, -2.5323211020554215`}, {-2.2823424802816827`, \
-2.5376540857225858`}, {-2.1575091775472637`, -2.541975404439326}, \
{-2.030931704738328, -2.5451031148583216`}, {-1.9025657867709225`, \
-2.5468552736322527`}, {-1.7722340854046132`, -2.5470755531896483`}, \
{-1.639865712924151, -2.5455871333383575`}, {-1.6080385377958473`, \
-2.5447789969223495`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.587170421876279, -2.5442491263215157`}, \
{-1.5055760700333567`, -2.542177331800042}, {-1.3694805574360505`, \
-2.5366334662963625`}, {-1.2535953642165858`, -2.5301400032602217`}, \
{-1.136386155212284, -2.521827440710142}, {-1.0180648405238153`, \
-2.5115938654680905`}, {-0.8988433302518534, -2.4993373643560344`}, \
{-0.7787905361008138, -2.4848624584322607`}, {-0.7549617431117551, \
-2.4815430443670423`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7342865408557588, -2.4786629338553055`}, \
{-0.6580897684921154, -2.468048521366}, {-0.5371245356019412, \
-2.448905918895637}, {-0.4162783456064734, -2.4274450167595534`}, \
{-0.29590322432115296`, -2.403537503163672}, {-0.1763763834500136, \
-2.377166008339884}, {-0.05811911000212683, -2.348507311065526}, {
            0.05844730901343501, -2.3177381901179355`}, {
            0.0829459474519103, -2.3107109990424046`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10301162993618924`, -2.304955357346966}, {
            0.17277102131554753`, -2.284945568894167}, {
            0.2844046268407283, -2.250288255095501}, {
            0.3930835169063714, -2.214050853955613}, {
            0.49854308282987064`, -2.176517970708179}, {
            0.6518967625765286, -2.1175288630155813`}, {
            0.7956745469181821, -2.0572948902693424`}, {
            0.8857906709713136, -2.016698921224516}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.90482343174837, -2.0081249465284072`}, {
            0.9306030488434603, -1.99651161374722}, {
            1.0574088813409948`, -1.9358745947269718`}, {
            1.2491956992768078`, -1.8397536052381518`}, {
            1.4198972344525127`, -1.7482115333160124`}, {
            1.5745051030474602`, -1.6625966459496666`}, {
            1.6453974014650934`, -1.6229883969271688`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.663620838185089, -1.6128067772623762`}, {
            1.7157924251612902`, -1.583657980355288}, {
            1.8465803136572527`, -1.511333233577218}, {
            1.9696898813985986`, -1.4455601026597997`}, {
            2.074383344923956, -1.392131570198439}, {
            2.1760384528332812`, -1.3433046875855867`}, {
            2.2887742690071, -1.2932013474095012`}, {
            2.400342084004932, -1.2480646657674812`}, {
            2.411772527916595, -1.2438949783476796`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4313833042594544`, -1.2367412047898627`}, {
            2.51170766456762, -1.2074398515555556`}, {
            2.623836777436005, -1.1708721136697535`}, {
            2.6388900992540507`, -1.1662509633126752`}, {
            2.653970425109799, -1.1616944462269134`}, {
            2.771595242165435, -1.1308268112650093`}, {
            2.8917766001400294`, -1.1030897257330556`}, {
            3.0725783506049673`, -1.0648789760178998`}, {
            3.240348998255886, -1.0355983514600267`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.260916832228309, -1.0320334250684038`}, {
            3.4547893502588405`, -1.0041091795427959`}, {
            3.65705919795501, -0.9799614780996172}, {
            3.8668952882038305`, -0.9592387061374491}, {
            3.9746346029963826`, -0.9497869279639842}, {
            4.0842614606048215`, -0.9410976969738319}, {
            4.090679495077615, -0.9406499796546463}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.111503729436204, -0.9391972965285824}, {
            4.264174005526156, -0.928547131432073}, {
            4.448599542132642, -0.9174607528999539}, {
            4.637413136122596, -0.9075370073075792}, {
            4.830489853194343, -0.8984743405850536}, {
            4.945218990883508, -0.8936522789646898}}]}, 
          {Arrowheads[{{0.0008396591211129234, 1.}}], 
           ArrowBox[{{4.966075419297203, -0.8927756840122896}, {
            5.001099999999999, -0.8913036021176809}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.315131608281671}, {-4.8386712193978125`, 
            2.3287090840269786`}, {-4.629056389983002, 
            2.347079174306251}, {-4.418610697823363, 
            2.366137606759052}, {-4.206965967959932, 
            2.3856857302992553`}, {-4.16940432996114, 2.389221405458068}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.1486213582120115`, 
            2.3911777055784746`}, {-3.993933268587014, 
            2.405738487934902}, {-3.7791802733763, 
            2.4261399473986995`}, {-3.6709763939746196`, 
            2.436329264066427}, {-3.5621237155849133`, 
            2.446435144691519}, {-3.45254932986432, 
            2.4564007187740837`}, {-3.3421803284699814`, 
            2.466169115814231}, {-3.3172009441521926`, 
            2.4683161019177784`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2964027836452825`, 
            2.470103710492097}, {-3.229077673769048, 
            2.4758903253055426`}, {-3.115041502801195, 
            2.4853677505861724`}, {-2.9999814033025807`, 
            2.4945147399291003`}, {-2.8838069630093623`, 
            2.5032446416073064`}, {-2.7664270430769418`, 
            2.5115060922641255`}, {-2.647751085925326, 
            2.519219497846608}, {-2.5276895511875805`, 
            2.526255860583308}, {-2.4635720088833954`, 
            2.529542712189137}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4427245413782916`, 
            2.5306114139762634`}, {-2.4061528984967717`, 
            2.532486182702779}, {-2.283013915977114, 
            2.537825555467652}, {-2.1581755289599043`, 
            2.5421537989132963`}, {-2.0315934028888303`, 2.5452890084273725`},
             {-1.9032232032075775`, 
            2.5470492793975428`}, {-1.7728876253332788`, 
            2.547278352244519}, {-1.6405157407043092`, 
            2.5457994513625724`}, {-1.608039355874127, 
            2.544977329350764}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.587171199273996, 
            2.5444490633206454`}, {-1.5062227787962268`, 
            2.5423998980997036`}, {-1.3701239690845892`, 
            2.536867013803914}, {-1.2543249354887234`, 
            2.5303891019196127`}, {-1.137203855787375, 
            2.5220956367558465`}, {-1.0189718217633557`, 
            2.51188481209691}, {-0.8998399251994768, 
            2.499654821727098}, {-0.779876619845031, 
            2.485210748712154}, {-0.7549627502017537, 2.4817449332435784`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7342870093329481, 
            2.4788686918746787`}, {-0.6592644698761277, 
            2.4684321646926617`}, {-0.5383857327158041, 
            2.4493289963151788`}, {-0.4176226657870975, 
            2.4279111702262615`}, {-0.2973255993391592, 
            2.404050351637903}, {-0.17787040536025125`, 
            2.377728814909748}, {-0.059677653882075576`, 
            2.3491224004098297`}, {0.05683208506366352, 2.318406948506181}, {
            0.08294651504919567, 2.310925553091551}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1030140843057529, 2.3051764932536774`}, {
            0.17110871840045472`, 2.2856683943382783`}, {0.2827057714876327, 
            2.251064597228442}, {0.3913581019472633, 2.2148792838189775`}, {
            0.496800567401412, 2.1773961807521864`}, {0.6500424088594071, 
            2.118516208867312}, {0.7937410227655013, 2.0583806593946217`}, {
            0.8858049368033781, 2.0169509266401873`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9048410788923131, 2.008384461835144}, {
            0.9286167918502087, 1.997685140128199}, {1.0553900988440443`, 
            1.9371252588621288`}, {1.2471068482582162`, 1.841124978458119}, {
            1.417774347016909, 1.7496650537119691`}, {1.5723590253992024`, 
            1.6641012410972842`}, {1.6454320653425507`, 
            1.6232794773897914`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.6636560210787446`, 1.6130987867348594`}, {
            1.7136200113379187`, 1.5851867386549554`}, {1.8443709369390164`, 
            1.5128645386168185`}, {1.9674254343084547`, 
            1.4470776332147088`}, {2.072072820122048, 1.393615333114357}, {
            2.1736625125948676`, 1.3447491200694093`}, {2.2864530388954547`, 
            1.2945328917054029`}, {2.398049708026419, 1.2492931650103813`}, {
            2.4118367700476595`, 1.2442525520463297`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4314423863584707`, 1.2370846490085217`}, {
            2.50942266372171, 1.208574702769655}, {2.621542049715276, 
            1.1719222677685348`}, {2.636592806349727, 1.1672904210449024`}, {
            2.6516703250033813`, 1.1627233544302549`}, {2.7692084867558644`, 
            1.1317959068578274`}, {2.8892912606101984`, 
            1.1040038335122988`}, {3.069934703749924, 1.0657173300377945`}, {
            3.2403961274520836`, 1.035878515557904}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.2609758502933235`, 1.032388928187811}, {
            3.451776680024642, 1.0048230275638712`}, {3.6538440902494846`, 
            0.9806246465248762}, {3.863469514220725, 0.9598578729187984}, {
            3.9711022836330585`, 0.9503860250157985}, {4.080621007049945, 
            0.9416782504992016}, {4.090732302561648, 0.940970685653897}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.111556220693405, 0.9395134764966252}, {
            4.260352223704052, 0.9291010797142025}, {4.4445943030386434`, 
            0.9179910452646156}, {4.633223728185104, 0.9080461090063779}, {
            4.826116982274822, 0.8989642327954265}, {4.945269861192634, 
            0.8939410393915149}}]}, 
          {Arrowheads[{{0.0008384467610530339, 1.}}], 
           ArrowBox[{{4.966126177794813, 0.8930617881897188}, {
            5.001099999999999, 0.8915873775451229}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.487296488299164}, \
{-4.928917900431168, -0.48882343721705734`}, {-4.787802247144116, \
-0.49192788405253135`}, {-4.646520803625163, -0.4951551071686621}, \
{-4.504751094284521, -0.49849492795289585`}, {-4.362170643532404, \
-0.5019371677926788}, {-4.21877945136881, -0.5054818266880111}, \
{-4.166334926796106, -0.5068082254711037}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145466758063188, -0.5073360120005505}, \
{-4.07457751779374, -0.5091289046388927}, {-3.924653329185088, \
-0.5129763081611444}, {-3.7729183126388537`, -0.5168962997663304}, \
{-3.61880571913968, -0.5208648335603688}, {-3.461748799672209, \
-0.5248578636491775}, {-3.3107435689194293`, -0.528585146460585}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2898747903023042`, -0.5290881070955855}, \
{-3.1349626434042692`, -0.5327394048184433}, {-3.0173767922992356`, \
-0.5353714817208313}, {-2.896162966294408, -0.5379063861525338}, \
{-2.748964285129909, -0.5406792736222659}, {-2.5938434951587674`, \
-0.5431561737013731}, {-2.4550358890762354`, -0.5448143484613838}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.434162536458604, -0.5450636983885541}, \
{-2.410733995035153, -0.5453435722164272}, {-2.2088452883147696`, \
-0.5466132683781804}, {-2.084264357793608, -0.5467171350599962}, \
{-1.9476685452750266`, -0.5461165111557189}, {-1.7939135408143108`, \
-0.5444289510549446}, {-1.6976389676886552`, -0.5427950010768164}, \
{-1.5992239456825685`, -0.5405795808277424}}]}, 
          {Arrowheads[{{0.017443242527457093`, 1.}}], 
           ArrowBox[{{-1.5783565733195857`, -0.5400256120791671}, \
{-1.4685576035032153`, -0.5368035515294526}, {-1.3892729066034295`, \
-0.5339824171811929}, {-1.300078164551968, -0.5302816529693424}, \
{-1.1966555488469817`, -0.5252166097398808}, {-1.1445861459732614`, \
-0.5223436681619441}, {-1.0872214611998232`, -0.5188871098597191}, \
{-1.0228902707079894`, -0.514609569432412}, {-0.9887287589954048, \
-0.5122284264701201}, {-0.9521212164676444, -0.5095307945025273}, \
{-0.9352768803178431, -0.5081642078296578}, {-0.9175093071019644, \
-0.506678717364786}, {-0.8872036455675822, -0.5041173317754052}, \
{-0.8684429959233639, -0.5025054297515363}, {-0.8598386151548851, \
-0.5017640091063493}, {-0.8547128014366253, -0.5013219213947365}, \
{-0.8512704762494355, -0.5010251757818441}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.0009903410551789689, 1.}}], 
           ArrowBox[{{0.8963690624149088, -0.3733793337537931}, {
            0.8924567476045491, -0.37432947565326496`}, {
            0.8824799012550578, -0.37676430818949014`}, {
            0.8708289169095967, -0.37962647687302115`}, {
            0.8614119016900603, -0.3819560861137894}, {
            0.8562176220943157, -0.3832476586028799}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.0010908773032368962`, 1.}}], 
           ArrowBox[{{0.8478846152146726, 0.43448237385571264`}, {
            0.8440736982134757, 0.43546592780980103`}, {0.8348973961321621, 
            0.4378404571522165}, {0.824742240612047, 0.4404749268633847}, {
            0.8150240485312271, 0.44300420855465955`}, {0.8080494744967108, 
            0.44482553216544884`}, {0.8038047819415314, 
            0.44593672729126965`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.014623039298189798`, 1.}}], 
           ArrowBox[{{0.993951164620277, 0.48864746188588615`}, {
            1.0622334941650857`, 0.4631434157637603}, {1.1546438372889913`, 
            0.42546658982818386`}, {1.185168403146419, 0.4123301043759822}, {
            1.2127175663718686`, 0.4001528783923122}, {1.2450156412830233`, 
            0.38526041995102694`}, {1.274359922308638, 0.3715114395683275}, {
            1.3284027474883926`, 0.34595766391025434`}, {1.3745841263742908`, 
            0.3238358801231603}, {1.4151977983424158`, 0.3043885857653071}, {
            1.4892788226317426`, 0.26966256053905785`}, {1.5520158499886674`, 
            0.24175024271345144`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.008984000616473536, 1.}}], ArrowBox[CompressedData["

1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAz+zCN28OrD9dkzow4HLwP4LZKHUL
JLY/YWmV8FZP8D/7D29AqQO3P+FarOSDS/A/wv+LD8RMuT+e2j6NiEHwP8SO
4FB/e7s/QskgyQA48D9Qw6GUlqm9P5fSEdJzLvA/py2Z1tltxT9i8BOM7+fv
P1fDcmoTK8s/9zDIRR6A7z9qSH5cRzjPPwjKzfhANe8/hk6o+obr0D9NhF5R
BgTvP71TM5gfrdE/Aq8jllrn7j+Hi/vF8inSPzasvLXF1O4/XdUcKKWV0j8i
d3MUpsTuP4Kzw+NR69I/NU3slbm37j+MIZCscUPTP/tZ/7dVqu4/v/bewvbH
0z/Pw/K4KJbuP1Xav6EPPdQ/uW1g3FuE7j9tt+2djJLUP+6axxhjd+4/UyXk
5bqc1T+RbXl3Gk/uPzOYwCTwEdc/XWlKiY0W7j8ezS5Cp3/YP7vs2Oeo3u0/
qhS+RrOa2T+3B/1TrLLtP/CMb2lojto/V+WT/iqM7T9UpcWL
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.836041936241341, -3.6018908447342923`}, \
{-4.704685154205492, -3.6156198016914955`}, {-4.573072678625806, \
-3.6296068715175003`}, {-4.441148820323924, -3.643871067339849}, \
{-4.308867635842084, -3.658408555171332}, {-4.176214855314453, \
-3.6731412479017926`}, {-4.0431762088752015`, -3.6879910584210744`}, \
{-4.005943121996848, -3.6921454542318877`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.9851970216232084`, -3.6944602639806616`}, \
{-3.9097374266585003`, -3.70287989961902}, {-3.7758842387985183`, \
-3.717729684385473}, {-3.641602375429426, -3.7324623256102765`}, \
{-3.506877566685394, -3.7469997361832736`}, {-3.3178764929921107`, \
-3.7668869691648164`}, {-3.1549558877636867`, -3.7833713280928665`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.134187085012665, -3.785472722195679}, \
{-3.1277861405695733`, -3.7861203718010223`}, {-2.936652894190573, \
-3.8044381568959658`}, {-2.7445231386279025`, -3.821578537253721}, \
{-2.551309169077846, -3.837260726736766}, {-2.357030552397897, \
-3.8512191383608547`}, {-2.3021047568616484`, -3.8545956063478055`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.281269246131019, -3.855876433221352}, \
{-2.1618945808526613`, -3.863214783659978}, {-1.9661085467067418`, \
-3.873008674168127}, {-1.769750759009179, -3.880243954873668}, \
{-1.5730027133814641`, -3.8846580640014667`}, {-1.4469321277570253`, \
-3.8856161297082634`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.4260578885944881`, -3.8857747622124124`}, \
{-1.3762264819468875`, -3.8861534529402615`}, {-1.1797841368287394`, \
-3.8846325730787914`}, {-0.9839887473318697, -3.879833943666161}, \
{-0.7891925850158807, -3.871627229663182}, {-0.5958165253861915, \
-3.860111601026153}, {-0.5916579782633378, -3.859791888530816}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5708445562549445, -3.8581917356672744`}, \
{-0.40428144394821725`, -3.845386227711373}, {-0.26991599625618057`, \
-3.832901302322793}, {-0.13711798860434987`, -3.818674691691509}, \
{-0.0058847169136022615`, -3.8028578819527343`}, {
            0.12378652289518527`, -3.785602359241684}, {
            0.2518984349011371, -3.7670596096935713`}, {
            0.25880814295775273`, -3.765985196885796}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.2794351132634168, -3.7627778426965266`}, {
            0.37845372318337805`, -3.7473811194436117`}, {
            0.503455091821031, -3.7267183746270196`}, {
            0.6269052448932182, -3.7052228613790086`}, {
            0.7359581687096801, -3.68549670963288}, {
            0.8436136325056999, -3.6654840334638252`}, {
            1.0549238958099187`, -3.6248598369874685`}, {
            1.1012951274258338`, -3.6156465078412023`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.1217697502133734`, -3.611578480482134}, {
            1.2612194663528835`, -3.5838717302110075`}, {
            1.4587938391801911`, -3.5374789499441084`}, {
            1.6530789612077759`, -3.4930688215519154`}, {
            1.84311625356812, -3.449337699381757}, {
            1.9362190882428427`, -3.4277634186049384`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.956555082211361, -3.42305105463358}, {
            2.0289057162612236`, -3.4062855834336316`}, {
            2.2104473492870866`, -3.3639124737075408`}, {
            2.38881002903111, -3.322693444627929}, {
            2.5650626318786927`, -3.2831035706192417`}, {
            2.739205157829835, -3.245142851681479}, {
            2.7708717497002415`, -3.2384551784471176`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.7912960842636116`, -3.234141759556064}, {
            2.911237606884537, -3.2088112878146413`}, {
            3.117496514560372, -3.167203947029228}, {
            3.323344372824618, -3.1281592726489857`}, {
            3.5287811816772745`, -3.091677264673914}, {
            3.611480931799343, -3.0779954664463007`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.6320758330091105`, -3.0745882580514294`}, {
            3.733806941118341, -3.057757923104013}, {
            3.89274048197786, -3.033171479020567}, {
            4.052202179598034, -3.0099622538029025`}, {
            4.222020431533322, -2.986741137720246}, {
            4.392836351974107, -2.9648443649872203`}, {
            4.458667800070261, -2.9569619103718976`}}]}, 
          {Arrowheads[{{0.012566834976493522`, 1.}}], 
           ArrowBox[{{4.479394591471493, -2.954480148276936}, {
            4.564649940920389, -2.944271935603825}, {
            4.737461198372167, -2.92502384957006}, {
            4.760661058559876, -2.922535877805995}, {
            4.783881995778758, -2.920068755196073}, {
            4.968142812430926, -2.9020503513515408`}, {
            5.001099999999999, -2.8990559439626287`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.013613567369012598`, 1.}}], 
           ArrowBox[{{0.9285951838753702, -0.3692885788354404}, {
            0.938994824135816, -0.3668327593621943}, {
            0.9522820691990637, -0.36369452715746386`}, {
            0.9668628865855227, -0.3602168800341159}, {
            1.0029234240082647`, -0.35123616761736454`}, {
            1.0332020923931282`, -0.3431947134822939}, {
            1.060209814383992, -0.3356897507233379}, {
            1.147717487170183, -0.30961514698529646`}, {
            1.180239612330437, -0.29929626788677294`}, {
            1.2090520054347196`, -0.28984109356586374`}, {
            1.2395406034687328`, -0.2793431534545357}, {
            1.267181393738525, -0.2696629343035426}, {
            1.3180319334741426`, -0.2516806590961721}, {
            1.3614172953017902`, -0.2361211479521704}, {
            1.3995591933484288`, -0.2224346575961309}, {
            1.4699999576826541`, -0.19764423129823097`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.020368891829957}, \
{-4.976436694823861, -4.0228803421202555`}, {-4.829059214430894, \
-4.038347284703185}, {-4.681398104397186, -4.054224818728006}, \
{-4.533429381419454, -4.0704375181327785`}, {-4.385129062194421, \
-4.0869099568555685`}, {-4.2364731634187995`, -4.10356670883444}, \
{-4.171037612316653, -4.1109509156629995`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.150294429089467, -4.113291722038927}, \
{-4.087355545597657, -4.120394187372131}, {-3.9376999442148435`, \
-4.137356318729683}, {-3.7875271884352477`, -4.154343946282608}, \
{-3.6368581074237656`, -4.171247913406418}, {-3.485713530345289, \
-4.1879590634766295`}, {-3.3341142863647124`, -4.204368239868754}, \
{-3.320443454048593, -4.205806786025977}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.29968323266813, -4.20799133017072}, \
{-3.1820812046469276`, -4.220366285958304}, {-3.0296351143568288`, \
-4.235844045120796}, {-2.8766506482944174`, -4.25064850451075}, \
{-2.7230556015742025`, -4.264642598999411}, {-2.5689505468328364`, \
-4.277741093537381}, {-2.468337994964531, -4.285631542179343}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.447527052130473, -4.287263621602573}, \
{-2.414436056706969, -4.289858753075258}, {-2.259612703833252, \
-4.300910342563642}, {-2.1045810608483366`, -4.310810626953132}, \
{-1.9494417003888744`, -4.319474371194329}, {-1.7942951950915171`, \
-4.32681634023783}, {-1.6219647969788342`, -4.333264174538001}, \
{-1.6138834110559523`, -4.333475620927791}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.593015710802616, -4.334021616370144}, \
{-1.4497884270052575`, -4.3377691037896815`}, {-1.2779364886989393`, \
-4.3402331198134165`}, {-1.1065908379311487`, -4.3405888634650225`}, \
{-0.9359443727467756, -4.338782566572958}, {-0.7661908115296955, \
-4.334794577090939}, {-0.75815086258723, -4.334500394551382}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.737289980647576, -4.333737092785373}, \
{-0.5975260403064423, -4.328623116166586}, {-0.4301432504962105, \
-4.320298890810231}, {-0.3968373156406178, -4.318381042542349}, \
{-0.3635915380050216, -4.316379597458816}, {-0.3304073199534328, \
-4.3142951394646385`}, {-0.31383077469849097`, -4.313232232614245}, \
{-0.2972700609646606, -4.312148767094854}, {-0.280725348208629, \
-4.311044825397278}, {-0.264196804444407, -4.309920492376812}, \
{-0.24768459584150881`, -4.30877585508315}, {-0.09614075593251017, \
-4.297055757478548}, {0.053520769244735256`, -4.283549675979084}, {
            0.09575705854583039, -4.279226197404091}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1165233850129995, -4.277100471658581}, {
            0.20134305284827664`, -4.268417985041217}, {
            0.3473691680361639, -4.251821059121403}, {
            0.49164218796644554`, -4.233919272676102}, {
            0.6342051857971697, -4.214873000161769}, {
            0.7751012346863864, -4.1948426160348635`}, {
            0.9143734077921446, -4.173988494751841}, {
            0.9444319042465921, -4.169326556774318}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9650601185646471, -4.166127213258132}, {
            1.0293111837763398`, -4.156162161231641}, {
            1.1430773576668058`, -4.138117459340298}, {
            1.255722275715665, -4.119907933427214}, {
            1.367296284175037, -4.101587127841797}, {
            1.477849729297044, -4.08320858693345}, {
            1.5874329573338075`, -4.064825855051579}, {
            1.7881216178897144`, -4.025917087648215}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8086248145697972`, -4.021996071476435}, {
            2.009485121684568, -3.9842565561332925`}, {
            2.2160995964078842`, -3.945446002616332}, {
            2.419437357815682, -3.907261217398129}, {
            2.6194984059079616`, -3.869702200478683}, {
            2.6292752262216403`, -3.8678945656354604`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.649802167223894, -3.8640993425885015`}, {
            2.8171939538920077`, -3.8331503002268215`}, {
            3.0134352149751056`, -3.797986865011371}, {
            3.2082221891572553`, -3.7642118948323313`}, {
            3.4015548764384573`, -3.7318253896897033`}, {
            3.472314298574508, -3.7203865231810673`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.4929216066622284`, -3.71705517536615}, {
            3.5505051194103956`, -3.707746307436757}, {
            3.699198965657666, -3.6845820061653063`}, {
            3.875899465818553, -3.658219347980524}, {
            4.052806810384762, -3.6330998475942016`}, {
            4.2299209993562945`, -3.6092235050063404`}, {
            4.319316574989556, -3.5978130899860172`}}]}, 
          {Arrowheads[{{0.015935041086002973`, 1.}}], 
           ArrowBox[{{4.340023421789029, -3.595170076457993}, {
            4.407242032733149, -3.5865903202169394`}, {
            4.430956781846697, -3.583648224610295}, {
            4.454680833885045, -3.580726977443443}, {
            4.627744861193768, -3.5607193431442723`}, {
            4.801471288650446, -3.541740259048856}, {
            4.9424249471054065`, -3.5266517923304272`}, {
            5.001099999999999, -3.5206277055569446`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.0008912116558057592, 1.}}], 
           ArrowBox[{{-0.8539049531539803, 
            0.3912518719862881}, {-0.8588296504414956, 
            0.3915749880837118}, {-0.8628070516292009, 
            0.3918360965998168}, {-0.8717168008198237, 
            0.3924214161628927}, {-0.8753761659003206, 
            0.3926619541210982}, {-0.8910326946494812, 
            0.3936914517993777}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.48440306629954216`}, {-4.885011559542864, 
            0.4868753487859364}, {-4.730133411084261, 
            0.4903101531857405}, {-4.574630067333233, 
            0.4938794114654887}, {-4.418501528289779, 
            0.4975831236251811}, {-4.2617477939539, 
            0.5014212896648176}, {-4.166332577770443, 
            0.5038135766907061}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145464293984184, 
            0.5043367943340896}, {-4.099799697918253, 
            0.5054817146631588}, {-3.936234154326547, 
            0.5096496545887015}, {-3.7704727929416855`, 
            0.5139018461669742}, {-3.601937243526574, 
            0.5182150261235055}, {-3.429641100130351, 
            0.5225454985365583}, {-3.3107373202423322`, 
            0.5254361502566749}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289868644293154, 
            0.5259434854657479}, {-3.2525979568021564`, 
            0.5268495674843956}, {-3.1311470129531025`, 
            0.5296898215924518}, {-3.006315234456163, 
            0.5324572616005655}, {-2.8424416702745146`, 
            0.5357831021671796}, {-2.669696404453633, 
            0.5388088155767742}, {-2.4790180800042156`, 
            0.5414104759923447}, {-2.455028660090682, 
            0.5416077370263187}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.434154523868377, 
            0.5417793815975241}, {-2.269434016752488, 
            0.543133851095641}, {-2.140173545940607, 
            0.5435120893431501}, {-1.9986995893254147`, 
            0.5432001045218937}, {-1.8397405808493064`, 
            0.5418171615064107}, {-1.7431824947917407`, 
            0.5404107050090018}, {-1.6363774979276973`, 
            0.5382861080006919}, {-1.5992176751891085`, 
            0.5373040747978097}}]}, 
          {Arrowheads[{{0.013579877084312526`, 1.}}], 
           ArrowBox[{{-1.5783501189692202`, 
            0.5367526019553502}, {-1.5151657633050981`, 
            0.5350828110200871}, {-1.4617434256888346`, 
            0.5334936829141956}, {-1.4045990363868615`, 
            0.5316010871693577}, {-1.3570540415128443`, 
            0.5296923773753501}, {-1.3058004185173864`, 
            0.5274446039152041}, {-1.1932475379403908`, 
            0.5219596511195769}, {-1.0531488284656962`, 
            0.5135223415345066}, {-1.0120425858397093`, 
            0.5107105738694732}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.7200504808007853}, {-4.944556462459822, 
            0.7217919274615174}, {-4.8074382089114165`, 
            0.7261695347040906}, {-4.670066209250511, 
            0.7307095506039406}, {-4.532440463477108, 
            0.7354119751610675}, {-4.394234166821568, 
            0.7402588595614724}, {-4.255120514514257, 
            0.7452322549911568}, {-4.16659084819753, 0.7484567212597505}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145729838743456, 
            0.7492165300799128}, {-4.115099506555174, 
            0.7503321614501203}, {-3.9741711429443183`, 
            0.7555585789383632}, {-3.825743845869835, 
            0.7611128746013813}, {-3.675359247084206, 
            0.7667424632267996}, {-3.522441894530929, 
            0.7724065415153829}, {-3.366416336153504, 
            0.778064306167896}, {-3.3113034137730226`, 0.7799842290119094}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.290441226762858, 
            0.7807109875956837}, {-3.2063193020628606`, 
            0.7836414728237924}, {-3.041187522369927, 
            0.7890637571225254}, {-2.9262528638760728`, 
            0.7926039220815937}, {-2.807776825534537, 
            0.7959695691812251}, {-2.5936636999663776`, 
            0.8011029466618144}, {-2.4800135011093403`, 
            0.8032308942941767}, {-2.455773840127, 0.8035798069127703}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4349011604645647`, 
            0.8038802542384731}, {-2.3607298565419925`, 
            0.8049478972180916}, {-2.2131192855106527`, 
            0.8062619244550169}, {-2.0525587719956406`, 
            0.8064647319735043}, {-1.8735630012496423`, 
            0.8049420253796603}, {-1.7604232789349399`, 
            0.8029523185382532}, {-1.6355366916198921`, 
            0.7996967298100884}, {-1.6000111686436946`, 
            0.79840086988619}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5791502005244706`, 
            0.797639927040182}, {-1.4941442779222784`, 
            0.7945391769550108}, {-1.4001073714554075`, 
            0.7902089911027453}, {-1.2948395152167766`, 
            0.7844091902437865}, {-1.1736751701171362`, 
            0.7763804844841184}, {-1.1139817943712516`, 
            0.7718878853647783}, {-1.048766130442031, 
            0.7665232878389837}, {-0.9765017135762488, 
            0.7599851184567895}, {-0.938380254612608, 
            0.7563767759268908}, {-0.8978913149406423, 
            0.7523443970186957}, {-0.8589404823361967, 
            0.7480398912972481}, {-0.8170883322394635, 
            0.7431555095469331}, {-0.7468529356750351, 
            0.7344396088607518}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6734486524390935`, -5.001099999999999}, {
            2.7387648760064764`, -4.99244677353232}, {
            2.858959595651036, -4.9765816259338065`}, {
            2.978634347297671, -4.9608438586738535`}, {
            3.097789130946381, -4.94523347175246}, {
            3.2164239465971662`, -4.929750465169628}, {
            3.3345387942500264`, -4.914394838925356}, {
            3.4521336739049615`, -4.899166593019643}, {
            3.5013905022913114`, -4.89281321864422}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.522093833565552, -4.890142806871625}, {
            3.5692085855619715`, -4.884065727452492}, {
            3.7242106648048936`, -4.864277115254747}, {
            3.87871456401199, -4.844902321643223}, {
            4.068408004459025, -4.821688420920289}, {
            4.257786736510067, -4.79920322627598}, {
            4.350869479796905, -4.788491756156855}}]}, 
          {Arrowheads[{{0.015164740904634207`, 1.}}], 
           ArrowBox[{{4.3716074651195855`, -4.7861053384142}, {
            4.446850760165117, -4.777446737710297}, {
            4.6356000754241755`, -4.75641895522324}, {
            4.660797823937468, -4.753658116979038}, {
            4.68599478523871, -4.750910847124476}, {
            4.865831534162349, -4.7320947277010506`}, {
            5.001099999999999, -4.718468830424541}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.582942542082662}, {-4.929414939372603, 
            4.590321633906745}, {-4.787913734127682, 
            4.605268762618512}, {-4.646154273927512, 
            4.620566696311135}, {-4.504122751968132, 
            4.6361597501573115`}, {-4.361756474650996, 
            4.652037469423153}, {-4.219010525393768, 
            4.668172952068074}, {-4.171051085289303, 4.673639669841491}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.150310548086815, 
            4.676003806351594}, {-4.075897762916807, 
            4.684485842304729}, {-3.9324310459404708`, 
            4.700895784345767}, {-3.7886232331851177`, 
            4.717322422403842}, {-3.644487183371107, 
            4.733685400691605}, {-3.5000357552187964`, 
            4.749904363421708}, {-3.355281807448543, 
            4.7658989548068025`}, {-3.320585855826872, 
            4.769648881797065}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2998318778190585`, 
            4.771891964884551}, {-3.210115096345504, 
            4.781588524990341}, {-3.064470142716726, 
            4.796892531050031}, {-2.9184269520654054`, 
            4.811730777599905}, {-2.7720655298947388`, 
            4.826023069253997}, {-2.625465881707922, 
            4.83968921062634}, {-2.478708013008151, 
            4.852649006330968}, {-2.4688510907298897`, 
            4.853466181659651}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.448047617776086, 
            4.85519086654291}, {-2.3318719292986234`, 
            4.864822260981913}, {-2.1850376360825354`, 
            4.87612877919321}, {-2.0255482681111467`, 
            4.887262489147317}, {-1.8662588997920069`, 
            4.897049511487739}, {-1.7072719916139292`, 
            4.905433601498235}, {-1.6148991181606658`, 
            4.909786775537137}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5940474178650121`, 
            4.910769435023636}, {-1.5475970921850437`, 
            4.912958458102483}, {-1.3886857250968845`, 
            4.918827281153711}, {-1.2302817391274168`, 
            4.923180682442527}, {-1.07238513427664, 
            4.92601866196893}, {-0.914995910544554, 
            4.92734121973292}, {-0.7593046305934038, 4.927137808528988}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.738431036873837, 
            4.926913730234018}, {-0.6025993990200955, 
            4.925392782576458}, {-0.44780705937363285`, 
            4.922109965806706}, {-0.2939519971376808, 
            4.917288083575938}, {-0.2553618086096799, 
            4.915833214075297}, {-0.2168448423969146, 
            4.914285102797183}, {-0.0998565400920346, 4.909054070273638}, {
            0.0163272101718083, 4.903090883774841}, {0.09598143947097786, 
            4.898468627826017}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.11682122328444879`, 4.897259315834029}, {
            0.13170640839461395`, 4.896395543300792}, {0.24628105457638227`, 
            4.888968048851491}, {0.3600511487171134, 4.880808400426939}, {
            0.4730166908168072, 4.871916598027134}, {0.585177680875464, 
            4.862292641652077}, {0.6965341188930834, 4.851936531301768}, {
            0.7227400414281668, 4.8494040908261065`}, {0.7488971217891548, 
            4.8468394524776715`}, {0.8039827538595938, 4.841201774683473}, {
            0.858848761595471, 4.835431488276611}, {0.9486623757786646, 
            4.825801018885162}}]}, 
          {Arrowheads[{{0.00010283168226107414`, 1.}}], 
           ArrowBox[{{0.9694182364986045, 4.823575424434093}, {
            0.9736869566478205, 4.823117701191225}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.694239093029094, 5.001099999999999}, {
            3.7976833125209977`, 4.988336070034479}, {3.9545859288890544`, 
            4.969304571931659}, {4.145398515706007, 4.946695962444756}, {
            4.33589284810508, 4.924770636316858}, {4.5235390044497095`, 
            4.903811177478482}}]}, 
          {Arrowheads[{{0.011001108434807063`, 1.}}], 
           ArrowBox[{{4.544291588539399, 4.901555352065736}, {
            4.715926749649591, 4.882969834138081}, {4.741276710486819, 
            4.880268164845903}, {4.766625588693948, 4.87757931802182}, {
            4.948994454311292, 4.858993858856028}, {5.001099999999999, 
            4.85387640790039}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.028403954551599, 4.722027052172247}, {
            1.155414457589207, 4.707205982997396}, {1.2813477897218954`, 
            4.692085781906119}, {1.4062460658011342`, 4.67672625674676}, {
            1.530151400678395, 4.6611872153676615`}, {1.653105909205148, 
            4.645528465617165}, {1.7715579055740265`, 4.624706212285065}, {
            1.8560001952399838`, 4.612273210167205}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8766523817511598`, 4.6092324508551625`}, {
            1.8913824115652007`, 4.607063650215121}, {2.010340320908809, 
            4.589420995470464}, {2.1284316336048508`, 4.5717782480510945`}, {
            2.245656349653327, 4.554135407957011}, {2.362014469054237, 
            4.536492475188216}, {2.477505991807581, 4.518849449744707}, {
            2.5921309179133587`, 4.501206331626485}, {2.70221936550489, 
            4.484132296731856}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.7228482045520956`, 4.480936984397951}, {
            2.8189993340311226`, 4.466047744348517}, {2.93167953174092, 
            4.448788129153993}, {3.043929840500963, 4.431784275249981}, {
            3.155750260311252, 4.415036182636482}, {3.2671407911717867`, 
            4.3985438513134945`}, {3.3781014330825667`, 4.382307281281018}, {
            3.4886321860435925`, 4.366326472539054}, {3.548699057689287, 
            4.357747480763003}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.569364192703144, 4.354796003210108}, {
            3.598733050054864, 4.350601425087602}, {3.7544971808021645`, 
            4.3287870751094255`}, {3.909909178209168, 4.307629106327702}, {
            4.093966567684757, 4.283415283338929}, {4.277998593019847, 
            4.260151993242929}, {4.3971826417587065`, 4.245699664589482}}]}, 
          {Arrowheads[{{0.01405403767590621, 1.}}], 
           ArrowBox[{{4.417905682499313, 4.243186776341004}, {
            4.462005254214439, 4.237839236039703}, {4.645986551268534, 
            4.21647701172925}, {4.670579621480966, 4.213684826652897}, {
            4.695177090864844, 4.210909274037111}, {4.875583004871282, 
            4.191590846924633}, {5.001099999999999, 4.178773412908419}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.889173417337377}, {-4.906891254686853, 
            4.898663762625979}, {-4.789027238845526, 
            4.910862085250042}, {-4.671003320289808, 
            4.923401522637578}, {-4.63964477387982, 
            4.926776238141285}, {-4.608272413182149, 
            4.930168009208565}, {-4.430462668636055, 
            4.949892985314845}, {-4.25217201927038, 
            4.96997345709268}, {-4.170968774488657, 4.979088483696294}}]}, 
          {Arrowheads[{{0.0042493477252818984`, 1.}}], 
           ArrowBox[{{-4.150224213777877, 
            4.981417051024697}, {-4.1145878084355445`, 
            4.985417221013293}, {-3.9767139347370137`, 
            5.000789541128734}, {-3.973910559639972, 5.001099999999999}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01963819870553472, 1.}}], 
           ArrowBox[{{1.6700896219754513`, -5.001099999999999}, {
            1.7137902147632573`, -4.995870818572981}, {
            1.9201081842135646`, -4.970238955001788}, {
            2.123773744457493, -4.943980472712131}, {
            2.324786895495042, -4.917095371704009}, {
            2.3508849597099712`, -4.913540678355314}, {
            2.3769447253960205`, -4.909983422102139}, {
            2.4831195819294045`, -4.895359051054693}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.7823215348651407, -2.2794518578562197`}, {
            0.8916826517099686, -2.236259796650213}, {
            0.9966244800580517, -2.1928428702298666`}, {
            1.0972434454958861`, -2.1498271426816022`}, {
            1.28551278764081, -2.0649992842013214`}, {
            1.4585388342025967`, -1.9831658909655356`}, {
            1.5453949803909945`, -1.941078010591332}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.5641805110528768`, -1.9319751065141897`}, {
            1.6183697412391043`, -1.9057166327304105`}, {
            1.8004364410375917`, -1.8172759604997364`}, {
            1.9702308699384616`, -1.736817328251543}, {
            2.131060728530067, -1.6641147594037617`}, {
            2.28623371740076, -1.598942277374325}, {
            2.323207684454337, -1.5845634578599495`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.342663124938739, -1.5769974245237774`}, {
            2.398382378442552, -1.5553287437342336`}, {
            2.50962910226938, -1.5152880083689277`}, {
            2.6328185174780363`, -1.4747172308217533`}, {
            2.756529859346533, -1.43788624533288}, {
            2.8813337832759665`, -1.4044735841188918`}, {
            3.0078009446674328`, -1.374157779396373}, {
            3.024825392832378, -1.3703105413537204`}, {
            3.0418872484980124`, -1.3665130000496966`}, {
            3.1439761628319998`, -1.3465724319163734`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.164463839527504, -1.3425706662427406`}, {
            3.1720677382386113`, -1.3410854309327471`}, {
            3.3048541381808856`, -1.3179984565513059`}, {
            3.4202780076973855`, -1.2988040024973022`}, {
            3.5378085212660406`, -1.2809908261532763`}, {
            3.657445678886851, -1.2645589275192284`}, {
            3.779189480559816, -1.2495083065951584`}, {
            3.903066401936018, -1.2356273683530041`}, {
            3.9911076018071703`, -1.2266002760383041`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.011873573482491, -1.2244710871631876`}, {
            4.029102918666538, -1.2227045177647033`}, {
            4.1572990307513775`, -1.210739754830256}, {
            4.287654738190535, -1.1997330795496621`}, {
            4.420263277772179, -1.1898665401040953`}, {
            4.55459630769669, -1.1801085301335712`}, {
            4.691014343544986, -1.1711629692719612`}, {
            4.829480090601798, -1.1629570382467962`}, {
            4.844477489408952, -1.162143985314602}}]}, 
          {Arrowheads[{{0.0032566777167161694`, 1.}}], 
           ArrowBox[{{4.865321722758884, -1.1610139583504318`}, {
            4.941488169599105, -1.1568847520970973`}, {
            5.001099999999999, -1.1538907057550913`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7800207294384336, 2.2805808553839833`}, {
            0.8894429209843109, 2.237414108474569}, {0.9944487580461416, 
            2.1940161558747935`}, {1.095131271121992, 2.151013521455746}, {
            1.283526325315751, 2.066194207159835}, {1.4566690746857687`, 
            1.9843506770449442`}, {1.54319421283844, 
            1.9424365762415858`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.5619808836514677`, 1.9333360254533587`}, {
            1.616600510352226, 1.9068774425691808`}, {1.7985674479946878`, 
            1.8184892033905937`}, {1.9682565900205384`, 1.738057001801439}, {
            2.1289678905956877`, 1.6653599263029968`}, {2.2840013038860456`, 
            1.6001770653965472`}, {2.3209493012850007`, 1.585788118836851}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.3404011424815354`, 1.5782128367331298`}, {
            2.39609746972831, 1.5565225819766473`}, {2.5072769709540785`, 
            1.516439968140276}, {2.63047650002467, 1.4757912289249622`}, {
            2.7541835377403436`, 1.4388886590780021`}, {2.8789712417748, 
            1.4054105235378973`}, {3.00541276980174, 1.3750350872431496`}, {
            3.022433049728184, 1.3711802900625338`}, {3.0394906064499567`, 
            1.3673752862672885`}, {3.141597316689138, 1.3473852456869453`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.1620832551596627`, 1.3433745911433514`}, {
            3.1695875889117073`, 1.3419054228988705`}, {3.3022840175818455`, 
            1.3187794074319046`}, {3.417621859185552, 1.2995535114828143`}, {
            3.5350629756397596`, 1.2817108749926804`}, {3.6546073669444676`, 
            1.2652514979615028`}, {3.7762550330996763`, 
            1.2501753803892817`}, {3.9000333603403643`, 
            1.2362707104888297`}, {3.9886911634906035`, 
            1.2271575509147872`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.009456591563899, 1.2250230669446107`}, {
            4.025969734901512, 1.22332567647296}, {4.154064156783117, 
            1.211340278341673}, {4.284316625985182, 1.200314516094968}, {
            4.416819699558028, 1.1904306806476712`}, {4.551048887549833, 
            1.1806557901491028`}, {4.687362077221841, 1.1716947028032563`}, {
            4.825722245753923, 1.1634745022442008`}, {4.842052067507323, 
            1.1625869991262376`}}]}, 
          {Arrowheads[{{0.0033148647070670367`, 1.}}], 
           ArrowBox[{{4.862896147794634, 1.1614541523306374`}, {
            4.937643424793734, 1.1573917417056019`}, {5.001099999999999, 
            1.154196598335383}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.3741293988813326, 
            3.3909502251453363`}, {-0.2554200080274358, 
            3.376047840272929}, {-0.11351567047602051`, 3.356208745182262}, {
            0.026280959312503904`, 3.334538667216146}, {0.16396988133813845`, 
            3.3110376063745814`}, {0.299551095600884, 3.2857055626575673`}, {
            0.449504834642544, 3.2553553051756516`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.46995690430871656`, 3.2511765862512454`}, {
            0.6308698591751125, 3.216169950351855}, {0.7900651754971366, 
            3.178994155781038}, {0.9449511148424348, 3.1402130355982485`}, {
            1.0956455242753627`, 3.1005722454957425`}, {1.2422662508602764`, 
            3.0608174411657783`}, {1.2802442656111745`, 
            3.0501954139417737`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3003476105731988`, 3.0445727325330485`}, {
            1.3848132945971763`, 3.0209486226083553`}, {1.523286655486063, 
            2.9809657898234745`}, {1.6852148075831834`, 2.933516453400325}, {
            1.8430753251500878`, 2.887403836655887}, {1.9968682081867757`, 
            2.842627939590161}, {2.1023037293013633`, 2.812038360676282}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.1223518602371474`, 2.8062218779875923`}, {
            2.1465934566932474`, 2.7991887622031464`}, {2.2933378165511327`, 
            2.757375963824335}, {2.4381880336420614`, 2.7174792037832187`}, {
            2.5811441079660336`, 2.679498482079797}, {2.722206039523049, 
            2.643433798714071}, {2.8932778558467387`, 2.6019043823182324`}, {
            2.9297176280379387`, 2.593627591646021}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.9500739727731387`, 2.5890039292548135`}, {
            3.0641191173566855`, 2.5631001507145066`}, {3.2347298240528897`, 
            2.527021103902894}, {3.4051099759353516`, 2.4936672418833936`}, {
            3.5525595551683518`, 2.4669174781313097`}, {3.7007770528335575`, 
            2.441901555707124}, {3.7698090537590447`, 2.4310763855519917`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.7904318722146892`, 2.4278424430924397`}, {
            3.860330888580919, 2.416881312954295}, {4.0212742549714635`, 
            2.393487881149814}, {4.183607152005191, 2.3717212602936812`}, {
            4.347329579682102, 2.3515814503858965`}, {4.369331916950954, 
            2.34899518759435}, {4.391362882061065, 2.3464337683775103`}, {
            4.563621746494552, 2.328234633874317}, {4.61867566567424, 
            2.322888459194123}}]}, 
          {Arrowheads[{{0.008699918342261019, 1.}}], 
           ArrowBox[{{4.639452773813194, 2.3208708362689032`}, {
            4.7376880765532485`, 2.3113314048163307`}, {4.848586479961216, 
            2.3008011064175284`}, {4.960204516288667, 2.2906785681894326`}, {
            5.001099999999999, 2.2871419935883357`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.2831445451523854, 
            2.977660410540555}, {-0.08617425052299943, 2.943192969269585}, {
            0.04392080632341197, 2.9175394886824235`}, {0.17154934754431367`, 
            2.890188885899393}, {0.29671137313970675`, 2.861141160920493}, {
            0.41940688310959134`, 2.8303963137457235`}, {0.5323472196065311, 
            2.8001259366278206`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.552510406731984, 2.794721779910058}, {
            0.5646441644696917, 2.7914696785442397`}, {0.7053088839224352, 
            2.751434144977177}, {0.841401041467821, 2.7102897130445354`}, {
            0.972920637105848, 2.6680363827463154`}, {1.1000413797585658`, 
            2.6253694342452376`}, {1.222936978348022, 2.582984147704024}, {
            1.3416074328742162`, 2.540880523122673}, {1.3471083950548024`, 
            2.5388702962835996`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3667151032432578`, 2.5317053804502545`}, {
            1.4560527433371484`, 2.4990585605011866`}, {1.5668559465226362`, 
            2.4579245442940723`}, {1.6746000792164981`, 
            2.4178847589558394`}, {1.7792851414187334`, 
            2.3789392044864877`}, {1.880911133129342, 2.3410878808860174`}, {
            2.0151595389400514`, 2.2917870173874952`}, {2.1464835113178036`, 
            2.2450384036039055`}, {2.150445517280366, 2.243674642803807}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.170183784536763, 2.2368805401698153`}, {
            2.2748830502625985`, 2.2008420395352486`}, {2.4003581557744367`, 
            2.159197925181525}, {2.524056648659571, 2.120013940857054}, {
            2.647126349724255, 2.083197966876158}, {2.7695672589684883`, 
            2.0487500032388355`}, {2.8913793763922713`, 
            2.0166700499450876`}, {2.969751718730132, 1.9974884566512154`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.9900280917443816`, 1.9925258240561923`}, {
            3.02176498888787, 1.9847582336632512`}, {3.152717484200567, 
            1.9551586957599523`}, {3.297319590180053, 1.9250825414251722`}, {
            3.443532904399313, 1.8972253007169966`}, {3.591357426858347, 
            1.8715869736354254`}, {3.740793157557154, 1.8481675601804584`}, {
            3.7608870361984885`, 1.8451837371081192`}, {3.781016751016542, 
            1.8422329225346765`}, {3.8103386807707915`, 1.838382760455378}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.8310358608521105`, 1.8356650846896498`}, {
            3.934325495793291, 1.8221024768064666`}, {4.089828852173475, 
            1.8035684717861922`}, {4.259593877293401, 1.7842244396474765`}, {
            4.4319585672629795`, 1.7663501224566056`}, {4.6069229220822105`, 
            1.7499455202135799`}, {4.661060933578156, 1.7453919788960037`}}]}, 
          {Arrowheads[{{0.007669753172274988, 1.}}], 
           ArrowBox[{{4.681862325745009, 1.743642376424883}, {
            4.784486941751093, 1.735010632918399}, {4.964565012905041, 
            1.7213021643167028`}, {5.001099999999999, 
            1.718754746366095}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.009265980178525791, 1.}}], 
           ArrowBox[{{0.6516440149333355, 0.8165743782395187}, {
            0.6710827852395809, 0.8095312007613619}, {0.6903155759075593, 
            0.8024571720605181}, {0.7675199226372105, 0.7732243813958757}, {
            0.803315458832861, 0.7591722009106321}, {0.8363275057221489, 
            0.7457641287048141}, {0.8696723108950566, 0.7313433178026935}, {
            0.9005802895860121, 0.7175776681026756}, {0.9581682227245616, 
            0.6912554077126659}, {1.0082358489165575`, 
            0.66716561056224}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3101910547679865, 2.0360613536138947`}, {
            0.41531540245515186`, 1.997479391877938}, {0.5169441192733454, 
            1.9576754271515462`}, {0.6609142788942259, 1.8969302076150372`}, {
            0.7949275897567635, 1.835533569369718}, {0.9195009733339717, 
            1.7740551778936262`}, {1.0351513510988648`, 
            1.7130646986648002`}, {1.0705648944534258`, 1.693344988932283}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.088802828719973, 1.6831893610060895`}, {
            1.1420389679495593`, 1.653545300755561}, {1.2406094100440896`, 
            1.596149350362803}, {1.4165785034162184`, 1.4880216367863224`}, {
            1.5149992793766225`, 1.4255341325119977`}, {1.6054512166479635`, 
            1.3671311171635356`}, {1.7690328202796513`, 
            1.2619761025891718`}, {1.798602368180458, 1.243727435909312}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.816366636730584, 1.232764325594936}, {
            1.9159745722349972`, 1.1712918938963968`}, {1.9851366145521734`, 
            1.1309021650061135`}, {2.052434597560475, 1.0934796091869305`}, {
            2.152258025162949, 1.0418712868655244`}, {2.2505667990904183`, 
            0.9958996754030268}, {2.447103791445436, 0.9184621394062176}, {
            2.460364712907746, 0.9138691340055405}, {2.473653732874049, 
            0.9093457588401812}, {2.561494539282707, 0.8831750274059641}, {
            2.570173158547147, 0.8808791898988308}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.5903538077692243`, 0.8755406112619981}, {
            2.6512344617911543`, 0.8594352741451762}, {2.8351902188406464`, 
            0.8161294425142347}, {3.0288041954061007`, 0.7803769107131056}, {
            3.233165625608559, 0.7507451893341786}, {3.3635110910379318`, 
            0.7352771388562641}, {3.4116493544929205`, 0.7303625373583363}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.432416249529895, 0.7282423733530133}, {
            3.4979788055673477`, 0.721548865673599}, {3.6366732088483325`, 
            0.7092630773558457}, {3.779698740532412, 0.6981224814726668}, {
            3.9269359412424754`, 0.6880129178995456}, {4.0781374092993365`, 
            0.6789248735438634}, {4.233215670901404, 0.6707180265231296}, {
            4.265220954237051, 0.6692139403313808}}]}, 
          {Arrowheads[{{0.017138907087664464`, 1.}}], 
           ArrowBox[{{4.286072782968517, 0.6682340100074153}, {
            4.392083252247088, 0.6632520549548532}, {4.554585361727586, 
            0.656453230591457}, {4.7205287404156895`, 0.6502858786910289}, {
            4.889768213532199, 0.6446667576295758}, {5.001099999999999, 
            0.6413381573697103}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.20671857644589986`, -2.0712884589947285`}, {
            0.31513015464376787`, -2.034111518957815}, {
            0.4203069025977648, -1.995380901611847}, {
            0.5219573369269099, -1.9554375355067692`}, {
            0.6657347547997017, -1.8945875843041224`}, {
            0.7995295981590081, -1.8331222176374218`}, {
            0.9238674560803093, -1.771606843598764}, {
            0.9742627464181469, -1.7449695884185465`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9927181271783072, -1.735214694985829}, {
            1.0392739176390853`, -1.7106068702802457`}, {
            1.145924783622363, -1.6511005152315177`}, {
            1.2442756854479324`, -1.593735748436187}, {
            1.4198589367124486`, -1.4857111265778433`}, {
            1.518100028498863, -1.4232893935272348`}, {
            1.6084029391498706`, -1.3649614055467294`}, {
            1.70623824751668, -1.3020842910692543`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.723799104085393, -1.2907982226014814`}, {
            1.7717704579414977`, -1.2599678367377103`}, {
            1.9185982373007096`, -1.169447333379877}, {
            1.9877361488520722`, -1.129137432411097}, {
            2.0550290310771127`, -1.091792361468459}, {
            2.154778797365247, -1.0403435798655012`}, {
            2.253050610833945, -0.9945142872818153}, {
            2.4495973591796685`, -0.9173160157327965}, {
            2.4628621609798818`, -0.9127371238701492}, {
            2.465346139186723, -0.9118944799293885}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.485224829702067, -0.9055354966027033}, {
            2.5641531749756044`, -0.8821066569933529}, {
            2.654065494509628, -0.8584147127149455}, {
            2.8383936358678334`, -0.8152000826471113}, {
            3.032431259704451, -0.7795298345952621}, {
            3.237259829026821, -0.7499715236098241}, {
            3.3029182742034813`, -0.742218166959771}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.3236490776986862`, -0.739770145038021}, {
            3.367848354119009, -0.7345508201996243}, {
            3.5025676607086083`, -0.7208653407114624}, {
            3.641520050539141, -0.7086183047413086}, {
            3.7848078253541315`, -0.697512931885133}, {
            3.9323105604111097`, -0.6874353607760387}, {
            4.083780558689896, -0.6783762552112053}, {
            4.155959410352588, -0.6745753296527378}}]}, 
          {Arrowheads[{{0.019759390078989154`, 1.}}], 
           ArrowBox[{{4.176805368760376, -0.6734775851711106}, {
            4.239129213517449, -0.6701956225327167}, {
            4.398267918220727, -0.6627534700826573}, {
            4.561041380408326, -0.6559762851857558}, {
            4.727256201564064, -0.6498285437282524}, {
            4.896766615827734, -0.644227235894498}, {
            5.001099999999999, -0.6411225673084427}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.2567058574142262`}, {-4.915043926959731, 
            1.2611037344645029`}, {-4.714775669405216, 
            1.2719136897270245`}, {-4.604034574980354, 
            1.278112026575437}, {-4.4929515843511085`, 
            1.2844532114305993`}, {-4.381526697517479, 
            1.2909372442925109`}, {-4.269759914479467, 
            1.297564125161172}, {-4.167433372263004, 1.303707479495671}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.146596304369216, 
            1.3049627125438201`}, {-4.044431695084265, 
            1.3111362502645756`}, {-3.9306780175505693`, 
            1.3180539493357768`}, {-3.816197961459478, 
            1.325059406086644}, {-3.7006615190652274`, 
            1.332099113309789}, {-3.5837386826220556`, 
            1.3391195637978235`}, {-3.465429452129964, 
            1.3461207575507472`}, {-3.3457338275889508`, 
            1.3531026945685605`}, {-3.313100707549506, 
            1.3549484040187318`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2922591746853462`, 
            1.3561271884597212`}, {-3.211972347754022, 
            1.3606681626298989`}, {-3.075513234166926, 
            1.3680272299524592`}, {-2.9357680944094664`, 
            1.3750649925145806`}, {-2.792148536063447, 
            1.3816665462946027`}, {-2.6437228041478336`, 
            1.3876351243604812`}, {-2.489559143681593, 
            1.3927739597801718`}, {-2.458137683477254, 
            1.3936150317612181`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4372703159156455`, 
            1.3941735977241023`}, {-2.3901699564902676`, 
            1.3954343536645415`}, {-2.287606694804576, 
            1.397556091823708}, {-2.1693421651942733`, 
            1.3992575105523446`}, {-2.0457217893114032`, 
            1.3999409889681043`}, {-1.8785128849732904`, 
            1.3988679404858142`}, {-1.6977835607450638`, 
            1.3948531031677625`}, {-1.6024598705521163`, 
            1.3908921786721269`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.581603026574708, 
            1.3900255275380327`}, {-1.4990839437092478`, 
            1.3865966647231587`}, {-1.391344532386576, 
            1.3803969754156693`}, {-1.276225486008738, 
            1.3721874081307062`}, {-1.1184329524556262`, 
            1.357846377353369}, {-0.9421712986555204, 
            1.3377230663313777`}, {-0.7508777326482434, 
            1.3104724072409628`}}]}, 
          {Arrowheads[{{0.01503388416570603, 1.}}], 
           ArrowBox[{{-0.7302564863087685, 
            1.3072396075871497`}, {-0.5977215551537184, 
            1.2848513796546326`}, {-0.43897333149675266`, 
            1.25408202772337}, {-0.26409446817986737`, 
            1.215299552785409}, {-0.22885535569259732`, 
            1.2069902412738034`}, {-0.19308347738316084`, 
            1.198344422691214}, {-0.15484892326458666`, 
            1.1886355424975839`}, {-0.11617531295815298`, 
            1.178571293053601}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.6371258291272244`}, \
{-4.801044074962794, -1.6503792290644672`}, {-4.597347217458928, \
-1.6645698045409807`}, {-4.392723542004085, -1.6793425654058958`}, \
{-4.1866165360392795`, -1.6945591955641512`}, {-4.168183708742296, \
-1.6959400120305776`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.14736719227567, -1.6974993923821453`}, \
{-3.994560255439117, -1.7089462708869219`}, {-3.800534455822586, \
-1.723553532209754}, {-3.604024923082748, -1.7382518974071268`}, \
{-3.4043065984378216`, -1.7528347538533444`}, {-3.314650761653059, \
-1.759110795923976}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.293826878075122, -1.7605684987807662`}, \
{-3.200622718859432, -1.767092928704942}, {-2.9918582404627116`, \
-1.7806673085536415`}, {-2.8853261592405106`, -1.7871382469609498`}, \
{-2.777230387353368, -1.7933664425483875`}, {-2.667127803390961, \
-1.7991691623985557`}, {-2.5545752859429696`, -1.8043636735940551`}, \
{-2.460216702164968, -1.8079023897020956`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.439356524641981, -1.808684705875798}, \
{-2.4212958922102983`, -1.8093620311211382`}, {-2.2843624421206017`, \
-1.8134230223425019`}, {-2.1427886348313914`, -1.8161138704187982`}, \
{-1.9960265254301746`, -1.8171941437726122`}, {-1.843136331531103, \
-1.8161946504474311`}, {-1.6831782707483292`, -1.8126461984867424`}, \
{-1.606034563723108, -1.8099748621962544`}, {-1.6045555647989356`, \
-1.8099102268129932`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5837006285468267`, -1.8089988219596764`}, \
{-1.526956203673294, -1.8065189704941427`}, {-1.3448359401724346`, \
-1.7958134317348944`}, {-1.1508209161202212`, -1.7795646896257757`}, \
{-1.0205570450742192`, -1.7656463046042976`}, {-0.8842686298900754, \
-1.7482824724610713`}, {-0.7530711400879111, -1.7285656124251363`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7324639946755106, -1.725243040945636}, \
{-0.5918554931114852, -1.7005513592461818`}, {-0.4352368698509514, \
-1.6685473018750137`}, {-0.27306739800877744`, -1.6304068512502208`}, \
{-0.06528704032154974, -1.5735057284529694`}, {
            0.038933885084708145`, -1.5413937406803662`}, {
            0.07812166736890164, -1.528362345949368}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.09793000727941364, -1.5217753363945103`}, {
            0.14214825542729834`, -1.5070711247157407`}, {
            0.34135420253821713`, -1.433350856647707}, {
            0.3791735940941275, -1.418342875805659}, {
            0.4163289002519364, -1.4032066776798497`}, {
            0.46003147472212724`, -1.3843825961558751`}, {
            0.5025857506595217, -1.3655081984216944`}, {
            0.6875586085217683, -1.278287733147629}, {
            0.845190452388211, -1.1946075266703933`}, {
            0.8607698411081908, -1.1854546250902063`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.8787683570865424, -1.1748804845831395`}, {
            0.977643263028854, -1.1167914093885771`}, {
            1.1398880725952745`, -1.0116404582928644`}, {
            1.2671540418341996`, -0.9210555664275067}, {
            1.3702090379475782`, -0.8430483713363347}, {
            1.4836439586577643`, -0.753171752628612}, {
            1.5595572273155722`, -0.6931234017373233}}]}, 
          {Arrowheads[{{0.00006990321890039805, 1.}}], 
           ArrowBox[{{1.575929270096544, -0.6801729098522943}, {
            1.5782181870772738`, -0.6783623477140802}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.37296988001664283`, -3.3906309589295494`}, \
{-0.2542925419271313, -3.3757156953038208`}, {-0.11220344915986638`, \
-3.3558293847478406`}, {0.027769648209638897`, -3.3341084353494455`}, {
            0.16562675018138373`, -3.310552847108635}, {
            0.30136785675536876`, -3.2851626200254103`}, {
            0.4506447247771742, -3.2549177221115713`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.47109777319316765`, -3.250743544873186}, {
            0.6325284632132395, -3.215592710335477}, {
            0.7916449957457048, -3.178406893539151}, {
            0.9464523478138549, -3.139620502108586}, {
            1.0970698493043767`, -3.0999784368452667`}, {
            1.2436168301039545`, -3.060225598550679}, {
            1.281361341639682, -3.049665029201909}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3014641545616066`, -3.044040445882917}, {
            1.3860932902125884`, -3.0203619872248226`}, {
            1.5244992296302793`, -2.980387602867697}, {
            1.6864657880679423`, -2.932917880786282}, {
            1.8443650735551027`, -2.8867887986497838`}, {
            1.9981970860917602`, -2.8420003564582026`}, {
            2.103411838513997, -2.8114768182121166`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.123460070914581, -2.8056606852615786`}, {
            2.147961825677915, -2.798552554211538}, {
            2.2947474183577037`, -2.756734404973996}, {
            2.4396419901752635`, -2.716834921809782}, {
            2.582645541130594, -2.6788541047188956`}, {
            2.723758071223695, -2.642791953701338}, {
            2.895027581998277, -2.60123731380174}, {
            2.93083691897689, -2.5931093278339383`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.951193952336862, -2.5884886982591784`}, {
            3.066072491949524, -2.5624136229644057`}, {
            3.2368928010774356`, -2.5263208811893354`}, {
            3.407488509382012, -2.4929590884765287`}, {
            3.555011676757854, -2.4662270596331437`}, {
            3.7033071039603906`, -2.441228867565415}, {
            3.7709435100028377`, -2.4306360939380935`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.7915669603157096`, -2.4274061834008385`}, {
            3.862875424031853, -2.416238316004349}, {
            4.023835577842062, -2.3928727254867406`}, {
            4.186187565391018, -2.371132096012591}, {
            4.349931386678721, -2.3510164275818997`}, {
            4.371936876302858, -2.348433255740324}, {
            4.393971016678315, -2.3458748971298076`}, {
            4.566314631842241, -2.3276917351019772`}, {
            4.619817540972448, -2.3225034156923585`}}]}, 
          {Arrowheads[{{0.008672393903707649, 1.}}], 
           ArrowBox[{{4.6405949193952996`, -2.320488578041383}, {
            4.740467650069487, -2.310803653698531}, {
            4.851411791063214, -2.3002837138898578`}, {
            4.963075880560234, -2.290171176042796}, {
            5.001099999999999, -2.2868875313842327`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.28217510382255073`, -2.977277929053801}, \
{-0.08525928098346935, -2.9427904664515276`}, {
            0.04500099276443928, -2.9170836023089697`}, {
            0.17278530408698134`, -2.8896765868771332`}, {
            0.29809365298415696`, -2.8605694201560183`}, {
            0.4209260394559649, -2.8297621021456254`}, {
            0.5332895097847585, -2.799619557653979}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.5534514948312393, -2.7942109179107852`}, {
            0.5661471679351342, -2.790805185689577}, {
            0.7067922213116029, -2.7507431632822175`}, {
            0.8428611995853704, -2.709576034923548}, {
            0.9743541027564362, -2.667303800613568}, {
            1.1014465035516767`, -2.6246216504299555`}, {
            1.2243139746979672`, -2.5822247744503897`}, {
            1.342956516195308, -2.540113172674869}, {
            1.348018502128361, -2.538262720822416}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3676244099197676`, -2.5310956150912975`}, {
            1.4573741280437, -2.498286845103394}, {
            1.5681509257236457`, -2.4571514390348463`}, {
            1.6758710247156485`, -2.4171126017681064`}, {
            1.7805344250197088`, -2.3781703333031747`}, {
            1.8821411266358268`, -2.340324633640051}, {
            2.0165268456667507`, -2.290976619676125}, {
            2.1479881606362627`, -2.244188767745722}, {
            2.151343520945686, -2.243034236847095}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.171082542297428, -2.236242325410567}, {
            2.276525071544363, -2.1999610778488408`}, {
            2.4021375783910512`, -2.158293549985482}, {
            2.5259765488726016`, -2.119092655097825}, {
            2.6491928506852873`, -2.082264864128049}, {
            2.7717864838291093`, -2.047810177076154}, {
            2.8937574483040667`, -2.015728593942139}, {
            2.9706737922265285`, -1.9969301048077412`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.9909517925975546`, -1.9919741260104868`}, {
            3.0242117653463643`, -1.9838453304327983`}, {
            3.1552404577556326`, -1.9542741255442304`}, {
            3.2998558509302747`, -1.9242437238284775`}, {
            3.4460871115105003`, -1.8964290145189897`}, {
            3.59393423949631, -1.8708299976157665`}, {
            3.743397234887704, -1.8474466731188086`}, {
            3.7634952031416176`, -1.8444674418177933`}, {
            3.7836290549691514`, -1.841521167612456}, {
            3.8112757455007067`, -1.837897457952359}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.8319735514816946`, -1.835184553151312}, {
            3.937023992740666, -1.8214153716880517`}, {
            4.092616539209764, -1.8029044456202796`}, {
            4.262478082750173, -1.7835847184397413`}, {
            4.434941355087658, -1.765733039993055}, {
            4.610006356222221, -1.749349410280221}, {
            4.662006921663948, -1.7449838284681543`}}]}, 
          {Arrowheads[{{0.007647006194172149, 1.}}], 
           ArrowBox[{{4.682808586843078, -1.7432374749353552`}, {
            4.787673086153861, -1.734433829301239}, {
            4.967855187144863, -1.7207432306008035`}, {
            5.001099999999999, -1.7184295829048355`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.002912551452294407, 1.}}], 
           ArrowBox[{{0.7498191833201883, -0.6420288264485062}, {
            0.75353607301208, -0.6408148530749083}, {
            0.7570336816402832, -0.6396733345257959}, {
            0.7635501031586325, -0.6375482661778594}, {
            0.774781167542156, -0.6338873866193128}, {
            0.7817663121553777, -0.6316107159835997}, {
            0.7899440669744774, -0.6289432667528754}, {
            0.8053484569105185, -0.6238356465253463}, {
            0.8225303781884918, -0.6180112969555525}, {
            0.8651155982781286, -0.6034002090171852}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.399513618552235, -0.31004228838201936`}, {
            2.566219277568379, -0.2849772466274437}, {
            2.577908869725846, -0.28350291445759657`}, {
            2.5896699413921485`, -0.28205250838925705`}, {
            2.7102494593629363`, -0.27032133225815436`}, {
            2.8382139957997428`, -0.26024415205151064`}, {
            3.0132552297800306`, -0.24802877260907336`}, {
            3.201099683837545, -0.23794330378850587`}, {
            3.23076441947046, -0.2367102130319753}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.2516212502946553`, -0.2358432454102817}, {
            3.4015563802919275`, -0.22961080750263665`}, {
            3.6144343414628186`, -0.22265434566429426`}, {
            3.7253954126668156`, -0.2196332438032075}, {
            3.83919003274966, -0.21683838283452628`}, {
            3.955818201711353, -0.21426976275825055`}, {
            4.075279919551893, -0.21192738357438035`}, {
            4.0862435069986365`, -0.2117383483452795}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.107115246663536, -0.21137847580278796`}, {
            4.278154425393425, -0.2084294018346653}, {
            4.487468278725156, -0.20529958352632996`}, {
            4.703221479547085, -0.20253792864937434`}, {
            4.813512835266875, -0.2012951624976639}, {
            4.925414027859213, -0.2001444372037984}, {
            4.942028757012426, -0.19998619736109413`}}]}, 
          {Arrowheads[{{0.0009149549560164414, 1.}}], 
           ArrowBox[{{4.962902652233048, -0.19978739292282272`}, {
            5.001099999999999, -0.19942359871067372`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.24791464095957536`}, {-4.95968638338491, 
            0.24836224149264222`}, {-4.846994734151946, 
            0.24962014918948816`}, {-4.734217203028388, 
            0.2509189155638369}, {-4.621205599901883, 
            0.252256467739233}, {-4.507811734660075, 
            0.2536307328392211}, {-4.394035607302966, 
            0.2550417108638012}, {-4.279877217830554, 
            0.2564894018129732}, {-4.166166854939866, 
            0.25795495912976174`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145293780902452, 
            0.2582266293800629}, {-4.0493343022053825`, 
            0.25947625221795306`}, {-3.932679938469012, 
            0.26101074410697583`}, {-3.815103637450119, 
            0.2625726137870205}, {-3.6753491215407443`, 
            0.2644356708489546}, {-3.533280770250393, 
            0.266316019246855}, {-3.4209766835529596`, 
            0.26777777624788707`}, {-3.310372053963637, 
            0.26918678673993335`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2894988172440653`, 
            0.26944563552412565`}, {-3.18962566217421, 
            0.2706766756673607}, {-3.0696182227378688`, 
            0.27209160953749606`}, {-2.878655627542849, 
            0.27416548218135517`}, {-2.675281565939869, 
            0.27604284120366435`}, {-2.567180694940624, 
            0.27685980325386617`}, {-2.4545462218278424`, 
            0.2775542379846658}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433671701576718, 
            0.2776700866308659}, {-2.4132289330868617`, 
            0.27778290945816636`}, {-2.3720528651682824`, 
            0.2779857835878891}, {-2.2827666475819974`, 
            0.2782379248806023}, {-2.1878469268952347`, 
            0.27834269876603024`}, {-1.9819397888416528`, 
            0.27809200998916017`}, {-1.863311016619052, 
            0.2774859938555416}, {-1.7293995346848885`, 
            0.276378870779282}, {-1.6554015084712093`, 
            0.27558403415745447`}, {-1.5986946786782208`, 
            0.27483984583077464`}}]}, 
          {Arrowheads[{{0.013426190203817998`, 1.}}], 
           ArrowBox[{{-1.5778216341129794`, 
            0.2745659198122611}, {-1.574058671327319, 
            0.2745165368192593}, {-1.4829287297524731`, 
            0.2730630008436234}, {-1.2666823544904529`, 
            0.2683287188387711}, {-1.197933665130069, 
            0.26642647227505806`}, {-1.1180724339764465`, 
            0.2638937613962204}, {-1.0174847377053649`, 
            0.2600844762218736}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.25142629770161234`}, \
{-4.992895177832986, -0.25151546517075335`}, {-4.883394253512786, \
-0.2527429012267497}, {-4.773775562743389, -0.25400903101679134`}, \
{-4.664039105524796, -0.2553138545408783}, {-4.554036400034476, \
-0.25665517563088214`}, {-4.4436189644498985`, -0.2580307981186744}, \
{-4.332786798771065, -0.2594407220042552}, {-4.221539902997974, \
-0.26088494728762446`}, {-4.166168643466348, -0.26161399316089223`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145295610716287, -0.26188881801620045`}, \
{-4.109610161355847, -0.2623586706042037}, {-3.9967294580699027`, \
-0.26385708858941437`}, {-3.882897793140141, -0.2653802012432565}, \
{-3.7681151665665626`, -0.2669280085657301}, {-3.6298973646970727`, \
-0.2687939905747559}, {-3.48927144531368, -0.27067337125833296`}, \
{-3.3668841417942255`, -0.27227401185246475`}, {-3.3103757845363253`, \
-0.27299255432860253`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2895026300313366`, -0.27325797078823116`}, \
{-3.241831803330931, -0.2738641380087808}, {-3.1134190945430897`, \
-0.27542709934369697`}, {-2.9809506800499954`, -0.27694624547362917`}, \
{-2.798852276703166, -0.27883682522643394`}, {-2.604353188670785, \
-0.2805097210968357}, {-2.45455078711999, -0.28141740409182237`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433676328395313, -0.2815438866516331}, \
{-2.3916302604723017`, -0.28179865226596695`}, {-2.3503594002811554`, \
-0.28199112989279984`}, {-2.308130465621736, -0.28216025836442904`}, \
{-2.2227565579794337`, -0.28231228996645047`}, {-2.131894400632205, \
-0.2823136093349946}, {-1.9345985149419487`, -0.2818502558474814}, \
{-1.820822862208684, -0.2811351930005596}, {-1.692363360694946, \
-0.279919350171909}, {-1.6213904379355186`, -0.27907136881785255`}, \
{-1.5987002868370717`, -0.278746206060751}}]}, 
          {Arrowheads[{{0.015015704265798943`, 1.}}], 
           ArrowBox[{{-1.5778275880770138`, -0.27844708842828025`}, \
{-1.5434309930177341`, -0.2779541656779709}, {-1.4562152248787377`, \
-0.27645823139185904`}, {-1.2455270882997242`, -0.2715760936903751}, \
{-1.1785863241907206`, -0.2696308318715995}, {-1.1009038516665761`, \
-0.26705218116181434`}, {-1.0054684342374653`, -0.2633102366210913}, \
{-0.9866854169187893, -0.2625045879572558}, {-0.9738855051572785, \
-0.2619520322364862}, {-0.966045335341045, -0.26161283777591143`}, \
{-0.9601936775782302, -0.2613594460956261}, {-0.9546810096584205, \
-0.26112060220061634`}, {-0.9511944300480598, -0.2609694950004848}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.7187662265894998}, \
{-4.908329442206096, -0.7216560636510817}, {-4.794374959199027, \
-0.7253168321588686}, {-4.680302297715134, -0.7290923263392158}, \
{-4.565957182955568, -0.7329746718075628}, {-4.4511853401214845`, \
-0.7369559941793484}, {-4.335986769212883, -0.7410362934545728}, \
{-4.220361470229762, -0.7452155696332358}, {-4.166591304021445, \
-0.74718533084621}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145730454784142, -0.7479495258375021}, \
{-4.104033557482698, -0.7494770072793029}, {-3.9867271452822624`, \
-0.7538037909567398}, {-3.8684422336284565`, -0.7581959206655464}, \
{-3.74917882252128, -0.7626533964057229}, {-3.6112834724193115`, \
-0.7678038209743471}, {-3.4711369486424375`, -0.7729729980418262}, \
{-3.3113027137697033`, -0.778683068050111}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2904411801079796`, -0.7794283452917701}, \
{-3.2683166848516234`, -0.7802187417729266}, {-3.0578765240735537`, \
-0.7872643880223988}, {-2.850846482589509, -0.7934845596086865}, \
{-2.7427248051409925`, -0.7963533082117209}, {-2.6307738330010775`, \
-0.7989940879315034}, {-2.5140354499595667`, -0.8013163800907847}, \
{-2.4557723485614362`, -0.8022264912352626}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.434900052982761, -0.8025525313594774}, \
{-2.391551539806263, -0.8032296660123152}, {-2.3518495268972095`, \
-0.8037708587137676}, {-2.311413967588559, -0.8042552174294288}, \
{-2.2005357484240373`, -0.8048152776022629}, {-2.1129223875843866`, \
-0.8048632065916723}, {-2.020118456956675, -0.8044362843537542}, \
{-1.8203286488212338`, -0.8021821375558189}, {-1.7072189870434658`, \
-0.7996791281885983}, {-1.60001174025396, -0.7963826386354617}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5791480385679173`, -0.7957066020792045}, \
{-1.388253050155838, -0.7874096772403512}, {-1.2094567504693476`, \
-0.7766251720540165}, {-1.0486194394699389`, -0.7641204160981963}, \
{-0.9014207218956112, -0.7499918917702593}, {-0.8588429951660606, \
-0.7454179223434906}, {-0.8128964785564827, -0.7401828337610594}, \
{-0.7625257513043018, -0.734062951018796}, {-0.7468608409088127, \
-0.7320660009427996}}]}, 
          {Arrowheads[{{0.0015875105679296724`, 1.}}], 
           ArrowBox[{{-0.7261587163884168, -0.7293865497855931}, \
{-0.7136210959863162, -0.7277393077631146}, {-0.6968521705706104, \
-0.7254792303994552}, {-0.6837729171334753, -0.7236841944440437}, \
{-0.6759033668434439, -0.7225925247435564}, {-0.6706179707528918, \
-0.7218539615799617}, {-0.6660090809974129, -0.7212060547973561}, \
{-0.6604897612296822, -0.7204241401523046}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.0222348220113755`}, {-4.988961422841575, 
            4.023468239662339}, {-4.843867851183203, 
            4.038637223477415}, {-4.698505584119879, 
            4.054190967335198}, {-4.552849428791843, 
            4.07006366376992}, {-4.406874192339335, 
            4.086189505315813}, {-4.260490867482301, 
            4.1025685238750365`}, {-4.1710234625951825`, 
            4.112686516612835}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.1502808447791795`, 
            4.11503232799174}, {-4.11363365218443, 
            4.11917680976141}, {-3.9663121614515786`, 
            4.135912643126662}, {-3.8185360102896047`, 
            4.1526743041225185`}, {-3.670314813704367, 
            4.169360072900705}, {-3.5216581867017234`, 
            4.185868229612948}, {-3.372575744287532, 
            4.202097054410975}, {-3.3204387639252726`, 
            4.207623894092956}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2996802311083493`, 
            4.209824425886611}, {-3.2230771014676507`, 
            4.2179448274465114`}, {-3.0730385595348375`, 
            4.233291674972324}, {-2.9223848974957027`, 
            4.2480243246589815`}, {-2.7711984469268884`, 
            4.262050958784918}, {-2.6195615394050358`, 
            4.275279759628563}, {-2.4683398990924146`, 
            4.287555316847019}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4475232693268696`, 
            4.289112966100067}, {-2.3152656798087756`, 
            4.2989765905827095`}, {-2.162771390887649, 
            4.309260985250074}, {-2.0101559713200454`, 
            4.318380275748875}, {-1.8305494193303757`, 
            4.327443632872397}, {-1.6509093146680125`, 
            4.3345462754753274`}, {-1.613898791357685, 
            4.335578590251615}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5930320649156193`, 
            4.33616061471688}, {-1.4714074423203185`, 
            4.3395530254107975`}, {-1.2922346956529025`, 
            4.342360941933363}, {-1.1135972005558317`, 
            4.3428800447159945`}, {-0.9357088346267437, 
            4.341058907397685}, {-0.7587897600731571, 
            4.336865779696154}, {-0.758167883740346, 4.336842567758569}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.737307568107932, 
            4.336063942943762}, {-0.583063073297979, 
            4.330306667103714}, {-0.5480806972001878, 
            4.328714505922152}, {-0.5131564756894275, 
            4.327029247225964}, {-0.47829209310222476`, 
            4.325251350178011}, {-0.4608750708633122, 
            4.324339302439576}, {-0.44347353937111456`, 
            4.323404254090367}, {-0.4260877041447266, 
            4.322446274432625}, {-0.40871776929651904`, 
            4.321465435687328}, {-0.3913639372545345, 
            4.320461812918878}, {-0.24137112190057464`, 
            4.310566467045252}, {-0.09305085161176163, 4.298847862729414}, {
            0.05361477076379262, 4.285459074503583}, {0.09570469473791793, 
            4.281133121402528}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.11647014697630634`, 4.278998872536678}, {
            0.1986436423779751, 4.270553176899976}, {0.34205366038267465`, 
            4.254283244450811}, {0.48386272192978025`, 4.236802351688304}, {
            0.6240887241711788, 4.218263573144674}, {0.7627495642587583, 
            4.198819983352139}, {0.9444788482611666, 4.171907134598975}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9651284789847094, 4.168849067257093}, {
            0.9753135090164522, 4.167340734825721}, {1.1838837309665002`, 
            4.134938366695871}, {1.3887262575755526`, 4.101985741976478}, {
            1.5872694899993247`, 4.064878518199934}, {1.7832821506820267`, 
            4.028898921396355}, {1.788080960575048, 4.028008329766171}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8086053427658049`, 4.024199293067224}, {
            1.9760991709570332`, 3.993114794031015}, {2.1657205508243442`, 
            3.957526136103914}, {2.35214629028396, 3.9221329476150517`}, {
            2.536093852381912, 3.8873403026868916`}, {2.6292483692835313`, 
            3.8700645539769187`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.649773242237296, 3.866258162625785}, {
            2.7182807001642315`, 3.853553275441896}, {2.8987068336309187`, 
            3.820771865880066}, {3.077372252781974, 3.7889960740014}, {
            3.2157982486069088`, 3.7649666008037785`}, {3.353701526638788, 
            3.741690861886987}, {3.472260622740545, 3.722394660107915}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.492864356898166, 3.7190412791799212`}, {
            3.531028020482087, 3.7128299147434727`}, {3.7081820247541053`, 
            3.685251130767375}, {3.8851635394548416`, 3.6589545099586944`}, {
            4.061972564584297, 3.63394005231743}, {4.085562647412817, 
            3.630686538769885}, {4.109157006343843, 3.6274551659051}, {
            4.2710152233325225`, 3.6065024384855247`}, {4.319359688006372, 
            3.6005541537355468`}}]}, 
          {Arrowheads[{{0.015936500576239944`, 1.}}], 
           ArrowBox[{{4.340078292135001, 3.598004944476316}, {
            4.43327233421825, 3.5865383845908685`}, {4.555263359440834, 
            3.5717933119998393`}, {4.677616348056319, 3.5575330181064047`}, {
            4.800331300064708, 3.5437575029105655`}, {4.923408215465999, 
            3.530466766412321}, {5.001099999999999, 
            3.5224067635678495`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.018501364382491826`, 1.}}], 
           ArrowBox[{{1.6741964150871043`, -0.6932970075736102}, {
            1.8083182998968346`, -0.5976645079449351}, {
            1.8183677204993365`, -0.5910090395074347}, {
            1.8283437266389726`, -0.5844917852791155}, {
            1.87078539752091, -0.5588393017830536}, {
            1.9125496867986953`, -0.5353001118561104}, {
            1.9955084830096603`, -0.491925970717952}, {
            2.0782105630350243`, -0.4552712548018534}, {
            2.1622036195197487`, -0.42411485217830225`}, {
            2.3673682838705554`, -0.36861518603175986`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.011251333955730669`, 1.}}], 
           ArrowBox[{{3.108084472008453, 5.001099999999999}, {
            3.1896415255941877`, 4.990538823158872}, {3.383168170445434, 
            4.965531040184068}, {3.408734725676079, 4.96223082429967}, {
            3.434282104894852, 4.9589389781067945`}, {3.573986602015325, 
            4.941180712670888}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.007094679677820104, 1.}}], 
           ArrowBox[{{4.706439530344936, -5.001099999999999}, {
            4.716948779349911, -4.9999777592571775`}, {
            4.907660808990831, -4.9802466305779145`}, {
            4.933144282637845, -4.977652557856093}, {
            4.958627574668483, -4.975070768438586}, {
            5.001099999999999, -4.970941102363324}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.00831606520238174, 1.}}], 
           ArrowBox[{{-3.789338290177466, 
            4.962415439888859}, {-3.757796680149796, 
            4.966003260554107}, {-3.726239232934878, 
            4.969589230762135}, {-3.5764300906430337`, 
            4.986442190524708}, {-3.4443072400004384`, 5.001099999999999}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.0543254527522654`, 0.2517234447441636}, {
            3.0688935672683253`, 0.25087717144062666`}, {3.0835415531695776`, 
            0.25004356991733695`}, {3.218950334710396, 
            0.24372878252006203`}, {3.3605645355974865`, 
            0.23817702825794485`}, {3.4883640269965843`, 
            0.23347124006443323`}, {3.620656347096804, 
            0.22919808356839547`}, {3.757441495898146, 
            0.22535755876983157`}, {3.888767212519329, 
            0.22218973310031961`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.9096367427343446`, 0.2217199421748953}, {
            4.0441847833344635`, 0.21888875380425485`}, {4.193531929429979, 
            0.21608917271550124`}, {4.346760911687155, 
            0.21355092240248064`}, {4.503871730105991, 
            0.21127400286519307`}, {4.665282088454792, 
            0.20932028009521253`}, {4.74451922674408, 
            0.20835925466199917`}}]}, 
          {Arrowheads[{{0.0055123070672438304`, 1.}}], 
           ArrowBox[{{4.765392533483344, 0.20810609334036662`}, {
            4.828624998713165, 0.20733918014028638`}, {4.995515582118555, 
            0.20556991816783404`}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(tot\\)]\\)}\"", 
          TraditionalForm]}}], {194.4, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.6522838633812708, -0.7182373772803955}, \
{-0.6553710348795826, -0.7203499448469081}, {-0.6591734726905827, \
-0.7229250717108915}, {-0.6633669747343017, -0.7257522275175647}, \
{-0.6662594340572292, -0.7277004838453288}, {-0.6700973527621306, \
-0.7302863099327687}, {-0.676872512181708, -0.7348362273116694}, \
{-0.6937446659844575, -0.7464134305982573}, {-0.7188653859829143, \
-0.764600576717242}, {-0.74504460100222, -0.7847825201234974}, \
{-0.8021598024409362, -0.831987381593239}, {-0.8567994115561622, \
-0.8800994375487785}, {-0.908388966309853, -0.9272230263592166}, \
{-1.002834699073491, -1.01554370683016}, {-1.0862781282145986`, \
-1.0952895491850143`}, {-1.175171661447798, -1.1816346201764456`}, \
{-1.2540410057553955`, -1.2588437216387438`}, {-1.2718490038104944`, \
-1.276386676830918}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.2867199964097398`, -1.2910363390795625`}, \
{-1.3467724595086328`, -1.350195019693969}, {-1.4292354982384978`, \
-1.4317405024150007`}, {-1.5299530029882298`, -1.531652072720799}, \
{-1.6195999093755664`, -1.6207670607824083`}, {-1.7214536824240134`, \
-1.7221919104347119`}, {-1.8129504057294052`, -1.8134069127883476`}, \
{-1.8791465580406566`, -1.8794600850122658`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.8939232501122236`, -1.8942048602329415`}, \
{-1.8960191690946415`, -1.896296252144394}, {-1.9725890623226219`, \
-1.9727441128039294`}, {-2.0434752410875134`, -2.043552814142881}, \
{-2.109859003143614, -2.1098862687761386`}, {-2.159143761560899, \
-2.159145713727679}, {-2.16239330646329, -2.1623939143506177`}, \
{-2.232877420473911, -2.2328662017297054`}, {-2.2994118219046507`, \
-2.2994022111577377`}, {-2.4258217306183782`, -2.425832599799944}, \
{-2.4844761630393335`, -2.484511240079801}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4992338595994847`, -2.499275027436867}, \
{-2.540371000360251, -2.540429146319457}, {-2.6455156121717933`, \
-2.645635982191533}, {-2.757846120293952, -2.7580474755902604`}, \
{-2.861783198280562, -2.8620713456345133`}, {-2.958578619668255, \
-2.958956860842709}, {-3.0494841579936627`, -3.049953289733264}, \
{-3.0894283683432935`, -3.0899398020015383`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.104181296688711, -3.104708354067369}, \
{-3.1352401684659497`, -3.1358001179672854`}, {-3.216587006294282, \
-3.2172368312058803`}, {-3.3450460479073265`, -3.3458438268870454`}, \
{-3.464387494593337, -3.4653286045730454`}, {-3.5759169721390767`, \
-3.5769966671906164`}, {-3.6809401063313096`, -3.682153517666494}, \
{-3.6942590509550097`, -3.695489771341321}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.709010204953815, -3.7102600956637484`}, \
{-3.7802465142879256`, -3.781588982372057}, {-3.874625813126814, \
-3.8760928876786838`}, {-4.027907842116911, -4.029580591971544}, \
{-4.1703788290661326`, -4.17224603537434}, {-4.29904204444397, \
-4.301087369976033}}]}, 
          {Arrowheads[{{0.020000000000000014`, 1.}}], 
           ArrowBox[{{-4.313792499399764, -4.315858392400987}, \
{-4.429051451261808, -4.431278567925529}, {-4.547728328174523, \
-4.550122924060736}, {-4.660544646378888, -4.663099553279513}, \
{-4.753166015159244, -4.755853247310347}, {-4.842609021412661, \
-4.845424490381896}, {-4.903803219730629, -4.906706756772858}}]}, 
          {Arrowheads[{{0.002695138778317765, 1.}}], 
           ArrowBox[{{-4.918553344313161, -4.921478109103838}, \
{-4.928873665139142, -4.931813282494161}, {-4.998060407571418, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.6990211849055333, -0.6717985610824918}, {
            0.7013763934544007, -0.6743629737068528}, {
            0.704223510177147, -0.6774192642669452}, {
            0.7077513198392806, -0.681171423163878}, {
            0.7108840505966135, -0.6844865348824258}, {
            0.716607227451129, -0.6905230756391207}, {
            0.7279743324565577, -0.7025763227680561}, {
            0.7430206736504141, -0.7187583393659739}, {
            0.7609502312866716, -0.7381631134014027}, {
            0.778272774120923, -0.756838264770453}, {
            0.809785042080744, -0.7905785703953737}, {
            0.8381194387993263, -0.8206870375957339}, {
            0.8639919873216758, -0.8480093633976392}, {
            0.9521013366202042, -0.9401838168502455}, {
            1.0536796983487748`, -1.0450241966783098`}, {
            1.170523717826514, -1.1643737701922623`}, {
            1.278038655704146, -1.2733622807630876`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.2926985933855437`, -1.2882231438626424`}, {
            1.3027226970399068`, -1.2983846353601314`}, {
            1.4554955386851982`, -1.4524246296033603`}, {
            1.5465107853141666`, -1.543918223261264}, {
            1.627484384018202, -1.6252014671832398`}, {
            1.7283394526619629`, -1.726316022167204}, {
            1.818318374272436, -1.816442820427548}, {
            1.8817983746704148`, -1.8799784982458752`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.896552645142915, -1.8947457094826143`}, {
            1.899574410033493, -1.8977701247209071`}, {
            1.9742608211290051`, -1.9724861978039177`}, {
            2.0432390380666363`, -2.0414622483091005`}, {
            2.107747806740289, -2.1059502103839667`}, {
            2.159503936561418, -2.15767824453922}, {
            2.1629085552556866`, -2.1610806913839484`}, {
            2.2320277826180437`, -2.2301406705201017`}, {
            2.2972105922879678`, -2.2952563890569673`}, {
            2.4209692817043447`, -2.418872240774082}, {
            2.4871730969545345`, -2.4849845272412203`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.5019440463385507`, -2.499735055339597}, {
            2.5329867789309235`, -2.5307348704123975`}, {
            2.6357356576512, -2.6333247546111465`}, {
            2.7452341645027576`, -2.7426406679213167`}, {
            2.8465348901337895`, -2.843761648849774}, {
            2.94086689545696, -2.9379177752612033`}, {
            3.0294592413849353`, -3.02633912502029}, {
            3.0928920800726325`, -3.0896459437394306`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.1076674919650253`, -3.104392001799004}, {
            3.113035555820274, -3.109749401095449}, {
            3.192319466665535, -3.1888723064550972`}, {
            3.3182233552487572`, -3.3145147916164133`}, {
            3.43516258104477, -3.431205596663246}, {
            3.5444266942870395`, -3.540233139626444}, {
            3.647305245209031, -3.6428858385368565`}, {
            3.698725918917929, -3.6941922858579583`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.713503065114125, -3.70893660595698}, {
            3.74457561028467, -3.7399401262715974`}, {
            3.8370151659878817`, -3.832172435707781}, {
            3.9875501531715183`, -3.9823666942339617`}, {
            4.127438055819144, -4.121934731319082}, {
            4.258201524558066, -4.252396636628772}, {
            4.304605431677563, -4.298692853849035}}]}, 
          {Arrowheads[{{0.019999999999999987`, 1.}}], 
           ArrowBox[{{4.31938331155912, -4.313436438592659}, {
            4.381363210015595, -4.375272499828659}, {
            4.497844257032901, -4.491481766554472}, {
            4.60856581045116, -4.601943882441938}, {
            4.6996382671187416`, -4.692802233052062}, {
            4.787577762532025, -4.7805345348103625`}, {
            4.87238429669101, -4.865140787716839}, {
            4.910506041412597, -4.903172276096308}}]}, 
          {Arrowheads[{{0.0025651122300620064`, 1.}}], 
           ArrowBox[{{4.925284267646686, -4.917915513673592}, {
            4.9540578695956965`, -4.946620991771493}, {
            5.001099999999999, -4.993551516791685}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.65213323922647, 
            0.7186447816126301}, {-0.6550931037791153, 
            0.7206662270151589}, {-0.6588537863726606, 
            0.7232115141708004}, {-0.663052666731834, 
            0.7260419033578253}, {-0.6659364965510531, 
            0.727984466451704}, {-0.669774333875597, 
            0.7305706314237721}, {-0.676498879182903, 
            0.7350872904188313}, {-0.6932056719793964, 
            0.7465548021666625}, {-0.7182724867333661, 
            0.7647107887764614}, {-0.7445022886308267, 
            0.7849393938258061}, {-0.8015999458550807, 
            0.8321551195210709}, {-0.856212841997517, 
            0.8802753808632854}, {-0.9077764104074889, 
            0.9274089244440895}, {-1.0021735440530468`, 
            1.0157503886835935`}, {-1.0855730054998545`, 
            1.0955165293874682`}, {-1.1744208040628572`, 
            1.1818866618150552`}, {-1.2532486349716474`, 
            1.25911809164353}, {-1.2714526166067637`, 1.2770659243816298`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.286317571041944, 
            1.2917217134946795`}, {-1.3459318624638577`, 
            1.3504971700232042`}, {-1.4283511274266305`, 
            1.432066979776501}, {-1.529015051170867, 
            1.5320086504943526`}, {-1.6186134685914662`, 
            1.6211499259036644`}, {-1.7204222230137118`, 
            1.7226149547762535`}, {-1.8118770303219323`, 
            1.8138647520684785`}, {-1.8784957162467186`, 
            1.880395458901015}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.893266208525519, 
            1.89514644472326}, {-1.8949066070308727`, 
            1.896784676857881}, {-1.9714396696552785`, 
            1.9732600882220028`}, {-2.0422911552528524`, 
            2.0440937532683354`}, {-2.108642028823372, 
            2.110450220276758}, {-2.157920929296198, 
            2.159745334863096}, {-2.1611700523834116`, 
            2.1629958524523993`}, {-2.2316209114829295`, 
            2.233494305003722}, {-2.2981235787602854`, 
            2.3000546885043867`}, {-2.4244726775404515`, 
            2.426530892340557}, {-2.4835697177897202`, 
            2.485702227143828}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.498321184658182, 
            2.5004722389960525`}, {-2.5389659736954098`, 
            2.5411681251180296`}, {-2.6440586094355303`, 
            2.6464117335250283`}, {-2.7563317211133183`, 
            2.75886066090569}, {-2.8602153635505725`, 
            2.862918855029698}, {-2.9569607597545122`, 
            2.959836086131881}, {-3.0478191327323585`, 
            3.0508621244470686`}, {-3.088266187053366, 
            3.0913862159936247`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.103012879048784, 
            3.1061609951824467`}, {-3.13353049738607, 
            3.1367367387079943`}, {-3.214834868617606, 
            3.2181996976473894`}, {-3.3432286676472014`, 
            3.346849969225721}, {-3.462509175634897, 
            3.4663746312493235`}, {-3.573981440572931, 
            3.5780797098432098`}, {-3.6789505104535403`, 
            3.6832712311323923`}, {-3.6928410593030314`, 
            3.697191583945528}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.707585974541258, 
            3.711968136300651}, {-3.7782056395508996`, 
            3.7827393249074786`}, {-3.8725360821391828`, 
            3.877274120959074}, {-4.025731346301832, 
            4.030804565855439}, {-4.168121924947649, 
            4.173509976619617}, {-4.29736821885438, 4.303044564502897}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.312112429398828, 
            4.317821820009342}, {-4.426649065719554, 
            4.432615592764754}, {-4.545259379215246, 
            4.55149366446354}, {-4.658012509933313, 
            4.664502434665798}, {-4.750581996889793, 
            4.757282511694247}, {-4.839974942968889, 
            4.846879274364691}, {-4.901873538781534, 
            4.9089193361992605`}}]}, 
          {Arrowheads[{{0.002618929515345463, 1.}}], 
           ArrowBox[{{-4.916617423248253, 
            4.923696917047228}, {-4.926191348170603, 
            4.933292722677131}, {-4.993843613540928, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.7012423689505736, 0.6748320676129324}, {
            0.7040542186770308, 0.6778465898949796}, {0.7075688265764892, 
            0.6815824817621153}, {0.7107056421063063, 0.6849010274238703}, {
            0.716418589427034, 0.6909270332392035}, {0.7277289166640956, 
            0.7029272424800861}, {0.7426933060054435, 0.7190352264979739}, {
            0.7605757065481649, 0.738405872571895}, {0.7778817853257572, 
            0.7570798302774951}, {0.8093722072371122, 0.7908273256144985}, {
            0.8376873283270717, 0.8209424238968713}, {0.8635425435731268, 
            0.8482709151724454}, {0.9515941785033654, 0.9404668395360339}, {
            1.0531071447810203`, 1.0453316228916827`}, {1.169876980658986, 
            1.1647089454413877`}, {1.2801060371311057`, 
            1.2765449816696293`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.2947595792344573`, 1.2914121511618855`}, {
            1.3019933329102764`, 1.2987513624737386`}, {1.4546708710181642`, 
            1.4528270343604295`}, {1.5456302244650388`, 1.54434244341771}, {
            1.6265545027598356`, 1.6256453612455672`}, {1.727343697052965, 
            1.7267798063111368`}, {1.8172646000964559`, 
            1.8169250056302406`}, {1.8836253935351228`, 
            1.8834003775194335`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8983733983749198`, 1.8981738462431794`}, {
            1.8984688127690896`, 1.898269425379705}, {1.9731079359496475`, 
            1.9730015317363558`}, {2.0420427683423386`, 2.041992642888981}, {
            2.106511153711459, 2.1064948565066772`}, {2.158261677376666, 
            2.158261110445231}, {2.1616658849233876`, 2.161666028347692}, {
            2.230742473702776, 2.23074185592488}, {2.295885229730467, 
            2.2958726629423056`}, {2.4195681055785676`, 2.419517377007084}, {
            2.4887472364471876`, 2.488659335340747}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.503511945002055, 2.5034161102653703`}, {
            2.5315173749135043`, 2.531406491811665}, {2.634203941565506, 
            2.6340209184748606`}, {2.743636554928396, 2.743363481107323}, {
            2.8448764897181498`, 2.8445092715190277`}, {2.939152021468572, 
            2.9386886249361037`}, {3.027691425713468, 3.0271318765846784`}, {
            3.094211432739699, 3.093575876837155}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.108980610344518, 3.1083281789545696`}, {
            3.1112178752800177`, 3.1105628875570592`}, {3.1904545429954, 
            3.1897055189455523`}, {3.316282633186597, 3.315378547078068}, {
            3.433151618988305, 3.4320978742344335`}, {3.542350232277996, 
            3.541152191293809}, {3.6451672049331405`, 3.643830189135355}, {
            3.6997901007962524`, 3.6983778252976984`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.7145610152817157`, 3.7131283883428603`}, {
            3.7423794265213384`, 3.7409084712355023`}, {3.8347637866101882`, 
            3.8331636410706826`}, {3.985217090358478, 3.983403312050008}, {
            4.1250286815307335`, 4.123013140293448}, {4.255720490090049, 
            4.253513781478038}, {4.305414301126442, 4.303134180087338}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{4.320185950409604, 4.3178840072843405`}, {
            4.3788144459995175`, 4.376425891280812}, {4.495231241708026, 
            4.492669241157866}, {4.6058915696644585`, 4.603163602565297}, {
            4.6969140893768255`, 4.694048897852186}, {4.7848052829982315`, 
            4.781807134151113}, {4.869565150528677, 4.866438311462078}, {
            4.91105954640319, 4.907869459090816}}]}, 
          {Arrowheads[{{0.002547669768087337, 1.}}], 
           ArrowBox[{{4.925831542563651, 4.92261893888915}, {
            4.951193691968163, 4.9479424297850825`}, {5.001099999999999, 
            4.997772424886306}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.9545045070843204, -0.29911389719262677`}, \
{-0.9592517346068733, -0.2998206527022259}, {-0.9637885449800605, \
-0.3005030158602801}, {-0.9714871602023013, -0.30167855030325863`}, \
{-0.9856543996521394, -0.3039102687049946}, {-0.9975161856727218, \
-0.30584308388257275`}, {-1.012271754786233, -0.30839100071872855`}, \
{-1.1192730535217552`, -0.33159612100251623`}, {-1.2425183410656124`, \
-0.3634125603354485}, {-1.2509152315044776`, -0.36566372149209686`}, \
{-1.2592924255256315`, -0.36791618385577946`}, {-1.3283720310749176`, \
-0.38688506983954446`}, {-1.3943819590012354`, -0.40522193313105814`}, \
{-1.545526170008766, -0.44750776095075046`}, {-1.6787700427575938`, \
-0.48521314431327006`}, {-1.7622273630724885`, -0.5089655189894436}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.7823048957540304`, -0.5146796861472884}, \
{-1.7972223880138611`, -0.5189252797518699}, {-1.912975957975812, \
-0.5520265942550452}, {-2.017562426674136, -0.5820092043175841}, \
{-2.202562608239699, -0.6350881759477295}, {-2.3628255437908394`, \
-0.6811388938841971}, {-2.5049708716047983`, -0.7220224059570025}, \
{-2.5848974411865533`, -0.7450259212323586}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           
           ArrowBox[{{-2.6049579688099502`, -0.7507995038599039}, \
{-2.6255264735656785`, -0.7567192864280229}, {-2.736279492424262, \
-0.7886088441856101}, {-2.935464263315301, -0.8459817143456149}, \
{-3.1115425919722335`, -0.8967179528297309}, {-3.2701567289524465`, \
-0.9424333164933274}, {-3.4073131172326003`, -0.9819718350955767}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.427371087050804, -0.9877542975055081}, \
{-3.5582895138562938`, -1.0254998046682846`}, {-3.686862825275028, \
-1.0625722763147516`}, {-3.807150287398866, -1.0972583980569295`}, \
{-3.9204828475012987`, -1.1299408715487886`}, {-4.027685669559832, \
-1.1608572564576107`}, {-4.226734852276028, -1.2182646314746328`}, \
{-4.229672804144175, -1.2191120159553452`}}]}, 
          {Arrowheads[{{0.018730747667084838`, 1.}}], 
           ArrowBox[{{-4.249730029481791, -1.2248970601766347`}, \
{-4.416022441491737, -1.2728602724828881`}, {-4.590411976096852, \
-1.323161306159506}, {-4.752922208210752, -1.370037242110968}, \
{-4.905078239831026, -1.4139277393846064`}, {-5.001099999999999, \
-1.4416262355631995`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.061863822286002276`, 0.9537421883386369}, {
            0.061515509284284745`, 0.9573331262981254}, {0.06116195163863789, 
            0.9609927602658697}, {0.06080417753414335, 0.9647160495546638}, {
            0.06010962944507837, 0.9720405750260819}, {0.0588928103165631, 
            0.9853003444334016}, {0.05807040611060432, 0.9947440492938777}, {
            0.05734384045025115, 1.004007286761508}, {0.05673638796894994, 
            1.0130366948230423`}, {0.056520777664068024`, 
            1.0165316875019847`}, {0.048237028390450715`, 
            1.195469539371219}, {0.04550969040031006, 1.3359944134898398`}, {
            0.04491237135523302, 1.4986009644829066`}, {0.04615885710419119, 
            1.6807634725559477`}, {0.04761863822510513, 1.788271626870343}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.0479020575765732, 1.809144544691227}, {
            0.04891475066186328, 1.8837261123842826`}, {0.050944764974052814`,
             2.0024558264441095`}, {0.052926945111871695`, 
            2.108486718594569}, {0.05559960081956894, 2.2415998182840124`}, {
            0.05810853148743936, 2.3605125864834067`}, {0.061068163303527406`,
             2.4952381550427742`}, {0.06381255064655335, 
            2.6168042069567963`}, {0.06444366643986109, 
            2.6439713659378565`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.06492847565103076, 2.664840577348807}, {
            0.06876725422703941, 2.8300855434443735`}, {0.07102106102558763, 
            2.9252313739253766`}, {0.07315443846317761, 
            3.0145414821087426`}, {0.07483586109990598, 
            3.0844916313676096`}, {0.07494696919810155, 3.089101672490745}, {
            0.07723809325244693, 3.1835766743979637`}, {0.07941612931531358, 
            3.272952329487834}, {0.08357640937516601, 3.4430641591060582`}, {
            0.08496786488684428, 3.499593660523773}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.08548153682358127, 3.5204621814590857`}, {
            0.08738366406148257, 3.5977383167642847`}, {0.0909040397243043, 
            3.7400903709137188`}, {0.09470768497395302, 
            3.8933710143456057`}, {0.09824355166744367, 4.035425599693059}, {
            0.10154956775992698`, 4.1679048820884494`}, {0.10466366120655364`,
             4.292459616664151}, {0.10623476008406596`, 4.355197907581717}}]}, 
          {Arrowheads[{{0.014975705274930277`, 1.}}], 
           ArrowBox[{{0.1067573462370012, 4.3760662071913865`}, {
            0.10760896363123527`, 4.410073627471972}, {0.11040860665788349`, 
            4.521730738563718}, {0.11481550646803845`, 4.697263002325481}, {
            0.11892070765003886`, 4.860556542859153}, {0.12245801526812283`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.06235684287791754, -0.9538195912738008}, {
            0.06200057607292391, -0.9574993281628488}, {
            0.06161455979879489, -0.961502817461125}, {
            0.06110284356120072, -0.9668541681460507}, {
            0.06007996212992487, -0.9777444214620816}, {
            0.05851636057542379, -0.9957189810208145}, {
            0.057693230389506994`, -1.005659769645717}, {
            0.05711312752196362, -1.0140879047032418`}, {
            0.05690331900852324, -1.017571003863536}, {
            0.04887425311362907, -1.1955912556560897`}, {
            0.04622742218976419, -1.3361032002147437`}, {
            0.04572052087718035, -1.4986977901021823`}, {
            0.04706675768778813, -1.6808514412271458`}, {
            0.04858496581771877, -1.78835461378672}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.04887974032532544, -1.8092273743342813`}, {
            0.0499330071506956, -1.8838084038036842`}, {
            0.05202740857739611, -2.0025366252282124`}, {
            0.054067021538755526`, -2.108566094295901}, {
            0.05681173961000381, -2.2416787662221753`}, {
            0.05938500597708994, -2.360591091520345}, {
            0.06241757060488277, -2.495319549798949}, {
            0.06522774465579967, -2.616887970711935}, {
            0.06587330779487921, -2.6440451202437796`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{0.06636939161842442, -2.664914066688825}, {
            0.07029782719278246, -2.8301730566478436`}, {
            0.07260309338410192, -2.9253204546377987`}, {
            0.07478476953093177, -3.014631999816369}, {
            0.0765038538283387, -3.084576570214534}, {
            0.07661744414526343, -3.089186253913336}, {
            0.07895965179106326, -3.1836627501921417`}, {
            0.08118601175452077, -3.2730397967869838`}, {
            0.085438265182362, -3.4431542478287667`}, {
            0.08685956789574457, -3.499656206359574}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{0.0873845069897979, -3.520524446913912}, {
            0.08932914145948809, -3.5978307484705447`}, {
            0.09292647379921098, -3.7401849391937976`}, {
            0.09681297981806758, -3.893467808441207}, {
            0.10042563694958309`, -4.035524456610383}, {
            0.10380326609176753`, -4.168005665313016}, {
            0.10698468814263086`, -4.292562216160798}, {
            0.10858835513651985`, -4.355248847880499}}]}, 
          {Arrowheads[{{0.014974696818531936`, 1.}}], 
           ArrowBox[{{0.10912220653516787`, -4.376116862342117}, {
            0.1099935667708962, -4.410177947592635}, {
            0.11285356564528665`, -4.521836698047434}, {
            0.1173553552264806, -4.697371821399587}, {
            0.12154882930819301`, -4.8606680195605865`}, {
            0.12515918595960168`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9496063226424689, 0.02412728315925946}, {
            0.9532097388069756, 0.02429631988553734}, {0.9584829362170801, 
            0.0245406316590688}, {0.9623848132202253, 
            0.024719218390660918`}, {0.9682313979026694, 
            0.02498335442365986}, {0.9776772390782258, 
            0.025400590663539287`}, {0.991299784885757, 
            0.025981299651088745`}, {1.0124889981646015`, 
            0.02679922398471907}, {1.0409457198192031`, 
            0.027737039615084915`}, {1.152700706166801, 
            0.031022588756334853`}, {1.198920072996892, 0.0323310125343632}, {
            1.2405985633224723`, 0.0335064573452869}, {1.278716560257337, 
            0.034578130548500494`}, {1.408644994428829, 
            0.03821349418548303}, {1.5563971601009035`, 
            0.04231888969890047}, {1.722469956565747, 
            0.046908259000187205`}, {1.7842344219049546`, 
            0.04860814015315264}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8051013623766525`, 0.049182439932695526`}, {
            1.9136810117957102`, 0.052170768231651676`}, {2.127927649926358, 
            0.05804974276976186}, {2.255713295226081, 0.06155029624847671}, {
            2.369720684023171, 0.06467084395108039}, {2.503846299185878, 
            0.06833942514129718}, {2.6244311744093376`, 
            0.07163589493329507}, {2.639781702320389, 0.07205529468734366}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.660648757418265, 0.07262541434879628}, {
            2.8352071063814432`, 0.07739461375656252}, {2.929014973431649, 
            0.07995653922898957}, {3.016988687209625, 0.08235869827257845}, {
            3.0889211256655043`, 0.08432257078622668}, {3.0936553905395057`, 
            0.08445181605254205}, {3.187122660837203, 0.08700311738165589}, {
            3.2754875390992315`, 0.089414878856504}, {3.4435965507268183`, 
            0.09400274449032776}, {3.4953313919521167`, 
            0.09541443207641813}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.516198466714689, 0.09598383153145962}, {
            3.5963234551971937`, 0.09817020050249406}, {3.736807192105338, 
            0.10200316140874874`}, {3.8878055780433822`, 
            0.10612267305107582`}, {4.027718616767147, 
            0.10993948034486706`}, {4.158182964091807, 
            0.11349831112451542`}, {4.28083527583254, 0.11684389322441391`}, {
            4.35088160290444, 0.1187544698775834}}]}, 
          {Arrowheads[{{0.015080002716911163`, 1.}}], 
           ArrowBox[{{4.371748683969749, 0.11932363830610428`}, {
            4.3966479625288235`, 0.12000278855258188`}, {4.50659343472014, 
            0.1230015590170387}, {4.679965648532576, 0.12773014956521728`}, {
            4.8412199515805, 0.13212808702656365`}, {4.992073300307216, 
            0.13624220866268455`}, {5.001099999999999, 
            0.13648837850148934`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.9535452330768147, 
            0.26959400979910036`}, {-0.9571546344724827, 
            0.2700087352160274}, {-1.005128842534288, 
            0.27556778670680226`}, {-1.108462719898011, 
            0.2949540413823024}, {-1.2032920865681136`, 
            0.316375663763775}, {-1.3003493590362123`, 
            0.3396003232550974}, {-1.3937445089704374`, 
            0.36256705546414325`}, {-1.5641526760507642`, 
            0.4050819126158973}, {-1.7125918034433538`, 
            0.442553457556631}, {-1.7668679200344575`, 0.4563725347547177}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7870973728520663`, 
            0.46152309429580707`}, {-1.8430846403148275`, 
            0.4757778424202269}, {-1.959653935831807, 
            0.505551219340568}, {-2.088196184556465, 
            0.5384661559739932}, {-2.20381147306138, 
            0.5681167401769698}, {-2.3906026228539483`, 
            0.6160855162950796}, {-2.553593564381133, 
            0.6579868903031124}, {-2.5959340826246073`, 
            0.6688809432085738}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.6161504717428623`, 
            0.6740825425689124}, {-2.697979657308866, 
            0.6951368780789474}, {-2.8289562613030785`, 
            0.7288514955004639}, {-2.9488575620043633`, 
            0.7597263273158142}, {-3.0600177450533144`, 
            0.7883569582731511}, {-3.163468688207767, 
            0.8150074838621518}, {-3.260717662935615, 
            0.8400638433779175}, {-3.3139329847418715`, 
            0.8537761552795818}, {-3.317466986751608, 
            0.8546868118751436}, {-3.4191985850569413`, 
            0.8809042483278445}, {-3.424757034678077, 
            0.8823368488236314}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.4449712871194924`, 
            0.8875467454752839}, {-3.5155427537707435`, 
            0.9057353996871641}, {-3.6990658504554705`, 
            0.9530384586614827}, {-3.866175600889379, 
            0.99611587268697}, {-4.020127222382642, 
            1.0358046610335419`}, {-4.186438947523001, 
            1.0786824762622482`}, {-4.253531504680331, 
            1.0959809409169134`}}]}, 
          {Arrowheads[{{0.017991649886952496`, 1.}}], 
           ArrowBox[{{-4.273745287893075, 
            1.101192657823496}, {-4.340638050342551, 
            1.1184396094365001`}, {-4.4844935687564735`, 
            1.1555315399792851`}, {-4.619774540679954, 
            1.1904137473135912`}, {-4.7475403784376216`, 
            1.2233591102885883`}, {-4.868850494354107, 
            1.2546405077534468`}, {-5.001099999999999, 
            1.2887425892038298`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAAD9OritH079JiDMztzrtP/i1Nv5V
ZdO/+TzxYtxT7T+zYDNNUoTTv22VVrW4be0/IbLsvU6j0786lq2BnoftP5Vd
mWyX09O/nurHYQ+w7T+IfV6IuQHUv4gi2+7V1u0/iDI3qCwu1L+/WEIKUPzt
PwVcUd+mbtS/PuLPA+sy7j9UZDLNa8jUv39Akdzdf+4/Lzf1FNxS1b/CSICF
aPzuP3AxFg2eq9W/nTSgQAtP7z9YQI7O/g3Wv8gKtid6rO8/033ItVty1r9b
5iXcuAbwP+smfD1e69e/dRCn6jHD8D9Wng0t4D7Zv8NYCQs6dfE/0wzfEt6n
3b+B9OvdLunzPzh8Hij3Q+G/R2EGIWbR9j/aPUMA1sDjvxSIr9jT5vk/1HUP
HNp55L8m9ovEKdD6P24Opck=
            "]]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.6475679603491339, 
            1.6952264907344865`}, {-0.6610072905160442, 
            1.7291248967188255`}, {-0.6997323956931161, 
            1.8275012532826629`}, {-0.7468450440563892, 
            1.947912286691418}, {-0.788755307070191, 
            2.0554788976635554`}, {-0.8400651146771589, 
            2.1876448327473375`}, {-0.8858398187933559, 
            2.3058545988877697`}, {-0.9418673050753901, 
            2.450858392461216}, {-0.9505310574927026, 2.473316198661978}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.9580444289625611, 
            2.492792036873518}, {-0.9919705680043882, 
            2.580733914600652}, {-1.054433154176827, 
            2.7428664300880445`}, {-1.1103112756266094`, 
            2.888051986382829}, {-1.1713710549391574`, 
            3.046833852457599}, {-1.2266905518284874`, 
            3.1907711811050676`}, {-1.2579243791615253`, 
            3.272077814422872}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.2654100858203325`, 
            3.2915643025801686`}, {-1.277287901886487, 
            3.3224841519220276`}, {-1.3241812407050446`, 
            3.4445929445052736`}, {-1.3678130394076948`, 
            3.5582403365724677`}, {-1.4088281359142174`, 
            3.6650926524423033`}, {-1.4246631824282059`, 
            3.706350891373741}, {-1.4673603904783088`, 
            3.8176182753862125`}, {-1.5078006758559586`, 
            3.923016973919193}, {-1.5646167984443875`, 
            4.071108895036071}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5720941122316356`, 
            4.090598605229227}, {-1.5848444809059843`, 
            4.123832597728343}, {-1.6550183053244876`, 
            4.306771372527961}, {-1.7196857796018863`, 
            4.475375528307672}, {-1.7896226092619185`, 
            4.6577342503928945`}, {-1.8544819573265199`, 
            4.8268669260654065`}, {-1.8711052750706596`, 
            4.870218232360182}}]}, 
          {Arrowheads[{{0.00285748897618391, 1.}}], 
           ArrowBox[{{-1.878579216965918, 
            4.889709235860066}, {-1.9150047177770904`, 
            4.984701888163931}, {-1.9212923461931057`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9014332553711245, -0.3487013349925286}, {
            0.9054491648055429, -0.35032569221247717`}, {
            0.9095945339720327, -0.3520089950972797}, {
            0.9170194690731114, -0.35504348965131044`}, {
            0.9311283648004286, -0.36087962320633693`}, {
            0.9451128957170063, -0.3667333312889868}, {
            0.9620504311599128, -0.37388195123108725`}, {
            0.9791970488941679, -0.3811378807339291}, {
            1.0199956577678644`, -0.39830039143829504`}, {
            1.0551723608902261`, -0.41296828444802325`}, {
            1.0871779237876171`, -0.42625970699810545`}, {
            1.1955482258362577`, -0.47097610236439047`}, {
            1.3189053731206695`, -0.5213931175508951}, {
            1.4594849741290257`, -0.5784049534008453}, {
            1.617654257339802, -0.6421682998624869}, {
            1.6742380235672767`, -0.6648786618218717}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.6936107409220804`, -0.6726540619515793}, {
            1.7998368394314805`, -0.7152887840198033}, {
            1.9080073246924047`, -0.7585920050610726}, {
            2.004343742872596, -0.7971092374075123}, {
            2.125227049338457, -0.8453869090953736}, {
            2.233083574237271, -0.8884251899864473}, {
            2.3673166584249596`, -0.9419482760838671}, {
            2.468999913383986, -0.982469547219522}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.488391773493435, -0.9901970814768828}, {
            2.6383828016942186`, -1.0499392492328081`}, {
            2.7734647857025583`, -1.1037225228505068`}, {
            2.926038534977258, -1.1644502617708348`}, {
            3.063881056187628, -1.219301780885456}, {
            3.189671182280938, -1.2693475761227162`}, {
            3.264188736593548, -1.2989906964558042`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.2835852170712423`, -1.3067066260799383`}, {
            3.306087746204459, -1.315658143410961}, {
            3.4142731631927026`, -1.3586894030012848`}, {
            3.5158872910820915`, -1.3991036482933399`}, {
            3.561251523172893, -1.4171451115381224`}, {
            3.667553786099862, -1.4594185516302947`}, {
            3.768170247720141, -1.4994288701409502`}, {
            3.959760081397595, -1.5756120503618618`}, {
            4.059477514577171, -1.6152606425882428`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.078875267699818, -1.6229733722398654`}, {
            4.134106608611397, -1.644933874471966}, {
            4.294669384282276, -1.7087719173546412`}, {
            4.467897963295364, -1.7776431632854564`}, {
            4.6285066332863245`, -1.8414948958138877`}, {
            4.778344782583238, -1.90106298618667}, {
            4.854796131875119, -1.9314555470288697`}}]}, 
          {Arrowheads[{{0.0032710588357057666`, 1.}}], 
           ArrowBox[{{4.874194339432941, -1.9391671336639182`}, {
            4.919261799514181, -1.9570833056505383`}, {
            5.001099999999999, -1.989616475877643}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.30287503626165946`, -0.9175191622348225}, \
{-0.3047392718719547, -0.9206327323126099}, {-0.3066679383711013, \
-0.9238587230866478}, {-0.3095708440416455, -0.9287251627078833}, \
{-0.3122798326123717, -0.9332827437418721}, {-0.3149865204121599, \
-0.937851311439115}, {-0.3188849353356594, -0.9444620259239478}, \
{-0.32425915427629415`, -0.9536928609005229}, {-0.33261073087019927`, \
-0.968759352864372}, {-0.3379996270432053, -0.9788183948784431}, \
{-0.3439881255326067, -0.990218844279161}, {-0.3501039333997694, \
-1.002061808481341}, {-0.373079174553116, -1.048100755185889}, \
{-0.39376681858090123`, -1.0915835092535495`}, {-0.4625526043584304, \
-1.2449352125542361`}, {-0.538559204101025, -1.42659834811288}, \
{-0.6161449747222012, -1.6193396706149012`}, {-0.6403352755509768, \
-1.6804834244082523`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.6480148157388576, -1.6998943411148093`}, \
{-0.6597770574635, -1.7296247531985611`}, {-0.698425981358317, \
-1.8280143208724489`}, {-0.7454472220340426, -1.9484458524342756`}, \
{-0.7872759774203176, -2.056030997839857}, {-0.8384865855513879, \
-2.188222000959349}, {-0.88417268276529, -2.3064544263536204`}, \
{-0.9400919720740422, -2.451487235199872}, {-0.9503814132165618, \
-2.4782161118917174`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.957880824717585, -2.4976973298214182`}, \
{-0.9900984342994937, -2.581388999941606}, {-1.0524405451176935`, \
-2.7435552059369455`}, {-1.1082108852709003`, -2.8887711817615456`}, \
{-1.1691522199937887`, -3.047584821814511}, {-1.2243644820993231`, \
-3.191551307214499}, {-1.2571959348883122`, -3.277200231564726}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-1.2646676665723169`, -3.2966920824396024`}, \
{-1.274863813784322, -3.323291241692089}, {-1.3216663572456038`, \
-3.44542522897786}, {-1.3652137177104544`, -3.559096240605843}, \
{-1.4061494715778575`, -3.6659708862009723`}, {-1.4219562473456553`, \
-3.7072439236836083`}, {-1.4645707915195538`, -3.8185344499973084`}, \
{-1.5049328151954098`, -3.9239551801259855`}, {-1.5633133716044192`, \
-4.07645177080387}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.5707767051368422`, -4.095946838833246}, \
{-1.5818275741417092`, -4.124812953699703}, {-1.6518657335610007`, \
-4.307790422208616}, {-1.7164082546987165`, -4.476430452980017}, \
{-1.7862102086878275`, -4.6588286861843695`}, {-1.850944512400995, \
-4.827998136344669}, {-1.86922784321475, -4.875781024230279}}]}, 
          {Arrowheads[{{0.0027139044851196914`, 1.}}], 
           ArrowBox[{{-1.8766878023463902`, -4.895277383753032}, \
{-1.9113506181420536`, -4.985867520628838}, {-1.9171787710996047`, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAA/BVpXxOa2T/F2VO0JJbrP2LaZwOU
sNk/WOsdD7Sz6z8wUxUGO8vZP/FCCLW11us/AgVbwMPn2T8sLMkpL/zrP6iI
P/r0/dk/TB5qYFQZ7D9PXJfhrCLaP4puNHaPSew/4df1HWJC2j+ducDfOXPs
P8ekxw11bto/b7+zaDOt7D81FlepzKraP+waB5Q8/ew/6rHu+c7x2j9Xn4ts
AF7tP3Xa4LBEWts/3/Fsgcfv7T9fzBxF/dbbP8J7+oiEnu4/ykFFLCLK3D++
njiufu7vPwscx9xJqd0/KjOev1eO8D+glnr6ZnjeP3P1NMFQGPE/hNlmTlel
4D/60GbW7+3yP7zMho9gUOI/q3DeP+kG9T8AQ0N+tT3kP51Yg+kZZPc/n+Yo
++B/5j+a7cmtFB36PxWo1qg9l+Y/6NzR3ec4+j972K5w
            "]]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.7140422207817265, 1.6581405807336234`}, {
            0.783257900609648, 1.8230169502943243`}, {0.830884998193042, 
            1.9357258215914017`}, {0.8734865703799836, 2.0362324860325227`}, {
            0.9267888713176917, 2.1616479833873474`}, {0.9744909545065981, 
            2.2736621602471367`}, {1.0336985502419824`, 2.41245171441475}, {
            1.0398834590317878`, 2.426931095308373}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.048083449624825, 2.446127948674492}, {
            1.0867379338251286`, 2.536621279943222}, {1.1534188110812713`, 
            2.6925506417906337`}, {1.2131290712612803`, 
            2.8320614843880376`}, {1.279772755928306, 2.987659760231091}, {
            1.340096105545196, 3.1284300729234533`}, {1.3766729038717183`, 
            3.213749792335483}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.384898035484036, 3.2329358871660165`}, {
            1.395230372587572, 3.257037288679472}, {1.4463068095310563`, 
            3.376146273713493}, {1.4938135879031904`, 3.486903557793435}, {
            1.538461321070723, 3.590977347440735}, {1.556332524398117, 
            3.632630671458461}, {1.6029371915950417`, 3.741237176496404}, {
            1.6470683700722826`, 3.8440683278905867`}, {1.7141172007321788`, 
            4.000287938530303}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.7223503243656813`, 4.019470605188556}, {
            1.7311290287525232`, 4.039924441112855}, {1.8076701375466948`, 
            4.218234270986398}, {1.8781903315975863`, 4.382500126344953}, {
            1.9543603351915253`, 4.55991220821065}, {2.024996954724549, 
            4.724424365741886}, {2.0517561471513934`, 4.786742553411966}}]}, 
          {Arrowheads[{{0.00508769693165307, 1.}}], 
           ArrowBox[{{2.059992513411501, 4.805923828023303}, {
            2.090908676317771, 4.877922982979075}, {2.143802768233797, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAQtOi0qaI2T80yKDAk3Trv1goh2wx
ndk/cPSVuY+P679ySJh1VbTZP+78S4X0reu/oaO+rSvP2T+2XAylMtHrv7da
dpyQ69k/WjWzTnv267/tgPVmcwHaP6/s9f03E+y/ZPb1KH8l2j+6ypXzjULs
vw95oDGXRdo/qXqF97Zs7L94LMEbxHLaP9iVvrkdqOy/i78ewBWx2j9wWrjS
r/rsvwbcR/7c+No/8jDd01Bc7b8Ld+o0uWHbP4mRkANh7u2/F31tRaXe2z/B
ePlKGp3uvwrMYkQi0tw/H+PTnAPt7792lLQPmLHdP4rC4VKSjfC/HrcStvuA
3j8ldybggxfxv4cJP7YXquA/OBtnVwjt8r9vTFsVplXiP0J4BfjiBfW/EJOg
/Y9D5D8qFKn28GL3vw40w8dnhuY/ztafi8Ub+r/wD4ByeJDmPwKjhkS+J/q/
BxS/BA==
            "]]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7132251140192823, -1.6539465891985146`}, {
            0.7841471205911394, -1.822657763592446}, {
            0.8318291736651209, -1.935344167342931}, {
            0.8744795847648317, -2.0358304416156643`}, {
            0.927843256998243, -2.161221540757752}, {
            0.9755999983532417, -2.2732135815465604`}, {
            1.034875716477968, -2.411976661643105}, {
            1.0394149843373899`, -2.4225892406674467`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.0476242645674239`, -2.4417821232803045`}, {
            1.0879758975650147`, -2.5361222034893447`}, {
            1.1547333220639484`, -2.692021873380806}, {
            1.2145119329240193`, -2.831505840282472}, {
            1.2812338697588883`, -2.9870788568879085`}, {
            1.3416277637596346`, -3.1278257322115963`}, {
            1.3765799478016332`, -3.209247094358382}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.3848143569489277`, -3.228429209228258}, {
            1.3968262881262803`, -3.256411088623786}, {
            1.4479621160588476`, -3.3754995484947297`}, {
            1.495524019756063, -3.486237511586899}, {
            1.5402234839757771`, -3.5902929891362074`}, {
            1.558114393089913, -3.631936660616524}, {
            1.6047732003057302`, -3.7405244218750804`}, {
            1.6489555833501854`, -3.843337693737093}, {
            1.7144028984639201`, -3.9956226806575272`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.7226452957415639`, -4.0148013644497915`}, {
            1.7331136819336324`, -4.039159553193926}, {
            1.8097433559086014`, -4.2174378618569595`}, {
            1.8803450392012668`, -4.381674446017762}, {
            1.9566027182879766`, -4.559054134342186}, {
            2.0273205829765146`, -4.723536125793567}, {
            2.0524213616589564`, -4.781914253756122}}]}, 
          {Arrowheads[{{0.005214743813283653, 1.}}], 
           ArrowBox[{{2.0606669999403944`, -4.80109154434207}, {
            2.093308066660962, -4.8770064947886285`}, {
            2.146666780654455, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9011904132209612, 0.3771432935406063}, {
            0.9048814128787542, 0.37875620912000285`}, {0.9085151292207249, 
            0.38034952831378455`}, {0.9149187115112783, 0.3831732645125305}, {
            0.9273879152998931, 0.3887354540796858}, {0.9469431519371868, 
            0.3975846421752169}, {0.9710546890102671, 0.4085861624141902}, {
            0.9939635681546203, 0.41902188772982357`}, {1.0344693988029565`, 
            0.4373391524338492}, {1.070512725205682, 0.4535461089817925}, {
            1.1033426889764333`, 0.4682489331403275}, {1.214675191949742, 
            0.5177969044630854}, {1.3414305303182592`, 0.5736896596818326}, {
            1.4857736232868393`, 0.6368701039400934}, {1.6480504411602295`, 
            0.7075037438095054}, {1.6648585994674547`, 0.7147899557679677}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.6840113151752059`, 0.7230925159697511}, {
            1.8346243664456017`, 0.7883821565840421}, {1.9452448904270525`, 
            0.8362218966583589}, {2.04380701707716, 0.8787979526923115}, {
            2.167304383565057, 0.9320912889554748}, {2.2775340674129003`, 
            0.9796223441827362}, {2.4145583114155063`, 1.0386670370274382`}, {
            2.4505617625845204`, 1.054173192308686}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.469734065744026, 1.0624304204420352`}, {
            2.537085790196531, 1.0914378145642731`}, {2.6912566227044015`, 
            1.1578069309984447`}, {2.8291430355050915`, 
            1.2171453789674902`}, {2.9842515423659304`, 1.283875577015297}, {
            3.1244548392338025`, 1.3441806544232942`}, {3.2367349626413624`, 
            1.3924668514229601`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.255911742718795, 1.4007136769113435`}, {
            3.370944870323307, 1.450178120661647}, {3.481086041763265, 
            1.4975341333943564`}, {3.584554661613136, 1.542018026312149}, {
            3.626728954439561, 1.5601490579500155`}, {3.7348126149263776`, 
            1.6066118686128368`}, {3.837128818364154, 1.6505933602354703`}, {
            4.023021072143947, 1.7304980230551397`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.042199331020855, 1.738741408966366}, {
            4.209319783941666, 1.810572666242778}, {4.372666318064708, 
            1.8807786278206406`}, {4.548976898880404, 1.9565539442435935`}, {
            4.712455067087097, 2.026811965970161}, {4.809341346859606, 
            2.068449715140954}}]}, 
          {Arrowheads[{{0.004499237150800537, 1.}}], 
           ArrowBox[{{4.828520097985892, 2.076691955741795}, {
            4.864979721332529, 2.0923608064328665`}, {5.001099999999999, 
            2.1508586085407733`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.8088643056903, 
            0.5160579905758492}, {-0.813668234570552, 
            0.5170441596629829}, {-0.8177263216475406, 
            0.5179926950097768}, {-0.8217553935182974, 
            0.5189993302176086}, {-0.826115224517585, 
            0.5201506278476434}, {-0.8321511413135635, 
            0.5217888858997267}, {-0.8394826347637646, 
            0.5237709818858037}, {-0.8577973951941186, 
            0.5291596344501529}, {-0.8798583594342404, 
            0.5365145025642026}, {-0.9072713960584836, 
            0.5469682956937594}, {-0.9370190641566352, 
            0.5596556514434656}, {-0.9682634822606999, 
            0.5740195800191763}, {-1.09689070332057, 
            0.6386954286494465}, {-1.2193819086033908`, 
            0.7045280332710431}, {-1.3303509962624909`, 
            0.7654290716379246}, {-1.4304336234834374`, 
            0.8208239470520465}, {-1.5534448890047892`, 
            0.8897232987451966}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5716574908506071`, 
            0.899924286878308}, {-1.6029239582889816`, 
            0.917436823857005}, {-1.787876318247364, 
            1.0219984602545575`}, {-1.943455737514213, 
            1.1102744894491094`}, {-2.130567268549155, 
            1.216696918829575}, {-2.2907393206405984`, 
            1.3079263165783832`}, {-2.297884774219122, 
            1.311999997867331}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.316019518585022, 
            1.322338763348259}, {-2.4411348454783477`, 
            1.3936680303464803`}, {-2.5754202807188813`, 
            1.4702679453490557`}, {-2.6971585578537343`, 
            1.5397369230436475`}, {-2.8098146604228473`, 
            1.6040377006642268`}, {-2.9155123477113025`, 
            1.6643749789443392`}, {-3.0142516197191003`, 
            1.7207487578839844`}, {-3.0412512008436323`, 
            1.7361665219609128`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.059378694842992, 
            1.7465179946189135`}, {-3.1060324764462406`, 
            1.7731590374831627`}, {-3.2748670146019143`, 
            1.8695850255018247`}, {-3.4281640327216905`, 
            1.9571488698420316`}, {-3.568630695537466, 
            2.0373928333054483`}, {-3.69897416778114, 
            2.111859178693739}, {-3.784420411763028, 
            2.1606785255846734`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.8025454968422627`, 
            2.1710342156030484`}, {-3.8203856848587585`, 
            2.181227130900313}, {-3.9346048609687494`, 
            2.246488723774098}, {-3.9633358106154666`, 
            2.262905187072662}, {-4.081687550708517, 
            2.3305324016281856`}, {-4.193850178892275, 
            2.3946249549085508`}, {-4.303377385022638, 
            2.4572122106155594`}, {-4.4076337470462095`, 
            2.516788871175855}, {-4.507166211783712, 
            2.5736672022802716`}, {-4.527525914195829, 
            2.585302044326476}}]}, 
          {Arrowheads[{{0.012564801094574805`, 1.}}], 
           ArrowBox[{{-4.545650073977442, 
            2.5956593536825174`}, {-4.602521726055866, 
            2.628159469619643}, {-4.7822324361980915`, 
            2.7308597887657933`}, {-4.8813411953842705`, 
            2.7874989043754272`}, {-4.976932385356623, 
            2.8421280893553433`}, {-5.001099999999999, 
            2.8559396659120266`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.8035010644586197, -0.5279296740950038}, \
{-0.8077201172641456, -0.5290885436547846}, {-0.8128541823321824, \
-0.5305233614823365}, {-0.8166179003822609, -0.5315917087736656}, \
{-0.8220389969063288, -0.5331511387308282}, {-0.8302069926733988, \
-0.5355269095525006}, {-0.846169553322558, -0.5403442361702107}, \
{-0.8710195119112039, -0.5486817491393385}, {-0.8994981014649214, \
-0.5598837217896787}, {-1.0238733235612087`, -0.6197977024736395}, \
{-1.1497519677177053`, -0.6878650136860763}, {-1.265080860346464, \
-0.7527902591586161}, {-1.3690097712098945`, -0.8121398876870406}, \
{-1.4630322632725037`, -0.8661825025488611}, {-1.5427056685508227`, \
-0.912395978183618}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5607627725641722`, -0.9228697558945134}, \
{-1.6259102025263357`, -0.9606576370162803}, {-1.810372485244601, \
-1.0684445544457417`}, {-1.9656782284104144`, -1.1594923682435416`}, \
{-2.0637877610397863`, -1.2171154452708242`}, {-2.154190327718345, \
-1.2702486749229998`}, {-2.2812078894463848`, -1.3449730027710078`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.299200127549367, -1.3555578217553725`}, \
{-2.3155467613975587`, -1.3651745331003673`}, {-2.4671152980112514`, \
-1.454420033089551}, {-2.602454023731125, -1.5341505120347034`}, \
{-2.725155077535311, -1.6064613682284452`}, {-2.8387088912769434`, \
-1.6733955428774514`}, {-2.945254128369538, -1.7362064452146369`}, \
{-3.0185959487315293`, -1.7794493830388582`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.0365778910688084`, -1.7900516834809763`}, \
{-3.0447907888130943`, -1.794894075240002}, {-3.137318872607613, \
-1.8494584329535466`}, {-3.307540065568251, -1.9498536460391709`}, \
{-3.4621084625701672`, -2.0410283990655063`}, {-3.6037502379827013`, \
-2.124586801820679}, {-3.7351915661751947`, -2.202132964092815}, \
{-3.755776345251257, -2.2142780618033426`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.773755175011166, -2.224885639535812}, \
{-3.8576322329880868`, -2.2743734217965366`}, {-3.9728244130768546`, \
-2.3423401272233044`}, {-4.000353412390489, -2.3585834110233495`}, \
{-4.119665190200359, -2.4289850542035234`}, {-4.2327418331737, \
-2.4957093733750044`}, {-4.343163241655249, -2.560867525238122}, \
{-4.4482741811532165`, -2.622893342484512}, {-4.492889263139967, \
-2.649221123207029}}]}, 
          {Arrowheads[{{0.013634355866027455`, 1.}}], 
           ArrowBox[{{-4.510867261646923, -2.6598301097076353`}, \
{-4.548625451361405, -2.682111573621057}, {-4.644767851973615, \
-2.7388469671546396`}, {-4.825967606004934, -2.8457782924108184`}, \
{-4.925911449747641, -2.904758854192195}, {-5.001099999999999, \
-2.9491304867469412`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.9524589087233185, -0.015860819622689575`}, \
{-0.9564335592437784, -0.015810254454133876`}, {-0.9621472061104768, \
-0.01574109435137525}, {-0.9673210838934456, -0.01568211105940696}, \
{-0.9753773920157454, -0.015596788505614185`}, {-0.9883900715926194, \
-0.01547846815387624}, {-1.0131723185798116`, -0.01539349896501318}, \
{-1.0895565408886778`, -0.015920345117760627`}, {-1.1674276211421872`, \
-0.016786546242178433`}, {-1.2556810362728588`, -0.0178818591865308}, \
{-1.3460613956500067`, -0.01905900276196355}, {-1.5164100373977782`, \
-0.021331133657058066`}, {-1.6681838796810122`, -0.02339255238833547}, \
{-1.7873888527711452`, -0.02503200089586444}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.8082617167977182`, -0.025319354237933547`}, \
{-1.924291199322191, -0.02692200533188158}, {-2.061734003937224, \
-0.028826892490419864`}, {-2.184750701059887, -0.03053524580559497}, \
{-2.332869901140628, -0.03259558773445816}, {-2.465456830609913, \
-0.03444188189891797}, {-2.6141260017425463`, -0.036513992335352456`}, \
{-2.6431748166316753`, -0.03691910923226442}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-2.664047628835733, -0.03721020299778318}, \
{-2.748250251257356, -0.03838449892818492}, {-2.8621660968323877`, \
-0.039973877324053324`}, {-2.9691749959180553`, -0.041467182351674035`}, \
{-3.1624719546212967`, -0.04416557230217237}, {-3.3341410756612264`, \
-0.04656290686228538}, {-3.4901823073319913`, -0.048742424114618536`}, \
{-3.4989599622060745`, -0.04886504624109092}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.51983276749742, -0.049156635259682425`}, \
{-3.6332890809169904`, -0.05074159782802203}, {-3.7661548276996237`, \
-0.05259790177134606}, {-3.88997450843509, -0.05432798301495603}, \
{-4.006495429091447, -0.055956188085859865`}, {-4.04842179395272, \
-0.05654206908545259}, {-4.169374884744161, -0.058232373332509725`}, \
{-4.284031685741647, -0.05983475333539496}, {-4.354744939733427, \
-0.06082301718932354}}]}, 
          {Arrowheads[{{0.014983187652207946`, 1.}}], 
           ArrowBox[{{-4.375617743319712, -0.061114728235697864`}, \
{-4.396004821196144, -0.06139965094841658}, {-4.502610625564663, \
-0.06288958378171096}, {-4.701938058830397, -0.06567551117661236}, \
{-4.885786441771326, -0.06824519672942446}, {-5.001099999999999, \
-0.06985691217140325}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5516660290252076, 
            0.9163943947384406}, {-0.6422003874078407, 
            1.0341418213316822`}, {-0.7176744661731471, 
            1.1406462907657957`}, {-0.7821429506799089, 
            1.234981576933025}, {-0.8907200712890162, 
            1.3969817214009215`}, {-0.9796082995204014, 
            1.5317667736534455`}, {-1.0261360041709124`, 
            1.6031310627463469`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.0375368125007047`, 
            1.620617646012197}, {-1.0921871612531642`, 
            1.7044404633356294`}, {-1.186142007120044, 
            1.8493725394054505`}, {-1.267598638272499, 
            1.9754090856013953`}, {-1.339877133708313, 
            2.0874572106648834`}, {-1.4055608642493147`, 
            2.1893918950609237`}, {-1.4660049642936726`, 
            2.283264231905826}, {-1.490829880409169, 
            2.3218576267269206`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.5021228977470849`, 
            2.3394140154299454`}, {-1.5737026858881316`, 
            2.450693627094504}, {-1.6753956902492833`, 
            2.6089374690388665`}, {-1.766109016031335, 
            2.7501767472931644`}, {-1.84830856894706, 
            2.8782104158897743`}, {-1.9243637906726598`, 
            2.996701552632399}, {-1.9534042407565755`, 
            3.0419519217362896`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.964678985680292, 
            3.0595200506005513`}, {-1.995720866813407, 
            3.1078890178477407`}, {-2.062379797369301, 
            3.2117728115357997`}, {-2.124340582340343, 
            3.308352933696576}, {-2.2383284870248192`, 
            3.4860589780562337`}, {-2.3418453523637868`, 
            3.647463965546668}, {-2.415514776939935, 
            3.7623440122953227`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4267832971468875`, 
            3.7799161344560543`}, {-2.4367162083973875`, 
            3.7954055089879293`}, {-2.524766085165764, 
            3.932721221200066}, {-2.6067972267854715`, 
            4.060659578487329}, {-2.683981106798349, 
            4.181043913624689}, {-2.6989572616219344`, 
            4.204402961532696}, {-2.7787822407457603`, 
            4.328915197987122}, {-2.8544448736543124`, 
            4.446938686878413}, {-2.877461153437093, 4.482841385545164}}]}, 
          {Arrowheads[{{0.014245081593259087`, 1.}}], 
           ArrowBox[{{-2.8887271982179867`, 
            4.500415094882725}, {-2.928334693350006, 
            4.562198144797402}, {-2.998678886619982, 
            4.671929540771788}, {-3.0658447420238186`, 
            4.776705242947066}, {-3.1301995481210945`, 
            4.877097619468733}, {-3.1920003770441068`, 
            4.973507364946973}, {-3.2096876420217484`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5506903102585115, -0.917125361458242}, \
{-0.6411129459176927, -1.035026452205645}, {-0.7164605637990973, \
-1.1416172320249167`}, {-0.7808093655936115, -1.236011190313933}, \
{-0.889176878614576, -1.3981009069855996`}, {-0.9778895717655004, \
-1.5329557937394054`}, {-1.02436180050854, -1.6044137081678682`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.0357425782237903`, -1.6219133345490866`}, \
{-1.0902386551722107`, -1.7057091005064144`}, {-1.1840029995812777`, \
-1.8507109295890785`}, {-1.2652955505936603`, -1.9768103418868341`}, \
{-1.3374292995703043`, -2.088915997049684}, {-1.4029820547220342`, \
-2.19090407952729}, {-1.463306039763342, -2.284826353223198}, \
{-1.4882308365352204`, -2.3236729022688305`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.4995037052974671`, -2.34124223506081}, \
{-1.570790777621046, -2.4523467217566415`}, {-1.6722722066773617`, \
-2.6106604799760276`}, {-1.7627985535457227`, -2.7519650432167255`}, \
{-1.844829887237456, -2.8800598796203802`}, {-1.920730205634184, \
-2.998608839621253}, {-1.9499781379962902`, -3.0442978130531784`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.9612327066130377`, -3.061878874174086}, \
{-1.9919423969729846`, -3.1098512986718982`}, {-2.058466461253858, \
-3.213787256772316}, {-2.120302398476804, -3.3104167139225056`}, \
{-2.2340615167482025`, -3.4882149911774034`}, {-2.3373713767864674`, \
-3.649704996241791}, {-2.411261009599087, -3.7652201557151277`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-2.4225093426239668`, -3.7828052070101217`}, \
{-2.4320531149347193`, -3.7977254378799863`}, {-2.5199278675360786`, \
-3.935115024856307}, {-2.601796193844618, -4.063122759995592}, \
{-2.6788271142683855`, -4.183572757234309}, {-2.693780510744769, \
-4.206955369505342}, {-2.7734468731986026`, -4.3315348777501}, \
{-2.8489593640785342`, -4.449622459789422}, {-2.8723795056146018`, \
-4.486247653284373}}]}, 
          {Arrowheads[{{0.014137402271138957`, 1.}}], 
           ArrowBox[{{-2.883625358517904, -4.503834290750457}, \
{-2.9227026385392763`, -4.5649446362978985`}, {-2.9929074801616404`, \
-4.674736001744682}, {-3.0599404181544694`, -4.779569185963923}, \
{-3.1241679817266053`, -4.880016818789774}, {-3.185846714970972, \
-4.976479784683387}, {-3.201588747344486, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9331479812932979, -0.6009949582719674}, {
            1.017311278121481, -0.6590988009364511}, {
            1.1223023971754262`, -0.7307164625560713}, {
            1.242249528532178, -0.811677253497729}, {
            1.379100698697859, -0.9032906602497939}, {
            1.5329867775829396`, -1.005680793088306}, {
            1.6258523840775863`, -1.06720157237856}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.6432549275378667`, -1.0787302542632864`}, {
            1.7099221759825356`, -1.1228953788155007`}, {
            1.8147888567408708`, -1.1921941604648232`}, {
            1.9081643037774245`, -1.2538260727337132`}, {
            2.025092621852819, -1.3309233745273599`}, {
            2.129398609937603, -1.399643824850352}, {
            2.259387681536061, -1.485226001653463}, {
            2.340290986753652, -1.538463434918334}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.357729040677716, -1.549938333620615}, {
            2.3755301571518173`, -1.5616521412058717`}, {
            2.519808332916381, -1.6565495566628865`}, {
            2.648892982992149, -1.7414247161027103`}, {
            2.808272726932713, -1.8461883045881833`}, {
            2.9510853951285148`, -1.9400411990151945`}, {
            3.0554583943820037`, -2.008619231458698}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.072904376537662, -2.02008207279541}, {
            3.1301636995641604`, -2.057704175640874}, {
            3.290594353185333, -2.1630993514723693`}, {
            3.466632867827523, -2.278733747434499}, {
            3.626266360101661, -2.3835830264801703`}, {
            3.7708010547319875`, -2.4785083634346843`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.7882495294675844`, -2.489967410265453}, {
            3.907908467243354, -2.5685514336987025`}, {
            4.03407608079581, -2.651406343074521}, {
            4.152734333890633, -2.7293274535519987`}, {
            4.1763713988256255`, -2.744849308719229}, {
            4.299291691826192, -2.82556579054789}, {
            4.4157593429842725`, -2.9020435875520225`}, {
            4.486206469883305, -2.948301948321667}}]}, 
          {Arrowheads[{{0.01425388152673846, 1.}}], 
           ArrowBox[{{4.503655720254748, -2.9597598140199928`}, {
            4.5294822987504535`, -2.976718563625384}, {
            4.6377158637328355`, -3.047787897837203}, {
            4.741032321860947, -3.115627599512413}, {
            4.840003957064316, -3.1806136779759484`}, {
            4.935030227413806, -3.243008556684218}, {
            5.001099999999999, -3.2863900384756084`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0004334532541135`, 0.6676061688345085}, {
            1.032179904960355, 0.6900292587516159}, {1.1399112965791633`, 
            0.7655854447522866}, {1.262925793649755, 0.8509902599021637}, {
            1.4030951869016044`, 0.9475499879828991}, {1.5605480376675829`, 
            1.0553989799105665`}, {1.6562187842249578`, 1.12071559147628}, {
            1.6875258535701667`, 1.1420551709005873`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7047747956100348`, 1.1538124249758994`}, {
            1.7412627367697993`, 1.1786833993179104`}, {1.8482349245146243`, 
            1.2514939529121987`}, {1.9435209004096927`, 
            1.3162799630774082`}, {2.0626994173284503`, 
            1.3972335451747482`}, {2.169046624159355, 1.4694193710324734`}, {
            2.3014575377071305`, 1.5592400567399056`}, {2.395486394296118, 
            1.6229942481491837`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.4127641821161614`, 1.634709070936223}, {
            2.4197964364871396`, 1.6394771358417213`}, {2.5666986335143434`, 
            1.739039899048949}, {2.6981626234408385`, 1.8281119510302664`}, {
            2.860390267306549, 1.9379980560764625`}, {3.005785739769488, 
            2.0364629777021204`}, {3.099288036384905, 2.09977545765216}, {
            3.104070939663822, 2.1030138754605883`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.1213563185196227`, 2.1147174946742164`}, {
            3.188052638813188, 2.1598763738736793`}, {3.3513687611083527`, 
            2.2704435151311575`}, {3.530151715389451, 2.3914682744696085`}, {
            3.6923258397571956`, 2.501241244473718}, {3.8128172950174926`, 
            2.5827945779835666`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.8301046228594804`, 2.5944953181725374`}, {
            3.840817358001112, 2.601746116662113}, {3.9785524939107253`, 
            2.694966582553421}, {4.106807345576412, 2.7817673075048073`}, {
            4.227442924710507, 2.863409194088257}, {4.249623075073367, 
            2.8784197144226207`}, {4.374504890945582, 2.9629320597191917`}, {
            4.492842777113877, 3.043014441269963}, {4.5216215812198595`, 
            3.0624896939816706`}}]}, 
          {Arrowheads[{{0.013367058079884586`, 1.}}], 
           ArrowBox[{{4.538909848302426, 3.0741890463640895`}, {
            4.608396330403892, 3.121212084360734}, {4.718381217937348, 
            3.1956402505315027`}, {4.823377128639995, 3.2666914420694657`}, {
            4.923963751437583, 3.3347581612618193`}, {5.001099999999999, 
            3.3869555553833086`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6986844366067038, -1.0193880835688565`}, {
            0.7685252352089544, -1.129701859981818}, {
            0.8496028720325886, -1.2555087230732975`}, {
            0.9420383851924254, -1.3970517595918464`}, {
            1.0494917046261227`, -1.5600404794692946`}, {
            1.1136473420140294`, -1.6568304377547611`}, {
            1.1548061239214211`, -1.7187662788754043`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1663597806995765`, -1.7361522513802359`}, {
            1.1708475975346353`, -1.7429055297231217`}, {
            1.2427989179235783`, -1.8509340131269996`}, {
            1.307019999444051, -1.9471924573543533`}, {
            1.387326301913866, -2.067381672460324}, {
            1.459084856970183, -2.174658676276005}, {
            1.5484018068293262`, -2.3080556276894173`}, {
            1.6283010789734265`, -2.427300813074754}, {
            1.6303523029467988`, -2.4303602244055247`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.6419771188513137`, -2.4476986983889035`}, {
            1.7274522661139247`, -2.5751853295073075`}, {
            1.8162404643589394`, -2.707551296149989}, {
            1.9257726839737053`, -2.8707760412760246`}, {
            2.0239841355863613`, -3.017086201802396}, {
            2.087127932655312, -3.1111336756433765`}, {
            2.107226158245291, -3.14106565415979}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.118862923841978, -3.158396110337685}, {
            2.147080682354369, -3.2004203844604393`}, {
            2.2574130396428025`, -3.364711507022811}, {
            2.377965270994842, -3.544190280790467}, {
            2.4873567882973733`, -3.7070337208971167`}, {
            2.5844410721645477`, -3.851542143842695}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.596082532334228, -3.8688694468621083`}, {
            2.680499305947242, -3.9945143053366987`}, {
            2.7670674722989137`, -4.123353757574083}, {
            2.848502401875332, -4.244548447717255}, {
            2.8633516392399523`, -4.266647189818918}, {
            2.9476358853021543`, -4.392075183165522}, {
            3.027510601290057, -4.510937945701526}, {
            3.0617804915778355`, -4.5619349920318}}]}, 
          {Arrowheads[{{0.012173598712989994`, 1.}}], 
           ArrowBox[{{3.0734236362020173`, -4.579261163222993}, {
            3.105508553676142, -4.627006750068787}, {
            3.179752978858594, -4.737487638098563}, {
            3.2506340491009924`, -4.842961697711178}, {
            3.318541936666918, -4.9440100168269545`}, {
            3.3569088296324097`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6977996626498019, 1.019919886805171}, {
            0.767541852554313, 1.1302900162077345`}, {0.84850748452013, 
            1.2561608009704723`}, {0.9408174708593645, 1.3977757970218048`}, {
            1.0481249789923235`, 1.5608449694122135`}, {1.1121933340802537`, 
            1.657681513752684}, {1.1533232129336524`, 1.7196877580527106`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.1648621359790565`, 1.7370835127025788`}, {
            1.1693165239316452`, 1.74379882223655}, {1.2411700417604874`, 
            1.8518786102028921`}, {1.3053045127125074`, 
            1.9481835415571687`}, {1.3855015917538416`, 
            2.0684291456036803`}, {1.457163185841877, 2.175757250739453}, {
            1.5463585781773026`, 2.309216244378094}, {1.6261497092429877`, 
            2.428517654881019}, {1.6282681702609472`, 2.431683121768787}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.63987835245535, 2.449031398175939}, {
            1.7251658398798533`, 2.5764704754563166`}, {1.8138336710267755`, 
            2.7088983397593043`}, {1.9232165661441736`, 2.872198063541326}, {
            2.021294681131787, 3.018576192114761}, {2.084352501871875, 
            3.1126669517225554`}, {2.104542500865913, 3.142790458032909}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.1161646496029016`, 3.1601307199577326`}, {
            2.1442237464095415`, 3.2019949310439872`}, {2.254406506877611, 
            3.3663625488277606`}, {2.374789119020647, 3.545915646649414}, {
            2.484027566636371, 3.708827755221}, {2.581158327987983, 
            3.853668977746809}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{2.5927851860946762`, 3.871006082331442}, {
            2.6769015066943567`, 3.9964320192567637`}, {2.7633498559211893`, 
            4.125327719409352}, {2.844672317104089, 4.246575675947381}, {
            2.859505384523472, 4.268690597640949}, {2.943672744994155, 
            4.3941729879682}, {3.0234368963773233`, 4.5130876018658626`}, {
            3.0578988207204687`, 4.56446390082452}}]}, 
          {Arrowheads[{{0.012093489231333895`, 1.}}], 
           ArrowBox[{{3.0695273575551014`, 4.581799879480822}, {
            3.101326960754954, 4.62920715437629}, {3.17546885112151, 
            4.739736584112245}, {3.246252168523532, 4.8452571867838685`}, {
            3.314066514007562, 4.946350258101294}, {3.350793715862094, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.0931132235820422`, -0.19169233665610186`}, {
            1.130481365692197, -0.1986389047539739}, {
            1.1645297370260508`, -0.20494559360188883`}, {
            1.280007727293945, -0.22621430977004914`}, {
            1.4111332713833185`, -0.2501619923776998}, {
            1.5602378488285962`, -0.27720679624624384`}, {
            1.7278234696779788`, -0.3074424253153054}, {
            1.9146451173639676`, -0.34101565863865246`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.9351918983971321`, -0.3447019575361763}, {
            2.0348541724489437`, -0.36257048865236824`}, {
            2.136750185354813, -0.3808187400508648}, {
            2.264413318783698, -0.40365848107643953`}, {
            2.3784020026691612`, -0.42403592989096345`}, {
            2.5205924332847696`, -0.44943751702422036`}, {
            2.6477448422277523`, -0.47214077115304326`}, {
            2.7571504507796116`, -0.4916663492820028}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7777005827270442`, -0.49533392366151763`}, {
            2.8052186759675006`, -0.5002450674926113}, {
            2.9462682097093653`, -0.5254093730680579}, {
            3.1234794054355977`, -0.5570155462292303}, {
            3.28219155278094, -0.5853157707553884}, {
            3.4575604149084493`, -0.6165798621307018}, {
            3.59972651348165, -0.6419211218546423}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.6202774354853795`, -0.6455842666314746}, {
            3.7618679988462747`, -0.6708199876419858}, {
            3.896655656173209, -0.6948413514435985}, {
            4.022107738205006, -0.7171973963091198}, {
            4.140070077092337, -0.7382177032116723}, {
            4.179036447687811, -0.7451611158898949}, {
            4.301722007340504, -0.767021458326514}, {
            4.417952309491378, -0.7877309323961317}, {
            4.442320956512039, -0.7920727956011951}}]}, 
          {Arrowheads[{{0.013094794845713546`, 1.}}], 
           ArrowBox[{{4.462872137867976, -0.7957344850693989}, {
            4.531438274797588, -0.8079511988982632}, {
            4.639435566414467, -0.8271930502654224}, {
            4.841258471638916, -0.8631506915124201}, {
            5.001099999999999, -0.8916278324051929}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.17809628963337645`, 
            1.1532165018505969`}, {-0.1890120342581242, 
            1.1996979549143636`}, {-0.22408120713631122`, 
            1.3597147077602707`}, {-0.25948527242561875`, 
            1.5363726604655796`}, {-0.29634337755519957`, 
            1.7308231139167933`}, {-0.3171900249200095, 
            1.8439857393648016`}, {-0.33555965015400757`, 
            1.9449740578583448`}, {-0.3404534146273986, 1.972174721380121}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.344149732541397, 
            1.9927197027323837`}, {-0.35798927705534245`, 
            2.069643060132464}, {-0.3778749545319676, 
            2.1810507305946123`}, {-0.40224094628335744`, 
            2.3184967759028816`}, {-0.4239343294365253, 
            2.4414771602301397`}, {-0.45057569402129516`, 
            2.5931588273566994`}, {-0.4743647424299124, 
            2.7290276723801243`}, {-0.48937425128447976`, 
            2.8149864496936527`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.49296493894398996`, 
            2.835550155269692}, {-0.5035097378858917, 
            2.8959397411545784`}, {-0.5295989175932077, 
            3.04564982242246}, {-0.5621586104744131, 
            3.2328140855578993`}, {-0.5913133835300846, 
            3.400621959140731}, {-0.6228327691171118, 
            3.582237887289841}, {-0.6360061435274625, 3.6582004926680027`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-0.6395730039899419, 
            3.678768344556991}, {-0.6514388308449623, 
            3.747191141540981}, {-0.677642396461593, 
            3.8983846594004525`}, {-0.7019542937149605, 
            4.038721378374556}, {-0.7245980536787091, 
            4.169477450235288}, {-0.7458998695753384, 
            4.292516428631512}, {-0.7520672384806131, 
            4.3281443709163145`}, {-0.7741447131772334, 
            4.455712142075459}, {-0.7820699363196585, 4.501513175080631}}]}, 
          {Arrowheads[{{0.011643996297190456`, 1.}}], 
           ArrowBox[{{-0.7856291425922888, 
            4.52208235288615}, {-0.7950691164241378, 
            4.576637353454648}, {-0.815502660083359, 
            4.694732902338856}, {-0.8349544845672142, 
            4.807169126233102}, {-0.868499804775465, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.17740469907265508`, -1.1534472318915008`}, \
{-0.18828526512912347`, -1.1999180547828905`}, {-0.223237305355215, \
-1.3598965975508124`}, {-0.2585208926823138, -1.5365329465909252`}, \
{-0.2952506484027306, -1.7309730791483147`}, {-0.3160237109002134, \
-1.844134180735356}, {-0.33432772119515025`, -1.9451210617364287`}, \
{-0.33923753202023316`, -1.9725093586397597`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.34292097833933577`, -1.993056651602592}, \
{-0.35667692734621476`, -2.0697911794713146`}, {-0.37649075189986136`, \
-2.181199794985268}, {-0.4007684488054865, -2.31864888569051}, \
{-0.42238282945039785`, -2.4416319631037684`}, {-0.44892697929413977`, \
-2.5933182195644346`}, {-0.4726289433822783, -2.7291911575848236`}, \
{-0.4876289254594089, -2.815414465792208}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.49120671595601106`, -2.8359804192116}, \
{-0.5016671010466728, -2.896109091566159}, {-0.5276604497044524, \
-3.0458244281174656`}, {-0.5601004367868746, -3.232995860637592}, \
{-0.5891478810020679, -3.400810164816956}, {-0.6205512668963046, \
-3.5824340007330604`}, {-0.633731491143586, -3.6587203856124253`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.637285445689322, -3.6792904714647743`}, \
{-0.6490519623932809, -3.747394397856834}, {-0.6751589449902096, \
-3.898594438208334}, {-0.6993811921843034, -4.038937203807616}, \
{-0.7219414208365852, -4.16969890560019}, {-0.7431646347515655, \
-4.292743182564803}, {-0.7493103887913861, -4.328379303059632}, \
{-0.7713064014416917, -4.455952766636391}, {-0.7792659431377856, \
-4.502124580032164}}]}, 
          {Arrowheads[{{0.011627819859748499`, 1.}}], 
           ArrowBox[{{-0.7828122403823742, -4.52269598739139}, \
{-0.7921535845518413, -4.576883378616438}, {-0.812511715339665, \
-4.694984204315039}, {-0.8318917414828372, -4.807425457450749}, \
{-0.8652675545006445, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.28681762967782337`, 1.2449966909237553`}, {
            0.31299490451878675`, 1.385334832209428}, {0.34508362725492314`, 
            1.5478333247456086`}, {0.3825694047359873, 1.7305598884108215`}, {
            0.4255281768908987, 1.9348610227612557`}, {0.4511341337838729, 
            2.0550614996408343`}, {0.452894358842701, 2.063275126533171}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.4572686307157245, 2.0836865147874533`}, {
            0.4741315277077934, 2.1623727847744116`}, {0.5028664508010225, 
            2.295764300713301}, {0.5286562511106293, 2.4150267424955056`}, {
            0.5607330455988471, 2.562872020989068}, {0.5895187872008696, 
            2.695223370185342}, {0.6250772516679873, 2.858367567452515}, {
            0.6341085831061455, 2.899738702062562}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.6385607188165088, 2.9201332482085953`}, {
            0.6570052321094594, 3.004624715218147}, {0.6970581567728145, 
            3.187850492223947}, {0.7329912796236614, 3.3520616471316966`}, {
            0.7722159691278544, 3.5311595133365823`}, {0.8078336947292413, 
            3.693690071041947}, {0.8170713232925451, 3.735822131855488}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{0.8215420214723947, 3.756212616956899}, {
            0.8404743429749956, 3.8425613714476077`}, {0.8707678004122906, 
            3.98068146575338}, {0.8989904927360639, 4.109321855179237}, {
            0.9255459490745134, 4.230337664039294}, {0.9334429632002806, 
            4.266320797339456}, {0.96101047107649, 4.391909998584037}, {
            0.9871404406737516, 4.5109342943235164`}, {1.0005038070442638`, 
            4.571802657067791}}]}, 
          {Arrowheads[{{0.01002763540512455, 1.}}], 
           ArrowBox[{{1.0049801704710493`, 4.59219189921549}, {
            1.0126581566451736`, 4.6271641086599145`}, {1.0369513653649163`, 
            4.73780496019015}, {1.0823719771954932`, 4.94464184396186}, {
            1.09477157512398, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.287462171371621, -1.2449107616492885`}, {
            0.31371155702842346`, -1.385226066008852}, {
            0.3458831193746268, -1.5476998789998848`}, {
            0.38346189114378415`, -1.7304008209168027`}, {
            0.4265247787032677, -1.9346755700899854`}, {
            0.4521921675768795, -2.054861721807637}, {
            0.4539627587211678, -2.0631030895983984`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.45834749770097716`, -2.0835122318872137`}, {
            0.4752443271114937, -2.1621599683333335`}, {
            0.5040475511133024, -2.295536438859846}, {
            0.529898353843109, -2.4147851955504844`}, {
            0.562050967932767, -2.56261447735064}, {
            0.5909045277240347, -2.6949512838012404`}, {
            0.6265467534644089, -2.858078342728575}, {
            0.6356055758435497, -2.8994736987186855`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{0.6400681513224045, -2.9198659630603836`}, {
            0.6585497734659364, -3.004319912579015}, {
            0.6986968070824714, -3.1875266607128188`}, {
            0.7347142273527417, -3.351720564503726}, {
            0.7740315341482005, -3.5308027119720906`}, {
            0.8097332289139272, -3.6933186427631086`}, {
            0.8189962414566946, -3.7354633695043686`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{0.8234773738887851, -3.7558515640544567`}, {
            0.8424507280147427, -3.8421762690369614`}, {
            0.8728154478154679, -3.9802835029538306`}, {
            0.9011044790728143, -4.108911769002027}, {
            0.9277223208066464, -4.229916075844777}, {
            0.9356376202969315, -4.265894586949396}, {
            0.9632699209845388, -4.391472079579671}, {
            0.9894612789972627, -4.510485198543373}, {
            1.002856495115501, -4.571349917880623}}]}, 
          {Arrowheads[{{0.01003992367031845, 1.}}], 
           ArrowBox[{{1.0073432912346207`, -4.591736866781123}, {
            1.0150389353605098`, -4.626704068184007}, {
            1.0393891884248032`, -4.737334439178506}, {
            1.084916409361541, -4.9441515856342155`}, {
            1.0974542297198828`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1809244111916835`, 0.2579106251599307}, {
            1.2995402650247079`, 0.2849464407958553}, {1.432767992306102, 
            0.3150652376380093}, {1.5888401344223282`, 
            0.35011641229489227`}, {1.7606221065356413`, 
            0.3885000079048025}, {1.9578481746669276`, 0.4324071935830033}, {
            1.9956407661375046`, 0.44080271248388564`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.0160188403318706`, 0.44532964489061355`}, {
            2.0747160311372626`, 0.45836906229121765`}, {2.1789182895873593`, 
            0.4814931344039771}, {2.309304746417066, 0.5104011330229595}, {
            2.4257654757472586`, 0.536203348099414}, {2.570888436879267, 
            0.5683356950476268}, {2.7007015952304663`, 0.5970645715395922}, {
            2.831244711791931, 0.6259429597764292}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.8516267907014368`, 0.6304518270635483}, {
            2.861337737277604, 0.6326000558844965}, {3.005256563074797, 
            0.6644273421114814}, {3.1859932687596744`, 0.7043857601547738}, {
            3.3478965053772223`, 0.7401728230086506}, {3.5262411334380985`, 
            0.7795869992689988}, {3.666938546312759, 0.8106771818162503}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.6873216790843055`, 0.8151812825371128}, {
            3.687918841903687, 0.8153132387734476}, {3.8358830639739847`, 
            0.8480057311366221}, {3.973087232848989, 0.8783186659731471}, {
            4.100813748915326, 0.9065358891077515}, {4.220931519916728, 
            0.9330710133196215}, {4.257502753631831, 0.9411497270006738}, {
            4.382301300146805, 0.9687170520139715}, {4.500546761337693, 
            0.9948360862444903}, {4.502656535793861, 0.995302105795137}}]}, 
          {Arrowheads[{{0.011726617941483667`, 1.}}], 
           ArrowBox[{{4.523040037817498, 0.999804535154775}, {
            4.616005327368248, 1.0203392621420784`}, {4.725890103078138, 
            1.0446107213738052`}, {4.9312641812828275`, 
            1.0899726972108075`}, {5.001099999999999, 
            1.1053970839134049`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.1212590626890069`, 
            0.8669795689214393}, {-1.2567968509487928`, 
            0.9670187744587576}, {-1.3744944795894238`, 
            1.0549121303809381`}, {-1.4789086985829325`, 
            1.1332490513668194`}, {-1.5717189134804368`, 
            1.2032083718691002`}, {-1.6546045298330545`, 
            1.2659689263404785`}, {-1.7492001513313697`, 
            1.3378057819824498`}, {-1.789106426539408, 
            1.3681559390412101`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.8057218955302838`, 
            1.38079260059003}, {-1.8350968083056494`, 
            1.4031332778813081`}, {-1.9871448925259847`, 
            1.5189387150978446`}, {-2.1197106383752735`, 
            1.6200280939271932`}, {-2.237795111924076, 
            1.7101433866241766`}, {-2.3453623425771175`, 
            1.7922684566467686`}, {-2.444519224288502, 
            1.8679951901413054`}, {-2.469636707912086, 
            1.8871830982150983`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4862250396338874`, 
            1.899855362242242}, {-2.5362693536845584`, 
            1.9380855333856084`}, {-2.621616327391613, 
            2.0033014326574965`}, {-2.7869413722438585`, 
            2.1296621761513466`}, {-2.934851235053538, 
            2.242738599636661}, {-3.0691721449531606`, 
            2.3454428757435024`}, {-3.149603657091737, 
            2.4069482883906295`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.1661858545199633`, 
            2.4196285783454172`}, {-3.193628144326982, 
            2.440613504696854}, {-3.3105007799253796`, 
            2.5299905032279315`}, {-3.419790051748355, 
            2.6135738713367354`}, {-3.521495959795906, 
            2.6913636090232655`}, {-3.617280797694137, 
            2.764628737215057}, {-3.7088068590691488`, 
            2.834638276839645}, {-3.8294244727512794`, 2.92690461102164}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.8460046209437917`, 
            2.9395875803427614`}, {-3.8790826522495165`, 
            2.9648905903872107`}, {-4.035269516991351, 
            3.0843715333853763`}, {-4.180313630948993, 
            3.1953320895535535`}, {-4.315516593652626, 
            3.298767105362031}, {-4.442780733590273, 
            3.3961306642209554`}, {-4.460174252467347, 
            3.4094377351877587`}, {-4.509187527183205, 3.44693644691732}}]}, 
          {Arrowheads[{{0.01433536520441079, 1.}}], 
           ArrowBox[{{-4.525766687480872, 
            3.4596207075859766`}, {-4.591499684429521, 
            3.5099112200642213`}, {-4.716017803623987, 
            3.6051779031480233`}, {-4.83763386733863, 
            3.6982247269253676`}, {-4.953445820093626, 
            3.7868318320897956`}, {-5.001099999999999, 
            3.8232920686894576`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.3419855882545697`, -1.042984404907991}, \
{-1.4448039476587071`, -1.1209116332971782`}, {-1.5362272893752429`, \
-1.1905644082229092`}, {-1.6178973391710425`, -1.2530973461229582`}, \
{-1.7112468003303214`, -1.3248032484439742`}, {-1.7959759312745738`, \
-1.3899929317546735`}, {-1.9458771465316516`, -1.5055070970517619`}, \
{-2.00472089136393, -1.550911807378638}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           
           ArrowBox[{{-2.0212477313791126`, -1.5636641633962034`}, \
{-2.076495374439936, -1.6062940680117122`}, {-2.1927915502609276`, \
-1.69610397815473}, {-2.2986960270615366`, -1.7779274567352474`}, \
{-2.396296129452383, -1.8533592209387975`}, {-2.486584252067334, \
-1.9231614268142685`}, {-2.570552789540259, -1.9880962304105512`}, \
{-2.6819373660805104`, -2.074255546712816}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.6984489001646446`, -2.0870277143861062`}, \
{-2.733723239397526, -2.1143134755365374`}, {-2.879617781334498, \
-2.2271955870336453`}, {-3.012047948479222, -2.3296776790177955`}, \
{-3.1347149769648843`, -2.42461435784955}, {-3.2498850504363705`, \
-2.5137545122864213`}, {-3.3575581688936813`, -2.5970981423284094`}, \
{-3.3587987791778633`, -2.598058507883125}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.37530570020312, -2.610836636977484}, \
{-3.4577343323368153`, -2.6746452479755143`}, {-3.552060367267687, \
-2.7476681075749703`}, {-3.6421831001882086`, -2.8174389994740117`}, \
{-3.809818659998202, -2.9472248801708503`}, {-3.963553751319536, \
-3.066255115548532}, {-4.035551581718954, -3.1220017912624063`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.052057101662488, -3.1347817300838474`}, \
{-4.106301113704952, -3.1767819310895598`}, {-4.239346210121499, \
-3.2797996908560902`}, {-4.364567424288626, -3.3767614998388376`}, \
{-4.382344046343478, -3.390526523694535}, {-4.511607219206109, \
-3.4906211203762125`}, {-4.634160021266996, -3.5855209179450647`}, \
{-4.712261834975825, -3.646000029599095}}]}, 
          {Arrowheads[{{0.008250129962827321, 1.}}], 
           ArrowBox[{{-4.728766717878928, -3.658780791127308}, \
{-4.753852727373124, -3.6782064548488917`}, {-4.867825241569734, \
-3.7664634704226683`}, {-4.976667991014298, -3.8507489489263858`}, \
{-5.001099999999999, -3.869668713364857}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.3816431874437916`, 
            0.5679876316012139}, {-1.5204037905175378`, 
            0.6228039722493043}, {-1.6434394817936262`, 
            0.6720956498203009}, {-1.7532069412139364`, 
            0.7162854587619197}, {-1.8792101053184966`, 
            0.7672071482979316}, {-1.9918361913401563`, 
            0.8128267874215334}, {-2.1265768765190267`, 
            0.8675068818825769}, {-2.1563119647659867`, 
            0.8795888622920984}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.1756513316206703`, 
            0.8874468464194778}, {-2.2471544068773297`, 
            0.9165000224953831}, {-2.393245236085829, 
            0.9759215517828932}, {-2.5241373460783216`, 
            1.02919929488311}, {-2.6860241790336374`, 
            1.0951331951650176`}, {-2.831032269889846, 
            1.1542183563311668`}, {-2.9490064594849152`, 
            1.202305876076522}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.968337118961523, 
            1.2101852560702535`}, {-2.9942917396203352`, 
            1.220764632268537}, {-3.141765433160317, 
            1.280891634302539}, {-3.2683580655525946`, 
            1.3325148139148884`}, {-3.3873237453924143`, 
            1.3810320205326043`}, {-3.4986624726797766`, 
            1.4264432541556875`}, {-3.6023742474146805`, 
            1.4687485147841375`}, {-3.7415038001174095`, 
            1.5255068676334893`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.7608321432480873`, 
            1.5333919279825896`}, {-3.7935407325993933`, 
            1.546735503229846}, {-3.96744699431883, 
            1.6176873720424385`}, {-4.127058481840817, 
            1.6828118552499636`}, {-4.275340644433177, 
            1.7433166868804701`}, {-4.413609737814731, 
            1.7997382397174462`}, {-4.533945776410334, 
            1.848843587541211}}]}, 
          {Arrowheads[{{0.011585277897473977`, 1.}}], 
           ArrowBox[{{-4.5532733182238765`, 
            1.8567306118424538`}, {-4.569971673269989, 
            1.8635447958656077`}, {-4.704441824565974, 
            1.9184201609344846`}, {-4.831967289623094, 
            1.9704625126601751`}, {-4.956530110885139, 
            2.0212961461152728`}, {-5.001099999999999, 
            2.0394852002959185`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.127628004422163, -1.4089137431037912`}, \
{-1.2638473698618773`, -1.5760245469955771`}, {-1.3769706507286266`, \
-1.7155417431601772`}, {-1.455498902812141, -1.8127086024434442`}, \
{-1.5266162526232259`, -1.9008324828667333`}, {-1.6522081227353913`, \
-2.0566781557673024`}, {-1.6531206178684765`, -2.0578118156299854`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6662096638559885`, -2.074073300802717}, \
{-1.7615244662168728`, -2.1924898948625233`}, {-1.8588158830657513`, \
-2.3134538494928614`}, {-1.947409876291499, -2.423652357505647}, \
{-2.029063106939981, -2.5252482186445477`}, {-2.1046055203210736`, \
-2.619268018964}, {-2.1748670617446533`, -2.7067383445184414`}, \
{-2.189398139149719, -2.7248329931769897`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.202468889771527, -2.7411091875438762`}, \
{-2.3107134829992497`, -2.875899460077993}, {-2.432278997465954, \
-3.0273133095012184`}, {-2.5427015774847512`, -3.1648708410717994`}, \
{-2.6450331643053193`, -3.2923617854768517`}, {-2.7251959743441234`, \
-3.392239610970502}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7382622638501637`, -3.4085193868728454`}, \
{-2.7411427815939446`, -3.4121083310279396`}, {-2.831030429350627, \
-3.524110477725064}, {-2.9146961075753675`, -3.628368225568224}, \
{-2.9935023344314846`, -3.7265761715181105`}, {-3.068811628082299, \
-3.8204289125354127`}, {-3.1406239885278096`, -3.9099264486201313`}, \
{-3.2089394157680173`, -3.9950687797722657`}, {-3.2608470268223706`, \
-4.059764044510468}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.273910657337411, -4.076045954185093}, \
{-3.3374959021504447`, -4.155295685834565}, {-3.456897518747502, \
-4.304117489278091}, {-3.5682123855123384`, -4.442864253579085}, \
{-3.6730017793711442`, -4.573480255717577}, {-3.6854950136082905`, \
-4.5890527680739135`}, {-3.7935490526995848`, -4.723741935473315}, \
{-3.796434891316247, -4.727339178846745}}]}, 
          {Arrowheads[{{0.007906461876519928, 1.}}], 
           ArrowBox[{{-3.8094974910333073`, -4.743621915518387}, \
{-3.896011812745168, -4.851463382705059}, {-3.996090426098604, \
-4.9762135980343505`}, {-4.016054872052618, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.1289276798832113`, 
            1.4077604390929221`}, {-1.265299055797098, 
            1.5747308101899433`}, {-1.3785521950301898`, 
            1.7141346429633129`}, {-1.4571977453247933`, 
            1.811255836518158}, {-1.5284196820438807`, 
            1.899336193470969}, {-1.6541930155827274`, 
            2.055100728052558}, {-1.6550425533878181`, 
            2.0561540988149787`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.6681472095496472`, 
            2.0724030068326393`}, {-1.7636645611347364`, 
            2.1908382134363396`}, {-1.8610923044107561`, 
            2.3117337037438843`}, {-1.9498093591111654`, 
            2.4218684494938305`}, {-2.0315752686917024`, 
            2.5234045691265976`}, {-2.107221266951191, 
            2.6173682296692484`}, {-2.1775785876884552`, 
            2.704785598148846}, {-2.19196078671838, 2.7226596441730813`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.20504717402631, 
            2.7389232689877723`}, {-2.313626505504056, 
            2.873864522691457}, {-2.435369686126984, 
            3.0252014695463436`}, {-2.545951829167348, 
            3.162686846971237}, {-2.6484301801243424`, 
            3.290109523733048}, {-2.728399969586157, 
            3.3895508772601635`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7414819030081414`, 
            3.405818084851786}, {-2.744676967109743, 
            3.4097911039257065`}, {-2.8346921901235502`, 
            3.521731587549212}, {-2.918475849165764, 
            3.6259309746035644`}, {-2.997392667869488, 
            3.7240832711173337`}, {-3.072807369867827, 
            3.8178824831190887`}, {-3.144719955160781, 
            3.9073286106088294`}, {-3.2131304237483493`, 
            3.9924216535865558`}, {-3.2646926120023716`, 
            4.056559963468783}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.27777189119243, 
            4.0728293052119104`}, {-3.3418651711194345`, 
            4.152555065280015}, {-3.461431772293187, 
            4.301289297473513}, {-3.572899954487609, 
            4.439953796294202}, {-3.677833333288611, 
            4.570491922789907}, {-3.6903384851226106`, 
            4.586048620841236}, {-3.7985417017037713`, 
            4.720658356928659}, {-3.800922149229119, 4.72361978386235}}]}, 
          {Arrowheads[{{0.008027255898625173, 1.}}], 
           ArrowBox[{{-3.814000399623581, 
            4.739889952623182}, {-3.901145627511032, 
            4.848304115195747}, {-4.001362009160581, 
            4.972980259926849}, {-4.023964788596927, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.582101556640065, -0.23456539241163946`}, \
{-1.7328686573157017`, -0.25633255059721977`}, {-1.8658763641979768`, \
-0.27570850919361056`}, {-1.9847688918929978`, -0.2930852292998329}, \
{-2.1232651827968017`, -0.313380759844172}, {-2.2472414544412174`, \
-0.33157826566003185`}, {-2.3959039156070627`, -0.35342892423583666`}, \
{-2.408326434737531, -0.3552564707495763}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.428978981425707, -0.35829478281039234`}, \
{-2.529135064410203, -0.37302930632899167`}, {-2.692871751040962, \
-0.3971360662071141}, {-2.8395839284797284`, -0.4187480049680067}, \
{-3.005040056053105, -0.4431321500528512}, {-3.154477092497303, \
-0.46516231953355913`}, {-3.255056409951518, -0.47999323914597525`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-3.2757079463378957`, -0.4830384106958685}, \
{-3.281363637304674, -0.4838723704025363}, {-3.4006494142808843`, \
-0.501463505584588}, {-3.5123344234259335`, -0.5179357250797143}, \
{-3.616418664739821, -0.5332890288879153}, {-3.8083511238901786`, \
-0.5616041642673796}, {-3.983013071748022, -0.587374186546819}, \
{-4.101761890793474, -0.6048961971353581}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.12241312822217, -0.6079433954468927}, \
{-4.1433615502191, -0.6110344448989542}, {-4.292353601209162, \
-0.6330202884965054}, {-4.431305094396145, -0.6535255793957299}, \
{-4.562141479033357, -0.6728340172268221}, {-4.5937037359711255`, \
-0.6774919741738564}, {-4.728949484993698, -0.6974521762291739}, \
{-4.8572205339774905`, -0.7163834637267559}, {-4.9484599590144835`, \
-0.7298493965043706}}]}, 
          {Arrowheads[{{0.0007745072129945434, 1.}}], 
           ArrowBox[{{-4.969111095842509, -0.7328972765210934}, \
{-4.982515082205995, -0.7348755570642861}, {-5.001099999999999, \
-0.7376185184955671}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.541917255764954, -0.6724613125854118}, \
{-1.6633299019600065`, -0.724368157663744}, {-1.7716776629102615`, \
-0.7708875976390455}, {-1.8975069919160688`, -0.8250979799141434}, \
{-2.0099845295114727`, -0.8736571131989038}, {-2.145067247397483, \
-0.9320760766858359}, {-2.2659548806821777`, -0.984416118924155}, \
{-2.3087219460546953`, -1.0029506163211064`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.3278754311515497`, -1.0112514014364282`}, \
{-2.4126618874223342`, -1.0479963672029462`}, {-2.5441108649294217`, \
-1.1050021699002017`}, {-2.706839625938018, -1.1756133555104002`}, \
{-2.852606105770869, -1.2388900469537665`}, {-3.0167431017009703`, \
-1.310165782327082}, {-3.0938521180437943`, -1.3436579472544552`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.1129988503662767`, -1.3519742965891919`}, \
{-3.1650177552613674`, -1.3745686159660833`}, {-3.2923564997926875`, \
-1.4298876969707408`}, {-3.4120256068970836`, -1.481879153601724}, \
{-3.5240250765745555`, -1.530542985859033}, {-3.6283549088251035`, \
-1.5758791937426675`}, {-3.820666483576114, -1.6594555843869432`}, \
{-3.8788231268962066`, -1.6847318874516346`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.897967925886304, -1.6930526864826736`}, \
{-3.995621153680802, -1.7354951735325805`}, {-4.156200562700155, \
-1.8052916978380338`}, {-4.305386354195159, -1.870138893961757}, \
{-4.444501993275006, -1.9306113200456305`}, {-4.575483281530509, \
-1.9875494366553808`}, {-4.600593885150341, -1.9984652885900371`}, \
{-4.663745166656401, -2.025918510693613}}]}, 
          {Arrowheads[{{0.008310949165557257, 1.}}], 
           ArrowBox[{{-4.682889286600871, -2.034240871923331}, \
{-4.735852314822709, -2.057265040908921}, {-4.8641279842250205`, \
-2.113030265963839}, {-4.989424650365012, -2.1675006923994578`}, \
{-5.001099999999999, -2.1725763889271428`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5881113495519477`, 
            0.18855388949772697`}, {-1.7395171598103767`, 
            0.2060599330874356}, {-1.8731294937948193`, 
            0.221647518784334}, {-1.992568630986254, 
            0.2356273900134093}, {-2.131620013514897, 
            0.25194581378808384`}, {-2.256099842472463, 
            0.2665780430194769}, {-2.405331820254554, 
            0.28414357390815437`}, {-2.4174494732036007`, 
            0.28557119204152526`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.438180935366327, 
            0.2880136296521129}, {-2.5390797470330737`, 
            0.29990083039772863`}, {-2.703418050559401, 
            0.3192768783093505}, {-2.8506765607091036`, 
            0.3366485097790784}, {-3.0167906716816395`, 
            0.35625333753761285`}, {-3.1668238935854, 
            0.3739657717275016}, {-3.2674236405290698`, 
            0.3858449683072148}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.288154449923593, 
            0.38829294027072286`}, {-3.2940943445828212`, 
            0.38899434537822547`}, {-3.4137469394076256`, 
            0.403124858193648}, {-3.525781678059812, 
            0.4163573101737692}, {-3.6301985605393807`, 
            0.42869170131858897`}, {-3.8227559603039607`, 
            0.4514405984532504}, {-3.997996342024661, 
            0.4721458469485582}, {-4.1173819733595085`, 
            0.48625290065003446`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.138112589579718, 
            0.4887025079688829}, {-4.158883385072733, 
            0.4911568630212134}, {-4.30838076881943, 
            0.5088230628879171}, {-4.447807699875776, 
            0.5253000883784424}, {-4.579094603138326, 
            0.540815716933916}, {-4.610783926309871, 
            0.5445608711885443}, {-4.746488817114489, 
            0.560599458306309}, {-4.875197710178553, 
            0.575811562427984}, {-4.967335516726419, 0.5867013695560976}}]}, 
          {Arrowheads[{{0.00031436528319460865`, 1.}}], 
           ArrowBox[{{-4.98806606847618, 
            0.5891515224159554}, {-5.000920757946342, 
            0.5906708237132913}, {-5.001099999999999, 
            0.590692008575152}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3475648988856967`, -1.09316343781182}, {
            1.5011424125894992`, -1.219462808410664}, {
            1.594387428281728, -1.2958944854061625`}, {
            1.6772509682542605`, -1.363708008943818}, {
            1.7814104562874757`, -1.4488295528531883`}, {
            1.8741625514512732`, -1.5245482708376485`}, {
            1.9901123034503123`, -1.6191165066203803`}, {
            1.9937052289030324`, -1.6220448446237576`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.0098864403244496`, -1.6352329992263384`}, {
            2.0935468582923034`, -1.7034186558834317`}, {
            2.222301636860047, -1.8082937115443702`}, {
            2.3373382200600488`, -1.9019523087292662`}, {
            2.4800506254278143`, -2.018097596747072}, {
            2.6077347040543826`, -2.121981563708428}, {
            2.657426807899934, -2.162400760712418}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6736209870187997`, -2.1755729886011337`}, {
            2.765799930880034, -2.2505506732475142`}, {
            2.9073884482153187`, -2.365695691229984}, {
            2.996807160725528, -2.4384041630401363`}, {
            3.0817363230230663`, -2.507458228097917}, {
            3.2381259969801324`, -2.634603137956362}, {
            3.321472796506343, -2.702358018006548}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.337670666461872, -2.7155257070137333`}, {
            3.338573774136497, -2.7162598678035232`}, {
            3.433962050334926, -2.7938007525357733`}, {
            3.52429082557542, -2.8672257921531115`}, {
            3.6095600998579793`, -2.9365349866555386`}, {
            3.7069745705629584`, -3.0157133479869493`}, {
            3.8000200329663443`, -3.0913389252413}, {
            3.8886964870681364`, -3.1634117184185895`}, {
            3.973003932868335, -3.231931727518819}, {
            3.9856228121334434`, -3.242187321347685}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.0018223384906975`, -3.25535297251604}, {
            4.13156045502031, -3.360793511195953}, {
            4.278738254878627, -3.4804043939805602`}, {
            4.415875708820958, -3.591852845057815}, {
            4.544926889756632, -3.696727994106522}, {
            4.560700650734316, -3.7095466393477348`}, {
            4.649814902075539, -3.7819648573099154`}}]}, 
          {Arrowheads[{{0.010342001503413934`, 1.}}], 
           ArrowBox[{{4.666015012356693, -3.7951297899631653`}, {
            4.693925588544221, -3.817811169870168}, {
            4.820218896203106, -3.920441606873458}, {
            4.943559522582733, -4.020672177142771}, {
            5.001099999999999, -4.067431010317821}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3822766433716585`, 1.6810106418151043`}, {
            1.4678470523942686`, 1.785715122103272}, {1.5441529156482852`, 
            1.8789629996269546`}, {1.6395733003275643`, 
            1.9954378407726372`}, {1.7247738341628138`, 
            2.0993501725070676`}, {1.8308490959668011`, 2.228626703809935}, {
            1.9115037763848124`, 2.326868739292669}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.9247495331366706`, 2.3430028321694554`}, {
            1.9256813658989635`, 2.344137858020686}, {2.043337743516566, 
            2.487381821771344}, {2.148647934609655, 2.615549118901195}, {
            2.2790181022374223`, 2.7741666336310966`}, {2.3958311104867924`, 
            2.9162569104158864`}, {2.454903803732093, 2.988100395812002}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.4681617137424348`, 3.0042245034475847`}, {
            2.4695994467646423`, 3.005973056725079}, {2.5396699792026363`, 
            3.091186296580554}, {2.6687176325590563`, 3.2481040569303485`}, {
            2.7516012773310816`, 3.348876985610418}, {2.8303147239931454`, 
            3.4445754505327595`}, {2.9048579725452477`, 3.535199451697374}, {
            2.975231022987389, 3.6207489891042615`}, {2.9985666820500185`, 
            3.6491159724736795`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.0118283718972063`, 3.6652369714279365`}, {
            3.055580068298838, 3.7184218264550837`}, {3.132329856017342, 
            3.811716940887774}, {3.2054803861428995`, 3.9006343324023325`}, {
            3.2750316586755117`, 3.985174000998759}, {3.4058452135171313`, 
            4.14417306162519}, {3.5272793030974343`, 4.29176701495504}, {
            3.5423248258956535`, 4.310053186845323}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5555879283717, 4.326173023618568}, {
            3.6404361440365447`, 4.4292966622610725`}, {3.74692521327264, 
            4.558719761576499}, {3.759634753703148, 4.574166335761107}, {
            3.8695553795303437`, 4.707756396113181}, {3.9737600761518066`, 
            4.834398028607296}, {4.075529674555109, 4.958079659372458}, {
            4.086124845873471, 4.97095594746838}}]}, 
          {Arrowheads[{{0.00043502720958659986`, 1.}}], 
           ArrowBox[{{4.099388545905918, 4.987075292564737}, {
            4.110928686733737, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3833776959704067`, -1.6801942552408613`}, {
            1.4690208179980708`, -1.784852796631315}, {
            1.5453908643137306`, -1.8780590708870661`}, {
            1.6408925008202884`, -1.9944832751820398`}, {
            1.726164950718449, -2.0983497416679873`}, {
            1.8323307042892465`, -2.227570463883126}, {
            1.9130118437650656`, -2.3257186238285263`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.9262677590233843`, -2.3418443714251636`}, {
            1.9272432585699257`, -2.3430310612282903`}, {
            2.045000161942961, -2.486213510839455}, {
            2.1503997274943667`, -2.614325078694898}, {
            2.2808814169180467`, -2.772874738686941}, {
            2.3977937558186464`, -2.9149035402849273`}, {
            2.4568279246799656`, -2.986608148237508}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.4700959784631635`, -3.002723909891626}, {
            2.47162534476235, -3.0045815224067898`}, {
            2.5417558162287675`, -3.0897583454893978`}, {
            2.6709134067297433`, -3.24660851453685}, {
            2.753867925566145, -3.3473383677498103`}, {
            2.832648544190187, -3.4429957650870326`}, {
            2.9072552626018675`, -3.533580706548517}, {
            2.977688080801188, -3.619093192134264}, {
            3.0009065560983683`, -3.647281562783584}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.01417838500736, -3.66339421564699}, {
            3.058108995849137, -3.7167281372507683`}, {
            3.13492721053474, -3.8099867890227683`}, {
            3.208142724857997, -3.8988691474502635`}, {
            3.2777555388189077`, -3.983375212533254}, {
            3.4086843700343317`, -4.142310504728623}, {
            3.5302250085616538`, -4.289844707671775}, {
            3.5450803473201526`, -4.307876601584167}}]}, 
          {Arrowheads[{{0.020000000000000014`, 1.}}], 
           ArrowBox[{{3.5583535870925025`, -4.323988092230034}, {
            3.643480744184022, -4.427318207462819}, {
            3.750062612043973, -4.5566881453156824`}, {
            3.7627801065481887`, -4.5721245860101485`}, {
            3.8727970952662605`, -4.705660473631605}, {
            3.977092916575122, -4.83225047694403}, {
            4.078951423061143, -4.955881579654132}, {
            4.089295969754759, -4.968437179446122}}]}, 
          {Arrowheads[{{0.0005136808008447861, 1.}}], 
           ArrowBox[{{4.1025698063902585`, -4.98454817835557}, {
            4.116206836456671, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.6268890926342445`, 1.3423616769733342`}, {
            1.7115941937515553`, 1.4126755222239664`}, {1.8179253617905387`, 
            1.5008274736464513`}, {1.9126462273990175`, 1.579278054429665}, {
            2.0309341037120174`, 1.6771644599980966`}, {2.1364881540215572`, 
            1.7644579172826373`}, {2.267776330939382, 1.872973505266437}, {
            2.270055620962713, 1.8748566639246302`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.2861484003341577`, 1.8881525834862167`}, {
            2.3851092731292622`, 1.9699144578062506`}, {2.530581203730493, 
            2.090060774058718}, {2.6607664561661104`, 2.1975529184851292`}, {
            2.8218503679657387`, 2.330526662787612}, {2.930015401140496, 
            2.4198006864637622`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.946114928969508, 2.43308843377356}, {
            2.9661747307531927`, 2.4496447936877868`}, {3.0572818881287827`, 
            2.524830589289099}, {3.143822391936866, 2.5962441616551297`}, {
            3.303203438850513, 2.7277546366813468`}, {3.4055499289807383`, 
            2.8121971218056947`}, {3.5027485867282513`, 
            2.8923896454280813`}, {3.590167934599601, 2.9645112068582704`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.6062703677288543`, 2.9777954333004577`}, {
            3.681702405075139, 3.0400248081669705`}, {3.7807705477170033`, 
            3.1217507214112725`}, {3.875407947716891, 3.199819955599976}, {
            3.9656146050748013`, 3.27423251073308}, {4.051390519790735, 
            3.3449883868105847`}, {4.2127349197449036`, 
            3.4780769272337624`}, {4.250390315485457, 3.5091370676517757`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.2664937781054055`, 3.52242004610294}, {
            4.362525946027625, 3.6016324023044732`}, {4.502119839643264, 
            3.716774237105638}, {4.633497267770221, 3.825137183472614}, {
            4.648403112378938, 3.837431751334389}, {4.783962009868185, 
            3.9492413502499892`}, {4.91064242916682, 4.053726883122909}}]}, 
          {Arrowheads[{{0.002308554871932031, 1.}}], 
           ArrowBox[{{4.926746361485775, 4.06700929211949}, {
            5.001099999999999, 4.128335613096852}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.8860826607112499, 
            1.7531092923034315`}, {-0.9823619840141704, 
            1.9406698029977796`}, {-1.0630704805739193`, 
            2.098632356578444}, {-1.1332777674654282`, 
            2.236397344499548}, {-1.1957403470458123`, 
            2.359166954645199}, {-1.25260847617843, 
            2.4710471902489672`}, {-1.2656994526749341`, 
            2.496818870089157}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.2751532916022785`, 
            2.515430263224062}, {-1.3050148667693307`, 
            2.57421754734565}, {-1.3985781295635893`, 
            2.75857942305448}, {-1.4854635244440857`, 
            2.929928087882168}, {-1.5632332537576965`, 
            3.0833789682287733`}, {-1.6338876488955019`, 
            3.2228403970018116`}, {-1.6527856648650268`, 
            3.2601504477491496`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6622180774527278`, 
            3.2787727090957626`}, {-1.6993733957992245`, 
            3.3521278599897397`}, {-1.7608826278076255`, 
            3.4735808649047324`}, {-1.8184153449207046`, 
            3.58719941174679}, {-1.871971547138462, 
            3.692983500515912}, {-1.922421273668827, 
            3.792644350825574}, {-1.9706345637197296`, 
            3.88789318228925}, {-2.039384937826386, 4.023728809743162}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-2.0488116646583183`, 
            4.042353949906991}, {-2.0603518343831473`, 
            4.065154788678645}, {-2.142667659347877, 
            4.22781121160564}, {-2.219126338833081, 
            4.378905342991779}, {-2.2904107810670773`, 
            4.519783941443739}, {-2.3575192820388184`, 
            4.652415998586113}, {-2.3689146882455447`, 
            4.674938244110845}, {-2.425811130829669, 4.787394781853498}}]}, 
          {Arrowheads[{{0.005236539460727719, 1.}}], 
           ArrowBox[{{-2.435235076430071, 
            4.806021329418917}, {-2.4381896952590374`, 
            4.8118611708705785`}, {-2.503883253377649, 
            4.941709340246362}, {-2.533930098744781, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.8843831807093679, -1.75379385533131}, \
{-0.9804676142256216, -1.9414014600322502`}, {-1.0610125829147623`, \
-2.099404766221749}, {-1.1310777028283054`, -2.237206175379318}, \
{-1.1934139283182517`, -2.3600089223347194`}, {-1.2501671347134278`, \
-2.4719198096988837`}, {-1.2633108223601852`, -2.497854797040123}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.2727473978059698`, -2.516474949261364}, \
{-1.3024677141274235`, -2.5751187673655376`}, {-1.3958423099997876`, \
-2.759532593033133}, {-1.482548720367269, -2.930922377711276}, \
{-1.5601587975343574`, -3.084411351254716}, {-1.6306685400067114`, \
-3.2239082895785214`}, {-1.649688311315915, -3.2615453554644067`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-1.6591034326088876`, -3.280176364989518}, \
{-1.6960204618522814`, -3.3532292234785372`}, {-1.7574041479454667`, \
-3.4747140112473796`}, {-1.8148195982862674`, -3.5883626528850474`}, \
{-1.8682668128746829`, -3.694175148391541}, {-1.9186139971216092`, \
-3.7938630351713187`}, {-1.9667293564379413`, -3.8891378506288397`}, \
{-2.035578339709997, -4.025482393925416}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.044987767179153, -4.044116279714184}, \
{-2.056264600278824, -4.066448267577111}, {-2.1384136271705723`, \
-4.229149943072147}, {-2.214717519886427, -4.3802864209497425`}, \
{-2.285857772547806, -4.521204768497981}, {-2.3528306167300292`, \
-4.653874433425953}, {-2.3642087441166133`, -4.676414470016247}, \
{-2.421295075183458, -4.789506948225422}}]}, 
          {Arrowheads[{{0.005177176873040228, 1.}}], 
           ArrowBox[{{-2.4307017171707925`, -4.808142240318874}, \
{-2.4333436349926663`, -4.813376085761679}, {-2.4989043969519242`, \
-4.9432611051721995`}, {-2.528098735058014, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.5480576961967325`, -0.8041245088064829}, {
            1.7239840925507346`, -0.896561234001869}, {
            1.8284755994684507`, -0.9513143545721306}, {
            1.9214926931077774`, -0.9999905436822725}, {
            2.038197154652662, -1.0609910594334881`}, {
            2.1422849524159795`, -1.1153484474888147`}, {
            2.2722078765725793`, -1.18314442794931}, {
            2.287857788312384, -1.1913059690408274`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.306366867284586, -1.2009585863277066`}, {
            2.3882760383162194`, -1.2436748058349714`}, {
            2.53255133287613, -1.3188762879097067`}, {
            2.6616275294801772`, -1.3861290987321737`}, {
            2.821636908733299, -1.4694705542299096`}, {
            2.9649649888102934`, -1.544104286679332}, {
            3.0468906774790163`, -1.5867550267533475`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0654066175395096`, -1.596394476351867}, {
            3.1416166824403984`, -1.6360696468866567`}, {
            3.300074510697731, -1.718549356298589}, {
            3.4019160070660974`, -1.7715529040598448`}, {
            3.498628748382229, -1.8218846688685535`}, {
            3.676667965857786, -1.9145328496283285`}, {
            3.7755365147195414`, -1.9659780244750524`}, {
            3.806093598660618, -1.9818775925896033`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.8246116566465784`, -1.9915129728786625`}, {
            3.869969735577954, -2.01511384614606}, {
            4.045530193284748, -2.1064574299609236`}, {
            4.206446391082976, -2.1901770504464286`}, {
            4.355815381077448, -2.267886156976083}, {
            4.494995902363773, -2.3402923246804774`}, {
            4.565352235397944, -2.3768930896733638`}}]}, 
          {Arrowheads[{{0.011264891972794287`, 1.}}], 
           ArrowBox[{{4.5838710786686026`, -2.3865269605881583`}, {
            4.625971583314577, -2.40842848117879}, {
            4.6487609017279, -2.4202837918103426`}, {
            4.784153501018079, -2.490715430187534}, {
            4.9125050526270915`, -2.5574832745660445`}, {
            5.001099999999999, -2.6035694866876464`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8552086047644147`, 1.0171896173010353`}, {
            1.9498798705867721`, 1.0693642107543926`}, {2.0685151420537573`, 
            1.134675108566468}, {2.1743562255449906`, 1.1928947308739404`}, {
            2.3063402156666606`, 1.2654423535039978`}, {2.424279110561908, 
            1.3302345295596851`}, {2.570770869309723, 1.4106744941631009`}, {
            2.5868820475829617`, 1.4195181211019705`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.60518131313662, 1.4295628164723067`}, {
            2.701858169151232, 1.482629949969065}, {2.8642676382260173`, 
            1.5717506569915136`}, {3.009772838152931, 1.6515765365311896`}, {
            3.189028791554194, 1.7498983463319884`}, {3.337244422831409, 
            1.8311820793499267`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.3555476722708777`, 1.841219513515841}, {
            3.4531815950462668`, 1.8947574713763158`}, {3.551316274706598, 
            1.9485675694572926`}, {3.7319923318066963`, 
            2.0476297595017643`}, {3.832135470732999, 2.1025328597844593`}, {
            3.9277968114390363`, 2.1549773939689256`}, {4.087716383774968, 
            2.242646239857689}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.106021106716476, 2.2526809866366166`}, {
            4.268747523783026, 2.341884100515365}, {4.420140419939657, 
            2.4248716341763523`}, {4.561224868698032, 2.5022061584483457`}, {
            4.6940044339810285`, 2.5749868680657775`}, {4.71537612599256, 
            2.5867012426683464`}, {4.838227905352967, 2.6540382385361245`}}]}, 
          {Arrowheads[{{0.003948726117580675, 1.}}], 
           ArrowBox[{{4.856533332237125, 2.6640717011225092`}, {
            4.982611627438171, 2.733176240648665}, {5.001099999999999, 
            2.7433097021160644`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.026150478705463, -1.8792625763079305`}, {
            1.075899014547178, -1.9712049795683506`}, {
            1.16316548306709, -2.1321258319860585`}, {
            1.2387414192379154`, -2.2712232239284984`}, {
            1.3058139171374983`, -2.3945182987054663`}, {
            1.3668065782988026`, -2.5065564364788853`}, {
            1.422978176312578, -2.609686767264651}, {
            1.424765283911494, -2.612965584385742}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4347554809515777`, -2.6312946593211137`}, {
            1.5231829192621442`, -2.7935330152448485`}, {
            1.618371515890896, -2.968060728787122}, {
            1.7033656155082473`, -3.123832385897673}, {
            1.7804522015119166`, -3.2650709663556112`}, {
            1.8346273580592862`, -3.3643136805598584`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8446294053505008`, -3.382636291587506}, {
            1.8518258493214117`, -3.395819356996233}, {
            1.9188253196536256`, -3.5185414865691156`}, {
            1.9814506125085578`, -3.633237355074259}, {
            2.0397017278862086`, -3.7399069625116637`}, {
            2.094543567532473, -3.840323165181846}, {
            2.1469410331932464`, -3.9362588193853236`}, {
            2.244402842558319, -4.114688482392164}, {
            2.244832307387087, -4.115474658915128}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.2548397845380723`, -4.133794304816691}, {
            2.3337843113049366`, -4.278309826003078}, {
            2.416782594756607, -4.4302367246889585`}, {
            2.4941452031181477`, -4.571839753070945}, {
            2.5669641461268826`, -4.705120926133094}, {
            2.5785661251726246`, -4.7263556988480735`}, {
            2.653777718456721, -4.864008729456614}, {
            2.655172651935178, -4.866561685666777}}]}, 
          {Arrowheads[{{0.0031721677107644187`, 1.}}], 
           ArrowBox[{{2.665181950002414, -4.884880336738496}, {
            2.725091060912303, -4.994523799387248}, {
            2.7286843008772004`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.0247819196936958`, 1.8799107008259484`}, {
            1.0744558543140768`, 1.9718708909169185`}, {1.1615937027223553`, 
            2.1328264949123876`}, {1.237059937048664, 2.271956645119459}, {
            1.3040360795556123`, 2.395282371917645}, {1.364941672943199, 
            2.50734925380406}, {1.4210334446778858`, 2.610506622837801}, {
            1.422877474523913, 2.6138955749613766`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.432854710990981, 2.632231708069706}, {
            1.5210966704238353`, 2.79440249747028}, {1.6161446350782058`, 
            2.9689657583771445`}, {1.7010142800501113`, 
            3.1247710909052393`}, {1.7779887353943002`, 3.266041508970487}, {
            1.8322085388640588`, 3.3655330947566298`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8421976377710831`, 3.383862768182849}, {
            1.8492590060575533`, 3.396820150609231}, {1.916161697457483, 
            3.5195711343922023`}, {1.9786968095940891`, 
            3.6342944603194027`}, {2.036864342467372, 3.740990128390831}, {
            2.0916276997884617`, 3.84143122921886}, {2.14395028526849, 
            3.937390853415862}, {2.2412731407053603`, 4.115865671916787}, {
            2.241882820178333, 4.1169836247848055`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.251877355008118, 4.1353103347574764`}, {
            2.3305275055489165`, 4.279529002541057}, {2.4134079765700913`, 
            4.4314952639361245`}, {2.4906609533752184`, 4.573135299456899}, {
            2.5633768277404076`, 4.706451523419457}, {2.574966083747205, 
            4.727698660430709}, {2.650071029539735, 4.865387525827685}, {
            2.6516926078047143`, 4.8683602667444}}]}, 
          {Arrowheads[{{0.003121679462228688, 1.}}], 
           ArrowBox[{{2.661688965709968, 4.886685982378891}, {
            2.721283356056998, 4.995936757637412}, {2.7240998208759137`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7367043949420824`, -0.4918547472390012}, {
            1.9317901032785425`, -0.5476026249619594}, {
            2.0473942674273697`, -0.5805659446312812}, {
            2.1504567879406893`, -0.6099220568796941}, {
            2.279438702563136, -0.6466265889279638}, {
            2.394630186545446, -0.679383225058474}, {
            2.538107486308723, -0.720157625805862}, {
            2.5397480066177045`, -0.7206236164840231}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.5598284682205694`, -0.7263274824275769}, {
            2.6664397695065114`, -0.7566104800313813}, {
            2.8257704416064797`, -0.8018493783833791}, {
            2.9684649400750103`, -0.842351838096627}, {
            3.144528608609427, -0.8923118960191175}, {
            3.302436938477011, -0.9371107657354483}, {
            3.3630940566287837`, -0.9543161339320805}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.383176633155417, -0.9600125490273907}, {
            3.5004438230130446`, -0.993275342255326}, {
            3.677973540128665, -1.0436245370520856`}, {
            3.8711955643953297`, -1.0984177037771805`}, {
            4.046641272996682, -1.148165773054422}, {
            4.186494025566315, -1.1878186200540561`}}]}, 
          {Arrowheads[{{0.019780605223402956`, 1.}}], 
           ArrowBox[{{4.20657721769974, -1.1935128643953283`}, {
            4.207421009545645, -1.1937521070870198`}, {
            4.356645117655141, -1.2360600680781841`}, {
            4.495675840952108, -1.2754763552129533`}, {
            4.626501376207374, -1.3125653121978114`}, {
            4.655604236727163, -1.3208158210304513`}, {
            4.7910387895627515`, -1.3592098134235553`}, {
            4.919424057618281, -1.3956047206195137`}, {
            5.001099999999999, -1.4187579906294279`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.185600816963676, 0.7016158553581612}, {
            2.316891997385686, 0.7438844134666386}, {2.434180306185024, 
            0.7816199284582227}, {2.5801366696330397`, 0.8285517048937283}, {
            2.710718908940653, 0.8705215347893903}, {2.8727276175858636`, 
            0.9225719606718421}, {2.9805188095508255`, 0.9571932164024516}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.0003936467446866`, 0.9635767789974043}, {
            3.017851773910532, 0.9691841229201128}, {3.196814593073611, 
            1.026650258894465}, {3.3573532827281194`, 1.0781904243608882`}, {
            3.5585977107239226`, 1.1427881551870964`}, {3.7390583139658795`, 
            1.2007070869059935`}, {3.795426544886896, 1.2187965433373054`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.8153029576474435`, 1.2251751984195716`}, {
            3.93504545243824, 1.2636024580142506`}, {4.113052375053044, 
            1.3207233531182034`}, {4.276217896292353, 1.3730784688019217`}, {
            4.427680830638226, 1.421676501649476}, {4.56881802700842, 
            1.4669597204511453`}, {4.610369260670274, 1.4802908844734075`}}]}, 
          {Arrowheads[{{0.009328748344953355, 1.}}], 
           ArrowBox[{{4.630246130419928, 1.4866681153647499`}, {
            4.701639534573534, 1.509573745282379}, {4.7289526393438, 
            1.5183366662007864`}, {4.86635783846782, 1.5624196316766694`}, {
            4.99662230300319, 1.6042109430312532`}, {5.001099999999999, 
            1.6056474207942786`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.785344537112203, 0.2192552921875535}, {
            1.9847124826945044`, 0.2439553911696383}, {2.102847715506817, 
            0.25856051986454237`}, {2.2081925204929425`, 
            0.27157092772727937`}, {2.3400152065846, 0.2878365560034852}, {
            2.4577711983488575`, 0.3023562840695221}, {2.6044291938327415`, 
            0.32042853900852364`}, {2.6140407564123405`, 
            0.3216123861043665}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.6347590353470034`, 0.32416423697611996`}, {
            2.7356351315413416`, 0.3365890505827138}, {2.898517627439592, 
            0.3566428293834464}, {3.0444227923320937`, 0.3746007527475109}, {
            3.2244263198502114`, 0.3967493992867893}, {3.3858987330433337`, 
            0.4166137506377621}, {3.463500009155902, 0.42615853229258616`}}]},
           
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.4842187184435995`, 0.42870688672987634`}, {
            3.5883763839930025`, 0.44151804429258323`}, {3.7699442997710038`, 
            0.4638473979647883}, {3.967239613610622, 0.4881080603890247}, {
            4.146431504740678, 0.5101407898124608}, {4.310681498956839, 
            0.5303349346393291}, {4.312970134926969, 0.5306163039461204}}]}, 
          {Arrowheads[{{0.016106356020035222`, 1.}}], 
           ArrowBox[{{4.333688984308758, 0.5331635191276312}, {
            4.463151122054771, 0.5490798432738623}, {4.605226703638981, 
            0.5665461629586139}, {4.738932032149448, 0.5829829881743237}, {
            4.769404533793228, 0.5867290099285686}, {4.907804456112655, 
            0.6037422418140967}, {5.001099999999999, 
            0.6152106419923641}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.12222917954379782`, 
            3.4138854042211744`}, {-0.1270357614666619, 
            3.549217933111518}, {-0.13154230854374221`, 
            3.676368196802685}, {-0.13574882077503878`, 
            3.7953361952946754`}, {-0.1396552981605516, 
            3.9061219285874893`}, {-0.1468367931667044, 
            4.110290698963806}, {-0.15168270529431638`, 4.248359438762727}}]}, 
          {Arrowheads[{{0.017540876350133502`, 1.}}], 
           ArrowBox[{{-0.15241491594064216`, 
            4.2692214351306585`}, {-0.153355438334679, 
            4.296018607319854}, {-0.1593275313379916, 
            4.466481712237199}, {-0.16486936985015838`, 
            4.624856072297407}, {-0.17003178063838706`, 
            4.772547897577782}, {-0.17488893224357363`, 
            4.911613326383693}, {-0.17588523782213017`, 
            4.940150495494158}, {-0.17801171443537944`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.29629109956449445`, 
            2.855939501432828}, {-0.31464047598755296`, 
            3.0320268213061956`}, {-0.33101910987960387`, 
            3.1896690416907174`}, {-0.3458711403753274, 
            3.332914441334612}, {-0.3596213172268501, 
            3.465700290958338}, {-0.37252795599237387`, 
            3.590437596663713}, {-0.38245619805381487`, 3.686475448261669}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.3846027547135884, 
            3.707239631832584}, {-0.3958106192654247, 
            3.815766576319412}, {-0.4164640135587094, 
            4.015940147329636}, {-0.4352330222364573, 
            4.19799707672231}, {-0.452444928460531, 
            4.365061926011059}, {-0.4684270153927929, 
            4.520259256709506}, {-0.4702357744350834, 4.5378306377390905`}}]}, 
          {Arrowheads[{{0.010654947005716281`, 1.}}], 
           ArrowBox[{{-0.4723732895100461, 
            4.558595754020741}, {-0.48332335784407754`, 
            4.664971351045317}, {-0.49734442741491836`, 
            4.801219048604518}, {-0.5003703621578637, 
            4.830627667677468}, {-0.5148553685561572, 
            4.971440076607255}, {-0.5179058341399044, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.2818254568655601, 3.402328424089785}, {
            0.29304715350016075`, 3.537324258919896}, {0.30359786784652976`, 
            3.6641352171822748`}, {0.31347759990466706`, 
            3.7827612988769204`}, {0.32268634967457277`, 3.893202504003834}, {
            0.3396714780158899, 4.096693358992813}, {0.3511792977719486, 
            4.234436872203099}}]}, 
          {Arrowheads[{{0.01792748985071222, 1.}}], 
           ArrowBox[{{0.3529172374896887, 4.255239242030204}, {
            0.355133828536682, 4.281770856587565}, {0.36933397550903363`, 
            4.451611545659374}, {0.38253249320502936`, 4.609391975079525}, {
            0.394845279789658, 4.756516954480867}, {0.4064419155614383, 
            4.895040180669361}, {0.4088312488393366, 4.923576091114288}, {
            0.41532419005184557`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.43633022143688593`, 2.890035135753954}, {
            0.4631626167230674, 3.0681339715323426`}, {0.48720907563519056`, 
            3.2274412882114616`}, {0.5090755057010538, 3.3721160955721743`}, {
            0.5293545663033261, 3.506181274838788}, {0.5484101769923982, 
            3.632095942231855}, {0.5610636273908276, 3.715659730115341}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.5641889246925017, 3.7362992926509744`}, {
            0.5662423377682703, 3.7498600977513763`}, {0.5828510486309422, 
            3.859473741397352}, {0.6134644557838156, 4.061397631647713}, {
            0.6413167336181484, 4.245015751561989}, {0.6668828315673309, 
            4.413491028381848}, {0.6894028322493723, 4.561851175458993}}]}, 
          {Arrowheads[{{0.010141632344278905`, 1.}}], 
           ArrowBox[{{0.6925360675452055, 4.582489534437357}, {
            0.7127918197206782, 4.715899149552878}, {0.7336529941925765, 
            4.85327168371466}, {0.7379628474282731, 4.8816496688666975`}, {
            0.7561069615130411, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.7470175542392072`, -0.13074736631248643`}, {
            1.9413673099152364`, -0.14543639126430358`}, {
            2.0566701137696737`, -0.15413103181066307`}, {
            2.1594438852729407`, -0.161872165059261}, {
            2.288214238731217, -0.17156171562329087`}, {
            2.403200991375578, -0.18020742695290065`}, {
            2.546559067693513, -0.19097901318150642`}, {
            2.579652533541672, -0.19346428535648524`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.600468758352805, -0.1950275542068553}, {
            2.674772113605467, -0.20060763041175597`}, {
            2.834071056281726, -0.2125652942747417}, {
            2.976726926216393, -0.22326994619786286`}, {
            3.152836523011137, -0.2364809009978914}, {
            3.310777775280964, -0.24832623283405178`}, {
            3.433122126077231, -0.2575000137552247}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.4539385299789775`, -0.25906089603314264`}, {
            3.5088966715614225`, -0.2631818378455825}, {
            3.6865202479449772`, -0.27649859846650365`}, {
            3.880054741655788, -0.29100633729255493`}, {
            4.0557672574774, -0.30417689566174405`}, {
            4.216779203167179, -0.31624465093724907`}, {
            4.2865961154046355`, -0.32147712128688904`}}]}, 
          {Arrowheads[{{0.01666198208421104, 1.}}], 
           ArrowBox[{{4.307412577780421, -0.32303722354112846`}, {
            4.366211986482491, -0.327443980482248}, {
            4.505431672338744, -0.33787740354834944`}, {
            4.636431797498734, -0.34769451636589066`}, {
            4.668723746578514, -0.3501144220581449}, {
            4.804434079761595, -0.36028403940734754`}, {
            4.933078939146366, -0.36992399283617483`}, {
            5.001099999999999, -0.3750209992722413}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.6837123364794343, -2.1360777669727793`}, {
            0.72782463646444, -2.2753962777984293`}, {
            0.7670498343986668, -2.3989456441407233`}, {
            0.8027602369406504, -2.5112466843685963`}, {
            0.8356741919309219, -2.6146394444195034`}, {
            0.8944541831296996, -2.799003572361246}, {
            0.9368467713504867, -2.9317767907189833`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9431960298822735, -2.9516626133316564`}, {
            0.9502042658054729, -2.9736123474145884`}, {
            1.0000293031322145`, -3.129523430330172}, {
            1.0452482973551442`, -3.27093278365386}, {
            1.0871330453758592`, -3.4018653693103955`}, {
            1.1264607216401064`, -3.5247756113848228`}, {
            1.1632313261478857`, -3.6396635098771415`}, {
            1.197444858899197, -3.7465290647873517`}, {
            1.197583560665358, -3.746962178043749}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.2039500993675838`, -3.7668424750696796`}, {
            1.2604501684199494`, -3.943270862185888}, {
            1.3177261094898969`, -4.122078721904872}, {
            1.370264965719602, -4.286065165835947}, {
            1.4190590207196279`, -4.438342715870761}, {
            1.4586958750452563`, -4.562027375620069}}]}, 
          {Arrowheads[{{0.010543801058628413`, 1.}}], 
           ArrowBox[{{1.4650664811810181`, -4.5819063696169815`}, {
            1.5073654819879052`, -4.713886912414216}, {
            1.5160028311611105`, -4.740835770452256}, {
            1.5602748263685131`, -4.878955897445983}, {
            1.599428148201137, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5321345864788557, 
            1.9363549563893019`}, {-0.5765707670404973, 
            2.094275771652893}, {-0.6150362373018161, 
            2.231783105886636}, {-0.6491528883966791, 
            2.354203321829749}, {-0.6801591646605841, 
            2.4657056911275217`}, {-0.708698563702179, 
            2.568492389995631}, {-0.756403717014028, 2.740666087284313}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.761973246340009, 
            2.760784221910682}, {-0.806947579911479, 
            2.923420334907712}, {-0.8492996276844322, 
            3.0767579585703024`}, {-0.8877402476197316, 
            3.216050364697261}, {-0.923348005580402, 
            3.345143100234305}, {-0.9567816207476691, 
            3.4663915179871245`}, {-0.9841493071008381, 
            3.5656768738621287`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-0.9896958779126012, 
            3.585801350901738}, {-1.0171264227019936`, 
            3.6853554001400908`}, {-1.0706859681035277`, 
            3.8798111203418544`}, {-1.1193715715730943`, 
            4.056627787778112}, {-1.164027315716106, 
            4.2188516465784645`}, {-1.2054972831379758`, 
            4.369528940872513}, {-1.2113603120164311`, 
            4.390835084324575}}]}, 
          {Arrowheads[{{0.014660357552520237`, 1.}}], 
           ArrowBox[{{-1.2168987834960154`, 
            4.410961791918118}, {-1.2441538996048112`, 
            4.51000640275919}, {-1.280541392665896, 
            4.642252616291635}, {-1.2884013967468892`, 
            4.6708206419353875`}, {-1.3260107976011999`, 
            4.807529270399875}, {-1.3616727670831392`, 
            4.937168390257819}, {-1.379258930502864, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.5308128863482435, -1.9366470137462746`}, \
{-0.5751394273105107, -2.0945848841762906`}, {-0.6135093222967374, \
-2.232106603793283}, {-0.6475408451508008, -2.354539466609635}, \
{-0.6784695789868482, -2.4660533293429943`}, {-0.7069375023789477, \
-2.5688506387582586`}, {-0.7545413367912063, -2.7411087083023}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-0.7600973021060817, -2.7612305930826575`}, \
{-0.8049396180953355, -2.923814875596355}, {-0.8471849878542819, \
-3.0771681503492947`}, {-0.8855287394854061, -3.216474923059731}, \
{-0.9210467501431775, -3.3455810775322234`}, {-0.9543960905132783, \
-3.466842170530486}, {-0.9817317818296123, -3.5662725426125634`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-0.987264796857509, -3.5864007508928677`}, \
{-1.014588760390468, -3.685829172104318}, {-1.0680132628812848`, \
-3.880305656106998}, {-1.1165761117500381`, -4.057141350864296}, \
{-1.1611192636567198`, -4.2193827856271025`}, {-1.2024846752613214`, \
-4.370076489646308}, {-1.2083874060200073`, -4.391583478605944}}]}, 
          {Arrowheads[{{0.014638966183823888`, 1.}}], 
           ArrowBox[{{-1.213912331444152, -4.411713908902979}, \
{-1.2410438328426958`, -4.510569324284784}, {-1.2773395916092176`, \
-4.642830063643547}, {-1.2851813880363119`, -4.671407090666844}, \
{-1.3226959693945517`, -4.808130775089271}, {-1.3582680359347687`, \
-4.937784221108419}, {-1.3756389684764652`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.1547998904378884, -2.1172947535818554`}, \
{-0.16558304551395436`, -2.255828610847085}, {-0.17503729878377405`, \
-2.378994494280727}, {-0.1913916800479858, -2.594397430575649}, \
{-0.20523977432945184`, -2.778803653366857}, {-0.21799119673127618`, \
-2.949893353230167}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.21953612438704836`, -2.970710947212452}, \
{-0.22960023071693247`, -3.1063789793386927`}, {-0.23998277444271654`, \
-3.2467985171410003`}, {-0.24958327911009845`, -3.3769002736736566`}, \
{-0.258587941124737, -3.49907766182897}, {-0.2669967604866321, \
-3.61333068160694}, {-0.27480973719578383`, -3.719659333007568}, \
{-0.2809571419140276, -3.803442509251714}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.2824846808536048, -3.8242613864950776`}, \
{-0.28917900960328025`, -3.915498607920536}, {-0.30222660529464945`, \
-4.093550563811617}, {-0.31418360419283015`, -4.25689145964386}, \
{-0.3252810862207612, -4.408597554380312}, {-0.33562031648409235`, \
-4.550027335769467}, {-0.3434390763702017, -4.657027257261018}}]}, 
          {Arrowheads[{{0.007763269154588502, 1.}}], 
           ArrowBox[{{-0.34496039862086314`, -4.677846589706988}, \
{-0.3453491184847434, -4.6831662306121}, {-0.347624752900179, \
-4.714315993991015}, {-0.35768111637397393`, -4.852025080214097}, \
{-0.3672145410627413, -4.982610727985522}, {-0.36856418790590384`, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.2839894732083947, -2.2932098105865686`}, {
            0.29904312696979557`, -2.417674286529717}, {
            0.31280055872675755`, -2.5308959221913763`}, {
            0.32551410570493694`, -2.635190176357193}, {
            0.34830107795422316`, -2.8212924403748985`}, {
            0.36984109245757246`, -2.9964792021296334`}, {
            0.3853183341351682, -3.1220321583924804`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3878722985261956, -3.142750176897529}, {
            0.3891443787197806, -3.15306942061259}, {
            0.40669671379121336`, -3.295200340128566}, {
            0.42297389419539844`, -3.4268619710476775`}, {
            0.4382683483603284, -3.550491374775533}, {
            0.4525800762860033, -3.6660885513121335`}, {
            0.46590907797242304`, -3.773653500657479}, {
            0.49043500109478805`, -3.971420984198738}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{0.49300581342318517`, -3.9921369188580766`}, {
            0.5128247203409746, -4.1518384619129}, {
            0.5333379263560594, -4.317040227408094}, {
            0.5523968139313798, -4.470470944381707}, {
            0.5701704651815905, -4.613505968119068}, {
            0.5869061259914835, -4.748155132513225}, {
            0.5906301556410491, -4.778113377794362}, {
            0.5959328823703648, -4.820762560942676}}]}, 
          {Arrowheads[{{0.0038527562775243053`, 1.}}], 
           ArrowBox[{{0.5985084950879417, -4.841477899318266}, {
            0.6079420650664159, -4.917350949975415}, {
            0.6183565136662191, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.347141129803425, 
            2.0552434100608634`}, {-2.45857444490833, 
            2.1528056338221093`}, {-2.561322421387485, 
            2.2427822206571886`}, {-2.6564207062734027`, 
            2.3260764270414214`}, {-2.7449049465985973`, 
            2.4035915094501283`}, {-2.8329401812975044`, 
            2.4807226660071993`}, {-2.915698272022654, 
            2.5532377216871436`}, {-2.975247559790419, 
            2.605422232051652}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.9909471684710502`, 
            2.6191801865566364`}, {-3.0686263486298695`, 
            2.6872523690135144`}, {-3.2075968120672154`, 
            2.809049272492827}, {-3.3364203625027806`, 
            2.921960860036296}, {-3.457432559766323, 
            3.0280303674399427`}, {-3.5706334038578422`, 
            3.127257794703767}, {-3.618882956196883, 3.169553773197723}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.6345803545653625`, 
            3.1833142495465787`}, {-3.6760228947773395`, 
            3.2196431418277687`}, {-3.7753081218143976`, 
            3.306680878815698}, {-3.8701961742585995`, 
            3.3898654756713036`}, {-3.9606870521099466`, 
            3.4691969323945857`}, {-4.046780755368438, 
            3.544675248985545}, {-4.208810413537368, 
            3.6867298841165357`}, {-4.262452679280319, 
            3.733760235426287}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-4.2781490516627745`, 
            3.7475218820907474`}, {-4.359318924195902, 
            3.8186868034103205`}, {-4.49964864995644, 
            3.94172215904672}, {-4.631762077760948, 
            4.057555513925027}, {-4.645379424437927, 
            4.0694949105114375`}, {-4.781538021684651, 
            4.188877311869131}, {-4.9059935315643255`, 
            4.2979996280488315`}}]}, 
          {Arrowheads[{{0.002529657949037948, 1.}}], 
           ArrowBox[{{-4.9216894450238255`, 
            4.311761798137805}, {-5.001099999999999, 4.381388997733802}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4412500444143452`, -2.147887168091683}, \
{-2.5561566100495905`, -2.2489969187341976`}, {-2.6621540117099394`, \
-2.342283430087083}, {-2.760301756024493, -2.428675967626881}, \
{-2.8516593496223526`, -2.509103796830133}, {-2.9420076150044263`, \
-2.5886512311159624`}, {-3.026995147255314, -2.6634852287061106`}, \
{-3.068008054362634, -2.6996016102546876`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.083674338957865, -2.7133974992027543`}, \
{-3.1841577063530178`, -2.8018841706457915`}, {-3.32709212203819, \
-2.927765617154472}, {-3.4596614869508273`, -3.04452536892843}, \
{-3.584236069100313, -3.154247674793468}, {-3.7008158684866457`, \
-3.256932534749585}, {-3.710287901895227, -3.265276001734937}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.7259523011147464`, -3.279074031376074}, \
{-3.8094008851098264`, -3.3525799487967816`}, {-3.9117316323883107`, \
-3.4427213123550047`}, {-4.009548623740555, -3.5288880208442026`}, \
{-4.102851859166559, -3.6110800742643745`}, {-4.191641338666322, \
-3.6892974726155208`}, {-4.276693226541154, -3.7642234568406128`}, \
{-4.352510749366627, -3.8310151065956486`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.368174309096391, -3.844814089220181}, \
{-4.514080326223901, -3.9733523704173903`}, {-4.658907603126877, \
-4.100942627652147}, {-4.795278384024943, -4.221084392252915}, \
{-4.807912439821051, -4.232214982932778}, {-4.948365960960732, \
-4.355955706780498}, {-4.994707760205639, -4.396783539823161}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.5210947959558503`, 
            1.6744038747888026`}, {-2.626241390857882, 
            1.744210030340216}, {-2.723629567918778, 
            1.8088813076536303`}, {-2.814302635985679, 
            1.8691068227151628`}, {-2.9876396652697252`, 
            1.9842625862968652`}, {-3.1430861946389244`, 
            2.0875534306640264`}, {-3.2166192713772963`, 
            2.136421328422138}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2340049931499197`, 
            2.147975362493885}, {-3.284504223183311, 
            2.181535650184762}, {-3.4156899327237102`, 
            2.2687251017195145`}, {-3.538975386261176, 
            2.3506680876813597`}, {-3.6543605837957083`, 
            2.427364608070298}, {-3.761845525327307, 
            2.49881466288633}, {-3.8631473841412562`, 
            2.566157843094408}, {-3.9293933311488427`, 
            2.6101977090703286`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.946777265043566, 
            2.6217544329672666`}, {-3.95998333352284, 
            2.630533739659485}, {-4.140257503988909, 
            2.750383681860637}, {-4.305737039265809, 
            2.8604026609637523`}, {-4.459490941893832, 
            2.962628848442796}, {-4.602880798585853, 
            3.057966798423801}, {-4.642114696099356, 3.084053358492758}}]}, 
          {Arrowheads[{{0.009825770329290549, 1.}}], 
           ArrowBox[{{-4.659497787267674, 
            3.0956113499411075`}, {-4.7378981103776345`, 
            3.14773960810179}, {-4.755523656550372, 
            3.1594589175900682`}, {-4.89471339747332, 
            3.252008271996059}, {-5.001099999999999, 3.322747163182085}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.748068025481712, -1.8644790874992916`}, \
{-2.839386853128762, -1.9264463721465488`}, {-3.013831415359295, \
-2.0448449157026247`}, {-3.1702962697644703`, -2.1510602544006225`}, \
{-3.312659096409376, -2.2477151313701493`}, {-3.438924585280736, \
-2.333447794021407}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.4561944961699393`, -2.345174225819469}, \
{-3.568860850476258, -2.4216770013143334`}, {-3.6850424771459003`, \
-2.5005711179679793`}, {-3.793277936906344, -2.5740740224093273`}, \
{-3.8952933384741186`, -2.643356080813344}, {-3.9928147905657547`, \
-2.7095876593549955`}, {-4.085842293181252, -2.7727687580342826`}, \
{-4.146959112033702, -2.814278355327128}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.1642276173819734`, -2.8260068568479064`}, \
{-4.174375846320611, -2.8328993768512043`}, {-4.341047743325222, \
-2.9461034378968716`}, {-4.495917120733896, -3.051294105490916}, \
{-4.640353807455038, -3.1494010927180023`}, {-4.7763614758038475`, \
-3.2417843732512797`}, {-4.793369611410686, -3.2533372607565965`}, \
{-4.854952981444835, -3.295168781037858}}]}, 
          {Arrowheads[{{0.0037317736178023556`, 1.}}], 
           ArrowBox[{{-4.872220828804072, -3.3068982512929144`}, \
{-4.9335500399046435`, -3.348557129924674}, {-5.001099999999999, \
-3.3944420352178426`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.3229937819448687`, -2.5949261745694083`}, \
{-2.418995011272526, -2.702211519366187}, {-2.5078864953480933`, \
-2.8015682738520704`}, {-2.5906281641963544`, -2.8940654680758993`}, \
{-2.6722686625590715`, -2.9853412328423485`}, {-2.7490774680043346`, \
-3.071222603876026}, {-2.879683464401559, -3.2172693509263945`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.8935985798955524`, -3.232829832459029}, \
{-3.020374755184345, -3.374607752367309}, {-3.1402539563861027`, \
-3.5086804942283267`}, {-3.252915516993188, -3.634685654646803}, \
{-3.3583594370056016`, -3.7526232336227383`}, {-3.450151012141857, \
-3.855295758669892}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.464063932561432, -3.8708582028947767`}, \
{-3.5491640770503716`, -3.966049394277799}, {-3.63766424069065, \
-4.06504547001855}, {-3.722086207344178, -4.1594814583783855`}, \
{-3.8024299770109544`, -4.249357359357306}, {-3.8793961855287513`, \
-4.335456335562317}, {-3.95368546873534, -4.418561549600424}, \
{-4.02056061057347, -4.493373975381523}}]}, 
          {Arrowheads[{{0.015811516451355583`, 1.}}], 
           ArrowBox[{{-4.03447264938063, -4.508937207729407}, \
{-4.094233259214892, -4.575790691175925}, {-4.225316400411039, \
-4.722434580849926}, {-4.34875299853231, -4.860526029611365}, \
{-4.359532018253595, -4.872584852823849}, {-4.474406592606109, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.566385252800335, 
            1.2527777517675254`}, {-2.7039863020566273`, 
            1.3198959348745944`}, {-2.874719042705935, 
            1.4032086685757237`}, {-3.0277246906889204`, 
            1.4778929933555807`}, {-3.200432129346492, 
            1.5622149774789753`}, {-3.3167700110214637`, 
            1.6190251253865016`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.3355278490314513`, 
            1.6281849582494552`}, {-3.3564957608368564`, 
            1.6384240149851195`}, {-3.4898891467379953`, 
            1.703571069421877}, {-3.615299719887712, 
            1.7648231287469303`}, {-3.7327274802860066`, 
            1.8221801929602788`}, {-3.8421724279328795`, 
            1.875642262061923}, {-3.945360942669612, 
            1.926051015016753}, {-4.044019404337487, 
            1.9742481307896587`}, {-4.085801192663873, 
            1.9946605346456654`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.104557347246081, 
            2.0038238140899756`}, {-4.227746168466663, 
            2.0640074507896973`}, {-4.39645442482097, 
            2.146433682093086}, {-4.553245877900974, 
            2.223040284730872}, {-4.699500032681329, 
            2.2945006428479546`}, {-4.837235447817612, 
            2.361800143284438}, {-4.854791988413636, 
            2.3703786159613323`}}]}, 
          {Arrowheads[{{0.0034003906089847863`, 1.}}], 
           ArrowBox[{{-4.873547558385349, 
            2.3795430919375615`}, {-5.000442623298249, 
            2.4415476511544827`}, {-5.001099999999999, 
            2.4418688648139475`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.5077366802699284`, 
            2.8118093712085606`}, {-2.590426129443659, 
            2.9045922891003584`}, {-2.671966291493075, 
            2.996095162658397}, {-2.7486855595554744`, 
            3.082195622495514}, {-2.890595115703831, 
            3.2414726713473625`}, {-3.019696024365786, 
            3.386387480139236}, {-3.0632119829947637`, 
            3.435236692122131}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.077097298195883, 
            3.4508237716000747`}, {-3.139459643329912, 
            3.520829156134429}, {-3.252016380396178, 
            3.6471852898681885`}, {-3.3573662355645837`, 
            3.7654558813405155`}, {-3.4555092088351294`, 
            3.8756409305514086`}, {-3.5480120936236927`, 
            3.9794974330635666`}, {-3.632479609539261, 4.07433393786767}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.646363452085664, 
            4.089922329094002}, {-3.720797978002508, 
            4.173495784679772}, {-3.8010809775927594`, 
            4.263637633783819}, {-3.8779902670263433`, 
            4.349992830210622}, {-3.9522254312126965`, 
            4.433346272418973}, {-4.092673383843709, 
            4.59104789418032}, {-4.201701406485734, 4.713472003220294}}]}, 
          {Arrowheads[{{0.008725284303904342, 1.}}], 
           ArrowBox[{{-4.215584585866242, 
            4.7290609850720635`}, {-4.223666254234758, 
            4.738135634190672}, {-4.347019820995943, 
            4.876647254591844}, {-4.35774126119788, 
            4.888686255056046}, {-4.457851245463632, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.995218868481492, -2.6951813624588015`}, {
            3.081874153961871, -2.773089949393656}, {
            3.241835269930592, -2.916893824497508}, {
            3.3870435391971805`, -3.0474243823738876`}, {
            3.521567430820481, -3.1683445399187913`}, {
            3.6161926532587145`, -3.2533981638341847`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.6317176964747473`, -3.267352806718418}, {
            3.6478922110636356`, -3.281891225180317}, {
            3.7660178799266437`, -3.388064438158465}, {
            3.8759444374095064`, -3.486864178853236}, {
            3.9794731279595146`, -3.5799109235493543`}, {
            4.078405196023959, -3.6688251485315453`}, {
            4.17274064160284, -3.753606853799809}, {
            4.252746237868713, -3.8255086902203965`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.268272374706461, -3.8394621163149862`}, {
            4.3484170569682, -3.9114879864069785`}, {
            4.4313488100832545`, -3.9860179761707277`}, {
            4.588194798842401, -4.126972083830979}, {
            4.7344215962780645`, -4.258380858275518}, {
            4.872081235610237, -4.382089243509215}, {
            4.884157938592058, -4.392941960550336}, {
            4.88932793861625, -4.3975879321500155`}}]}, 
          {Arrowheads[{{0.0030993643256918874`, 1.}}], 
           ArrowBox[{{4.904854577665531, -4.411540799408021}, {
            5.001099999999999, -4.498030837449177}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.640030017217553, 
            0.875987553635254}, {-2.808364142533537, 
            0.9317916514376587}, {-2.9592183292191194`, 
            0.9818204841610458}, {-3.129491324696751, 
            1.038307855185863}, {-3.2833274657518983`, 
            1.0893539498805083`}, {-3.4143558456138585`, 
            1.1328392641527563`}, {-3.4325586054048514`, 
            1.138880814568082}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.4523707042803826`, 
            1.1454565094387665`}, {-3.537545962182193, 
            1.1737264322779823`}, {-3.652897815456902, 
            1.2120154542561858`}, {-3.760411405437985, 
            1.2477063300873672`}, {-3.958696817961335, 
            1.3135363837669503`}, {-4.139175222194305, 
            1.3734593337750192`}, {-4.244835130170527, 
            1.408543134682805}}]}, 
          {Arrowheads[{{0.01858692827235944, 1.}}], 
           ArrowBox[{{-4.264646390195585, 
            1.4151213564110305`}, {-4.304893666438497, 
            1.4284852467818676`}, {-4.458899198995518, 
            1.4796241894577895`}, {-4.602547691742848, 
            1.5273258499215137`}, {-4.737823223587081, 
            1.572248317264652}, {-4.763762382190849, 
            1.580862351960767}, {-4.903390557750754, 
            1.6272320293358333`}, {-5.001099999999999, 
            1.6596812962339138`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.5790815189894096`, -1.3164085843072515`}, \
{-2.7170775149342843`, -1.3867979243572577`}, {-2.888376424021256, \
-1.4742081782899799`}, {-3.0418918631070717`, -1.552565786550516}, \
{-3.2151878680875847`, -1.6410407314663746`}, {-3.3228079746602925`, \
-1.6959943901775667`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.3413993089830347`, -1.7054876147607205`}, \
{-3.3717878681290436`, -1.7210048128124287`}, {-3.505670058650255, \
-1.7893769422923056`}, {-3.6315414966971504`, -1.853661751508404}, \
{-3.7494021822697303`, -1.9138592404607235`}, {-3.8592521153679944`, \
-1.9699694091492645`}, {-3.9628237074304753`, -2.0228755231928197`}, \
{-4.061849369895706, -2.073460848210181}, {-4.085013093461112, \
-2.085294115277552}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.103602717692754, -2.09479068812319}, \
{-4.246262906034415, -2.167669131166324}, {-4.415605062775874, \
-2.2541823302575796`}, {-4.57298817911183, -2.334588517723833}, \
{-4.7197965019011034`, -2.4095942705493503`}, {-4.847176607362881, \
-2.474675289272832}}]}, 
          {Arrowheads[{{0.003640166503776946, 1.}}], 
           ArrowBox[{{-4.865765714686622, -2.4841728739021303`}, \
{-4.878515922900889, -2.490687276480043}, {-5.001099999999999, \
-2.5533196394686914`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.8313322161755083`, -1.0204999016814675`}, \
{-2.9830539402287513`, -1.0751657296262573`}, {-3.154337005066995, \
-1.1368985702854713`}, {-3.3090939565564295`, -1.1926870573466575`}, \
{-3.440946590231105, -1.2402262621002649`}, {-3.5649146307190125`, \
-1.284925977760276}, {-3.6168499656819395`, -1.303654099115175}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.6364870550144452`, -1.3107353241104251`}, \
{-3.6809980780201514`, -1.326786204326691}, {-3.7891969321345216`, \
-1.3658069417995096`}, {-3.988753383238703, -1.4377809791412588`}, \
{-4.170396506467301, -1.5032991194624243`}, {-4.337190969400225, \
-1.5634651084917597`}, {-4.421950296303429, -1.594040699482575}}]}, 
          {Arrowheads[{{0.014247040230477463`, 1.}}], 
           ArrowBox[{{-4.441586573276261, -1.60112417684418}, \
{-4.492201439617383, -1.6193826919580183`}, {-4.6367916965094444`, \
-1.6715432729348136`}, {-4.772957427397571, -1.720665999600615}, \
{-4.797863197244144, -1.7296510518303814`}, {-4.938372037170721, \
-1.780342411702621}, {-5.001099999999999, -1.8029730743697001`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.711763437658445, -2.991249178018369}, {
            2.7903316072720052`, -3.0778334920328936`}, {
            2.9353637103322208`, -3.237649083124328}, {
            3.067018669070701, -3.382710969110244}, {
            3.1889853890099564`, -3.5170906818958247`}, {
            3.272921580521408, -3.6095662303328946`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.2869513896160174`, -3.6250233801883818`}, {
            3.3035174341839517`, -3.6432747927109963`}, {
            3.4106148045926865`, -3.7612633015557586`}, {
            3.5102775002361613`, -3.8710562084301126`}, {
            3.604138872531784, -3.9744547877552048`}, {
            3.6938322728969637`, -4.073260313952184}, {
            3.7793577013317003`, -4.167472787021049}, {
            3.8481762108008044`, -4.2432799123271705`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.862207322950798, -4.258735879353477}, {
            3.938625901307702, -4.3429136330150016`}, {
            4.013811190644684, -4.425732124421209}, {
            4.156005406914467, -4.58236030329265}, {
            4.288571081699112, -4.728380003286845}, {
            4.413368956155015, -4.865841855462382}, {
            4.423465123638277, -4.876962472863088}}]}, 
          {Arrowheads[{{0.003515995824391913, 1.}}], 
           ArrowBox[{{4.437496872628878, -4.892417861733976}, {
            4.536168044311468, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.0736723336749314`, -2.879541884608832}, \
{-2.2006762705731298`, -3.056022771927619}, {-2.3145323197017103`, \
-3.2142699309867213`}, {-2.41809251689774, -3.3582299691936006`}, \
{-2.514150504430777, -3.4917740800196264`}, {-2.5613141764181044`, \
-3.557347068251598}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.5735031241842816`, -3.574293707364991}, \
{-2.6044203827133803`, -3.6172788470767197`}, {-2.688902151745549, \
-3.7347442703648808`}, {-2.7675958115272836`, -3.8441703498841093`}, \
{-2.841760805940041, -3.947305033328629}, {-2.9126565788652785`, \
-4.045896268392664}, {-2.9802831303029964`, -4.139944055076213}, \
{-3.0446404602531945`, -4.229448393379277}, {-3.06100101209855, \
-4.252202438534736}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-3.073187309188018, -4.2691509838449795`}, \
{-3.1657950720834633`, -4.3979486698024495`}, {-3.278368030748517, \
-4.554519042620678}, {-3.3833560014791355`, -4.700544417829751}, \
{-3.4822166527283716`, -4.838050404077726}, {-3.4935105937722555`, \
-4.853759398039942}, {-3.560620732676808, -4.947106068832339}}]}, 
          {Arrowheads[{{0.0010928146264429955`, 1.}}], 
           ArrowBox[{{-3.572806104376863, -4.964055279475247}, \
{-3.595372678413582, -4.995444196141234}, {-3.5994387675900166`, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.876466699793347, 3.0865593201367694`}, {
            0.9219545074372847, 3.2466691772553995`}, {0.9632825320701816, 
            3.3920467893406467`}, {1.001590283326933, 3.5267490161983623`}, {
            1.0375754111199147`, 3.6532544157620315`}, {1.0712379154491263`, 
            3.7715629880316532`}, {1.1025777963145682`, 3.881674733007228}, {
            1.104864997868409, 3.8897085212693927`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1105808869808231`, 3.9097855637941463`}, {
            1.160322492079969, 4.084502795214209}, {1.212842302841944, 
            4.268933656520946}, {1.2610386024716405`, 4.438147839303907}, {
            1.305812764840205, 4.595325865939559}, {1.3392937177158755`, 
            4.7128452614578284`}}]}, 
          {Arrowheads[{{0.006679157310245073, 1.}}], 
           ArrowBox[{{1.3450133113851497`, 4.732921248934029}, {
            1.3475634177252869`, 4.741872217465692}, {1.3868733056721572`, 
            4.879839604022764}, {1.3942520899316166`, 4.90573601621347}, {
            1.4214265894130342`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9612402932045863, 2.7095678929883693`}, {
            1.0285668009704168`, 2.8995826590682596`}, {1.0919863581651381`, 
            3.078377201321548}, {1.1487221178459917`, 3.2382203864567374`}, {
            1.2002514375613227`, 3.383326770116529}, {1.2404509843410694`, 
            3.4964959534540463`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.2474383347152542`, 3.516166641282248}, {
            1.2480045586344413`, 3.5177606666793912`}, {1.2928563279648817`, 
            3.6440041902442784`}, {1.3348067455526442`, 
            3.7620573408111917`}, {1.3738558113977288`, 
            3.8719201183801304`}, {1.4457934220701458`, 4.074270728153223}, {
            1.5112126941924149`, 4.258252193192697}, {1.5271027315961516`, 
            4.3029336068034585`}}]}, 
          {Arrowheads[{{0.017249037994056866`, 1.}}], 
           ArrowBox[{{1.5340972999266405`, 4.3226017292038375`}, {
            1.5712395029146105`, 4.427042398030084}, {1.626999723386807, 
            4.583819227196915}, {1.6789908555762159`, 4.729985338225427}, {
            1.7279400850048074`, 4.867590611698552}, {1.736654541064907, 
            4.8920877034052666`}, {1.775436121641622, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           
           ArrowBox[{{-2.874470701364171, -0.621708455033627}, \
{-3.028789482291774, -0.6550688659896136}, {-3.203249186633757, \
-0.6927956649765603}, {-3.3608780758609567`, -0.7268905370054547}, \
{-3.494316397948267, -0.7557578763600146}, {-3.619810354490664, \
-0.7829086830381867}, {-3.690593646931467, -0.7982241055710169}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.71099636231983, -0.8026386530753052}, \
{-3.7373599454881474`, -0.8083429570399713}, {-3.8469651709407175`, \
-0.8320606983653682}, {-4.04918221416623, -0.8758229029147563}, \
{-4.233301173122311, -0.9156716166141079}, {-4.402410367042923, \
-0.952274169444734}, {-4.527095859706431, -0.9792626884832606}}]}, 
          {Arrowheads[{{0.011116433324634393`, 1.}}], 
           ArrowBox[{{-4.547498228503787, -0.9836788375231853}, \
{-4.559598115162024, -0.9862978913879452}, {-4.706241116949808, \
-1.0180404137161676`}, {-4.844354561672902, -1.04793743787473}, \
{-4.871433575494992, -1.0537992411684034`}, {-5.001099999999999, \
-1.0818688345722784`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.961430313352628, 
            0.553366605504167}, {-3.132678603801026, 
            0.5853559949621517}, {-3.287386213254619, 
            0.6142629076447776}, {-3.4184925598788203`, 
            0.6387645649515693}, {-3.541776976242982, 
            0.6618064299868975}, {-3.6572394623471034`, 
            0.6833885027507622}, {-3.764880018191185, 
            0.7035107832431632}, {-3.782214969116598, 
            0.7067516998329779}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-3.8027342803918596`, 
            0.7105879596879786}, {-3.9634375481435935`, 
            0.7406328031222051}, {-4.1441917751445745`, 
            0.7744293253326537}, {-4.310184216205384, 
            0.8054680206265605}, {-4.464456388337279, 
            0.8343165597559771}, {-4.608363316119279, 
            0.8612279905197627}, {-4.623502823820514, 
            0.8640592526156924}}]}, 
          {Arrowheads[{{0.008701117606704212, 1.}}], 
           ArrowBox[{{-4.6440219386389305`, 
            0.8678965631263024}, {-4.743888213883066, 
            0.8865727053985728}, {-4.772581235563719, 
            0.8919387192338095}, {-4.912519384241886, 
            0.9181098863710703}, {-5.001099999999999, 0.9346764878457878}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.713018740632285, 2.998437659856675}, {
            2.791565474247737, 3.0851659469092496`}, {2.9365663812945955`, 
            3.2452566020503375`}, {3.0682013094499556`, 3.390577378477492}, {
            3.1901544505495325`, 3.5252024502094197`}, {3.2735811937544974`, 
            3.617294811911431}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.287596107468892, 3.6327654686028663`}, {
            3.3046767166885984`, 3.651620257630017}, {3.411768107867153, 
            3.7698308007392844`}, {3.5114286240851964`, 3.879834079537221}, {
            3.605290307012895, 3.9834334036377737`}, {3.6949851983204156`, 
            4.082432082654889}, {3.780513298007758, 4.176830116588568}, {
            3.8482249086356553`, 4.251562516714315}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.862241110905235, 4.267032006002065}, {
            3.9397900141951374`, 4.352620441586449}, {4.014980414041634, 
            4.435605117412323}, {4.157186188913469, 4.592549688098773}, {
            4.289764742286197, 4.73886668267984}, {4.4145761859604615`, 
            4.876610008349357}, {4.422902779143167, 4.8857992752757315`}}]}, 
          {Arrowheads[{{0.003226854968301132, 1.}}], 
           ArrowBox[{{4.436919615086561, 4.901268190396726}, {
            4.527380298571616, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.076899153367539, 
            2.877426553987058}, {-2.2041296381133275`, 
            3.053817732127929}, {-2.318186478480102, 
            3.211981202216692}, {-2.421927717247978, 
            3.355862862419742}, {-2.51815265512297, 
            3.4893328910057555`}, {-2.565277180363939, 
            3.5547014882089334`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.5774845356741958`, 
            3.571634872431094}, {-2.608578827709834, 
            3.614767195589833}, {-2.6932062350085713`, 
            3.732165776171974}, {-2.7720348770191814`, 
            3.8415286327521794`}, {-2.8463266084274763`, 
            3.9446030560229564`}, {-2.917343283919268, 
            4.043136336676812}, {-2.985084903494556, 
            4.137128474713749}, {-3.0495514671533415`, 
            4.226579470133764}, {-3.0657188680853023`, 
            4.249013404106386}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.077923577498039, 
            4.265948695454244}, {-3.1709111853131415`, 
            4.394978578660287}, {-3.2836741969904075`, 
            4.5514542077936335`}, {-3.388838967905702, 
            4.697390591268541}, {-3.4878657902729993`, 
            4.834812341092888}, {-3.4991741514644734`, 
            4.850505378547843}, {-3.5660935491310997`, 4.94337361261522}}]}, 
          {Arrowheads[{{0.001204253866033145, 1.}}], 
           ArrowBox[{{-3.5782973349330955`, 
            4.960309569540803}, {-3.6012080910568804`, 
            4.992104258921657}, {-3.6076901818198612`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0919403186065657`, 2.802272854826904}, {
            3.2522745709178573`, 2.9474535207766253`}, {3.3978360201117477`, 
            3.07924712318384}, {3.5326957214339783`, 3.201345270631738}, {
            3.6593409448540415`, 3.316002810438542}, {3.710920990534653, 
            3.3626989131664167`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.7263961865870723`, 3.3767088143803927`}, {
            3.7777716903719374`, 3.4232197426042528`}, {3.887987957987667, 
            3.5229960671288705`}, {3.991793536065935, 3.616966247750027}, {
            4.090992212971449, 3.7067647482053543`}, {4.185583988704209, 
            3.7923915684948524`}, {4.275568863264214, 3.8738467086185215`}, {
            4.3454256945691005`, 3.9370809298854725`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.360901783301769, 3.951089844990674}, {
            4.361743725693279, 3.951851969044747}, {4.444905465033221, 
            4.027129150241915}, {4.602189574445733, 4.169499274949079}, {
            4.748828323858757, 4.302231383574355}, {4.886878165738404, 
            4.427187747488403}, {4.898765459437324, 4.437947520216285}, {
            4.9799551458656, 4.5114356079495765`}}]}, 
          {Arrowheads[{{0.00018312665728002333`, 1.}}], 
           ArrowBox[{{4.995431671272024, 4.525444040632446}, {
            5.001099999999999, 4.530574675534338}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-2.85148712577016, -0.23029144393455214`}, \
{-3.0052061955178333`, -0.24269747274146328`}, {-3.178999516526145, \
-0.25672869542564486`}, {-3.3360141254773086`, -0.2694084553203895}, \
{-3.468636952155389, -0.28012043164168454`}, {-3.593368940679019, \
-0.2901959222613656}, {-3.6837716745297824`, -0.29749910137872176`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.704578731288698, -0.29917999813861634`}, \
{-3.7102100910481983`, -0.2996349271794327}, {-3.819160403262927, \
-0.30843744639588583`}, {-4.020176266629242, -0.3246799147841657}, \
{-4.203204284178175, -0.33947021448642084`}, {-4.37131267272835, \
-0.3530558472038541}, {-4.527569649098395, -0.3656843146376684}, \
{-4.536859444963103, -0.3664351348537955}}]}, 
          {Arrowheads[{{0.01065587981852837, 1.}}], 
           ArrowBox[{{-4.557666439751991, -0.36811679853638496`}, \
{-4.673343504808289, -0.37746605445668735`}, {-4.810637228958751, \
-0.3885627459724463}, {-4.8397234797957855`, -0.3909136649276642}, \
{-4.981462422303983, -0.4023701253449067}, {-5.001099999999999, \
-0.40395738979601215`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.333974464459476, -2.4473121441905685`}, {
            3.4668671679590886`, -2.544782938698432}, {
            3.5916214739694774`, -2.636280780200884}, {
            3.7082373824906427`, -2.7218056686979253`}, {
            3.816714893522585, -2.801357604189555}, {
            3.918848575670308, -2.876254329087234}, {
            4.007302228699371, -2.941117936856844}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.024136081668606, -2.953462183252837}, {
            4.109468159128109, -3.0160353743351225`}, {
            4.197954060438186, -3.0809196946853312`}, {
            4.364435506095591, -3.20299316266363}, {
            4.519034758385921, -3.3163512215626727`}, {
            4.663142749682218, -3.4220144120727944`}, {
            4.697506268096648, -3.447210126725558}}]}, 
          {Arrowheads[{{0.008516933270713956, 1.}}], 
           ArrowBox[{{4.71434082578964, -3.459553412032456}, {
            4.798791531461084, -3.5214736105598785`}, {
            4.814675637281714, -3.533119924300532}, {
            4.954599012483831, -3.6357111989670354`}, {
            5.001099999999999, -3.6698051519099097`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4870017712913848`, 3.3404286368492437`}, {
            2.586188418878517, 3.4735056125574313`}, {2.6793157041442974`, 
            3.598445974580457}, {2.7663836270887248`, 3.715249722918321}, {
            2.8473921877117996`, 3.823916857571022}, {2.9236748382435183`, 
            3.926239170866066}, {2.9860383686734604`, 4.009888802057766}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.998515408829787, 4.0266244673810485`}, {
            3.0660627657228723`, 4.1172247103657}, {3.132168042670508, 
            4.2058879365702895`}, {3.2565523991182106`, 4.372712370872506}, {
            3.3720692763934967`, 4.5276388270211}, {3.4797554704153697`, 
            4.6720589945508895`}, {3.4976281185286084`, 4.696027890250642}}]}, 
          {Arrowheads[{{0.008615030207399498, 1.}}], 
           ArrowBox[{{3.5101064935425015`, 4.71276256030711}, {
            3.5811259158958157`, 4.80800625985616}, {3.592706062015002, 
            4.823536163685698}, {3.6972557391671272`, 4.963743295538106}, {
            3.7251122457677215`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.425268221670665, -2.0075369459300316`}, {
            3.561028268281176, -2.0870482825766077`}, {
            3.688498013215265, -2.1617008014002503`}, {
            3.8076774564729328`, -2.2314945024009596`}, {
            3.9185665980541793`, -2.2964293855787354`}, {
            4.02299011211573, -2.357575457392066}, {
            4.122772672814312, -2.4160027242994397`}, {
            4.145803910066299, -2.4294880813087896`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.163817953457856, -2.440035747665538}, {
            4.308414934122569, -2.5247008433963156`}, {
            4.478709401971244, -2.6244085438206244`}, {
            4.636872096352635, -2.717010626523627}, {
            4.784321088928457, -2.8033379399887823`}, {
            4.884390107985755, -2.861924607160569}}]}, 
          {Arrowheads[{{0.0027393146036086345`, 1.}}], 
           ArrowBox[{{4.902404638788074, -2.872471441038965}, {
            4.923128441958586, -2.884604452537651}, {
            4.941638671329958, -2.895441406361761}, {
            5.001099999999999, -2.9302529044986696`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.9513955648506467`, 
            3.413646278402669}, {-2.028636810588779, 
            3.5489186594250013`}, {-2.1012321335227373`, 
            3.6760656622074017`}, {-2.1691815336525218`, 
            3.79508728674987}, {-2.2324850109781327`, 
            3.9059835330524053`}, {-2.292152209059401, 
            4.010518232053436}, {-2.349192771456158, 
            4.110455214691392}, {-2.365367445750135, 4.138795723945683}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.3757146682875923`, 
            4.156925644261187}, {-2.4553939891961383`, 
            4.296536030878072}, {-2.5528926712396824`, 
            4.467381249626507}, {-2.6434928246284, 
            4.626146138950753}, {-2.727994900946688, 
            4.774231496397596}, {-2.7895698704575405`, 
            4.882141688535357}}]}, 
          {Arrowheads[{{0.0027805361871901853`, 1.}}], 
           ArrowBox[{{-2.7999155447059687`, 
            4.900272492412504}, {-2.8075697324651046`, 
            4.913686463678884}, {-2.8182077597664317`, 
            4.932329914139282}, {-2.857447194660159, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-1.9466181874509794`, -3.4133192438423485`}, \
{-2.023671812201054, -3.548581295751468}, {-2.0960906877102112`, \
-3.6757184436059798`}, {-2.1638748139784503`, -3.794730687405882}, \
{-2.227024191005771, -3.9056180271511756`}, {-2.286546051938078, \
-4.01014421321628}, {-2.343447629921275, -4.110072995975614}, \
{-2.3598544596326394`, -4.138888137797144}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.370183285318962, -4.157028545312625}, \
{-2.4493899370403405`, -4.296138351576971}, {-2.54665078092207, \
-4.466969179677099}, {-2.637029830125568, -4.625720565997848}, \
{-2.721325604324055, -4.773793217652996}, {-2.783302422360591, \
-4.88266414107812}}]}, 
          {Arrowheads[{{0.0027642398360772924`, 1.}}], 
           ArrowBox[{{-2.7936296937944607`, -4.900805433469164}, \
{-2.8007061081054614`, -4.913236141998331}, {-2.8113394293492315`, \
-4.931915353084773}, {-2.8507223980827088`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.826517621899435, 2.3303161307781894`}, {
            3.9378741077393884`, 2.398076109698264}, {4.042745802987825, 
            2.461887493051715}, {4.142960556185909, 2.5228640148102888`}, {
            4.238518367333642, 2.5810056749739854`}, {4.329419236431024, 
            2.6363124735428047`}, {4.500474961200382, 2.7403853138601963`}, {
            4.539846782297641, 2.7643391122127037`}}]}, 
          {Arrowheads[{{0.012432046474265839`, 1.}}], 
           ArrowBox[{{4.557680386970055, 2.77518906932203}, {
            4.659352543219634, 2.8370463637268495`}, {4.807474605991722, 
            2.927161729593504}, {4.946920032160921, 3.0119970019658435`}, {
            4.9647033190008445`, 3.022815841780829}, {5.001099999999999, 
            3.044958137027218}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.6466716919304667`, -1.6739154269629926`}, {
            3.8317617919403006`, -1.7588171213280497`}, {
            3.934162615528702, -1.8057854437396217`}, {
            4.031993300031777, -1.850656346881736}, {
            4.2139442517819505`, -1.9341058953575923`}, {
            4.380792904256306, -2.010625141522787}, {
            4.40564258607459, -2.02202118833849}}]}, 
          {Arrowheads[{{0.015190727397796713`, 1.}}], 
           ArrowBox[{{4.42461725855282, -2.0307229599529433`}, {
            4.535717514520328, -2.08167346014449}, {
            4.68011612655432, -2.14789256706634}, {
            4.816030697234008, -2.2102196887426038`}, {
            4.838655430881418, -2.2205947258789855`}, {
            4.979055602843468, -2.2849769398496136`}, {
            5.001099999999999, -2.2950854377452536`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.917764592590023, -1.3356011722174241`}, {
            4.1217923087164845`, -1.4051067471733045`}, {
            4.307230711897047, -1.4682756417469416`}, {
            4.477307131731705, -1.5262085588717658`}, {
            4.635248897820456, -1.580006201481208}, {
            4.708159939072079, -1.604840166110914}}]}, 
          {Arrowheads[{{0.006912403274982878, 1.}}], 
           ArrowBox[{{4.727920015853703, -1.6115705740086919`}, {
            4.782476869091276, -1.6301529854014214`}, {
            4.9210666572931805`, -1.6773565120413014`}, {
            4.945555254281864, -1.6856972035550128`}, {
            5.001099999999999, -1.7046149732088343`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.6775006391100544`, 
            0.14590226493332495`}, {-3.796591847367668, 
            0.15062889476986677`}, {-3.907665601932395, 
            0.1550377642627211}, {-4.112645159180407, 
            0.16317479198111154`}, {-4.299323720051304, 
            0.1705859178522406}, {-4.470818051276108, 
            0.17739467705958947`}, {-4.511837163605585, 
            0.17902331104849084`}}]}, 
          {Arrowheads[{{0.011228193350816755`, 1.}}], 
           ArrowBox[{{-4.53269557109142, 
            0.17985147893064596`}, {-4.630244919585841, 
            0.1837246047866395}, {-4.778995504183528, 
            0.18963086993573064`}, {-4.919106647641306, 
            0.195194252266724}, {-4.947152091534441, 
            0.1963078670944444}, {-5.001099999999999, 0.1984500330794251}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.6301910208938641`, 
            3.675038960506554}, {-1.6780003205883485`, 
            3.7829705678560552`}, {-1.766097894250362, 
            3.9818895221729695`}, {-1.8462266123998947`, 
            4.162842915761201}, {-1.9197597927555994`, 
            4.328922676864029}, {-1.968282368040396, 4.438523523486232}}]}, 
          {Arrowheads[{{0.014236161843065092`, 1.}}], 
           ArrowBox[{{-1.9767329618651461`, 
            4.457611385831064}, {-1.9880707530361283`, 
            4.483220733724739}, {-2.051767418512843, 
            4.627107091623729}, {-2.1117386426894087`, 
            4.762585144764486}, {-2.121984480286881, 
            4.785731664270209}, {-2.1838779978096605`, 
            4.925562576102816}, {-2.2173120469927166`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.367445317543604, 
            4.1479157825724045`}, {-1.4291142024547268`, 
            4.335373787328047}, {-1.4857244379005055`, 
            4.5074823904074135`}, {-1.538326122734801, 
            4.667421276682255}, {-1.5873847968096269`, 
            4.816601802296793}, {-1.6283267228311935`, 
            4.941108905801276}}]}, 
          {Arrowheads[{{0.0010126102198287248`, 1.}}], 
           ArrowBox[{{-1.6348474967956053`, 
            4.960939148658676}, {-1.6414691650122186`, 
            4.981076802041036}, {-1.6480527771480862`, 5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.3637521722541963`, -4.146800012345667}, \
{-1.4252561731478062`, -4.334213391296876}, {-1.481714836864897, \
-4.506280490453625}, {-1.5341755439528553`, -4.666180458056153}, \
{-1.5831026185212416`, -4.815324386282574}, {-1.6240596010764279`, \
-4.940181686481863}}]}, 
          {Arrowheads[{{0.0010356238346086136`, 1.}}], 
           ArrowBox[{{-1.6305660188908948`, -4.960016644311448}, \
{-1.6370535323255626`, -4.979794532195071}, {-1.6440416731382705`, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.825384995688661, 1.8627582074416893`}, {
            3.927647841336839, 1.9125172865416447`}, {4.025346876273193, 
            1.960054437033186}, {4.207053514010427, 2.0484629521910276`}, {
            4.373678524345309, 2.1295296239358925`}, {4.528395522722786, 
            2.2048003232884597`}, {4.576225962559461, 2.228069419878968}}]}, 
          {Arrowheads[{{0.010817021354196673`, 1.}}], 
           ArrowBox[{{4.594997316758045, 2.2372015218515404`}, {
            4.672600606867374, 2.2749548534006814`}, {4.808332910295524, 
            2.3409860780851575`}, {4.830304016725668, 2.3516744936038436`}, {
            4.9704990713428945`, 2.419874808866285}, {5.001099999999999, 
            2.4347608626494126`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.8198772753366947`, -0.4873736996739765}, {
            3.9309882401356004`, -0.5015420644144966}, {
            4.13552339128835, -0.5276213849643828}, {
            4.321405738947498, -0.5513207171248358}, {
            4.491876787049498, -0.5730539029523403}, {
            4.648165940967056, -0.5929782740705986}}]}, 
          {Arrowheads[{{0.008021984457601111, 1.}}], 
           ArrowBox[{{4.668873202600967, -0.5956180355200859}, {
            4.797735543813986, -0.6120453490748429}, {
            4.936632248817247, -0.6297513983265598}, {
            4.964661484026156, -0.633324415838717}, {
            5.001099999999999, -0.6379692238081639}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.2175530188692121, 1.77709567509822}, {
            0.24142726062618805`, 1.9899951480898712`}, {0.2549668013924502, 
            2.1079246196847263`}, {0.26725207390625944`, 2.213838895001401}, {
            0.28893185985499986`, 2.398719479666636}, {0.29864103931497615`, 
            2.4809027149202993`}, {0.3077697231236547, 2.5579250088058303`}, {
            0.31354936980396575`, 2.6065504219661593`}}]}, 
          {Arrowheads[{{0.004637407181724798, 1.}}], 
           ArrowBox[{{0.3160132229951369, 2.627279349877137}, {
            0.3189906847379835, 2.652329377227113}, {0.3197206582730176, 
            2.658461224381362}, {0.329602052634148, 2.741274825558381}, {
            0.3389556031367682, 2.8195255133285198`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.528539116842289, -4.078789590536091}, {
            1.5976834261871868`, -4.2629393931923385`}, {
            1.6611276393372039`, -4.4318844435319065`}, {
            1.72006202066461, -4.588805407057971}, {
            1.7750124791914643`, -4.735106173239462}, {
            1.8221042005454213`, -4.860476215760185}}]}, 
          {Arrowheads[{{0.003098068937093062, 1.}}], 
           ArrowBox[{{1.8294445739350396`, -4.880017913316336}, {
            1.8357574280023976`, -4.896823789195838}, {
            1.8749291102474166`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.017047932478880815`, 1.}}], 
           ArrowBox[{{-0.15160860893496053`, 
            2.069281059961496}, {-0.1598865030548814, 
            2.1740590346470205`}, {-0.17408899191493102`, 
            2.3571721853074683`}, {-0.18032583353079681`, 
            2.4386221572067113`}, {-0.18613975118619447`, 
            2.5149730278648024`}, {-0.1935565803550282, 
            2.6128729246567883`}, {-0.19403612662312705`, 
            2.6192208895050313`}, {-0.20021469097977754`, 
            2.701339275587926}, {-0.20603539194278542`, 
            2.7789422064076255`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.937895602336475, 1.4735173397146408`}, {
            4.042702463183522, 1.5127068811719975`}, {4.1428456539869885`, 
            1.5501515744696033`}, {4.329141025463176, 1.6198064165855615`}, {
            4.500017675064233, 1.6836931630618857`}, {4.658711561089349, 
            1.7430231108979455`}, {4.720010370041457, 1.7659398588584947`}}]}, 
          {Arrowheads[{{0.006687840681080244, 1.}}], 
           ArrowBox[{{4.739563456646698, 1.7732498403286594`}, {
            4.806648154995819, 1.798329660807348}, {4.945910009170409, 
            1.8503920461831291`}, {4.9693943474360305`, 1.859171458535514}, {
            5.001099999999999, 1.8710239848477566`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.312385740030398, -3.8240210931441125`}, {
            2.3798065341251977`, -3.9353683724856587`}, {
            2.443316138426647, -4.040248941933916}, {
            2.5040124978593794`, -4.140480231908087}, {
            2.561895612423396, -4.236062242408171}, {
            2.616965482118696, -4.32699497343417}, {
            2.7206091731103004`, -4.498126918078096}, {
            2.7449145641509887`, -4.538257227199653}}]}, 
          {Arrowheads[{{0.012461101738854438`, 1.}}], 
           ArrowBox[{{2.755728820818574, -4.556112503103815}, {
            2.816887257041345, -4.657090386854057}, {
            2.9066585516465357`, -4.805304974139946}, {
            2.9911783777943364`, -4.944845532670159}, {
            3.0019689121688042`, -4.962660248113426}, {
            3.0252527133058265`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8578668198158788`, -3.8310205069757584`}, {
            1.9076545679906436`, -3.9335297826345204`}, {
            1.9552308747752711`, -4.031480408502196}, {
            2.043749164174115, -4.213705710864285}, {
            2.1249528772784463`, -4.380856137412487}, {
            2.2003732033543018`, -4.5360914114972655`}, {
            2.2227199379755906`, -4.5820841796825444`}}]}, 
          {Arrowheads[{{0.010658463535223884`, 1.}}], 
           ArrowBox[{{2.2318426800661175`, -4.600860084497916}, {
            2.2706857655425154`, -4.680804696370426}, {
            2.336877868230756, -4.817031619148728}, {
            2.3474707039363514`, -4.838831755069196}, {
            2.4158172321922518`, -4.97948424011014}, {
            2.4263211357203986`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.6269523871683038`, -3.6757836173794463`}, \
{-1.6746649467307755`, -3.7837333506591264`}, {-1.7625843876595275`, \
-3.9826860875733208`}, {-1.8425512026209547`, -4.16367054434238}, \
{-1.915935899198554, -4.329779076810037}, {-1.964423860167175, \
-4.439542376301099}}]}, 
          {Arrowheads[{{0.014204194681026815`, 1.}}], 
           ArrowBox[{{-1.972858955231083, -4.458637092746991}, \
{-1.9841089849758213`, -4.484104040820023}, {-2.0476771444185218`, \
-4.628015641910043}, {-2.1075274180647257`, -4.763517569809964}, \
{-2.1177578721346895`, -4.786680125079866}, {-2.1795265823702112`, \
-4.926535750406724}, {-2.2124575150567534`, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.489536331158792, -3.3387647090227435`}, {
            2.5888346860173206`, -3.4717897588322866`}, {
            2.6820663149626496`, -3.5966806550637154`}, {
            2.7692312179947782`, -3.7134373977170294`}, {
            2.8503293951137065`, -3.82205998679223}, {
            2.926696005129237, -3.9243397868474017`}, {
            2.989059118358703, -4.007862178303533}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.001548310762969, -4.024588776821017}, {
            3.069240000279511, -4.115245113571918}, {
            3.1354173854142533`, -4.203870640241262}, {
            3.2599369630307984`, -4.370623533200806}, {
            3.3755789719286544`, -4.5254829543259465`}, {
            3.4833814338904023`, -4.669840127174178}, {
            3.5011471129818927`, -4.693629490346221}}]}, 
          {Arrowheads[{{0.008691671531567363, 1.}}], 
           ArrowBox[{{3.5136376398094016`, -4.710355092411841}, {
            3.584861066202128, -4.805727745947243}, {
            3.596450993775907, -4.821247232069017}, {
            3.701113847043855, -4.961393609492317}, {
            3.730767392019664, -5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.2813995274278906`, 2.462900248124737}, {
            3.4126536338633544`, 2.5613348576363473`}, {3.5358480461211745`, 
            2.653721058638228}, {3.650982764201352, 2.740058851130379}, {
            3.7580577881038866`, 2.8203482351128}, {3.8588537984512765`, 
            2.8959262281742033`}, {3.94943439997624, 
            2.9638432068898277`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.96613599674449, 2.976365814057092}, {4.04695082034812,
             3.0369590943000913`}, {4.134251831897573, 3.102413967364576}, {
            4.29848566282801, 3.225547031332639}, {4.450979775286799, 
            3.339875477643503}, {4.593110271134592, 3.4464316899666017`}, {
            4.634216063416899, 3.4772484990763552`}}]}, 
          {Arrowheads[{{0.010482950325321698`, 1.}}], 
           ArrowBox[{{4.6509183814262, 3.489770144255898}, {4.726887188549364,
             3.546723583112688}, {4.7428742872718415`, 3.5587089359069286`}, {
            4.880901189020902, 3.66218481391513}, {5.001099999999999, 
            3.752294406943694}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.308158718827754, 3.822852980955732}, {
            2.375459602538255, 3.934171669344228}, {2.438856060144002, 
            4.039024960534862}, {2.499444187952307, 4.13923000733143}, {
            2.5572239859631707`, 4.234786809733932}, {2.612195454176592, 
            4.325695367742368}, {2.715653744873778, 4.496781452717433}, {
            2.7402057324268303`, 4.537380668955802}}]}, 
          {Arrowheads[{{0.012480351147006614`, 1.}}], 
           ArrowBox[{{2.7510079469740716`, 4.5552432327628685`}, {
            2.811759403706531, 4.655701964397018}, {2.9013697563468273`, 
            4.8038761959476215`}, {2.9857379387301095`, 4.943378553190721}, {
            2.996531570756058, 4.961225523977582}, {3.0206476882198787`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8554259814792653`, 3.831707261419508}, {
            1.9051471643355748`, 3.934232363477205}, {1.9526599238312519`, 
            4.032198229848961}, {2.0410601727407096`, 4.214452255534655}, {
            2.1221557937690148`, 4.381629402582819}, {2.197475852477543, 
            4.536889735099682}, {2.2198388341096553`, 4.58298464769308}}]}, 
          {Arrowheads[{{0.010631315767766757`, 1.}}], 
           ArrowBox[{{2.2289505707909334`, 4.601765895775602}, {
            2.2676950446308197`, 4.681626585396804}, {2.333799321858301, 
            4.817875832466125}, {2.3443816094466996`, 4.83968676779869}, {
            2.412637383635353, 4.980362143713271}, {2.4226996619961714`, 
            5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.010948478585290019`, 1.}}], 
           ArrowBox[{{-4.666864278409445, 
            4.349865946212344}, {-4.816104764945756, 
            4.489090151293192}, {-4.95665180054296, 
            4.620205714260319}, {-4.967608698509003, 
            4.630427396122798}, {-5.001099999999999, 4.6616716488247025`}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.4011526993594887`, -0.7873780202895184}, {
            3.6046873342787547`, -0.8344762712091959}, {
            3.787215324104555, -0.8767080986325284}, {
            3.985323895768214, -0.9225397986988526}, {
            4.165278396664479, -0.9641684109257735}, {
            4.214657762594497, -0.9755905367944457}}]}, 
          {Arrowheads[{{0.018834378266694245`, 1.}}], 
           ArrowBox[{{4.234995595687242, -0.9802949570539244}, {
            4.3302455103534605`, -1.0023275711591706`}, {
            4.48339192039527, -1.0377509152449236`}, {
            4.6261073529491386`, -1.0707602588215934`}, {
            4.760420834899752, -1.101825426507654}, {
            4.7889726055712085`, -1.1084290252920337`}, {
            4.927930437700361, -1.1405671310617769`}, {
            5.001099999999999, -1.15748939522472}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.012143919699496741`, 1.}}], 
           ArrowBox[{{-0.558214125771623, -4.497910654027205}, \
{-0.5778950313318797, -4.657376820406888}, {-0.5962447680892741, \
-4.806100865680974}, {-0.6135202987580546, -4.946147573073293}, \
{-0.6169158712032742, -4.9736773719986}, {-0.6202975943239653, \
-5.001099999999999}}]}}, 
         {RGBColor[0, 0, 1], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.5413813543414705, 1.6770844998864296`}, {
            0.6030083253567203, 1.8748487837594245`}, {0.6383856477958968, 
            1.9873615009371157`}, {0.6701907898895682, 2.0881019942216876`}, {
            0.7257738452813275, 2.263388851578407}, {0.7505038345281776, 
            2.3411432839577024`}, {0.7736907421265916, 2.4139514724774402`}, {
            0.7926380926005098, 2.4733762803577033`}}]}, 
          {Arrowheads[{{0.004372576990308402, 1.}}], 
           ArrowBox[{{0.7989794113754631, 2.493264636274686}, {
            0.8037201654530948, 2.5081331214836675`}, {0.8056668894918398, 
            2.514234575076957}, {0.8307862246678949, 2.592890247241789}, {
            0.8545230793965849, 2.6671633296410366`}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sca\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(sca\\)]\\)}\"", 
          TraditionalForm]}}], {583.2, -189.}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.162305389879444}, \
{-4.821889415864387, -2.1623192044171278`}, {-4.621279449026206, \
-2.162334668536951}, {-4.420669482188025, -2.162350132656774}, \
{-4.220059515349844, -2.1623655967765973`}, {-4.166106325967133, \
-2.162369755785238}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231484116311, -2.162371364932883}, \
{-4.019449548511663, -2.1623810608964202`}, {-3.818839581673482, \
-2.1623965250162436`}, {-3.65834669931489, -2.1623965107894807`}, \
{-3.497853466924774, -2.1623963336212273`}, {-3.4818041140551097`, \
-2.1623963068646836`}, {-3.465754758509956, -2.1623962795258542`}, \
{-3.457730079425167, -2.162396265590936}, {-3.449705399693793, \
-2.1623962515326123`}, {-3.4416807193221555`, -2.1623962373569636`}, \
{-3.4336560383165646`, -2.1623962230699387`}, {-3.4256313566832937`, \
-2.1623962086774178`}, {-3.3102378085727406`, -2.1623960002815372`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362966659933, -2.1623959620632918`}, \
{-3.162379754193911, -2.1623957185371854`}, {-3.044919182689947, \
-2.162395496536761}, {-2.9274586111859824`, -2.1623952745363364`}, \
{-2.8099980396820183`, -2.162395052535912}, {-2.692537468178054, \
-2.1623948305354874`}, {-2.57507689667409, -2.162394608535063}, \
{-2.4576163251701257`, -2.1623943865346384`}, {-2.454369290147727, \
-2.162394380397744}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944482349217`, -2.1623943409443025`}, \
{-2.3401557536661617`, -2.162394164534214}, {-2.222695182162197, \
-2.1623939425337895`}, {-2.192544244599234, -2.1623939278758044`}, \
{-2.16239330646329, -2.1623939143506177`}, {-2.0623896454525257`, \
-2.162393883935158}, {-1.9623859824551415`, -2.162393862651155}, \
{-1.9582478920952897`, -2.1623938617786473`}, {-1.9490521357294892`, \
-2.16239385992178}, {-1.9398563793560137`, -2.1623938581324964`}, \
{-1.8478988153993312`, -2.1623938463083614`}, {-1.7559412520178936`, \
-2.1623938393575473`}, {-1.6409943140125853`, -2.1623938419253856`}, \
{-1.5985007717216086`, -2.162393842874663}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625929808766, -2.1623938433409933`}, \
{-1.5260473760072775`, -2.1623938444932245`}, {-1.4111004380019692`, \
-2.162393847061063}, {-1.296153499996661, -2.1623938496289017`}, \
{-1.181206561991353, -2.16239385219674}, {-1.066259623986045, \
-2.162393854764579}, {-0.9513126859807366, -2.1623938573324173`}, \
{-0.8363657479754286, -2.162393859900256}, {-0.7426322532950618, \
-2.162393859976792}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574113822192, -2.1623938599938364`}, \
{-0.7214188110231199, -2.162393859994113}, {-0.6064718740708108, \
-2.1623938600879704`}, {-0.49152493711850176`, -2.1623938601818273`}, \
{-0.3765780001661927, -2.1623938602756847`}, {-0.2616310632138837, \
-2.1623938603695416`}, {-0.14668412626157462`, -2.162393860463399}, \
{-0.031737189309265584`, -2.162393860557256}, {
            0.08320974764304301, -2.1623938606511133`}, {
            0.11323626512922923`, -2.162393492585655}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110704050352`, -2.16239323670156}, {
            0.2205743305290575, -2.162392176834195}, {
            0.35793891341507145`, -2.162390493017276}, {
            0.49530349630108494`, -2.1623888092003574`}, {
            0.6326680791870984, -2.1623871253834386`}, {
            0.7700326620731124, -2.16238544156652}, {
            0.9073972449591263, -2.162383757749601}, {
            0.9691047834914751, -2.1623830013377576`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899796254027494, -2.1623827454536624`}, {
            1.0447618278451407`, -2.1623820739326827`}, {
            1.1821264107311542`, -2.162380390115764}, {
            1.3194909936171682`, -2.162378706298845}, {
            1.456855576503182, -2.1623770224819263`}, {
            1.5942201593891956`, -2.1623753386650075`}, {
            1.73158474227521, -2.162373654848089}, {
            1.824973301853721, -2.16237251008986}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481437649954`, -2.162372254205765}, {
            1.868949325161224, -2.1623719710311704`}, {
            2.006313908047238, -2.1623702872142516`}, {
            2.1436784909332514`, -2.162368603397333}, {
            2.2810430738192653`, -2.162366919580414}, {
            2.4184076567052792`, -2.1623652357634953`}, {
            2.5557722395912927`, -2.162363551946577}, {
            2.680841820215967, -2.1623620188419626`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.7017166621272413`, -2.1623617629578673`}, {
            2.83050140536332, -2.1623601843127394`}, {
            2.967865988249334, -2.1623585004958206`}, {
            3.1052305711353476`, -2.162356816678902}, {
            3.2425951540213624`, -2.162355132861983}, {
            3.3799597369073764`, -2.1623534490450647`}, {
            3.51732431979339, -2.162351765228146}, {
            3.536710338578213, -2.162351527594065}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.557585180489487, -2.1623512717099698`}, {
            3.6546889026794043`, -2.162350081411227}, {
            3.792053485565418, -2.1623483975943083`}, {
            3.929418068451432, -2.1623467137773895`}, {
            4.066782651337446, -2.1623450299604707`}, {
            4.204147234223459, -2.1623433461435524`}, {
            4.341511817109473, -2.1623416623266336`}, {
            4.3925788569404585`, -2.162341036346167}}]}, 
          {Arrowheads[{{0.014075472171732962`, 1.}}], 
           ArrowBox[{{4.4134536988517326`, -2.162340780462072}, {
            4.478876399995487, -2.162339978509715}, {
            4.6918932994858356`, -2.162148166612845}, {
            4.904910198976184, -2.1619563547159752`}, {
            5.001099999999999, -2.1618697402349736`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.1629074895829916`}, {-4.820335472182759, 
            2.1629213845688433`}, {-4.6197619061877075`, 
            2.1629368022334443`}, {-4.419188340192656, 
            2.1629522198980458`}, {-4.218614774197604, 
            2.162967637562647}, {-4.166106325953146, 2.162971673775693}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231484101975, 
            2.1629732783805107`}, {-4.018041208202552, 
            2.162983055227248}, {-3.8174676422075007`, 
            2.1629984728918497`}, {-3.6570038707367942`, 
            2.1629984554973034`}, {-3.4965397495390467`, 
            2.162998276173531}, {-3.4804933078218347`, 
            2.162998249278524}, {-3.464446863432505, 
            2.162998221807781}, {-3.4564236399273143`, 
            2.162998207810083}, {-3.4484004157763812`, 
            2.1629981936905316`}, {-3.4403771909860303`, 
            2.162998179455177}, {-3.4323539655625686`, 
            2.1629981651099506`}, {-3.424330739512268, 
            2.1629981506607097`}, {-3.3102378085569932`, 
            2.162997943790478}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629666441857`, 
            2.1629979055714443`}, {-3.161156501579246, 
            2.1629976591048496`}, {-3.0436956646796487`, 
            2.1629974367864397`}, {-2.9262348277800516`, 
            2.16299721446803}, {-2.8087739908804545`, 
            2.16299699214962}, {-2.691313153980857, 
            2.16299676983121}, {-2.57385231708126, 
            2.1629965475128}, {-2.4563914801816624`, 
            2.1629963251943907`}, {-2.454369290131984, 
            2.1629963213669865`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4334944482191787`, 
            2.1629962818571227`}, {-2.3389306432820653`, 
            2.1629961028759808`}, {-2.221469806382468, 
            2.162995880557571}, {-2.1913199296676416`, 
            2.1629958659389628`}, {-2.1611700523834116`, 
            2.1629958524523993`}, {-2.0612050740986168`, 
            2.1629958221580097`}, {-1.961240093854657, 
            2.162995800976082}, {-1.9571024299074549`, 
            2.1629958001075353`}, {-1.947907621125548, 
            2.1629957982593266`}, {-1.9387128123361543`, 
            2.1629957964785818`}, {-1.8467647242368443`, 
            2.1629957847276455`}, {-1.7548166367256313`, 
            2.162995777837942}, {-1.6398815435822107`, 
            2.1629957804011837`}, {-1.598500771705869, 
            2.1629957813240432`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259297930264`, 
            2.1629957817895864`}, {-1.5249464504387902`, 
            2.1629957829644257`}, {-1.4100113572953699`, 
            2.1629957855276674`}, {-1.2950762641519493`, 
            2.162995788090909}, {-1.180141171008529, 
            2.162995790654151}, {-1.0652060778651085`, 
            2.1629957932173927`}, {-0.950270984721688, 
            2.1629957957806347`}, {-0.8353358915782675, 
            2.1629957983438763`}, {-0.7426322532793221, 
            2.1629957984204777`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574113664795, 
            2.162995798437727}, {-0.7204007994808119, 
            2.162995798438848}, {-0.6054657073833565, 
            2.1629957985338195`}, {-0.49053061528590103`, 
            2.1629957986287915`}, {-0.37559552318844536`, 
            2.162995798723763}, {-0.26066043109098974`, 
            2.1629957988187347`}, {-0.14572533899353407`, 
            2.1629957989137063`}, {-0.03079024689607887, 
            2.1629957990086783`}, {0.08414484520137677, 2.16299579910365}, {
            0.1132362651450341, 2.1629954420917947`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1341111070563048, 2.162995185914336}, {
            0.22150923381436982`, 2.1629941133586668`}, {0.35887362242736387`,
             2.1629924276136836`}, {0.4962380110403575, 
            2.1629907418687004`}, {0.6336023996533511, 2.1629890561237173`}, {
            0.7709667882663447, 2.162987370378734}, {0.9083311768793383, 
            2.1629856846337505`}, {0.9691047835071328, 
            2.1629849388159768`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796254184035, 2.162984682638518}, {
            1.045695565492332, 2.1629839988887674`}, {1.1830599541053255`, 
            2.162982313143784}, {1.320424342718319, 2.162980627398801}, {
            1.4577887313313127`, 2.162978941653818}, {1.5951531199443063`, 
            2.1629772559088343`}, {1.7325175085573004`, 2.162975570163851}, {
            1.8249733018692313`, 2.1629744355401592`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.845848143780502, 2.1629741793627004`}, {
            1.869881897170294, 2.162973884418868}, {2.0072462857832876`, 
            2.162972198673885}, {2.144610674396281, 2.1629705129289016`}, {
            2.2819750630092748`, 2.162968827183918}, {2.4193394516222693`, 
            2.162967141438935}, {2.556703840235263, 2.1629654556939517`}, {
            2.68084182023133, 2.1629639322643417`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.7017166621426005`, 2.1629636760868824`}, {
            2.83143261746125, 2.162962084203985}, {2.9687970060742437`, 
            2.162960398459002}, {3.1061613946872377`, 2.1629587127140186`}, {
            3.243525783300231, 2.1629570269690355`}, {3.380890171913225, 
            2.1629553412240523`}, {3.518254560526218, 2.1629536554790687`}, {
            3.5367103385934286`, 2.1629534289885233`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.557585180504699, 2.1629531728110645`}, {
            3.655618949139212, 2.1629519697340855`}, {3.7929833377522058`, 
            2.1629502839891024`}, {3.9303477263651994`, 
            2.1629485982441192`}, {4.0677121149781925`, 2.162946912499136}, {
            4.205076503591187, 2.1629452267541525`}, {4.34244089220418, 
            2.1629435410091693`}, {4.392578856955527, 2.1629429257127057`}}]}, 
          {Arrowheads[{{0.01407547216432203, 1.}}], 
           ArrowBox[{{4.413453698866798, 2.162942669535247}, {
            4.479805280817174, 2.162941855264186}, {4.692777738659196, 
            2.162750046113403}, {4.9057501965012165`, 2.162558236962619}, {
            5.001099999999999, 2.1624723621738235`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.6916798037135163`}, \
{-4.89963506942341, -3.6916739007811583`}, {-4.781322997504322, \
-3.691667017731481}, {-4.663010925585233, -3.691660134681803}, \
{-4.544698853666144, -3.691653251632126}, {-4.4263867817470555`, \
-3.6916463685824485`}, {-4.264999382476973, -3.6916367218567707`}, \
{-4.166106324877753, -3.6916316400579006`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231482992472, -3.6916305673663437`}, \
{-4.103610335749629, -3.6916284285883125`}, {-3.9862956347535325`, \
-3.6916233555518607`}, {-3.8689809337574363`, -3.691618282515409}, \
{-3.7516662327613406`, -3.691613209478957}, {-3.6343515317652444`, \
-3.691608136442505}, {-3.517036830769148, -3.691603063406053}, \
{-3.3997221297730524`, -3.6915979903696012`}, {-3.310237807275505, \
-3.691594120801456}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.28936296538218, -3.6915932181112314`}, \
{-3.2824074287769562`, -3.6915929173331494`}, {-3.1650927277808596`, \
-3.6915878442966976`}, {-3.134369652305425, -3.691587592540305}, \
{-3.1036465782702396`, -3.6915873625028306`}, {-2.973877939765894, \
-3.691586811654772}, {-2.8441093927479812`, -3.6915865325435604`}, \
{-2.687146858605531, -3.691586120324888}, {-2.5301843244630806`, \
-3.691585708106216}, {-2.454369288989372, -3.6915855089989993`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494447076601, -3.691585454177002}, \
{-2.373221790320631, -3.6915852958875432`}, {-2.216259256178181, \
-3.6915848836688707`}, {-2.0592967220357306`, -3.6915844714501986`}, \
{-1.9023341878932811`, -3.691584059231526}, {-1.7453716537508304`, \
-3.691583647012854}, {-1.598500770565776, -3.6915832612971107`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259286530054`, -3.6915832064751135`}, \
{-1.4314465854659306`, -3.6915828225755094`}, {-1.2744840513234803`, \
-3.691582410356837}, {-1.1175215171810304`, -3.691581998138165}, \
{-0.9605589830385806, -3.6915815859194923`}, {-0.8035964488961302, \
-3.69158117370082}, {-0.7426322521421805, -3.691581013595223}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574102294099, -3.691580958773226}, \
{-0.6466339147536799, -3.6915807614821476`}, {-0.4896713806112296, \
-3.691580349263475}, {-0.3327088464687802, -3.691579937044803}, \
{-0.1757463123263303, -3.6915795248261305`}, {-0.018783778183879996`, \
-3.6915791126074584`}, {0.11323626628141506`, -3.691578765893335}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110819418567`, -3.6915787110713376`}, {
            0.13817875595856988`, -3.691578700388786}, {
            0.2951412901010202, -3.691578288170114}, {
            0.4521038242434705, -3.6915778759514413`}, {
            0.6090663583859202, -3.691577463732769}, {
            0.76602889252837, -3.6915770515140967`}, {
            0.9229914266708201, -3.691576639295424}, {
            0.9691047847050106, -3.6915765181914466`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796266177813, -3.6915764633694494`}, {
            1.0799539608132696`, -3.691576227076752}, {
            1.2369164949557196`, -3.6915758148580795`}, {
            1.3938790290981697`, -3.6915754026394074`}, {
            1.55084156324062, -3.691574990420735}, {
            1.7078040973830704`, -3.691574578202063}, {
            1.8249733031286062`, -3.6915742704895584`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458481450413768`, -3.6915742156675613`}, {
            1.8647666315255205`, -3.6915741659833903`}, {
            2.0217291656679706`, -3.691573753764718}, {
            2.178691699810421, -3.6915733415460457`}, {
            2.333603890575591, -3.6912718900759414`}, {
            2.4905604237130357`, -3.691270596766777}, {
            2.647512956180474, -3.6912687160639517`}, {
            2.6808415282286595`, -3.691268191954993}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.701716370138921, -3.691267863687354}, {
            2.8044614879779077`, -3.6912662479674645`}, {
            2.961406019105337, -3.6912631924773165`}, {
            3.118346549562763, -3.6912595495935068`}, {
            3.275283079350184, -3.691255319316036}, {
            3.4322156084676014`, -3.6912505016449035`}, {
            3.536710046374955, -3.6912469025593}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5575848882754153`, -3.691246183570381}, {
            3.5891441369150137`, -3.6912450965801096`}, {
            3.7460686646924217`, -3.691239104121655}, {
            3.9029891917998247`, -3.6912325242695383`}, {
            4.059905718237224, -3.691225357023761}, {
            4.216818244004619, -3.691217602384322}, {
            4.373726769102008, -3.6912092603512217`}, {
            4.392578563910452, -3.6912081874967475`}}]}, 
          {Arrowheads[{{0.014075474148057964`, 1.}}], 
           ArrowBox[{{4.4134534057894905`, -3.69120699951079}, {
            4.530631293529394, -3.69120033092446}, {
            4.687531817286775, -3.6911908141040373`}, {
            4.844428340374151, -3.6911807098899527`}, {
            5.001099999999999, -3.691170033333137}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.456476187209355}, \
{-4.923652593445322, -4.45645440292092}, {-4.809928363400284, \
-4.456422414742883}, {-4.696204133355247, -4.456390426564846}, \
{-4.58247990331021, -4.456358438386809}, {-4.468755673265172, \
-4.456326450208773}, {-4.355031443220135, -4.456294462030736}, \
{-4.241307213175098, -4.4562624738527}, {-4.166106356517632, \
-4.456241321470395}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231515430574, -4.45623544982692}, \
{-4.12758298313006, -4.456230485674663}, {-4.013858753085023, \
-4.456198497496626}, {-3.900134523039985, -4.45616650931859}, \
{-3.7543956306273594`, -4.456160746889638}, {-3.608656838228404, \
-4.456156649832176}, {-3.491276063364802, -4.456154499687375}, \
{-3.3738952885011995`, -4.456152349542574}, {-3.3102378488341855`, \
-4.456151183485244}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.289363006924845, -4.456150801106333}, \
{-3.2565145136375975`, -4.456150199397773}, {-3.139133738773995, \
-4.456148049252971}, {-3.021752963910393, -4.45614589910817}, \
{-2.904372189046791, -4.4561437489633695`}, {-2.7869914141831886`, \
-4.456141598818569}, {-2.6696106393195866`, -4.456139448673768}, \
{-2.639137099634201, -4.4561397862123036`}, {-2.6086635836441743`, \
-4.456140129484718}, {-2.494547936237851, -4.4561414663610375`}, \
{-2.4543693305294627`, -4.456141933297695}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944886180296`, -4.456142175895185}, \
{-2.3804325812457225`, -4.456142792555451}, {-2.2364973348953545`, \
-4.45614277552336}, {-2.0925620885449865`, -4.45614275849127}, \
{-1.948626842194618, -4.456142741459179}, {-1.8046915958442495`, \
-4.456142724427089}, {-1.6607563494938815`, -4.456142707394998}, \
{-1.5985008121079138`, -4.4561427000282}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259701950714`, -4.456142697558046}, \
{-1.5168211031435133`, -4.456142690362908}, {-1.3728858567931452`, \
-4.456142673330818}, {-1.2289506104427768`, -4.456142656298727}, \
{-1.0850153640924085`, -4.456142639266637}, {-0.9410801177420403, \
-4.456142622234546}, {-0.7971448713916721, -4.456142605202456}, \
{-0.7426322936813728, -4.456142598751894}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574517685303, -4.45614259628174}, \
{-0.653209625041304, -4.456142588170366}, {-0.5092743786909358, \
-4.456142571138275}, {-0.3653391323405677, -4.456142554106185}, \
{-0.2214038859901991, -4.456142537074094}, {-0.07746863963983097, \
-4.456142520042004}, {0.06646800546797449, -4.456140937963652}, {
            0.11323622473364978`, -4.456140423911187}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411106664523142`, -4.456140194465548}, {
            0.2104046505757804, -4.4561393558853}, {
            0.35434129568358563`, -4.456137773806948}, {
            0.4982779407913911, -4.456136191728596}, {
            0.6422145858991966, -4.4561346096502445`}, {
            0.7861512310070018, -4.456133027571894}, {
            0.9300878761148073, -4.456131445493542}, {
            0.9691047431084967, -4.456131016639996}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899795850200783, -4.456130787194358}, {
            1.0740245212226127`, -4.45612986341519}, {
            1.2179611663304186`, -4.456128281336838}, {
            1.361897811438224, -4.456126699258486}, {
            1.5058344565460293`, -4.456125117180134}, {
            1.6497711016538352`, -4.456123535101782}, {
            1.7937077467616411`, -4.45612195302343}, {
            1.8249732614833436`, -4.456121609368804}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481033949252`, -4.456121379923165}, {
            1.937644391869446, -4.4561203709450785`}, {
            2.081581036977251, -4.456118788866727}, {
            2.225517682085057, -4.456117206788375}, {
            2.369347316968266, -4.456172440811955}, {
            2.5131769518514737`, -4.456227674835537}, {
            2.6570065867346813`, -4.456282908859118}, {
            2.680841746311377, -4.456292062131093}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7017165866849675`, -4.456300078569613}, {
            2.8008362216178897`, -4.456338142882698}, {
            2.944665856501098, -4.45639337690628}, {
            3.088495491384306, -4.45644861092986}, {
            3.2323251262675137`, -4.456503844953441}, {
            3.376154761150722, -4.456559078977023}, {
            3.5199843960339305`, -4.456614313000603}, {
            3.5367102016285874`, -4.456620736110426}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.5575850420021777`, -4.456628752548946}, {
            3.663814030917138, -4.456669547024184}, {
            3.8076436658003456`, -4.456724781047765}, {
            3.951473300683554, -4.456780015071346}, {
            4.095302935566763, -4.456835249094927}, {
            4.239132570449971, -4.456890483118507}, {
            4.38296220533318, -4.456945717142089}, {
            4.392578656945798, -4.45694941008976}}]}, 
          {Arrowheads[{{0.014075472965629564`, 1.}}], 
           ArrowBox[{{4.413453497319388, -4.45695742652828}, {
            4.526791840216387, -4.45700095116567}, {
            4.670621475099595, -4.45705618518925}, {
            4.814451109982803, -4.457111419212832}, {
            4.958280744866012, -4.4571666532364125`}, {
            5.001099999999999, -4.457183096855627}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQ3WShpKbF9sH+0X+hLXfXm9gbzPl9/YDYB3vGqRB+
iOzPE0rqH+zZtSH81TtunPnm/MFeIV8QzN9ytvZzbfQH+/YrAmA+h1hs6uzq
D/Y6//nB/FWhJ+rUl3+wX3eDD8y3LhO+r3bgg72kHoQfsNcgPu3OB/veLF4w
/8emqf/LJD7aM+7jBvNPvoxonhP20d7kNieYLzHzQsMdr0/2ETMZwfxfjeKf
OjM/2wfJfd4M4tdnnF09z+ur/Uu+c2A+s39z6mbt7/YN/1eA+R2mlvIneH7a
S3xoBvN5Zd7fuPP2l/36B3Fg/iSmpZM+nvtj73bREsxvkimq8kn6a+9Rrgfm
AwDy9Jrt
            "]]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8573735585568447`, 0.00031565821259917174`}, {
            1.917974756490883, 0.00031565821253123715`}, {2.0354261624279166`,
             0.00031565821239957294`}, {2.15287756836495, 
            0.0003156582122679087}, {2.1830719482339087`, 
            0.0003156582104500702}, {2.213266328467798, 
            0.00031565820845020357`}, {2.3148787373129522`, 
            0.00031565819840031654`}, {2.416491153684432, 
            0.00031565818492869244`}, {2.4200335703152165`, 
            0.00031565818445553333`}, {2.4469070763942717`, 
            0.00031565818059917984`}, {2.4713375370789348`, 
            0.0003156581768255307}, {2.593489881616822, 
            0.00031565814106488256`}, {2.692367235070549, 
            0.00031565811211809266`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.713242076983392, 0.00031565810600688883`}, {
            2.7156422261547095`, 0.0003156581053042344}, {2.837794646061308, 
            0.00031565804141291234`}, {2.959947065967907, 
            0.00031565797752159037`}, {3.1126554094460643`, 
            0.0003156541962353897}, {3.265363752924222, 
            0.00031565041494918905`}, {3.41807209640238, 
            0.0003156466336629884}, {3.548235753497096, 
            0.0003156434106168261}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5691105954099385`, 0.00031564289372462576`}, {
            3.5707804398805374`, 0.00031564285237678773`}, {3.723488783358695,
             0.0003156390710905871}, {3.8761971268368525`, 
            0.0003156352898043864}, {4.02890547031501, 
            0.00031563150851818576`}, {4.181613813793168, 
            0.0003156277272319851}, {4.334322157271325, 
            0.00031562394594578444`}, {4.404104271923643, 
            0.00031562221803661344`}}]}, 
          {Arrowheads[{{0.013799407166026803`, 1.}}], 
           ArrowBox[{{4.424979113836486, 0.0003156217011444131}, {
            4.4870305007494835`, 0.0003156201646595838}, {4.639738844227641, 
            0.0003156163833733832}, {4.792447187705799, 
            0.0003156126020871825}, {4.945155531183956, 
            0.00031560882080098186`}, {5.001099999999999, 
            0.0003156074355325471}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.000317273199926499}, {-4.978332273873804, 
            0.0003172776223227946}, {-4.865320418856539, 
            0.00031729957371162546`}, {-4.752308563839275, 
            0.00031732152510045625`}, {-4.639296708822009, 
            0.0003173434764892871}, {-4.526284853804745, 
            0.0003173654278781179}, {-4.4132729987874795`, 
            0.00031738737926694866`}, {-4.300261143770215, 
            0.00031740933065577945`}, {-4.166106323486308, 
            0.00031741014869596484`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481573465, 
            0.00031741027598516334`}, {-4.142620684308732, 
            0.0003174102919051062}, {-3.98498107509814, 
            0.00031741104920075564`}, {-3.8676475647414064`, 
            0.00031741148834585364`}, {-3.7503140543846727`, 
            0.00031741192749095164`}, {-3.632980544027939, 
            0.0003174123666360497}, {-3.5156470336712053`, 
            0.0003174128057811477}, {-3.3983135233144717`, 
            0.0003174132449262457}, {-3.310237805059761, 
            0.00031741357456796363`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629631469183`, 
            0.0003174136526964068}, {-3.280980012957738, 
            0.0003174136840713437}, {-3.1636465026010043`, 
            0.00031741412321644174`}, {-3.0463129922442707`, 
            0.00031741456236153973`}, {-3.015641164063997, 
            0.0003174145819238297}, {-2.984969339539346, 
            0.00031741460020417387`}, {-2.858953592745447, 
            0.00031741465268728553`}, {-2.732937881929087, 
            0.00031741469141060864`}, {-2.724254989841877, 
            0.0003174146940220078}, {-2.7155720978960045`, 
            0.0003174146965776632}, {-2.706889206088441, 
            0.00031741469907858}, {-2.698206314416224, 
            0.0003174147015257468}, {-2.6895234228764537`, 
            0.0003174147039201362}, {-2.672157640309609, 
            0.00031741470850354746`}, {-2.654791858233359, 
            0.000317414712889062}, {-2.481134076056245, 
            0.00031741474059814365`}, {-2.454369286633214, 
            0.00031741474320243045`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944447203712`, 
            0.0003174147452336093}, {-2.307476317872987, 
            0.0003174147574955159}, {-2.0904041516453993`, 
            0.0003174147625455935}, {-1.8733319854178112`, 
            0.000317414767595671}, {-1.6562598257858703`, 
            0.0003174147684071606}, {-1.5985007682066668`, 
            0.00031741476862308366`}}]}, 
          {Arrowheads[{{0.014940810726197169`, 1.}}], 
           ArrowBox[{{-1.5776259262938241`, 
            0.0003174147687011209}, {-1.439187666153929, 
            0.0003174147692186502}, {-1.2221155071931462`, 
            0.00031741476947624853`}, {-1.1678474674718027`, 
            0.0003174147695229176}, {-1.1135794277640099`, 
            0.0003174147695561465}, {-1.086445407912718, 
            0.00031741476957006205`}, {-1.0593113880636007`, 
            0.00031741476958165374`}, {-1.0041500062801363`, 
            0.0003174147695974726}, {-0.9924999258527796, 
            0.00031741476960069943`}, {-0.9833190634614062, 
            0.00031741476960319326`}, {-0.9694447478753098, 
            0.00031741476960692877`}, {-0.9621506732657462, 
            0.0003174147696088517}, {-0.9580388974002424, 
            0.00031741476960992594`}, {-0.953851802375686, 
            0.00031741476961101437`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.6923476975263503`}, {-4.907500243178262, 
            3.6923556958205994`}, {-4.690951811142647, 
            3.692374200335328}, {-4.474403379107033, 
            3.692392704850056}, {-4.257854947071417, 
            3.692411209364784}, {-4.166106326534881, 3.692419049475581}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231484698253, 
            3.692420833274312}, {-4.041306515035802, 
            3.6924297138795126`}, {-3.824758083000187, 
            3.6924482183942406`}, {-3.6082096509645716`, 
            3.6924667229089687`}, {-3.4348407705493784`, 
            3.692462976161467}, {-3.3102378102148156`, 
            3.692460283314693}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629683068477`, 
            3.6924598321797397`}, {-3.2614718901341853`, 
            3.6924592294139655`}, {-3.088103009718992, 
            3.6924554826664644`}, {-2.914734129303799, 
            3.692451735918963}, {-2.7413652488886053`, 
            3.692447989171461}, {-2.567996368473412, 
            3.6924442424239596`}, {-2.4543692919881366`, 
            3.6924417867816097`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944500801687`, 
            3.6924413356466563`}, {-2.394627488058219, 
            3.6924404956764585`}, {-2.2212586076430254`, 
            3.6924367489289565`}, {-2.047890355821234, 
            3.6924371924440105`}, {-1.8745221039994424`, 
            3.6924376359590645`}, {-1.7011538521776508`, 
            3.692438079474118}, {-1.598500773618065, 
            3.6924383420838245`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259317052908`, 
            3.692438395486374}, {-1.5277856003558594`, 
            3.692438522989172}, {-1.354417348534068, 
            3.692438966504226}, {-1.1810490967122764`, 
            3.69243941001928}, {-1.007680844890485, 
            3.692439853534334}, {-0.834312593068694, 
            3.692440297049388}, {-0.7426322551940208, 3.692440316097926}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574132811786, 
            3.692440320435118}, {-0.6956186532236447, 
            3.6924403258660004`}, {-0.5569247141973306, 
            3.6924403319209436`}, {-0.5430553200018424, 
            3.6924403311370053`}, {-0.5257879241650617, 
            3.692440330022813}, {-0.48040833193448107`, 
            3.6924403268110852`}, {-0.43502873921244267`, 
            3.692440322884502}, {-0.3166943774771064, 
            3.692440311447675}, {-0.19836001574176992`, 
            3.692440300010848}, {-0.08002565400643347, 3.692440288574021}, {
            0.038308707728902824`, 3.6924402771371936`}, {
            0.11323626323252221`, 3.692440269895565}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110514536473`, 3.692440267878045}, {
            0.15664306946423912`, 3.6924402657003665`}, {0.27497743119957563`,
             3.6924402542635395`}, {0.3933117929349119, 
            3.6924402428267125`}, {0.5116461546702483, 3.6924402313898854`}, {
            0.5382925648486991, 3.6924402334232895`}, {0.5649389748638829, 
            3.6924402351658627`}, {0.6144266899985473, 3.6924402362768216`}, {
            0.6639144047834462, 3.6924402355210426`}, {0.6675373427958098, 
            3.6924402354582653`}, {0.6823248448629182, 3.6924402349946908`}, {
            0.6971123469121123, 3.692440234328125}, {0.8449873685948924, 
            3.692440201333886}, {0.9691047816590496, 
            3.6924401423762707`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796235718898, 3.6924401324604106`}, {
            0.9928623990174681, 3.6924401310910495`}, {1.1777074112391739`, 
            3.6924398391521027`}, {1.3625524234608795`, 3.692439547213155}, {
            1.5473974356825853`, 3.692439255274208}, {1.7322424479042908`, 
            3.6924389633352606`}, {1.824973300084556, 3.692438816878794}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8458481419973727`, 3.6924387839096635`}, {
            1.9170874601259964`, 3.6924386713963133`}, {2.1019324723477024`, 
            3.692438379457366}, {2.286777484569408, 3.692438087518419}, {
            2.4716224967911136`, 3.6924377955794716`}, {2.6564664331548844`, 
            3.692444438109841}, {2.680841818375205, 3.6924453140608717`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.701716660274569, 3.6924460642167816`}, {
            2.841310369518656, 3.6924510806402107`}, {3.0261543058824274`, 
            3.6924577231705804`}, {3.2109982422461987`, 3.69246436570095}, {
            3.3958421786099704`, 3.69247100823132}, {3.536710336249123, 
            3.692476070453179}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.557585178148487, 3.6924768206090888`}, {
            3.5806861149737412`, 3.692477650761689}, {3.7655300513375125`, 
            3.692484293292059}, {3.9503739877012842`, 3.6924909358224287`}, {
            4.065774989377758, 3.6924575545850638`}, {4.181175991054232, 
            3.6924241733476992`}, {4.2965769927307065`, 
            3.6923907921103343`}, {4.392578835908252, 3.69236302233132}}]}, 
          {Arrowheads[{{0.014075468214103914`, 1.}}], 
           ArrowBox[{{4.413453676947764, 3.6923569840126436`}, {
            4.527378996083655, 3.692324029635605}, {4.64277999776013, 
            3.69229064839824}, {4.758180999436604, 3.692257267160875}, {
            4.873582001113078, 3.6922238859235104`}, {4.988983002789553, 
            3.6921905046861454`}, {5.001099999999999, 
            3.6921869996874523`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5943513594427685, 
            1.023622227422012}, {-0.5469325701368665, 
            1.023622227425118}, {-0.49951378083285874`, 
            1.023622227428378}, {-0.3810926623538634, 
            1.0236222274357856`}, {-0.262671543874868, 
            1.023622227443193}, {-0.14425042539587268`, 
            1.0236222274506006`}, {-0.025829306916877348`, 
            1.023622227458008}, {0.09259181156211799, 1.0236222274654156`}, {
            0.21101293004111338`, 1.023622227472823}, {0.2406423170709358, 
            1.0236222274746765`}}]}, 
          {Arrowheads[{{0.007996840139707508, 1.}}], 
           ArrowBox[{{0.2615171589837784, 1.0236222274759823`}, {
            0.32943404852010855`, 1.0236222274802307`}, {0.44785516699910405`,
             1.023622227487638}, {0.47416947334759896`, 
            1.0236222274863385`}, {0.500483779696446, 1.0236222274848465`}, {
            0.5479332430578292, 1.0236222274815825`}, {0.5953827064211152, 
            1.023622227478484}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5938505644023719, -1.0231186718333385`}, \
{-0.5464466696141624, -1.0231186718364285`}, {-0.4990427748278379, \
-1.0231186718396694`}, {-0.3806222909651602, -1.0231186718470318`}, \
{-0.26220180710248236`, -1.023118671854394}, {-0.14378132323980458`, \
-1.0231186718617566`}, {-0.025360839377126854`, -1.023118671869119}, {
            0.09305964448555082, -1.0231186718764813`}, {
            0.2114801283482285, -1.0231186718838436`}, {
            0.24114311211133244`, -1.0231186718856877`}}]}, 
          {Arrowheads[{{0.007996840200808663, 1.}}], 
           ArrowBox[{{0.26201795402417505`, -1.0231186718869856`}, {
            0.3299006122109063, -1.023118671891206}, {
            0.44832109607358395`, -1.0231186718985685`}, {
            0.47463794208696897`, -1.023118671897271}, {
            0.5009547881007064, -1.0231186718957823`}, {
            0.5484191460556352, -1.0231186718925334`}, {
            0.5958835040124658, -1.023118671889459}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.643178838052145, -1.2155199804459147`}, {
            0.7608279745343665, -1.2155199804155905`}, {
            0.8784771110165879, -1.2155199803852665`}, {
            0.9961262474988093, -1.2155199803549424`}, {
            1.1137753839810307`, -1.2155199803246182`}, {
            1.2314245204632521`, -1.215519980294294}, {
            1.3490736569454738`, -1.2155199802639698`}, {
            1.466722793427695, -1.2155199802336456`}, {
            1.4781725145658493`, -1.215519980369215}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.499047356478692, -1.2155199806193844`}, {
            1.5255262613700595`, -1.2155199809601107`}, {
            1.6053904137083523`, -1.2155199822926495`}, {
            1.6852545654793785`, -1.2155199838240638`}, {
            1.69311827321191, -1.2155199839762605`}, {
            1.6994345043173236`, -1.215519984099803}, {
            1.7625968149056273`, -1.215519985423097}, {
            1.8257591249348377`, -1.2155199867885815`}, {
            1.983664869563411, -1.215519968370407}, {
            2.1415706141919846`, -1.2155199499522322`}, {
            2.299476358820558, -1.2155199315340575`}, {
            2.334041032992393, -1.215519927502423}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.3549158749052355`, -1.2155199250675752`}, {
            2.4573821034491314`, -1.2155199131158827`}, {
            2.6152878076293606`, -1.2155197143499246`}, {
            2.77319351180959, -1.2155195155839664`}, {
            2.931099215989819, -1.2155193168180085`}, {
            3.0890049201700482`, -1.2155191180520504`}, {
            3.189909547842068, -1.2154922527441254`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.210784389015042, -1.2154866949312784`}, {
            3.3114617755997613`, -1.215459890125056}, {
            3.4226902033146174`, -1.2154302761615585`}, {
            3.5339186310294735`, -1.215400662198061}, {
            3.6451470587443295`, -1.2153710482345639`}, {
            3.7563754864591856`, -1.2153414342710664`}, {
            3.8676039141740417`, -1.215311820307569}, {
            3.9788323418888982`, -1.2152822063440718`}, {
            4.045778035933998, -1.2152643824173968`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.066652877106972, -1.2152588246045497`}, {
            4.090060769603754, -1.2152525923805744`}, {
            4.20128919731861, -1.215222978417077}, {
            4.3125176250334665`, -1.2151933644535797`}, {
            4.4237460527483226`, -1.2151637504900823`}, {
            4.534974480463179, -1.2151341365265849`}, {
            4.646202908178035, -1.2151045225630877`}, {
            4.757431335892892, -1.2150749085995902`}, {
            4.868659763607748, -1.2150452946360928`}, {
            4.901646524025929, -1.215036512090668}}]}, 
          {Arrowheads[{{0.001882137309452443, 1.}}], 
           ArrowBox[{{4.922521365198903, -1.215030954277821}, {
            4.979888191322604, -1.2150156806725956`}, {
            5.001099999999999, -1.2150100331439846`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.5196297050109981`}, {-4.9858608438214045`, 
            1.5196306200373506`}, {-4.835643657171011, 
            1.5196396397417722`}, {-4.685426470520618, 
            1.519648659446194}, {-4.535209283870223, 
            1.5196576791506156`}, {-4.384992097219829, 
            1.5196666988550374`}, {-4.234774910569435, 
            1.519675718559459}, {-4.16610632499151, 1.5196798417251152`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231483116298, 
            1.519681095142968}, {-4.084557723919041, 
            1.5196847382638807`}, {-3.934340537268647, 
            1.5196937579683023`}, {-3.7841233506182537`, 
            1.519702777672724}, {-3.6339061639678594`, 
            1.5197117973771457`}, {-3.4836889773174655`, 
            1.5197208170815675`}, {-3.3334717906670717`, 
            1.519729836785989}, {-3.3102378081078085`, 
            1.519731231857085}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629662325963`, 
            1.5197324852749379`}, {-3.1832546040166774`, 
            1.5197388564904108`}, {-3.033037417366284, 
            1.5197478761948324`}, {-2.8828202307158897`, 
            1.5197568958992542`}, {-2.732603044065496, 
            1.5197659156036758`}, {-2.6124312866149255`, 
            1.519765920565816}, {-2.4922595291643557`, 
            1.519765925527956}, {-2.4543692907225445`, 
            1.5197659217395931`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494448809702, 
            1.519765919652473}, {-2.3720877350144045`, 
            1.5197659135128727`}, {-2.2519159408644533`, 
            1.5197659014977893`}, {-2.2278815771401006`, 
            1.5197658985192308`}, {-2.2014437765999832`, 
            1.5197658952787836`}, {-2.1979587937483975`, 
            1.519765894857743}, {-2.1028459314176775`, 
            1.5197658833862644`}, {-2.007733064357321, 
            1.5197658728827208`}, {-1.8898102299372412`, 
            1.5197658614702023`}, {-1.7718873955171617`, 
            1.5197658500576838`}, {-1.6539645610970823`, 
            1.5197658386451653`}, {-1.598500772296002, 
            1.5197658332774049`}}]}, 
          {Arrowheads[{{0.016691574224503705`, 1.}}], 
           ArrowBox[{{-1.5776259303831595`, 
            1.5197658312571471`}, {-1.5360417266770028`, 
            1.5197658272326469`}, {-1.4181188922569232`, 
            1.5197658158201282`}, {-1.3001960578368439`, 
            1.5197658044076097`}, {-1.182273223416764, 
            1.5197657929950912`}, {-1.0643503889966845`, 
            1.5197657815825727`}, {-1.0360444529656556`, 
            1.5197657815974923`}, {-1.007738516948307, 
            1.5197657816264019`}, {-0.9442482504206307, 
            1.5197657817557158`}, {-0.8807579839571753, 
            1.5197657819025656`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.675873029665423, 1.0823755117931497`}, {
            0.793467238821905, 1.0823755117819247`}, {0.9110614479783871, 
            1.0823755117706997`}, {1.028655657134869, 1.0823755117594747`}, {
            1.1462498662913512`, 1.0823755117482496`}, {1.263844075447833, 
            1.0823755117370246`}, {1.3814382846043152`, 
            1.0823755117257996`}, {1.4990324937607973`, 
            1.0823755117145748`}, {1.5108667061791272`, 
            1.0823755117134453`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.5317415480919698`, 1.0823755117114526`}, {
            1.6166267029172792`, 1.0823755117033498`}, {1.6462485021762798`, 
            1.082375511960226}, {1.6758703013739893`, 1.0823755122177878`}, {
            1.7604887494910078`, 1.0823755128414352`}, {1.8451071968209203`, 
            1.0823755132034678`}, {1.8531635842444265`, 
            1.0823755132351376`}, {1.8596345781526167`, 
            1.0823755132578152`}, {1.9243445166761213`, 
            1.0823755131920416`}, {1.9890544545680509`, 
            1.0823755126981687`}, {2.150829278334058, 1.0823754558291294`}, {
            2.3126041021000647`, 1.08237539896009}, {2.366735224605651, 
            1.082375379931264}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.387610066518492, 1.0823753725930876`}, {
            2.474378925866071, 1.0823753420910507`}, {2.636153749632078, 
            1.0823752852220112`}, {2.797928625275274, 1.0823749269480087`}, {
            2.95970350091847, 1.0823745686740063`}, {3.121478376561666, 
            1.0823742104000036`}, {3.222603743030743, 1.0823739864431645`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.2434785849435346`, 1.0823739402127894`}, {
            3.2832532522048616`, 1.0823738521260011`}, {3.4944432935496463`, 
            1.0823216453658875`}, {3.705633334894432, 1.0822694386057736`}, {
            3.916823376239217, 1.08221723184566}, {4.078472237159543, 
            1.0821772718018483`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.099347078434564, 1.0821721114835685`}, {
            4.128013417584002, 1.0821650250855464`}, {4.339203458928788, 
            1.0821128183254327`}, {4.550393500273573, 1.0820606115653189`}, {
            4.761583541618359, 1.0820084048052052`}, {4.9343407294353705`, 
            1.081965698752378}}]}, 
          {Arrowheads[{{0.001099036603083441, 1.}}], 
           ArrowBox[{{4.955215570710391, 1.0819605384340982`}, {
            4.9727735829631445`, 1.0819561980450916`}, {5.001099999999999, 
            1.0819491956767522`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.006491469464451509, 1.}}], 
           ArrowBox[{{-0.7423226425881997, 
            1.368046977351826}, {-0.6239919342653705, 
            1.3680469745162274`}, {-0.5973169495374188, 
            1.36804697453743}, {-0.5706419648123795, 
            1.368046974556836}, {-0.5209739048451609, 
            1.368046974582593}, {-0.4713058448832591, 
            1.3680469746016717`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.0198343045551424, 1.}}], 
           ArrowBox[{{-0.7082034307060625, 
            1.5930487180923287`}, {-0.5889373934342557, 
            1.593048718486099}, {-0.4696713561624486, 
            1.5930487188798697`}, {-0.35040531889064164`, 
            1.5930487192736402`}, {-0.23113928161883468`, 
            1.5930487196674108`}, {-0.11187324434702772`, 
            1.5930487200611814`}, {0.007392792924778971, 
            1.5930487204549517`}, {0.030325692019334546`, 
            1.5930487204551729`}, {0.05325859111382857, 
            1.5930487204560704`}, {0.08656555224396992, 
            1.5930487204594757`}, {0.11987251337348084`, 
            1.5930487204637385`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.7561305999502189}, {-4.934614018951054, 
            0.7561357915528912}, {-4.8208862133838455`, 
            0.7561446720652937}, {-4.707158407816637, 
            0.7561535525776961}, {-4.593430602249429, 
            0.7561624330900986}, {-4.479702796682221, 
            0.756171313602501}, {-4.365974991115013, 
            0.7561801941149034}, {-4.252247185547804, 
            0.7561890746273059}, {-4.166106326031929, 
            0.7561958009944196}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231484182727, 
            0.7561974310205246}, {-4.138519379980597, 
            0.7561979551397083}, {-4.024791574413388, 
            0.7562068356521108}, {-3.9110637688461805`, 
            0.7562157161645131}, {-3.729124665252799, 
            0.7562169560584775}, {-3.547185988170764, 
            0.7562178517179532}, {-3.5289921502982176`, 
            0.7562179150975004}, {-3.510798314837831, 
            0.7562179762478424}, {-3.501701398267821, 
            0.7562180057407761}, {-3.492604482261138, 
            0.7562180347044996}, {-3.483507566806894, 
            0.7562180631468123}, {-3.4744106518943214`, 
            0.7562180910754422}, {-3.465313737512814, 
            0.7562181184980304}, {-3.332507363344688, 
            0.7562185115645301}, {-3.310237808390429, 
            0.7562185616333925}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629664776394`, 
            0.7562186085665077}, {-3.199701084268981, 
            0.7562188101542114}, {-3.0822468759034436`, 
            0.7562190079425506}, {-2.9647926675379064`, 
            0.7562192057308897}, {-2.8473384591723687`, 
            0.756219403519229}, {-2.7298842508068315`, 
            0.7562196013075682}, {-2.6124300424412943`, 
            0.7562197990959073}, {-2.494975834075757, 
            0.7562199968842465}, {-2.4543692899652183`, 
            0.7562200652640946}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4334944480524054`, 
            0.7562201004165201}, {-2.3775216257102194`, 
            0.7562201946725857}, {-2.260067417344682, 
            0.7562203924609249}, {-2.229884397329776, 
            0.7562203961619826}, {-2.1997013774224503`, 
            0.7562203994826314}, {-2.098517936233143, 
            0.7562204062365594}, {-1.9973344953110348`, 
            0.7562204106703764}, {-1.9937439867945188`, 
            0.7562204108262668}, {-1.9824595314582594`, 
            0.756220411291571}, {-1.972200935698925, 
            0.7562204116941519}, {-1.8696149780834272`, 
            0.7562204141888705}, {-1.7670290203250185`, 
            0.7562204156496946}, {-1.6387965725176725`, 
            0.7562204159458332}, {-1.5985007715389479`, 
            0.7562204160388919}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259296261053`, 
            0.7562204160871}, {-1.5105641247103265`, 
            0.7562204162419719}, {-1.3823316764669007`, 
            0.7562204161881297}, {-1.2540992282234749`, 
            0.7562204161342875}, {-1.1258667798600883`, 
            0.7562204160641295}, {-0.9976343314277313, 
            0.7562204160095085}, {-0.9335181072013944, 
            0.7562204159877444}, {-0.8694018829683439, 
            0.7562204159713695}, {-0.7824219462023838, 
            0.7562204159575782}, {-0.7606769620106402, 
            0.7562204159545689}, {-0.7426322531124009, 
            0.756220415952454}}]}, 
          {Arrowheads[{{0.0017310542109199704`, 1.}}], 
           ArrowBox[{{-0.7217574111995583, 
            0.756220415950213}, {-0.6950445126941674, 
            0.7562204159474185}, {-0.6859119408531057, 
            0.7562204159466035}, {-0.6786742341280048, 
            0.7562204159459781}, {-0.6728772471506833, 
            0.7562204159454886}, {-0.6644874772808002, 
            0.7562204159447983}, {-0.6591766023875828, 
            0.7562204159443768}, {-0.6529492146549237, 
            0.75622041594391}, {-0.6494864452085285, 
            0.7562204159436892}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.009874752227413994, 1.}}], 
           ArrowBox[{{0.750236751661951, -0.6244979514621382}, {
            0.7540425720281513, -0.624497951462541}, {
            0.7602700375159247, -0.6244979514632031}, {
            0.7652868670759249, -0.6244979514637392}, {
            0.7728953860237461, -0.6244979514645573}, {
            0.7847340032583788, -0.6244979514658451}, {
            0.8062544351566497, -0.6244979514682656}, {
            0.8426089586205233, -0.6244979514725789}, {
            0.8993028881786201, -0.6244979514799327}, {
            0.9224957524201696, -0.6244979514831743}, {
            0.9456886166609146, -0.6244979514864918}, {
            0.968881480900756, -0.6244979514898251}, {
            0.9735200537486086, -0.6244979514904889}, {
            0.977114947705666, -0.6244979514910015}, {
            1.0054930860158446`, -0.6244979514950384}, {
            1.033871224324352, -0.6244979514988532}, {
            1.0981878796761289`, -0.6244979515018622}, {
            1.1625045350134662`, -0.6244979514953674}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.013133367257400358`, 1.}}], 
           ArrowBox[{{0.7616933072725054, -0.9228501562492654}, {
            0.8795115817389574, -0.9228501562519567}, {
            0.9973298562055681, -0.9228501562997984}, {
            1.1151481306721789`, -0.9228501563476401}, {
            1.1438740414124728`, -0.9228501563874699}, {
            1.1725999521467054`, -0.9228501564316359}, {
            1.2413035950264333`, -0.9228501565719681}, {
            1.310007237835577, -0.9228501567324201}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3001972241914852`, -0.6072519808776866}, {
            1.4177430985173622`, -0.607251980764954}, {
            1.5352889728432393`, -0.6072519806522214}, {
            1.6528348470745167`, -0.6072519800377594}, {
            1.770380721305794, -0.6072519794232973}, {
            1.8001967940890191`, -0.6072519788922688}, {
            1.830012866892723, -0.6072519782834787}, {
            1.9195057319024353`, -0.6072519752250681}, {
            2.0089985974767512`, -0.6072519708522348}, {
            2.012542702143268, -0.6072519706772807}, {
            2.0394290134721946`, -0.6072519692130037}, {
            2.063871114750328, -0.6072519677416207}, {
            2.135190900705189, -0.6072519577160203}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.1560657426180314`, -0.6072519547815916}, {
            2.186081627194873, -0.6072519505621836}, {
            2.3082921396394185`, -0.6072519333827465}, {
            2.4305026670464693`, -0.6072518973222931}, {
            2.55271319445352, -0.6072518612618397}, {
            2.7054850408622126`, -0.6072475665921897}, {
            2.8582568872709055`, -0.6072432719225396}, {
            2.991059418958519, -0.6072395386234031}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.011934260863113, -0.6072389517970206}, {
            3.1638005800882905`, -0.6072346825832394}, {
            3.316572426496983, -0.6072303879135894}, {
            3.4693442729056754`, -0.6072260932439393}, {
            3.6221161193143674`, -0.6072217985742893}, {
            3.7748879657230603`, -0.6072175039046391}, {
            3.846927937046884, -0.60721547874172}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{3.867802778951478, -0.6072148919153375}, {
            3.9276598121317527`, -0.6072132092349891}, {
            4.080431658540445, -0.607208914565339}, {
            4.233203504949137, -0.607204619895689}, {
            4.38597535135783, -0.6072003252260388}, {
            4.538747197766522, -0.6071960305563888}, {
            4.691519044175215, -0.6071917358867387}, {
            4.70279645513525, -0.607191418860037}}]}, 
          {Arrowheads[{{0.006645049379978203, 1.}}], 
           ArrowBox[{{4.723671297039844, -0.6071908320336545}, {
            4.844290890583908, -0.6071874412170887}, {
            4.9970627369926, -0.6071831465474385}, {
            5.001099999999999, -0.6071753376634204}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.01230740493079905, 1.}}], 
           ArrowBox[{{0.2509369302897384, 1.6228800206749217`}, {
            0.36916455220384814`, 1.6228800206932696`}, {0.4873921741179581, 
            1.6228800207116174`}, {0.605619796032068, 1.6228800207299654`}, {
            0.6327062420156875, 1.622880020675306}, {0.659792688005567, 
            1.6228800206138347`}, {0.712279941415678, 1.6228800204565972`}, {
            0.764767194865278, 1.6228800202769618`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.7769778290727765, 1.621952746210147}, {
            0.8947240349141719, 1.6219527462058736`}, {1.0124702407555675`, 
            1.6219527462016}, {1.1302164465969629`, 1.6219527461973264`}, {
            1.2479626524383582`, 1.6219527461930527`}, {1.2769747666045952`, 
            1.6219527462996322`}, {1.3059868807876696`, 
            1.6219527464539498`}, {1.3789085888199644`, 
            1.6219527473878943`}, {1.451830296835917, 1.6219527488437082`}, {
            1.4590911791729633`, 1.6219527489934846`}, {1.4649232131780545`, 
            1.6219527491184071`}, {1.5232435531496376`, 
            1.6219527507842102`}, {1.5815638929750693`, 1.621952752930816}, {
            1.6119715055864805`, 1.621952757992566}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.632846347499323, 1.6219527614674603`}, {
            1.7273647196836877`, 1.6219527772012958`}, {1.873165546392306, 
            1.6219528014717757`}, {2.018966373100924, 1.6219528257422555`}, {
            2.1647671998095426`, 1.6219528500127354`}, {2.310567927005915, 
            1.6219528667833525`}, {2.456368654202287, 1.6219528835539698`}, {
            2.467840024013018, 1.6219528848734555`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4887148659258607`, 1.621952887274568}, {
            2.602169381398659, 1.621952900324587}, {2.7479701085950308`, 
            1.6219529170952043`}, {2.8777993096278003`, 
            1.6219022035177093`}, {3.0076285106605694`, 1.621851489940214}, {
            3.137457711693339, 1.6218007763627191`}, {3.267286912726108, 
            1.621750062785224}, {3.3237084985158645`, 1.6217280235179359`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.3445833388361432`, 1.621719869436852}, {
            3.3971161137588775`, 1.6216993492077287`}, {3.526945314791647, 
            1.6216486356302338`}, {3.656774515824416, 1.6215979220527386`}, {
            3.786603716857185, 1.6215472084752436`}, {3.916432917889954, 
            1.6214964948977484`}, {4.046262118922723, 1.6214457813202534`}, {
            4.176091319955493, 1.6213950677427582`}, {4.17957695164729, 
            1.6213937061934958`}}]}, 
          {Arrowheads[{{0.01917734928143735, 1.}}], 
           ArrowBox[{{4.200451791967568, 1.6213855521124119`}, {
            4.305920520988263, 1.621344354165263}, {4.435749722021032, 
            1.621293640587768}, {4.565578923053801, 1.6212429270102728`}, {
            4.69540812408657, 1.6211922134327779`}, {4.825237325119339, 
            1.6211414998552827`}, {4.955066526152109, 1.6210907862777877`}, {
            5.001099999999999, 1.6210728047903813`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.5979433427692727}, \
{-4.965188439545129, -0.59794449167659}, {-4.816502825729585, \
-0.5979492485289108}, {-4.66781721191404, -0.5979540053812318}, \
{-4.519131598098497, -0.5979587622335526}, {-4.370445984282952, \
-0.5979635190858734}, {-4.2217603704674085`, -0.5979682759381942}, \
{-4.166106323913616, -0.5979700564606921}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231482011456, -0.5979707243029776}, \
{-4.073074756651864, -0.5979730327905151}, {-3.9243891428363202`, \
-0.597977789642836}, {-3.7757035290207757`, -0.5979825464951568}, \
{-3.6270179152052315`, -0.5979873033474776}, {-3.4783323013896874`, \
-0.5979920601997984}, {-3.3296466875741433`, -0.5979968170521193}, \
{-3.310237805925073, -0.5979974379943971}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629640229136`, -0.5979981058366826}, \
{-3.180961073758599, -0.5980015739044402}, {-3.032275459943055, \
-0.598006330756761}, {-2.8835898461275105`, -0.5980110876090818}, \
{-2.734904232311966, -0.5980158444614028}, {-2.615963826900645, \
-0.5980159017049834}, {-2.4970234214893243`, -0.598015958948564}, \
{-2.454369287792991, -0.5980159695831844}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494445880149, -0.5980159747877449}, \
{-2.3780830421363714`, -0.5980159886030354}, {-2.2591426627834186`, \
-0.5980160182575067}, {-2.235354589332602, -0.5980160210891882}, \
{-2.2115665160279763`, -0.5980160237051136}, {-2.2057384381034844`, \
-0.5980160242926927}, {-2.110394184881466, -0.5980160337781067}, \
{-2.0150499333091187`, -0.5980160405662326}, {-1.8971316460214709`, \
-0.598016046453416}, {-1.7792133587338228`, -0.5980160523405995}, \
{-1.661295071446175, -0.5980160582277829}, {-1.5985007693664512`, \
-0.5980160613628487}}]}, 
          {Arrowheads[{{0.01973848008685587, 1.}}], 
           ArrowBox[{{-1.5776259274536086`, -0.5980160624050451}, \
{-1.543376784158527, -0.5980160641149664}, {-1.4254584968708792`, \
-0.5980160700021498}, {-1.3075402095832314`, -0.5980160758893334}, \
{-1.1896219222955835`, -0.5980160817765168}, {-1.0717036350079352`, \
-0.5980160876637002}, {-1.0433771942894465`, -0.5980160876632818}, \
{-1.0150507535690276`, -0.5980160876618328}, {-0.9513292537404998, \
-0.5980160876550864}, {-0.8875992711668, -0.59801608764819}, \
{-0.8839417831920346, -0.5980160876477948}, {-0.8792223126455122, \
-0.5980160876472872}, {-0.8556271221797279, -0.598016087644847}, \
{-0.8307342470416695, -0.5980160876424347}, {-0.7910849552675095, \
-0.598016087638715}, {-0.7678677183467972, -0.5980160876366422}, \
{-0.7580116994810548, -0.5980160876357706}, {-0.7535506246277931, \
-0.5980160876353773}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.3802012475769017`}, \
{-4.944452079001034, -1.3802053317184948`}, {-4.827216762137846, \
-1.380213784025752}, {-4.709981445274659, -1.3802222363330094`}, \
{-4.592746128411471, -1.3802306886402667`}, {-4.475510811548284, \
-1.380239140947524}, {-4.358275494685096, -1.3802475932547813`}, \
{-4.3272018437780595`, -1.3802481692886668`}, {-4.296128204704615, \
-1.3802487156878804`}, {-4.166106325177061, -1.3802503228723788`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231483265814, -1.3802505809037382`}, \
{-4.128650173130425, -1.3802507858632782`}, {-3.9611722921979036`, \
-1.3802522897388}, {-3.781325156535381, -1.3802522974723894`}, \
{-3.6014780208728583`, -1.3802523052059787`}, {-3.421630885210334, \
-1.3802523129395683`}, {-3.310237806760129, -1.3802523177295714`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362964847286, -1.3802523186272084`}, \
{-3.241783749547812, -1.3802523206731576`}, {-3.0619366138852877`, \
-1.380252328406747}, {-2.882089478222766, -1.3802523361403363`}, \
{-2.7022423425602415`, -1.3802523438739258`}, {-2.52239520689772, \
-1.3802523516075151`}, {-2.4543692883335826`, -1.380252354532691}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.43349444642074, -1.380252355430328}, \
{-2.3425480712351963`, -1.3802523593411045`}, {-2.1627009355726736`, \
-1.3802523670746938`}, {-1.98285379991015, -1.3802523748082833`}, \
{-1.803006664247627, -1.3802523825418727`}, {-1.623159528585104, \
-1.380252390275462}, {-1.5985007699070364`, -1.380252391335811}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259279941938`, -1.380252392233448}, \
{-1.4433123929225808`, -1.3802523980090513`}, {-1.2634652572600578`, \
-1.3802524057426409`}, {-1.0836181215975347`, -1.3802524134762302`}, \
{-0.9037709859350116, -1.3802524212098195`}, {-0.7426322514804902, \
-1.3802524281389306`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574095676476, -1.3802524290365676`}, \
{-0.5440767146099654, -1.3802524366769984`}, {-0.36422957894744235`, \
-1.3802524444105877`}, {-0.18438244328491926`, -1.380252452144177}, \
{-0.0045353076223959565`, -1.3802524598777663`}, {
            0.11323626694605604`, -1.3802524649420507`}}]}, 
          {Arrowheads[{{0.009602347940648036, 1.}}], 
           ArrowBox[{{0.13411110885889863`, -1.3802524658396877`}, {
            0.17531182804012713`, -1.380252467611356}, {
            0.3551589637026502, -1.3802524753449452`}, {
            0.5350060993651733, -1.3802524830785345`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHXrt27Z/y17aq3xq0/EQfmj/WfPkcacTL+0df0P4
+nnFZ02fv7TfwtwO5lec8pJbL/XKfqMghO/cket9peyVfZUWhL9FeWat6NpX
9h8sIHxtW3a3mI+v7D96Qfh7LnFzCbm+tl+QAOHzHi17eazotX14DoTPU19f
I734tX19BYR/fp6wyrWjr+2/N0D4JrWNpyY6v7EPmAfhv8/fccZn0xt7q20Q
fnVI1R8Olbf2689A+CIGARMvT3tr/+0BhP9FQkfm5OT39u94OsD8pxO6/9gc
/mCftAMiz710i8GLPR/t3zdB/H/X7W7K5G2f7OXvNIP5TY890verfbV//98L
zH+2+2Dm62nf7b/nb9IG8TkvuOeIs/+yt9DZpQXia/mfXr9Q/5f9vyuLwXwA
2HOuUw==
            "]]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.657503647737125, 0.5336037472931862}, {
            1.7791170435248156`, 0.5336037452958831}, {1.9315027671987928`, 
            0.5336037395651978}, {2.0838884954998034`, 0.533603728074845}, {
            2.2362742284278476`, 0.5336037108248247}, {2.3886599659829257`, 
            0.533603687815137}, {2.4924973242508126`, 
            0.5336037410349487}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.5133721661636526`, 0.5336037517339416}, {
            2.541045577063908, 0.5336037659174083}, {2.693431445720116, 
            0.5336036360360941}, {2.8458173143763235`, 0.5336035061547798}, {
            2.998203183032531, 0.5336033762734655}, {3.111026358711551, 
            0.5335890641023471}, {3.22384953439057, 0.5335747519312285}, {
            3.336672710069589, 0.53356043976011}, {3.34836583985975, 
            0.5335589564294604}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.369240681604632, 0.5335563083537851}, {
            3.4494958857486075`, 0.5335461275889914}, {3.5623190614276266`, 
            0.533531815417873}, {3.675142237106646, 0.5335175032467545}, {
            3.787965412785665, 0.5335031910756359}, {3.900788588464684, 
            0.5334888789045175}, {4.013611764143703, 0.533474566733399}, {
            4.1264349398227225`, 0.5334602545622804}, {4.20423435139991, 
            0.5334503853267736}}]}, 
          {Arrowheads[{{0.018586747059901997`, 1.}}], 
           ArrowBox[{{4.2251091931447915`, 0.5334477372510983}, {
            4.239258115501741, 0.5334459423911619}, {4.35208129118076, 
            0.5334316302200434}, {4.46490446685978, 0.5334173180489249}, {
            4.5777276425387985`, 0.5334030058778064}, {4.690550818217817, 
            0.5333886937066878}, {4.803373993896836, 0.5333743815355694}, {
            4.916197169575855, 0.5333600693644509}, {5.001099999999999, 
            0.5333492990255541}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.1333455540098651`}, {-4.82011670998741, 
            1.1333537737790194`}, {-4.702855073411717, 
            1.133357933523696}, {-4.5855934368360245`, 
            1.133362093268373}, {-4.468331800260332, 
            1.1333662530130497`}, {-4.351070163684639, 
            1.1333704127577267`}, {-4.233808527108947, 
            1.1333745725024034`}, {-4.166106324084461, 
            1.1333769741734603`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.1452314821847525`, 
            1.1333777146885597`}, {-4.116546890533255, 
            1.1333787322470803`}, {-3.999285253957562, 
            1.133382891991757}, {-3.8820236173818694`, 
            1.1333870517364337`}, {-3.851060198690264, 
            1.1333872944655183`}, {-3.8200967874275418`, 
            1.1333875233724746`}, {-3.6676720768069253`, 
            1.1333883080344151`}, {-3.5152474538722216`, 
            1.1333888767583529`}, {-3.3663466878181203`, 
            1.1333888763740858`}, {-3.310237805841538, 
            1.133388876229286}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289362963928695, 
            1.1333888761754145`}, {-3.2174459217640186`, 
            1.1333888759898187`}, {-3.0685451557099173`, 
            1.1333888756055517`}, {-2.919644389655816, 
            1.1333888752212846`}, {-2.7707436236017147`, 
            1.1333888748370176`}, {-2.621842857547613, 
            1.1333888744527505`}, {-2.472942091493512, 
            1.1333888740684834`}, {-2.4543692874149907`, 
            1.1333888740205527`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.433494445502148, 
            1.133388873966681}, {-2.3240413254394103`, 
            1.1333888736842164`}, {-2.1751405593853086`, 
            1.1333888732999493`}, {-2.0262397933312073`, 
            1.133388872915682}, {-1.877339027277106, 
            1.133388872531415}, {-1.7284382612230047`, 
            1.133388872147148}, {-1.5985007689884436`, 
            1.1333888718118192`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625927075601, 
            1.1333888717579477`}, {-1.4306367291148017`, 
            1.1333888713786138`}, {-1.2817359630607004`, 
            1.1333888709943467`}, {-1.132835197006599, 
            1.1333888706100796`}, {-0.9839344311269635, 
            1.1333888712747422`}, {-0.835033665247328, 
            1.1333888719394045`}, {-0.7426322505618966, 
            1.1333888723518655`}}]}, 
          {Arrowheads[{{0.0008532881214167333, 1.}}], 
           ArrowBox[{{-0.721757408649054, 
            1.1333888724450465`}, {-0.6861328993676925, 
            1.1333888726040668`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            0.37892055381723944`}, {-4.938645842822022, 
            0.3789256275317007}, {-4.829475566954109, 
            0.3789344964178156}, {-4.720305291086195, 
            0.3789433653039305}, {-4.591355071244856, 
            0.37894501112315093`}, {-4.462404851403519, 
            0.37894665694237134`}, {-4.333454631562181, 
            0.37894830276159175`}, {-4.204504411720842, 
            0.37894994858081216`}, {-4.166106324458026, 
            0.3789504386638079}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231482546883, 
            0.37895070509387746`}, {-4.075554191879505, 
            0.37895159440003257`}, {-3.9466039720381665`, 
            0.378953240219253}, {-3.8176537521968283`, 
            0.3789548860384734}, {-3.6887035323554898`, 
            0.37895653185769385`}, {-3.5597578315497884`, 
            0.37895686687266184`}, {-3.430812130744088, 
            0.3789572018876298}, {-3.3102378060716404`, 
            0.3789575151528513}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629641588684`, 
            0.37895756938796304`}, {-3.172920729132686, 
            0.3789578719175658}, {-3.0439750283269853`, 
            0.3789582069325338}, {-2.9150293275212844`, 
            0.3789585419475018}, {-2.7860836267155835`, 
            0.3789588769624698}, {-2.657137925909882, 
            0.3789592119774378}, {-2.5539819566775948`, 
            0.37895924093634414`}, {-2.454369287647304, 
            0.3789592621777012}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494445734462, 
            0.3789592656696155}, {-2.4291632513049737`, 
            0.3789592663403826}, {-2.425552793218218, 
            0.37895926688072706`}, {-2.3236708699630633`, 
            0.37895928203467233`}, {-2.2217889530414503`, 
            0.3789592932469938}, {-2.103998117370376, 
            0.3789593026942001}, {-1.986207281699302, 
            0.3789593121414064}, {-1.8684164460282275`, 
            0.3789593215886127}, {-1.7506256103571536`, 
            0.3789593310358189}, {-1.6328347746860792`, 
            0.3789593404830252}, {-1.5985007692207613`, 
            0.3789593432367236}}]}, 
          {Arrowheads[{{0.011888832968008085`, 1.}}], 
           ArrowBox[{{-1.5776259273079187`, 
            0.37895934491095346`}, {-1.515043939015005, 
            0.3789593499302315}, {-1.3972531033439308`, 
            0.3789593593774378}, {-1.2794622676728564`, 
            0.3789593688246441}, {-1.2506257321647665`, 
            0.3789593688634403}, {-1.221789196659647, 
            0.37895936889578047`}, {-1.1515300532464585`, 
            0.3789593689357792}, {-1.0812709098371993`, 
            0.3789593689589901}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3188611402764815, -1.6883869024809623`}, {
            0.3633830012065064, -1.688386902478285}, {
            0.40790486213655086`, -1.6883869024661307`}, {
            0.525602972171285, -1.6883869024012632`}, {
            0.6433010822060191, -1.6883869023363955`}, {
            0.7609991922407533, -1.688386902271528}, {
            0.8786973022754874, -1.6883869022066607`}, {
            0.9963954123102214, -1.6883869021417932`}, {
            1.1140935223449555`, -1.6883869020769255`}, {
            1.1538548167901859`, -1.6883869020550117`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1747296587030285`, -1.688386902043507}, {
            1.2317916323796898`, -1.688386902012058}, {
            1.3494897424144239`, -1.6883869019471907`}, {
            1.3786939838530408`, -1.6883869022082916`}, {
            1.4078982253084664`, -1.688386902546689}, {
            1.4840426529852477`, -1.688386904343741}, {
            1.5601870805527012`, -1.6883869070003794`}, {
            1.565915494082204, -1.6883869072038504`}, {
            1.5892967737714496`, -1.688386908134853}, {
            1.6126780534336744`, -1.6883869091643036`}, {
            1.7295844483302034`, -1.6883869206754918`}, {
            1.8464908432267322`, -1.6883869321866798`}, {
            1.9633972288761739`, -1.6883869522173016`}, {
            2.009723335216729, -1.6883869601547699`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.0305981771295714`, -1.6883869637314441`}, {
            2.0803036145256155`, -1.6883869722479234`}, {
            2.2264356976814366`, -1.6883842042274169`}, {
            2.3725677808372576`, -1.6883814362069105`}, {
            2.5186998639930787`, -1.688378668186404}, {
            2.6648319471489, -1.6883759001658976`}, {
            2.8109640303047208`, -1.688373132145391}, {
            2.865591853502396, -1.688372097390178}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.8864666954114937`, -1.6883717019808384`}, {
            2.9570961134605422`, -1.6883703641248846`}, {
            3.1032281966163633`, -1.6883675961043783`}, {
            3.2493602797721843`, -1.6883648280838717`}, {
            3.395492362928005, -1.6883620600633653`}, {
            3.541624446083826, -1.6883592920428587`}, {
            3.687756529239647, -1.6883565240223524`}, {
            3.721460371775402, -1.6883558856072605`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.7423352136844996`, -1.688355490197921}, {
            3.8338886123954685`, -1.688353756001846}, {
            3.98002069555129, -1.6883509879813394`}, {
            4.126152778707111, -1.688348219960833}, {
            4.272284861862932, -1.6883454519403265`}, {
            4.418416945018753, -1.6883426839198201`}, {
            4.564769228677605, -1.6879491183655166`}, {
            4.577328360880562, -1.6879484884213436`}}]}, 
          {Arrowheads[{{0.009650295797006476, 1.}}], 
           ArrowBox[{{4.598203202767146, -1.687947441375672}, {
            4.7109038822673135`, -1.6879417885060943`}, {
            4.857040249479614, -1.687931417420728}, {
            5.001099999999999, -1.687918195855136}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.006824251028681758, 1.}}], 
           ArrowBox[{{0.5940894524157376, 0.8075383372247835}, {
            0.6257886367745258, 0.807538337225974}, {0.6460947189714896, 
            0.8075383372269054}, {0.6664345270500549, 0.8075383372281988}, {
            0.6849723843877167, 0.8075383372296829}, {0.7068964440908867, 
            0.8075383372317081}, {0.7121862437868853, 0.8075383372322421}, {
            0.7397082800082884, 0.8075383372350826}, {0.7672303162295453, 
            0.8075383372386229}, {0.8231150457215713, 0.8075383372514702}, {
            0.8789997752103081, 0.8075383372692665}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.9928736743045009}, \
{-4.903103130784327, -0.9928955577752504}, {-4.7885384001134454`, \
-0.9929211409796183}, {-4.663617231888585, -0.9929250757982844}, \
{-4.538696063663726, -0.9929290106169504}, {-4.413774895438865, \
-0.9929329454356165}, {-4.288853727214005, -0.9929368802542825}, \
{-4.166106329094909, -0.992940746602638}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231487192421, -0.9929414041270491}, \
{-4.039011390764285, -0.9929447498916147}, {-3.9140902225394245`, \
-0.9929486847102807}, {-3.7891690543145646`, -0.9929526195289468}, \
{-3.6642510717630756`, -0.9929534130158894}, {-3.5393330892115866`, \
-0.9929542065028318}, {-3.4144151066600976`, -0.9929549999897744}, \
{-3.310237810865013, -0.99295566173056}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289362968952591, -0.9929557943288789}, \
{-3.1645791415571187`, -0.9929565869636595}, {-3.0396611590056297`, \
-0.992957380450602}, {-2.9147431764541407`, -0.9929581739375446}, \
{-2.7898251939026517`, -0.9929589674244872}, {-2.68989112255523, \
-0.9929590292892906}, {-2.5899570536319168`, -0.9929590749986329}, \
{-2.579963646836979, -0.9929590783093121}, {-2.568970899366782, \
-0.9929590818205283}, {-2.565473206990922, -0.9929590828950866}, \
{-2.4594298182545584`, -0.9929591152453594}, {-2.4543692924490004`, \
-0.9929591163063811}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494450536158, -0.9929591206831317}, \
{-2.3533864292604916`, -0.9929591374790832}, {-2.2356627789536114`, \
-0.9929591538706121}, {-2.117939128646731, -0.9929591702621409}, \
{-2.0002154783398507`, -0.9929591866536698}, {-1.8824918280329703`, \
-0.9929592030451987}, {-1.76476817772609, -0.9929592194367275}, \
{-1.6470445274192098`, -0.9929592358282564}, {-1.5985007740224628`, \
-0.9929592425873599}}]}, 
          {Arrowheads[{{0.008936079674678401, 1.}}], 
           ArrowBox[{{-1.5776259321096204`, -0.9929592454939175}, \
{-1.5293208771123294`, -0.9929592522197852}, {-1.411597226805449, \
-0.9929592686113141}, {-1.382493017632914, -0.9929592684907435}, \
{-1.3533888084373642`, -0.9929592683754797}, {-1.2789681197825584`, \
-0.9929592681422239}, {-1.2045474310506668`, -0.99295926795742}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.004374282607618338, 1.}}], 
           ArrowBox[{{-1.0502271449439873`, -1.139648270375236}, \
{-1.0219608441826953`, -1.1396482703305828`}, {-0.9936945434200773, \
-1.1396482702940431`}, {-0.930648386263017, -1.1396482702581034`}, \
{-0.8676022291117278, -1.139648270243332}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -1.768153365445022}, \
{-4.800384506142651, -1.7682086334909521`}, {-4.674799405987704, \
-1.7682130828590232`}, {-4.549214305832757, -1.7682175322270943`}, \
{-4.42362920567781, -1.7682219815951654`}, {-4.298044105522863, \
-1.7682264309632365`}, {-4.172459005367917, -1.7682308803313076`}, \
{-4.166106331493545, -1.7682311054008761`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231489593804, -1.7682318449779033`}, \
{-4.04687390521297, -1.7682353296993787`}, {-3.9212888050580235`, \
-1.7682397790674498`}, {-3.7957037049030764`, -1.768244228435521}, \
{-3.6701182687722618`, -1.768244759628853}, {-3.544532832641447, \
-1.768245290822185}, {-3.4189473965106325`, -1.768245822015517}, \
{-3.3102378133038095`, -1.768246281828434}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2893629713911534`, -1.7682463701235194`}, \
{-3.167776524249003, -1.7682468844021808`}, {-3.042191088118188, \
-1.7682474155955128`}, {-2.9166056519873735`, -1.7682479467888448`}, \
{-2.7910202158565585`, -1.7682484779821768`}, {-2.6905514098100194`, \
-1.7682484391285889`}, {-2.590082580745725, -1.768248398313687}, \
{-2.5800356959067416`, -1.7682483942964542`}, {-2.568984122375178, \
-1.7682483898988046`}, {-2.565467712546434, -1.7682483885074503`}, \
{-2.4594245150360066`, -1.7682483465941932`}, {-2.4543692948819333`, \
-1.7682483447471575`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.433494452969092, -1.7682483371200757`}, \
{-2.353381300701149, -1.768248307848976}, {-2.235658265133204, \
-1.7682482696807436`}, {-2.1179352295652594`, -1.7682482315125112`}, \
{-2.0002121939973145`, -1.7682481933442789`}, {-1.88248915842937, \
-1.7682481551760465`}, {-1.764766122861425, -1.7682481170078141`}, \
{-1.6470430872934803`, -1.7682480788395818`}, {-1.5985007764554329`, \
-1.768248063101165}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259345425914`, -1.7682480563331113`}, \
{-1.5293200517255354`, -1.7682480406713494`}, {-1.4115970161575908`, \
-1.768248002503117}, {-1.3824929289524606`, -1.768248002135499}, \
{-1.3533888417754811`, -1.7682480018621973`}, {-1.2789681524170928`, \
-1.7682480018244897`}, {-1.2045474633269895`, -1.7682480020958333`}, \
{-1.1973533492248523`, -1.768248002123945}, {-1.1915749443255421`, \
-1.7682480021482387`}, {-1.133790895497221, -1.7682480025043215`}, \
{-1.076006846828761, -1.768248002929443}, {-0.9315467272524565, \
-1.7682480031609809`}, {-0.7870866076761519, -1.7682480033925188`}, \
{-0.7426322580288957, -1.7682480034637693`}}]}, 
          {Arrowheads[{{0.019196110065376623`, 1.}}], 
           ArrowBox[{{-0.721757416116053, -1.7682480034972272`}, \
{-0.6426264880998473, -1.7682480036240567`}, {-0.4981663685235428, \
-1.7682480038555946`}, {-0.35370624894353847`, -1.7682480038836315`}, \
{-0.20924612936353404`, -1.7682480039116684`}, {-0.06478600978352983, \
-1.768248003939705}, {0.0796741097964746, -1.768248003967742}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.007014867496273642, 1.}}], 
           ArrowBox[{{-1.055448850414376, -0.8690074496775916}, \
{-0.9374300764224761, -0.8690074519607969}, {-0.9095060621567512, \
-0.8690074519462684}, {-0.8815820478896204, -0.8690074519338257}, \
{-0.8220811991283696, -0.8690074519187624}, {-0.7625803503658753, \
-0.8690074519093657}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            1.8757711113204611`}, {-4.881891052493567, 
            1.875781952481187}, {-4.740372588184983, 
            1.8757918658436086`}, {-4.598855155491005, 
            1.8757988224304867`}, {-4.457206707742239, 
            1.8761812895114183`}, {-4.315690822470167, 
            1.8761838109349807`}, {-4.174174937198095, 
            1.876186332358543}, {-4.166106840895246, 
            1.8761864761098124`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231998985717, 
            1.8761868480420385`}, {-4.032659051926022, 
            1.8761888537821056`}, {-3.8911431666539498`, 
            1.876191375205668}, {-3.7496272813818776`, 
            1.8761938966292304`}, {-3.6081113961098055`, 
            1.8761964180527928`}, {-3.466595510837733, 
            1.8761989394763552`}, {-3.325079625565661, 
            1.8762014608999178`}, {-3.310238322604549, 
            1.8762017253310868`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893634806950196`, 
            1.8762020972633129`}, {-3.1835637402935886`, 
            1.8762039823234802`}, {-3.042047855021516, 
            1.8762065037470426`}, {-2.9005319697494443`, 
            1.876209025170605}, {-2.7590160844773717`, 
            1.8762115465941673`}, {-2.617500199205299, 
            1.87621406801773}, {-2.4759843139332274`, 
            1.8762165894412923`}, {-2.4543698043138513`, 
            1.8762169745523611`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494962404322, 
            1.8762173464845873`}, {-2.3344684286611552`, 
            1.8762191108648547`}, {-2.192952543389082, 
            1.876221632288417}, {-2.079738439702335, 
            1.8762215969892562`}, {-1.9665243360155877`, 
            1.8762215616900952`}, {-1.8533102197314206`, 
            1.8762215414247914`}, {-1.7400961034472535`, 
            1.8762215211594873`}, {-1.7174532792855788`, 
            1.8762215192994207`}, {-1.694810455091759, 
            1.876221517610298}, {-1.6892629631579499`, 
            1.8762215172393664`}, {-1.6092795936483097`, 
            1.8762215119821708`}, {-1.5985012859288135`, 
            1.8762215115115035`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776264440159709`, 
            1.8762215105999407`}, {-1.5292962240499832`, 
            1.8762215084894562`}, {-1.4109138916453308`, 
            1.8762215054167724`}, {-1.292531559240678, 
            1.8762215023440882`}, {-1.1741492268360256`, 
            1.8762214992714044`}, {-1.0557668944313732`, 
            1.8762214961987203`}, {-0.9373845620267206, 
            1.8762214931260364`}, {-0.8190022296220681, 
            1.8762214900533523`}, {-0.7426327675022667, 
            1.8762214880711374`}}]}, 
          {Arrowheads[{{0.006926405773245782, 1.}}], 
           ArrowBox[{{-0.7217579255894241, 
            1.8762214875293184`}, {-0.7006198972174157, 
            1.8762214869806684`}, {-0.582237564812763, 
            1.8762214839079843`}, {-0.5557709702694881, 
            1.8762214840057645`}, {-0.5293043757332813, 
            1.8762214840887175`}, {-0.48094352511698113`, 
            1.876221484173427}, {-0.432582674508012, 1.8762214842233558`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.009880349956902264, 1.}}], ArrowBox[CompressedData["

1:eJxTTMoPSmViYGCQBGIQnXZDLEM79619Zrv8g6kMV/Z7rl558mH3W/sNiyD8
HMFUsZqDb+3nr4XwU23+7K9/+NbebRmEn7fdu19P8539lloIn3Wq4YXTHu/s
F6dA+CGWiY38xe/sBW0h/CsyxmJHVr2zl2SA8P/OM+StYntvX9InB+afnb3Q
pHH+e/u0PbJg/txUsaCvrB/si2Ug/Lry3+ExTh/sfaJkwHzfyyvvL63/YC9W
Kw3m7wif/GHPzA/2nGIQvlrcIo3SzR/so1ZJgfmRyVaui259sP/wUxLMZw+P
1HKz/2i//IM4mL80vIL/1eKP9jNqRMH87ozpX3o5Ptm/6BEC8/exs+xZJ/PJ
vvCZIJjvPTdO2UPnk31BIoQv/TTCRHnRJ/sPabxgfqFfsOs/8c/233s5wHyZ
jRwTxU2+2K/d9uk+iG/ve+COQcBXe+XfF8F8ANs8y0E=
            "]]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.4624988803046497`}, {-4.973096215031099, 
            2.462502456628464}, {-4.941918512900958, 
            2.462503153345991}, {-4.91074076488981, 
            2.462503793910271}, {-4.723825168883478, 
            2.462505692933974}, {-4.536908151647904, 
            2.462506426666506}, {-4.3903432086674465`, 
            2.4625041704063784`}, {-4.2437782656869905`, 
            2.462501914146251}, {-4.166106323784048, 2.4625007184435}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231481873679, 
            2.462500397090573}, {-4.097213322706533, 
            2.4624996578861236`}, {-3.9506483797260747`, 
            2.4624974016259964`}, {-3.8040834367456187`, 
            2.4624951453658688`}, {-3.6575184937651626`, 
            2.462492889105741}, {-3.5109535507847065`, 
            2.462490632845614}, {-3.3643886078042486`, 
            2.4624883765854864`}, {-3.310237805458914, 2.46248754297348}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362963548545, 
            2.4624872216205524`}, {-3.2178236648237926`, 
            2.462486120325359}, {-3.0712587218433347`, 
            2.4624838640652316`}, {-2.9246937788628786`, 
            2.462481607805104}, {-2.7781288358824217`, 
            2.4624793515449768`}, {-2.631563892901964, 
            2.462477095284849}, {-2.4849989499215077`, 
            2.462474839024722}, {-2.4543692871337806`, 2.46247436750346}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944452234115`, 
            2.4624740461505326`}, {-2.3384340069410507`, 
            2.4624725827645944`}, {-2.1918690639605938`, 
            2.462470326504467}, {-2.0453041209801377`, 
            2.4624680702443396`}, {-1.8987391779996807`, 
            2.462465813984212}, {-1.7521742350192238`, 
            2.4624635577240848`}, {-1.6056092920387668`, 
            2.462461301463957}, {-1.598500768808647, 2.46246119203344}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625926898278, 
            2.4624608706805127`}, {-1.4590443490583098`, 
            2.46245904520383}, {-1.3124794060778529`, 
            2.4624567889437023`}, {-1.1659144630973968`, 
            2.4624545326835747`}, {-1.0193495201169398`, 
            2.4624522764234476`}, {-0.8727845771364828, 
            2.46245002016332}, {-0.7426322504835134, 2.46244801656342}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574085731443, 
            2.462447695210493}, {-0.5796546911755698, 
            2.462445507643065}, {-0.4330897481951128, 
            2.4624432513829375`}, {-0.28652480521465673`, 
            2.4624409951228103`}, {-0.13995986223419976`, 
            2.4624387388626827`}, {0.006605080746258096, 
            2.4624364826025555`}, {0.11323626784162033`, 
            2.4624348410934}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110975198945`, 2.4624345197404724`}, {
            0.15317002372671418`, 2.462434226342428}, {0.29973496670717115`, 
            2.4624319700823003`}, {0.446299909687629, 2.462429713822173}, {
            0.5928648526680851, 2.4624274575620455`}, {0.739429795648542, 
            2.4624252013019183`}, {0.885994738628999, 2.4624229450417907`}, {
            0.969104786166754, 2.4624216656233795`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899796280771231, 2.462421344270452}, {
            1.0325596816094555`, 2.462420688781663}, {1.179124624589912, 
            2.462418432521536}, {1.325689567570369, 2.4624161762614083`}, {
            1.4722545105508256`, 2.462413920001281}, {1.618819453531282, 
            2.4624116637411535`}, {1.76538439651174, 2.462409407481026}, {
            1.8249733044918877`, 2.4624084901533596`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458481464022567`, 2.4624081688004322`}, {
            1.9119493394921965`, 2.4624071512208987`}, {2.058514282472653, 
            2.462404894960771}, {2.205079225453111, 2.462402638700644}, {
            2.3516441684335674`, 2.4624003824405163`}, {2.498209111414024, 
            2.462398126180389}, {2.644774054394481, 2.4623958699202615`}, {
            2.680841822817021, 2.4623953146833397`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.7017166647273902`, 2.4623949933304123`}, {
            2.7913389973749374`, 2.462393613660134}, {2.937903940355394, 
            2.4623913574000067`}, {3.084468883335851, 2.462389101139879}, {
            3.2310338263163065`, 2.462386844879752}, {3.377598769296764, 
            2.4623845886196243`}, {3.524163712277222, 2.4623823323594967`}, {
            3.5367103411421548`, 2.4623821392133194`}}]}, 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{3.557585183052524, 2.462381817860392}, {
            3.6707286552576774`, 2.4623800760993695`}, {3.817293598238133, 
            2.462377819839242}, {3.963858541218591, 2.4623755635791147`}, {
            4.110423484199049, 2.462373307318987}, {4.256988427179504, 
            2.4623710510588595`}, {4.392578859467289, 2.4623689637432995`}}]}, 
          {Arrowheads[{{0.014075467206021507`, 1.}}], 
           ArrowBox[{{4.413453701377658, 2.4623686423903726`}, {
            4.55011831314042, 2.4623665385386047`}, {4.696683256120875, 
            2.4623642822784775`}, {4.843248199101333, 2.46236202601835}, {
            4.953488847762335, 2.4623294851376354`}, {5.001099999999999, 
            2.4623154312578324`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.078909925655838}, {-4.9119335405086355`, 
            3.078908114188808}, {-4.730715279641265, 
            3.0789036310462987`}, {-4.613459357267729, 
            3.078900488736436}, {-4.496203434894193, 
            3.078897346426574}, {-4.378947512520657, 
            3.0788942041167116`}, {-4.261691590147121, 
            3.0788910618068495`}, {-4.166106323762893, 
            3.0788885002430564`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231481857547, 
            3.078887940823794}, {-4.144435667773585, 
            3.078887919496987}, {-4.0271797454000495`, 
            3.0788847771871244`}, {-3.9099238230265136`, 
            3.0788816348772623`}, {-3.792667900652978, 
            3.0788784925673998`}, {-3.7617297010018684`, 
            3.078877953677111}, {-3.730791476483436, 
            3.078877431325717}, {-3.5811902389438, 
            3.0788753684758743`}, {-3.4315886414935086`, 
            3.0788736727266834`}, {-3.310237805503388, 
            3.0788736256859637`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.289362963590547, 
            3.0788736175939917`}, {-3.2864197009199696`, 
            3.0788736164530586`}, {-3.1412507603464297`, 
            3.0788735601794337`}, {-2.9960818197728907`, 
            3.0788735039058084`}, {-2.8509128791993517`, 
            3.0788734476321835`}, {-2.7057439386258113`, 
            3.0788733913585586`}, {-2.5605749980522723`, 
            3.0788733350849333`}, {-2.454369287076905, 
            3.0788732939151053`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944451640643`, 
            3.078873285823133}, {-2.415406057478733, 
            3.0788732788113085`}, {-2.270237116905194, 
            3.0788732225376836`}, {-2.125068176331654, 
            3.0788731662640583`}, {-1.9798992357581149`, 
            3.0788731099904334`}, {-1.834730295184575, 
            3.0788730537168085`}, {-1.689561354611036, 
            3.078872997443183}, {-1.5985007686504227`, 
            3.0788729621442466`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5776259267375816`, 
            3.0788729540522746`}, {-1.5443924140374965`, 
            3.0788729411695583`}, {-1.399223473463957, 
            3.0788728848959335`}, {-1.2540545328904171`, 
            3.078872828622308}, {-1.108885592316878, 
            3.0788727723486833`}, {-0.9637166517433386, 
            3.0788727160750584`}, {-0.8185477111697992, 
            3.078872659801433}, {-0.74263225022394, 3.0788726303733878`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574083110989, 
            3.078872622281416}, {-0.6733787705962595, 
            3.0788726035278082`}, {-0.5282098300227203, 
            3.0788725472541834`}, {-0.383040889449181, 
            3.0788724909805585`}, {-0.23787194887564178`, 
            3.078872434706933}, {-0.09270300830210254, 3.0788723784333083`}, {
            0.05246593227143714, 3.0788723221596834`}, {0.11323626820254283`, 
            3.0788722986025294`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411111011538387`, 3.078872290510557}, {
            0.19763487284497683`, 3.078872265886058}, {0.34280381341851607`, 
            3.0788722096124332`}, {0.4879727539920553, 3.0788721533388084`}, {
            0.6331416945655945, 3.078872097065183}, {0.7783106351391338, 
            3.078872040791558}, {0.923479575712673, 3.0788719845179333`}, {
            0.9691047866290255, 3.0788719668316706`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899796285418666, 3.078871958739698}, {
            1.0686485162862132`, 3.078871928244308}, {1.2138174568597524`, 
            3.078871871970683}, {1.3585294838028243`, 3.0787866252354537`}, {
            1.5036970870681774`, 3.0787863196238923`}, {1.6488637987947383`, 
            3.07878584778704}, {1.794029618982509, 3.0787852097248964`}, {
            1.8249732799440836`, 3.0787850382812985`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481218566059`, 3.078784922624072}, {
            1.9391945476314878`, 3.0787844054374625`}, {2.0843585847416755`, 
            3.078783434924737}, {2.2295217303130728`, 3.078782298186721}, {
            2.374683984345678, 3.078780995223414}, {2.519845346839493, 
            3.078779526034816}, {2.665005817794516, 3.0787778906209273`}, {
            2.6808417983374677`, 3.0787776940736302`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.7017166402487027`, 3.0787774349868156`}, {
            2.8101653972107488`, 3.0787760889817473`}, {2.95532408508819, 
            3.0787741211172763`}, {3.1004818814268393`, 3.078771987027515}, {
            3.245638786226699, 3.0787696867124623`}, {3.3907947994877663`, 
            3.078767220172119}, {3.5359499212100425`, 3.078764587406484}, {
            3.5367103166618277`, 3.0787645727438733`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.5575851585707894`, 3.078764170216899}, {
            3.681104151393528, 3.0787617884155587`}, {3.826257490038222, 
            3.078758823199342}, {3.9714099371441254`, 3.0787556917578347`}, {
            4.116561492711237, 3.0787523940910364`}, {4.2617121567395575`, 
            3.0787489301989472`}, {4.392578834877747, 3.0787456572940393`}}]}, 
          {Arrowheads[{{0.014075467634674585`, 1.}}], 
           ArrowBox[{{4.413453676783868, 3.078745127675605}, {
            4.552010810179826, 3.0787415037388963`}, {4.697158799591773, 
            3.078737541170934}, {4.8423058974649305`, 3.078733412377681}, {
            4.987452103799294, 3.0787291173591376`}, {5.001099999999999, 
            3.0787286978719988`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            2.7708709954181314`}, {-5.000849124559718, 
            2.770871015185076}, {-4.8836598524844295`, 
            2.770880248746801}, {-4.852495975067702, 
            2.7708802009315625`}, {-4.821332030296799, 
            2.770880118817759}, {-4.637243213653665, 
            2.770878576926067}, {-4.453152548827477, 
            2.7708765301400176`}, {-4.266011785581627, 
            2.7707580467369985`}, {-4.166106381399559, 
            2.7706947941774698`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.14523154367052, 
            2.770681577806174}, {-4.078871022335774, 
            2.7706395633339795`}, {-3.891730259089922, 
            2.77052107993096}, {-3.70458949584407, 
            2.770402596527941}, {-3.51744873259822, 
            2.7702841131249216`}, {-3.3303079693523685`, 
            2.7701656297219026`}, {-3.3102380345089695`, 
            2.7701529229543476`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.289363196779931, 
            2.770139706583052}, {-3.143167206106517, 
            2.770047146318883}, {-2.9560264428606633`, 
            2.769928662915864}, {-2.7688856796148134`, 
            2.7698101795128447`}, {-2.5817449163689616`, 
            2.7696916961098257`}, {-2.4543696876183803`, 
            2.7696110517312253`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334948498893416`, 
            2.7695978353599298`}, {-2.39460415312311, 
            2.7695732127068062`}, {-2.20746338987726, 
            2.769454729303787}, {-2.0203226266314083`, 
            2.7693362459007678`}, {-1.8331818633855548`, 
            2.7692177624977488`}, {-1.6460411001397048`, 
            2.7690992790947293`}, {-1.598501340727791, 
            2.769069180508103}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.5776265029987522`, 
            2.7690559641368075`}, {-1.4589003368938531`, 
            2.7689807956917103`}, {-1.2717595736480014`, 
            2.768862312288691}, {-1.0846188104021515`, 
            2.7687438288856714`}, {-0.8974780471562998, 
            2.7686253454826524`}, {-0.7426329938372017, 2.768527309284981}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.721758156108163, 
            2.7685140929136853`}, {-0.7103372839104463, 
            2.768506862079633}, {-0.5231965206645945, 
            2.768388378676614}, {-0.3360557574187437, 
            2.7682698952735945`}, {-0.1489149941728929, 
            2.7681514118705755`}, {0.038225769072959714`, 
            2.768032928467556}, {0.11323535305338753`, 
            2.7679854380618587`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1341101907824263, 2.767972221690563}, {
            0.22536653231881143`, 2.767914445064537}, {0.41250729556466226`, 
            2.7677959616615175`}, {0.599648058810514, 2.7676774782584985`}, {
            0.7867888220563657, 2.767558994855479}, {0.9691036999439768, 
            2.767443566838737}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899785376730156, 2.767430350467441}, {
            1.1610703485480691`, 2.7673220280494406`}, {1.34821111179392, 
            2.7672035446464216`}, {1.5353518750397717`, 2.767085061243402}, {
            1.7224926382856243`, 2.766966577840383}, {1.8249720468345663`, 
            2.7669016956156143`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458468845636051`, 2.7668884792443187`}, {
            1.909633401531475, 2.7668480944373637`}, {2.096774164777326, 
            2.7667296110343447`}, {2.2839149280231785`, 2.766611127631325}, {
            2.4710556912690294`, 2.766492644228306}, {2.65819645451488, 
            2.7663741608252868`}, {2.6808403937251555`, 2.766359824392492}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.701715231454194, 2.7663466080211965`}, {
            2.845337217760733, 2.7662556774222677`}, {3.0324779810065836`, 
            2.7661371940192483`}, {3.2196187442524344`, 
            2.7660187106162293`}, {3.406759507498287, 2.76590022721321}, {
            3.5367087406157447`, 2.7658179531693703`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.5575835783447833`, 2.7658047367980747`}, {
            3.593900270744137, 2.765781743810191}, {3.781041033989989, 
            2.7656632604071714`}, {3.968181797235841, 2.7655447770041524`}, {
            4.155322560481691, 2.765426293601133}, {4.342463323727543, 
            2.765307810198114}, {4.392577087506334, 2.765276081946248}}]}, 
          {Arrowheads[{{0.014075512403795966`, 1.}}], 
           ArrowBox[{{4.413451925235373, 2.7652628655749525`}, {
            4.529604086973395, 2.7651893267950944`}, {4.716744850219247, 
            2.7650708433920754`}, {4.9038856134651, 2.764952359989056}, {
            5.001099999999999, 2.764890811178742}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            3.3849993070635205`}, {-5.000822371348418, 
            3.384999299987365}, {-4.8836434485284075`, 
            3.3849963133493803`}, {-4.852480195727973, 
            3.3849946759051655`}, {-4.821316837811359, 
            3.3849930505446335`}, {-4.637227426219185, 
            3.384984173868872}, {-4.453135373296201, 
            3.3849761555306466`}, {-4.296560724685522, 
            3.3849827755981545`}, {-4.1661063242550425`, 
            3.384988291286328}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-4.145231482360859, 
            3.384989173886824}, {-4.139986076074843, 
            3.3849893956656625`}, {-3.983411427464162, 
            3.3849960157331704`}, {-3.826836778853483, 
            3.3850026358006784`}, {-3.6702621302428042`, 
            3.3850092558681864`}, {-3.5136874816321235`, 
            3.3850158759356943`}, {-3.3571128330214446`, 
            3.3850224960032023`}, {-3.3102378065934914`, 
            3.385024477906672}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629646993072`, 
            3.3850253605071683`}, {-3.2005381844107657`, 
            3.38502911607071}, {-3.0439635358000867`, 
            3.385035736138218}, {-2.887388887189408, 
            3.385042356205726}, {-2.730814238578729, 
            3.385048976273234}, {-2.574239589968048, 
            3.3850555963407416`}, {-2.45436928893194, 3.3850606645270163`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944470377557`, 
            3.3850615471275125`}, {-2.417664941357369, 
            3.3850622164082496`}, {-2.2610902927466894`, 
            3.3850688364757575`}, {-2.1045156441360104`, 
            3.3850754565432655`}, {-1.9479409955253315`, 
            3.3850820766107734`}, {-1.7913663469146517`, 
            3.3850886966782814`}, {-1.6347916983039719`, 
            3.3850953167457893`}, {-1.5985007712703887`, 
            3.385096851147361}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259293762045`, 
            3.385097733747857}, {-1.4782170496932938`, 
            3.3851019368132973`}, {-1.321642401082614, 
            3.3851085568808053`}, {-1.1650677524719342`, 
            3.385115176948313}, {-1.0084931038612552`, 
            3.385121797015821}, {-0.8519184552505754, 
            3.385128417083329}, {-0.7426322536088374, 3.3851330377677056`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574117146532, 
            3.385133920368202}, {-0.6953438066398965, 
            3.385135037150837}, {-0.5387691580292167, 
            3.385141657218345}, {-0.38219450941853683`, 
            3.385148277285853}, {-0.2256198608078579, 
            3.3851548973533605`}, {-0.06904521219717896, 
            3.3851615174208685`}, {0.08752943641350086, 
            3.3851681374883764`}, {0.11323626405271384`, 
            3.3851692243880493`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.134111105946898, 3.3851701069885456`}, {
            0.2441040850241798, 3.3851747575558844`}, {0.4006787336348596, 
            3.3851813776233923`}, {0.5572533822455386, 3.3851879976909003`}, {
            0.7138280308562184, 3.3851946177584082`}, {0.8704026794668982, 
            3.385201237825916}, {0.9691047817142651, 3.385205411008394}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899796236084493, 3.3852062936088902`}, {
            1.0269773280775771`, 3.385207857893424}, {1.183551976688257, 
            3.385214477960932}, {1.340126625298936, 3.38522109802844}, {
            1.4967012739096148`, 3.385227718095948}, {1.6532759225202946`, 
            3.385234338163456}, {1.809850571130974, 3.385240958230964}, {
            1.8249732993758163`, 3.3852415976287387`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.8458481412700005`, 3.385242480229235}, {
            1.966425219741653, 3.385247578298472}, {2.1229998683523323`, 
            3.3852541983659794`}, {2.279574516963012, 3.3852608184334874`}, {
            2.4361491655736907`, 3.3852674385009953`}, {2.5927238141843705`, 
            3.3852740585685033`}, {2.6808418170373676`, 3.385277784249083}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.7017166589315518`, 3.385278666849579}, {
            2.74929846279505, 3.3852806786360112`}, {2.905873111405729, 
            3.385287298703519}, {3.062447760016408, 3.385293918771027}, {
            3.219022408627088, 3.385300538838535}, {3.375597057237767, 
            3.385307158906043}, {3.532171705848447, 3.385313778973551}, {
            3.536710334698919, 3.385313970869427}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5575851765931032`, 3.3853148534699233`}, {
            3.688746354459126, 3.385320399041059}, {3.8453210030698046`, 
            3.385327019108567}, {4.001895651680485, 3.385333639176075}, {
            4.158470300291164, 3.385340259243583}, {4.315044948901843, 
            3.385346879311091}, {4.3925788523604705`, 3.3853501574897713`}}]}, 
          {Arrowheads[{{0.01407546722327669, 1.}}], 
           ArrowBox[{{4.413453694254654, 3.3853510400902675`}, {
            4.4716195975125235`, 3.3853534993785983`}, {4.6281942461232015`, 
            3.3853601194461063`}, {4.7847688947338805`, 3.385366739513614}, {
            4.941343543344561, 3.385373359581122}, {5.001099999999999, 
            3.385375886118979}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.3693994381759471`, -0.9123354386518312}, {
            1.4868202621331426`, -0.9123354389205931}, {
            1.604241086090338, -0.912335439189355}, {
            1.7216619100475334`, -0.9123354394581168}, {
            1.839082734004729, -0.9123354397268787}, {
            1.9565035579619245`, -0.9123354399956406}, {
            2.07392438191912, -0.9123354402644025}, {
            2.191345205876315, -0.9123354405331644}, {
            2.2043931146896516`, -0.9123354405630295}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.225267956602494, -0.9123354406108095}, {
            2.308766029833511, -0.9123354408019263}, {
            2.3390817616013546`, -0.9123354368220123}, {
            2.369397493363421, -0.912335432354448}, {
            2.47594719818844, -0.9123354067333161}, {
            2.5824969047275403`, -0.9123353703670153}, {
            2.585966977140315, -0.9123353691748992}, {
            2.596872919037019, -0.9123353652904082}, {
            2.6067874116960192`, -0.9123353616372089}, {
            2.7059323414998904`, -0.9123353122602228}, {
            2.8050772764462755`, -0.912335246606166}, {
            2.9290089253702014`, -0.9123344769235703}, {
            3.0529405742941274`, -0.9123337072409745}, {
            3.0602616331112316`, -0.912333661773238}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0811364750236714`, -0.912333532129175}, {
            3.176872223218053, -0.9123329375583787}, {
            3.300803872141979, -0.9123321678757831}, {
            3.4247355210659047`, -0.9123313981931873}, {
            3.5486671699898307`, -0.9123306285105915}, {
            3.6725988189137566`, -0.9123298588279959}, {
            3.7965304678376826`, -0.9123290891454001}, {
            3.916130151470629, -0.9123255302618952}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.9370049933742295`, -0.9123249090969535}, {
            4.0444006216507455`, -0.9123217133650053}, {
            4.168335698557278, -0.9123180254748078}, {
            4.292270775463809, -0.9123143375846103}, {
            4.416205852370341, -0.9123106496944129}, {
            4.540140929276872, -0.9123069618042154}, {
            4.664076006183404, -0.912303273914018}, {
            4.771998669518259, -0.9123000624992827}}]}, 
          {Arrowheads[{{0.0049874986940664475`, 1.}}], 
           ArrowBox[{{4.792873511310322, -0.9122985345391681}, {
            4.9054781431378425`, -0.9122741841453328}, {
            5.001099999999999, -0.9122535062226215}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.6059222111466545`, -0.30569218095170614`}, {
            1.6938924314458876`, -0.30569218036171264`}, {
            1.7818626521022727`, -0.3056921794948896}, {
            1.8992196126169056`, -0.305692177832602}, {
            2.0165765731315384`, -0.3056921761703144}, {
            2.133933533646171, -0.3056921745080268}, {
            2.2512904941608043`, -0.30569217284573924`}, {
            2.368647454675437, -0.30569217118345166`}, {
            2.440915887660359, -0.30569217015981476`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.4617907295732016`, -0.3056921698641358}, {
            2.4860044151900698`, -0.3056921695211641}, {
            2.603361375704703, -0.30569216785887654`}, {
            2.7207183362193357`, -0.30569216619658895`}, {
            2.751290410733502, -0.30569215782630854`}, {
            2.781862486904641, -0.30569214879009804`}, {
            2.9014555125323893`, -0.30569209798084646`}, {
            3.0210485820903172`, -0.3056920311319723}, {
            3.027068195236331, -0.3056920277215006}, {
            3.0330878085123216`, -0.3056920242648198}, {
            3.0391074219200713`, -0.30569202076140767`}, {
            3.045127035461383, -0.3056920172107377}, {
            3.0511466491380737`, -0.30569201361227966`}, {
            3.063185877044026, -0.30569200622099313`}, {
            3.0752251055176387`, -0.3056919986309713}, {
            3.195617456089572, -0.30569190028335885`}, {
            3.2967844060867684`, -0.3056917943471235}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.317659247999549, -0.30569176117102936`}, {
            3.466504604665947, -0.30569058399750465`}, {
            3.6169993176146704`, -0.3056893937797131}, {
            3.7674940305633933`, -0.3056882035619216}, {
            3.917988743512116, -0.30568701334413007`}, {
            4.068483456460839, -0.3056858231263385}, {
            4.15265292448714, -0.305685157455124}}]}, 
          {Arrowheads[{{0.01982223954874403, 1.}}], 
           ArrowBox[{{4.17352776639933, -0.30568499236222635`}, {
            4.218978169409562, -0.30568463290854697`}, {
            4.369472882358285, -0.3056834426907554}, {
            4.519967595307008, -0.3056822524729639}, {
            4.670483551135896, -0.30567725165981535`}, {
            4.820999506964784, -0.3056722508466668}, {
            4.971515462793672, -0.3056672500335183}, {
            5.001099999999999, -0.3056662671028925}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.017340695408330088`, 1.}}], 
           ArrowBox[{{-0.37340907408225665`, 
            1.3206362899195727`}, {-0.2546212818025415, 
            1.320636290006774}, {-0.13583348952282637`, 
            1.3206362900939754`}, {-0.017045697243111335`, 
            1.3206362901811768`}, {0.1017420950366037, 1.3206362902683784`}, {
            0.22052988731631873`, 1.3206362903555797`}, {0.24537668828921405`,
             1.3206362903561524`}, {0.2702234892620317, 
            1.3206362903563866`}, {0.3103914828972976, 1.3206362903544584`}, {
            0.3505594765330359, 1.320636290350466}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -0.30007673855162376`}, \
{-4.996642950587454, -0.3000768312710928}, {-4.843496393448644, \
-0.30008001716071425`}, {-4.690349836309835, -0.30008320305033576`}, \
{-4.537203279171026, -0.3000863889399572}, {-4.384056722032216, \
-0.30008957482957865`}, {-4.230910164893406, -0.3000927607192001}, \
{-4.166106323666971, -0.300094108825805}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481758645, -0.30009454308265954`}, \
{-4.077763607754598, -0.30009594660882155`}, {-3.9246170506157885`, \
-0.300099132498443}, {-3.7714704934769787`, -0.30010231838806445`}, \
{-3.618323936338169, -0.30010550427768595`}, {-3.4651773791993596`, \
-0.3001086901673074}, {-3.3120308220605508`, -0.30011187605692885`}, \
{-3.3102378054256167`, -0.30011191335684073`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289362963517291, -0.30011234761369526`}, \
{-3.158884264921741, -0.3001150619465503}, {-3.005737707782932, \
-0.30011824783617175`}, {-2.8525911506441224`, -0.30012143372579325`}, \
{-2.7300860208354063`, -0.3001214793113983}, {-2.60758089102669, \
-0.3001215248970034}, {-2.485075814525179, -0.30012154954010606`}, \
{-2.4543692870981153`, -0.3001215557170265}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494445185273, -0.3001215599162065}, \
{-2.362570738023668, -0.3001215741832087}, {-2.338069728265934, \
-0.3001215766748492}, {-2.3111186179711027`, -0.3001215792077693}, \
{-2.3075659716655488`, -0.30012157951693624`}, {-2.209193185265595, \
-0.3001215880096411}, {-2.110820403344288, -0.3001215942770758}, \
{-1.992964914599031, -0.30012159973500163`}, {-1.8751094258537737`, \
-0.30012160519292747`}, {-1.7572539371085165`, -0.3001216106508533}, \
{-1.639398448363259, -0.30012161610877913`}, {-1.5985007686715715`, \
-0.30012161800276393`}}]}, 
          {Arrowheads[{{0.014920007190883895`, 1.}}], 
           ArrowBox[{{-1.577625926758729, -0.30012161896948464`}, \
{-1.5215429596180017`, -0.30012162156670497`}, {-1.4036874708727445`, \
-0.30012162702463074`}, {-1.2858319821274873`, -0.3001216324825566}, \
{-1.1679764933822299`, -0.3001216379404824}, {-1.1393985194452365`, \
-0.30012163795814617`}, {-1.1108205455103346`, -0.3001216379727023}, \
{-1.0422206919116421`, -0.300121637989553}, {-1.024471880058239, \
-0.3001216379932702}, {-1.007220361268013, -0.3001216379964522}, \
{-0.9991416651936739, -0.3001216379978762}, {-0.9921296333934418, \
-0.3001216379990871}, {-0.9802070285865339, -0.3001216380011211}, \
{-0.9719055001622332, -0.3001216380025032}, {-0.9661411562781677, \
-0.3001216380034493}, {-0.9602144124954286, -0.300121638004413}, \
{-0.9547203438623769, -0.3001216380052979}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.014244006002823613`, 1.}}], 
           ArrowBox[{{-0.3999892819010807, 
            1.8793775403915345`}, {-0.28089588981036584`, 
            1.879377541696053}, {-0.16180249771965105`, 
            1.8793775430005712`}, {-0.04270910562893626, 
            1.8793775443050897`}, {0.07638428646177865, 1.879377545609608}, {
            0.10000660910717692`, 1.8793775456163362`}, {0.12362893175181666`,
             1.8793775456247732`}, {0.159161198441301, 1.879377545641724}, {
            0.19469346512796737`, 1.8793775456592616`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9534776582762998, 0.8143924224104522}, {
            1.0785331797742232`, 0.8143924224694047}, {1.203588701272147, 
            0.8143924225283572}, {1.3286442227700703`, 0.8143924225873097}, {
            1.4536997442679933`, 0.8143924226462622}, {1.578755265765917, 
            0.8143924227052147}, {1.7038107872638402`, 0.8143924227641672}, {
            1.788471334790004, 0.8143924228040771}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8093461767028467`, 0.8143924228139177}, {
            1.8288663087617638`, 0.8143924228231196}, {1.953921830259687, 
            0.8143924228820721}, {2.0539662455580188`, 0.814392419580751}, {
            2.1540106606924305`, 0.8143924143514821}, {2.164015102211471, 
            0.814392413556794}, {2.1750199878852112`, 0.81439241264369}, {
            2.178521542418868, 0.8143924123396264}, {2.2858214596243425`, 
            0.8143924029458798}, {2.3931213774784417`, 0.8143923888635772}, {
            2.5104126876711947`, 0.8143923664577262}, {2.627703997863948, 
            0.8143923440518751}, {2.644339853216545, 0.8143923408739714}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.665214695129387, 0.8143923368863052}, {
            2.744995308056701, 0.8143923216460242}, {2.862286618249454, 
            0.8143922992401731}, {2.979577928442207, 0.814392276834322}, {
            3.09686923863496, 0.814392254428471}, {3.214160548827713, 
            0.8143922320226199}, {3.331451859020466, 0.814392209616769}, {
            3.3622858892793834`, 0.8143921377744123}, {3.393119923680259, 
            0.8143920610433085}, {3.5002083716422336`, 0.8143916832245396}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.521083213554946, 0.8143916095760068}, {
            3.53204268395833, 0.8143915709098977}, {3.670965593797429, 
            0.8143909288110159}, {3.810892269305689, 0.8143143009050968}, {
            3.9508189448139497`, 0.8142376729991776}, {4.090745620322209, 
            0.8141610450932584}, {4.23067229583047, 0.8140844171873391}, {
            4.35607678733553, 0.8140157420505791}}]}, 
          {Arrowheads[{{0.014949777106768498`, 1.}}], 
           ArrowBox[{{4.376951626118217, 0.8140043103834113}, {
            4.51052564684699, 0.8139311613755007}, {4.65045232235525, 
            0.8138545334695815}, {4.79037899786351, 0.8137779055636623}, {
            4.93030567337177, 0.813701277657743}, {5.001099999999999, 
            0.8136625086311741}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.41691330046839337`, 1.3465278014623523`}, {
            0.5447019027031033, 1.346535950921713}, {0.6724905049378131, 
            1.3465441003810736`}, {0.800279107172523, 1.3465522498404345`}, {
            0.9280677094072329, 1.3465603992997952`}, {1.0558563116419428`, 
            1.3465685487591559`}, {1.1836449138766518`, 
            1.3465766982185168`}, {1.2519069752841412`, 
            1.3465810514932657`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.2727818171545349`, 1.3465823827440386`}, {
            1.3114335161113617`, 1.3465848476778775`}, {1.4392221183460725`, 
            1.3465929971372383`}, {1.5670107205807824`, 1.346601146596599}, {
            1.6947993228154914`, 1.3466092960559597`}, {1.8225879250502013`, 
            1.3466174455153206`}, {1.9503765272849112`, 
            1.3466255949746813`}, {2.078165129519621, 1.346633744434042}, {
            2.107775491970283, 1.346635632774952}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.128650333840677, 1.346636964025725}, {
            2.20595373175433, 1.3466418938934028`}, {2.33374233398904, 
            1.3466500433527635`}, {2.46153093622375, 1.3466581928121242`}, {
            2.5893195384584597`, 1.346666342271485}, {2.7171081406931687`, 
            1.3466744917308457`}, {2.8448967429278786`, 
            1.3466826411902064`}, {2.963644008656425, 1.3466902140566386`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.9845188505508786`, 1.3466907820546141`}, {
            3.1067945274939466`, 1.346690693242914}, {3.2409036924753765`, 
            1.346690541090397}, {3.3581374838437084`, 1.346690342759954}, {
            3.4753712752120403`, 1.346690144429511}, {3.592605066580372, 
            1.3466899460990678`}, {3.7098388579487036`, 
            1.3466897477686246`}, {3.8195125270636363`, 
            1.3466895622280297`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.840387368976449, 1.3466895269129844`}, {
            3.9443064406853674`, 1.3466893511077385`}, {4.0615402320537, 
            1.3466891527772953`}, {4.178774023422031, 1.346688954446852}, {
            4.209836319655349, 1.3466885321973077`}, {4.240898624980842, 
            1.3466880859631574`}, {4.4066307482386655`, 1.346684755461526}, {
            4.572363385147334, 1.3466804141981328`}, {4.6753810424914874`, 
            1.346655962819285}}]}, 
          {Arrowheads[{{0.007301710979255822, 1.}}], 
           ArrowBox[{{4.696255883816331, 1.3466510081477578`}, {
            4.80551926823156, 1.3466250743372303`}, {4.922097209773672, 
            1.3465974044067792`}, {5.001099999999999, 
            1.3465786529887829`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3264717166413037, 1.8917944016871746`}, {
            0.451027883327312, 1.891794401724723}, {0.5755840500133201, 
            1.8917944017622712`}, {0.6254065167049326, 1.8917944015785582`}, {
            0.675228983428611, 1.8917944013360235`}, {0.6802112301053171, 
            1.891794401305404}, {0.6864141272185769, 1.8917944012662904`}, {
            0.7433437710647411, 1.89179440089953}, {0.8002734149892954, 
            1.8917944004450957`}, {0.91782722558577, 1.891794399326128}, {
            1.0353810361822444`, 1.8917943982071603`}, {1.152934846778719, 
            1.8917943970881925`}, {1.161465393155008, 1.8917943970069921`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1823402350678507`, 1.8917943968082893`}, {
            1.2704886573751937`, 1.8917943959692247`}, {1.388042467971668, 
            1.8917943948502571`}, {1.5055962785681427`, 
            1.8917943937312893`}, {1.6231500891646173`, 
            1.8917943926123215`}, {1.740703899761092, 1.891794391493354}, {
            1.770484493973809, 1.8917943939571318`}, {1.8002650881192863`, 
            1.8917943967425213`}, {1.8888172442033895`, 1.891794409441809}, {
            1.97736939826943, 1.8917944260921102`}, {1.9829270638146588`, 
            1.8917944271482727`}, {2.0056114127900813`, 
            1.8917944317652784`}, {2.0173339115815514`, 
            1.8917944343022222`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.038208753494393, 1.8917944402745315`}, {
            2.141717489872971, 1.8917944778645583`}, {2.2551392181735497`, 
            1.8917945190545677`}, {2.36856091625686, 1.8917945785494568`}, {
            2.481982614340171, 1.891794638044346}, {2.6237577073690703`, 
            1.8917903034927737`}, {2.7655328003979696`, 
            1.8917859689412015`}, {2.8732024298252083`, 
            1.8917826771107993`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.8940772717282948`, 1.89178203889518}, {
            2.907307893426869, 1.8917816343896292`}, {3.049082986455768, 
            1.8917772998380569`}, {3.1908580794846673`, 
            1.8917729652864845`}, {3.3326331725135665`, 
            1.8917686307349124`}, {3.4744082655424657`, 1.89176429618334}, {
            3.616183358571365, 1.8917599616317677`}, {3.72907094785175, 
            1.8917565102704097`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.7499457897548365`, 1.8917558720547905`}, {
            3.757958451600264, 1.8917556270801954`}, {3.899733544629164, 
            1.8917512925286233`}, {4.041508637658063, 1.891746957977051}, {
            4.183283730686963, 1.8917426234254786`}, {4.325058823715862, 
            1.8917382888739063`}, {4.466833916744761, 1.8917339543223342`}, {
            4.584939465878292, 1.8917303434300203`}}]}, 
          {Arrowheads[{{0.009468012528419478, 1.}}], 
           ArrowBox[{{4.605814307781378, 1.891729705214401}, {
            4.6086090097736605`, 1.8917296197707618`}, {4.75038410280256, 
            1.8917252852191895`}, {4.89234876285526, 1.8912378026363454`}, {
            5.001099999999999, 1.8912301516965648`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9530884210893966, 0.26958847591853724`}, {
            0.9573828501279324, 0.2695884759178683}, {0.9630559143911538, 
            0.26958847591697727`}, {0.9751872750789653, 
            0.26958847591502977`}, {0.9981717215639159, 0.2695884759111763}, {
            1.012762837008622, 0.26958847590868135`}, {1.0283004850969122`, 
            0.2695884759057705}, {1.0903873564381374`, 0.2695884758926145}, {
            1.2079260038275381`, 0.2695884758519431}, {1.3254646512580792`, 
            0.26958847576272}, {1.4430032987798993`, 0.2695884755844786}, {
            1.5605419463017196`, 0.26958847540623726`}, {1.6780805943466248`, 
            0.2695884748216107}, {1.7880820976031009`, 0.2695884742744732}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.8089569395159435`, 0.2695884740564155}, {
            1.825464568869004, 0.2695884738329316}, {1.8553098954331284`, 
            0.2695884733788633}, {1.9456027235165798`, 0.2695884712252306}, {
            2.035895553180321, 0.26958846826387234`}, {2.0395851597075683`, 
            0.26958846814171167`}, {2.067575278369539, 
            0.26958846712660856`}, {2.0930208409751865`, 
            0.26958846611370657`}, {2.2202486679296065`, 
            0.26958845486195343`}, {2.3474764948840265`, 
            0.2695884436102003}, {2.474704351568155, 0.2695884207378544}, {
            2.601932208252284, 0.2695883978655085}, {2.6439506160245014`, 
            0.26958774054056506`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.6648254579347896`, 0.26958741398001684`}, {
            2.7609798083915607`, 0.26958590976659413`}, {2.920027408530838, 
            0.2695834216676798}, {3.0790750086701153`, 0.2695809335687655}, {
            3.238122608809392, 0.26957844546985116`}, {3.397170208948669, 
            0.2695759573709368}, {3.4998191343463216`, 0.2695743515580883}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.52069397625661, 0.2695740249975401}, {
            3.556217809087946, 0.2695734692720225}, {3.7152654092272237`, 
            0.2695709811731082}, {3.874313009366501, 0.2695684930741939}, {
            4.0333606095057775`, 0.26956600497527955`}, {4.192408209645055, 
            0.2695635168763652}, {4.351455809784332, 0.2695610287774509}, {
            4.355687652668141, 0.2695609625756115}}]}, 
          {Arrowheads[{{0.014959095453407059`, 1.}}], 
           ArrowBox[{{4.37656249457843, 0.2695606360150633}, {
            4.51050340992361, 0.2695585406785366}, {4.669551010062887, 
            0.2695560525796223}, {4.828598610202164, 0.26955356448070794`}, {
            4.987646210341441, 0.26955107638179365`}, {5.001099999999999, 
            0.2695508659142392}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.200899939099535}, \
{-4.993632597229871, -4.200898828389233}, {-4.9624481833434455`, \
-4.20089429662513}, {-4.773894565838077, -4.200871432922597}, \
{-4.585337536059042, -4.2008523537102365`}, {-4.456624697036034, \
-4.200855476906032}, {-4.327911858013026, -4.200858600101827}, \
{-4.1991990189900195`, -4.200861723297622}, {-4.166106326373074, \
-4.200862526286347}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231484466377, -4.200863032810941}, \
{-4.070486179967012, -4.200864846493418}, {-3.941773340944005, \
-4.200867969689213}, {-3.813060501920998, -4.200871092885008}, \
{-3.6843476628979905`, -4.200874216080804}, {-3.5556348238749838`, \
-4.200877339276599}, {-3.426921984851976, -4.200880462472394}, \
{-3.3102378081984876`, -4.200883293794683}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2893629662917903`, -4.200883800319276}, \
{-3.1694963068059616`, -4.200886708863985}, {-3.040783467782955, \
-4.20088983205978}, {-2.912070628759947, -4.200892955255576}, \
{-2.7833577897369404`, -4.200896078451371}, {-2.6546449507139336`, \
-4.200899201647166}, {-2.525932111690926, -4.2009023248429616`}, \
{-2.4543692900239007`, -4.200904061303018}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.4334944481172034`, -4.200904567827612}, \
{-2.3972192726679173`, -4.200905448038757}, {-2.2685064336449106`, \
-4.200908571234552}, {-2.1397935946219038`, -4.2009116944303475`}, \
{-2.011080755598896, -4.200914817626143}, {-1.8823679165758893`, \
-4.200917940821938}, {-1.7536550775528825`, -4.2009210640177335`}, \
{-1.6249422385298748`, -4.200924187213529}, {-1.5985007718493138`, \
-4.200924828811353}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259299426165`, -4.200925335335947}, \
{-1.496229399506868, -4.200927310409324}, {-1.3675165604838613`, \
-4.200930433605119}, {-1.2388037214608527`, -4.200933556800915}, \
{-1.110090882437846, -4.20093667999671}, {-0.9813780434148391, \
-4.200939803192505}, {-0.8526652043918315, -4.200942926388301}, \
{-0.742632253674727, -4.20094559631969}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574117680298, -4.2009461028442825`}, \
{-0.5952395263458179, -4.200949172779891}, {-0.4665266873228102, \
-4.200952295975687}, {-0.3378138482998021, -4.200955419171482}, \
{-0.2091010092767953, -4.200958542367277}, {-0.08038817025378853, \
-4.200961665563073}, {0.04832466876921915, -4.200964788758868}, {
            0.11323626449985988`, -4.200966363828025}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110640655713`, -4.200966870352619}, {
            0.17703750779222638`, -4.200967911954663}, {
            0.30575034681523316`, -4.2009710351504586`}, {
            0.43446318583824084`, -4.200974158346254}, {
            0.5631760248612476, -4.200977281542049}, {
            0.6918888638842549, -4.200980404737844}, {
            0.8206017029072625, -4.200983527933639}, {
            0.9493145419302693, -4.200986651129434}, {
            0.9691047826744467, -4.20098713133636}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899796245811439, -4.200987637860954}, {
            1.078027380953276, -4.20098977432523}, {
            1.2067402199762842`, -4.200992897521025}, {
            1.335453058999291, -4.20099602071682}, {
            1.4641658980222978`, -4.2009991439126155`}, {
            1.5928787370453055`, -4.201002267108411}, {
            1.7215915760683134`, -4.201005390304206}, {
            1.8249733008490334`, -4.201007898844695}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8458481427557307`, -4.201008405369289}, {
            1.8503044150913202`, -4.2010085135000015`}, {
            1.9790172541143272`, -4.201011636695797}, {
            2.107730093137335, -4.201014759891592}, {
            2.236442932160342, -4.201017883087387}, {
            2.365155771183349, -4.201021006283183}, {
            2.4938686102063565`, -4.201024129478978}, {
            2.6225814492293633`, -4.201027252674773}, {
            2.6808418190236205`, -4.2010286663530305`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716660930318, -4.201029172877624}, {
            2.75129428825237, -4.201030375870569}, {
            2.8800071272753778`, -4.201033499066364}, {
            3.008719966298385, -4.201036622262159}, {
            3.137432805321392, -4.201039745457955}, {
            3.2661456443443995`, -4.20104286865375}, {
            3.3948584833674076`, -4.201045991849545}, {
            3.5235713223904135`, -4.201049115045341}, {
            3.5367103371982074`, -4.201049433861367}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.5575851791049047`, -4.2010499403859605`}, {
            3.652284161413421, -4.201052238241136}, {
            3.7947906168203787`, -4.201085339413729}, {
            3.937297072227336, -4.201118440586322}, {
            4.079803527634293, -4.201151541758916}, {
            4.22230998304125, -4.20118464293151}, {
            4.364816438448207, -4.201217744104103}, {
            4.392578835620076, -4.201224192709521}}]}, 
          {Arrowheads[{{0.014075468004416336`, 1.}}], 
           ArrowBox[{{4.413453676969786, -4.201229041484438}, {
            4.507322893855164, -4.2012508452766975`}, {
            4.649829349262121, -4.201283946449291}, {
            4.7923358046690785`, -4.201317047621885}, {
            4.934842260076035, -4.201350148794478}, {
            5.001099999999999, -4.201365539036826}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.9456737741411874`}, \
{-4.938869694725646, -3.9456668456807282`}, {-4.801630221410768, \
-3.9456515660149756`}, {-4.66439074809589, -3.9456362863492225`}, \
{-4.527151274781009, -3.94562100668347}, {-4.38991180146613, \
-3.9456057270177167`}, {-4.252672328151251, -3.9455904473519636`}, \
{-4.166106328661443, -3.9455808094576623`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231486877979, -3.945578485340574}, \
{-4.115432854836373, -3.945575167686211}, {-3.9781933815214927`, \
-3.945559888020458}, {-3.840953908206613, -3.945544608354705}, \
{-3.7037144348917344`, -3.945529328688952}, {-3.5664749615768554`, \
-3.9455140490231995`}, {-3.429235488261976, -3.9454987693574464`}, \
{-3.3102378155394225`, -3.9454855206570496`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629737559587`, -3.9454831965399615`}, \
{-3.1547565416322176`, -3.9454682100259406`}, {-3.0175170683173387`, \
-3.945452930360188}, {-2.8802775950024593`, -3.945437650694435}, \
{-2.7430381216875803`, -3.945422371028682}, {-2.6057986483727014`, \
-3.945407091362929}, {-2.4685591750578224`, -3.9453918116971765`}, \
{-2.4543693024174025`, -3.945390231856437}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-2.4334944606339386`, -3.9453879077393488`}, \
{-2.331319701742943, -3.9453765320314234`}, {-2.164025034900372, \
-3.945377268377422}, {-1.9967303680577997`, -3.945378004723421}, \
{-1.8294357012152285`, -3.9453787410694203`}, {-1.6621410343726573`, \
-3.945379477415419}, {-1.5985007847605943`, -3.945379757527416}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.577625942847954, -3.945379849407848}, \
{-1.4948463675300854`, -3.945380213761418}, {-1.327551700687514, \
-3.945380950107417}, {-1.1602570338449427`, -3.9453816864534157`}, \
{-0.9929623670023708, -3.9453824227994145`}, {-0.8256677001597987, \
-3.945383159145414}, {-0.7426322663423378, -3.9453835246251425`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574244296974, -3.9453836165055747`}, \
{-0.6583730333172275, -3.9453838954914127`}, {-0.4910783664746563, \
-3.9453846318374115`}, {-0.323783699632084, -3.9453853681834103`}, \
{-0.1564890327895121, -3.945386104529409}, {
            0.010805634053059343`, -3.945386840875408}, {
            0.11323625207591882`, -3.945387291722869}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411109398855922`, -3.9453873836033013`}, {
            0.17810030089563034`, -3.9453875772214073`}, {
            0.3453949677382018, -3.945388313567406}, {
            0.5126883980051942, -3.9453883418796885`}, {
            0.6799818282721861, -3.9453883701919708`}, {
            0.8472752585391786, -3.945388398504253}, {
            0.969104770500208, -3.945388419122346}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899796124130503, -3.945388422655147}, {
            1.014568688806171, -3.945388426816535}, {
            1.1818621190731635`, -3.945388455128817}, {
            1.349155549340156, -3.9453884834410995`}, {
            1.5164489796071483`, -3.945388511753382}, {
            1.6837424098741407`, -3.945388540065664}, {
            1.8249732889267427`, -3.9453885639671915`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{1.845848130839585, -3.9453885674999927`}, {
            1.851035840141133, -3.9453885683779464`}, {
            2.0183292704081257`, -3.9453885966902287`}, {
            2.1856227006751174`, -3.945388625002511}, {
            2.35291613094211, -3.945388653314793}, {
            2.5202095612091027`, -3.945388681627075}, {
            2.6808418073532776`, -3.945388708812037}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.7017166492661198`, -3.945388712344838}, {
            2.854796421743087, -3.9453887382516397`}, {
            3.022089852010079, -3.945388766563922}, {
            3.157866497564858, -3.945389193618675}, {
            3.293643306233755, -3.945390066768723}, {
            3.410872693471874, -3.9453912908180078`}, {
            3.528102080709993, -3.9453925148672924`}, {
            3.5367103257630905`, -3.9453926047501833`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.5575851676747954`, -3.9453928227146027`}, {
            3.645331467948112, -3.945393738916577}, {
            3.762560855186231, -3.945394962965862}, {
            3.8797902424243498`, -3.9453961870151466`}, {
            3.9970196296624683`, -3.945397411064431}, {
            4.114249016900587, -3.945398635113716}, {
            4.231478404138706, -3.9453998591630004`}, {
            4.2625505400446295`, -3.9454016959765528`}, {
            4.293622627002417, -3.9454036004709265`}, {
            4.392578843755034, -3.9454110985749495`}}]}, 
          {Arrowheads[{{0.014075467480279201`, 1.}}], 
           ArrowBox[{{4.413453685607951, -3.9454126803021095`}, {
            4.461019884979317, -3.9454162844850758`}, {
            4.628414827881272, -3.945431100349181}, {
            4.765039211859017, -3.945444588216852}, {
            4.901663595836762, -3.9454580760845226`}, {
            5.001099999999999, -3.9454678926708593`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.0009016647914490518, 1.}}], 
           ArrowBox[{{0.5006832096204847, -0.7676098807523131}, {
            0.5044176354621229, -0.7676098807524461}, {
            0.5100436356993031, -0.7676098807526464}, {
            0.519771808078554, -0.7676098807529925}, {
            0.53200706242452, -0.767609880753428}, {
            0.538327429580235, -0.7676098807536529}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.20058752917443728`, -1.9243650659837193`}, {
            0.32054107472148907`, -1.9243650659155596`}, {
            0.4404946202685408, -1.9243650658474}, {
            0.560448165815593, -1.9243650657792404`}, {
            0.6804017113626448, -1.9243650657110807`}, {
            0.8003552569096964, -1.9243650656429212`}, {
            0.9203088031314725, -1.9243650643830479`}, {
            1.0355812056881417`, -1.9243650631723408`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0564560476009843`, -1.9243650629530922`}, {
            1.160215895575025, -1.9243650618633015`}, {
            1.280169441796801, -1.9243650606034282`}, {
            1.4001229880185773`, -1.9243650593435548`}, {
            1.5200765342403533`, -1.9243650580836817`}, {
            1.6400300804621293`, -1.9243650568238084`}, {
            1.7599836266839057`, -1.9243650555639351`}, {
            1.8559464688201315`, -1.924365064242559}, {
            1.891449724114688, -1.9243650689079792`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.9123245660275303`, -1.9243650716511054`}, {
            1.9519093099824938`, -1.924365076852867}, {
            1.9615055939076622`, -1.9243650785848379`}, {
            1.97110187780756, -1.9243650803681767`}, {
            1.975420205548264, -1.9243650811986122`}, {
            2.0758638790816204`, -1.9243651006585285`}, {
            2.1763075487866277`, -1.924365126335202}, {
            2.2936181625846617`, -1.9243651645038804`}, {
            2.410928776382695, -1.9243652026725588`}, {
            2.528239390180729, -1.9243652408412373`}, {
            2.645550003978763, -1.9243652790099157`}, {
            2.7473182425411986`, -1.924365312121661}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7681930844540403`, -1.924365318913588}, {
            2.8801712315748307`, -1.9243653553472728`}, {
            2.9974818453728647`, -1.9243653935159513`}, {
            3.114792459170898, -1.9243654316846297`}, {
            3.145545586166866, -1.9243654525413187`}, {
            3.176298708470599, -1.924365472253152}, {
            3.308364769727708, -1.9243655140508074`}, {
            3.440430715049998, -1.9243654948552098`}, {
            3.447854309233636, -1.9243654935358923`}, {
            3.455277903020964, -1.924365491970753}, {
            3.4627014964091067`, -1.924365490154181}, {
            3.4701250893951965`, -1.9243654880804844`}, {
            3.4775486819763683`, -1.9243654857438945`}, {
            3.492395865501893, -1.924365479983916}, {
            3.507243047367741, -1.9243654730892186`}, {
            3.6031867609676036`, -1.9243653363051627`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.624061602880425, -1.9243653065445308`}, {
            3.6557146877644526`, -1.9243652614176834`}, {
            3.8041861289501036`, -1.9243648439021632`}, {
            3.9897739740454377`, -1.9243517497002423`}, {
            4.175361819140773, -1.924338655498321}, {
            4.360949664236108, -1.9243255612963999`}, {
            4.459055277763525, -1.924318639427608}}]}, 
          {Arrowheads[{{0.012483205474053414`, 1.}}], 
           ArrowBox[{{4.47993011962441, -1.9243171665973466`}, {
            4.546537509331442, -1.9243124670944787`}, {
            4.732125354426776, -1.9242993728925575`}, {
            4.917713199522111, -1.9242862786906363`}, {
            5.001099999999999, -1.9242803953117844`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.456150605837897}, {-4.897218074578924, 
            4.456126782498008}, {-4.780005744987659, 
            4.456099902083963}, {-4.662793415396394, 
            4.456073021669917}, {-4.5455810858051295`, 
            4.4560461412558725`}, {-4.428368756213865, 
            4.456019260841827}, {-4.397281609279529, 
            4.456016321723857}, {-4.366194415286717, 
            4.456013500627534}, {-4.196499483312455, 
            4.456001987241842}, {-4.166106339243788, 4.4560004428873}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231497357893, 
            4.455999382182399}, {-4.026804071856608, 
            4.455993364577507}, {-3.89106035918922, 
            4.456010318629865}, {-3.755316646521832, 
            4.456027272682222}, {-3.6195729338544425`, 
            4.45604422673458}, {-3.4838292211870545`, 
            4.4560611807869375`}, {-3.348085508519665, 
            4.456078134839295}, {-3.310237826586072, 
            4.4560828619207085`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893629848360466`, 
            4.456085469136564}, {-3.212341795852277, 
            4.456095088891653}, {-3.076598083184889, 
            4.45611204294401}, {-2.9408543705175, 
            4.456128996996368}, {-2.8051106578501113`, 
            4.456145951048725}, {-2.6693669451827224`, 
            4.456162905101083}, {-2.5336232325153345`, 
            4.45617985915344}, {-2.454369314835038, 4.456189757770794}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944730850125`, 
            4.4561923649866495`}, {-2.3978795198479466`, 
            4.456196813205797}, {-2.2621358071805577`, 
            4.456213767258155}, {-2.126392094513169, 
            4.456230721310512}, {-1.99064838184578, 
            4.45624767536287}, {-1.8549046691783913`, 
            4.4562646294152275`}, {-1.7191609565110033`, 
            4.456281583467585}, {-1.5985008030840038`, 
            4.456296653620879}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259613339785`, 
            4.456299260836736}, {-1.4476735311762257`, 
            4.4563154915723}, {-1.3119298185088368`, 
            4.456332445624658}, {-1.176186105841449, 
            4.456349399677015}, {-1.04044239317406, 
            4.456366353729373}, {-0.9046986805066721, 
            4.45638330778173}, {-0.7689549678392833, 
            4.456400261834087}, {-0.7426322913329698, 4.456403549470965}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574495829446, 
            4.45640615668682}, {-0.6332112551718945, 
            4.456417215886445}, {-0.49746754250450653`, 
            4.456434169938802}, {-0.3617238298371177, 
            4.45645112399116}, {-0.22598011716972888`, 
            4.4564680780435175`}, {-0.09023640450234005, 4.456485032095875}, {
            0.045507308165048777`, 4.456501986148233}, {0.11323622041806408`, 
            4.456510445321051}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1341110621680893, 4.4565130525369065`}, {
            0.1812510208324376, 4.45651894020059}, {0.31699473349982554`, 
            4.456535894252948}, {0.4527384461672135, 4.456552848305305}, {
            0.5884821588346023, 4.456569802357663}, {0.7242258715019916, 
            4.45658675641002}, {0.8599695841693804, 4.456603710462377}, {
            0.969104732169098, 4.456617341171136}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899795739191232, 4.456619948386992}, {
            0.9957132968367692, 4.456620664514735}, {1.1314570095041572`, 
            4.456637618567092}, {1.2672007221715451`, 4.45665457261945}, {
            1.4029444348389344`, 4.4566715266718075`}, {1.5386881475063232`, 
            4.456688480724165}, {1.6744318601737112`, 4.456705434776523}, {
            1.810175572841099, 4.45672238882888}, {1.8249732439201318`, 
            4.456724237021223}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458480856701571`, 4.456726844237078}, {
            1.945919285508488, 4.456739342881238}, {2.0816629981758767`, 
            4.456756296933595}, {2.217406710843265, 4.456773250985953}, {
            2.353150423510653, 4.45679020503831}, {2.488894136178042, 
            4.456807159090667}, {2.6246378488454307`, 4.456824113143025}, {
            2.6808417556711657`, 4.456831132871308}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.701716597421191, 4.456833740087164}, {
            2.760381561512819, 4.456841067195382}, {2.896125274180207, 
            4.45685802124774}, {3.031868986847596, 4.456874975300098}, {
            3.1676126995149847`, 4.456891929352455}, {3.3033564121823735`, 
            4.456908883404813}, {3.4391001248497624`, 4.45692583745717}, {
            3.5367102674221997`, 4.456938028721394}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.557585109172225, 4.45694063593725}, {
            3.5748438375171503`, 4.456942791509528}, {3.7105875501845387`, 
            4.4569597455618855`}, {3.8463312628519275`, 4.456976699614243}, {
            3.9820749755193163`, 4.4569936536666}, {4.117818688186706, 
            4.457010607718957}, {4.253562400854094, 4.457027561771315}, {
            4.389306113521483, 4.4570445158236724`}, {4.392578779173234, 
            4.457044924571479}}]}, 
          {Arrowheads[{{0.014075469583426314`, 1.}}], 
           ArrowBox[{{4.413453620923259, 4.457047531787334}, {
            4.525049826188872, 4.45706146987603}, {4.660793538856259, 
            4.457078423928388}, {4.781435797237687, 4.457123543971392}, {
            4.902078055619112, 4.457168664014396}, {5.001099999999999, 
            4.457205698088929}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.927930908679255}, \
{-4.981002195359007, -2.927933500408691}, {-4.770752591445119, \
-2.927960613324608}, {-4.5605029875312315`, -2.927987726240526}, \
{-4.350253383617344, -2.928014839156443}, {-4.166106330429105, \
-2.9280385859958025`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.1452314886898325`, -2.928041277928716}, \
{-4.140003779703456, -2.9280419520723604`}, {-3.929754175789568, \
-2.928069064988278}, {-3.71950457187568, -2.9280961779041954`}, \
{-3.509254967961792, -2.9281232908201127`}, {-3.310237819118938, \
-2.928148955245264}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2893629773796653`, -2.928151647178178}, \
{-3.088755760134016, -2.9281775166519477`}, {-2.878506156220129, \
-2.9282046295678654`}, {-2.6932265884313855`, -2.9282039104895334`}, \
{-2.507947020642642, -2.928203191411202}, {-2.4543693042853496`, \
-2.928202983473676}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.433494462372664, -2.928202902457476}, \
{-2.3226674528538984`, -2.92820247233287}, {-2.1373878850651553`, \
-2.9282017532545384`}, {-1.9521082980859117`, -2.9282017431371}, \
{-1.766828711106668, -2.9282017330196615`}, {-1.5985007858611908`, \
-2.928201723827891}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259439483482`, -2.9282017226879926`}, \
{-1.396269537148181, -2.9282017127847846`}, {-1.3221577803244997`, \
-2.9282017413630363`}, {-1.2480460284771229`, -2.928201767395135}, \
{-1.2406348537216907`, -2.9282017697121474`}, {-1.2298886504037936`, \
-2.9282017730125776`}, {-1.1635678690229376`, -2.9282017930911834`}, \
{-1.0972470904476543`, -2.9282018107222316`}, {-0.978092671576665, \
-2.9282018379580803`}, {-0.8589382527056757, -2.928201865193929}, \
{-0.7426322674346697, -2.928201891778694}}]}, 
          {Arrowheads[{{0.01662018902975848, 1.}}], 
           ArrowBox[{{-0.7217574255218276, -2.928201896550183}, \
{-0.620629414963697, -2.9282019196656264`}, {-0.5014749960927076, \
-2.928201946901475}, {-0.3823205772217182, -2.9282019741373237`}, \
{-0.2631661583507289, -2.9282020013731724`}, {-0.14401173947973955`, \
-2.928202028609021}, {-0.12063939477488511`, -2.9282020283485997`}, \
{-0.09726705005436981, -2.9282020281244603`}, {-0.0625684192365261, \
-2.9282020279439163`}, {-0.02786978840630431, -2.928202027862447}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.24630354200686072`, -2.927701048910254}, \
{-0.23204388340705534`, -2.9277010486863437`}, {-0.22855026704767328`, \
-2.927701048632929}, {-0.1920110401341049, -2.9277010480768935`}, \
{-0.1554718131649948, -2.9277010475733016`}, {-0.037424215928939075`, \
-2.9277010461765824`}, {0.08062338130711655, -2.9277010447798633`}, {
            0.19867097854317217`, -2.9277010433831436`}, {
            0.3167185757792279, -2.9277010419864244`}, {
            0.43476617301528364`, -2.9277010405897053`}, {
            0.5528137702513394, -2.927701039192986}, {
            0.5886901345068437, -2.927701038768503}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.6095649764196863, -2.927701038521515}, {
            0.670861367487395, -2.927701037796267}, {
            0.7889089647234507, -2.9277010363995477`}, {
            0.8167085590534127, -2.927701034274006}, {
            0.8445081534910954, -2.927701031835934}, {
            0.9028366234738741, -2.927701024475622}, {
            0.961165094377701, -2.9277010154335357`}, {
            0.9653320341484083, -2.92770101478163}, {
            0.9823399516797278, -2.9277010119591256`}, {
            0.9993478693098191, -2.927701008984638}, {
            1.1694270591918259`, -2.927700963252955}, {
            1.3395062702282703`, -2.9277009021302787`}, {
            1.4445586529318635`, -2.927701465035609}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4654334948444063`, -2.9277015768899}, {
            1.552105346737812, -2.9277020413062815`}, {
            1.7647044232473537`, -2.9277031804822844`}, {
            1.9773034997568955`, -2.9277043196582873`}, {
            2.1899025762664373`, -2.92770545883429}, {
            2.3004271713461235`, -2.92770605106154}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.3213020132586664`, -2.9277061629158307`}, {
            2.4025016527759786`, -2.9277065980102925`}, {
            2.6151007292855204`, -2.9277077371862954`}, {
            2.8276998057950617`, -2.9277088763622983`}, {
            3.0402988823046035`, -2.927710015538301}, {
            3.1562956897469916`, -2.9277118845462113`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.1771705316571244`, -2.9277122208937842`}, {
            3.252886050489425, -2.927713440866185}, {
            3.465473218674246, -2.927716866194069}, {
            3.678060386859067, -2.927720291521953}, {
            3.890647555043888, -2.9277237168498367`}, {
            4.0121642080624405`, -2.927725674796704}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.033039049972573, -2.927726011144277}, {
            4.103234723228709, -2.9277271421777207`}, {
            4.31582189141353, -2.9277305675056047`}, {
            4.528409059598351, -2.9277339928334882`}, {
            4.740996227783173, -2.9277374181613722`}, {
            4.868032676659393, -2.9276250067977605`}}]}, 
          {Arrowheads[{{0.0026872666627196077`, 1.}}], 
           ArrowBox[{{4.888907510399703, -2.9276065351815697`}, {
            4.944828148414155, -2.9275570524132077`}, {
            5.001099999999999, -2.927507258864776}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.841079400609472}, {-4.974086492440059, 
            4.841068422942863}, {-4.8499992772335805`, 
            4.84101799675974}, {-4.725912062027101, 
            4.840967570576618}, {-4.601824846820621, 
            4.8409171443934955`}, {-4.477737631614142, 
            4.840866718210373}, {-4.353650416407662, 
            4.840816292027251}, {-4.229563201201183, 
            4.840765865844128}, {-4.16610639243264, 4.840740078460198}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.145231552243456, 
            4.840731595406465}, {-4.105475985994702, 
            4.840715439661005}, {-3.9813887707882225`, 
            4.840665013477882}, {-3.857301555581743, 
            4.84061458729476}, {-3.733214340375264, 
            4.8405641611116375`}, {-3.6091271251687838`, 
            4.840513734928515}, {-3.485039909962304, 
            4.8404633087453925`}, {-3.3609526947558246`, 
            4.84041288256227}, {-3.3102379446760977`, 4.840392273257192}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.2893631044869136`, 
            4.84038379020346}, {-3.2368654795493454`, 
            4.840362456379148}, {-3.1127782643428654`, 
            4.840312030196025}, {-2.988691049136386, 
            4.840261604012903}, {-2.8646038339299063`, 
            4.84021117782978}, {-2.7405166187234267`, 
            4.840160751646658}, {-2.616429403516947, 
            4.840110325463535}, {-2.492342188310467, 
            4.840059899280413}, {-2.454369496919555, 4.840044468054186}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.433494656730371, 
            4.840035985000454}, {-2.368254973103988, 
            4.8400094730972905`}, {-2.2441677578975083`, 
            4.839959046914168}, {-2.1200805426910287`, 
            4.8399086207310456`}, {-1.9959933274845487`, 
            4.839858194547923}, {-1.8719061122780687`, 
            4.839807768364801}, {-1.7864904187059634`, 
            4.8398088606480565`}, {-1.7010748369744788`, 
            4.839809827988525}, {-1.5985010266051243`, 
            4.8398108416388945`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776261846933008`, 
            4.839811047927333}, {-1.4647189809184618`, 
            4.839812163693907}, {-1.3465410528904531`, 
            4.8398133315465985`}, {-1.2283631248624445`, 
            4.8398144993992895`}, {-1.1101851968344358`, 
            4.8398156672519805`}, {-0.9920072688064274, 
            4.8398168351046715`}, {-0.8738293407784189, 
            4.839818002957363}, {-0.7556514127504104, 
            4.839819170810054}, {-0.7426325082197331, 4.839819165685149}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217576663068924, 
            4.839819156850724}, {-0.7011309985126785, 
            4.839819146812417}, {-0.6473365086076092, 
            4.839819109174264}, {-0.5935420140985348, 
            4.839819066619019}, {-0.589297210934999, 
            4.839819063237318}, {-0.5850524077423006, 
            4.8398190598328314`}, {-0.5808076045204033, 
            4.83981905640653}, {-0.5765628012692756, 
            4.839819052959381}, {-0.5723179979888915, 
            4.839819049492344}, {-0.5638283913109816, 
            4.839819042484438}, {-0.555338784515844, 
            4.839819035410257}, {-0.47044270497039004`, 
            4.839818962005424}, {-0.3855466145654599, 
            4.839818892470787}, {-0.1733064133650185, 4.839819075768348}, {
            0.038933787835422784`, 4.8398192590659095`}, {
            0.11323601020652056`, 4.839819323235732}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1341108521193554, 4.839819341263926}, {
            0.25117398903586413`, 4.83981944236347}, {0.4634141902363055, 
            4.839819625661031}, {0.6756543893165091, 4.839818755896503}, {
            0.8878945883967131, 4.839817886131974}, {0.9691045286286908, 
            4.839817553332035}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899793705413581, 4.839817467786521}, {
            1.1001347874769172`, 4.839817016367446}, {1.312374986557121, 
            4.839816146602918}, {1.448021341234762, 4.8398159232790805`}, {
            1.5836676959124034`, 4.839815699955243}, {1.7193140505900448`, 
            4.839815476631405}, {1.8249730470516607`, 4.839815302677798}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.8458478889644752`, 4.839815268310123}, {
            1.8549604052676862`, 4.839815253307567}, {1.9906067599453277`, 
            4.839815029983729}, {2.126253114622969, 4.839814806659891}, {
            2.2618994693006105`, 4.839814583336054}, {2.397545823978252, 
            4.839814360012216}, {2.5331921786558933`, 4.8398141366883785`}, {
            2.6688385333335347`, 4.839813913364541}, {2.680841565477048, 
            4.839813893603131}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{2.701716407389862, 4.8398138592354565`}, {
            2.804484888011176, 4.839813690040703}, {2.9401312426888175`, 
            4.8398134667168655`}, {3.075777597366459, 4.839813243393028}, {
            3.2114239520441004`, 4.83981302006919}, {3.3470703067217418`, 
            4.839812796745353}, {3.482716661399383, 4.839812573421515}, {
            3.5367100804000313`, 4.839832021336846}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.5575849209587527`, 4.839839540255619}, {
            3.6183426271657275`, 4.839861424602786}, {3.7539685929320696`, 
            4.8399102757840575`}, {3.8895945586984126`, 4.839959126965328}, {
            4.025220524464756, 4.8400079781466}, {4.1608464902310995`, 
            4.840056829327871}, {4.296472455997442, 4.840105680509143}, {
            4.3925785433076, 4.840140297006551}}]}, 
          {Arrowheads[{{0.01407547555825925, 1.}}], 
           ArrowBox[{{4.4134533838663215`, 4.840147815925324}, {
            4.4320984217637855`, 4.8401545316904135`}, {4.567724387530129, 
            4.840203382871685}, {4.703350353296472, 4.840252234052956}, {
            4.838976319062816, 4.840301085234228}, {4.9746022848291584`, 
            4.840349936415499}, {5.001099999999999, 4.840359480640159}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -2.5489724918471746`}, \
{-4.974871919439763, -2.548974053387846}, {-4.846221154404888, \
-2.548981712865693}, {-4.717570389370012, -2.5489893723435397`}, \
{-4.588919624335136, -2.548997031821387}, {-4.460268859300261, \
-2.5490046912992335`}, {-4.3316180942653855`, -2.5490123507770805`}, \
{-4.20296732923051, -2.549020010254927}, {-4.166106324966176, \
-2.5490222048477498`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.14523148309033, -2.5490234476727642`}, \
{-4.074316564195635, -2.5490276697327743`}, {-3.945665799160758, \
-2.549035329210621}, {-3.8170150341258817`, -2.549042988688468}, \
{-3.6883642690910063`, -2.5490506481663147`}, {-3.5597135040561305`, \
-2.5490583076441617`}, {-3.431062739021255, -2.549065967122009}, \
{-3.310237808056507, -2.54907316067334}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.2893629661806614`, -2.5490744034983543`}, \
{-3.173761208951504, -2.5490812860777026`}, {-3.0451104439166286`, \
-2.549088945555549}, {-2.916459678881752, -2.5490966050333963`}, \
{-2.7878089138468756`, -2.549104264511243}, {-2.659158148812, \
-2.54911192398909}, {-2.530507383777125, -2.5491195834669367`}, \
{-2.454369291146838, -2.5491241164989296`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334944492709925`, -2.549125359323944}, \
{-2.401856618742249, -2.5491272429447838`}, {-2.2732058537073736`, \
-2.5491349024226304`}, {-2.144555088672498, -2.5491425619004775`}, \
{-2.0159043236376224`, -2.549150221378324}, {-1.887253558602747, \
-2.5491578808561712`}, {-1.7586027935678716`, -2.5491655403340183`}, \
{-1.6299520285329958`, -2.549173199811865}, {-1.5985007742371689`, \
-2.5491750723245197`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.5776259323613233`, -2.549176315149534}, \
{-1.5013012634981204`, -2.549180859289712}, {-1.3726504984632442`, \
-2.5491885187675587`}, {-1.2439997334283674`, -2.549196178245406}, \
{-1.1153489683934916`, -2.5492038377232524`}, {-0.9866982033586167, \
-2.5492114972010995`}, {-0.8580474383237409, -2.549219156678946}, \
{-0.7426322573274997, -2.5492260281501093`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574154516542, -2.549227270975124}, \
{-0.6007459082539901, -2.54923447563464}, {-0.4720951432191143, \
-2.549242135112487}, {-0.34344437818423756`, -2.5492497945903336`}, \
{-0.21479361314936174`, -2.5492574540681807`}, {-0.08614284811448591, \
-2.5492651135460274`}, {0.04250791692038902, -2.5492727730238744`}, {
            0.11323625958216937`, -2.549276983975699}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411110145801497`, -2.5492782268007135`}, {
            0.17115868195526485`, -2.5492804325017215`}, {
            0.29980944699014067`, -2.549288091979568}, {
            0.4284602120250156, -2.5492957514574153`}, {
            0.5571109770598923, -2.549303410935262}, {
            0.6857617420947681, -2.549311070413109}, {
            0.8144125071296431, -2.5493187298909556`}, {
            0.9430632721645198, -2.5493263893688027`}, {
            0.9691047764918385, -2.549327939801289}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.989979618367684, -2.5493291826263036`}, {
            1.0717140371993956`, -2.5493340488466494`}, {
            1.2003648022342706`, -2.5493417083244965`}, {
            1.3290155672691464`, -2.549349367802343}, {
            1.4576663323040222`, -2.54935702728019}, {
            1.586317097338898, -2.549364686758037}, {
            1.7149678623737739`, -2.549372346235884}, {
            1.8249732934015075`, -2.549378895626879}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.845848135277353, -2.5493801384518933`}, {
            1.9722693924435255`, -2.5493876651915777`}, {
            2.1009201574784013`, -2.5493953246694248`}, {
            2.229570922513277, -2.5494029841472714`}, {
            2.358221687548152, -2.5494106436251185`}, {
            2.486872452583028, -2.549418303102965}, {
            2.6155232176179037`, -2.549425962580812}, {
            2.6808418103111764`, -2.5494298514524685`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716652187022, -2.549431094277483}, {
            2.7441739826527787`, -2.549433622058659}, {
            2.8705692341701825`, -2.549433906690934}, {
            2.996964427463189, -2.5494342638729623`}, {
            3.1142105134949665`, -2.5494346679098716`}, {
            3.2314565995267435`, -2.5494350719467804`}, {
            3.348702685558521, -2.5494354759836897`}, {
            3.4659487715902983`, -2.5494358800205985`}, {
            3.536710328621448, -2.5494361238690866`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.557585170534167, -2.54943619580502}, {
            3.5831948576220753`, -2.5494362840575078`}, {
            3.700440943653853, -2.5494366880944166`}, {
            3.8176870296856302`, -2.549437092131326}, {
            3.9349331157174077`, -2.549437496168235}, {
            3.965940187280601, -2.5494377012618386`}, {
            3.9969472343245447`, -2.549437904148395}, {
            4.154963853810903, -2.5494387853069904`}, {
            4.312979629163128, -2.549439400696213}, {
            4.39257881246565, -2.5493652098473247`}}]}, 
          {Arrowheads[{{0.01407547449687257, 1.}}], 
           ArrowBox[{{4.413453645311226, -2.54934575334658}, {
            4.426638312777182, -2.5493334645060286`}, {
            4.540296996391236, -2.5492275283158445`}, {
            4.65395568000529, -2.5491215921256605`}, {
            4.767614363619344, -2.5490156559354764`}, {
            4.881273047233398, -2.5489097197452923`}, {
            4.994931730847453, -2.5488037835551083`}, {
            5.001099999999999, -2.5487980343865164`}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.001099999999999, -3.3056400000054045`}, \
{-4.9911923340527276`, -3.305640078665439}, {-4.867186038835182, \
-3.305641063189899}, {-4.743179743617636, -3.305642047714359}, \
{-4.61917344840009, -3.305643032238819}, {-4.495167153182544, \
-3.3056440167632792`}, {-4.371160857964999, -3.3056450012877394`}, \
{-4.247154562747453, -3.305645985812199}, {-4.166106323512611, \
-3.305646629279322}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.145231481600426, -3.3056467950111696`}, \
{-4.123148267529908, -3.3056469703366593`}, {-3.999141972312361, \
-3.3056479548611195`}, {-3.875135677094814, -3.3056489393855797`}, \
{-3.7511293818772686`, -3.3056499239100394`}, {-3.6271230866597226`, \
-3.3056509084344996`}, {-3.503116791442177, -3.30565189295896}, \
{-3.379110496224631, -3.3056528774834195`}, {-3.3102378051130374`, \
-3.3056534242850875`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-3.2893629632008525`, -3.3056535900169353`}, \
{-3.2551042010070854`, -3.3056538620078797`}, {-3.13109790578954, \
-3.30565484653234}, {-3.007091610571994, -3.3056558310568}, \
{-2.8830853153544482`, -3.30565681558126}, {-2.759079020136902, \
-3.30565780010572}, {-2.6350727249193566`, -3.30565878463018}, \
{-2.5110664297018097`, -3.3056597691546403`}, {-2.454369286713464, \
-3.305660219290853}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.433494444801279, -3.305660385022701}, \
{-2.3870601344842632`, -3.3056607536791}, {-2.2630538392667177`, \
-3.3056617382035602`}, {-2.1390475440491716`, -3.3056627227280204`}, \
{-2.0150412488316274`, -3.30566370725248}, {-1.8165807821228133`, \
-3.3056639154375707`}, {-1.618120315413998, -3.305664123622661}, \
{-1.5985007683009917`, -3.305664144203572}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776259263881607`, -3.3056641661012875`}, \
{-1.419659848705183, -3.3056643318077517`}, {-1.2211993819963682`, \
-3.305664539992842}, {-1.0227389152875537`, -3.3056647481779327`}, \
{-0.8242784485787387, -3.305664956363023}, {-0.7426322498749158, \
-3.3056650420099105`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217574079620848, -3.305665063907626}, \
{-0.6258179818699241, -3.3056651645481137`}, {-0.4273575151611093, \
-3.3056653727332046`}, {-0.22889746249399828`, -3.3056653655181423`}, \
{-0.03043740982688725, -3.30566535830308}, {
            0.11323626855145719`, -3.305665353079789}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411111046429977`, -3.305665352320879}, {
            0.16802264284022428`, -3.305665351088017}, {
            0.36648269550733525`, -3.305665343872955}, {
            0.5649427481744463, -3.3056653366578925`}, {
            0.7634028008415576, -3.30566532944283}, {
            0.9618628535086688, -3.305665322227768}, {
            0.9691047869780036, -3.3056653219644856`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{0.9899796288908462, -3.3056653212055758`}, {
            1.16032290617578, -3.3056653150127056`}, {
            1.3190909748053063`, -3.3056652362104244`}, {
            1.477859071809777, -3.3056651251051687`}, {
            1.4937358856032599`, -3.305665110863287}, {
            1.5096126998796187`, -3.3056650963318557`}, {
            1.5175511072660743`, -3.3056650889245662`}, {
            1.5254895147792356`, -3.305665081447782}, {
            1.5334279224208123`, -3.3056650739024165`}, {
            1.5413663301925156`, -3.3056650662894196`}, {
            1.5493047380960578`, -3.3056650586097778`}, {
            1.6353636397683442`, -3.3056649746447175`}, {
            1.721422558328713, -3.305664883791607}, {
            1.824973305404308, -3.305664768467681}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458481473171378`, -3.3056647452194787`}, {
            1.956147087699148, -3.3056646223801254`}, {
            2.0735093523843657`, -3.3056644916743845`}, {
            2.190871617069583, -3.3056643609686436`}, {
            2.3082338817548007`, -3.3056642302629027`}, {
            2.425596146440018, -3.3056640995571622`}, {
            2.5429584111252357`, -3.3056639688514213`}, {
            2.660320675810453, -3.30566383814568}, {
            2.680841823830303, -3.3056638753867684`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.7017166657431058`, -3.30566391619922}, {
            2.7213982423292022`, -3.3056639572271656`}, {
            2.8390792027495975`, -3.305664381489356}, {
            2.9567601587501997`, -3.3056649784775503`}, {
            3.1275790738807245`, -3.3054888857184554`}, {
            3.2983979890112494`, -3.3053127929593606`}, {
            3.469216904141775, -3.3051367002002654`}, {
            3.536710034097922, -3.3050671232950095`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.557584864918916, -3.305045603977011}, {
            3.640035819272301, -3.3049606074411706`}, {
            3.8108547344028256`, -3.3047845146820753`}, {
            3.9816736495333513`, -3.3046084219229805`}, {
            4.152492564663876, -3.3044323291638857`}, {
            4.323311479794402, -3.3042562364047905`}, {
            4.392578097758678, -3.3041848312570576`}}]}, 
          {Arrowheads[{{0.014075493029369217`, 1.}}], 
           ArrowBox[{{4.413452928579672, -3.304163311939059}, {
            4.494130394924927, -3.3040801436456957`}, {
            4.664949310055452, -3.3039040508866004`}, {
            4.835768225185977, -3.3037279581275056`}, {
            5.001099999999999, -3.30355752191808}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.02000000000000001, 1.}}], 
           ArrowBox[{{-5.001099999999999, -4.844303278278376}, \
{-4.877752324149532, -4.844264488475657}, {-4.683817328790809, \
-4.844203500701395}, {-4.489882333432087, -4.844142512927134}, \
{-4.295947338073365, -4.844081525152872}, {-4.166106364774533, \
-4.844040693368208}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231523893897, -4.844034128745454}, \
{-4.102012342714643, -4.844020537378611}, {-3.9080773473559196`, \
-4.84395954960435}, {-3.7141423519971966`, -4.8438985618300885`}, \
{-3.5202073566384744`, -4.8438375740558275`}, {-3.3262723612797522`, \
-4.843776586281566}, {-3.3102378886684316`, -4.843771543835285}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.289363047787795, -4.843764979212531}, \
{-3.132337365921029, -4.843715598507305}, {-2.9384023705623066`, \
-4.843654610733044}, {-2.7444673752035844`, -4.843593622958782}, \
{-2.5505323798448623`, -4.843532635184521}, {-2.4543694125623294`, \
-4.843502394302363}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334945716816927`, -4.843495829679609}, \
{-2.356597384486139, -4.84347164741026}, {-2.2567657951593967`, \
-4.8434736696433065`}, {-2.1569344983451813`, -4.843475566982523}, \
{-2.0391125868568, -4.843477636016637}, {-1.9212906753684182`, \
-4.843479705050751}, {-1.8034687638800366`, -4.843481774084865}, \
{-1.6856468523916552`, -4.84348384311898}, {-1.5985008990949676`, \
-4.843485373462088}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-1.5776260571853438`, -4.843485740038725}, \
{-1.5678249409032736`, -4.843485912153094}, {-1.450003029414892, \
-4.8434879811872085`}, {-1.3321811179265106`, -4.843490050221322}, \
{-1.2143592064381288`, -4.843492119255437}, {-1.1856710729488014`, \
-4.843492203972892}, {-1.1569829414318848`, -4.843492279788569}, \
{-1.0887731584125067`, -4.843492395264728}, {-1.0205633786358614`, \
-4.843492471451564}, {-1.013102718304893, -4.843492479349584}, \
{-1.0056420579885819`, -4.843492486819325}, {-0.99818139768325, \
-4.843492493867682}, {-0.990720737385293, -4.84349250050156}, \
{-0.9832600770911701, -4.843492506727824}, {-0.968338756497578, \
-4.843492517591045}, {-0.9534174358719978, -4.843492526919733}, \
{-0.804204214186047, -4.843492496464193}, {-0.7426323807280582, \
-4.843492454061036}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217575388152205, -4.843492439684995}, \
{-0.6549909620991634, -4.843492393704335}, {-0.46847444130238447`, \
-4.843492403347682}, {-0.28195792050560553`, -4.843492412991028}, \
{-0.09544139970882648, -4.843492422634375}, {
            0.09107512108795246, -4.8434924322777215`}, {
            0.11323613769846705`, -4.843492433423498}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411097961130963`, -4.843492434502777}, {
            0.2775916418847315, -4.843492441921067}, {
            0.4641081626815105, -4.843492451564414}, {
            0.6506246834782895, -4.84349246120776}, {
            0.8371412042750686, -4.843492470851107}, {
            0.9691046560987874, -4.843489839946918}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.9899794980074814, -4.843489423773287}, {
            1.0236608200140986`, -4.843488752281825}, {
            1.2101804357531283`, -4.843485033712542}, {
            1.3967000514921581`, -4.8434813151432605`}, {
            1.5832196672311882`, -4.843477596573978}, {
            1.7697392829702183`, -4.843473878004695}, {
            1.8249731743552438`, -4.843472776828012}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.845848016263938, -4.84347236065438}, {
            1.9562588987092482`, -4.843470159435412}, {
            2.142778514448278, -4.8434664408661305`}, {
            2.329298130187308, -4.843462722296848}, {
            2.445843882917644, -4.843516302823017}, {
            2.562389635647979, -4.843569883349186}, {
            2.678935388378314, -4.843623463875355}, {
            2.6808416555305965`, -4.843624340259047}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716495237395, -4.8436339372187724`}, {
            2.795481141108649, -4.843677044401524}, {
            2.912026893838984, -4.8437306249276935`}, {
            3.028572646569318, -4.843784205453862}, {
            3.1451183992996525`, -4.843837785980031}, {
            3.261664152029988, -4.8438913665062}, {
            3.378209904760323, -4.843944947032369}, {
            3.4947556574906575`, -4.843998527558538}, {
            3.536710083509338, -4.844017815607811}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5575849232161363`, -4.844027412567536}, {
            3.611301410220992, -4.844052108084707}, {
            3.7278471629513272`, -4.844105688610877}, {
            3.8443929156816625`, -4.844159269137045}, {
            3.9609386684119965`, -4.844212849663214}, {
            4.077484421142331, -4.844266430189384}, {
            4.194030173872666, -4.844320010715553}, {
            4.3105759266030015`, -4.844373591241721}, {
            4.39257851148808, -4.844411290956575}}]}, 
          {Arrowheads[{{0.014075476915248714`, 1.}}], 
           ArrowBox[{{4.413453351194878, -4.844420887916302}, {
            4.427121679333336, -4.844427171767891}, {
            4.54366743206367, -4.84448075229406}, {
            4.660213184794006, -4.844534332820229}, {
            4.776758937524341, -4.844587913346398}, {
            4.893304690254675, -4.844641493872567}, {
            5.001099999999999, -4.84469105148646}}]}}, 
         {RGBColor[1, 0, 0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.001099999999999, 
            4.072916372947976}, {-4.914854305982432, 
            4.072906422826221}, {-4.7504667921218715`, 
            4.072889260631039}, {-4.586074963565528, 
            4.072873901046569}, {-4.4216788203133985`, 
            4.072860344072811}, {-4.2572783623654855`, 
            4.072848589709764}, {-4.166106326819914, 4.072843070882646}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.145231484945316, 
            4.072841807286383}, {-4.092873589721789, 
            4.072838637957429}, {-3.9284645023823055`, 
            4.072830488815805}, {-3.7640511003470385`, 
            4.072824142284894}, {-3.6001856646763875`, 
            4.072588864193598}, {-3.435765790597445, 
            4.072585221578754}, {-3.310237977829268, 4.072582440592108}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.2893631359215485`, 
            4.07258197812363}, {-3.2713459165185013`, 
            4.07258157896391}, {-3.1069260424395573`, 
            4.072577936349066}, {-2.9425061683606146`, 
            4.072574293734221}, {-2.778086294281672, 
            4.072570651119378}, {-2.613666420202728, 
            4.072567008504533}, {-2.454369459612758, 4.07256347938449}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.4334946177050383`, 
            4.072563016916011}, {-2.284826672044842, 
            4.072559723274845}, {-2.1204067979658987`, 
            4.072556080660001}, {-1.9559869238869554`, 
            4.072552438045157}, {-1.7915670498080125`, 
            4.072548795430313}, {-1.6271471757290694`, 
            4.072545152815469}, {-1.5985009413962477`, 4.07254451817687}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.5776260994885278`, 
            4.072544055708391}, {-1.4627273016501259`, 
            4.072541510200625}, {-1.2983074275711832`, 
            4.072537867585781}, {-1.1338875534922401`, 
            4.072534224970937}, {-0.969467679413297, 
            4.072530582356093}, {-0.7627886873430203, 
            4.072530705060196}, {-0.7426324231241102, 4.072530717026852}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.7217575812112712, 
            4.072530729420123}, {-0.556109695272743, 
            4.072530827764299}, {-0.34943070320246583`, 
            4.072530950468403}, {-0.1427517111321891, 4.072531073172506}, {
            0.06392732441521506, 4.072531049741192}, {0.11323609530232946`, 
            4.07253104415103}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13411093721517192`, 4.072531041784438}, {
            0.2706063599626192, 4.072531026309878}, {0.4772853955100236, 
            4.072531002878564}, {0.6839644310574275, 4.07253097944725}, {
            0.7666360266766988, 4.072530982798143}, {0.8493076206562252, 
            4.072530975110942}, {0.857574780030089, 4.072530972903378}, {
            0.8658419394109785, 4.0725309705331565`}, {0.8699755191058877, 
            4.0725309692650065`}, {0.8741090988033934, 4.072530967954694}, {
            0.8782426785037425, 4.072530966601792}, {0.8823762582071848, 
            4.072530965205874}, {0.8865098379139731, 4.07253096376651}, {
            0.950194270392944, 4.072530940914873}, {0.9691046137288637, 
            4.072530930789739}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.9899794556417033, 4.072530919612757}, {
            1.0138787042582997`, 4.0725309068164215`}, {1.1313705590132308`, 
            4.0725308203005826`}, {1.248862413768162, 4.072530733784743}, {
            1.3663542685230932`, 4.072530647268904}, {1.4838461232780242`, 
            4.072530560753065}, {1.6013379780329555`, 4.072530474237225}, {
            1.7188298327878866`, 4.072530387721386}, {1.8249731321551843`, 
            4.072530309562125}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.8458479740680214`, 4.072530294190808}, {
            1.9538135422977487`, 4.072530214689708}, {1.983826331721027, 
            4.072530059103717}, {2.0138391297054916`, 4.072529900149527}, {
            2.109145186949955, 4.072529360128469}, {2.2044513492173428`, 
            4.07252880582268}, {2.3552693831195803`, 4.072549338985542}, {
            2.506087417021819, 4.072569872148405}, {2.6569054509240564`, 
            4.072590405311267}, {2.6808416461626554`, 4.072593664111176}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.701716487882035, 4.072596506122265}, {
            2.807723484826294, 4.0726109384741305`}, {2.9585415187285324`, 
            4.072631471636993}, {3.10935955263077, 4.072652004799855}, {
            3.2601775865330076`, 4.072672537962718}, {3.4109956204352456`, 
            4.07269307112558}, {3.5367101566572114`, 4.07271018656582}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.557584998376591, 4.072713028576909}, {
            3.561813654337483, 4.072713604288443}, {3.7126316882397212`, 
            4.072734137451305}, {3.863449722141959, 4.0727546706141675`}, {
            4.014267756044196, 4.072775203777031}, {4.165085789946435, 
            4.072795736939893}, {4.315903823848672, 4.072816270102756}, {
            4.392578667151768, 4.0728267090204655`}}]}, 
          {Arrowheads[{{0.01407547178150105, 1.}}], 
           ArrowBox[{{4.4134535088711475`, 4.072829551031554}, {
            4.46672185775091, 4.072836803265618}, {4.6175398916531485`, 
            4.072857336428481}, {4.768357925555386, 4.072877869591343}, {
            4.919175959457624, 4.0728984027542054`}, {5.001099999999999, 
            4.072909556325322}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(inc\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(inc\\)]\\)}\"", 
          TraditionalForm]}}], {972., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[{
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAivu/N8H07789RAwvnwI0P7A0HlHu
1O+/2IvoFMH0Mz9AIvwt1bfvvzy4KBka6DM/tME+tN2H77+CArdQTtMzP8DM
YCtJNO+/LFTN+ECvMz8MNkWUd/buv9R+YDa1lDM/VsGS1DGm7r+DIrULZXIz
P6xUcjFpRO6/uMrfYcZIMz8MPhSgnYnsv3zXg4UQjDI/W1r1fvOj67/3Ou0e
yikyP36dUYSjw+q/TvneZJDJMT9qJW2tiejpvz2zjRNWazE/st+QjoMS6b9D
J/SFDg8xP6GTzIJO6Oi/Imy1kdT8MD8Ao+K4SL7ov/sIksas6jA/8YQi+eKe
6L9oFWGwGt0wP/CRYZVB4+K/KjuGI9q4LD9cZsOavS3cv/wj+PiVcSg/UdiK
7jon1L/RW23kNckkP/pCG1W04cq/TyzfEQmoIT9OAXTq1vfEvw6aykYjQCA/
YTeu2g==
            "]]}, 
          {Arrowheads[{{0.010544751997785118`, 1.}}], 
           ArrowBox[{{-0.14294311613699778`, 
            0.00011911717877177456`}, {-0.09320758927424688, 
            0.00010737944659803445`}, {-0.04494082589125085, 
            0.0000957967522340497}, {-0.022335177998380692`, 
            0.00009032341263731426}, {-0.0011664340775211282`, 
            0.00008515178673044452}, {0.019280407732672682`, 
            0.00008006764706148876}, {0.03837139432533407, 
            0.00007527831567678839}, {0.07400155140970965, 
            0.00006625886128033216}, {0.1048606596373046, 
            0.000058294700296142427`}, {0.13156879515356293`, 
            0.00005126693693679098}, {0.1907501628154638, 
            0.000035072591833070126`}, {0.2293876265424882, 
            0.000023905999698713255`}, {0.2544397187612071, 
            0.000016251755899779352`}, {0.2704353802976876, 
            0.00001104548729006922}, {0.28249315857086016`, 
            6.8484148920488736`*^-6}, {0.2895412151741145, 
            4.2292346582484596`*^-6}, {0.29357600310404863`, 
            2.608060578916319*^-6}, {0.29720211708096234`, 
            9.653937789357664*^-7}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.016552562890384898`, 1.}}], 
           ArrowBox[{{0.424559650949201, 0.9053928928613812}, {
            0.42287612583299516`, 0.8929735752003614}, {0.4197093888364043, 
            0.8713984396249185}, {0.4154039661194552, 0.8436729331629791}, {
            0.4130766027500175, 0.8288762696849606}, {0.4107988782521288, 
            0.8143621322648302}, {0.4041366872393153, 0.7715280967395898}, {
            0.39789110770978153`, 0.731099472197793}, {0.3861736509916492, 
            0.6547280251325717}, {0.37589709266448956`, 0.5867586463558506}, {
            0.36686701363309343`, 0.5261479906286815}, {0.34773794454426876`, 
            0.39414216300325877`}, {0.3339964112063471, 
            0.29556542137819214`}, {0.3241228853904461, 
            0.22183389920631846`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.018942463333020933`, 1.}}], 
           ArrowBox[{{-0.4470667457948534, 
            0.8992702546819025}, {-0.4440744806034279, 
            0.8959919058694746}, {-0.4397236367077183, 
            0.8912898739540357}, {-0.43143363238472765`, 
            0.8824650024886308}, {-0.4169923388083052, 
            0.8671987921620612}, {-0.40821361801862427`, 
            0.8579359251986741}, {-0.3988246825736373, 
            0.848026152232453}, {-0.36145271056032063`, 
            0.8085188506773382}, {-0.3210562015973029, 
            0.7651854368450378}, {-0.28314843854905913`, 
            0.7242047096112215}, {-0.17162254575740257`, 
            0.6021316372158582}, {-0.08140512464228342, 
            0.5006078539903748}, {-0.008319763189867865, 
            0.4160360240562348}, {0.07987060934587317, 
            0.31002195567295615`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019545549541172026`, 1.}}], 
           ArrowBox[{{-0.5732846067697503, -0.7618911133602151}, \
{-0.5703360745909672, -0.7596329692679514}, {-0.5642301380868552, \
-0.7549648051106492}, {-0.5593630650605237, -0.7512482914990272}, \
{-0.5546527481583186, -0.7476506526667712}, {-0.5341055478958071, \
-0.7319071492855269}, {-0.5140573175450001, -0.7165017344919319}, \
{-0.37022834499492474`, -0.604777809814941}, {-0.2517068256876594, \
-0.5104646277185343}, {-0.15387790367976922`, -0.4306766336956813}, \
{-0.0309161541887796, -0.3269089186450417}, {
            0.059644591662998826`, -0.2474188178898851}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.015974558903015485`, 1.}}], 
           ArrowBox[{{-0.8838617834048176, 
            0.47678583455891826`}, {-0.8798062452603883, 
            0.47532901508647707`}, {-0.861539746963311, 
            0.46877717462972346`}, {-0.8495521629694551, 
            0.4645054648596949}, {-0.7944386971684131, 
            0.4448568238749577}, {-0.7419624150504278, 
            0.4260494551492183}, {-0.6325306056358727, 
            0.38659612279400085`}, {-0.5344225654397969, 
            0.3507744194803001}, {-0.44639906089594295`, 
            0.3182144085756594}, {-0.25800573532888993`, 
            0.24681425507320967`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.013102447251170197`, 1.}}], 
           ArrowBox[{{0.8616045667364823, -0.5219779696630351}, {
            0.8557797195076045, -0.5173306251132628}, {
            0.8294864633343524, -0.4962889759773091}, {
            0.7572346321326017, -0.43755685262302185`}, {
            0.7253067560598716, -0.41118904209683277`}, {
            0.6958102217622486, -0.3865812428232363}, {
            0.6664911050212732, -0.36163194660706327`}, {
            0.6394776831183596, -0.33841265244481267`}, {
            0.5896490661426631, -0.29515024739572215`}, {
            0.5474864067344833, -0.25774394097691705`}, {
            0.5116861450525908, -0.22530101675681655`}, {
            0.4475107578158777, -0.1650032422402842}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.013365218792134799`, 1.}}], 
           ArrowBox[{{0.9835944574391093, 0.20910296127009495`}, {
            0.9782025022596703, 0.20763480910153334`}, {0.9525572970664082, 
            0.20073714591265507`}, {0.9386036307509172, 
            0.19702287057902243`}, {0.9233417631693193, 0.1929805698570972}, {
            0.8942609148489875, 0.18516783355731}, {0.8666899310348332, 
            0.1777126748967428}, {0.8258101994928784, 0.1666037522580093}, {
            0.788163349624943, 0.1562676195333808}, {0.7534445225409642, 
            0.14663798362742572`}, {0.6406572307716638, 
            0.11456943363480086`}, {0.5569365192519795, 
            0.08984754854495662}, {0.49432328153608, 0.07065155080528708}, {
            0.4472960257908012, 0.055676166262086525`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.006146885032555197, 1.}}], 
           ArrowBox[{{0.9908082972157257, -0.16093930208605686`}, {
            0.9870914642811961, -0.16015734198014558`}, {
            0.9768815226472951, -0.15802528937852456`}, {
            0.9678635461891203, -0.1561613999253962}, {
            0.9549882534933791, -0.15352940317860278`}, {
            0.9388180472025015, -0.1502532346071941}, {
            0.9042217031217343, -0.14326721937066075`}, {
            0.872796721713364, -0.1368579015775709}, {
            0.8364536158201167, -0.1293057222018699}, {
            0.8026243187535133, -0.12221443505737711`}, {
            0.7395710521531444, -0.10888220819340061`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.00842897222190273, 1.}}], 
           ArrowBox[{{-0.6853872093208448, 
            0.738052985210419}, {-0.6791846611304094, 
            0.7339674302229724}, {-0.6691110438945095, 
            0.7273486413293705}, {-0.6636229460398975, 
            0.7237465333229579}, {-0.6575680468893006, 
            0.719772768841082}, {-0.6447092412826106, 
            0.7113271059342072}, {-0.6316258001491772, 
            0.7027125065586158}, {-0.5827762345770519, 
            0.6702960862488577}, {-0.5364963224041203, 
            0.6393940485577719}, {-0.39290589149362287`, 
            0.5425099029184063}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.015701311321652218`, 1.}}], 
           ArrowBox[{{-0.8952029448224029, -0.4456710953287399}, \
{-0.8951969854742867, -0.44566911711837676`}, {-0.8833051359855175, \
-0.4417288679413819}, {-0.8682959265151401, -0.4367809439811653}, \
{-0.8572884530792048, -0.4331602137916837}, {-0.8444602240270316, \
-0.4289424645270915}, {-0.8310589006633853, -0.42453402208133995`}, \
{-0.7795545564837063, -0.4075344121905664}, {-0.7209989947740443, \
-0.38814694718046694`}, {-0.6655961479608524, -0.36968775886944555`}, \
{-0.6155936132269262, -0.352823568955002}, {-0.5681239410071598, \
-0.3367176464749834}, {-0.4067851685762079, -0.28136534685192743`}, \
{-0.2746573750865987, -0.23488945058141225`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.015427548741247717`, 1.}}], 
           ArrowBox[{{0.03434406220900779, -0.9995151835011491}, {
            0.03438098926331006, -0.9994091453813265}, {
            0.03721203467131587, -0.991259663989132}, {
            0.04103825473732637, -0.9800060989241915}, {
            0.04892007443715232, -0.955345111450247}, {
            0.05637157608562145, -0.9308005979894501}, {
            0.06369872210572566, -0.9065482109451886}, {
            0.07811445417928588, -0.8587238029717155}, {
            0.09160551148134395, -0.8135469249083169}, {
            0.10440042351995858`, -0.7699242648283894}, {
            0.11638207742010634`, -0.7287116103231621}, {
            0.13883144602294079`, -0.6508086888344422}, {
            0.15845917978898746`, -0.5814099468777034}, {
            0.17564315230336858`, -0.5195171681834637}, {
            0.21281055531581722`, -0.38086261871909816`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.012237386674323359`, 1.}}], 
           ArrowBox[{{0.018239711668284038`, 0.9999098989581219}, {
            0.018266202963251363`, 0.9998339057030248}, {
            0.020772856177000497`, 0.9926405754625721}, {0.02251010162567543, 
            0.9876474171688882}, {0.02924200229040387, 0.9680754011171026}, {
            0.033567246016070446`, 0.9550893173589979}, {0.0367860166464895, 
            0.9451395161663783}, {0.04474546718301642, 0.9203750995383501}, {
            0.05245007936082176, 0.8962965883796524}, {0.06760828732822, 
            0.8488160154150894}, {0.08179332835121685, 0.8039681940732379}, {
            0.0952457911478229, 0.7606676699102444}, {0.10784168885732516`, 
            0.719765152403}, {0.13143848556152593`, 0.6424609330548576}, {
            0.15206236992459155`, 0.5736206427310093}, {0.17011122785653016`, 
            0.5122510688582171}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.00908022615511424, 1.}}], 
           ArrowBox[{{0.5401372802275728, -0.8152972094372984}, {
            0.5378566227416005, -0.8088553534478912}, {
            0.5299936703028003, -0.7855599724835242}, {
            0.5234430000351296, -0.7652321922023013}, {
            0.5161594356672959, -0.7433012818633887}, {
            0.4879044267531479, -0.6584882724266807}, {
            0.4635337718523703, -0.5840247775314904}, {
            0.45223843291048244`, -0.5491836197370691}, {
            0.4417548124786281, -0.5165416390827156}, {
            0.431734287974903, -0.4847701143971923}, {
            0.4224392509664925, -0.45503080130974316`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.007599656857380077, 1.}}], 
           ArrowBox[{{0.7349422238561276, 0.6574772183243229}, {
            0.6790432083674646, 0.5841776817950122}, {0.6533539724395344, 
            0.5499799748145756}, {0.6295538869594469, 0.5179895857538382}, {
            0.6066846599204848, 0.48667208940045187`}, {0.585494871096693, 
            0.4573839899792816}, {0.5461928234363016, 
            0.40255494754659177`}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \\(sp\\)]\\),\\!\\(\
\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(sp\\)]\\)}\"", 
          TraditionalForm]}}], {1360.8000000000002`, -189.}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {}},
  ContentSelectable->True,
  ImageSize->1050,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.554543363554977*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute Field Components around and in a Mie-Sphere. Done for an array of \
points to generate a Field-map / Field-Lines: XZ: \[Phi]=0, YZ: \[Phi]=\[Pi]/2\
\>", "Subtitle",
 CellChangeTimes->{{3.532092134203248*^9, 3.532092150415887*^9}, {
  3.5321141229964933`*^9, 3.532114136163643*^9}, {3.532195780162475*^9, 
  3.5321957995108*^9}, {3.532286988684536*^9, 3.532287098671701*^9}, {
  3.5323694900629387`*^9, 3.532369583549016*^9}, {3.532509295787271*^9, 
  3.532509311123616*^9}, {3.554281504526169*^9, 3.554281588858671*^9}, {
  3.554541314377347*^9, 3.554541349901637*^9}},
 Background->GrayLevel[0.85]],

Cell["\<\
Sphere and Thermal Lens (Conjugate[nParticle] or proper sign convention...)\
\>", "Subsubtitle",
 CellChangeTimes->{{3.577716058498433*^9, 3.577716077924766*^9}, {
  3.5800279448207703`*^9, 3.580027983111615*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]r", "=", 
    RowBox[{"R", "/", "30"}]}], ";", 
   RowBox[{"L", "=", "1000"}], ";", 
   RowBox[{"rT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"R", "+", 
        RowBox[{"\[CapitalDelta]r", " ", 
         SuperscriptBox["i", "1.3"]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "L"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"rT", "[", "]"}], " ", "is", " ", "a", " ", "Table", " ", "of", 
    " ", "radii", " ", "for", " ", "lens", " ", "discretization"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xC", "=", 
    RowBox[{"{", 
     RowBox[{"k", " ", "R"}], "}"}]}], ";", 
   RowBox[{"mC", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Conjugate", "[", "nParticle", "]"}], "/", "nmed"}], "}"}]}], 
   ";", 
   RowBox[{"AAC", "=", 
    RowBox[{"abL", "[", 
     RowBox[{"xC", ",", "mC", ",", "0"}], "]"}]}], ";", 
   RowBox[{"anC", "=", 
    RowBox[{"AAC", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";", 
   RowBox[{"bnC", "=", 
    RowBox[{"AAC", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Cold", " ", "scatterer", " ", "Mie"}], "-", 
    RowBox[{"Coefs", ".", " ", 
     RowBox[{"(", 
      RowBox[{"detection", " ", "laser"}], ")"}]}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xH", "=", 
   RowBox[{"k", "*", "rT"}]}], ";", 
  RowBox[{"mH", "=", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Conjugate", "[", "nParticle", "]"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"nmed", "-", 
         RowBox[{"0.5", "nmed", " ", 
          RowBox[{"R", "/", 
           RowBox[{"rT", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]}], "]"}], "/", 
    "nmed"}]}], ";", 
  RowBox[{"AAH", "=", 
   RowBox[{"abL", "[", 
    RowBox[{"xH", ",", "mH", ",", "nmax"}], "]"}]}], ";", 
  RowBox[{"anH", "=", 
   RowBox[{"AAH", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"bnH", "=", 
   RowBox[{"AAH", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"mH", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"mH", "[", 
    RowBox[{"[", "L", "]"}], "]"}], ",", 
   RowBox[{"rT", "[", 
    RowBox[{"[", "L", "]"}], "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.576510429323989*^9, 3.57651043668647*^9}, {
   3.576510552736178*^9, 3.5765105530163317`*^9}, {3.5765106526625547`*^9, 
   3.5765106574927197`*^9}, {3.576510714797584*^9, 3.576510743120948*^9}, {
   3.576510835144987*^9, 3.5765110385206842`*^9}, {3.576511071756483*^9, 
   3.5765112897903557`*^9}, {3.576511570963807*^9, 3.57651158423559*^9}, 
   3.576511634458062*^9, {3.5765116688416348`*^9, 3.5765117138043537`*^9}, {
   3.576512068894154*^9, 3.576512069883608*^9}, {3.576514516975209*^9, 
   3.5765145354688663`*^9}, {3.576519910948286*^9, 3.5765199713463306`*^9}, {
   3.576520015522944*^9, 3.576520030880722*^9}, {3.576650230909984*^9, 
   3.576650264467268*^9}, {3.5766786153756733`*^9, 3.576678615964115*^9}, {
   3.576773094543395*^9, 3.5767730963011713`*^9}, {3.5772619162262077`*^9, 
   3.577261917872023*^9}, {3.577342562397978*^9, 3.5773425740556393`*^9}, 
   3.5773426126069736`*^9, {3.57734270694177*^9, 3.577342707179178*^9}, {
   3.5773427477527103`*^9, 3.577342747922604*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.11972602739726028`", "\[InvisibleSpace]", "+", 
    RowBox[{"2.3710958904109587`", " ", "\[ImaginaryI]"}]}], ",", 
   "0.9981138329507655`", ",", "2654.319209831011`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.576511675285883*^9, 3.576511711998007*^9, 3.5765118604347067`*^9, 
   3.5765120103468847`*^9, 3.576512078152503*^9, 3.5765144114914627`*^9, {
   3.576514528671432*^9, 3.576514544855259*^9}, {3.576519895969533*^9, 
   3.5765200409302797`*^9}, 3.576520097815127*^9, 3.576524959804122*^9, 
   3.576650255382145*^9, 3.576650291573392*^9, 3.57667877426022*^9, 
   3.576773116314026*^9, {3.577261920032961*^9, 3.5772619418295*^9}, 
   3.577262072869615*^9, 3.5773425268843603`*^9, {3.5773425707277184`*^9, 
   3.577342594371118*^9}, 3.577342644375198*^9, 3.577342741205024*^9, 
   3.577342788912876*^9, 3.577342896744775*^9, 3.577360938710739*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plain Sphere near field calculation", "Subsubtitle",
 CellChangeTimes->{{3.577716058498433*^9, 3.5777160612946053`*^9}, {
  3.59150692245506*^9, 3.591506925367906*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Exact", "=", "0"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Axilliary", " ", "Functions", " ", "and", " ", "Tabulated", " ", "BSCs", 
    " ", "used", " ", "in", " ", "Field", " ", "decomposition"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Exact", "\[Equal]", "1"}], ",", 
     RowBox[{"gnET", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"2", 
         RowBox[{"gnTME", "[", 
          RowBox[{"n", ",", 
           RowBox[{"ArcSin", "[", 
            RowBox[{"NA", "/", "nmed"}], "]"}], ",", "f", ",", "wa", ",", 
           RowBox[{"2", 
            RowBox[{"\[Pi]", "/", "\[Lambda]"}]}], ",", "n1", ",", "n2", ",", 
           "d", ",", "ds", ",", "z0"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ",", "0"}], 
    "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "Terms", " ", "considered"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"anL", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"aMie", "[", 
       RowBox[{"n", ",", 
        RowBox[{"k", " ", "R"}], ",", 
        RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   SubscriptBox["a", "n"], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bnL", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"bMie", "[", 
       RowBox[{"n", ",", 
        RowBox[{"k", " ", "R"}], ",", 
        RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   SubscriptBox["b", "n"], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cnL", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"cMie", "[", 
       RowBox[{"n", ",", 
        RowBox[{"k", " ", "R"}], ",", 
        RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   SubscriptBox["c", "n"], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dnL", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"dMie", "[", 
       RowBox[{"n", ",", 
        RowBox[{"k", " ", "R"}], ",", 
        RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   SubscriptBox["d", "n"], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "Itot", "]"}], ";", 
   RowBox[{"NV", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}]}], ";"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Compute", " ", "Field", " ", "Components", " ", "and", " ", "Poynting", 
     " ", "Vectors", " ", "for", " ", "a", " ", "2", "D"}], "-", "Slice"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"use", " ", "for", " ", 
      RowBox[{"(", "Igor", ")"}], " ", "export", " ", 
      RowBox[{"(", 
       RowBox[{"rectangular", " ", "grid"}], ")"}], " ", "rmax"}], "=", 
     RowBox[{"2.011", "R"}]}], ";", " ", 
    RowBox[{"dr", "=", 
     RowBox[{
      RowBox[{"R", "/", "20"}], ":"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rmax", "=", 
    RowBox[{"100.0001", "R"}]}], ";", 
   RowBox[{"dr", "=", 
    RowBox[{"R", "/", "20"}]}], ";", 
   RowBox[{"rP", "=", 
    RowBox[{"rmax", "/", "R"}]}], ";", 
   RowBox[{"\[Phi]", "=", 
    RowBox[{"0", "*", 
     RowBox[{"\[Pi]", "/", "2"}]}]}], ";", 
   RowBox[{"rmaxz", "=", "rmax"}], ";", 
   RowBox[{"rmaxx", "=", 
    RowBox[{"rmax", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"anL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"anH", "[", 
        RowBox[{"[", "n", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"bnL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"bnH", "[", 
        RowBox[{"[", "n", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"anL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"anL", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"rmax", "=", 
     RowBox[{"7.001", 
      RowBox[{"rT", "[", 
       RowBox[{"[", "L", "]"}], "]"}]}]}], ";", 
    RowBox[{"dr", "=", 
     RowBox[{
      RowBox[{"rT", "[", 
       RowBox[{"[", "L", "]"}], "]"}], "/", "20"}]}], ";", 
    RowBox[{"rP", "=", 
     RowBox[{"rmax", "/", 
      RowBox[{"rT", "[", 
       RowBox[{"[", "L", "]"}], "]"}]}]}], ";", 
    RowBox[{"\[Phi]", "=", 
     RowBox[{"0", "*", 
      RowBox[{"\[Pi]", "/", "2"}]}]}], ";", 
    RowBox[{"rmaxz", "=", "rmax"}], ";", 
    RowBox[{"rmaxx", "=", 
     RowBox[{"3.001", 
      RowBox[{"rT", "[", 
       RowBox[{"[", "L", "]"}], "]"}]}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Itot", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"z", "/", "R"}], ",", 
            RowBox[{"x", "/", "R"}], ",", 
            RowBox[{"EHVi", "[", 
             RowBox[{
              RowBox[{"Sqrt", "[", 
               RowBox[{
                SuperscriptBox["x", "2"], "+", 
                SuperscriptBox["z", "2"]}], "]"}], ",", 
              RowBox[{"ArcTan", "[", 
               RowBox[{"z", ",", "x"}], "]"}], ",", "\[Phi]"}], "]"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", 
            RowBox[{"-", "rmaxz"}], ",", "rmaxz", ",", "dr"}], "}"}]}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "rmaxx"}], ",", "rmaxx", ",", "dr"}], "}"}]}], "]"}], 
      ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Cylindrical", " ", "grid"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"rmin", "=", 
     RowBox[{"R", "/", "100"}]}], ";", 
    RowBox[{"rmax", "=", 
     RowBox[{"8", "R"}]}], ";", 
    RowBox[{"dr", "=", 
     RowBox[{"R", "/", "40"}]}], ";", 
    RowBox[{"d\[Theta]", "=", 
     RowBox[{"\[Pi]", "/", "20.01"}]}], ";", 
    RowBox[{"rP", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"rmax", "/", "R"}], ")"}], "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";", 
    RowBox[{"\[Phi]", "=", 
     RowBox[{"0", "*", 
      RowBox[{"\[Pi]", "/", "2"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Itot", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", " ", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Theta]", "]"}], "/", "R"}]}], ",", 
             RowBox[{"r", " ", 
              RowBox[{
               RowBox[{"Sin", "[", "\[Theta]", "]"}], "/", "R"}]}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1.1"}], 
                   RowBox[{"rmax", "/", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}]}], "\[LessEqual]", 
                  RowBox[{"r", " ", 
                   RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "\[LessEqual]", 
                  RowBox[{"1.1", 
                   RowBox[{"rmax", "/", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ")"}], "&&", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1.1"}], 
                   RowBox[{"rmax", "/", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}]}], "\[LessEqual]", 
                  RowBox[{"r", " ", 
                   RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "\[LessEqual]", 
                  RowBox[{"1.1", 
                   RowBox[{"rmax", "/", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ")"}]}], ",", 
               RowBox[{"EHVi", "[", 
                RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"NV", ",", "NV", ",", "NV", ",", "NV", ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
                "}"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "rmin", ",", "rmax", ",", "dr"}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]", ",", "d\[Theta]"}], 
          "}"}]}], "]"}], ",", "1"}], "]"}]}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.554280896316976*^9, 3.5542809143259*^9}, {
   3.554281408769741*^9, 3.554281409183889*^9}, {3.554525179570805*^9, 
   3.554525208233419*^9}, {3.5545252631913757`*^9, 3.554525341457645*^9}, {
   3.554525390168347*^9, 3.554525415819179*^9}, {3.554525907828788*^9, 
   3.5545259185866117`*^9}, {3.5545407591847553`*^9, 3.554540762563393*^9}, 
   3.554541352257002*^9, {3.554549444881707*^9, 3.554549458781704*^9}, {
   3.55465785533605*^9, 3.554657866886689*^9}, {3.555302083372678*^9, 
   3.555302083676983*^9}, {3.557740439553154*^9, 3.55774044548018*^9}, {
   3.564099806080031*^9, 3.564099814794713*^9}, {3.564099867961811*^9, 
   3.564099882022935*^9}, {3.564467446290587*^9, 3.564467466023671*^9}, {
   3.564478341380666*^9, 3.564478406371771*^9}, {3.566034770199492*^9, 
   3.566034770584791*^9}, {3.566034810694343*^9, 3.5660348555981913`*^9}, {
   3.566136758607656*^9, 3.566136778635261*^9}, {3.568649080004354*^9, 
   3.568649101227427*^9}, {3.568657063122492*^9, 3.568657066583561*^9}, {
   3.568657202427176*^9, 3.568657203086315*^9}, 3.572086321019392*^9, {
   3.57208652951589*^9, 3.572086530486446*^9}, {3.5765113209673433`*^9, 
   3.5765113821395283`*^9}, {3.5765117393061037`*^9, 3.576511767059079*^9}, {
   3.5765122820217648`*^9, 3.576512284176037*^9}, {3.576514386919312*^9, 
   3.576514388675317*^9}, {3.5765197563259907`*^9, 3.576519758742931*^9}, {
   3.576524976212981*^9, 3.5765249896729803`*^9}, {3.5766787991175127`*^9, 
   3.576678828688611*^9}, {3.5767731464831743`*^9, 3.576773149283903*^9}, {
   3.577261971887528*^9, 3.577261973394745*^9}, {3.577342801738874*^9, 
   3.57734280316004*^9}, {3.57771604232725*^9, 3.577716044087515*^9}, {
   3.5908132236119347`*^9, 3.5908132777001457`*^9}, {3.590989122645212*^9, 
   3.590989125001336*^9}, {3.591001870322551*^9, 3.5910018752816133`*^9}, {
   3.59100191476851*^9, 3.591001920704007*^9}, {3.59100196627429*^9, 
   3.591001973477826*^9}, {3.591259298266849*^9, 3.591259307623929*^9}, {
   3.5912625794517107`*^9, 3.591262579947318*^9}, {3.591329420072391*^9, 
   3.591329469494932*^9}, {3.5913706489077377`*^9, 3.591370652388538*^9}, {
   3.591451376398815*^9, 3.591451397688734*^9}, 3.59150683436738*^9, {
   3.591506869418721*^9, 3.591506914616184*^9}, {3.5915083781125383`*^9, 
   3.591508387275316*^9}, {3.591508438576494*^9, 3.591508438673725*^9}, {
   3.5928926500622377`*^9, 3.5928926562449007`*^9}}],

Cell[BoxData[
 RowBox[{"Hold", "[", 
  RowBox[{
   RowBox[{"Abort", "[", "]"}], ",", 
   RowBox[{"Abort", "[", "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.5929022120737867`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Transform to Cartesian Coordinates and Generate Tables for Plotting of \
field lines etc. \n",
 Cell[BoxData[
  RowBox[{
   GraphicsBox[
    {Thickness[0.005317938980894221], 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      LineBox[{{97.1992, 84.51120000000002}, {97.1992, 
       46.11120000000002}}]}, 
     {RGBColor[0.925756, 0., 0.], Opacity[1.], JoinForm[{"Miter", 4.}], 
      LineBox[{{110., 46.1108}, {161.373, 46.1108}}]}, 
     {FaceForm[{RGBColor[0.925756, 0., 0.], Opacity[1.]}], 
      PolygonBox[{{158.56449999999998`, 42.4077}, {160.13649999999998`, 
       46.1107}, {158.56449999999998`, 49.8147}, {167.34149999999997`, 
       46.1107}, {158.56449999999998`, 42.4077}}]}, 
     {RGBColor[0.118, 0.239, 1.], Opacity[1.], 
      Dashing[{0.015953816942682664`}], JoinForm[{"Miter", 4.}], 
      LineBox[{{180.1328, 69.91160000000002}, {169.33180000000002`, 
       102.31160000000003`}}]}, 
     {FaceForm[{RGBColor[0.118, 0.239, 1.], Opacity[1.]}], 
      PolygonBox[{{173.7334, 100.8188}, {169.7224, 101.1398}, {166.7064, 
       98.47579999999999}, {167.4444, 107.9748}, {173.7334, 100.8188}}]}, 
     {JoinForm[{"Miter", 4.}], 
      LineBox[{{16.5, 7.5}, {16.5, 120.76400000000001`}}]}, 
     {Thickness[0.005317938980894221], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQ3fnl9vXGz3oOFS/VDDlOxDm4ZuZ/aJ2i53DU27zz
78I4B1NBM5u9ZnoOgTvkWk/XxTnkHf23qfqmrsNFpds/L8XGOXDEz/ARrdF1
+FmXtafELs7hy4aA7FnftR1A3MlHYh1SVyWEBLEbw/k2fhcn9rw2cmBbIxMl
cSXWoaM16rLNUSOHT3+vVHC+jnX4khNWuy7JyCF2lycPk1acw4y7k9tZPxs6
TMsTalYoj3PIZMhvDNlj6OC67fPfA/PjHBJDgtQXdBrC3b8gTvO0Q4Shg/A6
94ffPsY5TNvEU6ijbehQY28aN0sq3sFK2at6MpOhg1/v9LxljvEONc36Psvu
GThotYvdPJcW7+C3jMtt6n4DB6DzUo53xjvMB5o3YamBQ4Et13XnVfEOyfU3
bU9OMHAAqv7+/Xi8w50MhvzsDgOHe/694uuvxjv03AYKNBo4WN/3753+KN5B
rZRpVlEVQp4xv5FFtAih/4bQJ0f/WIT5p57aL/F3Rtjfx/ZBzEMF4b57k9tb
sxgM4O5/EiG+/eJ6fbj/mO4xcb4K1Yf7Hz1+Ad4Z2co=
       "]]}, 
     {JoinForm[{"Miter", 4.}], 
      LineBox[{{7., 15.}, {238.69899999999998`, 15.}}]}, 
     {Thickness[0.005317938980894221], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQzae7ae57xTyHPaxCIvZsBg52XNcXv+HLc4jzPsG+
19TA4Vdd1p6Qv7kOad+fJC5MMXAIebx09o03uQ6ecxvUnCYbOMT0H/qqcTfX
oebC5sivBw0cJr6tsTddkOvQvjz8lFGLIZxvttouPPqjhsOnS75Jv5bnOnQk
x955pqHpMF9K/27J5lyHj1+8IttKNR1mH1HY8OlSroOEWjDrYistsPqGn7kO
F11ufPgiqe0gEGG55RxvnoPef8W/Ye3aDjD324dHb9z/Rtvh/fJj3s/N8hwO
O63NrPPXcXh6Qem2pXeew5VZz2SXr9Rx6HRMeHogLs+hZ2c2581fOg4lkyVY
wgrzHLh+Lkjf7KTrAJS+cKkpzyFj86viqw26Dh1AAYHJeQ5HgObd26Lr8ARo
3suFeQ7WjL4tufd0HW79rMs6siLPwQvoIM33umD7zdfnObz0ALkQIb9N9Pdp
KW49uH6g5Ler0npw8wNvSdckuurB7c8zadieUKkHd9+TT/KX8rfrwd3vCgwO
rf96cP/JLX/hoRegD/c/yHzRVfoO6PELAPvE6Uc=
       "]]}, 
     {JoinForm[{"Miter", 4.}], 
      LineBox[{{16.5166, 14.9502}, {109.9996, 46.111200000000004`}}]}, 
     {RGBColor[0.118, 0.239, 1.], Opacity[1.], JoinForm[{"Miter", 4.}], 
      LineBox[{{110., 46.1108}, {174.801, 67.7108}}]}, 
     {FaceForm[{RGBColor[0.118, 0.239, 1.], Opacity[1.]}], 
      PolygonBox[{{173.3076, 63.3091}, {173.6276, 67.3201}, {
       170.96460000000002`, 70.3361}, {180.4636, 69.5981}, {173.3076, 
       63.3091}}]}, 
     {RGBColor[0.118, 0.239, 1.], Opacity[1.], JoinForm[{"Miter", 4.}], 
      LineBox[{{110., 46.1108}, {99.199, 78.51079999999999}}]}, 
     {FaceForm[{RGBColor[0.118, 0.239, 1.], Opacity[1.]}], 
      PolygonBox[{{103.6006, 77.0181}, {99.5896, 77.3391}, {96.5736, 
       74.6751}, {97.3116, 84.17410000000001}, {103.6006, 77.0181}}]}, 
     {RGBColor[0.21200000000000008`, 0.30600000000000005`, 1.], Opacity[1.], 
      Dashing[{0.015953816942682664`}], JoinForm[{"Miter", 4.}], 
      LineBox[{{97.1992, 84.51120000000002}, {162.0002, 
       106.11120000000003`}}]}, 
     {FaceForm[{RGBColor[0.21200000000000008`, 0.30600000000000005`, 1.], 
      Opacity[1.]}], 
      PolygonBox[{{160.5068, 101.7095}, {160.8268, 105.7205}, {158.1638, 
       108.7365}, {167.6628, 107.9985}, {160.5068, 101.7095}}]}, 
     {Thickness[0.007976908471341332], JoinForm[{"Miter", 4.}], 
      LineBox[{{110., 46.1108}, {161.373, 102.3118}}]}, 
     {Thickness[0.005317938980894221], 
      PolygonBox[{{162.6309, 95.45460000000001}, {160.1219, 
       100.94360000000002`}, {154.4299, 102.95160000000001`}, {
       167.41389999999998`, 108.92060000000001`}, {162.6309, 
       95.45460000000001}}], PolygonBox[CompressedData["
1:eJw9V3lcj+kWL0JulibERDTpJjKWYmTt21DN70PyPu9mD41BlyhpRBI1CiFa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       "]], PolygonBox[CompressedData["
1:eJxdVntUTfsW3hLlkai8SkUizi4k5RGaKBGF1vxtIZXy2LouyaPQ8UpIRKIO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       "]], 
      PolygonBox[{{92.97460000000001, 99.0117}, {90.1496, 
       96.75970000000001}, {90.65360000000001, 96.0617}, {92.97460000000001, 
       97.56070000000001}, {95.29660000000001, 96.0617}, {95.8006, 
       96.72670000000001}}], PolygonBox[CompressedData["
1:eJxlV3lYj9sWbpAGkkopkuFEKbNESi1JypGkb++dcJKjOpo4OUjD7yRKMpQp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       "]], PolygonBox[CompressedData["
1:eJxFV3lcTt0WTpMxGiiVlDQhQ1R85WMRyVDtcw5RIqL2MVeGikLS9yJCylBk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       "]], 
      PolygonBox[CompressedData["
1:eJxFVH1UzXcYr5BC3k3eRh0sRnlptjlmHw2niXu/paIU5YrnokjCSN5aOne5
w5KYJUMoSbUrRXXuSeWt5N2apdOM2J0lnU7y0p7f/d5z/HHPPb/zfJ/v83ze
vk6LV/mE2VhZWWn4p/zHhE7wG5dGiEutzLjRSWBBTokpNYNgXWtjr5snsKHr
cJePswh70lrHPwkVSN7dY+PBbMIR/py6XODNtRdXSnMJ73Y2/3E/SsCnZlDM
5nOEwrc7m7vGCsx40NicUUh43tG916QEgR31FSluJYR0Ffrk7BEw9OMbSi39
BwRseOCGy4S28U/OjEgTOPhkyAm6QXDp0dWQfkIgpHPVAOMDQhfdUM2LLIHl
tZE631rC3ztSK2uyBdy35mP7Y8Jgh7qxu88KqLOTwuxeELrzZ9oZAQXe7GbC
LatamysZsl/fRlCjT2jpUYGeGydldm8ifJQ46/njnwUueWRpF5oI17d4lmze
LeuuzwjO+ujICzsEzPw1EC6Pmrz32nqBvOdRhjCub+XjRSsEevD5Yu4/znhD
Fws4v2uJrn5JSHbSR3sHWfpbCYb07ypGBQpUT3/QmNQu+4cECyxN0AQ/tNXK
+lKB2MSCFdpuWiS12C5KiZbn7bprUaHM32LRj7+Dw8ve5/4g8LYluu5XBy3+
C/SYGnJQIP6Le2V/dtGa9b2aLmBKnTImme9X6LLLERg5t9PR3tZaMPyO7gUC
LjzwAPOjjFtSItDg6doe+YpQ/j53U26pwMKHMzvU/0NYM8ih7rNyCx7mf+1M
3rBCYPSpPtXxDwlBHlMblDrL2eB4l3CY7WYolXgeVRJ4ec8ovr/Y2H/k7XKC
Im8gz1+j0z82sV9qTrcFBfB+xASPKCDc8ze5LWA/rLR/nRadK/Wcw3p5BTDC
TKnPoF3SX0tOSn0e/SKg0HnuKOH8Tata50wBu6oB3mNS5f3fGgTW1R3qNSKF
MLB+fv/8iwKOTIj1XkJIyux+1UaBcQxoWCJhHxPSekngjmLQ7R/wdhvuEuuz
mfAmKLzMtVz6JWIDQSj+YrxXSz2ynq0i3Pk0bEB9ocAhbm8lQuP3V3yN7Oe3
nCeHpYRtUTOTbFmfgd4cKI3kp4T37328yDg+RO6n5vxYsaFmBBMafj/dNjhO
4F5ZuHtxoMzz/XUCTF/T4flSn7HLpR8b/QmfTynyqVoooNBl8CPMN7ldWOYn
wHQuy/MlGE8eU8HLgm+e5MvGQ+CnydZz4hYQ2nM3NZ1lVIs4j95LCPlKPUDu
e5r3v+iT7NTG8yKUQGoJN+76m37cJMDrDHVeyfvzOmt1AhzPBA3zUZXBJ/bL
/DtGkcLW7adHBIrYD3PXS7z3Twn0YvyfxMg83+E8s9tGn9r2Ie/K+zQyQe63
mvlkORK/ZL3sFUMdE2hqnhXgryd4sb29UwT6KgHSW/RIkHny1Uv/vNkocB7b
6yu4n1+vKUVaAWVcno4Qz3J5zrO8NwkWfWZI/xzfQjgXF1Od91pt9kv1GsK/
DsXjDoxWm9+b2Ej2y/D97T0d1Zgd56B2W83vZY3uXVgHNfKVeRGEJs31YK8G
ldn/Nly/OuFSjutNlVmficxPZbDX5c5Glfl9TGF+zmd3eJqYr8I3WdraSOZH
9Uo/d+1vKpzhz8nMT0tBje4rrheusH89LJ7gNO2l5nqJCtP5/DbGc8jvcGZ4
lcrMV8EuwkQeF/GXCq+G3lq1aB/Btnffr8uD1PgfxBnYYA==
       "]], 
      PolygonBox[{{206.17969999999997`, 76.71000000000001}, {
       203.35369999999998`, 74.45800000000001}, {203.85769999999997`, 
       73.76}, {206.17969999999997`, 75.25900000000001}, {208.50169999999997`,
        73.76}, {209.00569999999996`, 74.42500000000001}}], 
      PolygonBox[CompressedData["
1:eJxlVGtMlFcQxZVQQXkIvjEqtYioFAmIERQOxAihinu3SK0iKir2XuuDAC4i
tLVIsaB1W19IFYmBLSVgkEpVXhUVgSpFBIJKFURYBFHptiUIFjv7fRqS9sdm
czL3OzNz5szYhe1UbVEYGRmto5/h37c2vLGzh8O81UmTYaXEWxy57GifiZ8S
aaNs00OL/4/bE9JrciwZglQOM1IIr4TNxnXTGVZnL6iZWMLh/eRe7pz5DB3e
mestSzlCfL2eVPoweAbWfRtXxrFi/MGA7g+ZgW+auMJR7GA52i+cwTuzpazt
qsx3JIbh0+D49/+o4Mi3b0/Yn8ywgRJmVHPsp/S13zOsqS/ZNFDDER1haz4n
l+Ek1WdWzzFvy+Q2/2KGUMebmua7HIHE96iKoVPM7VO3cHxVHVSe3cAQpUg7
0K3jiK109Ah6yLDMPlrh9YLjjtFDxckOub74fg73xaWqed0MkyObwmL+4SjP
zrQIecpw/lHXsQKFkPivET7levbCQopT+wMhDxg+Jj2KX3LsqBgqGLzFoHFR
O50kvtU9zsUnrjJsbaSKCOcNhGyv+Fnq5/FQv6yPu5Zh6cCzp8pBjijSX3eC
4fIhk972IQ5bGlhDCgPJGfLZSAEvQ8J9Ur3praMEGoJ7nD+KZaB0drUWAs1N
+yJ1UQw5JKD5eIGAbmO3rAj5faitkPg0u2RcYCewnPKfo/irSZFNegcBF905
e+NoBhu9T22bk4DBDinEP3+51myZq4Cx21j3xV8yZLWUWbQuFOikcqwOMlzb
nLMhylNApKlPKVIZHhxJSryxRMA0efomM62sd5qXAMl73I7613lnnvEibGhn
djlDZdGlQ270XuzsTfz6JsP24PjnScT3DQ3cp5FhLem1dJHALDLkCprfOL3P
YbW7wOuCvfpcHcOUyCbrea4yX8hzht4J/podzgIFym1pa/9mmJoe6vjBXIHZ
lqMLtYMM06o7XtfMEphKeiweoUIsGXrkuwJryb+TTVT4aUxET99UgQvaPZVL
zFQwtF84UaCfBMoyV+HXDu/NAdYCf5HgK61UOJfS/MnVMQLqU2dnLrKW+KId
3xGg9OoNNhJfbsqIN/4hTO42dRng0GT0n7clfInm7fEnh4IEcx6rQtnjcae1
PZK/w8wtVHCv8QyM0EnvXW6YqjD47ClSWzkKtXv8uLEKbWTPSc0cMzY9X2My
JM2j9UUjx6ry7Pfy+hh2K2jidRz3SZ7tpM/t8MatJ25x0DhLgsn/Py6o8Qyr
4ugi/WKaGe5a68tjrnPE6fNvP77N4EZ2v3tF9qe2guFoUuL9eNr3YOK/c1ni
6wwv4siiBqPzmFS/5qK0H7FnMuTv+y/I8Y1HhrFBjnrq33COxCqO9ankSLNh
LMXrmdSfciPHF/6/xJcSpnHYHxNc9lO97OfkCA59vnJbbB2Dx8yAvQm7OaaT
Hr6/MZD6zVV75X03Jb8Z5CiK42A0n1eFb+oh7PHdzc/9fxjGdF5WT6R7+Lae
/2KD//Lpnu4zrjjsouaSf+5ZK5Gc/6hrfDLHBDp/122UOF5ABjjN8dKwYOOU
0v24SPduCtFdpDhV6/z7fY6tS/nOfPq+ivZhV7s8j4axSlTTgW3pGc73L4Ac
pmQ=
       "]], PolygonBox[CompressedData["
1:eJxFWHlcTukXfyWhqKSVCAkJEcranIyyJeskvfde0vuEkLGGmkwqjSyJikiE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       "]], PolygonBox[CompressedData["
1:eJxlV2dUVccWviIP7CBRAY0hiEgMWO65vRzcsSCyCJk5QSQGu4jBQogKQSWI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       "]], 
      PolygonBox[CompressedData["
1:eJw9VQtUjVkY1VOGSamGLEpJc5NCelBy9zkXJSUqavKcyNsUoeQVpkHJ1SCv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       "]], 
      PolygonBox[CompressedData["
1:eJxNVnlcTekbL5HC2IY0jWZs9bNH55xb51zLN8WgLFmG0EKiad5bUgqFqKZU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       "]], PolygonBox[CompressedData["
1:eJw9V3lcjdkbT3YlNCH0S0hC2d333vve9/bFGESWCMV5rxKaRBiSMRq7LDPW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       "]], 
      PolygonBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQrfmWd5/BzWiHPaxCIvZ87g5/rArOJVyPdthnMFPL
45Wbg8mRjXp6l6IdJq1sCjx5ws0ht6Jq6ZeT0Q5l/nJiVavcHNzci37y7492
WMwINGGCm0OMguPH2xujHcLmr17rUeXm4Pe5L3jLomiHE+y2s69mujnsXM/8
/MvEaAdzqQPRBfFuDpauQAPqox3ubm2puRDtBrafIw8hzzMZaHEsQv8v/pfb
9f0Q5oeUqEz/74Cwf1VToKesGcJ93X9Tvz/RRbi/Y3n4qU0aCP/pOsu8fqSG
8D9MfpaWxFQTI3e4fpC964Pd4ea31VzY/LPQHW7/EzOgg3vc4e7bCzRPfpE7
3P07gP7u2eQO91/db6uCd3vc4f4Hyx9wh4cPTB4WfjD9sPCFmQ8Lf5j9sPiB
uQ8WfzD3w+IX5j/0+AcABEPoPQ==
       "]]}, 
     {JoinForm[{"Miter", 4.}], 
      BezierCurveBox[{{111.3936, 46.1113}, {111.3936, 45.3413}, {
       110.76960000000001`, 44.7173}, {109.9996, 44.7173}, {109.2316, 
       44.7173}, {108.6076, 45.3413}, {108.6076, 46.1113}, {108.6076, 
       46.8813}, {109.2316, 47.5043}, {109.9996, 47.5043}, {
       110.76960000000001`, 47.5043}, {111.3936, 46.8813}, {111.3936, 
       46.1113}},
       SplineClosed->True,
       SplineDegree->3]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      LineBox[{{167., 46.1108}, {85.916, 46.1108}}]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      LineBox[{{167., 108.5}, {167., 46.111000000000004`}}]}, 
     {JoinForm[{"Miter", 4.}], 
      BezierCurveBox[{{82.66799999999999, 15.}, {82.66799999999999, 20.008}, {
       80.74399999999999, 26.098}, {78.72999999999999, 29.1}},
       SplineDegree->3]}, 
     {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQ/WTp7CMKKsEOp+s99tfW2jk0ZO0pKdYPdsj70Hpy
yRNbhy7HhKcBlsEOKZKPIqaH2jpsPVG2779jsMOJkIMrRM7ZOGye+375Mc9g
hx1/2r/c9rZxuOKbJBCRGuyg+qR53lkvKwc7ruuLCwpDHLYsqzyuKWXr0Dc9
T4g7OcRhkfLOP+F2tg5KG4oyAv1CHNb8isl1LbV1EIyw3HJCLMSh4rim1SR+
OwfONTJRS64EO9zXnbCg4qKdwzKgc1dsCnZ4yWIi+MzS3oE1jE9308RghyV+
DsKJi+0dTpXtmy9WEOywjMtNdS6ng8OH5ce8xQOCHQ6lrEqY4uDg4Lbt898X
hsEOuoryX1TKHBxm5Ak1HxANdsjS/jb97koHhy1A/1z6HeTAkN/I4nvbwSFF
IMIy5EmQQ/F1oU+MXI4OZZMlWKrOBzl4BPyR6DZ1dFC5/fOf1LEgh4I13bd/
ezo6bP/890rF3iAHlqP9huWxjg4lGRPfmh6G8MXdHB1+1WXtkTkZ5NDWGnX5
j46jg819/97wq0EOJ57aL7n/1cFBERgenI+CwO5bs8PBIaAXGGDvgxwkQQ4o
dXDIBzo36E+QwwcxjwAbPQcH5ds/61ZxBjvoTVjww/CIvQNQ+tRPsWAHUPBr
qdg7oMcvAP0Z3HM=
       "]]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      LineBox[{{180.4639, 69.5981}, {180.4639, 46.11110000000001}}]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      LineBox[{{180.4639, 46.1108}, {166.9999, 46.1108}}]}, 
     {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxdVntQlWUaP+IlEpeLYaXIAjGMiRGgCIQBvyjp/d5DRMSyLBHyckmui8ga
niVjOUBIgoCLZEgsi8i6QIooIngNL0dEENdFRUdiVcRNU0RjWCzc5/s+Zprx
jzNnHs57eZ7f7cUuOjU4zkij0RTSR/5OzZ5xqrhb4J7zoUVmWo71TnY2jGqP
1e8kPEjkWN03nKg9J4AXxImLxRw1+z3WZ3QJRKScmvTbwTGNDhBnBWoD8cJ/
DnB42fMnmk6B5IqMyuCzHM+NvMiCDAIz3Szc37zOYfs4+dK7pwROTzZn+j3g
eDPwQulgh8C0AaPnZ2u0iMnq9+4/LOBJ96cu1MJHF7ZrWosA/2GGW6mzVl5v
EdokcCU73f+kmxYlrhlOdg1qXeau1D9W7RD4diIiZXCpFgeLZo1YVgpsXpdm
5fCqFveOvxGztUzA3KSlbvRFLWb7O6xbWiRw8uKSuP6nXF4fX1ogoNmXGfz2
KMfYV9c/nMwT8L3T35hwk8PmcfLnmXqB8rFZWZEXuXK/SZaAJcGzrIOj9vuj
dXsyBXrqz7c82cPRVjTLJWm9wKXQe85nKjkcu8zNsE7A505/QMNGjuBF1QUu
awXm3wh7qTWdo9g1Y8gnVeDPhsUVv3zM5fnjU5IF0qx+M1jyrtJf2NEEIdPx
SO/CETH59sSy1ervQy9z5IVfLOuNFajqrt/TpVH6SymPFmgkPPzvSLgyd7Qz
P0pgt8Mt+/jzktzfSF2kwIELmgG/A5K83mEsgvrNTq+7UymhvWhWU8ZHAq+0
/ZyflCOh1DWjzylcoGEiouh6goS1jZuuLfiDQG5nyHdBQcp647fCBI7tqn39
sruEk7H11TW/F1hD/emtJRn/u29Rvas2cDBuhqTyR7XOsNhry12Gc+aGdi+q
LxOfDpcZJn68e7yAaqeS6nFdB0PYruXdFnR+UFJFhuFbhleIkEtUWxbyH975
minnXaN+3qffF+cxDB41rbT/SJnHvzGNwcLQfrCI5rWWBfaeut41RtXH8tcZ
PMc7Yh0J339pBow65zHcsrTu3LpGoLh63HVgJoPiF52Kt5OGyXr8wDFbILjc
bvPD6QxXvXVhpzcKsGMbrK+YMkQu7goKLhHorj/fx20Zbvx3a/Phr1T/NHsw
9HvreldtV/iY/qeVDCT3nx5VqXjpQpT7H35aI7DMwv3w3ljlvtLbOwW+ILyN
P2WK3vBPgbFZq15O3shAf5jUNwrMIzzObGdYmuGU0LBH6TdqThND5bKa/a3N
AmTPGvtTTPZz007yl03M/atPrjLE9w07ph8UILhd9Q8ZTNMaH1kfEvhstKl3
h7GE1uis/h1HBNZSf+/ZStiYF95gdFzxb0GKpySf5+lJfia5PH5AeiC9v+93
UsDRa4u2g/QiN/zb0wKy3C/oJRhbVYV2GZTzokxIb3Wz/YdWUn7Ek/0jWiR5
3jcKKV9Cyu1Mm3sU/dhXdql+/d+wJOO9Jv2cgvc3NtM4Xq0uGDHrVvmxWMBB
dK5N7Vbw/92RpRzP5p0IIQeqfmycaJSU/NHpVH0tpPPDNuw+UE9+Nhl0KhmZ
yfHvwzctrT8XOJtFNzpwnCE5DfxFQI63lJVKPoT+kiNwP9zPJz6O4+yQb21+
vkCNfdvPL+Vx7JuT1rhpk8C46+3dDrUcW8jAZZsFbGPuh+vbOEjeKwZKBRJS
R/I6e7gyb/xWNV/tbk7lxdcC1fIBP3H0lkZMLv9G4LW4+Te2zdTKejPP+LvK
/4y5WmTmOAfU1U/NR3kqz/+0eSpfzbWKnw61CpA8Q+9RHpM8PEzbVP+VXeVw
WGdUcYVqiucvbU7QPLI/2wWo+1s59RwnYuujQtqn8quUYzhxyZgH1QHUQPRn
HEYVxlYDtH8vAerxCcc8684hX6o/oeu3BXLYyYBN6e22Gwe1b1jQqu7XU565
BNTN/oL0eYQM1jMuwb17RWDpPoHp1M6SPkl5H5bv/ZW/Z/mkeIrXkP4XmVHg
F0iw55k5ZuSPDRQAueHqfjvCJ3JbwLxYHwlJSyjx/yGwv44SifT9vFVVpDf5
bQU1UKCRQHAYryA/NsnzDJI/yFC95Ndegm/4GIMb4TdeQXr9jhKumsn5F/Ua
+Z2OL5yby5BLdPC/CrjI8ktkOEJy+qBYYE5LnW7Vh0zxlzfpY4GMpy+T83TE
lPSjpfevzZnBhN6rDr2aV9326v5O0itNpzPMZyjLzwuPSRcoJTzrKG8S6IXP
/aN6vsFDXX8oWa3/xpmCd2KSwMeUR6PRDAS3//ZEtfbKZiq/VMtyGdnJQFVw
K9VxMuE9DIUE78oktZ+iIabgb5us7m9+ymT/G0JSBNopD64tlHDbt/b7+9TP
lxQ44d4SypvnpE1QvrbS+6MXkvz/Q2ZO+q98Pcvfs/z+H9sa1Zw=
       "]], 
      PolygonBox[CompressedData["
1:eJxFVH1MlVUYh9CMzAhREBSBVYjEHBkRXcF+EZxz0Z1zA4YXZAy1kZUiDLM/
GqMrIwZITEALRD4EjZEpkUOGAvKpCYYMEYQRI7uKKJqAInYze977Ovzj3bvn
fDzP8/t4jtu2hLC4FywsLAR9yj+xO6N3xI/D5mvf4+sHJEwaWjnzPH66P8Wk
KefoO3TTeWyHRHO064e5hRwUVo4GSqy0/0JM53Gseer2ZMZFYuqTSzFv5XDs
GT1sG28p8dp4XbXVPo7IdL/+b28IhIUUG1gmR9NEiX9ap8B3HncXNWVw7FcK
nhTIehL3yEj7XkrBfQKfPjJuPZLNEXji85HJJIHknlNRD3Of9acXWL3sYJ91
EUfo0PLkP/0EZuh4/1GO/o54H8MqYe538ixHFNXvcBZQrtcPc1wOunb/geez
/TscHinZ9TtCBF5cvOSD80YOU9e9i23bBG5me9yNGeRodXAPj9grMEn4uno4
dvkY6ppLBIJW3Ln+YyeHc+UtbckZgX8V/s5z3H+wISq9T0ATzJOs2znmV+Rp
bCcEnKhgSyuHmV4LiY/ovi/FCn17XCUiSo+fKGhV+Yh+T4K6Ga5t48gxTrmE
SQltscE9tYOD0NV9HKfqMXmBozxPYymSJQIp30ynGgfkSxw2uLemd3Ncv1Bw
1v4niULPZQcP9Kr89DRLWDbMX7xkgGPKpTchlvQ+5kUdbdbOxesUgyRr1fzD
EqML86tas7WYR3gsb0m88QM5JF+L3bVLTV3/SVXPNC0SYxd0OzroEFBEiOK0
cA8nBpx0qLYay/a4webiV5u8C293MxD71vWOOih2GfuVqXrZ6cCTHtuszmPm
fkqtdJi1Ga/TG9TzbjMSa3ZVWDbEM5wjP3kZpZnf92MZZPWBOIsrEtM54V8a
Q5nZn6dbJE6nkYPWMey0fly2/YgEpR+vW8Xwu6PiIInND+uHst5lqh6Jqh7X
OMPFNnJgisRLBEgfw6DAPV8k8ZVupb3nbgbbY40tAzUSPn/7BVdnqP1WUr1+
ZaGYmfXCJQnFXitaGFJJENNVifYaQjDI5vjO7B0ZXbj8uR7llGDQjiPC27Mq
uFFCT/24vsKxZW2Et6ZCYqeYzrlnxfEP+TUkU+IoCRpmYmZ99iZIFJA8duMM
s2XbTx3yl9ik4LnKsCm65tzEyxLzSI6lrQykbtofQwLktjT/kwyNLQ7uV34W
UOzpRHgW6YjQSKHO8zcM6/WUwF/AU5m/LIYERe831fnYWMbm5m0LEdRfy9Dw
PTn6dQF959r2mnYGJfR9RyCXnpdfLqv93d4g5vgwz89nApF0/u2/GKrseoIi
MwQ2/rYgoIjwmN+HUoGq1NCQ4lmGrcSH56DA/xBCL34=
       "]], 
      PolygonBox[{{53.422900000000006`, 64.71390000000001}, {
       53.46790000000001, 64.87590000000002}, {53.288900000000005`, 
       65.05690000000001}, {53.13790000000001, 64.97390000000001}, {50.0369, 
       56.42290000000001}, {49.99190000000001, 56.26190000000001}, {50.1709, 
       56.08190000000001}, {50.36690000000001, 56.29690000000001}}], 
      PolygonBox[CompressedData["
1:eJxFVGtQVVUY5TmkoEQMmdMokAh3HEMCQ/M1i0Syu/c5+4APBvABGmIqiQOi
+SxR0kC8oZEigybZVVTMTJBBMjUfjAZhSKCNA6RIiA+QvEYy9J19Rvpx5843
e5/1fetba23fBcujEh3s7Ozi6af/R958fV2Cg4L1CcGzgroUbB4kju+6y/vr
T8qwqaWJYx3VKfUKhlvbpgfe4nBQ6Ga5gife15fPr+OYc+Jsx7x9Cr5M3Lpw
7jWOWwQbvF1BRMPj7s8rOI5OiY7r/EyB7FfA8fKa0CNTtiiIci7K7fmYo+Fi
8lhsVnCnSwfkqBlKN6k+7PlreIOF9ddTj314e8VAjqwcutmjIJzwN03n+GDu
HxET31JxP/WUV8U6Yz73BBUjTRuy+U4OD+pXla7K+fOsHOGEE5OlotTr36vW
co7dFvc1tkIVV3ZX5FmqOF6qpoYnVNAWRsX/zpHrviZ0ws8qaDgX/z85gvp8
e9V6FZm0r84OjtsRjqu1NhUBM5yLrncbeOk9KvJoHw09HLGZ4+ufuQmU0Piv
9HG8QUDuPgIqrdFir6BtmLWtM0TghR7FOu/pAtceVl0YQ+ehJERzvJA8j/Ry
1BLxjlUCv9E8D2wcn5JO97Yb9eDHHObAPt/KAwLexDeglWMMzRtTKpAy36U6
8ibH24RXfEWQuJd3f0t6xbtUD81vFIYulRw/tNMi/xKSb8hRjrF0f4BNSH8U
7OF4kjMj7Tt7DU0FHgd3beFoyzYlO7lo2J90sj0khePZnYSv0101bKS5dsZw
mM5nBvQO1jC+/mLytTCOVWL4qzkemsSzmTjay45neHtqhr/ciY//+Uwr1TRW
ZJKNYVJK9VY3qjsKJ40+08TwcNCPQe/T971PVzZNvMowxyescwXhLz7Znvp3
KQO/4jJ570ANceRLWxGTeI3OmtQ1KpfhXJxPWJidhoLWYVbPTQyFHgcrf3ki
MI38ZE5laCZelXeF5O2yiKEuv3XY2noB3R7RsUz6a8wlIfmaNYaubnOMwykh
c/L4PYY39Q+KhNR9dhjD5NF1+cUWIefbPonJPNSuF6B1jC16x8CrWCJkH+t4
hirZSEBfx1n6vocaLQkWWEj6O85mWEsyRXsLkMy0AuN7MUTAzY8Mv5fBabWr
n8lPyHzuO2Lwsx8n8JFO6Hsm81o4U0idZ5UwdOi5edH/AJN+dt0gZB60HQzz
qO3pLIFMXcA0JvfWRnx0uwYn/l/r+pWkMJgoB+3FAqN1wI0MK8h3jecE0skw
Iy3GvF/dEFg24J/9SaSP7mvHVoEN2eVLt51m8CHj9XUZeIE1DD+R8MueC5zJ
s7j3tDIsst1J8CL/ybz2MdzLNj0Y5KDhUdWFd3tHkN8I6H6fkP6JncpBMT7s
2S1QSo4vm8tB7PwONQt8U3luiH8qN/SuElhJ853K4JLP4mMCNZSztB0cLfo5
5SuGFrAyjyOBgGuXCpTJBHFcTqbFUl5f85/hHELniI47Ee0voMt0K4fL3Jud
BL6gdyQuw3j/LrWoKMqdYK+kGe+X43kVeuzYAo5DRHvcAVW+h48Ujptkyz0Z
KgbT83xjHMdTc0xm/CIV1Lwiz4fj+VV6KMyqocc0hhF6MGYq/X6K0g9GKYb+
Lby//g8DK6hQ
       "]], 
      PolygonBox[{{64.3965, 60.407199999999996`}, {64.591875, 60.429075}, {
       64.6935, 60.58219999999999}, {64.591875, 60.735324999999996`}, {
       64.3965, 60.7572}, {59.511500000000005`, 60.7572}, {
       59.317125000000004`, 60.735324999999996`}, {59.2165, 
       60.58219999999999}, {59.317125000000004`, 60.429075}, {
       59.511500000000005`, 60.407199999999996`}}], PolygonBox[CompressedData["
1:eJxdVX04l2cblpLJqyZfxdSrYmVNpZLMxxlek3qe576FEElei7dMJUUqsT7k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       "]]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      BezierCurveBox[{{71.333, 61.0386}, {78.041, 60.3106}, {
       92.55199999999999, 60.7626}, {100.5, 51.4326}},
       SplineDegree->3]}, 
     {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQneaSmf8hM9LhhtAnx/N5ng53mTi75JMiHQoaWY6W
T/Z0EEo8fFk7OtJh6f19fHe2ejp4i/Z4vQqJdNjMU7im+Zqnw/mrYW/0/SMd
rj3P0v721dNBd8KCH4ZWkQ6XJsb8cy7ycthU/WlDwP4IB97CNd23F3g6FEjz
PuC9FOGwwvSstV+fp0OUk92Lm+8jHGz8Lk6MAdovtv0iQ51wpEO85mmB466e
Djv+tH+5rxrpUMY0i2O3vqeDr4Nw4mHzSIeVIP2Sng6n6j32c3pFOqzfllSf
yOjpUOexv7YW6F6FLzlhe196OBgJmtkw5kQ6dLRGXZ5yycNhQ0D2rPLqSIdS
oHnSezwc9tXKWhzujHQoAfKbl3k4qPFzbz02LdJBRPbk0/8TPcDuT1kU6fDo
5dRNR+o8HDStJp2uXxPpkMmQ38iS6+HQD/Ru0NJIhxO7dvTua/ZwyMj/0Lpy
bqRDha6i/Ja5Hg5B0xT7Zk6NdNACemfRLg+HFywmgma9kQ59bB/EPG55OJxZ
df7qpJZIh5Ag9QWJfzwcZpTPWXQY6D6g9i9rFDwd3gAD6E5RpMPJp/ZLnrt5
OqDHFwD6fMZJ
       "]]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      BezierCurveBox[{{100.667, 46.1108}, {100.517, 51.1098}, {103.5, 
       52.2018}, {104.6, 52.8328}},
       SplineDegree->3]}, 
     {Thickness[0.005317938980894221], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQzWE7O3R+eJTDl5yw2nXvvBwKz3VcUnOJcpjS3hrF
/czLQcT+2J2vhlEOksXXhTbd83K4/4B78kGFKAe/ixNj0m54OexhFRKxF4hy
+Of86+3rS14OAXJiWb7nIx2S62/aVh7wcvjF/3L7evkoh8I13bczVng69Gm8
5bXTiXJ49/qA5eOTng5l/kANjlEObqqlTLP+QfivoqMcYoEG6tp6OVgVnOtQ
yopyWM7lpmob6+Xg97kvuKQiykFU9uRT+xoIf0J7lMObA5bKp2Z7OWzWy1uc
OC3KgSG/keXoTi+HRKCBp5ZEOdSu25b0/6qXgx3Qu6s3RTn0sX0Q8/jg5aCf
t5jxxX6Ifbkc3g5SB6IVEs9AzZfzdniauPDaj+tRDo9eTt3UY+jtUKoy/f+E
RxD3Kzt5O4TPX71W4FqUg8aCzg2WFt4ORzfq5T0+HuXwYB/fnM+63g5A4/fo
7ohykAMal6Ps7cAECrDlUQ7P7Jfc3yfh7aDjLPN615QoBwcgl43P22Feg9oh
t8YoB8NyXcV4Zoj6OzlRDgctlb0e//ByQI8vAFf1xTo=
       "]]}, 
     {RGBColor[0.925756, 0., 0.], Opacity[1.], JoinForm[{"Miter", 4.}], 
      LineBox[{{167., 46.1108}, {167., 102.36179999999999`}}]}, 
     {FaceForm[{RGBColor[0.925756, 0., 0.], Opacity[1.]}], 
      PolygonBox[{{170.70309999999998`, 99.5532}, {167.00009999999997`, 
       101.1262}, {163.29609999999997`, 99.5532}, {167.00009999999997`, 
       108.3312}, {170.70309999999998`, 99.5532}}]}, 
     {Thickness[0.0026589694904471106`], PolygonBox[CompressedData["
1:eJxFWHtcTdkXT0LyaCaPKBKTJnkV8qjuuevecw6R0aSmodLZk1eRGIzJe0jy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       "]], PolygonBox[CompressedData["
1:eJxFVm1UFeUaRbTID0IkKEMkNEUSUMhQmPec2R0RuYDIxY/ARHkEBEI9KeEX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       "]], 
      PolygonBox[{{148.32230000000004`, 42.4604}, {145.49630000000005`, 
       40.2084}, {146.00030000000004`, 39.5104}, {148.32230000000004`, 
       41.0094}, {150.64330000000004`, 39.5104}, {151.14830000000003`, 
       40.175399999999996`}}], PolygonBox[CompressedData["
1:eJxFUn1MzGEcT2EtrXJojZiMK+m0M2q6+t3nnjSa0rwLq3xjWk3sKmOrvAvL
kkOmFWnVH/qjNRoJycvsNLV2Q96uoVazq6yXU5N8f78z92y//fbZ8zzf5/MW
QAc37XN1cXHR8Sf/f3bEk884wUVe1wVC6ssGav4Qlu4uahmpF8hUnWo2TxKe
jQTtLjILrA8/b0jh/cu2XH1Oj4AxrdiWy/d9dqy++2pYoDHW0/XOMGHnXp3V
e1xgLD+9KdtG4Fvd7Yw9XZcV+M5zYr6tXzWbUF36fGFdugETliN96lAnfv/G
fuoM40hrgib6uAGXbLlPxhkP1rxcP3zFALdtXprlWkKOyW/q44cGBBf4Jr5e
QWgYmrAEWg34wAQ+rSSEJTXGxk0a0KvWnssIJ2Qz7xh/IZ/vPBnhmBcaJpBt
8jsdIhE07MOieIEbTMMoCLX+rGiPQBbvJ68l9DNtk1FApjsRR8jieWtOCIXf
1s2EJh6UcVFAlp+1kxDHvi0sUfw6kEKE2zENQ/nlArIN6gwCViU1VlQKNJsr
XrRnO/RXVgvw8+LPUQI/X5pco2Bj2jECy64vY3xzbujnxXVOrPjpQ5DjC2qV
wLZs85pBKB9ggfslZX+fJ2EWxxqgkZS8A/n8kuknrkZ7S7Lfm4fmEEY5bjFV
grssfP6/PFwlHH7ML9qd+MfG+wvOTEl19KUdil5TD/3HqTpr24VugoVrllgN
qLXukaPfCZ/G8s3WYih5b2LszfTtecBZ384Nlq+Emdynb9uBCGvCRXsXQZYX
uhLY4qVZUfWFIHm8q7SpALmeLz46+KT06uWcvhvek8JbVadHklxICzl6l6cH
17Kt/43ip644QY9xJjz4ilB5KMqjJlAv9zZ58KnjfO40vZxHzNsHpPzD+iTs
L7b9vsB+87TOXx0SrmWqTBl3lPe7gswSCksyVfYqR/96WyRo3WsLg28R+tTa
dVGPJLA9s9xuEFp5BT+QEFBnvJ9nInAsI/caJOhYb0khoZNz+HZPQiITTtjl
xH8BeL+pPA==
       "]], PolygonBox[CompressedData["
1:eJxFWHtciFcfT1rUktyqIYViJKR5c2t+UUITNc/znE9IpcU5yH2S2KolpJsk
UmhpKQkJIUkUKl5NF4kllpZECJPi/Z3z7H3f/vE5Hv3O+V2+l5/B3qvcftDU
0NAw6qKhwf9MPXDN7GQxg5sNU4/U5RNIf/X7HO8CBmds/y70KSHwjceFWXpn
GTxuisvWO0+g8O3XC6MSGKyr7v3afiOBo8XO7+PiGQRrFUUNCSLwne0O+xl7
GDxYprGK7iTg1ztEIyWawe6Fn6b3iyVwZ0jth6xdDHIwvvkBAuNsbN6s2M5g
vtvww3t/JSDrW2XXhajxaDqB9q2sQ+cnBi6/6c5IPEHgj7kR8S82MSiOst5o
dYZAsbPtrOj1DD4Zr6secIHAajvd6ld+DLQSug/wxXwSX6ZpG1IGTczynW4h
gR5W2UmfvRnkP+lrolNEILigxOvUQgax+L7F1wlcXB9rPFpm4G812FTvJoGA
vllh/nMZbM06662P9djK8tbHzvx/fR6nHtC6ai/qs1sTzysaP6Z/nMTAob2l
ue4GgUcBff3gGwZY3CxNjN8tc6D7HisGZQbXL6y+RiCt2Hlj+zCR78sxVwhs
M6y5vcGMQTSmN+MSgeWNH6lOfwYF+onfn88lYBLa7Jrbh8E9LH/UaQLek+ui
QnswSMmxvXfrOAFNLOD6bmq+AWkErpqdHBfWhcHazPDNiYcJMHzflY8Uurca
zpywn0DB268Th72j/Pvk+TEEwuP9ep9vpRBAjo5/t53AbmMtw8BmyuMZmv9M
IAHHZe1TCtvc7+Y9+VHEazpUT2HAQQ+dySsJlJaVlWk/FPFqxywhEIT1zbhH
wbXDuM8NQmA+9jeigor+6rgQ+FLT8vrpOxRuT3axbp+m1s/0FoUO7OchWwLY
ziUVNynP10tjFAHHs286K4opfH14x8nBZgScbXcEmV+jvB+/6vQlgOV7X3SF
wqx5Hcb53UQ8mneZQobn/NcOHxXom+VUr5tPeT/0j7xQoNK/yTcnj8Kn6e1z
6usVwPZr5V1U36dZqQBOf6E5nt/FPzzd44Yi3vfqAgWLDZoJ3S+Kf+/gjN/z
9RNt9DMU6D/mofk8jPeiuWBi1wQFTia9XNp2iQq8NOxUIBIBNKqAQs9Em19z
AhX4IigupLlQvW/lKgUojtcwzG9X7TKNnksU6Ekmri+/qcaLVxSYjfh6hPVB
eAVpzVHAz07XyOl3Cnk4z9J0BcrneBu0V4l83cImKVCE+GippfDa/t+++8cp
cBAf2Bf7xfG2w1K8r9EH+8nxKVsoMC93UGg59nu55bv4TlMFkA3uuLyigOWu
3zJAge32ng133qnxKo0UQDhvZTjfJpxA3suwuOHOkFtTGDxDunB9I4MHno85
Mtj3MDYstEXm/X9tNpvBAhyfO02yyGebizrPqxpk8d5SNwY+mMCMR+r3R4hH
HMdbk++L+N5n3Bl0x4Ebf1cW75nkwaAE8WRcKvN56OLlxXi/YkuvyDAqO+ml
kQ+DOt6gc7LId64v8hM+51/H1Pd+WMrAERt6IUkGLP+9rsgXfkFaRSmRIp69
J54R/j/VbJHBv2nYYDs843hmm6+XQbc6pbVimYpXPyZDVOFb/xF4vm+3acJF
TxkQTiFTMD7vTy9FBnxOdU+8/7NfkPmGOTLnR0jF9yFc459Pl2FhVGHoJ+Sn
qz4ZBYGTRPzVJpgPVrtxpLUM3TMHlnRdzEDekiV3DJcBn7/gNPLXoLYV8rtB
Mlh3z3xuhfV5aThz7CBDmfOX0waFAafLTT1kcMsdND58PoOiKOt4vS9kjqct
a1xFvLMPOyQer3kE9kN3hkXlqzYJCkqSHc9iv3j5XVok8PX1lY2dRH1t/m4Q
56eu0xlcyI3QfvuHBC4R8fk+U0W+nbPuSXAq6WWa22SRj2dHuQQD3X2Wm9gy
iAsLDehVJsGg0Oby4nEM3mO/IoslcKoPODJvNINT9U1v/a9IMAwTyhvBYOfJ
+qbKPInPwyk9CwYz53XkZuRK4IDvn4Z8eVpvTWZHjgQpq+3uLx4g+tGj/JQE
XK58DRmgfFhYnZAA0/ElvcT77AyPS7wfw231GKBcHIw5JsHkurlJWsifXxRF
xRzJUH+/sIv6/vkZ4vucXe0U7DaRr3/DM9e7qtcUsPxbsvH376Ws3lL4jIJL
ecyDAxg/Egdg3WPBT4W/nBT59tK9T/n7jkfliHgR6eUqX9WdlwDpZ+86xPsM
iw3BcQUSVGFCO6/8g7cbEpx507mnJ/IP6ue0K79LXF+yLE4LfordjPVHfUl4
kUnBtG1F1bDnEtxHeO5KowJ/DR8lWBBVeGt8KuX5tO7VkkGnOmXs4BTK9d/8
Ps7HpLq5lW7JFJCu1pw2EvPRefsQhYEHPUYMHyLDTyzv+f6DFAonDk2YaCXD
t7rVT84lUd6/Pi8nyIDjamGF57+Y5VNnRxmSeYBEqtbPTcWjCX4fMntzSNpC
Gcy1g+LW4blg4tDZF32RL5BwgzH+NTGwsuDrgMMUlvxUY7cpWobeITiRyf/w
1z4VH3b4vn6cgFJkEH4mgcKY77DjqTKcWLsspmUPhQko1xmHZVGPG7spnEM4
N8TKwg9ERVK4xP3ABhnK+E8whY8tSLhfyXy+fX3XUtgcghF3S9xv7LBfT2E2
/4udEngZkIk5/qKfVoPDJEB7gpCmsAb1b9k+ifsbG5tDKn8PvS+B25PU2o9Y
75GlBtetb+P8eBuQPulCP0csuSoJvV2bRYW/ycB52IvRDHLUf9+O84P6qtd4
Xr3fKV2CI5jvi8vq9+BfJdgzPXzUINSPEqTjw4mSyG9VGYVRfEDiJe536u+j
XvDyzY0V+PUlNRS4IBZHSTAyzHD/ozp1np7vkmBa+IrG5agPmJ1pDuY7uPZD
/uvnan8Mdkh8XiJWvqHCH7Zh/p8/f75c8YHCHeSr7/H8mDdEg/2vPoi/fIr4
+mpd9e7dYQIPMYf1GXy7iRyt3y6+Rxb2YzDnN91i7XCJ66/mrYGqf2yPQHzd
fj/50lAGHp+mB+TESHwedkaPZKJfVnslcM0dZOdgzeB8hPZqjwMi3+RK5Jun
aG+/TZYguiWw27RvBZ8uvZ4mwdKYlrxtDiq+W7MkeNVZYZCMfIf6PCT7rCT8
VuQ8Blxuv7gswV3/ptvOqEdY3sX11yXQsAyrqlrAAOknfCryW1RL4LlRXiLe
I6NaCVbiA2cj3yvIr97Il780u8Lo5QwMTW7+YNwqQX5JcmjFKpHvDGvEp66m
Zd0k9LPOm0NOpGrLfF4OePiLfNtX9pZ5Pjp2gQzuxizcGox8j/H876I//hv7
VTtS4HW8Kfrn/ljfNbaodzj/JtsYbA91vzvFQYZTa5fVlKLfjkH+Ge8qw7ju
mQuHhzP4GeE130MGs9BmahXBILUuPzJmuQw+SFC1ker7GvxlaAmcumh0tPDf
7522yXz+Hg2NYbAI33cqVujjiPN49prvljYgWeb9wA4zzkdcskBL1j+ejWfO
n/V5MqA8FPeMUfnXvUTm8+KgHy32AbPWKhn24895vD9Su9Xw6GOR7wQTfN/S
ysZn29FPcDvuEK72Zz/6D7GvhGE9EO6eOgqfL9cVwQwCEa7jjBXB1wVbVD20
N1fgMfLnEtwnJiFhF1gp0JUvIBsYhHJ/+40CiO4bD1Yz7k/LH9opEIYGsxH7
dxH1bp6jAmvQoDr6qn4+z1mBts4Kf7pYve83VwVa0eAXyUKvjKPQv+F+YpSI
eovHN8fcFXBAfJU6q/7iwyLxvTplFIMp+J6FfoqajzZT/WaIIvjNGPGEdqyp
y3bhD3O6ox5heWaOjVLAGAts0Sb4X07ep4A356cXVOi79xEFYrCBnU0URiM/
BmcrgPCydEJ8jxps2qZ3VfW3j/+kMHT25q5TyxQY/dBcu+YJBaxG315ViuAb
myeqvv3ySIE/+UL3WPXTic0KeBqQTUFPVD407FS4PnfqN1BYgf4mVJ8IP7yn
Ee/H+66aEriJAtG1WeWLjLGE+4VGl5dU1KuvPYGd+KClbWq8mnkENjYNewWY
L9Jl6d3FYr8rLsV6cL/6EPcP9Lehc7VUfxK4nsAAd5/N7cg3nH/vBBA+n00l
XzLA6v5RgfsMr9flnup8hm4jgO52ZGUfgdeqB+EEcm78uPVLY9WfVEWL35/l
OVDsg4Ur44jQo3Iz9f4k3KfQP033sBB8NtMrSeyzr7siP/H25eD+dePHfKMr
o1V/EpNChD7G2qj88SZV7DdFAROEHzxXlSbed3udHYMRyO/j08X++d2WaQyu
X8ht+TKDwAMuoE7/9Sfq/uWFfIX1NspPF/tjeg1hgPAoeoPxJBzvNk+xr457
doQI/56BfrWqkVnuPazuX69Xqfz6PIEIPbz2o+q/6mPV+4wRP6uDtByXY324
PW5AfJlxfOP+z/enocgvx8Nr/9LD/ZDPz03c97k+6VPC9eHzbcR3+vhbFze6
E/g5DgVrjzrvU2aLfc6+Zq/oXx+3CeL+zGfxjOv3nnOjxf8H5JXtU/eL4+a4
TwfFLdm6X+TXz7o/AQssx6f94j6naT1xfuw9Hb9LEHicUteVqHqeIOoXof23
ipc5eOb+6sMzRfgtXTzjeBksrVNgGQcMxmvkBh3xwPnGGO/n4xZ7ToFFXKAO
MeDyZpqpft93hMFzbmhOKqLeSWkMjPhAI77+AzkyAlg=
       "]], 
      PolygonBox[CompressedData["
1:eJxFVglYj9ka/99IWVIx2cO0SpO9UaJekrIV+Z8jdO2a+o4lo1GRkoYsc0lT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       "]], 
      PolygonBox[{{228.06640000000002`, 98.96190000000001}, {
       225.24140000000003`, 96.70990000000002}, {225.74540000000002`, 
       96.01190000000001}, {228.06640000000002`, 97.51090000000002}, {
       230.38840000000002`, 96.01190000000001}, {230.8924, 
       96.67690000000002}}], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQfeqp/ZL7c3Ic/loVnOvYFebwV6L4utCDHAfmPaxC
Iv7hDid27ehd9jTH4eeTxIXTIsMdSq4LfXJ8l+NQs1THWSYx3OFllvY36a85
DmbvLVz3J4c7hAWpL8j8l+PwP/X7k4Wp4Q7ZDPmMmiy5DrEKjh+90sIdVL2q
m3dz5To8NZM6cBjIP8A3x3iRVK7D177gEpV0BD/6685bXXPDHRZvMf9x6GeO
g7xYlu/nWeEOVRErTM8C3ZNY5i8nBuRvfPhy6qZVOXD1MD7MvDsZDPmNG3Ic
0s7Eeq8A2re2+3YGw7Ych+9A5X9Twh1k5sVpeu/OcehYHn7qEtA/Cl9ywmoP
QPx7LSbcQWNB54aHQPlnQK4JMDxu2VZGrOjOAfsn+UmYg8gnx/NpwQj7fh5K
WZWQhcmHuQ8c3ioI93e0Rl3e8zQbLg/jo7ifD2EeOH4yoO6bEgYxTybH4fX2
9czP34Q61K3blrRZAuLfHU9DHUDe6RPOcbAFRm/Qg1Cwe2p4IeaV3Al1CAXG
VydbjoOIiP2xOzdDHa7seSxy8F+2g9zrR2ZeN0IdHJfc36f3Ldthxv8JddXX
Qx34Ctd0334EdR8Sv0/jLe++BaEOWqcFju9iznE4yW47O3RxqEMw0PgN4pDw
NVoS6rBhW1J9pFmOwyuQexeFOkxtB3o4KAeuH8aHma/zbfpdZe8cB3YhEXs1
oHtuAJOfv0uOw4WOS/ce3Ap12MwDdIBtjsPbR8AE9RiifrIjVP/7UIe0VQkh
QZVQ9dlhDnqK8l9ydiDMB/mPbxEmH+ae/86/3r5+luMw/QpnhhLQ/SrA9Kuv
lguXh/Fh+u9NBnrgL8I8AMlInf4=
       "]]}, 
     {Thickness[0.0026589694904471106`], JoinForm[{"Miter", 4.}], 
      BezierCurveBox[{{198.40040000000002`, 90.73100000000001}, {
       192.02640000000002`, 90.275}, {178.2364, 90.558}, {170.68240000000003`,
        84.70800000000001}},
       SplineDegree->3]}, 
     {Thickness[0.007976908471341332], PolygonBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQZOqQ7mUgeiFZ6GOJRMlmCJ8E51YHneoyH6JsRh
xTFvc8mQVAcrV/ciy08hDrZc1xenxaQ6fNt5q2vr9xCHm+e+ByenpDpEnDI6
svFPiEPQDrnW182pDofaloef4gt16J2eJ9QclOrAlaGUU9EX6uCXJBCR6Zvq
MK9B7ZBaTajDGpmolN0uqQ7TrnBmKMWHOiQLRFgesUx1WNUU6FlrE+pwqmzf
/CvGqQ4SU69wLtEKddBuF7t5TjfVYfJKoALJUAcQN1091YEHKDCVPdQhaw/Q
B4qpDosZ97Bu+hbi8LbG3vSdVKrDmhvxZbufhThoxvQf+iqS6lD326rg3PUQ
B9O4XZ42/KkOWb6f+9hPhUDM50x1OLJRL695b4iD8u2fdbtYUh0eck9eGbcJ
op6HIdVBxP7Yna0rQhw6HROePmNNdTB7b+EavD7EYdXHS76TeFIdMoHejdoW
4hAIDI+/wqkOzxIXXtsBNM/6vn+vuEyqwxMzYIAfDXFQ3FCUcV4l1WGWlsRU
g7MhDiDni+ilOjgAjVe5GuJwAuR/c4j/VO+GOKDHFwD1qrwA
       "]]}},
    AspectRatio->Automatic,
    ImageSize->{352., 191.},
    PlotRange->{{0., 255.}, {0., 138.667}}], 
   GraphicsBox[InsetBox[
     GraphicsBox[{
       {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
       {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -2.6678041342529504`}, \
{-5.628231475275794, -2.6678115445620056`}, {-5.421788280513543, \
-2.667160690753425}, {-5.212399735329252, -2.6653073051928438`}, \
{-5.00325118175986, -2.661938371970305}, {-4.794342619805368, \
-2.6570538910858095`}, {-4.712506466827043, -2.6545439121544314`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.688905571864801, -2.6538200542143766`}, \
{-4.585674049465776, -2.650653862539357}, {-4.445905536559083, \
-2.645345021281961}, {-4.3067648732861805`, -2.6390343139498875`}, \
{-4.1682520596470685`, -2.631721740543136}, {-4.030367095641745, \
-2.623407301061706}, {-3.893109981270213, -2.614090995505599}, \
{-3.7564807165324705`, -2.6037728238748135`}, {-3.745903008894787, \
-2.6028923914969266`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           
           ArrowBox[{{-3.7223723854773336`, -2.6009338269914393`}, \
{-3.620479301428518, -2.5924527861693503`}, {-3.485105735958356, \
-2.580130882389209}, {-3.350546997480164, -2.5667518257028115`}, \
{-3.2167903057628604`, -2.5522244502136493`}, {-3.0328115232337622`, \
-2.530333572005533}, {-2.850780545401912, -2.506574172855656}, \
{-2.783771696835819, -2.4970380380430997`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7603952341837066`, -2.493711296813225}, \
{-2.670697372267309, -2.4809462527640176`}, {-2.492562003829954, \
-2.4534498117306183`}, {-2.4692272151538517`, -2.4497050673109517`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.3378161183196577`, \
-2.4274791142736163`}, {-2.230593088152367, -2.408391585011152}, \
{-2.034117496260978, -2.3726840783687524`}, {-1.840998526072801, \
-2.3361111112974533`}, {-1.8296499289650492`, -2.3338721337898516`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8064844757926708`, -2.329301795437552}, \
{-1.6512361775878368`, -2.298672683797255}, {-1.464830450806085, \
-2.260368795868157}, {-1.3300014963870224`, -2.23247414497471}, \
{-1.1968791013530922`, -2.2056942621659803`}, {-1.0654632657042946`, \
-2.1800291474419686`}, {-0.9357539894406304, -2.1554788008026744`}, \
{-0.8800504161911398, -2.1457078803789327`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8567935015558512, -2.14162840308606}, \
{-0.8071077280314303, -2.132913060227806}, {-0.6788809369460265, \
-2.113201763697072}, {-0.5510736161844187, -2.096344911210472}, \
{-0.4236857657466071, -2.082342502768006}, {-0.26892460907294624`, \
-2.0691242080265813`}, {-0.11129360081258652`, -2.059790671658014}, {
            0.05010740445437556, -2.052949247576246}, {
            0.08254347039483564, -2.051827761231128}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.10614136254870497`, -2.051011857296517}, {
            0.2161785521478434, -2.0472072896952205`}, {
            0.3867793620144847, -2.040542029170647}, {
            0.5617693538009683, -2.0309306971582357`}, {
            0.7399035334868286, -2.017056156908257}, {
            0.9199369070516001, -1.997601271670982}, {
            1.0473699978610307`, -1.9800441002433486`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0707610288576488`, -1.976821386751365}, {
            1.1004801138290303`, -1.9727268217824023`}, {
            1.2801437931528636`, -1.9425935875785107`}, {
            1.4582746747369393`, -1.9083054250647902`}, {
            1.634219488295096, -1.8709661902467234`}, {
            1.8637155649102648`, -1.8196476135002202`}, {
            1.9962414441263054`, -1.7896489890824354`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.0192708056604864`, -1.784436051267331}, {
            2.0896582631649174`, -1.7685031111209308`}, {
            2.31335637067389, -1.719731522750578}, {
            2.536118675052017, -1.6755316880308846`}, {
            2.7591250494440507`, -1.6359395893189919`}, {
            2.9466251210642107`, -1.6067420018915188`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{2.969955935758747, -1.603108917936341}, {
            2.9835553669947408`, -1.6009912089720413`}, {
            3.1389523352175877`, -1.5795386768322233`}, {
            3.295494460151299, -1.560053869548085}, {
            3.4531817417958757`, -1.5425367871196265`}, {
            3.6120141801513177`, -1.5269874295468477`}, {
            3.7719791856707205`, -1.5130754719454231`}, {
            3.9088385478001872`, -1.502366241655622}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.9323785824286612`, -1.500524236491023}, {
            3.9330641688071792`, -1.5004705894310275`}, {
            4.095269129560693, -1.4891727820036609`}, {
            4.258594067931265, -1.4791820496633228`}, {
            4.42284465269925, -1.4703066329796788`}, {
            4.587826552645005, -1.462354772522394}, {
            4.753539767768531, -1.4553264682914682`}, {
            4.875495821308352, -1.4508534407119837`}}]}, 
          {Arrowheads[{{0.016051864801428565`, 1.}}], 
           ArrowBox[{{4.899091948535454, -1.449987996768921}, {
            4.91998429806983, -1.4492217202869015`}, {
            5.11203446196108, -1.4431133706696224`}, {
            5.30437624107148, -1.4377720672139171`}, {
            5.497009635401031, -1.4331978099197857`}, {
            5.656854249492381, -1.430043412282737}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            2.6687014448852087`}, {-5.628575646685763, 
            2.6687089483243502`}, {-5.4217519770536144`, 
            2.6680575308658114`}, {-5.211955500909859, 
            2.66619867593964}, {-5.002399935865031, 
            2.662817349966801}, {-4.793085281919133, 
            2.657913552947295}, {-4.712506558938833, 2.655436816905503}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.6889057118049955`, 
            2.654711401230605}, {-4.584011539072163, 
            2.6514872848811213`}, {-4.444246255419217, 
            2.646167793788346}, {-4.305109829003859, 
            2.6398461484134423`}, {-4.166602259826089, 
            2.632522348756411}, {-4.028723547885906, 
            2.624196394817252}, {-3.891473693183311, 
            2.614868286595965}, {-3.754852695718305, 
            2.60453802409255}, {-3.7459025499368046`, 2.603792195825433}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.722372114725495, 
            2.6018313714828363`}, {-3.618860555490886, 
            2.593205607307007}, {-3.483497272501055, 
            2.5808710362393366`}, {-3.3489864093726798`, 
            2.5674828725548484`}, {-3.215277562492505, 
            2.552946731399905}, {-3.031326541585109, 
            2.531041045409627}, {-2.849324803778895, 
            2.507269961447205}, {-2.7837711143518495`, 
            2.4979362038070008`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7603948859764293`, 
            2.494607816768754}, {-2.6692723490738626`, 
            2.481633479512639}, {-2.4911691774700118`, 
            2.4541315996059296`}, {-2.467838968079956, 
            2.4503863831843447`}, {-2.444546998600464, 
            2.446612201231679}, {-2.3364763340739008`, 
            2.4281623379317}, {-2.229297341425842, 
            2.409077958286527}, {-2.0330390421392837`, 
            2.37340528563872}, {-1.8401311954067112`, 
            2.336875680639547}, {-1.829642873147605, 2.334807061509263}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8064771541841416`, 
            2.330238070565741}, {-1.6505738012281246`, 
            2.299489143289007}, {-1.4643668596035238`, 
            2.2612456735871005`}, {-1.329537202027628, 
            2.233370449933564}, {-1.196412321023544, 
            2.206613999176361}, {-1.0649922165912717`, 
            2.1809763213154922`}, {-0.9352768887308112, 
            2.1564574163509573`}, {-0.8800165048145531, 
            2.1467794927133936`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8567584982472705, 
            2.142706245378355}, {-0.8066218776608529, 
            2.133925662416497}, {-0.6783827236000886, 
            2.1142494376458516`}, {-0.5505594265485172, 
            2.0974287420390216`}, {-0.4231519865061391, 
            2.0834635755960065`}, {-0.26836191761590505`, 
            2.070286971147605}, {-0.11069605175971695`, 2.060987427768457}, {
            0.05074210849906302, 2.054171279965361}, {0.08259576032314508, 
            2.0530731482258036`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.10619373467151866`, 2.052259625030274}, {
            0.216849060597073, 2.0484448622451144`}, {0.3874817057271532, 
            2.04178887092594}, {0.5624969450821427, 2.0321840023260616`}, {
            0.7406509469954623, 2.018317726974506}, {0.9206998798005332, 
            1.9988775154003002`}, {1.0474344642031608`, 
            1.9814336915792419`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.070825921996213, 1.9782140773706733`}, {
            1.1012577860206438`, 1.9740254174473324`}, {1.2809387081790824`, 
            1.9439234829594898`}, {1.4590914701873967`, 
            1.9096731049324485`}, {1.635064895957135, 1.8723756763618842`}, {
            1.8648116687216236`, 1.8210704099158144`}, {1.9963653426804302`, 
            1.7913344844821872`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0193963101535357`, 1.7861286463566857`}, {
            2.0910075282029177`, 1.7699419008554202`}, {2.3149621321418308`, 
            1.7211877590865}, {2.5379851382791756`, 1.6770055945148508`}, {
            2.7612555214872487`, 1.6374311913274282`}, {2.946781225583616, 
            1.6085897755872967`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.9701129710728913`, 1.6049626740227092`}, {
            2.9859522566383445`, 1.6025003337111876`}, {3.141600425034927, 
            1.581050898793921}, {3.2983948131616057`, 1.5615706809295884`}, {
            3.4563354210183794`, 1.5440596801181903`}, {3.615422248605249, 
            1.5285178963597266`}, {3.7756422199086415`, 
            1.5146145270583973`}, {3.9089929619322255`, 
            1.5042038837282177`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.9325333262067783`, 1.5023660961568404`}, {
            3.9369822589149877`, 1.5020187696184029`}, {4.099442365624287, 
            1.4907306240397429`}, {4.2630225400365385`, 
            1.4807500903224178`}, {4.427527697637862, 1.471885185612149}, {
            4.592762753914376, 1.4639439270546588`}, {4.758727708866082, 
            1.4569263146499467`}, {4.875647821067172, 1.4526519942229916`}}]}, 
          {Arrowheads[{{0.016048651079750714`, 1.}}], 
           ArrowBox[{{4.8992440516301174`, 1.4517893723147874`}, {
            4.925422562492979, 1.450832348398013}, {5.114897846820877, 
            1.4448231410286185`}, {5.304687778590475, 1.439560598741194}, {
            5.494792357801774, 1.435044721535739}, {5.656854249492381, 
            1.431836822534929}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            0.0005099147223225828}, {-5.614045035798889, 
            0.000509896862148913}, {-5.45709150477684, 
            0.0005095813923242737}, {-5.300343688847845, 
            0.0005090160201355309}, {-5.143801588011904, 
            0.0005082007455826845}, {-4.987465202269018, 
            0.0005071355686657344}, {-4.831334531619185, 
            0.000505820489384681}, {-4.712374529592222, 
            0.0005046265161748425}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.6887625365954415`, 
            0.0005043895282243661}, {-4.675409576062407, 
            0.0005042555077395239}, {-4.519690335598682, 
            0.0005024406237302634}, {-4.355177838705192, 
            0.0005001573306367508}, {-4.190915266673364, 
            0.0004973861552711381}, {-3.975236786638663, 
            0.0004928659914194406}, {-3.759611063008718, 
            0.0004872641051227555}, {-3.7442828168550295`, 
            0.00048677617913503077`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7206708238690225`, 
            0.00048602456640097543`}, {-3.5435591478130366`, 
            0.00048038677923271526`}, {-3.3266020930811284`, 
            0.00047204029660095236`}, {-3.297960377561696, 
            0.00047084395045735397`}, {-3.2692889803835756`, 
            0.000469617214133102}, {-3.133411154277462, 
            0.0004629636962161674}, {-2.99635650847591, 
            0.00045547727483312504`}, {-2.8617377425701314`, 
            0.00044761545835505796`}, {-2.776191105033683, 
            0.00044198944757104425`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7525791120867753`, 
            0.0004404365948724825}, {-2.7248339068671323`, 
            0.00043861191972141203`}, {-2.585645001366914, 
            0.0004284666589321872}, {-2.4441710260694762`, 
            0.0004171796759873836}, {-2.2436595012159026`, 
            0.00039903793289275164`}, {-2.0328174867132467`, 
            0.00037709682085157686`}, {-1.8743718848497946`, 
            0.0003586295651219406}, {-1.8080993966273688`, 
            0.0003501628404401174}}]}, 
          {Arrowheads[{{0.01741466619689049, 1.}}], 
           ArrowBox[{{-1.7844874038220928`, 
            0.00034714626074568226`}, {-1.7053453899817113`, 
            0.00033703537371058815`}, {-1.573867230599304, 
            0.0003191269604781896}, {-1.4319187946164633`, 
            0.00029894398973325816`}, {-1.3140861622861484`, 
            0.00028227273233066976`}, {-1.1855324500353122`, 
            0.00026484320850703104`}, {-1.1167660999288185`, 
            0.0002561457395440388}, {-1.0442669515087548`, 
            0.00024835553938238453`}, {-1.0255393911934936`, 
            0.00024665463321237567`}, {-1.0071137056967354`, 
            0.00024513419778693504`}, {-0.9919168843703915, 
            0.00024393123675677835`}, {-0.9782430573772536, 
            0.0002428298979663486}, {-0.9707104627168346, 
            0.00024221899499535652`}, {-0.9663584063558541, 
            0.00024186667726030817`}, {-0.9620974581308767, 
            0.00024152257823604402`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -4.160207907142072}, \
{-5.527815661385164, -4.160159059238797}, {-5.316686659844921, \
-4.159288877275903}, {-5.1008667366339004`, -4.157274818689604}, \
{-4.881507025929927, -4.15394274571651}, {-4.7124510373758, \
-4.150264864480127}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.688844630144675, -4.149751297566844}, \
{-4.6597586619108196`, -4.149118520593227}, {-4.437557173469616, \
-4.142386508447086}, {-4.216210573727183, -4.133524272092839}, \
{-3.9959287232030785`, -4.12264747029823}, {-3.776921482416859, \
-4.109871761831003}, {-3.745364092641306, -4.107734094582059}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7218060866499294`, -4.106138297901271}, \
{-3.5594875477178505`, -4.095142996102255}, {-3.343854546791564, \
-4.078542870008401}, {-3.1301257371618374`, -4.060390813545161}, \
{-2.9184043763525085`, -4.0410062567082505`}, {-2.780650774554544, \
-4.027511466712207}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.757151272296593, -4.025209379188952}, \
{-2.7090850784669662`, -4.02050065881305}, {-2.502329372344959, \
-3.9991518557192087`}, {-2.2978908876148627`, -3.977528842238853}, \
{-2.0955232539050543`, -3.9562006131841088`}, {-1.9360605428152595`, \
-3.9399768771122177`}, {-1.8176295502159854`, -3.9286093481933078`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7941255801041012`, -3.926353333495702}, \
{-1.7777213428419893`, -3.9247787824649536`}, {-1.6203195344901449`, \
-3.9107639002809305`}, {-1.4656542728790187`, -3.8964090438535433`}, \
{-1.3110888651613712`, -3.883946469563162}, {-1.157088610074951, \
-3.8729822498132513`}, {-1.0036535076197577`, -3.8635163846038103`}, \
{-0.8523971189261402, -3.855632971990317}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8288074373230931, -3.8546082457761948`}, \
{-0.6980930552560486, -3.8490133716188164`}, {-0.5451962946535203, \
-3.8438435314682167`}, {-0.39209327598820826`, -3.840039353483041}, \
{-0.23878399926011218`, -3.8376008376632895`}, {-0.01351067103638609, \
-3.8354988154975125`}, {0.11538705935908289`, -3.83483481443924}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13899873907103721`, -3.8347131817288096`}, {
            0.21343998125378133`, -3.8343297066789632`}, {
            0.44206795761038986`, -3.8340935112076417`}, {
            0.6723732580334396, -3.834790229083548}, {
            0.9039873256792408, -3.834993593986498}, {
            1.083471318446813, -3.8336689991728816`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1070826684616704`, -3.8334947470220913`}, {
            1.1365416037041038`, -3.8332773395963087`}, {
            1.3700360921080283`, -3.8296414659129794`}, {
            1.6044707908910145`, -3.8240859729365106`}, {
            1.7455873936243556`, -3.8198914281744063`}, {
            1.8866137730429315`, -3.8151382960531333`}, {
            2.0275499291467423`, -3.8098265765726906`}, {
            2.05120446408939, -3.8088406810234763`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0747959751863116`, -3.8078574122402986`}, {
            2.168395861935787, -3.8039562697330793`}, {
            2.3091515714100668`, -3.7975273755342993`}, {
            2.4498170575695815`, -3.7905398939763497`}, {
            2.590392320414331, -3.7829938250592314`}, {
            2.7308773599443152`, -3.774889168782944}, {
            2.8569561366892304`, -3.7672475354739245`}, {
            2.9829464253583793`, -3.7593965984145314`}, {
            3.0178935369320112`, -3.757199548112184}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.041459006145507, -3.7557180373684025`}, {
            3.131344125449809, -3.750067151797274}, {
            3.2796050580980776`, -3.7408171050616166`}, {
            3.427729223303184, -3.73164645820756}, {
            3.575716621065129, -3.722555211235104}, {
            3.59549381767455, -3.721344993424866}, {
            3.6152694423899274`, -3.720138709992095}, {
            3.761153873284244, -3.711487979262924}, {
            3.907005894831119, -3.703070990954086}, {
            3.9842157888693417`, -3.6987301762584073`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.00779055374075, -3.6974047802443897`}, {
            4.067032913623697, -3.694074117644862}, {
            4.227081896735976, -3.6855522593466783`}, {
            4.387152844167959, -3.6775054160595353`}, {
            4.5472457559196435`, -3.669933587783434}, {
            4.70736063199103, -3.662836774518373}, {
            4.867497472382119, -3.6562149762643528`}, {
            4.951213232400989, -3.6530020237714416`}}]}, 
          {Arrowheads[{{0.014450046412662306`, 1.}}], 
           ArrowBox[{{4.974807854697524, -3.6520964786206855`}, {
            5.02765627709291, -3.650068193021374}, {
            5.187837046123404, -3.644396424789436}, {
            5.348060945567226, -3.6392165770714446`}, {
            5.508349141518001, -3.6345455553703068`}, {
            5.656854249492381, -3.6306398700041296`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            4.161002370340662}, {-5.529270190333502, 
            4.160956138816243}, {-5.318206205754528, 
            4.160091730773391}, {-5.1024040014541505`, 
            4.158085893511722}, {-4.883023954241249, 
            4.154763910310908}, {-4.7124509331938045`, 
            4.151062598939335}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.688844497189158, 
            4.150550356326232}, {-4.661226440924707, 
            4.14995106445062}, {-4.438963786662454, 
            4.14323092347957}, {-4.2175547579331845`, 
            4.134380427531238}, {-3.9972093935269215`, 
            4.123514918762445}, {-3.7781377322336906`, 
            4.11074973933001}, {-3.7453639659547697`, 4.10853172077536}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.7218058608958877`, 
            4.106937387256036}, {-3.5606385764112565`, 
            4.096030126114699}, {-3.3449397175631925`, 
            4.079437400218122}, {-3.1311446781982397`, 
            4.061291030128364}, {-2.9193569808251407`, 
            4.041910484333509}, {-2.7806491247589467`, 
            4.028327877475719}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.757149529393738, 
            4.026026740581133}, {-2.7099716271282555`, 
            4.021406966928648}, {-2.5031504354514493`, 
            4.000058293523268}, {-2.2986471532927184`, 
            3.9784338498770473`}, {-2.0962155281500605`, 
            3.9571030217496643`}, {-1.9367053330075616`, 
            3.9408769989181356`}, {-1.817625544920393, 
            3.9294486961001485`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7941215466450027`, 
            3.927192974839308}, {-1.7783192868515059`, 
            3.9256764033620697`}, {-1.6208713189952553`, 
            3.9116589161792614`}, {-1.4661601127429864`, 
            3.8973002867576962`}, {-1.3115496667006479`, 
            3.884834330649464}, {-1.157505157584837, 
            3.873866845110078}, {-1.0040265853955528`, 
            3.8643978301395383`}, {-0.8523914146357849, 3.856493873351911}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8288015909597171, 
            3.855472127833778}, {-0.6983814707700763, 
            3.849889042348186}, {-0.5454433662808991, 
            3.8447169304137483`}, {-0.39229963666526635`, 
            3.8409109499345324`}, {-0.23895028192317735`, 
            3.8384711009105383`}, {-0.013450392610105166`, 
            3.8363665031984344`}, {0.11539302715941399`, 
            3.835703064705152}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1390047071382684, 3.835581483817148}, {
            0.21372868773401704`, 3.835196716281583}, {0.4425869591091892, 
            3.8349617401599843`}, {0.6731244215154111, 3.835661574833638}, {
            0.9049710572246861, 3.8358666916092594`}, {1.0834772951730018`, 
            3.8345484178681883`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.10708864431416, 3.8343740473704298`}, {
            1.1377568485090161`, 3.834147561793564}, {1.3714817953684015`, 
            3.830504185386551}, {1.606145897802843, 3.8249365623882206`}, {
            1.7473545038089722`, 3.8207347665316536`}, {1.8884725198194738`, 
            3.8159747215408735`}, {2.0294999458343477`, 3.810656427415881}, {
            2.0512112265965157`, 3.8097511475457257`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.074802720642943, 3.8087674697562357`}, {
            2.170436781853594, 3.8047798841566762`}, {2.311283027877212, 
            3.7983450917632586`}, {2.452038683905203, 3.7913520502356284`}, {
            2.5927037499375665`, 3.783800759573785}, {2.7332782259743014`, 
            3.77569121977773}, {2.8594377454196036`, 3.7680454710053475`}, {
            2.98550897279605, 3.7601907160680064`}, {3.0179027161766574`, 
            3.758154719125131}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.0414682094649432`, 3.7566735913737452`}, {
            3.133886962431293, 3.7508649296117196`}, {3.282128251237743, 
            3.7416199613297794`}, {3.430232839215401, 3.7324558112221857`}, {
            3.578200726364267, 3.7233724792889387`}, {3.5979755770055557`, 
            3.722163398769891}, {3.617748864111301, 3.7209582542607995`}, {
            3.763711982018968, 3.712310467806193}, {3.9096429299118807`, 
            3.703896751479012}, {3.9842263188474543`, 3.6997077796124196`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.007801157697394, 3.6983837001074353`}, {
            4.069857208218475, 3.694898325501983}, {4.230093520488616, 
            3.686376233895503}, {4.390351866722304, 3.6783304766595726`}, {
            4.550632246919538, 3.670761053794192}, {4.710934661080319, 
            3.6636679652993607`}, {4.871259109204647, 3.657051211175079}, {
            4.951224190527707, 3.653988972711401}}]}, 
          {Arrowheads[{{0.014449806819168017`, 1.}}], 
           ArrowBox[{{4.974818889242955, 3.6530854209016703`}, {
            5.0316055912925215`, 3.650910791421347}, {5.191974107343943, 
            3.645246706038164}, {5.35238577158149, 3.640075546125334}, {
            5.512861698227745, 3.635413902782658}, {5.656854249492381, 
            3.631638933940879}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.5528757474394965`, 0.005106538878232603}, {
            1.5640468229079372`, 0.0038422771759907856`}, {1.580621121496495, 
            0.0029111469488959166`}, {1.6051518708295276`, 
            0.00222765788593847}, {1.6212413566771064`, 
            0.001959695430393163}, {1.640449364040145, 
            0.0017306183768011271`}, {1.7075931363896313`, 
            0.0012831476724842875`}, {1.807187240597266, 
            0.0009882003256990069}, {1.815100669876582, 
            0.0009724985898194364}, {1.8231897984254282`, 
            0.0009572371227985556}, {1.8625168719551581`, 
            0.0009004504919594494}, {1.9055431883485785`, 
            0.0008502188520797856}, {1.9988533077692079`, 
            0.0007608090333896519}, {2.1066582529566587`, 
            0.0006910320940681456}, {2.228659722421737, 
            0.0006364674741222112}, {2.4635745812447953`, 
            0.0005665504507415668}, {2.4972427864992244`, 
            0.000559670288912732}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.520854779004179, 0.0005548451333005554}, {
            2.593526967006472, 0.0005399944333558201}, {2.7318093236682475`, 
            0.0005190400788397904}, {2.9752596923100856`, 
            0.0004923922010507634}, {3.1028275567968624`, 
            0.00048160679083015124`}, {3.2342905413942113`, 
            0.0004725137330588067}, {3.3689793781169657`, 
            0.0004647049232802992}, {3.4653344932398076`, 
            0.00045983774556562166`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.4889464862076536`, 0.00045864503497806535`}, {
            3.5062247989799586`, 0.000457772257038198}, {3.6460268039831902`, 
            0.0004517157343325032}, {3.788385393126661, 
            0.00044653535516321483`}, {3.9338913487936202`, 
            0.00044247778214339225`}, {4.07919690414565, 
            0.00043814526046569873`}, {4.226586417731318, 
            0.000434491552233964}, {4.375823576597324, 
            0.0004314179924029644}, {4.433426205673158, 
            0.00043047714704216227`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.457038198667978, 0.00043009148349824276`}, {
            4.599033283903243, 0.0004277722244758044}, {4.82491219103328, 
            0.0004249638944539197}, {5.052671721600156, 
            0.0004227104413039453}, {5.281523299216587, 
            0.00042072930399251606`}, {5.401517918527193, 
            0.0004198201179270643}}]}, 
          {Arrowheads[{{0.00490692035172399, 1.}}], 
           ArrowBox[{{5.425129911524484, 0.0004196412124466851}, {
            5.511140998837307, 0.00041898951587471836`}, {5.656854249492381, 
            0.00041811289320531765`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -1.337968254850927}, \
{-5.536661966040593, -1.3378112712515295`}, {-5.336192282091987, \
-1.336922938090504}, {-5.124767122022398, -1.3351050191241636`}, \
{-4.913741418494116, -1.3322643622217796`}, {-4.7124405883608445`, \
-1.3284017931686394`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-4.688835074976716, -1.3278539193541181`}, \
{-4.493261106096414, -1.322809543603114}, {-4.465350971222034, \
-1.3219971121932141`}, {-4.43745243063786, -1.3211567393470625`}, \
{-4.265953107294687, -1.314658997413662}, {-4.09490388091568, \
-1.3069035639345585`}, {-3.9058544352669204`, -1.2973180492072838`}, \
{-3.7452895438778473`, -1.2874485613312203`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7217220306142202`, -1.285999930286089}, \
{-3.717236051012016, -1.2857241893011626`}, {-3.5290487281509666`, \
-1.272121984216195}, {-3.3412924666837727`, -1.2565114339523813`}, \
{-3.1536114238000374`, -1.2383685487563476`}, {-2.965649756689366, \
-1.2171693388747207`}, {-2.7819746410978077`, -1.1935022974053888`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7585967822066606`, -1.190188646312942}, \
{-2.5888845497872124`, -1.1656019450546864`}, {-2.4652988878527586`, \
-1.1456491289160402`}, {-2.3407294518621398`, -1.1234241628726567`}, \
{-2.215176241815355, -1.0989270469245362`}, {-2.088639257712405, \
-1.0721577810716785`}, {-1.8899720304641883`, -1.0245025471463542`}, \
{-1.8324480809778227`, -1.008486294892768}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8097013184897435`, -1.0021529695697589`}, \
{-1.6850755555112513`, -0.9674537238645892}, {-1.5231358606663252`, \
-0.9165857094462798}, {-1.3531195367927586`, -0.8577239555330751}, \
{-1.1250461369718572`, -0.771905415321205}, {-0.9492806696432257, \
-0.7051193598463978}, {-0.9175556002077166, -0.6936224945700644}}]}, 
          {Arrowheads[{{0.004801605898669028, 1.}}], 
           ArrowBox[{{-0.8953185077854755, -0.6856854673067024}, \
{-0.8488794521810501, -0.6699120084525728}, {-0.7932651945026091, \
-0.6528565675054385}, {-0.7660814057556473, -0.6451957950092684}, \
{-0.745956777575587, -0.639640862922115}, {-0.7341304671479313, \
-0.6363355269582184}, {-0.7259379958350395, -0.6340261675699765}, \
{-0.7195812366663366, -0.632224779471824}, {-0.7144664724064312, \
-0.630769296115475}, {-0.7058582733158641, -0.6283082349604278}, \
{-0.6999521474833869, -0.6266098912560265}, {-0.695564408069681, \
-0.6253431701690406}, {-0.6903593620579962, -0.623835272678256}, \
{-0.6839590902926407, -0.6219725266040489}, {-0.678249060058338, \
-0.6203029697298934}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            1.3388854641625225`}, {-5.536588985737063, 
            1.3387280990506931`}, {-5.336121692016142, 
            1.3378390680860057`}, {-5.124704923385183, 
            1.3360200508867979`}, {-4.913687297481391, 
            1.3331778502933274`}, {-4.712440654014933, 
            1.329314194698738}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-4.688835140708294, 
            1.3287663320415661`}, {-4.493222457022795, 
            1.3237182681141177`}, {-4.465313304572845, 
            1.3229054370464626`}, {-4.437415744980164, 
            1.3220646518426573`}, {-4.265917602422963, 
            1.31556355221222}, {-4.094869657578914, 
            1.3078041158309555`}, {-3.905830746975133, 
            1.2982145689502487`}, {-3.745290446242154, 
            1.2883425599484193`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7217229692373612`, 
            1.2868933391354553`}, {-3.7172244394316345`, 
            1.2866167137240516`}, {-3.5290507349484175`, 
            1.273010550152364}, {-3.3413096335254826`, 
            1.257396078235186}, {-3.1536457420602573`, 
            1.2392492922989944`}, {-2.9657036674501684`, 
            1.2180461866702654`}, {-2.7819785762771643`, 
            1.1943661365942686`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7586009981671262`, 
            1.1910504674248434`}, {-2.588984968795402, 
            1.1664710163351961`}, {-2.4653759829408126`, 
            1.1465087437624046`}, {-2.340785283179095, 
            1.1242730503990817`}, {-2.21521286951025, 
            1.099763936245227}, {-2.0886587419342773`, 
            1.0729814013008403`}, {-1.8898334999584088`, 
            1.0252655831268187`}, {-1.832465886038801, 
            1.009282698473896}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8097201648209906`, 
            1.0029456345151049`}, {-1.6847776279147189`, 
            0.9681360613225558}, {-1.5227881736297353`, 
            0.9172195802105144}, {-1.3527281720816688`, 
            0.8583093839551}, {-1.1247208224740652`, 
            0.7724637144544764}, {-0.9489924122720088, 
            0.7056399764606698}, {-0.917628342384755, 
            0.6942633807266755}}]}, 
          {Arrowheads[{{0.004819022767131045, 1.}}], 
           ArrowBox[{{-0.895396175189926, 
            0.6863124379773847}, {-0.8486135593422783, 
            0.6704051579252911}, {-0.7929256733539225, 
            0.6533157886912929}, {-0.7661869135669157, 
            0.6457773048890236}, {-0.7462193339790338, 
            0.6402620026842698}, {-0.7343346831470924, 
            0.6369385822243968}, {-0.7258412261812086, 
            0.6345429436233204}, {-0.7192941575210638, 
            0.6326861264830537}, {-0.714047273382854, 
            0.6311916638220243}, {-0.7054055866273625, 
            0.6287185677551077}, {-0.6994655104412575, 
            0.6270087151455638}, {-0.6950471732175456, 
            0.6257318234689455}, {-0.6897745555211059, 
            0.6242026953690296}, {-0.6833032613406346, 
            0.6223171233011239}, {-0.6775570873108753, 
            0.6206349987790521}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, -2.1709206751896004`}, \
{-5.459128173784755, -2.1705900757169845`}, {-5.224155797246894, \
-2.1688960054360407`}, {-4.989693816381473, -2.1656293351964555`}, \
{-4.755890829735595, -2.1604706681785975`}, {-4.712482063238238, \
-2.1591045551822057`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           
           ArrowBox[{{-4.688881754428707, -2.1583618321982314`}, \
{-4.522909654376422, -2.153138540655643}, {-4.290937989781208, \
-2.1434178718131838`}, {-4.060163535427208, -2.13109358083681}, \
{-3.830831225680758, -2.1159485692493205`}, {-3.7457868703726356`, \
-2.109157744346461}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7222497953358045`, -2.107278299735217}, \
{-3.6031402069969296`, -2.097767352703748}, {-3.377209496986084, \
-2.0763372715810333`}, {-3.1531581132585815`, -2.0514456662621168`}, \
{-3.0262935839730183`, -2.035645859047458}, {-2.9001123664805637`, \
-2.0186516917122828`}, {-2.7838831001179174`, -2.0017529276623027`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7605403083345896`, -1.9981998978363313`}, \
{-2.6498698213873233`, -1.9808591702830192`}, {-2.5258253376749322`, \
-1.9599027693428202`}, {-2.4025123602266616`, -1.9374739095078264`}, \
{-2.2799701377119237`, -1.9135743065556128`}, {-2.158237918800132, \
-1.8882056762637542`}, {-2.0373419542889883`, -1.8613954718198915`}, \
{-1.9173188932735632`, -1.833150556483613}, {-1.8350021654543336`, \
-1.812013141278747}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8121321252909381`, -1.8061405374047539`}, \
{-1.6801108661917472`, -1.772239916675793}, {-1.4473197124609856`, \
-1.704472190903664}, {-1.2191170950224963`, -1.6303822392717982`}, \
{-1.0804258255593506`, -1.582216148190906}, {-0.9440448691340064, \
-1.5319133791764983`}, {-0.9126429611847815, -1.519923212420417}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8905842845045083, -1.5115005645914183`}, \
{-0.8093327934920411, -1.4804763692465057`}, {-0.6759332473809978, \
-1.4284620278553342`}, {-0.5432282248608912, -1.3768272021276948`}, \
{-0.4105997199917358, -1.3265287391882983`}, {-0.29337119498617514`, \
-1.2842475170502323`}, {-0.1738749392831721, -1.244613656215065}, \
{-0.050854673412367137`, -1.2078198987624662`}, {-0.019133338320953656`, \
-1.1990520857577325`}, {-0.0015066239097834, -1.1943254399761662`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.021335257295126066`, -1.1883470711768764`}, {
            0.20067206248176775`, -1.1433388823206982`}, {
            0.3982000011215499, -1.087480044650594}, {
            0.5211485369328108, -1.0379242495791405`}, {
            0.6376213722631303, -0.9724949207305076}, {
            0.7421046589695489, -0.8889142267865713}, {
            0.7611048461523897, -0.8706454367028166}, {
            0.779156599827807, -0.8517374629970862}, {
            0.8030351592310093, -0.8199319512853668}, {
            0.824367638474274, -0.7862875622455455}, {
            0.8346082607455242, -0.7665387707665048}}]}, 
          {Arrowheads[{{0.008464175641731679, 1.}}], 
           ArrowBox[{{0.8454776914925896, -0.7455773374049498}, {
            0.8613278675350493, -0.7150106576390718}, {
            0.8847700432429749, -0.6368422097006022}, {
            0.8906766733180613, -0.5516284962428912}, {
            0.8874491765260504, -0.5167357198840971}, {
            0.8819280836562643, -0.48445267195529373`}, {
            0.8761767511999374, -0.4600831185128589}, {
            0.869766343754036, -0.43825869395886524`}, {
            0.8641500516017503, -0.42191000608884127`}, {
            0.8594149779670315, -0.40949962253508737`}, {
            0.8522662506460289, -0.3923259562376581}, {
            0.8477609090610425, -0.38241685584565555`}, {
            0.8447759033545766, -0.3761539164889849}, {
            0.8418530823275069, -0.37020771548531317`}, {
            0.840040449894641, -0.36661933718414735`}, {
            0.8377326954370184, -0.3621447560621785}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            2.176969463928433}, {-5.53771457136697, 
            2.176914023737852}, {-5.344568854728093, 
            2.1760283662334374`}, {-5.151706309354532, 
            2.174173185940033}, {-4.959213191389103, 
            2.171099270752088}, {-4.7671781916421105`, 
            2.1666272310127312`}, {-4.712488761940574, 
            2.1649193854152755`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688888273649834, 
            2.1641823876033564`}, {-4.575692435591353, 
            2.1606474995137654`}, {-4.384847048714633, 
            2.1530505090469965`}, {-4.194733156489746, 
            2.143726692404228}, {-4.005441884394493, 
            2.132566482377266}, {-3.817064357906671, 
            2.1194603117579134`}, {-3.7458601872129793`, 
            2.113698659077164}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.722325117817131, 
            2.111794263669491}, {-3.62969170250408, 
            2.1042986133379755`}, {-3.5019822348624614`, 
            2.0926966938460456`}, {-3.374920567840675, 
            2.0800974115421305`}, {-3.2485145546471923`, 
            2.0664542391330176`}, {-3.122772048490488, 
            2.051720649325496}, {-2.9976923407320064`, 
            2.035851086962893}, {-2.8732815722108156`, 
            2.0187992191793045`}, {-2.784026578935661, 
            2.005610574666364}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.760668213417775, 
            2.0021590570771015`}, {-2.7495578703518238`, 
            2.0005173521176722`}, {-2.626539362579938, 
            1.980957791920938}, {-2.504226053665042, 
            1.9600352444436486`}, {-2.3826324465010384`, 
            1.9376944957710664`}, {-2.141763835869459, 
            1.888748100796089}, {-1.9041993821775622`, 
            1.8341717881223474`}, {-1.8350390732179114`, 
            1.8163410121966461`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8121747529724697`, 
            1.8104461777587637`}, {-1.6703112277079768`, 
            1.7738712004477601`}, {-1.5318292113316552`, 
            1.7344443120571684`}, {-1.3950776369363123`, 
            1.692481690526316}, {-1.2598203373907784`, 
            1.6485922943026774`}, {-1.1261226110144034`, 
            1.603050190443685}, {-0.9947423001064528, 
            1.555460683221665}, {-0.9127604188599169, 1.5241102311440424`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8907059918239822, 
            1.5156764620309593`}, {-0.8656550899073978, 
            1.5060968196990716`}, {-0.7381230244944323, 
            1.4557872134801482`}, {-0.6112711161537117, 
            1.4055848306658123`}, {-0.4300054397289081, 
            1.3358831281014085`}, {-0.24680042679266603`, 
            1.270847958846958}, {-0.05654223170234459, 
            1.2124398389928361`}, {-0.024977242939628094`, 
            1.2036985488380822`}, {-0.0020312884723438507`, 
            1.1975607886480137`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.020804031682686894`, 1.1915551069919759`}, {
            0.15212061385612297`, 1.1573882716543884`}, {0.2651944034744492, 
            1.1268886689036894`}, {0.38050044577275177`, 
            1.0915524465003754`}, {0.4953776594470465, 1.0470707825981675`}, {
            0.5813297725584337, 1.0044592443896414`}, {0.6624857582257693, 
            0.9532081203468123}, {0.7361744792306802, 0.8921175677584995}, {
            0.7553397638414338, 0.8739702828323447}, {0.7736497868867926, 
            0.855142320059366}, {0.7978535619730209, 0.8235429160631577}, {
            0.8195216536067988, 0.7901176094161259}, {0.8326458990022271, 
            0.7654339104022072}}]}, 
          {Arrowheads[{{0.008366803021994109, 1.}}], 
           ArrowBox[{{0.8437308540147402, 0.7445856494266073}, {
            0.8572591387898427, 0.719142044899102}, {0.8816342025432817, 
            0.6411710789876403}, {0.8886978427472954, 0.5565727717319504}, {
            0.8859146225348901, 0.521247460131489}, {0.8805574373829583, 
            0.48790179036473585`}, {0.8747783444579968, 0.4624646621076541}, {
            0.8676970553533434, 0.4379099622782869}, {0.8616383081398736, 
            0.42029886906477365`}, {0.8566845290111496, 0.4073977090294713}, {
            0.8500356080131297, 0.3914947141544282}, {0.8458718014943765, 
            0.3823133147057709}, {0.8430932373942774, 0.3764481097236884}, {
            0.8403659352361393, 0.3708558945904046}, {0.8374922644165059, 
            0.3651489707902756}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -5.095918607427803}, \
{-5.594313962370117, -5.095730374971032}, {-5.452421514472959, \
-5.0951337983397185`}, {-5.310205053647296, -5.0943667348112704`}, \
{-5.167664579893132, -5.093429184385687}, {-5.024988178188807, \
-5.092098923030768}, {-4.882363933512666, -5.0901537267143135`}, \
{-4.73979184586471, -5.0875935954363225`}, {-4.712430457461105, \
-5.086984037038356}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.6888243217352885`, -5.086458138349921}, \
{-4.597271915244942, -5.084418529196794}, {-4.454804141653359, \
-5.080628527995731}, {-4.312388525089958, -5.07622359183313}, \
{-4.170025065554745, -5.0712037207089935`}, {-4.027713763047715, \
-5.06556891462332}, {-3.8857153837126344`, -5.0593249797067275`}, \
{-3.7449878720714733`, -5.052511476874518}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.7214086862319036`, -5.05126733498887}, \
{-3.6034396929896078`, -5.045027141772638}, {-3.463162381601661, \
-5.036973238755141}, {-3.323458759529426, -5.028316013037342}, \
{-3.1843288267729024`, -5.019055464619242}, {-3.0457725833320897`, \
-5.009191593500839}, {-2.907790029206989, -4.998724399682135}, \
{-2.779042009128607, -4.988642234845816}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7555020832692887`, -4.9867988401854255`}, \
{-2.702959459808567, -4.9826842651392145`}, {-2.4998246515580687`, \
-4.966735109949158}, {-2.2983856044554947`, -4.950876934111965}, \
{-2.0986423185008456`, -4.935109737627635}, {-1.9004371918863607`, \
-4.9199700941572075`}, {-1.8138483504819833`, -4.91382185863462}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7902956556661476`, -4.912149500943134}, \
{-1.7036126228042823`, -4.905994577361722}, {-1.50816861125461, \
-4.893183187241178}, {-1.3141051572373437`, -4.881535923795575}, \
{-1.1210713284218028`, -4.871326202184142}, {-0.9287161924773055, \
-4.862827437566111}, {-0.8473113248611386, -4.859944659838044}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8237141234911534, -4.859109015870477}, \
{-0.7370397494038523, -4.856039629941479}, {-0.5460419992014429, \
-4.850962779310249}, {-0.408044736978442, -4.848189797424937}, \
{-0.2699639113235003, -4.845979802748474}, {-0.13179952223661845`, \
-4.844332795280858}, {0.006448430282205209, -4.843248775022089}, {
            0.12058338616794262`, -4.842818879609182}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.14419521167690785`, -4.842729944406134}, {
            0.14477994623296986`, -4.842727741972169}, {
            0.283195025615675, -4.842769696131097}, {
            0.42169366843032086`, -4.843374637498873}, {
            0.5602758746769083, -4.844542566075496}, {
            0.7547628952286346, -4.8463450265209325`}, {
            0.9493601367877367, -4.847686532574483}, {
            1.0886542779546062`, -4.848316481143725}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.1122660294952, -4.848423263733256}, {
            1.144067599354214, -4.848567084236147}, {
            1.3388852829280673`, -4.848986681505926}, {
            1.5338131875092962`, -4.84894532438382}, {
            1.7288513130979004`, -4.8484430128698275`}, {
            1.9239996596938802`, -4.847479746963949}, {
            2.0567384127711836`, -4.846511547571969}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.080349777682644, -4.846339325755648}, {
            2.1192582272972356`, -4.846055526666185}, {
            2.3143855378767184`, -4.844137925509233}, {
            2.509140113401081, -4.841694517025787}, {
            2.7035219538703217`, -4.838725301215851}, {
            2.897531059284442, -4.835230278079421}, {
            3.024722140429165, -4.832589174175591}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.048329044574315, -4.832098980318176}, {
            3.0911674296434413`, -4.8312094476165}, {
            3.28443106494732, -4.826662809827085}, {
            3.4773219651960776`, -4.821590364711179}, {
            3.6698401303897143`, -4.8159921122687805`}, {
            3.8278341310944715`, -4.811106922941066}, {
            3.985602629298346, -4.806101666408921}, {
            3.9924396877360797`, -4.805885312859677}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.01603986757365, -4.805138502997342}, {
            4.110990254222568, -4.802133869741581}, {
            4.236255022918136, -4.798280439428565}, {
            4.36139693538505, -4.794541375469869}, {
            4.4864159916233115`, -4.790916677865497}, {
            4.503205723908306, -4.790437334482824}, {
            4.519993551039305, -4.789960528186641}, {
            4.694349806988296, -4.785309234381192}, {
            4.868514764938093, -4.780946445578545}, {
            4.96014703503642, -4.778717252265233}}]}, 
          {Arrowheads[{{0.014256387238985325`, 1.}}], 
           ArrowBox[{{4.983752043965705, -4.778142999024433}, {
            5.016142834296257, -4.777355008798497}, {
            5.163638917334435, -4.773980097393212}, {
            5.311003014052623, -4.770821711362687}, {
            5.458235124450824, -4.767879850706924}, {
            5.605258447628027, -4.765269473508371}, {
            5.656854249492381, -4.764442037750297}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            5.096521395341231}, {-5.593877418492312, 
            5.096331475417876}, {-5.451944368418021, 
            5.095733688963498}, {-5.309689082073207, 
            5.094965173346711}, {-5.1671115594578705`, 
            5.0940259285675165`}, {-5.02439916931863, 
            5.09269370122707}, {-4.8817392804020985`, 
            5.090746237926525}, {-4.739131892708279, 
            5.0881835386658825`}, {-4.712430412716418, 
            5.087588290226403}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.688824284700379, 
            5.087062045581239}, {-4.596577006237172, 
            5.0850056034451425`}, {-4.454074620988776, 
            5.081212432264305}, {-4.311624736963093, 
            5.07680402512337}, {-4.169227354160122, 
            5.071780382022338}, {-4.026882472579862, 
            5.066141502961207}, {-3.8848508497169916`, 
            5.059893235159256}, {-3.7449877345696976`, 
            5.0531186585276515`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.721408372304079, 
            5.051878019052162}, {-3.6025096526274516`, 
            5.045586074990723}, {-3.462200078400783, 
            5.037527182624141}, {-3.3224645203861813`, 
            5.028864748736014}, {-3.183302978583646, 
            5.0195987733263445`}, {-3.044715452993179, 
            5.009729256395131}, {-2.9067019436147787`, 
            4.9992561979423735`}, {-2.7790414663963974`, 
            4.989256592815597}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7555015779281815`, 
            4.98741272073757}, {-2.701864397533143, 
            4.983211337226003}, {-2.4987228073655947`, 
            4.967259760856287}, {-2.297277173112133, 
            4.951401468833223}, {-2.09752749477276, 
            4.935636461156812}, {-1.8993155782219528`, 
            4.920501054600868}, {-1.8138478796723434`, 
            4.914435283133049}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-1.7902951292392808`, 
            4.912763708912729}, {-1.702483229334189, 
            4.906531565939205}, {-1.5070304481094703`, 
            4.893727995171823}, {-1.3129572345477958`, 
            4.882090342298723}, {-1.1199125091603404`, 
            4.871891082303496}, {-0.9275451924582789, 
            4.863402690169734}, {-0.847310380034465, 4.860565851265109}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8237131318527813, 
            4.859731530230865}, {-0.7358552844416106, 
            4.856625165897436}, {-0.5448427851103377, 
            4.851558509486604}, {-0.40681931567133145`, 
            4.848792317172442}, {-0.26871217095268857`, 
            4.846588666380751}, {-0.13052135095440992`, 4.844947557111531}, {
            0.0077531443235044906`, 4.843868989364782}, {0.12058447272870844`,
             4.843448169082593}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1441963015044109, 4.843360105451784}, {
            0.14611131488105455`, 4.843352963140505}, {0.2845531607182399, 
            4.843399478438697}, {0.4230786818350609, 4.844008535259362}, {
            0.5616878782315184, 4.845180133602497}, {0.7562851386699976, 
            4.8469873645167505`}, {0.950991652178395, 4.848331987308379}, {
            1.088655264514029, 4.848955249622311}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1122670155209027`, 4.849062150162831}, {
            1.1458074187567102`, 4.849214001977383}, {1.3407324384049437`, 
            4.849633408523761}, {1.5357667111230953`, 4.849590206947515}, {
            1.7309102369111646`, 4.849084397248644}, {1.9261630157691523`, 
            4.848115979427147}, {2.056739375580129, 4.847159508219644}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0803507351463, 4.846986555124399}, {2.121525047697058,
             4.8466849534830265`}, {2.3167550335789575`, 4.844760027266189}, {
            2.5116116742989267`, 4.842309908626547}, {2.7060949698569656`, 
            4.839334597564097}, {2.900204920253074, 4.835834094078842}, {
            3.0247232602378866`, 4.833246699863125}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0483301573393318`, 4.8327561669101575`}, {
            3.0939415254872524`, 4.83180839817078}, {3.287304785559501, 
            4.827257509839912}, {3.480294700469818, 4.822181429086237}, {
            3.6729112702182047`, 4.816580155909757}, {3.8310093041344384`, 
            4.811692199119561}, {3.988881613010765, 4.806684540420146}, {
            3.9924415909452575`, 4.806571927817606}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.016041779208083, 4.805825384251993}, {
            4.114251176399461, 4.802718731341458}, {4.239498082222317, 
            4.7988683307775934`}, {4.364622330479335, 4.7951333387285535`}, {
            4.489623921170515, 4.791513755194337}, {4.506411439019984, 
            4.791035165578598}, {4.523197053832422, 4.790559113871192}, {
            4.697654482087485, 4.785912618669589}, {4.871920400834489, 
            4.7815550742289625`}, {4.9601491658374846`, 4.779412858531364}}]}, 
          {Arrowheads[{{0.01425634097131411, 1.}}], 
           ArrowBox[{{4.9837542019208225`, 4.778839722561044}, {
            5.020060448822769, 4.77795819812815}, {5.168067449034741, 
            4.774579423250502}, {5.315941401470404, 4.771418749596017}, {
            5.463682306129759, 4.768476177164696}, {5.611212555286534, 
            4.765867490231065}, {5.656854249492381, 4.765139835405076}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, -3.3292514758385434`}, \
{-5.584969482358292, -3.329358989164769}, {-5.372174936669185, \
-3.328825449974255}, {-5.159552567280787, -3.3270567082949265`}, \
{-4.947244390687819, -3.3238785940693276`}, {-4.735392423385001, \
-3.3191169372400022`}, {-4.71247145415646, -3.3183899125491956`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           
           ArrowBox[{{-4.688871329976332, -3.317641345906399}, \
{-4.524030561604496, -3.31241280136001}, {-4.313279197788514, \
-3.303555063093998}, {-4.103410092746836, -3.292591272051892}, \
{-3.8946950072892412`, -3.279568977843617}, {-3.7457506594847736`, \
-3.268672507094168}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.722201600769138, -3.2669497050324954`}, \
{-3.6875377010078076`, -3.2644137634182018`}, {-3.4822363344687766`, \
-3.2471487850533927`}, {-3.2789042699431734`, -3.227967952352191}, \
{-3.0776548697020227`, -3.2070651749175996`}, {-2.8787381811300445`, \
-3.184275559013306}, {-2.7825740378705417`, -3.17225558167125}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7591443633840864`, -3.1693270040651567`}, \
{-2.682294903521003, -3.1597212535744488`}, {-2.488274377009497, \
-3.134026732211208}, {-2.2966259417301282`, -3.1078164685337635`}, \
{-2.1547918621636, -3.088241112908714}, {-2.014379086435917, \
-3.068998597378104}, {-1.8752815248978987`, -3.050344841753408}, \
{-1.8232265032360937`, -3.042526933542409}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.799876380719168, -3.0390200842755144`}, \
{-1.738524710824967, -3.0298059545237193`}, {-1.602605707520383, \
-3.0110074663515722`}, {-1.4677897391071002`, -2.9933095777082848`}, \
{-1.3340768055851189`, -2.976712288593856}, {-1.2014669069544395`, \
-2.9612155990082862`}, {-1.0695800193830454`, -2.9471144966132465`}, \
{-0.938036119038922, -2.934703969070408}, {-0.8620527888043927, \
-2.928495645621731}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8385192194122576, -2.9265728026739777`}, \
{-0.80683520592207, -2.923984016379771}, {-0.6759772800324882, \
-2.9149546385413343`}, {-0.544908624573928, -2.907534979681037}, \
{-0.4130755227501409, -2.9016441839248164`}, {-0.2804779745611265, \
-2.8972822512726726`}, {-0.14711598000688375`, -2.894449181724606}, \
{-0.012619762630565495`, -2.892528276550191}, {
            0.1050784419838968, -2.8911215779490025`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1286888795591909, -2.8908514926489475`}, {
            0.26088466995884246`, -2.8895728631310407`}, {
            0.39989288517193367`, -2.8885383548863057`}, {
            0.5402620274533486, -2.8870745833553286`}, {
            0.6818490245924873, -2.8844568196086415`}, {
            0.8246538765893499, -2.880685063646244}, {
            0.9686765834439355, -2.875759315468137}, {
            1.0728867427943514`, -2.871058186576415}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.0964747461047248`, -2.869994084529631}, {
            1.1689553816892182`, -2.866724337969789}, {
            1.3695163891078463`, -2.8548485295269197`}, {
            1.5703596056998208`, -2.840131890139529}, {
            1.7714850314651422`, -2.8225744198076166`}, {
            1.972431088855965, -2.8031652635385815`}, {
            2.037956222709012, -2.7965338517756013`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.061448216535838, -2.794156365839465}, {
            2.1727362003244455`, -2.7828935663398218`}, {
            2.372400365870583, -2.761759328211338}, {
            2.5714235854943777`, -2.7397625491531303`}, {
            2.714208785379881, -2.723906750518427}, {
            2.856996139587242, -2.7085721186738096`}, {
            2.99978564811646, -2.693758653619279}, {
            3.0005632059850056`, -2.6936808263235306`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0240578031244443`, -2.691329205905257}, {
            3.142577310967536, -2.679466355354835}, {
            3.285371128140469, -2.6656952238804776`}, {
            3.4281670996352602`, -2.6524452591962064`}, {
            3.5709652254519084`, -2.639716461302022}, {
            3.713765505590415, -2.6275088301979235`}, {
            3.872390769595047, -2.6146871234369167`}, {
            3.964803359941805, -2.607728163841558}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.9883486896481135`, -2.6059551262341194`}, {
            4.03132748006166, -2.602718687726953}, {
            4.197229576377041, -2.5911238416178546`}, {
            4.363500000759215, -2.58040424540353}, {
            4.530138753208181, -2.570559899083979}, {
            4.6971458337239405`, -2.561590802659202}, {
            4.7195378505868, -2.5604481779140973`}, {
            4.741934655199243, -2.5593218659102495`}, {
            4.923814136539027, -2.5513356648469534`}, {
            4.931187435134219, -2.551050134404395}}]}, 
          {Arrowheads[{{0.014875259160795476`, 1.}}], 
           ArrowBox[{{4.954781743512635, -2.5501364465581533`}, {
            5.105989066988617, -2.5442809541441784`}, {
            5.237492088079505, -2.5394112031016616`}, {
            5.369143915609334, -2.5349810769797876`}, {
            5.500513457501977, -2.5309721832066456`}, {
            5.631169621681305, -2.5273661292103244`}, {
            5.656854249492381, -2.5267400127764907`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            3.3301806617884475`}, {-5.584159632534824, 
            3.330288235064471}, {-5.371462974246593, 
            3.3297506271537247`}, {-5.158937849184568, 
            3.3279784095257723`}, {-4.946726312330985, 
            3.3247977666608453`}, {-4.734970418668077, 
            3.320034883039177}, {-4.712471392001056, 
            3.3193210080171225`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688871275594003, 
            3.3185721963520707`}, {-4.523704516229084, 
            3.313331595248328}, {-4.313049118606441, 
            3.304477218189998}, {-4.103275529121174, 
            3.293519153815623}, {-3.8946550510943134`, 
            3.2805048040766422`}, {-3.7457500159816135`, 
            3.2696134868379514`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.7222009310590365`, 
            3.2678910430375887`}, {-3.687590691432879, 
            3.2653595564482316`}, {-3.482380094175097, 
            3.248106409986577}, {-3.2791365183388024`, 
            3.2289391840146306`}, {-3.0779732229418286`, 
            3.2080516978553457`}, {-2.879139921913617, 
            3.1852797205688526`}, {-2.782571579291185, 
            3.173214129398477}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.759141758256008, 
            3.1702867244733373`}, {-2.6827771652543224`, 
            3.16074546142554}, {-2.4888344660878516`, 
            3.135072400063746}, {-2.2972613375381092`, 
            3.1088840161218094`}, {-2.155354555409636, 
            3.089307329420676}, {-2.014869907373657, 
            3.070063784058167}, {-1.8757013254418102`, 
            3.0514094496416253`}, {-1.8232179433964584`, 
            3.0435306577716585`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7998675954973047`, 
            3.0400253095258125`}, {-1.7388741335015911`, 
            3.030868986633403}, {-1.6028857017178766`, 
            3.012070047804191}, {-1.4680012000615694`, 
            2.994372459135632}, {-1.3342206285326705`, 
            2.977776220627726}, {-1.2015439871311822`, 
            2.9622813322804733`}, {-1.069590667342194, 
            2.9481829271704982`}, {-0.9379800606507999, 
            2.935776138374426}, {-0.862034953797545, 2.929576869864583}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8385012352838017, 
            2.9276558528807812`}, {-0.8067121670569997, 
            2.925060965892256}, {-0.675786986560792, 
            2.9160374097239887`}, {-0.5446505349292018, 
            2.908624101285012}, {-0.4127488279292519, 
            2.902739671990714}, {-0.2800818655609411, 
            2.898384121841095}, {-0.1466496478242702, 
            2.895557450836155}, {-0.01208265198996053, 2.8936423535201072`}, {
            0.10509823876138304`, 2.89224653970518}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.12870867223922858`, 2.8919760119778624`}, {
            0.2615642421594139, 2.8906949635873294`}, {0.40064414047447766`, 
            2.8896626709705995`}, {0.5410847627676385, 2.888199921842035}, {
            0.6827425321900765, 2.8855819914566947`}, {0.8256174487417912, 
            2.8818088798145793`}, {0.969709512422782, 2.8768805869156884`}, {
            1.07290755041402, 2.87222498390329}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0964955523563664`, 2.8711608515318146`}, {
            1.1702073457697648`, 2.8678354700212294`}, {1.370984475330726, 
            2.855947444472928}, {1.5720409011056655`, 2.841216510270784}, {
            1.7733766230945835`, 2.823642667414798}, {1.974531639870612, 
            2.8042178501752386`}, {2.037984660482435, 2.7977989964893157`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.061476760053278, 2.795422555644319}, {
            2.175045950006883, 2.7839339928223756`}, {2.3749195535033967`, 
            2.7627910953562083`}, {2.5741524503601525`, 2.740789157776737}, {
            2.7170411070151967`, 2.7249368856547456`}, {2.859932880291752, 
            2.709606954896559}, {3.000600661308657, 2.6950301513187473`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.0240947257070467`, 2.692673347499419}, {
            3.145725776709396, 2.6805141174715996`}, {3.288626899850485, 
            2.666751210804827}, {3.4315311396130848`, 2.653510645501859}, {
            3.5744384959971955`, 2.6407924215626957`}, {3.7173489690028174`, 
            2.6285965389873374`}, {3.8760940994863855`, 
            2.6157887895517966`}, {3.9648444607855944`, 2.609118443552392}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.988390045244235, 2.6073487922202943`}, {
            4.035151409805293, 2.603834277164125}, {4.2010425501892685`, 
            2.592263317639652}, {4.367301089070986, 2.5815666452911015`}, {
            4.533927026450444, 2.571744260118474}, {4.700920362327642, 
            2.562796162121769}, {4.723310745756602, 2.5616562715117075`}, {
            4.745705901817621, 2.560532661818205}, {4.927704080100177, 
            2.5525611057665816`}, {4.931227976496646, 2.552425007077692}}]}, 
          {Arrowheads[{{0.014874391356216007`, 1.}}], 
           ArrowBox[{{4.954822378971856, 2.5515137523526046`}, {
            5.1099970635057685`, 2.5455206501901713`}, {5.241631279214413, 
            2.5406594657481256`}, {5.373414028813697, 2.536238036685896}, {
            5.50487032055542, 2.5322384100770106`}, {5.635525162691382, 
            2.5286426329949974`}, {5.656854249492381, 2.52812387996534}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5303689881843494, -1.6136893036119007`}, \
{-0.40936641187347117`, -1.583826484833065}, {-0.2882708723393188, \
-1.5582580159498618`}, {-0.1656240500067656, -1.5368440659549907`}, \
{-0.0399676253006839, -1.519444803841151}, {
            0.08965012534825756, -1.504466620459715}, {
            0.22418092550938953`, -1.4903159066620546`}, {
            0.36323360785398573`, -1.474080516702874}, {
            0.4017851888604247, -1.4683638250213775`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.4251417843110731, -1.4649003495572066`}, {
            0.5064170050533194, -1.4528483048368777`}, {
            0.6712194513168517, -1.4199600517359423`}, {
            0.8347094420726964, -1.375256491840056}, {
            0.9931978358330144, -1.3193336791438346`}, {
            1.0636111535195596`, -1.2901295597744173`}, {
            1.1321787301279176`, -1.2593020229052863`}, {
            1.3153675638152882`, -1.166622758814568}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.3361079344746114`, -1.1553475938238087`}, {
            1.4955695393396078`, -1.0657044476791044`}, {
            1.697479616080465, -0.9514858949777288}, {
            1.7141566571215838`, -0.9422345682463548}, {
            1.7307834490327787`, -0.9331550628806047}, {
            1.7990807611641222`, -0.8989686383184416}, {
            1.8673840007448372`, -0.8672901850900229}, {
            2.0048252059099205`, -0.8083879418535096}, {
            2.145053698079252, -0.758023292831609}, {
            2.184780163880133, -0.7465215077824735}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.207460692723681, -0.7399549390656203}, {
            2.2902886653287133`, -0.7159742119167775}, {
            2.453274670808212, -0.6788346653156926}, {
            2.6236585822858767`, -0.6486583926344298}, {
            2.8011407491958984`, -0.6241534521669568}, {
            2.9854215209724675`, -0.6040279022072417}, {
            3.1383663339824572`, -0.5908871668501919}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.1618916555165977`, -0.5888659147502633}, {
            3.1760383878945913`, -0.5876504536784708}, {
            3.372158832464483, -0.5738847862423799}, {
            3.4962918375738345`, -0.5668455796122407}, {
            3.6222535510299707`, -0.5607099255614323}, {
            3.7498401527070326`, -0.5552939794168321}, {
            3.8788478224791634`, -0.5504138965053175}, {
            4.0091510029542805`, -0.5460156764596322}, {
            4.10516447485, -0.5431713179915876}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.12876611353671, -0.5424721294346818}, {
            4.140668858302459, -0.5421195156587296}, {
            4.273264650741077, -0.5386528645488013}, {
            4.406801642487514, -0.5355431735760386}, {
            4.541186822517367, -0.5327559053061149}, {
            4.676352166525218, -0.5302782435158361}, {
            4.81219841680692, -0.5280702204680923}, {
            4.948626315658326, -0.5260918684257736}, {
            5.073064823806313, -0.5244845326018435}}]}, 
          {Arrowheads[{{0.011862717510706042`, 1.}}], 
           ArrowBox[{{5.09667505050417, -0.5241962714632652}, {
            5.222976208034549, -0.5227548461071215}, {
            5.3607773441596684`, -0.52136433957121}, {
            5.498900141582486, -0.5201285140592989}, {
            5.637570510103716, -0.5190282211508016}, {
            5.656854249492381, -0.5188932107082624}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.657398108075013, 
            1.6498547011540499`}, {-0.4915593360396402, 
            1.6042324291887908`}, {-0.2828183756218638, 
            1.557617177890294}, {-0.06904272398905029, 1.5239048979813774`}, {
            0.15654614769940894`, 1.4988280455308096`}, {0.27101218763468904`,
             1.4858313148468205`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.29447343558909883`, 1.4831674721791948`}, {
            0.39679589697309614`, 1.4715495506167595`}, {0.5903711976001648, 
            1.4392537361176252`}, {0.7855250541639653, 1.3921268803490445`}, {
            0.9750022089789917, 1.328880958681573}, {1.044324218864717, 
            1.3009550098839535`}, {1.1120367930863173`, 
            1.2713075009284618`}, {1.198168056051509, 1.228736910357506}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.2193357049178228`, 1.21827474734938}, {
            1.301321507634277, 1.1777530607988902`}, {1.4741071388361535`, 
            1.082024062859681}, {1.6831170336382515`, 0.963617430329785}, {
            1.6998880846933806`, 0.9542170798623715}, {1.7166025201467523`, 
            0.9449920375436932}, {1.7847194803749091`, 0.9104599181788603}, {
            1.8527569718603618`, 0.878450646841184}, {1.9895140159407465`, 
            0.8189140423785923}, {2.0610733105940025`, 0.7926046269552606}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.083234935445632, 0.7844567071427079}, {
            2.128641203290456, 0.7677626862004796}, {2.2724183118036345`, 
            0.7248197774297768}, {2.425610295343474, 0.68859050429741}, {
            2.5853828261665943`, 0.6588437990731614}, {2.751528956633326, 
            0.6344258925705893}, {2.923841739103998, 0.6141830156032525}, {
            3.0081577572442084`, 0.6062942744286429}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.031667076834145, 0.6040947049811415}, {
            3.1019417654069126`, 0.5975196930023385}, {3.285146100833015, 
            0.5833640694639854}, {3.4071511179878335`, 0.5756763985805792}, {
            3.53106305552565, 0.5689677740758353}, {3.656691848773527, 
            0.563045578583479}, {3.783847433058527, 0.5577171947372352}, {
            3.912396729972408, 0.5529219602581694}, {3.974496656476712, 
            0.5508905776906913}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.998096026678913, 0.550118606580083}, {
            4.042239224686755, 0.548674615774399}, {4.173233697898368, 
            0.5448956482802267}, {4.305238930304051, 0.5415055447699552}, {
            4.438157674774106, 0.5384661410495337}, {4.571917811135128, 
            0.5357629008172817}, {4.706415810518348, 0.533351752906056}, {
            4.841548144055, 0.5311886261487139}, {4.942342861932188, 
            0.5297496934616717}}]}, 
          {Arrowheads[{{0.014631093647853264`, 1.}}], 
           ArrowBox[{{4.965952449228966, 0.5294126459694578}, {
            4.977244523252519, 0.5292514417440857}, {5.113453654119028, 
            0.5275306879572724}, {5.2501004995367895`, 0.526001144220537}, {
            5.387110022388067, 0.5246375899661421}, {5.521519125734948, 
            0.5234479129639904}, {5.65618326263806, 0.5223950975524166}, {
            5.656854249492381, 0.5223904251984839}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           
           ArrowBox[{{-5.656854249492381, -0.6723608580137553}, \
{-5.517454281731932, -0.6722407564083698}, {-5.301438663986418, \
-0.6716484466600885}, {-5.085690349139244, -0.6705490507203332}, \
{-5.056934707810731, -0.6703651349203779}, {-5.028185964472404, \
-0.6701701868066009}, {-4.8379021704188405`, -0.6682618187526582}, \
{-4.712400145254443, -0.6665901758239335}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.688790246515668, -0.6662757002589148}, \
{-4.648001407072503, -0.6657324072328721}, {-4.435006440450529, \
-0.6623326811359015}, {-4.2223665520918825`, -0.657812268767289}, \
{-4.010081741996561, -0.6521711701270346}, {-3.798152010164566, \
-0.6454093852151385}, {-3.7446130736475998`, -0.6433143577188866}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.721019137592368, -0.6423911054468723}, \
{-3.5859133814916593`, -0.6371042937851727}, {-3.3727018808736036`, \
-0.6268332755907099}, {-3.158517508310399, -0.6145963306317498}, \
{-2.9433602638020453`, -0.6003934589082927}, {-2.803442236665754, \
-0.5898552141551399}, {-2.778194736464126, -0.5877117130813184}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7546673829954456`, -0.5857142516684438}, \
{-2.6614912173059793`, -0.577803638355643}, {-2.51750720572272, \
-0.5642387315098021}, {-2.371490201915977, -0.5491604936176171}, \
{-2.1658483399211224`, -0.524997749961658}, {-1.9505777813644247`, \
-0.4957661140495938}, {-1.816877504735393, -0.4753465638941476}}]}, 
          {Arrowheads[{{0.01934675925401892, 1.}}], 
           ArrowBox[{{-1.793536164753917, -0.47178172712294547`}, \
{-1.792654016873379, -0.4716469999305617}, {-1.6249027785763792`, \
-0.44345923884247307`}, {-1.4979538784113915`, -0.42064455497148456`}, \
{-1.3614203038158081`, -0.39496338531868413`}, {-1.1390960532350858`, \
-0.3536809453987747}, {-1.0771876019963993`, -0.3429522341399652}, \
{-1.011543991635311, -0.3328304422818669}, {-0.9510675038754307, \
-0.3248133639167005}, {-0.9409036062917946, -0.32360624617488476`}, \
{-0.93222171310853, -0.32259260384811267`}, {-0.9251430254147028, \
-0.3217748350818649}, {-0.9149783119960153, -0.32060038236736527`}, \
{-0.9085591720126943, -0.31985394116625054`}, {-0.9042311909484175, \
-0.319348605191202}, {-0.8978030665663126, -0.3185951283264076}, \
{-0.8931171260435125, -0.3180435629372244}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -1.7752181679128414`}, \
{-5.594225580410296, -1.7751625231391213`}, {-5.467518856853779, \
-1.7747815643702456`}, {-5.34022209154999, -1.7740828980742365`}, \
{-5.212959613757389, -1.7730182771381109`}, {-5.085761964699471, \
-1.771541232745564}, {-4.9586596855997325`, -1.7696052960802902`}, \
{-4.831768057058698, -1.767101147694359}, {-4.712467212121754, \
-1.764102096079073}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.688865146488172, -1.7634200316293793`}, \
{-4.578962593454311, -1.7600602574167332`}, {-4.453048758390959, \
-1.7555235155250388`}, {-4.327460854486834, -1.7503092424647564`}, \
{-4.2021988817419365`, -1.7444174382358861`}, {-4.0772628401562665`, \
-1.7378481028384283`}, {-3.9526527297298237`, -1.7306012362723824`}, \
{-3.8283854974956975`, -1.7224828571792772`}, {-3.745640178654118, \
-1.7163498703291502`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7220927770949257`, -1.7146045642968697`}, \
{-3.704478090486977, -1.713298984200641}, {-3.580930508703661, \
-1.7030496173364738`}, {-3.4577427521457507`, -1.6917347565867755`}, \
{-3.3349148208132453`, -1.679354401951546}, {-3.2124467147061457`, \
-1.6659085534307858`}, {-2.9685899781681617`, -1.635820374732672}, \
{-2.8501825948422757`, -1.61943250830217}, {-2.7836874200544193`, \
-1.6094377578169021`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.760337717570231, -1.605928112929446}, \
{-2.732034385622128, -1.601673898369886}, {-2.52495492760411, \
-1.5671239305685134`}, {-2.31859153620955, -1.5280157781023966`}, \
{-2.1319577343061096`, -1.487771611498269}, {-1.945412245791008, \
-1.4423268441936072`}, {-1.9200278237332464`, -1.4357875006766536`}, \
{-1.894639243578971, -1.429131124154446}, {-1.8364580135787745`, \
-1.4125580356260992`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8137493566625777`, -1.4060894102389991`}, \
{-1.8029784493706211`, -1.4030212867208196`}, {-1.7111251722515226`, \
-1.375028276005994}, {-1.5387677412536567`, -1.3190509058808941`}, \
{-1.3648720920734378`, -1.2557045845884365`}, {-1.1874288308316256`, \
-1.183106505108711}, {-1.0044285636489798`, -1.0993738604218086`}, \
{-0.9346231532555841, -1.064581384625917}}]}, 
          {Arrowheads[{{0.01181113877096596, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAT5K9qlA77b9agrjxYd3wv1B4D19S
Yeq/v6Ft63Un8L+kBPYKNZLlvxTQVgc45+2/wHHCSJY/5L/nKnh5ykTtv2Cl
nXcg2OK/Si1ZyI2e7L+uqIs5s2nhv4/xOm4a++u/3pxliC3u4L8yrrGIJ8Xr
v6rasyJzeuC/K06+HQ+T678BiEKCtBLgv+WQuupzZuu/MbdIMgn+3r9cDR6c
4Sbrv4O6MmswV96/SePnw6wC678kTb9OWOHdv/l7axUE6eq/+i77pxZ73b8p
K7aHs9Lqv8qrOn88JN2/1iaI7bW/6r+lkaoC/Nncv+Y7qHByr+q/vTUiya0S
3L+JCiQAroPqv4iD+Xjkkdu/PKhdPEln6r/LjiZxVzbbvwwr3eQMU+q/eFNM
fczY2r/SbLIHVT7qv3+irytfmNq/GO3j9Qgw6r9PJnJ/tTPav0Ea+zOnGeq/
BO2/Yw==
            "]]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -4.614874231139193}, \
{-5.4989338972552435`, -4.614948287106928}, {-5.311945376677376, \
-4.614581164978753}, {-5.124519506688714, -4.613410099270346}, \
{-4.937128779955456, -4.611309343600079}, {-4.712428188792252, \
-4.607184978595761}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.68882301918611, -4.606626666744441}, \
{-4.4690259002780595`, -4.60064799707365}, {-4.235632894422684, \
-4.5922934422356665`}, {-4.003081010399726, -4.582021088072156}, \
{-3.7718213404716203`, -4.569698473121094}, {-3.7451808128556903`, \
-4.568034803416281}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.721614727313382, -4.5665631290131685`}, \
{-3.5421854025969743`, -4.555357978124668}, {-3.314295459702698, \
-4.539320457682431}, {-3.088273774715705, -4.521906766393934}, \
{-2.8644994721258596`, -4.503219061549663}, {-2.779831070207826, \
-4.495689632289274}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.756311892054371, -4.493598108365858}, \
{-2.643146187172664, -4.483534458287358}, {-2.4240279489074816`, \
-4.4634362479774525`}, {-2.2069587863816746`, -4.443507721990381}, \
{-2.0257445856401097`, -4.427438524474129}, {-1.8458305950927634`, \
-4.412449182956087}, {-1.8155347293858923`, -4.410126781622435}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7919918083107393`, -4.408322043252124}, \
{-1.6670398438663023`, -4.398743554501351}, {-1.491083050402946, \
-4.384351020814013}, {-1.3154531273304761`, -4.3721595569829015`}, \
{-1.1405925018322258`, -4.361659520345282}, {-0.9665011739081952, \
-4.352850910901154}, {-0.8495252108979299, -4.3480474866278085`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8259331000104275, -4.347078715649736}, \
{-0.7931791435583843, -4.345733728650518}, {-0.6201648917218123, \
-4.340187776837167}, {-0.4469968993374994, -4.336092858704895}, \
{-0.27367516640544676`, -4.3334489742537}, {-0.10019969292565145`, \
-4.332256123483584}, {0.030515808250049847`, -4.331967643389422}, {
            0.11835709160885297`, -4.331858815684199}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1419690664857562, -4.331829562502285}, {
            0.1615576641373067, -4.331805293934597}, {
            0.29292587473612025`, -4.331769075119108}, {
            0.42462044004649036`, -4.331858986942955}, {
            0.5566413600684172, -4.33207502940614}, {
            0.6889886348019011, -4.332417202508663}, {
            0.8216622642469418, -4.332885506250521}, {
            0.954662248403538, -4.333479940631716}, {
            1.0864455130531046`, -4.33382381680482}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1100574256643967`, -4.333885429894843}, {
            1.1309074261916054`, -4.333939836032144}, {
            1.3072636990517694`, -4.333579632193715}, {
            1.4837310669840298`, -4.332399329116428}, {
            1.6603095299883868`, -4.330398926800283}, {
            1.8369990880648401`, -4.3275784252452825`}, {
            2.0137997412133903`, -4.323937824451424}, {
            2.0544485202926643`, -4.322912895287632}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.07805301109611, -4.322317725357098}, {
            2.190711489434036, -4.319477124418708}, {
            2.367734332726779, -4.314196325147136}, {
            2.6091752371058092`, -4.306301986052653}, {
            2.850140970865015, -4.298152832145623}, {
            3.0220464632207804`, -4.292145576136812}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0456440523919355`, -4.29132095583295}, {
            3.090631534004397, -4.289748863426046}, {
            3.3306469265239547`, -4.281090079893921}, {
            3.5701871484236882`, -4.2721764815492485`}, {
            3.8092521997035975`, -4.26300806839203}, {
            3.989458148969487, -4.255890743312095}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.013051747370415, -4.254958902214124}, {
            4.047842080363683, -4.253584840422263}, {
            4.285956790403944, -4.24390679763995}, {
            4.4645453681872596`, -4.23670523496338}, {
            4.643037270832711, -4.229832743113419}, {
            4.779502477799142, -4.22483089573245}, {
            4.915923288182447, -4.220082891146742}, {
            4.956833902509886, -4.218734718727401}}]}, 
          {Arrowheads[{{0.014328984100183665`, 1.}}], 
           ArrowBox[{{4.980433084951942, -4.217957028941744}, {
            5.052299701982624, -4.215588729356296}, {
            5.188631719199674, -4.21134841036111}, {
            5.2069525659175095`, -4.210795545369663}, {
            5.22527263441071, -4.2102494006369655`}, {
            5.4178008822095265`, -4.205251682367633}, {
            5.559974493650302, -4.2018562971194235`}, {
            5.656854249492381, -4.199710166097871}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            4.615499704213702}, {-5.500211659430803, 
            4.615575538890458}, {-5.313227337238787, 
            4.615212778174337}, {-5.125781818754679, 
            4.614047523876281}, {-4.93837047808379, 
            4.611953367146369}, {-4.712428104126709, 4.607815732819243}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688823152807036, 
            4.607247763742984}, {-4.470211946238145, 
            4.601311803174614}, {-4.236789005719974, 
            4.5929682416058135`}, {-4.004205860630167, 
            4.582707015563944}, {-3.7729134800461184`, 
            4.570394990350317}, {-3.7451807208847163`, 
            4.568664523476492}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7216145607651323`, 
            4.567194043774389}, {-3.5432434048784667`, 
            4.556064052174522}, {-3.3153181767460254`, 
            4.540034873835633}, {-3.0892603372676097`, 
            4.522628128132724}, {-2.8654493355015016`, 
            4.503945401021793}, {-2.779829968825475, 
            4.4963337385147275`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7563107340987005`, 
            4.494242850855606}, {-2.6440590945544074`, 
            4.484263547933301}, {-2.424903867117789, 
            4.464166145878011}, {-2.207797905883109, 
            4.444236771866687}, {-2.0265798974586087`, 
            4.428168022947499}, {-1.846662498666949, 
            4.41317790355087}, {-1.8155318573614132`, 4.410791225824965}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7919889526952548`, 
            4.4089862734110925`}, {-1.6678687105201675`, 
            4.399470407212714}, {-1.4919095232352375`, 
            4.38507359641917}, {-1.3162774511493545`, 
            4.372877379595727}, {-1.141414991732424, 
            4.362371772902594}, {-0.9673221449844484, 
            4.3535567763397705`}, {-0.8495222122830476, 4.348714654354518}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8259301413388882, 
            4.347744911140098}, {-0.7939989109054268, 
            4.346432389907255}, {-0.6209842997414423, 
            4.340878930154414}, {-0.44781732173857886`, 
            4.33677671363061}, {-0.27449797689683675`, 
            4.334125740335844}, {-0.10102626521621516`, 4.332926010270116}, {
            0.029617024627054206`, 4.3326333019766645`}, {
            0.11836010717116395`, 4.33252135320841}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1419720813815142, 4.332491566870668}, {
            0.16058601866754119`, 4.332468085521003}, {0.29188071690524575`, 
            4.332430360903131}, {0.4235011193401679, 4.332520128123049}, {
            0.5554472259723076, 4.332737387180756}, {0.687719036801665, 
            4.333082138076253}, {0.8203165518282399, 4.333554380809539}, {
            0.9532397710520325, 4.334154115380616}, {1.086448457582934, 
            4.3345082890111515`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1100603671229556`, 4.3345710680681595`}, {
            1.1294053432585418`, 4.334622502254691}, {1.305682283573588, 
            4.334271724427174}, {1.4820705919971708`, 4.3331017818980655`}, {
            1.65857026852929, 4.3311126746673665`}, {1.8351813131699453`, 
            4.328304402735076}, {2.011903725919138, 4.324676966101194}, {
            2.054451581853558, 4.323607072373299}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{2.0780561134110624`, 4.323013520954347}, {
            2.1887375067768673`, 4.32023036476572}, {2.365682655743132, 
            4.314964598728656}, {2.607952182489034, 4.307060798040006}, {
            2.849743705922978, 4.29890096555959}, {3.0220512160405493`, 
            4.292891701687868}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.045648862707801, 4.2920687283567664`}, {
            3.0910572260449642`, 4.290485101287407}, {3.3318927428549916`, 
            4.2818132052234565`}, {3.572250256353062, 4.27288527736774}, {
            3.812129766539173, 4.263701317720256}, {3.9894655911701182`, 
            4.256708677246741}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.013059248953208, 4.255778340882526}, {
            4.051531273413326, 4.254261326281005}, {4.290454776975522, 
            4.2445653030499875`}, {4.469195044336313, 4.237368871359817}, {
            4.647838756611102, 4.230502245306641}, {4.784284690234145, 
            4.225510788000343}, {4.9206861440553595`, 4.220774275657035}, {
            4.956842674269697, 4.219585939471377}}]}, 
          {Arrowheads[{{0.01432879599676117, 1.}}], 
           ArrowBox[{{4.980441924723998, 4.218810316282343}, {
            5.057043118074747, 4.216292708276717}, {5.193355612292304, 
            4.21206608585939}, {5.211673981733129, 4.211515131256697}, {
            5.229991574510874, 4.2109708882023416`}, {5.42239811181499, 
            4.205991252236693}, {5.563581282451002, 4.202627336280243}, {
            5.656854249492381, 4.200564878596105}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -2.9670878736294894`}, \
{-5.535479020474037, -2.9669619106070577`}, {-5.38831495068017, \
-2.9663951092456124`}, {-5.239134656193974, -2.965299106458516}, \
{-5.089915646460279, -2.9635629202316243`}, {-4.940852659311289, \
-2.961090996779844}, {-4.792140432579208, -2.9577877823180825`}, \
{-4.712479753944969, -2.955502758701499}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.688877468910411, -2.9548257398807465`}, \
{-4.643895430390051, -2.9535354543584122`}, {-4.496234116869835, \
-2.9482161904129067`}, {-4.34915649201856, -2.941829990481566}, \
{-4.20266255583623, -2.93437685456439}, {-4.0567523083228405`, \
-2.925856782661379}, {-3.911425749478392, -2.916269774772532}, \
{-3.766682879302886, -2.90561583089785}, {-3.745864767077934, \
-2.9039232117406004`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.7223304330764955`, -2.9020097498400443`}, \
{-3.622523697796323, -2.8938949510373333`}, {-3.45742525279263, \
-2.8790867819312562`}, {-3.293673278000727, -2.8629025113789455`}, \
{-3.131267773420616, -2.845342139380401}, {-2.9702087390522918`, \
-2.826405665935623}, {-2.810660935194621, -2.806208142681344}, \
{-2.783219665442596, -2.8024982129755323`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7598205458754586`, -2.7993347628306804`}, \
{-2.6527891221464635`, -2.784864621254298}, {-2.4965932999078193`, \
-2.762375101654484}, {-2.34207346847869, -2.738739583881903}, \
{-2.1893049729297798`, -2.714445434740156}, {-2.0383631583317943`, \
-2.6899800210328446`}, {-1.8892480246847345`, -2.665343342759969}, \
{-1.8265171273643053`, -2.654777514370558}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.803233097027098, -2.6508557616256523`}, \
{-1.7419595719886007`, -2.640535399921529}, {-1.526279924712034, \
-2.6043413614857283`}, {-1.3145104776570764`, -2.569784220108431}, \
{-1.1062460521003383`, -2.5381371281518654`}, {-0.9010814693184275, \
-2.510673237978259}, {-0.8698430863153507, -2.5072320588328623`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.846373067487178, -2.5046466324577}, \
{-0.6973375432835089, -2.4882290753209433`}, {-0.4933350879677484, \
-2.4716411659132493`}, {-0.2873454349630205, -2.4603299166237087`}, \
{-0.07763991586120042, -2.453715734320853}, {
            0.09608597444519035, -2.4504209960823777`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.11969372224218114`, -2.4499732715132083`}, {
            0.1368318530097796, -2.4496482442263923`}, {
            0.35712025532198666`, -2.4459770715620364`}, {
            0.5826123654886621, -2.440226230249755}, {
            0.8126952579230471, -2.4299197342115186`}, {
            0.9524336895531715, -2.4212452502630493`}, {
            1.0632314547054735`, -2.4126190466034685`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.0867722097912287`, -2.4107862718413524`}, {
            1.0925577200284406`, -2.410335838662378}, {
            1.2330673493488538`, -2.3971914994095065`}, {
            1.373962577514412, -2.3818122325044326`}, {
            1.5516359372834145`, -2.360183534355405}, {
            1.7282163748091899`, -2.3369741781326776`}, {
            1.903703890091738, -2.3121841638362497`}, {
            2.0238456095609028`, -2.294017213434348}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.0471921980708725`, -2.2904869134071117`}, {
            2.078098483131059, -2.2858134914661217`}, {
            2.2516963853534087`, -2.259008170201465}, {
            2.4247938281850443`, -2.232914209221451}, {
            2.5973908116259645`, -2.207531608526079}, {
            2.7694873356761702`, -2.1828603681153504`}, {
            2.896607783499733, -2.165346213268952}, {
            2.9817693411053803`, -2.154237390309798}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.0051829750834003`, -2.151183219836582}, {
            3.023792295599444, -2.148755743721594}, {
            3.1927386257046755`, -2.128084658689317}, {
            3.3622518684542353`, -2.1088562394687798`}, {
            3.5323320238481237`, -2.0910704860599814`}, {
            3.7029790918863403`, -2.074727398462922}, {
            3.7257741572193694`, -2.072644102222331}, {
            3.748580511414445, -2.070590323532437}, {
            3.899247269700907, -2.0584641800463515`}, {
            3.944654640219149, -2.055151003659007}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.968204028199126, -2.05343270825231}, {
            4.050432626968626, -2.0474328485665776`}, {
            4.242009854236882, -2.034165325022479}, {
            4.434408820476117, -2.0222598933538265`}, {
            4.62762952568633, -2.011716553560619}, {
            4.821671969867521, -2.002535305642857}, {
            4.911057775769609, -1.9988489806524916`}}]}, 
          {Arrowheads[{{0.015301163229078298`, 1.}}], 
           ArrowBox[{{4.934649714850257, -1.9978760347386915`}, {
            5.016421631501287, -1.994503711170999}, {
            5.211763989069226, -1.9874093317155017`}, {
            5.407699042571337, -1.9812521672763657`}, {
            5.604226792007619, -1.9760322178535907`}, {
            5.656854249492381, -1.974859640348612}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, -3.7258796660669766`}, \
{-5.569325494904021, -3.7258835177808}, {-5.425287170205636, \
-3.7255239349494493`}, {-5.2788941630206905`, -3.7247008535054587`}, \
{-5.132468485093759, -3.7233164902935676`}, {-4.98605164416711, \
-3.7212979857707964`}, {-4.839685147983007, -3.718572480394168}, \
{-4.712466094561025, -3.715265600818599}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688862074440334, -3.7146520476601776`}, \
{-4.606015005967356, -3.712498555150527}, {-4.3734103062959715`, \
-3.704131985812124}, {-4.141871048968856, -3.6934727723789598`}, \
{-3.9113972339860084`, -3.680520914851034}, {-3.7455368564316287`, \
-3.6694776397440108`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7219770275789834`, -3.6679089849795004`}, \
{-3.6825349665479505`, -3.665282863315145}, {-3.4558303518552083`, \
-3.647765067858092}, {-3.2312833899077797`, -3.627967528479875}, \
{-3.0088940807056646`, -3.6058902451804937`}, {-2.789032182253596, \
-3.582386670308045}, {-2.7815234532368547`, -3.5815534322540783`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.758055512293751, -3.578949212365674}, \
{-2.572067452556306, -3.5583102562106257`}, {-2.3579998916137925`, \
-3.5336610028882354`}, {-2.1468294994260586`, -3.508438910340874}, \
{-2.012328414146026, -3.492275394959744}, {-1.878886532253351, \
-3.476632476410106}, {-1.8198979377648923`, -3.469894098597937}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7964385088044441`, -3.467214284017439}, \
{-1.7465038537480349`, -3.4615101546919598`}, {-1.615180378630079, \
-3.446908429805306}, {-1.4847741851981477`, -3.4330848804467666`}, \
{-1.3551433517509064`, -3.4202970853129635`}, {-1.226287878288356, \
-3.408545044403897}, {-1.098207764810498, -3.397828757719567}, \
{-0.9706042120605648, -3.3883280379640723`}, {-0.8560197554478737, \
-3.381039513527344}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8324486216207116, -3.3796569010386737`}, \
{-0.7159303909741728, -3.373512737351883}, {-0.5888601226377166, \
-3.368198156495189}, {-0.41743775558147755`, -3.3627565341877643`}, \
{-0.24477406277277647`, -3.358851957712512}, {-0.07086904421161333, \
-3.3564844270694314`}, {0.10427730010201275`, -3.355653942258522}, {
            0.11160953911358873`, -3.355640444750984}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.13522149210460516`, -3.355596978831095}, {
            0.28084356182074943`, -3.3553289113307594`}, {
            0.45900833259724527`, -3.354477742337117}, {
            0.6387716124315009, -3.353100435277595}, {
            0.8201334013235169, -3.3511969901521934`}, {
            1.050170850867678, -3.3471006813783055`}, {
            1.0796343276002294`, -3.3462296947434926`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1032360102551164`, -3.345531991945615}, {
            1.2811593496378686`, -3.3402722986639843`}, {
            1.5130988976340891`, -3.33071184200923}, {
            1.7459894948563388`, -3.318419311414042}, {
            1.9791570634106934`, -3.3039963329239637`}, {
            2.046513227032907, -3.299380403288674}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.070069969062314, -3.2977660556507313`}, {
            2.211927525403228, -3.2880445325845367`}, {
            2.444300880833943, -3.270563910395762}, {
            2.676277129702837, -3.251554466357639}, {
            2.844809883942213, -3.2373699104464264`}, {
            3.0116288847126356`, -3.223713171124703}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.0351661911812613`, -3.22183667735893}, {
            3.18164576925801, -3.2101821542115117`}, {
            3.3499489003344305`, -3.197178953887809}, {
            3.5181754903565334`, -3.184569538759943}, {
            3.686325539324318, -3.172353908827914}, {
            3.854399047237785, -3.160532064091721}, {
            3.9770676527162276`, -3.1521874841070394`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.000625202884912, -3.1505849725201585`}, {
            4.022396014096933, -3.149104004551365}, {
            4.191708118921372, -3.1381939819435907`}, {
            4.361161635628354, -3.1280811262321238`}, {
            4.518976771373969, -3.119339379554892}, {
            4.676983385018781, -3.111205585587793}, {
            4.83518147656279, -3.103679744330826}, {
            4.943668491921404, -3.0989414204394996`}}]}, 
          {Arrowheads[{{0.014611014452874837`, 1.}}], 
           ArrowBox[{{4.967257995626339, -3.0979111154889933`}, {
            4.993571046005996, -3.096761855783991}, {
            5.0148293460137765`, -3.095874703965166}, {
            5.036091466852837, -3.094997607748307}, {
            5.227269416829563, -3.0880016850145675`}, {
            5.4186377137825605`, -3.0818255921283053`}, {
            5.567134039735048, -3.0772532336827867`}, {
            5.656854249492381, -3.0747669676025735`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            3.726830002849124}, {-5.570919104560654, 
            3.726835578654739}, {-5.4269250179013095`, 
            3.7264806814458216`}, {-5.280536849470861, 
            3.7256636780171286`}, {-5.1341151986463025`, 
            3.7242863937506523`}, {-4.987701542660502, 
            3.722275939802869}, {-4.841337358746326, 
            3.719559427330256}, {-4.712466050010351, 
            3.7162178261066097`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688861990798402, 
            3.715605778677905}, {-4.607518747493927, 
            3.7134965684585963`}, {-4.374764732733585, 
            3.70513924251152}, {-4.1430753144653, 
            3.6944874494890265`}, {-3.9124504926890715`, 
            3.681541189391116}, {-3.745536331112711, 
            3.6704375800702342`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.7219764103391744`, 
            3.6688703064882344`}, {-3.6834375472696843`, 
            3.666306590652782}, {-3.4565837580719205`, 
            3.6487897817090187`}, {-3.2318891250957784`, 
            3.6289907625598254`}, {-3.0093536483412615`, 
            3.6069095332052026`}, {-2.7893478751785965`, 
            3.5834003085459205`}, {-2.7815211031816025`, 
            3.5825321031326203`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7580530552272795`, 
            3.5799288477571785`}, {-2.572242352978014, 
            3.5593173034827483`}, {-2.3580370817395133`, 
            3.534660518015686}, {-2.146732061463094, 
            3.5094299521447345`}, {-2.0121090305365117`, 
            3.493257094981218}, {-1.8785464917726922`, 
            3.4776066423165024`}, {-1.8198912872291046`, 3.47090984945723}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7964317004076544`, 
            3.4682314171726643`}, {-1.7460444451716364`, 
            3.4624785941505887`}, {-1.614602890733344, 
            3.447872950483476}, {-1.484079071414282, 
            3.434047557022839}, {-1.3543302301709168`, 
            3.4212602594763504`}, {-1.2253563670032483`, 
            3.4095110578440107`}, {-1.0971574819112782`, 
            3.3987999521258194`}, {-0.9694339618750227, 
            3.3893059686374993`}, {-0.8560085557244763, 
            3.3821047433105678`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.83243806516721, 
            3.3807110198259487`}, {-0.7145141779097088, 
            3.374506447297637}, {-0.5873179139806519, 
            3.369200909446095}, {-0.4158393859720323, 
            3.3637741575206763`}, {-0.24311837053312596`, 
            3.3598804755572447`}, {-0.06915486766393353, 
            3.3575198635558006`}, {0.10605112263554439`, 3.356692321516344}, {
            0.1116202278742737, 3.3566820492511744`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1352321807058222, 3.3566384967898246`}, {
            0.2826765984096101, 3.3563665342228535`}, {0.4608985577025657, 
            3.355511186459308}, {0.6407170005144105, 3.3541262782257073`}, {
            0.8221319268451437, 3.3522118095220517`}, {1.0522868306943385`, 
            3.3480986423031296`}, {1.0796454120432288`, 3.347288243187545}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1032470529583709`, 3.346589129857067}, {
            1.2833896090269956`, 3.3412530575565538`}, {1.5154402618431153`, 
            3.331675055282324}, {1.7484387891426985`, 3.319364635480441}, {
            1.9817121384860918`, 3.3049253590986374`}, {2.0465266098397734`, 
            3.30048205360447}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0700833132267284`, 3.2988671421904345`}, {
            2.214587257433643, 3.288960787084647}, {2.4470641459853537`, 
            3.2714709194384706`}, {2.679142804141223, 3.2524557561601073`}, {
            2.847779524996003, 3.2382669525404286`}, {3.011645670995702, 
            3.224858387104337}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0351825054146553`, 3.222976056558359}, {
            3.1848243316147293`, 3.211077692316684}, {3.353232417378676, 
            3.198077235712618}, {3.521564291445677, 3.185472894780423}, {
            3.689819953815734, 3.173264669520099}, {3.8579994044888464`, 
            3.1614525599316456`}, {3.977086745101142, 3.1533652656935813`}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.000644478205935, 3.1517654456100974`}, {
            4.0261026434650145`, 3.1500365660150638`}, {4.195538952606144, 
            3.13913886405988}, {4.365117287490145, 3.129038512008754}, {
            4.5229159173460705`, 3.1203156544818524`}, {4.680905895132144, 
            3.1121998983334094`}, {4.839087220848364, 3.1046912435634257`}, {
            4.943688330598819, 3.100132943655151}}]}, 
          {Arrowheads[{{0.014610594095856896`, 1.}}], 
           ArrowBox[{{4.967277935465796, 3.099104957489823}, {
            4.997459894494731, 3.097789690171901}, {5.018716130578717, 
            3.0969046635704585`}, {5.03997618116769, 3.0960296794216906`}, {
            5.231276814823839, 3.08904698032826}, {5.42276428493355, 
            3.0828861652438952`}, {5.5698864188505715`, 3.078368064637387}, {
            5.656854249492381, 3.075961841734026}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            5.577906130133575}, {-5.498260932203243, 
            5.57769944904581}, {-5.3241655121477915`, 
            5.577104416046672}, {-5.14890057502358, 
            5.576066967868315}, {-4.973228895518762, 
            5.57452805339869}, {-4.797913248321493, 
            5.572428621525744}, {-4.7124084687313985`, 
            5.571094551071252}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.688799349160087, 
            5.57072619471705}, {-4.625256910907877, 
            5.569734787103521}, {-4.456330758523658, 
            5.566392532213191}, {-4.2900489625114435`, 
            5.562312606583387}, {-4.125325694213844, 
            5.557405759942747}, {-3.9165295127252375`, 
            5.549621754556163}, {-3.7448077414001615`, 
            5.541775514719147}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7212203575018323`, 
            5.5406977697729705`}, {-3.7044825690002847`, 
            5.539932993694137}, {-3.4901327573895196`, 
            5.5286278146233965`}, {-3.2744279722434797`, 
            5.515994554610668}, {-3.0591049472149345`, 
            5.502330158802348}, {-2.845269344514868, 
            5.487924686041097}, {-2.778506927216765, 5.483249977669981}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7549526047856436`, 
            5.481600702633203}, {-2.6329224513311336`, 
            5.473056144138036}, {-2.4220655548515846`, 
            5.458002540904285}, {-2.2128542825381543`, 
            5.443067170776224}, {-2.0053207896335117`, 
            5.428533098890026}, {-1.8127857781944732`, 
            5.415558072139882}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7892246338534643`, 
            5.414009982194253}, {-1.5945514574864301`, 
            5.401659505286458}, {-1.4699554868048166`, 
            5.394327978987098}, {-1.3457654307048903`, 
            5.387577068105414}, {-1.2219273629392888`, 
            5.38142102639379}, {-1.098962570565841, 
            5.37572206757918}, {-0.8534957621009417, 
            5.366265548736367}, {-0.8460051906097219, 5.366052219423511}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8224027675628888, 
            5.365380029231319}, {-0.6090054969944498, 
            5.3593025365928675`}, {-0.3652894650807826, 
            5.354849876733004}, {-0.12214535619435682`, 
            5.352924414741102}, {-0.07357372671979584, 
            5.352792042129517}, {-0.025025961688239173`, 
            5.3527620782000955`}, {-0.0007642071348712871, 
            5.352798419942962}, {0.023491356264227777`, 5.352860464279441}, {
            0.04774681619737859, 5.35293613445521}, {0.0720039115086864, 
            5.353021944686875}, {0.09626262888667625, 5.353117901967788}, {
            0.12194107903416544`, 5.35324147425242}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.1455527986314215, 5.353355100819365}, {
            0.28821887308090927`, 5.354041652097108}, {0.48020133834735745`, 
            5.355153666233889}, {0.6722100246860203, 5.35645394437813}, {
            0.8642449320968975, 5.35794248652983}, {1.0563060605799892`, 
            5.359619292688992}, {1.090008566146654, 5.359946526823974}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1136194462225237`, 5.360175776423904}, {
            1.2483934101352965`, 5.361484362855612}, {1.4405069807628181`, 
            5.3635376970296935`}, {1.632646772462554, 5.365779295211234}, {
            1.8246215210533174`, 5.367847447795983}, {2.0162399623539216`, 
            5.369380445179688}, {2.058050924317667, 5.369598579008221}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.0816625959795436`, 5.3697217645101984`}, {
            2.2075020963643657`, 5.37037828736235}, {2.3984079230846502`, 
            5.370840974343967}, {2.5889574425147748`, 5.37076850612454}, {
            2.7791506546547398`, 5.370160882704069}, {2.968987559504545, 
            5.369018104082555}, {3.0261333780214676`, 5.3685120527878984`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.0497444452618634`, 5.368302966428558}, {
            3.15846815706419, 5.367340170259996}, {3.299301321481524, 
            5.365793724156272}, {3.4398437033154265`, 5.364063428767898}, {
            3.668691231592519, 5.360924495784694}, {3.8967454219608815`, 
            5.357440028114534}, {3.9120368526411613`, 5.357194376860206}, {
            3.927320201329396, 5.356947496299052}, {3.9941389294344947`, 
            5.355807718991459}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.01774748802759, 5.3554050100487345`}, {
            4.0822889348658595`, 5.354304078040723}, {4.2369643399115775`, 
            5.35157605964682}, {4.4260534526314, 5.348930000708207}, {
            4.615142565351224, 5.346283941769595}, {4.804231678071047, 
            5.343637882830983}, {4.962122765437749, 5.341428400132353}}]}, 
          {Arrowheads[{{0.014211984970100965`, 1.}}], 
           ArrowBox[{{4.98573244687742, 5.341098013005814}, {4.99332079079087,
             5.340991823892371}, {5.179465968680583, 5.341200800453722}, {
            5.368035563489211, 5.33905857130922}, {5.556258813023708, 
            5.337252228694127}, {5.656854249492381, 5.336464898434827}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.01938641848684033, 1.}}], 
           ArrowBox[{{1.0121290138867345`, 1.0351878026376764`}, {
            1.0607592976180147`, 0.9976774942240741}, {1.1064457819553448`, 
            0.9586902948680535}, {1.2455301231486826`, 0.8145893780443881}, {
            1.3471316720238249`, 0.6760796479644097}, {1.3781226954524832`, 
            0.6258524463526071}, {1.4050270499271214`, 0.578028489529438}, {
            1.4280848640055945`, 0.5323535694231525}, {1.4337372113291882`, 
            0.5204365390319321}, {1.4391319230124857`, 0.5086658694254043}, {
            1.4535117958005956`, 0.4765274370252942}, {1.4667474042991657`, 
            0.44639968825908055`}, {1.491208140372942, 0.3898650850772547}, {
            1.5120274474342426`, 0.34022554660782295`}, {1.5298802135715202`, 
            0.29649113549222494`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019143633268722583`, 1.}}], 
           ArrowBox[{{1.0390559752919233`, -1.0200936987113314`}, {
            1.0872350255880827`, -0.9816731114819142}, {
            1.132436749097229, -0.9418553790238774}, {
            1.229314920682583, -0.8436188572470182}, {
            1.307813843036672, -0.74638061031764}, {
            1.3874052438271038`, -0.6273223109196715}, {
            1.445922581304625, -0.5214521030315399}, {
            1.451604654931329, -0.5098858771319622}, {
            1.457147312001684, -0.49859008961089657`}, {
            1.4724082671953207`, -0.46735029442867587`}, {
            1.486705155297976, -0.4381118721232146}, {
            1.513670414985739, -0.3833268888668338}, {
            1.5378154702901645`, -0.3353863255752971}, {
            1.5599438602114064`, -0.2933136656805766}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.07976321956970409, -1.7410778163408307`}, {
            0.22099991487800555`, -1.7323553797179978`}, {
            0.366555923437885, -1.7222222377555425`}, {
            0.5161705252678788, -1.7085588114096455`}, {
            0.6683897397635237, -1.6899246091369131`}, {
            0.8217595863203563, -1.6648791393939515`}, {
            1.0155654981882005`, -1.624348290631981}, {
            1.015635954956394, -1.6243298378446571`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.0384775550877925`, -1.618347570985559}, {
            1.2055712829770633`, -1.5745853448295604`}, {
            1.3905712827023402`, -1.5187352173686341`}, {
            1.569359839379427, -1.4599428236311471`}, {
            1.7430954830224097`, -1.4010816943364575`}, {
            1.9129367436453744`, -1.345025360203923}, {
            1.939621047253427, -1.3365169638748269`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.962117151002852, -1.3293439917271552`}, {
            2.0118437259879003`, -1.3134884755302239`}, {
            2.11032757764412, -1.2834415964713155`}, {
            2.2652355778839466`, -1.2398846045054723`}, {
            2.421045907148422, -1.2012793941391866`}, {
            2.578388603846719, -1.1672382992942552`}, {
            2.7378937063880113`, -1.1373736538924757`}, {
            2.7592044509989817`, -1.1336875599530405`}, {
            2.780559004163647, -1.1300642152858398`}, {
            2.880783050609313, -1.1150840390780277`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.9041411652075277`, -1.1116326311220592`}, {
            3.0240201291153324`, -1.0955584101586089`}, {
            3.2671159885966614`, -1.0662140220322205`}, {
            3.390731531195231, -1.053703308284134}, {
            3.5157254823657373`, -1.0426335814127863`}, {
            3.64195761776698, -1.032729790611602}, {
            3.769287713057759, -1.0237168850740064`}, {
            3.8438072555776968`, -1.0190041357116735`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.8673721713750537`, -1.0175138482227546`}, {
            3.897715768238074, -1.015594864799999}, {
            4.027241783307924, -1.0083637297895804`}, {
            4.157726540711401, -1.001865990222319}, {
            4.2890308228925935`, -0.9959441562777834}, {
            4.421154629851501, -0.990598227955974}, {
            4.554097961588124, -0.9858282052568904}, {
            4.7418588357266325`, -0.9798942921026832}, {
            4.810980661382394, -0.9779848812656186}}]}, 
          {Arrowheads[{{0.0174156963699339, 1.}}], 
           ArrowBox[{{4.834583650648508, -0.9773328758669724}, {
            4.930693473071844, -0.9746779526970116}, {
            5.120601873623757, -0.9701791870398756}, {
            5.311584037382372, -0.9663979951312752}, {
            5.5034554391909944`, -0.9632390952527491}, {
            5.656854249492381, -0.9611202859027713}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-0.20414212198056925`, 
            1.7656987656151437`}, {-0.05478500275678147, 
            1.7517136928791595`}, {0.09932444172013907, 
            1.7409120295414284`}, {0.25865865928309395`, 1.73051023613886}, {
            0.4236900977649838, 1.7177247732083636`}, {0.5928462246695824, 
            1.700035603420189}, {0.7360268952292639, 
            1.6790949487036557`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.7593903377606797, 1.6756779666408708`}, {
            0.7645545075006637, 1.6749226894445854`}, {0.9364454480077787, 
            1.6422083470154405`}, {1.1061495479404788`, 
            1.6017148918666415`}, {1.272423491312312, 1.5553103807868482`}, {
            1.434023962136826, 1.5048628705647207`}, {1.5912851676700583`, 
            1.4524360621524015`}, {1.6690038048585474`, 
            1.4258923932639016`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.6913485188306452`, 1.4182608815629805`}, {
            1.7445413151680462`, 1.4000936565020332`}, {1.8386259506327374`, 
            1.3680554561539007`}, {1.9317303864954032`, 
            1.3373922308926791`}, {2.0870287437048676`, 
            1.2891199628129983`}, {2.2419251640345106`, 
            1.2449077778478317`}, {2.397417706401396, 1.2052011504812958`}, {
            2.5545044297225874`, 1.1704455551975075`}, {2.5754325877840807`, 
            1.166166696051847}, {2.596398714383593, 1.1619617163528255`}, {
            2.599385480352002, 1.1614325445340807`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6226353858505536`, 1.1573133082402283`}, {
            2.71135990026765, 1.1415937931667535`}, {2.827636311531389, 
            1.1230369549402042`}, {3.041030952530078, 1.0919650890766917`}, {
            3.2589966066413223`, 1.0661323426322729`}, {3.481276464368407, 
            1.044782509097954}, {3.5592272206097224`, 1.038713088018722}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.5827679632095917`, 1.036880152890882}, {
            3.70761371621462, 1.0271593819647409`}, {3.9376597588181674`, 
            1.0127352511369299`}, {4.1707871061278246`, 
            1.0005602384422532`}, {4.394491623859791, 0.9913601252906825}, {
            4.525840951990655, 0.987062229892131}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.5494403147937055`, 0.9862900326206008}, {
            4.6205429029813425`, 0.9839634772362269}, {4.8485232035887, 
            0.9778771324516101}, {5.078014785778082, 0.9726079291095563}, {
            5.308353767483302, 0.9680646840608061}, {5.493671842978919, 
            0.9651055005147554}}]}, 
          {Arrowheads[{{0.0029558279193960925`, 1.}}], 
           ArrowBox[{{5.517280826244712, 0.9647285091466318}, {
            5.538735613973939, 0.964385916257824}, {5.656854249492381, 
            0.9628629409838312}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            0.6723471043804703}, {-5.509769938569337, 
            0.6722117432815616}, {-5.2937719085544614`, 
            0.6716032144857397}, {-5.264953301556742, 
            0.6714913615323318}, {-5.236139739656857, 
            0.6713703000735873}, {-5.03923197384605, 
            0.6699878832901617}, {-4.842689021090407, 
            0.668032638279962}, {-4.712400399999548, 0.6664263314510366}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688790201310348, 
            0.6661352452220995}, {-4.62512728940056, 
            0.6653503557260425}, {-4.408016237812093, 
            0.6616366787970561}, {-4.191355866325002, 
            0.656891607493003}, {-3.9751461749392893`, 
            0.6511151418138832}, {-3.758887065527815, 
            0.6439166558350543}, {-3.744608284332359, 
            0.6433231924305537}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7210166592242793`, 
            0.642342662932784}, {-3.5420784399634377`, 
            0.634905523631874}, {-3.3247202982461577`, 
            0.6240817452043425}, {-3.106812640375976, 
            0.6114453205524595}, {-2.955299421673896, 
            0.6013149738183324}, {-2.8019419551132123`, 
            0.5896185401741628}, {-2.7781970547744845`, 
            0.5875894567327948}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.75467080329622, 
            0.5855790575889355}, {-2.646740240693926, 
            0.5763560196199506}, {-2.489694278416037, 
            0.561527412155696}, {-2.2690597743272507`, 
            0.537536870422361}, {-2.0389598084567027`, 
            0.5082394738839294}, {-1.8717357096504628`, 
            0.48400116256680303`}, {-1.8168968200596858`, 
            0.4751590119613694}}]}, 
          {Arrowheads[{{0.01936064939571231, 1.}}], 
           ArrowBox[{{-1.7935859004447054`, 
            0.47140038986808985`}, {-1.6946768359870346`, 
            0.45545242209004866`}, {-1.5615726885525336`, 
            0.4322194135602905}, {-1.418807942237445, 
            0.4058064126438229}, {-1.188290929567109, 
            0.36241853445256833`}, {-1.1242681643311876`, 
            0.35076028729664405`}, {-1.056451913109834, 
            0.33932848684494993`}, {-0.9852276717720276, 
            0.32897323235836456`}, {-0.9524277264897091, 
            0.3248251830617108}, {-0.9281668146674829, 
            0.3219469767145833}, {-0.9139309278126901, 
            0.32030161949219055`}, {-0.9065907611618643, 
            0.3194476706547454}, {-0.9021056200173936, 
            0.31892336546907885`}, {-0.8965742389421804, 
            0.3182745069320215}, {-0.8924899765207116, 
            0.3177936913408589}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, -5.580979433759249}, \
{-5.52940457366039, -5.580896013543733}, {-5.395668475899052, \
-5.580527112105299}, {-5.263088967578767, -5.579877601152004}, \
{-5.131666048699534, -5.578947480683848}, {-5.001399719261354, \
-5.577736750700829}, {-4.872289979264226, -5.57624541120295}, \
{-4.744336828708149, -5.574473462190209}, {-4.712411011347995, \
-5.573934119194303}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688802386998858, -5.573535283792783}, \
{-4.6171209204765145`, -5.572324323507287}, {-4.49022290745271, \
-5.569701414998864}, {-4.363642789636734, -5.56660473666494}, \
{-4.237380567028589, -5.563034288505515}, {-4.111436239628275, \
-5.558990070520589}, {-3.9858098074357895`, -5.554472082710162}, \
{-3.860501270451134, -5.549480325074234}, {-3.7448044204700026`, \
-5.544421191832069}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7212181414990155`, -5.543320929206156}, \
{-3.500625057001465, -5.532611626466829}, {-3.266633494365406, \
-5.519902476432788}, {-3.033535940766135, -5.505887347510685}, \
{-2.8013323962036503`, -5.490566239700517}, {-2.7783236856729117`, \
-5.488978596338675}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7547677040877874`, -5.487353190267121}, \
{-2.5705064541132723`, -5.474638824984638}, {-2.3415417079303174`, \
-5.458804775345399}, {-2.114438157654785, -5.443064090782802}, \
{-1.889195803286676, -5.427416771296845}, {-1.8125269573127714`, \
-5.422364316025436}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.788966068683601, -5.420811660126662}, \
{-1.6656165697901864`, -5.412682963026906}, {-1.4435023821295097`, \
-5.399682812112364}, {-1.222853240304647, -5.388416318553218}, \
{-1.0036691443155994`, -5.378883482349468}, {-0.8457351479791477, \
-5.373083152331141}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8221354906059409, -5.3723223222673395`}, \
{-0.6767075659420784, -5.36783909679681}, {-0.513525086930656, \
-5.363773410969598}, {-0.3505414813694596, -5.360678729775132}, \
{-0.18775674925848906`, -5.358555053213411}, {-0.025170890597744244`, \
-5.357402381284436}, {0.12217709334938334`, -5.357237538579745}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1457889754092813, -5.357262436496845}, {
            0.29940420637306686`, -5.3580100513247215`}, {
            0.4614949109035791, -5.359332458928432}, {
            0.623589674424758, -5.360750002433791}, {
            0.7856884969366025, -5.362262681840796}, {
            0.9477913784391127, -5.363870497149448}, {
            1.0902323928672117`, -5.365366855646985}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1138430581105045`, -5.365617202236406}, {
            1.2720093184161296`, -5.367371535471694}, {
            1.4341243768906362`, -5.369264758485287}, {
            1.5962434943558093`, -5.371253117400528}, {
            1.7582461503798963`, -5.3730942489456925`}, {
            1.9200118245311453`, -5.374545789849059}, {
            2.0582698397898613`, -5.3754547499439935`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.081881326924725, -5.375609160809552}, {
            2.2428322272151315`, -5.376280099730399}, {
            2.403886955747869, -5.376562868708373}, {
            2.564704702407768, -5.376456047044548}, {
            2.7252854671948294`, -5.3759596347389245`}, {
            2.885629250109054, -5.375073631791503}, {
            3.0263520528762893`, -5.373999848482909}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0499633585082835`, -5.373819682757219}, {
            3.059871033984878, -5.373744082382975}, {
            3.2337076153374333`, -5.372108860224494}, {
            3.40713899416672, -5.370167965316058}, {
            3.580165170472738, -5.367921397657668}, {
            3.752988745517122, -5.3655219936243}, {
            3.925812320561506, -5.363122589590933}, {
            3.9943697373955755`, -5.362170769548866}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.017979455083042, -5.361842982950126}, {
            4.09863589560589, -5.360723185557566}, {
            4.266602254660507, -5.357132970321076}, {
            4.444465120946964, -5.353977566590171}, {
            4.6224232344298555`, -5.350870156181566}, {
            4.847757857635602, -5.347248198929244}, {
            4.9623172950033085`, -5.345623571797334}}]}, 
          {Arrowheads[{{0.014208167424509163`, 1.}}], 
           ArrowBox[{{4.985926913989833, -5.345288751476451}, {
            5.072650982103145, -5.34405887223399}, {
            5.087770144081472, -5.3438588056207585`}, {
            5.102887334836447, -5.343660773888913}, {
            5.295545684182794, -5.3414982901339165`}, {
            5.487861148605987, -5.339687857533916}, {
            5.6469120207947245`, -5.338238369213423}, {
            5.656854249492381, -5.338153657536217}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6261705817166885`, 
            5.656854249492381}, {-1.5623285327530831`, 
            5.653146083978946}, {-1.3654962519645402`, 
            5.642630329516407}, {-1.1753926527303578`, 
            5.63358675795777}, {-0.9862498001366231, 
            5.625923989699787}, {-0.7980676941833341, 
            5.619642024742458}, {-0.6825951060080113, 5.61656567596305}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.658991488011361, 
            5.6159368430723955`}, {-0.6097849357052837, 
            5.61462591275103}, {-0.4224912756798396, 
            5.611122701601299}, {-0.23563514990769913`, 
            5.60909846187573}, {-0.049142733745575984`, 5.608390365887517}, {
            0.13705979744981572`, 5.60883558594985}, {0.28542056080810474`, 
            5.6100053138172346`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.30903181994482204`, 5.610191473197728}, {
            0.32315180057023435`, 5.6103028000367825`}, {0.50922820670866, 
            5.612635481593677}, {0.695236201810213, 5.615632996140699}, {
            0.8811229718200172, 5.619094709198015}, {1.0667911582113265`, 
            5.622686922449431}, {1.2521790380348896`, 5.626182388647842}, {
            1.253372205303907, 5.626204032046522}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.2769803146191143`, 5.626632270178145}, {
            1.437287250602067, 5.629540149917043}, {1.622116435224219, 
            5.632719248380828}, {1.7514615517666785`, 5.634841541609208}, {
            1.8808691928927848`, 5.63687932028012}, {2.010211743270957, 
            5.6388133974397565`}, {2.1394032776016165`, 5.640594872490903}, {
            2.2213404355590045`, 5.641560842204941}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.2449507878817827`, 5.6418391882673395`}, {
            2.268680324381735, 5.64211893941027}, {2.397717884579183, 
            5.6433331757399054`}, {2.525076499410841, 5.644223515842474}, {
            2.6504225745373624`, 5.644803947570071}, {2.6753118041825656`, 
            5.6448863740690784`}, {2.700144772879996, 5.644958048088109}, {
            2.724929826696341, 5.645019351148483}, {2.73731141859625, 
            5.645047457556772}, {2.749683636841889, 5.645073089440062}, {
            2.7620475448841466`, 5.64509629427788}, {2.77440419194265, 
            5.645117119005608}, {2.7867546123791187`, 5.645135609976898}, {
            2.9504676597381465`, 5.6451989243515746`}, {3.1154539535144874`, 
            5.644960850768225}, {3.1894177347097608`, 5.644735265764894}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.213029617887624, 5.644663250967121}, {
            3.281545695513516, 5.644454281126077}, {3.4485750875406076`, 
            5.643712107324357}, {3.6139919104451055`, 5.6427318808146065`}, {
            3.775245945076352, 5.641511153048368}, {3.94316447955368, 
            5.6399433332225355`}, {4.10622578316494, 5.638159005636286}, {
            4.157479057303208, 5.637542581009933}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.181089342755732, 5.637258619416594}, {
            4.300925364158667, 5.635817348084002}, {4.497769684240274, 
            5.633370847951588}, {4.511165171754853, 5.633204522888802}, {
            4.52459225265028, 5.6330382511096655`}, {4.708790214235558, 
            5.630961462665957}, {4.8947447945226585`, 5.629154767213388}, {
            5.091504881055733, 5.627909624158604}, {5.125518026582742, 
            5.627694381155459}}]}, 
          {Arrowheads[{{0.010751539872707768`, 1.}}], 
           ArrowBox[{{5.149129546806153, 5.62754496202815}, {
            5.288264967588807, 5.62666448110382}, {5.479390358358244, 
            5.625799304271432}, {5.6022633925459315`, 5.625750594099958}, {
            5.617489842670879, 5.625744557926102}, {5.635791991327913, 
            5.625598553883228}, {5.656854249492381, 
            5.6254493651111845`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            2.9680577375090733`}, {-5.537900620786775, 
            2.9679394186196726`}, {-5.390791521436865, 
            2.967381209716819}, {-5.241631097275321, 
            2.9662958450119956`}, {-5.092429913608952, 
            2.9645720937000606`}, {-4.9433831230886005`, 
            2.9621141523595895`}, {-4.794685878365107, 
            2.958826217569157}, {-4.71247972304672, 2.956477084017111}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.688877364866603, 
            2.955802620027236}, {-4.64645461348257, 
            2.9545903420869726`}, {-4.498805762485089, 
            2.949288578671245}, {-4.351739325372664, 
            2.942920927321974}, {-4.205255302145295, 
            2.9354873880391597`}, {-4.059353692802979, 
            2.926987960822802}, {-3.91403449734572, 
            2.9174226456729015`}, {-3.769297715773516, 
            2.906791442589458}, {-3.7458651534853757`, 
            2.9048900585506447`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7223305112545786`, 
            2.9029803914580508`}, {-3.625143348086367, 
            2.895094351572471}, {-3.459994993102521, 
            2.880309000855316}, {-3.2961920734136343`, 
            2.8641463723548912`}, {-3.133734589019707, 
            2.846606466071198}, {-2.9726225399207387`, 
            2.8276892820042354`}, {-2.813020948364825, 
            2.8075101738183554`}, {-2.7832182112605923`, 
            2.8034857374095288`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7598185965646587`, 
            2.8003259517493904`}, {-2.655094836600062, 
            2.78618449517791}, {-2.498844204626449, 
            2.763712246082899}, {-2.3442690524439866`, 
            2.740093426533322}, {-2.1914449950159436`, 
            2.715814444518382}, {-2.040447647305589, 
            2.691361708027282}, {-1.8912770093129236`, 
            2.666735217060021}, {-1.826505061609182, 
            2.6558331037547256`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8032205903492997`, 
            2.6519139697325373`}, {-1.7439330810379468`, 
            2.641934971616601}, {-1.5280508422518895`, 
            2.6057268343249236`}, {-1.316086702670539, 
            2.5711503858326705`}, {-1.1076359775731732`, 
            2.5394814445738136`}, {-0.9022939822390713, 
            2.511995828982325}, {-0.8698116206266996, 2.5084172757153573`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8463416284648215, 
            2.5058316072800118`}, {-0.6983778035535017, 
            2.4895305625669395`}, {-0.49420452840173384`, 
            2.4729226688363917`}, {-0.2880469010970844, 
            2.4615952328648927`}, {-0.07817766595286887, 2.454971339726655}, {
            0.09612170155322158, 2.451665461615768}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.11972944867283128`, 2.4512177013308816`}, {
            0.13645610527039, 2.4509004524004614`}, {0.35690734081217074`, 
            2.447232033865096}, {0.5825644157142534, 2.441488120003897}, {
            0.8128157050184173, 2.431190746700202}, {0.9526793363626976, 
            2.4225206872825287`}, {1.063270081304265, 2.413921059866232}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.0868110085691083`, 2.4120904979722986`}, {
            1.0929296261814803`, 2.411614709227074}, {1.2335665744747655`, 
            2.398472812533838}, {1.374590181242553, 2.38309499720282}, {
            1.5526269412234945`, 2.361443165095575}, {1.7295686959217236`, 
            2.338209091650943}, {1.9054154453372398`, 2.3133927768689238`}, {
            2.023906132109581, 2.2954931956091826`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.047253236296984, 2.291966307547634}, {
            2.0801671894700426`, 2.2869942207495177`}, {2.2541221058107315`, 
            2.260163261153105}, {2.427578371849904, 2.234049735940066}, {
            2.6005359875875618`, 2.2086536451104006`}, {2.7729949530237032`, 
            2.1839749886641093`}, {2.9002306745457167`, 
            2.1664793452140008`}, {2.981850521147467, 2.1558540901627494`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.005264948090616, 2.1528060048194413`}, {
            3.0275325105390154`, 2.1499072180630985`}, {3.196478809217161, 
            2.129279148895742}, {3.365992402722901, 2.1100916322490906`}, {
            3.536073291056235, 2.0923446681231446`}, {3.7067214742171624`, 
            2.076038256517904}, {3.72951715171924, 2.0739596704895957`}, {
            3.752324105147531, 2.071910531517031}, {3.903109130310809, 
            2.059803208447987}, {3.944737052440938, 2.056773076021401}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.968286738739913, 2.0550588740041253`}, {
            4.054412454609748, 2.0487897087163573`}, {4.246228194578173, 
            2.0355382371489372`}, {4.4388654843557775`, 
            2.0236488880839416`}, {4.632324323942562, 2.01312166152137}, {
            4.826604713338527, 2.0039565574612235`}, {4.911141183621914, 
            2.000481481005225}}]}, 
          {Arrowheads[{{0.01529940275889379, 1.}}], 
           ArrowBox[{{4.934733251856462, 1.999511671873198}, {5.0215912667607,
             1.9959411627000967`}, {5.21716859842611, 1.9888630640345852`}, {
            5.413336708334756, 1.982722261464689}, {5.61009559648664, 
            1.9775187549904083`}, {5.656854249492381, 
            1.9764815248963117`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.7577127650736306`, 0.49673197998424057`}, {
            1.8999919421946265`, 0.4214792743053581}, {1.9121268306242032`, 
            0.41631480238387}, {1.9243788977881833`, 0.41127713514019093`}, {
            1.978963247769119, 0.3925801896452308}, {2.0360423633602465`, 
            0.3757313620839135}, {2.155809549875576, 0.34549494135570674`}, {
            2.286908953902008, 0.32153961904545214`}, {2.4291137681470873`, 
            0.302588693874438}, {2.595864204926353, 0.2866247280812693}, {
            2.667795742006976, 0.28157953897261456`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.6913498694525737`, 0.2799274815847792}, {
            2.773645434564275, 0.274155372359214}, {2.961164524139596, 
            0.26414465222487915`}, {3.1571500986218646`, 
            0.2561880590264252}, {3.3604255325452987`, 
            0.24977476343034916`}, {3.5699197289541886`, 
            0.24460334833726083`}, {3.6350214158381324`, 
            0.24332399799280513`}}]}, 
          {Arrowheads[{{0.01999999999999999, 1.}}], 
           ArrowBox[{{3.6586288508669558`, 0.24286007483533484`}, {
            3.784666029792575, 0.24038324641520237`}, {4.003854980159286, 
            0.23693944621670474`}, {4.2038348607855465`, 
            0.23439093189425417`}, {4.406480274664259, 
            0.23230001258019117`}, {4.603023074746668, 
            0.23063123729841062`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.62663436871719, 0.2304501060324932}, {
            4.817789972514166, 0.2290681583543014}, {5.025699377605151, 
            0.2277895142796949}, {5.234898264446576, 0.2267351561157359}, {
            5.4450927600098415`, 0.2258625475484215}, {5.571099931407548, 
            0.22542435543475778`}}]}, 
          {Arrowheads[{{0.0012975944078844042`, 1.}}], 
           ArrowBox[{{5.5947117816354055`, 0.22534224481800408`}, {
            5.65598899126635, 0.22512915226374897`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.0079662100114303, 1.}}], 
           ArrowBox[{{1.2465475373954231`, 0.23451346588845512`}, {
            1.1969844215276775`, 0.19337482154848873`}, {1.1831382636584906`, 
            0.18380448669024405`}, {1.1681704329125082`, 
            0.17434909675843036`}, {1.1506116751629523`, 
            0.16510299431074194`}, {1.1313412020538707`, 
            0.1558608639736281}, {1.088674447334063, 0.13732422242643816`}, {
            1.038389697248501, 0.11910469206653297`}, {0.9909837589584973, 
            0.10414131909640267`}, {0.9588017448862555, 
            0.09495236942351498}, {0.9409274428966194, 0.09019726195034565}, {
            0.9308336826879344, 0.08760761614452484}, {0.9239348402749168, 
            0.08586634556801093}, {0.9191469418242394, 0.08467099911090714}, {
            0.9120236421935589, 0.0829129330971012}, {0.9076078819553174, 
            0.08183564422159398}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.005497814140738653, 1.}}], 
           ArrowBox[{{1.2543222313111086`, -0.28709111923755}, {
            1.2118505455264483`, -0.23683740546451082`}, {
            1.2004930651121308`, -0.22607289311821718`}, {
            1.1880202280810217`, -0.2153649698212542}, {
            1.1745471482101313`, -0.2057533689721752}, {
            1.1599834677686707`, -0.19619878143900965`}, {
            1.1283107963327643`, -0.17716417140176977`}, {
            1.0908129473680797`, -0.1581690560556317}, {
            1.0459284547119014`, -0.13904355247366276`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            1.76182679283215}, {-5.581802186393281, 
            1.7617870994063092`}, {-5.3859346810288535`, 
            1.761033147554613}, {-5.19012744784314, 
            1.7594543240292349`}, {-4.982819058783855, 
            1.7565417107629449`}, {-4.776127092975173, 
            1.7521140203249694`}, {-4.712476695619203, 
            1.750278482176902}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688874514597044, 
            1.7495978469343365`}, {-4.570051550417092, 
            1.746171252715309}, {-4.364592431109612, 
            1.7387134079339635`}, {-4.33728301794071, 
            1.737619787139153}, {-4.3099908436742895`, 
            1.7364927368121144`}, {-4.142736358054244, 
            1.7280144498405792`}, {-3.9761615764927183`, 
            1.7181090784402797`}, {-3.768656374882312, 
            1.7043394214326837`}, {-3.7456639272697645`, 
            1.7024943301885267`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7221275960523634`, 
            1.7006055935311424`}, {-3.562183024422319, 
            1.6877704080981655`}, {-3.356741525112739, 
            1.6684020384367244`}, {-3.1523318769535726`, 
            1.6462343124483612`}, {-2.9487847286077815`, 
            1.6206188950271967`}, {-2.7836389865006894`, 
            1.5964304715059472`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7602762596101185`, 
            1.5930085998583332`}, {-2.7459307287383306`, 
            1.5909074510673522`}, {-2.5437698773452184`, 
            1.5570999805688277`}, {-2.3423021744284456`, 
            1.5191964835316234`}, {-2.2073015872306967`, 
            1.490920108818532}, {-2.072227040198864, 
            1.4597104127593392`}, {-1.9370785333329468`, 
            1.4255673953540446`}, {-1.8367295042481278`, 
            1.3980529246708795`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8139579707066795`, 
            1.3918092499911046`}, {-1.801856066632946, 
            1.3884910566026487`}, {-1.5801061525677933`, 
            1.31952875942248}, {-1.3557761273650302`, 
            1.2382846146425197`}, {-1.1956495862982779`, 
            1.1726682544431735`}, {-1.030790822607171, 
            1.098023774837622}, {-0.9348144660964062, 1.0505014970874305`}}]}, 
          {Arrowheads[{{0.011211446363170943`, 1.}}], 
           ArrowBox[{{-0.9136543301182264, 
            1.0400241472927017`}, {-0.8371297720763254, 
            1.0021333434094557`}, {-0.6891710438062552, 
            0.9282028460800987}, {-0.6485176002221841, 
            0.9087603903778948}, {-0.6054111548407679, 
            0.8889149227016621}, {-0.561694598413751, 
            0.8695151627679686}, {-0.5123544173079908, 
            0.848187709770835}, {-0.5032573026902777, 
            0.8443143312593712}, {-0.49607893521470936`, 
            0.8412529602998012}, {-0.49086077823740243`, 
            0.8390177258656805}, {-0.48492318644182547`, 
            0.8364643265613076}, {-0.47987539748661084`, 
            0.8342835136241603}, {-0.46977921721618393`, 
            0.8299066174828997}, {-0.4629473833789586, 
            0.8269367037752509}, {-0.4568703900660728, 
            0.8242892457565866}, {-0.4456485691200619, 
            0.8193876414194625}, {-0.43901345180496687`, 
            0.8164793307594125}, {-0.43475117431346316`, 
            0.8146070852343086}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            0.3429233473206922}, {-5.460679344666343, 
            0.3427690665419659}, {-5.431686763522379, 
            0.34273266338218805`}, {-5.40269841826247, 
            0.3426921162780327}, {-5.200502491892003, 
            0.34214661455735135`}, {-4.998663160124363, 
            0.3413243687483502}, {-4.87011350268417, 
            0.34071171536185785`}, {-4.741712267998219, 
            0.3399217217819998}, {-4.712381776493987, 
            0.33970049953673315`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688770455084178, 
            0.3395224135494855}, {-4.6134594560665105`, 
            0.33895438800877603`}, {-4.485355066889044, 
            0.3378097140421865}, {-4.35739910046582, 
            0.33648769988223126`}, {-4.229591556796837, 
            0.33498834552891027`}, {-4.101932435882096, 
            0.3333116509822235}, {-3.974421737721598, 
            0.331457616242171}, {-3.8467723615921567`, 
            0.32933246439163855`}, {-3.7443751435898123`, 
            0.3273416507090504}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.7207676119230837`, 
            0.3268826714714194}, {-3.7186972067705875`, 
            0.3268424185135119}, {-3.5901962732568897`, 
            0.32398747860779115`}, {-3.4612695610510644`, 
            0.32076764467447616`}, {-3.331917070153111, 
            0.317182916713567}, {-3.20213880056303, 
            0.3132332947250637}, {-3.0719347522808205`, 
            0.3089187787089663}, {-2.9413049253064827`, 
            0.3042393686652746}, {-2.8096433546051722`, 
            0.29906147558556867`}, {-2.776758191495476, 
            0.29762814712694147`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7531685947757434`, 
            0.29659997402063376`}, {-2.676344075142044, 
            0.2932515104614283}, {-2.5408608195560616`, 
            0.2867003793414317}, {-2.402647320486191, 
            0.2792989882741573}, {-2.2609142084658274`, 
            0.2708986296993342}, {-2.1142406184550864`, 
            0.2612316300084754}, {-1.9924533815313608`, 
            0.2524982840026641}, {-1.8650818439234, 
            0.2426025289365651}, {-1.810572916042526, 
            0.23803215252205814`}}]}, 
          {Arrowheads[{{0.00421417877154381, 1.}}], 
           ArrowBox[{{-1.7870434866723375`, 
            0.23605929498805317`}, {-1.7309306452640543`, 
            0.2313544362264966}, {-1.588804425186176, 
            0.21856407728877703`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -0.3429844633262989}, \
{-5.468333520938055, -0.3428423927624183}, {-5.439339217417055, \
-0.3428070557037541}, {-5.4103490684448134`, -0.3427676066057647}, \
{-5.207908407513919, -0.34223068764477466`}, {-5.005822598018904, \
-0.341417981072502}, {-4.877190531772433, -0.34081199228000486`}, \
{-4.748707783368345, -0.34002923764450393`}, {-4.712381804781997, \
-0.3397576363929613}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-4.688770471737519, -0.33958109971439043`}, \
{-4.620374352806638, -0.3390697171659993}, {-4.492190240087313, \
-0.3379334308444909}, {-4.36415544521037, -0.3366203786799788}, \
{-4.236269968175809, -0.3351305606724629}, {-4.10853380898363, \
-0.33346397682194323`}, {-3.9809469676338325`, -0.33162062712841983`}, \
{-3.853225548842016, -0.32950712800177673`}, {-3.744375118256316, \
-0.3274029743858002}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.7207677828122714`, -0.3269346901267913}, \
{-3.596527293079126, -0.32418953067878326`}, {-3.467550456108052, \
-0.32098543248243294`}, {-3.3381551464105588`, -0.31741780126284685`}, \
{-3.2083413639866456`, -0.31348663702002505`}, {-3.0781091088363133`, \
-0.3091919397539675}, {-2.947458380959562, -0.3045337094646743}, \
{-2.81578850428958, -0.2993792857845907}, {-2.7767582456689444`, \
-0.29768581050851395`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7531684471443194`, -0.2966622779473445}, \
{-2.6824988027595555`, -0.29359600834616223`}, {-2.5470482974882893`, \
-0.2870756946723538}, {-2.4088960095945784`, -0.2797101622861302}, \
{-2.2672616444730878`, -0.2713521011318058}, {-2.1207406718342123`, \
-0.26173635310914606`}, {-1.998627297137852, -0.25301399331962565`}, \
{-1.8709469997445516`, -0.24312745258402982`}, {-1.8105738438480017`, \
-0.23807937195363876`}}]}, 
          {Arrowheads[{{0.0010738857526330478`, 1.}}], 
           ArrowBox[{{-1.787043961119242, -0.236111928915843}, \
{-1.7365071494721587`, -0.23188631082103112`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, -1.0000294034236679`}, \
{-5.465958664868487, -0.9997648178342348}, {-5.437250067640607, \
-0.9996872695340837}, {-5.4085480546495415`, -0.9995981056526981}, \
{-5.206283246765347, -0.9982252809353738}, {-5.004492132091208, \
-0.9960791702206541}, {-4.790812506438952, -0.9931844030506859}, \
{-4.712425380066083, -0.9916638733872546}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-4.688817828064488, -0.9912059412654841}, \
{-4.577782057815465, -0.9890521031267764}, {-4.365400786220748, \
-0.9836822704489255}, {-4.153668691654799, -0.9770749050171335}, \
{-3.942372475148983, -0.9688277255742404}, {-3.744925286683211, \
-0.9592027037668913}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.721346480118926, -0.9579563992248196}, \
{-3.520447779411844, -0.9462070808836718}, {-3.3098193001805205`, \
-0.9318336156359964}, {-3.148884596412832, -0.91907590600167}, \
{-2.9870314293916396`, -0.904272990878167}, {-2.824259799116944, \
-0.8874248702654878}, {-2.780043478751247, -0.8823213643557101}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.756587211955071, -0.8796140111606559}, \
{-2.660569705588744, -0.868531544163632}, {-2.537492504642166, \
-0.8526962755026989}, {-2.4126406765614075`, -0.8348406078985702}, \
{-2.286014221346467, -0.8149645413512461}, {-2.157613138997347, \
-0.7930680758607265}, {-1.955906646400593, -0.7543492475750723}, \
{-1.8252282023748356`, -0.7256619235915254}}]}, 
          {Arrowheads[{{0.012972044931321395`, 1.}}], 
           ArrowBox[{{-1.8021653887516813`, -0.7205990349773238}, \
{-1.7447085942893483`, -0.7079857712513482}, {-1.5998374076864261`, \
-0.6727030281141038}, {-1.4462554734538517`, -0.6321671390879803}, \
{-1.2096265311162981`, -0.5655787636557476}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            0.9997273144154485}, {-5.458255183096332, 
            0.9994336074891882}, {-5.429548597515654, 
            0.9993530157331736}, {-5.400848674983862, 
            0.9992607239685257}, {-5.198829858896242, 
            0.9978634546687941}, {-4.9972864537424435`, 
            0.9956906192854315}, {-4.783693564975746, 
            0.9927635326120847}, {-4.712425263843086, 
            0.9913683197201587}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688817794255453, 
            0.9909061584873112}, {-4.570749761979473, 
            0.9885947516186507}, {-4.358455044753624, 
            0.9831842763051293}, {-4.1468094132982, 
            0.9765321066715204}, {-3.9355952086777624`, 
            0.9682345784984112}, {-3.744926161266092, 
            0.9588849911664449}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-3.7213442126396115`, 
            0.9576968743602629}, {-3.5138081031355286`, 
            0.9454924538754538}, {-3.303235202213733, 
            0.9310478574256056}, {-3.1427646242374627`, 
            0.9182661552942932}, {-2.9813670619208223`, 
            0.9034418709256636}, {-2.8190425152638108`, 
            0.8865750043197168}, {-2.7800402010106695`, 
            0.8820573605240791}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7565850283693383`, 
            0.8793405444277064}, {-2.655790984266429, 
            0.8676655554764527}, {-2.532955333866675, 
            0.8518101346978719}, {-2.408338668716762, 
            0.833935184597496}, {-2.28194098881669, 
            0.8140407051753252}, {-2.153762294166459, 
            0.7921266964313594}, {-1.9526487060114424`, 
            0.7534392466975955}, {-1.8252210784048235`, 
            0.7254195764253294}}]}, 
          {Arrowheads[{{0.004454551944054401, 1.}}], 
           ArrowBox[{{-1.8021600090760437`, 
            0.7203487486083583}, {-1.7420462121398739`, 
            0.7071305101415382}, {-1.5974704113007354`, 
            0.6718773019327381}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.7753052586586193`, -0.48671792094081234`}, {
            1.9256807024794291`, -0.4118650562743317}, {
            1.9380732780262042`, -0.4069555979586599}, {
            1.9505874475821208`, -0.4021663146085092}, {
            2.007641717516292, -0.3840411783657249}, {
            2.06735290912148, -0.36774176629545885`}, {
            2.1928474694875026`, -0.3386553489658713}, {
            2.3302952769248426`, -0.3158125300757575}, {
            2.4790962255838473`, -0.2978047789536775}, {
            2.66100130859448, -0.28214089439538564`}, {
            2.6883447704071393`, -0.2804395953839267}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.71191119139023, -0.2789733023082052}, {
            2.8548902004821097`, -0.2700772068359495}, {
            3.059184442607729, -0.2604857595614404}, {
            3.2724055402532617`, -0.2529498846329599}, {
            3.493190312592236, -0.24693181576046647`}, {
            3.6556379411642927`, -0.2434965857237611}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{3.6792446564960404`, -0.24299738177545846`}, {
            3.7203408746502493`, -0.24212833269028997`}, {
            3.952778478408784, -0.2382432204240955}, {
            4.189626160731242, -0.2351045422370689}, {
            4.401363011183024, -0.23284318115102537`}, {
            4.6155890604453305`, -0.23100369056165362`}, {
            4.623641755208768, -0.23094721742573596`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.64725316759212, -0.23078163180006597`}, {
            4.831800197444658, -0.22948741293219266`}, {
            5.049492311107506, -0.22819569072588153`}, {
            5.267692805657298, -0.22709866805226062`}, {
            5.485161379772844, -0.22620580424732822`}, {
            5.591719319702273, -0.22584619091818867`}}]}, 
          {Arrowheads[{{0.0008792842628268401, 1.}}], 
           ArrowBox[{{5.615331178238458, -0.22576650526490938`}, {
            5.656854249492381, -0.2256263725831063}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-5.516267442448932, -2.4284388025599157`}, \
{-5.375751238948935, -2.4276439293465666`}, {-5.23542282460658, \
-2.4261575117330447`}, {-5.095282199421865, -2.42397954971935}, \
{-4.955329363394792, -2.4211100433054824`}, {-4.815564316525361, \
-2.417548992491442}, {-4.675987058813569, -2.4132963972772288`}, \
{-4.572019687971175, -2.4096086782399344`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.548422534314325, -2.408771688018279}, \
{-4.5365975902594196`, -2.4083522576628424`}, {-4.397395910862912, \
-2.402716573648284}, {-4.25860752686448, -2.3962055043035004`}, \
{-4.120457944504558, -2.38863520869844}, {-3.9829471637831473`, \
-2.3800056868331034`}, {-3.846075184700248, -2.3703169387074907`}, \
{-3.709842007255858, -2.359568964321601}, {-3.6058540071949925`, \
-2.3505139635207573`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.582331026893823, -2.348465644432587}, \
{-3.5742476314499805`, -2.347761763675435}, {-3.4392920572826133`, \
-2.3348953367689926`}, {-3.304975284753757, -2.3209696836022737`}, \
{-3.1583281788576416`, -2.304327408291144}, {-3.0127140320904355`, \
-2.286151784487944}, {-2.868132844452138, -2.266442812192674}, \
{-2.7245846159427503`, -2.245200491405334}, {-2.645184462790011, \
-2.2325654542051088`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.6218658691075767`, -2.2288547397173457`}, \
{-2.582192276421911, -2.222541435529057}, {-2.4410787557492597`, \
-2.1985822579669776`}, {-2.3012440539247976`, -2.173322958719095}, \
{-2.1626881709485244`, -2.1467635377854095`}, {-2.025569711124279, \
-2.118929337158975}, {-1.8900472787559015`, -2.089845698832846}, \
{-1.7561208738433918`, -2.059512622807022}, {-1.6956628186829728`, \
-2.0450834539825946`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.6726958724450776`, -2.039602067858466}, \
{-1.6237904963867504`, -2.0279301090815034`}, {-1.5449020810943805`, \
-2.008448292495101}, {-1.4665991465298864`, -1.9887843736210746`}, \
{-1.3009825038172373`, -1.946171076643459}, {-1.1388079905076827`, \
-1.9030843284848844`}, {-0.9796847692897149, -1.8606651093703952`}, \
{-0.8232220028518268, -1.8200543995250358`}, {-0.803644465478632, \
-1.8150434932663129`}, {-0.784112713551054, -1.8100813479578641`}, \
{-0.7581746733719208, -1.8037137724659555`}}]}, 
          {Arrowheads[{{0.001364150224392406, 1.}}], 
           ArrowBox[{{-0.7352435576983871, -1.798084372204544}, \
{-0.728115759182763, -1.7963345563038091`}, {-0.6725833227271818, \
-1.7831281681094604`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.328257874466412, 
            2.1821949574248136`}, {-2.1323477214123447`, 
            2.1446216023080154`}, {-1.9393825143502759`, 
            2.1044002554064707`}, {-1.749645834209808, 
            2.061400763486396}, {-1.666998635684499, 
            2.041648821477996}, {-1.584959536272738, 
            2.021613971030483}, {-1.417345232770964, 
            1.9796121558697692`}, {-1.4065838017226215`, 
            1.9768230228898669`}}]}, 
          {Arrowheads[{{0.01332921109253634, 1.}}], 
           ArrowBox[{{-1.3837270181156753`, 
            1.970899032977536}, {-1.2527780591188755`, 
            1.9369598608933445`}, {-1.0912826326763192`, 
            1.8944004896548223`}, {-0.9328835708031411, 
            1.8526774457078163`}, {-0.9129752516461808, 
            1.8474348181756362`}, {-0.8931059932206425, 
            1.8422293792138094`}, {-0.8336298558400463, 
            1.8270328011011612`}, {-0.774581618745538, 
            1.8123018837551028`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.805429801688043, 
            4.2781446290895895`}, {-2.68092640632109, 
            4.265985469833054}, {-2.5571170213059546`, 
            4.253705265693085}, {-2.433978033446467, 
            4.241418538084642}, {-2.2618228607785342`, 
            4.224514128978667}, {-2.090987181297308, 
            4.20840680760675}, {-1.9213486701670672`, 
            4.19327265586802}, {-1.8652724057725723`, 4.187954290432871}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8417658959079852`, 
            4.1857248942540295`}, {-1.7540898007997705`, 
            4.1774095487375735`}, {-1.5874776380227225`, 
            4.163311979786389}, {-1.4218179939252222`, 
            4.150539744266648}, {-1.2571108685072698`, 
            4.139092842178349}, {-1.0933562617688646`, 
            4.128971273521492}, {-0.9301776436766701, 
            4.120280492550601}, {-0.8997369880770748, 4.118944193729979}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8761477133190185, 
            4.1179086601838835`}, {-0.7671984841973468, 
            4.1131259535202025`}, {-0.6044187833308967, 
            4.107507656430294}, {-0.4418385410773193, 
            4.103425601280877}, {-0.19821971089372797`, 4.099280851349234}, {
            0.046702915886282004`, 4.09675765372147}, {0.06803036101724004, 
            4.096644292072993}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.09164202047508503, 4.0965187891530235`}, {
            0.1696531529999437, 4.096104137021544}, {0.29292933926271075`, 
            4.095856008397586}, {0.41653147467458235`, 4.096013267849599}, {
            0.5404595592355578, 4.096575915377581}, {0.6646895577041692, 
            4.0971743272262495`}, {0.7891974348389474, 4.09743887964032}, {
            0.9139831906398923, 4.097369572619793}, {1.0361166352353535`, 
            4.096975852190031}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.0597282554696363`, 4.0968447964183605`}, {
            1.1643883382402804`, 4.096229380274943}, {1.2900077300397244`, 
            4.0951584949506215`}, {1.4159050005053346`, 4.093753750191701}, {
            1.5420801496371122`, 4.092015145998184}, {1.6751749893105614`, 
            4.0896992483723125`}, {1.8082398328119256`, 4.086767660313989}, {
            1.941274680141204, 4.083220381823215}, {2.0040513239516122`, 
            4.081255512008216}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.027651759684481, 4.08051683308278}, {
            2.074279531298397, 4.079057412899988}, {2.2072693843695474`, 
            4.074586598760535}, {2.3402592374406974`, 4.070115784621083}, {
            2.473249090511848, 4.065644970481631}, {2.605414640086875, 
            4.057873178465848}, {2.770514209463292, 4.050250293983379}, {
            2.9356137788397088`, 4.04262740950091}, {2.9712652018345675`, 
            4.040981332045034}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{2.99485206695821, 4.039892292571338}, {
            3.1007133482161255`, 4.035004525018442}, {3.2641890937168636`, 
            4.02470600172812}, {3.4083717323553846`, 4.016795221145927}, {
            3.5524156177214037`, 4.008927478115479}, {3.6949107405972046`, 
            4.0013214857970825`}, {3.837315751502251, 3.993912100207571}, {
            3.9379387516051105`, 3.988812342884412}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.9615204774573085`, 3.9876171779719716`}, {
            3.9796306504365435`, 3.9866993213469444`}, {4.1218554374000815`, 
            3.979683149215203}, {4.140913950880302, 3.9787558419664912`}, {
            4.159971693590173, 3.9778323687386767`}, {4.323100385781881, 
            3.9702461592808618`}, {4.486204715174063, 3.962955711159343}, {
            4.702178507414788, 3.953682410978416}, {4.905063415462625, 
            3.945685826507315}}]}, 
          {Arrowheads[{{0.01542726877591519, 1.}}], 
           ArrowBox[{{4.9286586526231915`, 3.944797663001997}, {
            5.1339551415186095`, 3.9375203703303026`}, {5.349647697437144, 
            3.9308266682305995`}, {5.557258143110527, 3.925112451032942}, {
            5.656854249492381, 3.9226627024490917`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.805199345428574, -4.277430804550784}, \
{-2.68075407628618, -4.265274466992066}, {-2.5570024121486346`, \
-4.252997183460846}, {-2.4339207564331082`, -4.240713369391828}, \
{-2.2617963381272035`, -4.223808061197469}, {-2.090991154566093, \
-4.2076997599918196`}, {-1.9213829787752204`, -4.192564440443383}, \
{-1.865043901449429, -4.187220107938854}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.8415374324328817`, -4.184990281104713}, \
{-1.7541533381753007`, -4.176701014089938}, {-1.587570683960113, \
-4.1626024554019825`}, {-1.42194058356605, -4.149828827708253}, \
{-1.257263036993111, -4.13838013100875}, {-1.0935380442412959`, \
-4.128256365303471}, {-0.9303891167164656, -4.119563172210465}, \
{-0.8995087624544157, -4.118206860930204}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8759195114774981, -4.117170785795788}, \
{-0.7674397658244809, -4.112406193347774}, {-0.6046899915653419, \
-4.1067854287154}, {-0.4421397939390477, -4.102700878313343}, \
{-0.1985865370829684, -4.098552871750305}, {
            0.04627069917274629, -4.096026565168367}, {
            0.06825861907399217, -4.09590939371625}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.0918702768220033, -4.095783569525619}, {
            0.1691883095754667, -4.095371549370312}, {
            0.2924319148280957, -4.095121958567533}, {
            0.41600151493063353`, -4.095277792760028}, {
            0.5398971098830795, -4.095839051947799}, {
            0.6640948165647699, -4.096436257689014}, {
            0.788570751855041, -4.096699931541844}, {
            0.9133249157538923, -4.096630073506286}, {
            1.0363449017721151`, -4.096233176175857}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.059956510813479, -4.096099663834552}, {
            1.1636679293773355`, -4.095489761770012}, {
            1.2892567791019274`, -4.094419308069296}, {
            1.4151238574350997`, -4.093015322480193}, {
            1.5412691643768512`, -4.091277805002704}, {
            1.6744685078988333`, -4.088960519215549}, {
            1.8076378848520487`, -4.086026225248916}, {
            1.9407772952364977`, -4.082474923102805}, {
            2.0042791179453214`, -4.080486369205327}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.027879542211972, -4.0797473240306275`}, {
            2.0738867390521807`, -4.078306612777218}, {
            2.2069811995834803`, -4.073829798361891}, {
            2.3400756601147794`, -4.0693529839465645`}, {
            2.4731701206460786`, -4.064876169531238}, {
            2.60543870994372, -4.05709257102667}, {
            2.7695470641231488`, -4.049510369257656}, {
            2.9336554183025774`, -4.041928167488641}, {
            2.9714915840559897`, -4.040180045375402}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.9950784155080954`, -4.039090276874244}, {
            3.097763772482006, -4.034345965719627}, {
            3.260265610918574, -4.024115059660336}, {
            3.4043151568351617`, -4.016208147188081}, {
            3.5482268963617267`, -4.0083399929144115`}, {
            3.6907418473414673`, -4.000725004404608}, {
            3.833166072261309, -3.993306462570715}, {
            3.938163624681827, -3.9879788178418907`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.961745280361057, -3.986782269154039}, {
            3.9754995711212517`, -3.9860843674127318`}, {
            4.117742343921297, -3.979058718930659}, {
            4.136802971847735, -3.9781301431332956`}, {
            4.155862822856086, -3.977205400066517}, {
            4.318861291682557, -3.969614848986718}, {
            4.481835198864498, -3.9623194719814956`}, {
            4.697247411538412, -3.953052969245333}, {
            4.905287387349439, -3.944830495798853}}]}, 
          {Arrowheads[{{0.0154225183547181, 1.}}], 
           ArrowBox[{{4.928883369134511, -3.9439621659178994`}, {
            5.127925425032827, -3.9368819392117573`}, {
            5.343126193721378, -3.9301764447107947`}, {
            5.5504948083454675`, -3.924445513924053}, {
            5.656854249492381, -3.9218199058707612`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            5.334588510328588}, {-5.566502491562625, 
            5.334377236897617}, {-5.427420872622804, 
            5.333783736503849}, {-5.288751237301512, 
            5.33292291965215}, {-5.150493585598749, 
            5.331794786342517}, {-5.012647917514517, 
            5.330399336574952}, {-4.875214233048812, 
            5.328736570349454}, {-4.738063802767328, 
            5.326654170806306}, {-4.712421059300064, 5.326157332534451}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688813497095527, 
            5.325699926702528}, {-4.601067897235761, 
            5.323999821085793}, {-4.464226516454106, 
            5.320773521187913}, {-4.327539660422366, 
            5.316975271112668}, {-4.1910073291405405`, 
            5.312605070860055}, {-4.0546295226086295`, 
            5.307662920430077}, {-3.918406240826634, 
            5.302148819822732}, {-3.782337483794553, 
            5.296062769038022}, {-3.744892156595687, 5.294245272000567}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.721307927997137, 
            5.29310055598885}, {-3.6466110268236718`, 
            5.289474966182442}, {-3.511414645225277, 
            5.28245560936249}, {-3.3767483389993687`, 
            5.275004698578167}, {-3.2426121081459462`, 
            5.267122233829473}, {-3.1090059526650102`, 
            5.258808215116406}, {-2.97592987255656, 
            5.2500626424389685`}, {-2.8433838678205965`, 
            5.240885515797158}, {-2.7785698819989677`, 
            5.236168078351721}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-2.7550201844247604`, 
            5.234454031240484}, {-2.711367938457121, 
            5.231276835190978}, {-2.5005137814057297`, 
            5.215577270424165}, {-2.2914229489477904`, 
            5.200056192800811}, {-2.0840954410833032`, 
            5.184713602320913}, {-1.8785312578122682`, 
            5.169549498984472}, {-1.8131005839382102`, 
            5.1649676056262965`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7895462723872921`, 
            5.163318175209925}, {-1.6744525247955655`, 
            5.155258541303766}, {-1.4715813676940752`, 
            5.142535387791071}, {-1.2699177865077975`, 
            5.131380038446387}, {-1.0694617812367326`, 
            5.121792493269713}, {-0.8698394241107239, 
            5.113851253936922}, {-0.846453713845665, 5.113121319469124}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.822853214341733, 
            5.112384680818857}, {-0.6706767873596153, 
            5.107634822123883}, {-0.4719738709834068, 
            5.103143197830596}, {-0.27373067498209824`, 
            5.100376381057061}, {-0.12641825541341958`, 5.099205550995677}, {
            0.02095924731983345, 5.098526018653828}, {0.12147602772611445`, 
            5.0983976925119565`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.14508800148186046`, 5.098367547958163}, {
            0.1684018332176599, 5.098337784031515}, {0.3159095022800599, 
            5.0986408471287366`}, {0.4634822545070333, 5.099435207945494}, {
            0.6111200898985792, 5.100720866481787}, {0.7588230084546987, 
            5.1024978227376145`}, {0.9065910101753918, 5.104766076712979}, {
            1.0895102979250693`, 5.10755507729385}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1131195467901305`, 5.1079150514092575`}, {
            1.1270955106802862`, 5.108128145238166}, {1.3474096501295039`, 
            5.110710100136647}, {1.5675334285230431`, 5.112511941408419}, {
            1.7874668458609042`, 5.113533669053485}, {2.007209902143088, 
            5.113775283071844}, {2.0575724812515537`, 5.11365175815179}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0811844032273545`, 5.113593844899015}, {
            2.2267625973695933`, 5.1132367834634955`}, {2.44612493154042, 
            5.1119181702284395`}, {2.6652969046555706`, 5.109819443366677}, {
            2.884096064976714, 5.1071655068231925`}, {3.025620348870783, 
            5.105230319815336}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{3.0492301347499993`, 5.104907482280782}, {
            3.1023399607655224`, 5.104181264542972}, {3.320028592021996, 
            5.100866716526015}, {3.537161958746135, 5.097221862772323}, {
            3.7537400609379388`, 5.0932467032818955`}, {3.9697628985974083`, 
            5.088941238054731}, {3.9935641810684785`, 5.0884291549947065`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.017170711056265, 5.087921262021822}, {
            4.185230471724543, 5.084305467090831}, {4.400142780319341, 
            5.079339390390196}, {4.582855144994554, 5.075108371283874}, {
            4.7653000001203445`, 5.071163280717921}, {4.961424233511398, 
            5.067286814234335}}]}, 
          {Arrowheads[{{0.014227976344979914`, 1.}}], 
           ArrowBox[{{4.98503161561713, 5.066820205779501}, {
            5.002256254791619, 5.0664797545497}, {5.238789457269202, 
            5.062314474655148}, {5.2546900510620045`, 5.062051654025035}, {
            5.270588725508067, 5.061791249551395}, {5.468570821768851, 
            5.058954239122002}, {5.656854249492381, 5.056621052750075}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, -4.847796740102592}, \
{-5.54025445255888, -4.847885594666024}, {-5.400633793870968, \
-4.847703483263112}, {-5.260886113351466, -4.847155017062304}, \
{-5.121046305028505, -4.846187129127026}, {-4.981149262930212, \
-4.844746752520706}, {-4.841306668635496, -4.842734841871164}, \
{-4.712424760504179, -4.84025966154404}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688818457899753, -4.839744427137075}, \
{-4.562119868193516, -4.83669928232588}, {-4.42277566204625, \
-4.832675633430138}, {-4.283597585281469, -4.827981405118995}, \
{-4.144585637899173, -4.822616597392452}, {-4.005739819899359, \
-4.816581210250509}, {-3.867060131282029, -4.809875243693165}, \
{-3.745079514203624, -4.803426767248633}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.721502103242367, -4.802150104994724}, \
{-3.5911697414624006`, -4.794719120653057}, {-3.4542016900769967`, \
-4.786335851250486}, {-3.317885067707865, -4.777415776592906}, \
{-3.182219874355007, -4.767958896680315}, {-3.047206110018423, \
-4.757965211512713}, {-2.9128437746981124`, -4.747434721090101}, \
{-2.7793489980198034`, -4.73638531453266}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.755821275991388, -4.734392203835716}, \
{-2.586081174614762, -4.720009904038724}, {-2.3946513204586903`, \
-4.7038880456250824`}, {-2.204843305925857, -4.688001850171553}, \
{-2.0166571310162635`, -4.672351317678134}, {-1.8299162760469545`, \
-4.657408856804252}, {-1.8145798054483144`, -4.656270894478332}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.791032544414572, -4.6545236935325445`}, \
{-1.6444442213349726`, -4.6436468762093295`}, {-1.4602409668803191`, \
-4.631065375893367}, {-1.2773065126829946`, -4.619664355856363}, \
{-1.095286194401933, -4.609679549876133}, {-0.9138253476960703, \
-4.60134669173049}, {-0.8482494854126796, -4.598924894471243}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8246535783463392, -4.5980534685978665`}, \
{-0.7329239725654073, -4.594665781419434}, {-0.5525820690099428, \
-4.589636818942965}, {-0.42372157758733264`, -4.586885695420012}, \
{-0.29471456562552817`, -4.58464459567755}, {-0.16556103312452913`, \
-4.582913519715579}, {-0.03626098008433565, -4.581692467534097}, {
            0.09318559349505229, -4.580981439133106}, {
            0.11962532319280256`, -4.580940429942993}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.14323728778868663`, -4.580903806741617}, {
            0.22277868761363462`, -4.580780434512605}, {
            0.35251830227141157`, -4.581089453672595}, {
            0.48240443746838346`, -4.581908496613075}, {
            0.6591753253732249, -4.583153453529944}, {
            0.8361908324143579, -4.583968485230479}, {
            1.0134509585917826`, -4.584353591714684}, {
            1.0877072807256307`, -4.5843348425020665`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.1113192729709351`, -4.584328880635788}, {
            1.1909557039054999`, -4.584308772982556}, {
            1.3687050683555082`, -4.583834029034096}, {
            1.546699051941809, -4.582929359869304}, {
            1.7249376546644015`, -4.58159476548818}, {
            1.9034208765232854`, -4.579830245890725}, {
            2.055770116454363, -4.57790039612458}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.0793802152916907`, -4.577601320502407}, {
            2.0818965777418446`, -4.577569445046461}, {
            2.260112618543462, -4.574746006924912}, {
            2.438068998928138, -4.571359931526079}, {
            2.615765718895872, -4.567411218849961}, {
            2.793202778446664, -4.562899868896558}, {
            2.9703801775805143`, -4.557825881665871}, {
            3.023604302781764, -4.5561301534099}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.047204320997497, -4.555378253447646}, {
            3.147297916297422, -4.552189257157899}, {
            3.3239559945973887`, -4.545989995372643}, {
            3.470187863124243, -4.540534956140119}, {
            3.616248231784011, -4.534926622540975}, {
            3.7479878300994134`, -4.5298309334993965`}, {
            3.8795981048578723`, -4.524797755886039}, {
            3.9910408382618976`, -4.520584638917772}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.0146360343526934`, -4.519694177758782}, {
            4.1424306837039575`, -4.514918934943981}, {
            4.160048738636474, -4.51426447945657}, {
            4.1776648095544875`, -4.513612797487696}, {
            4.341236878849189, -4.507827567736034}, {
            4.504667077245217, -4.502297616300419}, {
            4.726571533536334, -4.495032184921509}, {
            4.948258350963945, -4.488260318887523}, {
            4.9585801480739, -4.487969368670547}}]}, 
          {Arrowheads[{{0.01429105049027691, 1.}}], 
           ArrowBox[{{4.982182766084872, -4.487304059445967}, {
            5.169716036438878, -4.482017882521693}, {
            5.390933096871961, -4.476340740147251}, {
            5.498175565626508, -4.473911873959115}, {
            5.60028245708503, -4.471751667929087}, {
            5.656854249492381, -4.47062532339398}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-5.656854249492381, 
            4.848323351313337}, {-5.539728563578836, 
            4.848411774453421}, {-5.400046151362289, 
            4.848227983527988}, {-5.260236598451636, 
            4.847677417792239}, {-5.1203348407889795`, 
            4.846706935050809}, {-4.9803758143164245`, 
            4.845263393108333}, {-4.840471539058731, 
            4.843247771831743}, {-4.71242476263808, 4.840785827682965}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-4.688818378193893, 
            4.840274381865922}, {-4.561163302262209, 
            4.837203230877025}, {-4.421759340723382, 
            4.833174311198897}, {-4.2825221504241755`, 
            4.828474292053589}, {-4.14345173136459, 
            4.823103173441103}, {-4.004548083544627, 
            4.817060955361437}, {-3.8658112069642843`, 
            4.810347637814591}, {-3.7450792775801887`, 
            4.8039610347247175`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{-3.7215016135115953`, 
            4.802688964812966}, {-3.589808533940321, 
            4.795175823135624}, {-3.452785429101163, 
            4.786784355707569}, {-3.3164144787105547`, 
            4.777855848220466}, {-3.180695682768496, 
            4.768390300674315}, {-3.045629041274987, 
            4.758387713069116}, {-2.9112145542300265`, 
            4.747848085404869}, {-2.7793481997155043`, 
            4.736928420918705}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7558202641662093`, 
            4.734937866514648}, {-2.584401256631065, 
            4.720408181821388}, {-2.3929721362094893`, 
            4.704284020273597}, {-2.203164860368889, 
            4.688398933038204}, {-2.0149794291092658`, 
            4.672752920115207}, {-1.828238482692215, 
            4.6578178761289}, {-1.8145797188968624`, 4.656805130595481}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.791032364853999, 
            4.655059183598518}, {-1.642764661379332, 
            4.644065695703573}, {-1.4585579651706189`, 
            4.631496378839229}, {-1.2756183940660721`, 
            4.620109925535866}, {-1.0935910769050234`, 
            4.61014069647612}, {-0.9121211425268029, 
            4.601823052342624}, {-0.8482486523590952, 4.59946955172911}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8246526719529129, 
            4.598600113975602}, {-0.7312085909314083, 
            4.5951569931353795`}, {-0.5508534221188408, 
            4.590142518854386}, {-0.42196547400988216`, 
            4.587400843651327}, {-0.292930704181572, 
            4.585168417606292}, {-0.16374911263390984`, 
            4.58344524071928}, {-0.03442069936689529, 4.5822313129902925`}, {
            0.09505453561947075, 4.581526634419329}, {0.11962633734917007`, 
            4.581489587847866}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.14323830351075864`, 4.581453988407442}, {
            0.22467659232518866`, 4.581331205006389}, {0.3544454707502591, 
            4.581645024751473}, {0.48436117089468067`, 4.58246809365458}, {
            0.6612592256537724, 4.583717540718137}, {0.8384008088262138, 
            4.584534703217762}, {1.0157859204120059`, 4.584919581153455}, {
            1.0877082268832272`, 4.584900386084209}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.1113202190402764`, 4.584894084369947}, {
            1.1934145604111484`, 4.584872174525217}, {1.37128672882364, 
            4.584392483333047}, {1.5494024256494827`, 4.583480507576945}, {
            1.7277616508886755`, 4.58213624725691}, {1.906364404541218, 
            4.580359702372944}, {2.055770947090066, 4.578457675614715}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.0793810269606925`, 4.578157106423355}, {
            2.084958782771883, 4.578086098550321}, {2.263292881745443, 
            4.575250661414314}, {2.4413667014618983`, 4.571853390964924}, {
            2.6191802419212475`, 4.567894287202151}, {2.796733503123492, 
            4.563373350125994}, {2.974026485068631, 4.558290579736455}, {
            3.0236056952177157`, 4.556709770151863}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0472056951121638`, 4.55595729535613}, {
            3.151059187756665, 4.552645976033532}, {3.327831611187594, 
            4.546439539017227}, {3.474194305763928, 4.540977766702279}, {
            3.620385508611777, 4.535363139263957}, {3.7521086459312216`, 
            4.530268094367506}, {3.8837025894602815`, 4.525237328497472}, {
            3.9910428708038204`, 4.521182217936332}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{4.014638032487446, 4.520290837849215}, {
            4.015167339198956, 4.520270841653853}, {4.146502895147246, 
            4.515368633836651}, {4.164118998974106, 4.514715087694337}, {
            4.181733124984249, 4.514064317375972}, {4.345433994937941, 
            4.508282778386896}, {4.508993057888045, 4.502757098994598}, {
            4.731478768303324, 4.495485165892284}, {4.953745906034622, 
            4.488709665352345}, {4.958582437451648, 4.488573721810367}}]}, 
          {Arrowheads[{{0.01429099362321073, 1.}}], 
           ArrowBox[{{4.982185108761966, 4.4879103061388035`}, {
            5.175750202076346, 4.482469645855737}, {5.397447387422901, 
            4.476804155883419}, {5.504694837120452, 4.474386309635053}, {
            5.6067221001573495`, 4.472237672715991}, {5.656854249492381, 
            4.471244216252182}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3064481891657578`, -2.162405321769212}, {
            1.4475687987417285`, -2.1417393889187024`}, {
            1.5881615208184994`, -2.1188338053208207`}, {
            1.7280302464383988`, -2.094631219266402}, {
            1.8669788666437568`, -2.0700742790462816`}, {
            2.005007381434574, -2.0451629846604593`}, {
            2.14211579081085, -2.019897336108935}, {
            2.2372391320124865`, -2.0026015667279453`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.260470234944066, -1.9983775792849587`}, {
            2.3079001034441293`, -1.98975365946691}, {
            2.473408325031422, -1.9611094483554936`}, {
            2.6386404555727268`, -1.9339647027746858`}, {
            2.803596495068045, -1.9083194227244866`}, {
            2.968765981903912, -1.8843482810917134`}, {
            3.134638454466864, -1.8622259507631833`}, {
            3.193879163182587, -1.8550158992496568`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.2173181958455737`, -1.8521631880550908`}, {
            3.3012139127569013`, -1.8419524317388962`}, {
            3.468492356774023, -1.823527724018852}, {
            3.6181785509356845`, -1.8086608067654866`}, {
            3.7686009303679677`, -1.795170615021606}, {
            3.9421866648234163`, -1.7811054595028801`}, {
            4.1167487887212335`, -1.7683784556557323`}, {
            4.157708673174756, -1.7657209985524835`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.181271126937814, -1.7641922781725798`}, {
            4.292287302061418, -1.7569896034801626`}, {
            4.46880220484397, -1.7469389029761708`}, {
            4.492466759132184, -1.745684620031955}, {
            4.516147746511204, -1.7444495795645032`}, {
            4.691442410395185, -1.7364765741572}, {
            4.867388982888936, -1.7294522388218845`}, {
            5.084153209932846, -1.7213364490627092`}, {
            5.1246715389139466`, -1.7200216875215126`}}]}, 
          {Arrowheads[{{0.010773747599522786`, 1.}}], 
           ArrowBox[{{5.148271111076932, -1.7192559153228848`}, {
            5.30013142261366, -1.7143282664720219`}, {
            5.515323620931377, -1.7084276910498222`}, {
            5.656854249492381, -1.705263827969435}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.1657668865276334`, 2.1821323090047264`}, {
            1.3075979787343583`, 2.1636973781707005`}, {1.4489008452885999`, 
            2.143021778371916}, {1.5896754861903581`, 2.120105509608373}, {
            1.7297262822958033`, 2.0958929295446316`}, {1.8688576144611062`, 
            2.071328395845252}, {2.007069482686267, 2.0464119085102337`}, {
            2.0977159719575535`, 2.029728571400092}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.120937932437571, 2.0254546078063447`}, {
            2.1443618869712857`, 2.0211434675395767`}, {2.3103915372947004`, 
            1.9909963159600204`}, {2.4761482506060295`, 
            1.9623529694985127`}, {2.641632026905273, 1.9352134281550537`}, {
            2.806842866192432, 1.9095776919296432`}, {2.972270017197045, 
            1.885619408282892}, {3.053225458976192, 1.8748467145743588`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{3.076631133661741, 1.8717321350119762`}, {
            3.1384027286486536`, 1.8635122246754112`}, {3.305241000547256, 
            1.8432561411072006`}, {3.472784832892853, 1.8248511575782602`}, {
            3.6226160178333697`, 1.8100115385188036`}, {3.7731833873628617`, 
            1.7965468658745987`}, {3.94678268237826, 1.7825210224035652`}, {
            4.016250355180139, 1.7774707347989618`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.039800196621877, 1.7757586654647437`}, {
            4.121355812127204, 1.7698295865499074`}, {4.296902776609694, 
            1.7584725583136254`}, {4.4734235758257315`, 
            1.7484499376947187`}, {4.497089127097619, 1.747199138574396}, {
            4.520771062088781, 1.7459675334179956`}, {4.696210653438223, 
            1.738011473747052}, {4.872299443229115, 1.7310034422444889`}, {
            4.9829515718730395`, 1.726872838720554}}]}, 
          {Arrowheads[{{0.013776725882650895`, 1.}}], 
           ArrowBox[{{5.0065471303699525`, 1.7259920251449725`}, {
            5.088769793930972, 1.7229226831629005`}, {5.304395167699339, 
            1.7159443311388032`}, {5.519175564534217, 1.7100683861721968`}, {
            5.656854249492381, 1.7069963636794845`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.671767500991714, -3.9318143271105344`}, \
{-4.464898526998454, -3.925423315193715}, {-4.258705775941813, \
-3.9173703954522123`}, {-4.053438783309414, -3.9073971095064337`}, \
{-3.8493147784404576`, -3.8954070436126083`}, {-3.7284179770741415`, \
-3.8871694308480924`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-3.704860605969487, -3.8855642891179802`}, \
{-3.6464944549144103`, -3.881587362139655}, {-3.4451385063107343`, \
-3.8661252294564905`}, {-3.2455084888273418`, -3.849114860408691}, \
{-3.047785268567388, -3.830724829460505}, {-2.8520085039682, \
-3.8112538404088636`}, {-2.764130288094867, -3.80206960532135}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7406461996959797`, -3.7996152611300404`}, \
{-2.658217853467104, -3.791000597050695}, {-2.466714345790579, \
-3.77011894998313}, {-2.277589913433782, -3.7488786323631382`}, \
{-2.0905705704870625`, -3.7277521718274094`}, {-1.9053823310407743`, \
-3.707212096012633}, {-1.8018385356353679`, -3.696295182259365}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.7783566949315568`, -3.6938194257089334`}, \
{-1.7404288573533737`, -3.689820587052616}, {-1.576589947457169, \
-3.6738436862576447`}, {-1.4136206759039038`, -3.6594461039749815`}, \
{-1.2538886553600395`, -3.6450356401810935`}, {-1.0939241086419698`, \
-3.6329456914621927`}, {-0.9343393493703307, -3.622764481950124}, \
{-0.8370597123458888, -3.61770972204305}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.813479530652864, -3.6164844691466653`}, \
{-0.775134377545121, -3.614492011644887}, {-0.6163091931663424, \
-3.6081282805464827`}, {-0.4573008704225585, -3.603412518602461}, \
{-0.29754648350233115`, -3.6000839557603723`}, {-0.13704603240566204`, \
-3.5981425920202175`}, {0.02420048286744919, -3.597588427381996}, {
            0.13070372080661158`, -3.5975207612669657`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.1543157090389614, -3.5975057595492457`}, {
            0.25235375831567225`, -3.597443471734828}, {
            0.4826384488259211, -3.596616771803626}, {
            0.715054554398195, -3.595108327588391}, {
            0.9496020750324956, -3.592918139089122}, {
            1.0987600891156268`, -3.5905552041398523`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.1223691197984287`, -3.590181194040149}, {
            1.1855585610274413`, -3.589180158058122}, {
            1.4222015626816509`, -3.583028336247691}, {
            1.659531079995126, -3.57446267365783}, {
            1.8975471129678656`, -3.5634831702885386`}, {
            2.066108480967561, -3.554394415877022}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.08968622483287, -3.553123114355728}, {
            2.1357059387362183`, -3.550641751735578}, {
            2.373463834436532, -3.5364903435947097`}, {
            2.610820800068807, -3.521028945865934}, {
            2.847776835633044, -3.5042575585492504`}, {
            3.0320963308852202`, -3.49086149858517}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0556462086796925`, -3.489149929363206}, {
            3.0844081689864837`, -3.487059553928816}, {
            3.320791027986367, -3.470318304288788}, {
            3.556925412632694, -3.4540338096291667`}, {
            3.792811322925465, -3.4382060699499517`}, {
            3.954505995165633, -3.4276728135272867`}, {
            3.997938447496055, -3.424945484900025}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.021504024588295, -3.423465691115123}, {
            4.1162629220839975`, -3.417515332800984}, {
            4.269135655964888, -3.408415285050252}, {
            4.422068909872039, -3.3999056003111745`}, {
            4.5750626838054504`, -3.391986278583752}, {
            4.728116977765121, -3.384657319867984}, {
            4.748648003274136, -3.3837139806768355`}, {
            4.769180872528934, -3.3827804530447976`}, {
            4.951767391729577, -3.3753270396134574`}, {
            4.964706015630236, -3.3748504363610174`}}]}, 
          {Arrowheads[{{0.01416466266216318, 1.}}], 
           ArrowBox[{{4.988302005724582, -3.3739812615778377`}, {
            5.134515893447989, -3.3685953708543823`}, {
            5.327336997621014, -3.361871977626261}, {
            5.520353708648127, -3.3558999928444906`}, {
            5.656854249492381, -3.3521727725246206`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.4990820880991955`, 
            3.662749171150437}, {-1.3554084723045579`, 
            3.649058262257683}, {-1.2116566417511234`, 
            3.6371656746655905`}, {-1.0683080099397801`, 
            3.6267389674084223`}, {-0.9253625768705298, 
            3.6177781404861786`}, {-0.7828203425433712, 
            3.610283193898859}, {-0.6403053828673844, 
            3.6041610258525494`}, {-0.5567799122750147, 
            3.6013298544499093`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.5331814718913599, 
            3.6005299639603705`}, {-0.49744177375165144`, 
            3.5993185345533343`}, {-0.35422951519617146`, 
            3.5957557200012134`}, {-0.21066860720094388`, 
            3.5934725821961875`}, {-0.024397955203604355`, 
            3.591667934790794}, {0.1633412431457067, 3.590496401621811}, {
            0.35254898784699035`, 3.5899579826892385`}, {0.4112020876330271, 
            3.5899871114974116`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.43481407771916636`, 3.589998837887531}, {
            0.5432252789002464, 3.590052677993076}, {0.7352002118278983, 
            3.5898152526208027`}, {0.9283038821523704, 3.588280471659898}, {
            1.1225362898736626`, 3.5854483351103608`}, {1.3178974349917745`, 
            3.5813188429721916`}, {1.3792010394412848`, 
            3.57966840240174}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.4028044799132846`, 3.5790329409781085`}, {
            1.447797651149592, 3.577821616523886}, {1.5776645173156725`, 
            3.5736666819034335`}, {1.7074980334900163`, 
            3.5688540391108345`}, {1.8372981996726234`, 3.563383688146089}, {
            1.9670650158634935`, 3.5572556290091972`}, {2.096798482062627, 
            3.5504698617001584`}, {2.226498598270023, 3.5430263862189735`}, {
            2.3462282396774157`, 3.535546043783537}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.3697919267675625`, 3.534036783749598}, {
            2.5184370484839484`, 3.524345482281615}, {2.680544644751804, 
            3.5137192730695275`}, {2.8424881532892496`, 
            3.5030465749293795`}, {3.004267574096286, 3.492327387861171}, {
            3.1658829071729127`, 3.4815617118649027`}, {3.3122161822896485`, 
            3.4717619763404937`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.3357752041714512`, 3.4701812533492076`}, {
            3.4886213101349366`, 3.459890893088184}, {3.6497443800203344`, 
            3.448985750307734}, {3.806640917566315, 3.4384876342978727`}, {
            3.963574781314213, 3.4282922254165156`}, {4.1163649523330745`, 
            3.4187926787594174`}, {4.269205115844805, 3.4098392818641345`}, {
            4.27828786955743, 3.4093398320819515`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.301864244706441, 3.4080433953618328`}, {
            4.422095271849407, 3.4014320347306675`}, {4.575035420346877, 
            3.3935709373590157`}, {4.595543012996955, 3.3925536332240096`}, {
            4.6160521586717005`, 3.3915465008133365`}, {4.793771525991743, 
            3.3836558389480436`}, {4.971633606956407, 3.376476172970997}, {
            5.160930508743362, 3.3692152564969415`}, {5.245401556860285, 
            3.366314111973247}}]}, 
          {Arrowheads[{{0.008216858836522305, 1.}}], 
           ArrowBox[{{5.268999636191087, 3.365503639744638}, {
            5.350413573255958, 3.3627074912069617`}, {5.540081550628045, 
            3.356922434861343}, {5.656854249492381, 
            3.3537899952891594`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3689891137082277`, -2.611833863286821}, {
            1.5503291842763507`, -2.5949177190257338`}, {
            1.7315684123945612`, -2.575289218111715}, {
            1.9124065716122776`, -2.5539885982165362`}, {
            2.0925434354789187`, -2.53205609701197}, {
            2.271979003994485, -2.5094917144980156`}, {
            2.3073316250166327`, -2.504903625657765}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.3307472463477485`, -2.5018647293097533`}, {
            2.450713277158976, -2.486295450674674}, {
            2.672825287411116, -2.4577939251574397`}, {
            2.8948700389065047`, -2.4308500341908608`}, {
            3.116847531645144, -2.405463777774937}, {
            3.2684524707365443`, -2.3891845070910493`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.291929502245745, -2.38666355392763}, {
            3.338757765627032, -2.3816351559096685`}, {
            3.561047517957124, -2.3595863773819636`}, {
            3.784163565740373, -2.3395396509787316`}, {
            4.00810590897678, -2.321494976699971}, {
            4.232852869396109, -2.3054539018091287`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{4.256417768541382, -2.303963362297288}, {
            4.408769153456306, -2.294327890907257}, {
            4.5851457018245565`, -2.2843675894462496`}, {
            4.756204238197136, -2.2756928166631236`}, {
            4.9276850684619635`, -2.267864124350086}, {
            5.099588192619037, -2.2608815125071366`}, {
            5.199708435623146, -2.2573162171536834`}}]}, 
          {Arrowheads[{{0.009184246282306808, 1.}}], 
           ArrowBox[{{5.2233054718762455`, -2.256475923510918}, {
            5.271913610668358, -2.2547449811342757`}, {
            5.2950440861369374`, -2.2539790231090495`}, {
            5.318181417194771, -2.25322593562653}, {
            5.518456272984706, -2.2477416674636577`}, {
            5.656854249492381, -2.2445359014209183`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.6277747081904091, -3.1407226229804417`}, \
{-0.4786378270669926, -3.1341712557812653`}, {-0.32885412736726705`, \
-3.129390067736865}, {-0.17842360909123245`, -3.1263790588472404`}, \
{-0.026906152478022916`, -3.124458113347053}, {
            0.12613836223322905`, -3.1229471154709634`}, {
            0.2807099350425229, -3.1218460652189717`}, {
            0.3164308573652354, -3.121687916341275}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.3400426189526487, -3.1215833789062737`}, {
            0.436808565949858, -3.1211549625910777`}, {
            0.5942879640829855, -3.1200679629855363`}, {
            0.7530018385696563, -3.1177792218006015`}, {
            0.9129501894098699, -3.114288739036274}, {
            1.0741330166036258`, -3.1095965146925533`}, {
            1.2842325932922531`, -3.101339763095632}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3078263738543168`, -3.1004125456856606`}, {
            1.3100995515813612`, -3.1003232115512294`}, {
            1.5461896116199587`, -3.0879379856687157`}, {
            1.782403196719419, -3.0724408370450123`}, {
            2.0187403068797423`, -3.0538317656801195`}, {
            2.2498769980783737`, -3.0338351029241077`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{2.2733971839338643`, -3.031755072213162}, {
            2.4903644230872164`, -3.0124556971415446`}, {
            2.725296259310427, -2.9909831605715573`}, {
            2.9596412809466197`, -2.968987622467771}, {
            3.1222947790733433`, -2.953852887202024}, {
            3.2139464487608764`, -2.945699438156201}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.2374655587823646`, -2.9436071482304738`}, {
            3.2850439558247824`, -2.939374513546459}, {
            3.4478888112009365`, -2.925552501501075}, {
            3.6108293452018065`, -2.9123868510658726`}, {
            3.7738655578273916`, -2.899877562240852}, {
            3.9369974490776922`, -2.8880246350260124`}, {
            4.100225018952709, -2.8768280694213546`}, {
            4.179183751788431, -2.871732400807861}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.20274672734259, -2.870211744248926}, {
            4.26354826745244, -2.866287865426878}, {
            4.44068336503022, -2.8556586237699135`}, {
            4.618165351767802, -2.84587387810154}, {
            4.7809094774527, -2.8376432802861915`}, {
            4.9438627130720185`, -2.830112338059908}, {
            5.107025058625757, -2.8232810514226885`}, {
            5.145959542538379, -2.8218197686686777`}}]}, 
          {Arrowheads[{{0.010323837323733423`, 1.}}], 
           ArrowBox[{{5.169554922699659, -2.820934190676135}, {
            5.270396514113916, -2.8171494203745335`}, {
            5.292328305735906, -2.816373738953115}, {
            5.314262250626447, -2.8156103558730936`}, {
            5.513247177346133, -2.8097462427840436`}, {
            5.656854249492381, -2.805992916105022}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.6278596551935005, 
            3.1417834777612414`}, {-0.4786363221019322, 
            3.1352324859231673`}, {-0.3287661084249099, 
            3.1304526143772424`}, {-0.17824901416243238`, 
            3.1274438631234664`}, {-0.026644769161451698`, 
            3.1255255236624135`}, {0.12648689673108093`, 3.124016887494658}, {
            0.281145983515165, 3.1229179546201995`}, {0.31634625065263, 
            3.1227626206817116`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.33995801375159207`, 3.12265842521801}, {
            0.4373324911907997, 3.122228725039039}, {0.5948998269513007, 
            3.1211429982923744`}, {0.7537013979899833, 3.1188545739214057`}, {
            0.9137372043068468, 3.1153634519261324`}, {1.0750072459018907`, 
            3.1106696323065552`}, {1.284148803668764, 3.1024519022217354`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{1.3077425903040982`, 3.10152483936384}, {
            1.3112212440794155`, 3.101388153771128}, {1.5475564203147736`, 
            3.0889924057949822`}, {1.7840127746079641`, 
            3.0734823883781175`}, {2.0205903069589866`, 
            3.0548581015205345`}, {2.2497990063711453`, 
            3.0350341389608113`}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.273319730330345, 3.0329602346629936`}, {
            2.4926937571431425`, 3.0134562835369865`}, {2.727865887803429, 
            2.9919761434244654`}, {2.962451622175854, 2.9699765158981126`}, {
            3.125239207607495, 2.954843993474213}, {3.2138747486051367`, 
            2.9469672854218034`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.2373940557768295`, 2.9448772128154737`}, {
            3.288123209062854, 2.940369103250366}, {3.4511036265419315`, 
            2.9265518452265713`}, {3.614180460044728, 2.913392219402829}, {
            3.777353709571242, 2.9008902257791394`}, {3.9406233751214748`, 
            2.889045864355502}, {4.103989456695426, 2.877859135131917}, {
            4.1791135552523615`, 2.873020172469923}}]}, 
          {Arrowheads[{{0.020000000000000007`, 1.}}], 
           ArrowBox[{{4.202676716781938, 2.8715024003963756`}, {
            4.267451954293095, 2.867330038108385}, {4.444718285499189, 
            2.856714812963885}, {4.6223318792373025`, 2.8469441554503354`}, {
            4.785061491976132, 2.838733235791436}, {4.9479990601736485`, 
            2.8312213035208105`}, {5.111144583829854, 2.8244083586384585`}, {
            5.145889496514375, 2.8231079338146983`}}]}, 
          {Arrowheads[{{0.01032532464542967, 1.}}], 
           ArrowBox[{{5.169484968573882, 2.822224807761882}, {
            5.274498062944747, 2.8182944011443807`}, {5.296427580633019, 
            2.817521038378896}, {5.318359240555004, 2.816759951986755}, {
            5.517348592383383, 2.8109121734080174`}, {5.656854249492381, 
            2.807273812216783}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.59495692232418, -5.656854249492381}, \
{-1.5625539906720267`, -5.655022229519474}, {-1.4254795597517051`, \
-5.647792812618338}, {-1.2889749019681278`, -5.641116204624962}, \
{-1.1530400173212954`, -5.634992405539346}, {-1.0176749058112056`, \
-5.62942141536149}, {-0.882704072676459, -5.6244881266080835`}, \
{-0.7479520231556552, -5.620277431795814}, {-0.6513234726715162, \
-5.617772102509054}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.6277194120343292, -5.617160110048187}, \
{-0.6134187572487925, -5.616789330924682}, {-0.4791042749558716, \
-5.614023823994688}, {-0.34500857627689274`, -5.611980911005831}, \
{-0.21113166121185578`, -5.610660591958111}, {-0.0774735297607606, \
-5.610062866851529}, {0.05596581807639289, -5.610187735686084}, {
            0.18927881195730314`, -5.610814365176864}, {
            0.3166991414858368, -5.6116820272546075`}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{0.3403102924952151, -5.611880265222721}, {
            0.4558030268234918, -5.612910406272358}, {
            0.5890142478087702, -5.614379817877072}, {
            0.7221915444955047, -5.616130156853099}, {
            0.8553349168836952, -5.618161423200436}, {
            0.9884443649733419, -5.620473616919085}, {
            1.121519888764444, -5.623066738009046}, {
            1.2557225329637178`, -5.625758342025739}, {
            1.2846727185961222`, -5.626310646524983}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{1.3082804158482644`, -5.626761028348945}, {
            1.3896871994670945`, -5.628314086883098}, {
            1.5234138882745745`, -5.630733972581123}, {
            1.6572136581834636`, -5.632991958167604}, {
            1.7910435295800362`, -5.635148531953366}, {
            1.9251204241695956`, -5.637196911910223}, {
            2.059134311636743, -5.639094784672126}, {
            2.192775161666081, -5.640799836873028}, {
            2.252643657947491, -5.6414364762201}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{2.2762543160229036`, -5.641687551073733}, {
            2.3250309570866485`, -5.642206240047868}, {
            2.4554512702119355`, -5.6432589778107936`}, {
            2.5845684549532204`, -5.643991954914575}, {
            2.712914865221781, -5.644439076111978}, {
            2.842095975870022, -5.644656835664996}, {
            2.972858764997447, -5.64468365622824}, {
            3.1044478413859835`, -5.644526335143412}, {
            3.2207235141734403`, -5.6442307749757905`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{3.2443353859761244`, -5.644157370168494}, {
            3.398468183347247, -5.643514812353802}, {
            3.556771398358189, -5.64256699739579}, {
            3.712039922618965, -5.641389254938475}, {
            3.865296219898155, -5.640022615042157}, {
            4.101378659387384, -5.637538812272164}, {
            4.188780957958167, -5.636485583466472}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{4.212391236781348, -5.6362010712033666`}, {
            4.333487863725024, -5.634741813748416}, {
            4.569791906965733, -5.631823477270186}, {
            4.753030558971863, -5.629714428135846}, {
            4.941069924809593, -5.627813757979935}, {
            5.153672735114947, -5.626021600738777}, {
            5.156814780939027, -5.626000956664939}}]}, 
          {Arrowheads[{{0.010088821150451432`, 1.}}], 
           ArrowBox[{{5.180426264307721, -5.625845822961176}, {
            5.3658351807088875`, -5.624627637239298}, {
            5.3801065292345704`, -5.624547179675816}, {
            5.394375783858701, -5.624468645897662}, {
            5.444901032380904, -5.624221638041233}, {
            5.495399225565731, -5.623999308064223}, {
            5.592223542284686, -5.623758613167393}, {
            5.656854249492381, -5.6234977632765535`}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-5.656854249492381, -5.338055660114318}, \
{-5.544486282816296, -5.33774957644206}, {-5.3995044114018835`, \
-5.337052369305722}, {-5.254956210360861, -5.336054058338556}, \
{-5.110841679693226, -5.3347546435405615`}, {-4.9671608193989805`, \
-5.333154124911738}, {-4.823913629478128, -5.331252502452087}, \
{-4.712422737480245, -5.329406976207503}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-4.688813978743413, -5.329016176716441}, \
{-4.680985538856531, -5.328886591321558}, {-4.538261976460055, \
-5.3258932066801}, {-4.3957429422887015`, -5.322272348527716}, \
{-4.2534284363424675`, -5.318024016864403}, {-4.111318458621355, \
-5.313148211690163}, {-3.9694130091253665`, -5.307644933004995}, \
{-3.8277120878544997`, -5.3015141808088995`}, {-3.744893369474662, \
-5.297558549293992}}]}, 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{-3.7213082630229333`, -5.296432064941325}, \
{-3.6862156948087543`, -5.294755955101875}, {-3.545124414138939, \
-5.287484289939326}, {-3.404638829995861, -5.279813219376654}, \
{-3.2647589423795216`, -5.271742743413857}, {-3.1254847512899206`, \
-5.263272862050937}, {-2.986816256727057, -5.254403575287893}, \
{-2.8487534586909318`, -5.2451348831247255`}, {-2.778522647621557, \
-5.24019517229195}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-2.7549688438541526`, -5.238538506537258}, \
{-2.7112963571815456`, -5.235466785561434}, {-2.574444952198897, \
-5.225399282598018}, {-2.365865138208234, -5.209856991708233}, \
{-2.1589645292071986`, -5.194722977998964}, {-1.9537431251957915`, \
-5.17999724147021}, {-1.812973325908594, -5.170095285568975}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-1.78941953219499, -5.168438476879611}, \
{-1.7502009261740128`, -5.1656797821219715`}, {-1.5480907237916022`, \
-5.152373945293886}, {-1.3471653096983003`, -5.14068307632559}, \
{-1.1474246838941073`, -5.130607175217086}, {-0.948868846379024, \
-5.1221462419683705`}, {-0.8463089769375147, -5.118615854890593}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{-0.8227109607036942, -5.117803547581441}, \
{-0.7510648044042774, -5.115337293814258}, {-0.5535795652210943, \
-5.1102173479895585`}, {-0.35641312882947596`, -5.106786404494273}, \
{-0.15956549522942198`, -5.105044463328401}, {-0.013611112939107328`, \
-5.104562262870486}, {0.12162157141114091`, -5.104455715532982}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{0.14523354199116445`, -5.104469306666535}, {
            0.27853706345112056`, -5.104699290403635}, {
            0.4247308575510348, -5.105318518394697}, {
            0.5710044555874818, -5.106304889202086}, {
            0.7173578575604608, -5.107658402825801}, {
            0.8637910634699727, -5.109379059265842}, {
            1.0103040733160171`, -5.111466858522208}, {
            1.0896692888566728`, -5.112586358250081}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{1.113278933166085, -5.1129193881574455`}, {
            1.1879061147023429`, -5.113972054729981}, {
            1.3653950457764856`, -5.115980710471623}, {
            1.5427708665384459`, -5.117492825747134}, {
            1.720033576988223, -5.118508400556514}, {
            1.8971831771258176`, -5.119027434899762}, {
            2.0577297474073646`, -5.11904783360303}}]}, 
          {Arrowheads[{{0.020000000000000004`, 1.}}], 
           ArrowBox[{{2.0813417147072353`, -5.1190308460391725`}, {
            2.2511430464644584`, -5.118575882187866}, {
            2.4279533156655053`, -5.11760529513272}, {
            2.6392701107372774`, -5.115832272238057}, {
            2.8501047602604013`, -5.11343092271483}, {
            3.0257788280598525`, -5.110900714974757}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.0493883723772655`, -5.110560670183173}, {
            3.0604572642348793`, -5.11040124656304}, {
            3.2703276226607096`, -5.106743243782686}, {
            3.4799569083122166`, -5.10277107768805}, {
            3.6895861939637236`, -5.098798911593415}, {
            3.8992154796152305`, -5.0948267454987795`}, {
            3.9936800725677344`, -5.0920059926787395`}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.017281545843093, -5.091301242674343}, {
            4.104731823851753, -5.088689940274191}, {
            4.277491103733907, -5.08444158207362}, {
            4.4499627421288634`, -5.080276526384465}, {
            4.687420909490311, -5.074945803594612}, {
            4.9244373057207715`, -5.0701079072224084`}, {
            4.940363624978348, -5.069799094667135}, {
            4.956288037652773, -5.069492603366292}, {
            4.961503847834126, -5.069401985779137}}]}, 
          {Arrowheads[{{0.014226255703201858`, 1.}}], 
           ArrowBox[{{4.985112278078558, -5.06899182150726}, {
            5.144370760855245, -5.0662249226092015`}, {
            5.332179011339602, -5.063294756179733}, {
            5.513878913663469, -5.060620610648979}, {
            5.656854249492381, -5.058771169123271}}]}}, 
         {GrayLevel[0], 
          {Arrowheads[{{0.019999999999999997`, 1.}}], 
           ArrowBox[{{1.3703673140885948`, 2.6129050362814876`}, {
            1.55190934843634, 2.5959727950332905`}, {1.7333493750461408`, 
            2.576327170011745}, {1.914387925648287, 2.5550105781008288`}, {
            2.094725531973066, 2.533065436184516}, {2.274362194020479, 
            2.5104917442628083`}, {2.3087172506837517`, 
            2.5060369917625556`}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{2.332133208677714, 2.5030006906310565`}, {
            2.4532979117905254`, 2.4872895023357047`}, {2.675721509653105, 
            2.458777959055338}, {2.8980812936508107`, 2.4318302368408413`}, {
            3.120377263783643, 2.4064463356922157`}, {3.269850896153758, 
            2.390424919380963}}]}, 
          {Arrowheads[{{0.02, 1.}}], 
           ArrowBox[{{3.293328410693319, 2.387908468630235}, {
            3.342609420051602, 2.382626255609461}, {3.5652238353926964`, 
            2.360590784386264}, {3.7886665827449346`, 2.340560709816313}, {
            4.0129376621083175`, 2.322536031899607}, {4.234259047292825, 
            2.306785615240408}}]}, 
          {Arrowheads[{{0.019999999999999993`, 1.}}], 
           ArrowBox[{{4.25782220748756, 2.3052694406330922`}, {
            4.414106208172308, 2.2954168615540205`}, {4.590657161954411, 
            2.2854800954951444`}, {4.761710784960279, 2.276835650686693}, {
            4.933185291420885, 2.2690350155604637`}, {5.105080681336228, 
            2.2620781901164557`}, {5.20111549536893, 2.258671301606273}}]}, 
          {Arrowheads[{{0.009154442011897926, 1.}}], 
           ArrowBox[{{5.224712644351183, 2.2578341796047314`}, {
            5.277396954706311, 2.25596517435467}, {5.300526415971627, 
            2.255202206546919}, {5.323662707558905, 2.2544520787855835`}, {
            5.524109752841301, 2.248986770965738}, {5.656854249492381, 
            2.245926823641296}}]}}}}},
      Frame->True,
      FrameLabel->{{
         FormBox["\"y/R\"", TraditionalForm], 
         FormBox["\"\"", TraditionalForm]}, {
         FormBox["\"z/R\"", TraditionalForm], 
         FormBox[
         "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(tot\\)]\\)}\"", 
          TraditionalForm]}}], {194.4, -189.}, ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}],
    ImageSize->{211., Automatic}]}]], "Input",
  CellChangeTimes->{3.532430063576189*^9}],
 "\n",
 StyleBox["Plot Field Intensities for the example defined above, {{",
  FontSize->12],
 Cell[BoxData[
  SubscriptBox["z", "n"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}},
  FontSize->12],
 StyleBox[", ",
  FontSize->12],
 Cell[BoxData[
  SubscriptBox["x", "i"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}},
  FontSize->12],
 StyleBox[" or ",
  FontSize->12],
 Cell[BoxData[
  SubscriptBox["y", "i"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}},
  FontSize->12],
 StyleBox[", {Fields[r,\[Theta],\[Phi]]}},{},..}, coordinate transform to \
cartesian: {",
  FontSize->12],
 Cell[BoxData[
  SubscriptBox["S", "z"]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}, {
    3.53228811956033*^9, 3.53228814463232*^9}, 3.5322885694137793`*^9, {
    3.532288633051366*^9, 3.532288640729644*^9}, 3.532288693436808*^9, {
    3.532326560676771*^9, 3.532326561467997*^9}, 3.5323267539092283`*^9, {
    3.532326855841176*^9, 3.5323268626361923`*^9}, {3.532327648154467*^9, 
    3.532327648472391*^9}, {3.532328314440467*^9, 3.5323283774651546`*^9}, {
    3.532328422377253*^9, 3.532328424681246*^9}, {3.532328560525572*^9, 
    3.532328568167946*^9}, {3.532328656757094*^9, 3.532328674806654*^9}},
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" = ",
  FontSize->12],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[Theta]", "]"}], 
      StyleBox[
       SubscriptBox["S", "r"],
       FontColor->RGBColor[0, 0, 1]]}], "-", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], 
      StyleBox[
       SubscriptBox["S", "\[Theta]"],
       FontColor->RGBColor[0, 0, 1]]}]}], ",", 
    RowBox[{
     StyleBox[
      SubscriptBox["S", 
       RowBox[{"x", "/", "y"}]],
      FontColor->RGBColor[1, 0, 0]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       StyleBox[
        SubscriptBox["S", "r"],
        FontColor->RGBColor[0, 0, 1]]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "\[Theta]", "]"}], 
       StyleBox[
        SubscriptBox["S", "\[Theta]"],
        FontColor->RGBColor[0, 0, 1]]}]}]}]}], "}"}]],
  CellChangeTimes->{{3.5320769763361597`*^9, 3.5320769845817137`*^9}, {
    3.532077073205283*^9, 3.532077111570195*^9}, {3.532077178069942*^9, 
    3.532077185291717*^9}, {3.532077223352206*^9, 3.532077287254383*^9}, {
    3.532077347617381*^9, 3.532077471456766*^9}, {3.5320775217378197`*^9, 
    3.532077534014497*^9}, {3.532077566384733*^9, 3.532077586642006*^9}, {
    3.532077749266254*^9, 3.53207776671135*^9}, {3.532077800422965*^9, 
    3.532077812398676*^9}, {3.532077875412162*^9, 3.5320778756284657`*^9}, 
    3.532079046415043*^9, {3.532079218485832*^9, 3.532079246890177*^9}, 
    3.532079337745221*^9, {3.5320793748582*^9, 3.532079415996982*^9}, {
    3.532079507053657*^9, 3.5320795385771227`*^9}, {3.532079617392256*^9, 
    3.532079655505661*^9}, {3.532079769851645*^9, 3.53207977371844*^9}, {
    3.532079897461246*^9, 3.532079961897822*^9}, {3.53208019119515*^9, 
    3.532080234009427*^9}, {3.532080956561995*^9, 3.532080962374159*^9}, {
    3.532080999912609*^9, 3.5320810909896793`*^9}, {3.532081122199461*^9, 
    3.532081198305132*^9}, {3.5320812317587233`*^9, 3.532081328118986*^9}, {
    3.5320813626137333`*^9, 3.532081383224264*^9}, 3.532081428302641*^9, {
    3.5320818599456673`*^9, 3.532081897218287*^9}, {3.5320819470262527`*^9, 
    3.5320819645317717`*^9}, {3.532082104278542*^9, 3.53208215394158*^9}, {
    3.532085207712059*^9, 3.5320852199958982`*^9}, 3.53208526951476*^9, {
    3.532085381366343*^9, 3.5320853891812162`*^9}, {3.532085597092535*^9, 
    3.532085602033532*^9}, {3.532085663215652*^9, 3.532085695009119*^9}, {
    3.532085758736896*^9, 3.532085760935131*^9}, {3.53208579270499*^9, 
    3.5320857929396544`*^9}, {3.532085831439989*^9, 3.532085870569948*^9}, {
    3.532086285071228*^9, 3.532086285674509*^9}, {3.53208636627739*^9, 
    3.5320863828443947`*^9}, {3.532086594870747*^9, 3.532086676064364*^9}, {
    3.532086711544648*^9, 3.532086712904482*^9}, 3.532086786125029*^9, {
    3.532086839135477*^9, 3.5320868600034237`*^9}, 3.5320869028972397`*^9, {
    3.532086998494608*^9, 3.5320870014214897`*^9}, {3.532087074398869*^9, 
    3.532087074670475*^9}, {3.532087749463417*^9, 3.5320877627347097`*^9}, {
    3.53208787748464*^9, 3.532087897344034*^9}, 3.532088104491308*^9, {
    3.532088513193218*^9, 3.5320885876537743`*^9}, {3.532088893114394*^9, 
    3.5320889120757637`*^9}, {3.532088974472032*^9, 3.532088998503788*^9}, {
    3.5320890496991873`*^9, 3.532089069796011*^9}, {3.532089313757852*^9, 
    3.5320893455874147`*^9}, {3.532089598822143*^9, 3.532089749022552*^9}, {
    3.532089786987135*^9, 3.53208985405099*^9}, {3.532089950941577*^9, 
    3.532089998594523*^9}, {3.532090055818616*^9, 3.5320901547357388`*^9}, {
    3.532090225543851*^9, 3.532090258771899*^9}, {3.5320903250743732`*^9, 
    3.532090328984304*^9}, {3.532090385495761*^9, 3.5320904035333147`*^9}, {
    3.532090488089162*^9, 3.532090504184224*^9}, {3.532090543056446*^9, 
    3.5320905609038343`*^9}, {3.532091867776864*^9, 3.5320919414926167`*^9}, {
    3.532091984213526*^9, 3.532091986422538*^9}, {3.5320920442459793`*^9, 
    3.532092045667851*^9}, {3.532092083931205*^9, 3.532092092058172*^9}, {
    3.532092452548662*^9, 3.5320924533513203`*^9}, {3.532092773016841*^9, 
    3.5320927971531773`*^9}, {3.5320928369179497`*^9, 
    3.5320928384986897`*^9}, {3.532092895098557*^9, 3.53209295318114*^9}, {
    3.5320929846495867`*^9, 3.532092985489884*^9}, 3.532093084883656*^9, {
    3.532093143059556*^9, 3.5320931944391403`*^9}, 3.532093230107361*^9, {
    3.53209346380298*^9, 3.532093475354107*^9}, {3.532093791815895*^9, 
    3.53209379362562*^9}, {3.53209382417406*^9, 3.532093829133593*^9}, {
    3.532094215726666*^9, 3.532094230085832*^9}, {3.532094418353963*^9, 
    3.5320944257937326`*^9}, {3.5320944942919273`*^9, 3.532094504292047*^9}, {
    3.532094553039709*^9, 3.532094584291546*^9}, {3.532094628580636*^9, 
    3.532094643378213*^9}, {3.532094687856597*^9, 3.532094690865466*^9}, {
    3.5320949943325987`*^9, 3.532094994483083*^9}, {3.53209502582294*^9, 
    3.5320950261974277`*^9}, 3.532095069015456*^9, {3.532095155355728*^9, 
    3.532095155552475*^9}, {3.5320952795382357`*^9, 3.53209528087792*^9}, {
    3.532096953991341*^9, 3.5320969576834517`*^9}, {3.5320971134280376`*^9, 
    3.532097240346204*^9}, {3.532097270470587*^9, 3.532097316687305*^9}, {
    3.532105492430983*^9, 3.5321055093121643`*^9}, {3.532105550030024*^9, 
    3.532105774783189*^9}, {3.532106394355064*^9, 3.532106396626054*^9}, {
    3.532106592931974*^9, 3.53210659468219*^9}, {3.532106634905789*^9, 
    3.532106649678225*^9}, {3.532106683238309*^9, 3.5321066873933268`*^9}, {
    3.5321072728746023`*^9, 3.532107281145933*^9}, {3.532107457282984*^9, 
    3.532107462506843*^9}, {3.532108109574057*^9, 3.532108109703368*^9}, {
    3.5321081466337767`*^9, 3.532108246308222*^9}, {3.532108374922949*^9, 
    3.532108390757556*^9}, {3.532108490733326*^9, 3.5321084997648373`*^9}, {
    3.532108534215158*^9, 3.5321085792748632`*^9}, {3.5321086141979856`*^9, 
    3.5321086438980618`*^9}, {3.5321086994408283`*^9, 3.532108708041318*^9}, {
    3.53210990252299*^9, 3.532109914168846*^9}, {3.532112187413501*^9, 
    3.532112226098743*^9}, {3.5321122735578814`*^9, 3.532112412089611*^9}, {
    3.53211894704603*^9, 3.532118947461974*^9}, {3.532166412256401*^9, 
    3.532166416898077*^9}, {3.532173483580325*^9, 3.53217348379186*^9}, {
    3.532176528700502*^9, 3.532176531714116*^9}, {3.532192676905398*^9, 
    3.5321926808062563`*^9}, {3.532232803743095*^9, 3.5322328782493067`*^9}, {
    3.5322331214080257`*^9, 3.532233394179604*^9}, {3.532233515479403*^9, 
    3.532233519794229*^9}, {3.532234767526366*^9, 3.5322347714628277`*^9}, {
    3.532234850090028*^9, 3.532234850268606*^9}, 3.532235596028644*^9, {
    3.5322372613222446`*^9, 3.532237265502405*^9}, {3.53224078948053*^9, 
    3.532240789809482*^9}, {3.5322408242424297`*^9, 3.532240893670023*^9}, 
    3.532259297714774*^9, 3.532259365250252*^9, {3.5322599516964483`*^9, 
    3.532259972292923*^9}, {3.532260991067281*^9, 3.5322609927875338`*^9}, {
    3.5322610817461767`*^9, 3.532261096311199*^9}, 3.532261283981717*^9, {
    3.53226137160118*^9, 3.532261400067951*^9}, {3.5322616364382544`*^9, 
    3.5322616366872787`*^9}, {3.53226189150163*^9, 3.532261891638027*^9}, 
    3.532262281210929*^9, {3.532262804841838*^9, 3.532262807814683*^9}, {
    3.532262873327332*^9, 3.53226288069901*^9}, {3.5322637297540693`*^9, 
    3.5322637300780563`*^9}, 3.532264521619882*^9, 3.532264574423402*^9, {
    3.532264669214806*^9, 3.532264669406206*^9}, {3.53226524247554*^9, 
    3.5322652427170477`*^9}, 3.53226556609175*^9, {3.53226561149669*^9, 
    3.532265689532071*^9}, {3.532265841172805*^9, 3.5322659232413063`*^9}, 
    3.532266555018887*^9, {3.532268637812976*^9, 3.532268646742625*^9}, {
    3.532268684423477*^9, 3.53226868785918*^9}, {3.5322703025998507`*^9, 
    3.53227030273258*^9}, {3.5322709928414927`*^9, 3.532270993261281*^9}, {
    3.532273698372225*^9, 3.532273721668347*^9}, {3.532273896122361*^9, 
    3.532273898665365*^9}, {3.532274326822764*^9, 3.532274491024683*^9}, 
    3.532275804159421*^9, {3.532277992927287*^9, 3.532277996858384*^9}, {
    3.5322781819562273`*^9, 3.5322781941842527`*^9}, {3.5322807145618362`*^9, 
    3.5322807154258223`*^9}, {3.532280931995319*^9, 3.532280953623062*^9}, {
    3.532281665935253*^9, 3.532281673586946*^9}, {3.532282328386805*^9, 
    3.532282338027995*^9}, {3.532283925695341*^9, 3.532283942171123*^9}, {
    3.532284728472664*^9, 3.532284733155253*^9}, {3.532285368093528*^9, 
    3.5322853714563026`*^9}, {3.532286853377347*^9, 3.5322868540730333`*^9}, {
    3.53228811956033*^9, 3.53228814463232*^9}, 3.5322885694137793`*^9, {
    3.532288633051366*^9, 3.532288640729644*^9}, 3.532288693436808*^9, {
    3.532326560676771*^9, 3.532326561467997*^9}, 3.5323267539092283`*^9, {
    3.532326855841176*^9, 3.5323268626361923`*^9}, {3.532327648154467*^9, 
    3.532327648472391*^9}, {3.532328314440467*^9, 3.5323283774651546`*^9}, {
    3.532328422377253*^9, 3.532328424681246*^9}, {3.532328560525572*^9, 
    3.532328568167946*^9}, {3.532328656757094*^9, 3.532328674806654*^9}},
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.554281414967005*^9, 3.554281425257327*^9}, {
  3.5542814667689743`*^9, 3.554281510559516*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Field", " ", 
    RowBox[{"Intensities", ":", " ", 
     RowBox[{"|", "E", 
      SuperscriptBox["|", "2"]}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ItotS", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "2"], 
             "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ">", "1"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], ",", 
           "0"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Scattered", ",", " ", 
     RowBox[{"|", 
      SuperscriptBox["E", "sca"], 
      SuperscriptBox["|", "2"]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSM", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ItotS", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"-", 
            RowBox[{
             RowBox[{
             "ItotS", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
           RowBox[{
            RowBox[{
            "ItotS", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotS", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotS"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotT", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "2"], 
             "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], "<", "1"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}]}], "]"}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Total", ",", " ", 
     RowBox[{"|", 
      SuperscriptBox["E", "tot"], 
      SuperscriptBox["|", "2"]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotTM", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ItotT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"-", 
            RowBox[{
             RowBox[{
             "ItotT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
           RowBox[{
            RowBox[{
            "ItotT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotT", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotT"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotI", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "2"], 
             "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ">", "1"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], ",", 
           "0"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Incidence", ",", " ", 
     RowBox[{"|", 
      SuperscriptBox["E", "inc"], 
      SuperscriptBox["|", "2"]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotIM", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"-", 
            RowBox[{
             RowBox[{
             "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
           RowBox[{
            RowBox[{
            "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotI", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotI"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Poynting", " ", "Vector", " ", 
     RowBox[{"Fields", ":", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z", ",", "x"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["S", "z", "tot"], ",", 
           SubsuperscriptBox["S", "x", "tot"]}], "}"}]}], "}"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"for", " ", "\[Phi]"}], "=", "0"}], ")"}], " ", "or", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z", ",", "y"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           SubsuperscriptBox["S", "z", "tot"], ",", 
           SubsuperscriptBox["S", "y", "tot"]}], "}"}]}], "}"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"for", " ", "\[Phi]"}], "=", 
         RowBox[{"\[Pi]", "/", "2"}]}], ")"}]}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVec", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "2"], 
             "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ">", "1"}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], 
                RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
               RowBox[{
                RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}]}], ",", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
            RowBox[{"{", 
             RowBox[{"\[Theta]", "\[Rule]", 
              RowBox[{"ArcTan", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "}"}]}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], 
                RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
               RowBox[{
                RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}]}], ",", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
            RowBox[{"{", 
             RowBox[{"\[Theta]", "\[Rule]", 
              RowBox[{"ArcTan", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "}"}]}]}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Total", " ", "Field"}], ",", " ", 
     SuperscriptBox["S", "tot"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecM", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVec", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVec", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVec", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVec", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotSVec", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotSVec"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecSP", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
             RowBox[{
              RowBox[{"Sin", "[", "\[Theta]", "]"}], 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "Itot", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Theta]", "]"}], 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "Itot", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "6", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
          RowBox[{"{", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
             "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Interior", " ", "Field"}], ",", " ", 
     SuperscriptBox["S", "sp"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecMSP", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecSP", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecSP", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecSP", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecSP", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotSVecSP", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotSVecSP"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecS", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
             RowBox[{
              RowBox[{"Sin", "[", "\[Theta]", "]"}], 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "Itot", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Theta]", "]"}], 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "Itot", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
          RowBox[{"{", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
             "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Scattered", " ", "Field"}], ",", " ", 
     SuperscriptBox["S", "sca"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecMS", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecS", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecS", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecS", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecS", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotSVecS", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotSVecS"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecI", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
             RowBox[{
              RowBox[{"Sin", "[", "\[Theta]", "]"}], 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "Itot", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
              RowBox[{
               RowBox[{"Cos", "[", "\[Theta]", "]"}], 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "Itot", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
          RowBox[{"{", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
             "]"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Incidence", " ", "Field"}], ",", " ", 
     SuperscriptBox["S", "inc"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecMI", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecI", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecI", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecI", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecI", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotSVecI", "]"}]}], "}"}]}], "]"}], ",", 
       "ItotSVecI"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecDiff", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], 
                RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
               RowBox[{
                RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}]}], ",", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "5", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
            RowBox[{"{", 
             RowBox[{"\[Theta]", "\[Rule]", 
              RowBox[{"ArcTan", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "}"}]}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], 
                RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
               RowBox[{
                RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}]}], ",", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "Itot", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "8", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], "}"}], "/.", 
            RowBox[{"{", 
             RowBox[{"\[Theta]", "\[Rule]", 
              RowBox[{"ArcTan", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                 RowBox[{
                 "Itot", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], "}"}]}], ")"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Incidence", " ", "Field"}], ",", " ", 
     SuperscriptBox["S", "inc"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItotSVecMDiff", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecDiff", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecDiff", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
               "ItotSVecDiff", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{
                "ItotSVecDiff", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "ItotSVecDiff", "]"}]}], "}"}]}], "]"}], 
       ",", "ItotSVecDiff"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Poynting", " ", "Vector", " ", 
     RowBox[{"Magnitudes", ":", " ", 
      RowBox[{"|", "S", "|"}]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"STot2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "2"], 
             "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ">", "1"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], "]"}]}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"STot2M", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"-", 
            RowBox[{
             RowBox[{
             "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
           RowBox[{
            RowBox[{
            "STot2", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "STot2", "]"}]}], "}"}]}], "]"}], ",", 
       "STot2"}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["S", "tot"], "|"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SS2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
          "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "2"], 
             "+", 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ">", "1"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "9", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
           "0"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SS2M", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"-", 
            RowBox[{
             RowBox[{
             "ItotI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
           RowBox[{
            RowBox[{
            "SS2", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "SS2", "]"}]}], "}"}]}], "]"}], ",", 
       "SS2"}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["S", "sca"], "|"}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Maximum", " ", "Field", " ", "Values", " ", "and", " ", "Contour"}], 
     "-", 
     RowBox[{"Value", " ", "Tables"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxVS", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "ItotS", "]"}]}], "]"}]}], ";", 
    RowBox[{"MinVS", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "ItotS", "]"}]}], "]"}]}], ";", 
    RowBox[{"NContS", "=", "7"}], ";", 
    RowBox[{"ContoursTS", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MaxVS", "/", 
        RowBox[{"Exp", "[", "n", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NContS"}], "}"}]}], "]"}]}], ";"}], " ", 
   
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["E", "sca"], 
     SuperscriptBox["|", "2"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxVT", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "ItotT", "]"}]}], "]"}]}], ";", 
    RowBox[{"MinVT", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "ItotT", "]"}]}], "]"}]}], ";", 
    RowBox[{"NContT", "=", "7"}], ";", 
    RowBox[{"ContoursTT", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MaxVT", "/", 
        RowBox[{"Exp", "[", 
         RowBox[{"n", "/", "2"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NContT"}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     RowBox[{
      SuperscriptBox["E", "inc"], "+", 
      SuperscriptBox["E", "sca"]}], 
     SuperscriptBox["|", "2"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxVI", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "ItotI", "]"}]}], "]"}]}], ";", 
    RowBox[{"MinVI", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "ItotI", "]"}]}], "]"}]}], ";", 
    RowBox[{"NContI", "=", "7"}], ";", 
    RowBox[{"ContoursTI", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MinVI", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"MaxVI", "-", "MinVI"}], ")"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "-", "1"}], ")"}], "/", "NContI"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NContI"}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["E", "inc"], 
     SuperscriptBox["|", "2"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxVSP", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"Select", "[", 
        RowBox[{"ItotT", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
              "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "2"], "+", 
             SuperscriptBox[
              RowBox[{
              "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ")"}], "<", "1"}], "&"}]}], "]"}]}], "]"}]}], ";", 
    RowBox[{"MinVSP", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"Select", "[", 
        RowBox[{"ItotT", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
              "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "2"], "+", 
             SuperscriptBox[
              RowBox[{
              "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "2"]}], ")"}], "<", "1"}], "&"}]}], "]"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["E", "sp"], 
     SuperscriptBox["|", "2"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NContSP", "=", "20"}], ";", 
    RowBox[{"ContoursSP", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MinVSP", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"MaxVSP", "-", "MinVSP"}], ")"}], "/", 
         RowBox[{"Exp", "[", 
          RowBox[{"n", "/", "2"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NContSP"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxStot2", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "STot2M", "]"}]}], "]"}]}], ";", 
    RowBox[{"MinStot2", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "STot2M", "]"}]}], "]"}]}], ";", 
    RowBox[{"NContS2", "=", "7"}], ";", 
    RowBox[{"ContoursTS2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MaxStot2", "/", 
        RowBox[{"Exp", "[", 
         RowBox[{"n", "/", "2"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NContS2"}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["S", "tot"], 
     SuperscriptBox["|", "2"]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxSS2", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "SS2", "]"}]}], "]"}]}], ";", 
    RowBox[{"MinSS2", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Last", "/@", 
       RowBox[{"N", "[", "SS2", "]"}]}], "]"}]}], ";", 
    RowBox[{"NContSS2", "=", "7"}], ";", 
    RowBox[{"ContoursTSS2", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MaxSS2", "/", 
        RowBox[{"Exp", "[", "n", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "NContSS2"}], "}"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"|", 
     SuperscriptBox["S", "sca"], 
     SuperscriptBox["|", "2"]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Generate", " ", "Some", " ", "Plots"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"<<", "PlotLegends`"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P1", "=", 
     RowBox[{"ShowLegend", "[", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListDensityPlot", "[", 
          RowBox[{"ItotSM", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", 
               RowBox[{"1", "-", "#"}], "]"}], "&"}], ")"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<z/R\>\"", ",", 
                "\"\<Scattered/Interior Field Intensity: \
|\!\(\*SuperscriptBox[\(E\), \(sca\)]\)\!\(\*SuperscriptBox[\(|\), \(2\)]\)\>\
\""}], "}"}]}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ListContourPlot", "[", 
          RowBox[{"ItotSM", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
           RowBox[{"Contours", "\[Rule]", "ContoursTS"}], ",", 
           RowBox[{"ContourStyle", "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<SolarColors\>\"", "]"}], "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "1"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"NContS", "-", "1"}], ")"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "1", ",", "NContS"}], "}"}]}], "]"}]}]}], 
          "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", "#1", 
           "]"}], "&"}], ",", "20", ",", 
         RowBox[{"ToString", "[", "MaxVS", "]"}], ",", 
         RowBox[{"ToString", "[", "MinVS", "]"}], ",", 
         RowBox[{"LegendPosition", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "0.75"}]}], "}"}]}], ",", 
         RowBox[{"LegendShadow", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendBorder", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendSize", "\[Rule]", "1.5"}], ",", 
         RowBox[{"LegendBorderSpace", "\[Rule]", "0.1"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P2", "=", 
     RowBox[{"ShowLegend", "[", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListDensityPlot", "[", 
          RowBox[{"ItotIM", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", 
               RowBox[{"1", "-", "#"}], "]"}], "&"}], ")"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<z/R\>\"", ",", 
                "\"\<Incidence Field Intensity: |\!\(\*SuperscriptBox[\(E\), \
\(inc\)]\)\!\(\*SuperscriptBox[\(|\), \(2\)]\)\>\""}], "}"}]}], "}"}]}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ListContourPlot", "[", 
          RowBox[{"ItotIM", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
           RowBox[{"Contours", "\[Rule]", "ContoursTI"}], ",", 
           RowBox[{"ContourStyle", "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<SolarColors\>\"", "]"}], "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "1"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"NContI", "-", "1"}], ")"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "1", ",", "NContI"}], "}"}]}], "]"}]}]}], 
          "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", "#1", 
           "]"}], "&"}], ",", "20", ",", 
         RowBox[{"ToString", "[", "MaxVI", "]"}], ",", 
         RowBox[{"ToString", "[", "MinVI", "]"}], ",", 
         RowBox[{"LegendPosition", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "0.75"}]}], "}"}]}], ",", 
         RowBox[{"LegendShadow", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendBorder", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendSize", "\[Rule]", "1.5"}], ",", 
         RowBox[{"LegendBorderSpace", "\[Rule]", "0.1"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P3", "=", 
     RowBox[{"ShowLegend", "[", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListDensityPlot", "[", 
          RowBox[{"ItotTM", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", 
               RowBox[{"1", "-", "#"}], "]"}], "&"}], ")"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<z/R\>\"", ",", 
                "\"\<Total Field Intensity: |\!\(\*SuperscriptBox[\(E\), \
\(inc\)]\)+\!\(\*SuperscriptBox[\(E\), \(sca\)]\)\!\(\*SuperscriptBox[\(|\), \
\(2\)]\) and |\!\(\*SuperscriptBox[\(E\), \
\(sp\)]\)\!\(\*SuperscriptBox[\(|\), \(2\)]\)\>\""}], "}"}]}], "}"}]}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ListContourPlot", "[", 
          RowBox[{"ItotTM", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
           RowBox[{"Contours", "\[Rule]", "ContoursTT"}], ",", 
           RowBox[{"ContourStyle", "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<SolarColors\>\"", "]"}], "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "1"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"NContT", "-", "1"}], ")"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "1", ",", "NContT"}], "}"}]}], "]"}]}]}], 
          "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", "#1", 
           "]"}], "&"}], ",", "20", ",", 
         RowBox[{"ToString", "[", "MaxVT", "]"}], ",", 
         RowBox[{"ToString", "[", "MinVT", "]"}], ",", 
         RowBox[{"LegendPosition", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "0.75"}]}], "}"}]}], ",", 
         RowBox[{"LegendShadow", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendBorder", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendSize", "\[Rule]", "1.5"}], ",", 
         RowBox[{"LegendBorderSpace", "\[Rule]", "0.1"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P4", "=", 
     RowBox[{"ShowLegend", "[", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListDensityPlot", "[", 
          RowBox[{"ItotTM", ",", 
           RowBox[{"RegionFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
              RowBox[{"0", "<", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "+", 
                RowBox[{"y", "^", "2"}]}], "<", "1"}]}], "]"}]}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "Full"}], "}"}]}],
            ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", 
               RowBox[{"1", "-", "#"}], "]"}], "&"}], ")"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<z/R\>\"", ",", 
                "\"\<Interior Field Intensity: |\!\(\*SuperscriptBox[\(E\), \
\(sp\)]\)\!\(\*SuperscriptBox[\(|\), \(2\)]\)\>\""}], "}"}]}], "}"}]}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ListContourPlot", "[", 
          RowBox[{"ItotTM", ",", 
           RowBox[{"RegionFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
              RowBox[{"0", "<", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "+", 
                RowBox[{"y", "^", "2"}]}], "<", "1"}]}], "]"}]}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", "Full"}], 
             "}"}]}], ",", 
           RowBox[{"InterpolationOrder", "\[Rule]", "3"}], ",", 
           RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
           RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
           RowBox[{"Contours", "\[Rule]", "ContoursSP"}], ",", 
           RowBox[{"ContourStyle", "\[Rule]", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ColorData", "[", "\"\<SolarColors\>\"", "]"}], "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "1"}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"NContSP", "-", "1"}], ")"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "1", ",", "NContSP"}], "}"}]}], "]"}]}]}], 
          "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", "#1", 
           "]"}], "&"}], ",", "20", ",", 
         RowBox[{"ToString", "[", "MaxVSP", "]"}], ",", 
         RowBox[{"ToString", "[", "MinVSP", "]"}], ",", 
         RowBox[{"LegendPosition", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"-", "0.75"}]}], "}"}]}], ",", 
         RowBox[{"LegendShadow", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendBorder", "\[Rule]", "None"}], ",", 
         RowBox[{"LegendSize", "\[Rule]", "1.5"}], ",", 
         RowBox[{"LegendBorderSpace", "\[Rule]", "0.1"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"P1", ",", "P2", ",", "P3", ",", "P4"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.532082019235787*^9, 3.5320820349713573`*^9}, {
   3.532082322490747*^9, 3.532082332593883*^9}, {3.532088617438347*^9, 
   3.5320886387728043`*^9}, {3.532111994058914*^9, 3.532112147887659*^9}, {
   3.532112417710577*^9, 3.532112456333234*^9}, {3.5321125284039373`*^9, 
   3.532112597290176*^9}, 3.532112653171301*^9, {3.532112714037202*^9, 
   3.532112732596943*^9}, {3.532112809163021*^9, 3.5321128110975657`*^9}, {
   3.532112844394051*^9, 3.5321128474724894`*^9}, {3.532112996204665*^9, 
   3.532113003035262*^9}, {3.532113047313781*^9, 3.532113076164485*^9}, {
   3.532113205631452*^9, 3.5321132082368813`*^9}, {3.532114077565645*^9, 
   3.53211409016395*^9}, {3.53211455026978*^9, 3.532114553963818*^9}, {
   3.53211478286127*^9, 3.532114793107601*^9}, {3.532114848566669*^9, 
   3.532114872947755*^9}, {3.532114974595973*^9, 3.532115006175384*^9}, {
   3.5321153292312202`*^9, 3.53211535524557*^9}, {3.532115393715624*^9, 
   3.532115395818391*^9}, {3.5321158209912987`*^9, 3.532115837199778*^9}, 
   3.53211642034958*^9, {3.53211645745471*^9, 3.532116541898827*^9}, {
   3.532118716862348*^9, 3.532118852180031*^9}, {3.53211888246356*^9, 
   3.53211888426153*^9}, {3.532119909061564*^9, 3.532119918132997*^9}, 
   3.532151498358191*^9, 3.5321515286527977`*^9, 3.5321659049876423`*^9, {
   3.532166138874308*^9, 3.5321661786239243`*^9}, {3.532166380277111*^9, 
   3.53216638953551*^9}, {3.532166423187047*^9, 3.532166423336441*^9}, {
   3.532166706523076*^9, 3.532166709140696*^9}, {3.532166743721134*^9, 
   3.53216674402715*^9}, {3.532176561738065*^9, 3.532176850554895*^9}, {
   3.532176886475889*^9, 3.5321771562291517`*^9}, {3.5321771920872173`*^9, 
   3.53217731860979*^9}, {3.532177351959427*^9, 3.532177352223207*^9}, {
   3.5321889540178127`*^9, 3.532188990765874*^9}, {3.532190935583757*^9, 
   3.532190950708104*^9}, {3.532191103262259*^9, 3.532191125274177*^9}, 
   3.532192523187934*^9, {3.532192573891185*^9, 3.532192574717001*^9}, 
   3.532192654800736*^9, {3.5321927042823267`*^9, 3.532192704620072*^9}, {
   3.532194878808981*^9, 3.5321948957108727`*^9}, {3.5321953310948133`*^9, 
   3.532195336575502*^9}, {3.5321956871500893`*^9, 3.532195724940546*^9}, {
   3.5321990477489443`*^9, 3.532199063557231*^9}, {3.532235098841626*^9, 
   3.532235170816842*^9}, {3.532235588289168*^9, 3.5322356053587008`*^9}, {
   3.532240621547387*^9, 3.532240656748625*^9}, {3.5322409040897303`*^9, 
   3.532240986236053*^9}, {3.5322410490660057`*^9, 3.5322410735413427`*^9}, 
   3.5322411629703197`*^9, 3.532241710642879*^9, {3.5322419899092493`*^9, 
   3.532242022806869*^9}, {3.5322593895763617`*^9, 3.532259391620164*^9}, 
   3.53225943266063*^9, 3.532259872446707*^9, {3.5322600568504457`*^9, 
   3.5322600848166323`*^9}, {3.532260144521873*^9, 3.532260166883828*^9}, {
   3.532260284188095*^9, 3.5322602903128567`*^9}, {3.5322604968589287`*^9, 
   3.532260501667817*^9}, {3.5322605551480103`*^9, 3.5322605561077557`*^9}, {
   3.53226059159872*^9, 3.5322605981850033`*^9}, {3.532260647913005*^9, 
   3.5322607093805513`*^9}, {3.532260827827821*^9, 3.5322608303558817`*^9}, {
   3.532260877032058*^9, 3.532260879522472*^9}, {3.53226116601857*^9, 
   3.5322611972254953`*^9}, 3.532261620597068*^9, {3.532262297473366*^9, 
   3.532262299054072*^9}, {3.532262823501758*^9, 3.532262823948121*^9}, {
   3.532262936219536*^9, 3.5322629427014847`*^9}, {3.532262990722331*^9, 
   3.532262997202491*^9}, {3.5322630901024942`*^9, 3.532263093034919*^9}, {
   3.532263278839402*^9, 3.53226328218615*^9}, {3.5322636575118847`*^9, 
   3.5322636767206383`*^9}, {3.5322640376746283`*^9, 
   3.5322640445619802`*^9}, {3.532264122856711*^9, 3.532264133416081*^9}, {
   3.532264222403949*^9, 3.532264228992378*^9}, 3.532264720368807*^9, {
   3.532264797433514*^9, 3.5322648632114563`*^9}, {3.5322649204383802`*^9, 
   3.5322649272267723`*^9}, {3.532265323314404*^9, 3.532265330373959*^9}, {
   3.5322653649633427`*^9, 3.5322653657487926`*^9}, {3.532265699322712*^9, 
   3.532265774141108*^9}, {3.532265949223422*^9, 3.532266010482649*^9}, {
   3.532266164234878*^9, 3.532266164398573*^9}, {3.532266353183302*^9, 
   3.532266386598404*^9}, {3.53226649472233*^9, 3.532266541624124*^9}, {
   3.5322667705267887`*^9, 3.5322667712907743`*^9}, {3.532275474708603*^9, 
   3.53227547487607*^9}, {3.532280764759893*^9, 3.532280765032751*^9}, 
   3.5322818065751743`*^9, {3.532284655726035*^9, 3.532284684847742*^9}, {
   3.532284763753192*^9, 3.532284764015036*^9}, {3.53228482406889*^9, 
   3.532284832545689*^9}, {3.5322849549773397`*^9, 3.5322849552449636`*^9}, {
   3.5322852469251347`*^9, 3.5322852479711103`*^9}, {3.5322853181272297`*^9, 
   3.5322853188364477`*^9}, {3.53228567665946*^9, 3.532285681496481*^9}, {
   3.532285725909437*^9, 3.5322858010993023`*^9}, {3.532286106595758*^9, 
   3.532286116480391*^9}, {3.53228646888904*^9, 3.532286469182426*^9}, {
   3.532286536700522*^9, 3.5322865552710667`*^9}, {3.5322881295485287`*^9, 
   3.53228813286528*^9}, 3.532327008379521*^9, {3.5323271114407167`*^9, 
   3.532327111687046*^9}, 3.532327850482483*^9, {3.532328695188064*^9, 
   3.532328698148809*^9}, 3.532426257247923*^9, {3.5324286819546432`*^9, 
   3.532428693678549*^9}, {3.532428996034226*^9, 3.532428996313765*^9}, {
   3.532429186426215*^9, 3.53242918868997*^9}, {3.532429665598234*^9, 
   3.532429692804357*^9}, {3.5324300314802837`*^9, 3.532430031720591*^9}, 
   3.532430601514634*^9, {3.532462269384609*^9, 3.532462284818416*^9}, {
   3.532462357665565*^9, 3.5324623585537148`*^9}, {3.532462785341126*^9, 
   3.532462785778338*^9}, {3.5324628435572233`*^9, 3.532463018951808*^9}, {
   3.532463063323386*^9, 3.5324631870051327`*^9}, {3.5324632727212152`*^9, 
   3.53246353287836*^9}, 3.5324645113633966`*^9, {3.532464551065888*^9, 
   3.5324645943744164`*^9}, {3.532464651540078*^9, 3.532464660495504*^9}, {
   3.53246481182222*^9, 3.532464834542893*^9}, {3.53246494902564*^9, 
   3.5324649796009407`*^9}, {3.532465179700041*^9, 3.532465204272888*^9}, {
   3.5324653797590218`*^9, 3.5324654348145123`*^9}, {3.532465549449143*^9, 
   3.532465559348528*^9}, {3.53246563972381*^9, 3.532465651792583*^9}, {
   3.532465749249773*^9, 3.532465785996861*^9}, 3.532503938731542*^9, {
   3.532507094908676*^9, 3.53250710068748*^9}, {3.5325072740583687`*^9, 
   3.532507278039267*^9}, {3.532508500071204*^9, 3.532508540889377*^9}, {
   3.532508579019844*^9, 3.5325087221514063`*^9}, 3.532508770026146*^9, {
   3.532509088930051*^9, 3.532509091265554*^9}, {3.532513854978648*^9, 
   3.532513860033011*^9}, {3.5325138949385147`*^9, 3.532513915800434*^9}, 
   3.5325176176711884`*^9, 3.532519006147437*^9, 3.5325200753485107`*^9, {
   3.5325216320503597`*^9, 3.532521666924562*^9}, {3.532521828873268*^9, 
   3.532521829140736*^9}, 3.5325269339672527`*^9, {3.532684904710631*^9, 
   3.5326849492200193`*^9}, 3.5326910280431967`*^9, 3.532693088582265*^9, 
   3.5327116828737183`*^9, {3.5327174167034807`*^9, 3.5327174231046057`*^9}, {
   3.532717711453409*^9, 3.532717718558906*^9}, {3.532719062931047*^9, 
   3.532719066498788*^9}, {3.532719180449216*^9, 3.5327191830716352`*^9}, {
   3.532755835415242*^9, 3.532755843456418*^9}, {3.532854775247805*^9, 
   3.532854797919425*^9}, {3.532890326904924*^9, 3.532890340585086*^9}, {
   3.533111824823041*^9, 3.533111838957677*^9}, {3.533118267394972*^9, 
   3.533118267763967*^9}, {3.533127221368281*^9, 3.533127221695479*^9}, {
   3.533128786582285*^9, 3.53312880658908*^9}, {3.533148573702444*^9, 
   3.533148584569018*^9}, 3.533203441744689*^9, {3.533217548318079*^9, 
   3.533217548501123*^9}, {3.554281406976404*^9, 3.554281412879291*^9}, {
   3.554281443265378*^9, 3.5542814473927717`*^9}, {3.564113957917429*^9, 
   3.56411399699061*^9}, {3.5641140271167393`*^9, 3.5641140340643187`*^9}, {
   3.564114878906653*^9, 3.564114899336872*^9}, {3.564118360708213*^9, 
   3.564118407006666*^9}, {3.564118468158392*^9, 3.564118497725514*^9}, {
   3.56411853577986*^9, 3.56411853992004*^9}, {3.564121462517626*^9, 
   3.564121493469344*^9}, {3.577294654567284*^9, 3.577294661083355*^9}, {
   3.577294840185989*^9, 3.577294849012993*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"z", ",", 
    RowBox[{"y", "/", "x"}], ",", 
    RowBox[{"|", "S", 
     SuperscriptBox["|", "2"]}]}], "}"}], "-", 
  RowBox[{"Export", " ", "XZ", " ", "or", " ", "YZ"}], "-", 
  RowBox[{"Planes", " ", 
   RowBox[{"to", " ", ".", "dat"}], " ", "files"}]}]], "Input",
 CellChangeTimes->{{3.532430814320787*^9, 3.5324308263608227`*^9}, {
  3.5324309659018173`*^9, 3.532430988579377*^9}, {3.5325215684407988`*^9, 
  3.532521602954556*^9}, {3.5327996578292*^9, 3.532799658133326*^9}, {
  3.554280957032215*^9, 3.55428096164752*^9}},
 FontSize->14,
 Background->RGBColor[1, 0.5, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/NRe3_R30lambda635n146_E2inc.dat\>\"", ",", 
   "ItotIM", ",", "\"\<Table\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/NRe3_R30lambda635n146_E2tot.dat\>\"", ",", 
   "ItotTM", ",", "\"\<Table\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/NRe3_R30lambda635n146_E2sca.dat\>\"", ",", 
   "ItotSM", ",", "\"\<Table\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/NRe3_R30lambda635n146_S2tot.dat\>\"", ",", 
   "STot2M", ",", "\"\<Table\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/NRe3_R30lambda635n146_S2sca.dat\>\"", ",", "SS2M", 
   ",", "\"\<Table\>\""}], "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0ltIkwEUB/BtZXSZYJgyQWSTzBUhKaahpn5hOctCXZRb8zZK9KEtygzJ
rYs6RtKwmBdCgkk65zVkxHpIp4wuuMyJq7kkr236TWdTm5uBds73cPg9nT9/
OIcjlubdYtBotDgYlH18zGHIJQmmyL6CviyP9KDmGYcfZa8lh70H90/3Uza1
TSUNgnWuqGR008W3oEGROxMot9idNwRKVQl81FdS6QzKI4mEmKpl1N5r/RwM
LgmPfEHrxhvq2WChokWFWh/QFk+Ar+QblOKIfa7TYA/XSKl4GzeSCJb65JRX
P3BsmWDL6BRlaD0ZXQHGKr/Ho2b1oV0mnyQmc4op5wP2mH0PSYK3FfoNNfpT
Lm9UQ8+7rZT5XW2aheckYYux6lCuRZrvBkVigQBV9tBXA1Ukoa+xU44PeASx
4BlhvRAVLrtr0sAr9MRaVNra/CsdzFZPzKDXvEe1ElDJ0OrQtqGfvWjfyXd9
6KmaKM0TzNmapQwOnJ1rBmXme/Ook1/rRA+Lq5ZQ8kbgzW6QJQ0rQwcEBdo+
UNI/SjlpsRzQg+dVkoNoREuBt/sFScRfL9tGWUozfQ4szTUx0OoSdUVnE0mM
PXtThWYUrsgGwdv0dDnKtW2vd7ZD/7nwTbThRyNDB97nrFKqhmd5LjD1UlIW
mt2xk+AHX68VJaJlIf8yoztIotXziYfeaX/0N0QLvdaZXrTSMJp5AXyskfPQ
9ZyvVrcR7qXYO43aePaujGHYK1roRllmmfci2Plx0YcaAnSiXTDF11iAxvNk
4mMjJFFuMFH+5g+txYKsfs0f9Gm4LPUcOOHRp6ESddZZhwn+U1ROoP8B38O1
ow==
  "]],

Cell[BoxData["\<\"/Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PS_R600lambda532n133_E2inc.dat\"\>"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+Ij2zom/a5+5fjB6fSNLzWvHN99WXRHsfaVo82rpTrv
el85+q00nPodSPfNP/aet++V4xunzukmQJrr55dASyD9wpTlFphWTd7oAqQ/
fVtzvABIz7HtjWoF0tPnBpztAdIGPybXzwLSUT1zJ68F0jdW9VzeAKSdWG8+
2Q6kD+znzFk38ZVjkAc/70MgfUxirQyI9v0erLt+2ivHtG8FrNeBdFzrHa5V
S185spS3fVwLpE9cemK7F0hv2Jm36zuQrpnr+pFj2StHPgU/YVMg7TpBIVVl
+SvHtrnyhkVAOm/fzpD3B145qqSJBHkdfOV4cq75jgAgnaXMf+UnkLYoOxAg
cOiVo+OjTXnaQLqoI3yeGZBe2WbP5QykAVp+p0Y=
  "]],

Cell[BoxData["\<\"/Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PS_R600lambda532n133_E2tot.dat\"\>"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+Ij2zom/a5+5fjB6fSNLzWvHN99WXRHsfaVo82rpTrv
el85+q00nPodSPfNP/aet++V4xunzukmQJrr55dASyD9wpTlFphWTd7oAqQ/
fVtzvABIz7HtjWoF0tPnBpztAdIGPybXzwLSUT1zJ68F0jdW9VzeAKSdWG8+
2Q6kD+znzFk38ZVjkAc/70MgfUxirQyI9v0erLt+2ivHtG8FrNeBdFzrHa5V
S185spS3fVwLpE9cemK7F0hv2Jm36zuQrpnr+pFj2StHPgU/YVMg7TpBIVVl
+SvHtrnyhkVAOm/fzpD3B145qqSJBHkdfOV4cq75jgAgnaXMf+UnkLYoOxAg
cOiVo+OjTXnaQLqoI3yeGZC2sszhcgbSAFX5prc=
  "]],

Cell[BoxData["\<\"/Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PS_R600lambda532n133_E2sca.dat\"\>"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+Ij2zom/a5+5fjB6fSNLzWvHN99WXRHsfaVo82rpTrv
el85+q00nPodSPfNP/aet++V4xunzukmQJrr55dASyD9wpTlFphWTd7oAqQ/
fVtzvABIz7HtjWoF0tPnBpztAdIGPybXzwLSUT1zJ68F0jdW9VzeAKSdWG8+
2Q6kD+znzFk38ZVjkAc/70MgfUxirQyI9v0erLt+2ivHtG8FrNeBdFzrHa5V
S185spS3fVwLpE9cemK7F0hv2Jm36zuQrpnr+pFj2StHPgU/YVMg7TpBIVVl
+SvHtrnyhkVAOm/fzpD3B145qqSJBHkdfOV4cq75jgAgnaXMf+UnkLYoOxAg
cOiVo+OjTXnaQLqoI3yeGZBm+DKLyxlIAwBaWqdm
  "]],

Cell[BoxData["\<\"/Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PS_R600lambda532n133_S2tot.dat\"\>"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+Ij2zom/a5+5fjB6fSNLzWvHN99WXRHsfaVo82rpTrv
el85+q00nPodSPfNP/aet++V4xunzukmQJrr55dASyD9wpTlFphWTd7oAqQ/
fVtzvABIz7HtjWoF0tPnBpztAdIGPybXzwLSUT1zJ68F0jdW9VzeAKSdWG8+
2Q6kD+znzFk38ZVjkAc/70MgfUxirQyI9v0erLt+2ivHtG8FrNeBdFzrHa5V
S185spS3fVwLpE9cemK7F0hv2Jm36zuQrpnr+pFj2StHPgU/YVMg7TpBIVVl
+SvHtrnyhkVAOm/fzpD3B145qqSJBHkdfOV4cq75jgAgnaXMf+UnkLYoOxAg
cOiVo+OjTXnaQLqoI3yeGZB+s/E4lzOQBgBg86g8
  "]],

Cell[BoxData["\<\"/Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PS_R600lambda532n133_S2sca.dat\"\>"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+Ij2zom/a5+5fjB6fSNLzWvHN99WXRHsfaVo82rpTrv
el85+q00nPodSPfNP/aet++V4xunzukmQJrr55dASyD9wpTlFphWTd7oAqQ/
fVtzvABIz7HtjWoF0tPnBpztAdIGPybXzwLSUT1zJ68F0jdW9VzeAKSdWG8+
2Q6kD+znzFk38ZVjkAc/70MgfUxirQyI9v0erLt+2ivHtG8FrNeBdFzrHa5V
S185spS3fVwLpE9cemK7F0hv2Jm36zuQrpnr+pFj2StHPgU/YVMg7TpBIVVl
+SvHtrnyhkVAOm/fzpD3B145qqSJBHkdfOV4cq75jgAgnaXMf+UnkLYoOxAg
cOiVo+OjTXnaQLqoI3yeGZDu6vvC5QykAV38p+Q=
  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Plot", " ", "generated", " ", 
  RowBox[{"Data", ":", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "z"], ",", 
       SubscriptBox["S", "x"]}], "}"}], " ", "/", " ", "ZX"}], "-", 
    "Plane"}]}]}]], "Input",
 CellChangeTimes->{{3.532430814320787*^9, 3.5324308263608227`*^9}, {
  3.5324309659018173`*^9, 3.532430988579377*^9}, {3.532526572998685*^9, 
  3.532526573726693*^9}, {3.5542811814007187`*^9, 3.554281187216064*^9}},
 FontSize->14,
 Background->RGBColor[1, 0.5, 0]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VP1x", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecM", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(tot\)]\),\!\(\*SubsuperscriptBox[\(S\), \(x\), \(tot\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VP1Sx", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecMS", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Blue"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(sca\)]\),\!\(\*SubsuperscriptBox[\(S\), \(x\), \(sca\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VP1Ix", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecMI", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(inc\)]\),\!\(\*SubsuperscriptBox[\(S\), \(x\), \(inc\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VP2x", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecMSP", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{"0", "<", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "1"}]}], "]"}]}]}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(sp\)]\),\!\(\*SubsuperscriptBox[\(S\), \(x\), \(sp\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"VP1x", ",", "VP1Sx", ",", "VP1Ix", ",", "VP2x"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1050"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.532264956992012*^9, 3.532264981474468*^9}, {
   3.532265108711255*^9, 3.532265145008803*^9}, {3.532265388680956*^9, 
   3.532265431191146*^9}, {3.532265483501107*^9, 3.532265532252995*^9}, {
   3.532265789429961*^9, 3.532265819885236*^9}, {3.532266145498715*^9, 
   3.532266155947565*^9}, {3.5322662999431667`*^9, 3.532266336508833*^9}, {
   3.532266568638742*^9, 3.5322665788300943`*^9}, {3.5322666672154083`*^9, 
   3.5322666676032953`*^9}, {3.532267117183426*^9, 3.5322671261862907`*^9}, {
   3.532267195157434*^9, 3.5322673625795393`*^9}, {3.5322682683716717`*^9, 
   3.5322683390842037`*^9}, 3.532268371783064*^9, 3.53227031612687*^9, {
   3.532326975171595*^9, 3.532326982522382*^9}, {3.532327093239863*^9, 
   3.5323271030567417`*^9}, {3.532425990523096*^9, 3.532426047841234*^9}, {
   3.5641150482623987`*^9, 3.5641150594100227`*^9}}],

Cell[BoxData[{
 RowBox[{"ListVectorPlot", "[", 
  RowBox[{"ItotSVecMDiff", ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"VectorScale", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Automatic", ",", "None"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<z/R\>\"", ",", 
        "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(tot\)]\),\!\(\*SubsuperscriptBox[\(S\), \(x\), \(tot\)]\)}\>\""}], "}"}]}], 
     "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListVectorPlot", "[", 
  RowBox[{"ItotSVecMDiff", ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<z/R\>\"", ",", 
        "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(tot\)]\),\!\(\*SubsuperscriptBox[\(S\), \(x\), \(tot\)]\)}\>\""}], "}"}]}], 
     "}"}]}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", 
        RowBox[{"y", "^", "2"}]}], ">", "1.1"}]}], "]"}]}]}], "]"}]}], "Input",\

 CellChangeTimes->{{3.577293644508748*^9, 3.577293648273093*^9}, {
  3.577294901859701*^9, 3.577294910842214*^9}, {3.577295206851693*^9, 
  3.577295207123014*^9}}],

Cell[BoxData[
 RowBox[{"Plot", " ", "generated", " ", 
  RowBox[{"Data", ":", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "z"], ",", 
       SubscriptBox["S", "y"]}], "}"}], " ", "/", " ", "ZY"}], "-", 
    "Plane"}]}]}]], "Input",
 CellChangeTimes->{{3.532430814320787*^9, 3.532430851832561*^9}, {
   3.532430976406941*^9, 3.532430984821843*^9}, {3.532526567700533*^9, 
   3.532526568829319*^9}, 3.554281190353518*^9},
 FontSize->14,
 Background->RGBColor[1, 0.5, 0]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VP1y", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecM", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(tot\)]\),\!\(\*SubsuperscriptBox[\(S\), \(y\), \(tot\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VP1Sy", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecMS", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Blue"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(sca\)]\),\!\(\*SubsuperscriptBox[\(S\), \(y\), \(sca\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VP1Iy", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecMI", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Red"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "rP"}], ",", "rP"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(inc\)]\),\!\(\*SubsuperscriptBox[\(S\), \(y\), \(inc\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VP2y", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"ListStreamPlot", "[", 
      RowBox[{"ItotSVecMSP", ",", 
       RowBox[{"StreamStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"StreamPoints", "\[Rule]", "Fine"}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{"0", "<", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "1"}]}], "]"}]}]}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<y/R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z/R\>\"", ",", 
          "\"\<{\!\(\*SubsuperscriptBox[\(S\), \(z\), \
\(sp\)]\),\!\(\*SubsuperscriptBox[\(S\), \(y\), \(sp\)]\)}\>\""}], "}"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"VP1y", ",", "VP1Sy", ",", "VP1Iy", ",", "VP2y"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1050"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.532264956992012*^9, 3.532264981474468*^9}, {
   3.532265108711255*^9, 3.532265145008803*^9}, {3.532265388680956*^9, 
   3.532265431191146*^9}, {3.532265483501107*^9, 3.532265532252995*^9}, {
   3.532265789429961*^9, 3.532265819885236*^9}, {3.532266145498715*^9, 
   3.532266155947565*^9}, {3.5322662999431667`*^9, 3.532266336508833*^9}, {
   3.532266568638742*^9, 3.5322665788300943`*^9}, {3.5322666672154083`*^9, 
   3.5322666676032953`*^9}, {3.532267117183426*^9, 3.5322671261862907`*^9}, {
   3.532267195157434*^9, 3.5322673625795393`*^9}, {3.5322682683716717`*^9, 
   3.5322683390842037`*^9}, 3.532268371783064*^9, 3.53227031612687*^9, {
   3.532326975171595*^9, 3.532326982522382*^9}, {3.532327017626029*^9, 
   3.5323270255290413`*^9}, {3.532327071285819*^9, 3.532327082160307*^9}, {
   3.5324262211390667`*^9, 3.532426227707692*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EXAMPLES OF RESULTS : AuNP", "Title",
 CellChangeTimes->{{3.5542810471639137`*^9, 3.55428105814813*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "AuNP, R = 30 nm, ",
 StyleBox["\[Lambda]=532nm",
  FontColor->RGBColor[0., 0.5882352941176471, 0.000045777065690089265`]],
 ", nParticle = 0.5163 - 2.2304 I; w0=233nm"
}], "Subsubtitle",
 CellChangeTimes->{{3.532328089689765*^9, 3.532328135651807*^9}, {
  3.532521845057863*^9, 3.532521848633419*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"VP1x", ",", "VP1Sx", ",", "VP1Ix", ",", "VP2x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"VP1y", ",", "VP1Sy", ",", "VP1Iy", ",", "VP2y"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1050"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.532327174821657*^9, 3.532327208396069*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.7258827324744885`}, \
{-5.554342372298548, -2.723157711290033}, {-5.402600826953819, \
-2.718681348897575}, {-5.250499331513853, -2.7136658362449473`}, \
{-5.09822266421236, -2.708035604241689}, {-4.945955603283046, \
-2.701715083797339}, {-4.793746667985855, -2.6946429254556343`}, \
{-4.7130671482449795`, -2.6904604127131173`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689486820013497, -2.689237983233893}, \
{-4.641644377580726, -2.6867577797603115`}, {-4.489784140377019, \
-2.6779309669752323`}, {-4.338301364684092, -2.668033807364258}, \
{-4.1871960505019485`, -2.657066300927389}, {-4.036468197830586, \
-2.645028447664625}, {-3.886117806670005, -2.631920247575966}, \
{-3.7477155363557793`, -2.6188355989842953`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.724216946207758, -2.6165258366264577`}, \
{-3.586549408881189, -2.6024928069209636`}, {-3.4373314022529535`, \
-2.5861735663546197`}, {-3.30440916503543, -2.5706796206146993`}, \
{-3.1721409199858823`, -2.554328581823486}, {-2.9996607290778132`, \
-2.5315057099461153`}, {-2.8285137413811303`, -2.507087188481996}, \
{-2.7869684065082856`, -2.500722761406635}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.763628692281207, -2.4971472959635803`}, \
{-2.6586999568958327`, -2.4810730174311293`}, {-2.490219375621921, \
-2.4534631967935137`}, {-2.4680613948966967`, -2.4497122812788863`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.3376355012390193`, \
-2.426709653861704}, {-2.230044163004424, -2.407084335910441}, \
{-2.0179372208922164`, -2.367742380142585}, {-1.8336994917335223`, \
-2.332408674776952}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.810510109889434, -2.327961340403956}, \
{-1.8092313086539404`, -2.3277160877823433`}, {-1.6039264262895965`, \
-2.2870054588297157`}, {-1.4020225737991843`, -2.2456104932847025`}, \
{-1.2686795189039406`, -2.218318586290151}, {-1.1368317487242705`, \
-2.1923516373230107`}, {-1.0064792632601742`, -2.1677096463832815`}, \
{-0.8838481996122539, -2.1455192485588586`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.860568676631442, -2.1415740361654274`}, \
{-0.7495926951957734, -2.123231967034331}, {-0.621723710029609, \
-2.1050591355216626`}, {-0.49401510701315887`, -2.089874118932957}, \
{-0.3664668861464224, -2.0776769172682137`}, {-0.21130982107580878`, \
-2.0666266086024665`}, {-0.05303047693094798, -2.0592701093648524`}, {
             0.07900669393986165, -2.055015933264402}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.10260644068597195`, -2.0542555604245276`}, {
             0.1091470405398795, -2.0540448253459314`}, {
             0.2759986255883926, -2.049388162336262}, {
             0.44718252978773754`, -2.043320987845238}, {
             0.6223570047110585, -2.033864169382252}, {
             0.8183536893791579, -2.018212719931461}, {
             1.0159398502305226`, -1.9958316612833071`}, {
             1.0444715663615904`, -1.991709807004067}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.067840955112228, -1.9883337319519199`}, {
             1.2133595953379224`, -1.9673112800542454`}, {
             1.4088570327741277`, -1.933241862860729}, {
             1.6019447199812353`, -1.8951511839974977`}, {
             1.7917452603550172`, -1.8557892371950833`}, {
             1.9953176934664092`, -1.8113874681763968`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0184068400863544`, -1.8064464487893155`}, {
             2.210608757173824, -1.7656685317650698`}, {
             2.417069586332647, -1.725070516338442}, {
             2.6231766986151346`, -1.6882000612331913`}, {
             2.8297602952090672`, -1.6554215428598902`}, {
             2.9476598498609614`, -1.6389962687213293`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9710459839408045`, -1.6357382100760978`}, {
             3.037394971302668, -1.6264947459302643`}, {
             3.246528943639516, -1.601343414992275}, {
             3.4571421635045234`, -1.5798499075531178`}, {
             3.691271585387438, -1.559561812731644}, {
             3.910815432959631, -1.5434384930745901`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9343702973723835`, -1.5418030680353974`}, {
             4.164680302398195, -1.5278882438167276`}, {
             4.403959597526039, -1.5165027697232851`}, {
             4.644330104830384, -1.5074488051259156`}, {
             4.877879883243741, -1.5003129510725426`}}]}, 
           {Arrowheads[{{0.01599777980481206, 1.}}], 
            ArrowBox[{{4.901483982888196, -1.4997073697860415`}, {
             5.1264685192531605`, -1.4944273121795841`}, {
             5.368236426371591, -1.4904597838306222`}, {
             5.610105394753718, -1.4879275757953643`}, {
             5.656854249492381, -1.4876364402349234`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.727640092549523}, {-5.477180375056137, 
             2.7227007985142184`}, {-5.267760611297326, 
             2.7158982132353864`}, {-5.058251709330639, 
             2.707764905086284}, {-4.848653669156075, 
             2.6983008740669114`}, {-4.713103731394536, 2.691322725812069}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689522964817118, 
             2.6901087814321794`}, {-4.638966490773636, 
             2.6875061201772685`}, {-4.487236817172735, 
             2.6786706657129824`}, {-4.335885146806337, 
             2.6687665149927726`}, {-4.18491147967444, 
             2.657793668016639}, {-4.034315815777046, 
             2.6457521247845817`}, {-3.884098155114155, 
             2.6326418852966005`}, {-3.7477499224306445`, 
             2.619739607867553}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7242501442589497`, 
             2.617441927198839}, {-3.5847968434918798`, 
             2.6032153175528667`}, {-3.4357131925324955`, 
             2.586898989297114}, {-3.3028391851162744`, 
             2.5714004589585406`}, {-3.170619094056359, 
             2.5550453097984884`}, {-2.9981700162383924`, 
             2.5322134180853566`}, {-2.8270548784278353`, 
             2.507786241289595}, {-2.7870003123753424`, 2.501647054903567}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.763660871526249, 
             2.4980698053752497`}, {-2.657273680624688, 
             2.481763779411203}, {-2.488826422828951, 
             2.454146032450182}, {-2.4666730829740313`, 
             2.45039412697285}, {-2.444546998600464, 
             2.446612201231679}, {-2.3362956001278334`, 
             2.4273974782587158`}, {-2.228748185667102, 
             2.407779973588095}, {-2.0171919426843927`, 
             2.3685432803378355`}, {-1.83372518890194, 2.33336644115213}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8105355965154548`, 
             2.328920204734121}, {-1.809019672217544, 
             2.328629550301392}, {-1.6042313742665564`, 
             2.288038783478763}, {-1.4028270488314298`, 
             2.2467709798699502`}, {-1.2694426636368847`, 
             2.2194895649335082`}, {-1.1375533397445736`, 
             2.1935330605051657`}, {-1.0071590771544965`, 
             2.168901466584923}, {-0.8838487623207866, 
             2.1466053278923085`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8605670553159587, 
             2.142672799472281}, {-0.7501885253403997, 
             2.1244436954947945`}, {-0.6222778150350896, 
             2.106278888777023}, {-0.4945277449507233, 
             2.0911003630194673`}, {-0.3669383150873008, 
             2.078908118222126}, {-0.21166695205316902`, 
             2.0678584548241443`}, {-0.05327409307077627, 
             2.0605047338212326`}, {0.07902267036568658, 
             2.0562491232971185`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.10262245686556981`, 2.055489985301698}, {
             0.10901681067368846`, 2.0552842971302425`}, {0.2759823079940363, 
             2.050634486668026}, {0.4472810028227375, 2.0445760004730285`}, {
             0.6225714990922612, 2.035129536583695}, {0.818718931709284, 
             2.019489438843576}, {1.0164582567198703`, 1.9971204257938384`}, {
             1.044498538030789, 1.9930745988738656`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0678685198932318`, 1.9897026319278162`}, {
             1.2140341207263552`, 1.9686129461266118`}, {1.409691170331073, 
             1.9345574485340242`}, {1.602941510825617, 1.8964822886072756`}, {
             1.7929069317348525`, 1.857138506410526}, {1.995398649926253, 
             1.8130335276431717`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.018487626842039, 1.8080917516466906`}, {
             2.212285176733214, 1.7670363691682076`}, {2.419008102837723, 
             1.7264528751346737`}, {2.625380337962202, 1.6895999673297826`}, {
             2.8322317295806054`, 1.656841613352714}, {2.947766579926899, 
             1.640778844125472}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9711536277712334`, 1.6375273511663864`}, {
             3.040136178784409, 1.6279367315887445`}, {3.249540683904747, 
             1.6028083226871883`}, {3.4604243270842807`, 
             1.5813384253025413`}, {3.695285990619107, 1.561040526346681}, {
             3.9109247757111865`, 1.5452526843561971`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.9344759929198694`, 1.5435623709916606`}, {
             4.170166591593133, 1.5293751445724575`}, {4.410185529032332, 
             1.5180076617540943`}, {4.651292702611556, 1.5089780332468994`}, {
             4.877986683894371, 1.5020985831602167`}}]}, 
           {Arrowheads[{{0.015995543929493514`, 1.}}], 
            ArrowBox[{{4.901589467205171, 1.501444110480709}, {
             5.13487919270579, 1.4960154859620205`}, {5.377358509220796, 
             1.4920825671843365`}, {5.61992909171833, 1.4895874181196953`}, {
             5.656854249492381, 1.4893630927342854`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.0005287284754555529}, {-5.598579074524613, 
             0.0005283705160645417}, {-5.46216154459498, 
             0.0005275325617218242}, {-5.3257440146653465`, 
             0.0005266946073791066}, {-5.189326484735713, 
             0.0005258566530363891}, {-5.05290895480608, 
             0.0005250186986936715}, {-4.916491424876447, 
             0.0005241807443509541}, {-4.780073894946813, 
             0.0005233427900082366}, {-4.712374529591418, 
             0.0005229269418600694}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688762536593894, 
             0.0005227819035201823}, {-4.64365636501718, 
             0.000522504835665519}, {-4.504298225430266, 
             0.0005155189627766216}, {-4.340790455367233, 
             0.0005124766447022828}, {-4.177152756513301, 
             0.000508985379295994}, {-3.966398145321094, 
             0.0005037095286635799}, {-3.755070344366212, 
             0.0004974679257546722}, {-3.744282817081357, 
             0.0004970923092050624}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.720670824097701, 
             0.0004962701508827947}, {-3.5427180455083054`, 
             0.0004900739200949409}, {-3.328889940607026, 
             0.00048134086121005593`}, {-3.30060516617349, 
             0.0004801013824479622}, {-3.2722812971779383`, 
             0.00047883379244347945`}, {-3.136084867403018, 
             0.00047195477783715906`}, {-2.9984819438385446`, 
             0.00046427091573581565`}, {-2.86402526342497, 
             0.0004562733319341798}, {-2.776191105341343, 
             0.000450426839455732}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525791123956815`, 
             0.0004488551577527374}, {-2.72708918709517, 
             0.00044715847550750264`}, {-2.587673714849144, 
             0.00043692634645578406`}, {-2.4457788466868924`, 
             0.0004255769447790242}, {-2.245391485602008, 
             0.0004074468724309512}, {-2.0343860032074126`, 
             0.00038551561865981897`}, {-1.8763444748966778`, 
             0.00036709668402245307`}, {-1.8080993969557222`, 
             0.00035835578654642877`}}]}, 
           {Arrowheads[{{0.016908606146064036`, 1.}}], 
            ArrowBox[{{-1.784487404151427, 
             0.0003553315390177567}, {-1.7076306188950718`, 
             0.0003454876455014529}, {-1.5769352502984835`, 
             0.00032755469164583926`}, {-1.4358094199335416`, 
             0.00030721348172792526`}, {-1.1943764947846027`, 
             0.000272574687234242}, {-1.1269676175859888`, 
             0.00026349226427769813`}, {-1.0557728399804303`, 
             0.0002550121826245387}, {-1.037350715641599, 
             0.0002530658832981709}, {-1.01867089556824, 
             0.0002512439056131741}, {-1.0021912208074097`, 
             0.0002497365168740818}, {-0.9940637278956569, 
             0.0002490094652869665}, {-0.9900056676134553, 
             0.0002486446582408885}, {-0.9859956315530888, 
             0.0002482829829825745}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.261888407061696}, \
{-5.4557627083879705`, -4.254124326397431}, {-5.233793034182097, \
-4.244624619699242}, {-5.0111339664151, -4.234010432072969}, \
{-4.788007613457506, -4.222132003323587}, {-4.713431866072334, \
-4.217634149735627}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689862701802474, -4.2162126333071175`}, \
{-4.564587432081669, -4.208656962178726}, {-4.34108580033848, \
-4.193399026227895}, {-4.117783208516266, -4.176427568568881}, \
{-3.8949601469033546`, -4.157811962299474}, {-3.748172509170802, \
-4.144290983563797}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7246600537321704`, -4.142125192118958}, \
{-3.672998265243975, -4.137366494762792}, {-3.4521982857176337`, \
-4.115109521905691}, {-3.2327193072655716`, -4.0914165197315615`}, \
{-3.0147204288290297`, -4.066662964243796}, {-2.7986559443775185`, \
-4.041051858756695}, {-2.785802112566012, -4.039481863608998}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7623643033126575`, -4.036619118293825}, \
{-2.5847439918579314`, -4.014924184735832}, {-2.372789436177584, \
-3.988862385411506}, {-2.1625971422437917`, -3.9634489040140197`}, \
{-1.9907026118007236`, -3.9435680676384792`}, {-1.824450266436603, \
-3.9255568868762762`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8009590044868122`, -3.923173503322655}, \
{-1.64984328324987, -3.908095427820343}, {-1.4822884065789115`, \
-3.890953963753205}, {-1.314869577265706, -3.8761660134719356`}, \
{-1.1479935034170323`, -3.863284559488686}, {-0.9816601850328893, \
-3.852309601803457}, {-0.8597963014827719, -3.8456438549538885`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8362195518250345, -3.8443542469077974`}, \
{-0.8158696221132764, -3.843241140416248}, {-0.6501600622594399, \
-3.835997221528661}, {-0.48406975307262545`, -3.8304958913422977`}, \
{-0.3175986945528323, -3.8267371498571587`}, {-0.15074688670006042`, \
-3.824720997073243}, {0.08577383282821333, -3.8234190917684585`}, {
             0.10792212593406816`, -3.823356267479493}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1315340239427417, -3.8232892916318995`}, {
             0.3241043445907753, -3.8227430602174635`}, {
             0.5642446485876252, -3.8226929024202585`}, {
             0.8061947448187623, -3.823268618376844}, {
             1.04937567731158, -3.8232458530864317`}, {
             1.0760115149114664`, -3.8230442430476326`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0996228315530743`, -3.822865525992223}, {
             1.2932084900934713`, -3.8214002515482353`}, {
             1.537693183164436, -3.817731813762254}, {
             1.7828297565244746`, -3.812240539728488}, {
             2.0279853353463673`, -3.805218995343994}, {
             2.0438983831386444`, -3.804681541746478}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0674969204301186`, -3.8038845153735936`}, {
             2.2725270448028962`, -3.7969597465058262`}, {
             2.5164548848940607`, -3.787462793213986}, {
             2.759768855619861, -3.7767281354684727`}, {
             2.8871560559193745`, -3.770778221862191}, {
             3.011165015419832, -3.765004129204087}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0347519533158476`, -3.7639166750282183`}, {
             3.145098630747831, -3.758836814822273}, {
             3.2757331662747866`, -3.7529263232407835`}, {
             3.4061432641115177`, -3.747129493283927}, {
             3.5363289242580236`, -3.741446324951704}, {
             3.5537563052603613`, -3.740692502137253}, {
             3.571180567365654, -3.739941515628565}, {
             3.715532138151905, -3.73394661719398}, {
             3.8595886786371616`, -3.7284035998956955`}, {
             3.9783851004691853`, -3.724048539652304}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.001981242827871, -3.723183508366858}, {
             4.018719001556537, -3.722569904468032}, {
             4.177559979834427, -3.7173260062422613`}, {
             4.336111613470831, -3.7126719052183823`}, {
             4.49437390246575, -3.7086076013963964`}, {
             4.6523684470780635`, -3.705125098576366}, {
             4.810116847566653, -3.702216400558355}, {
             4.946162572758063, -3.700199589827223}}]}, 
           {Arrowheads[{{0.014549777911498843`, 1.}}], 
            ArrowBox[{{4.969772073175237, -3.699857396551776}, {
             5.124875216172663, -3.6981204189283896`}, {
             5.279811350470258, -3.6969118957730775`}, {
             5.430353673004479, -3.6962346983330687`}, {
             5.576502183775328, -3.696088826608363}, {
             5.656854249492381, -3.6963073168919323`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.262624383808983}, {-5.458262285074379, 
             4.254963473935781}, {-5.236235627305677, 
             4.245471628366315}, {-5.013516697217935, 
             4.234867223787797}, {-4.790327509924569, 
             4.2229998867315475`}, {-4.713432041560688, 4.218367460846323}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689862779061249, 
             4.216947574030868}, {-4.566840908238233, 
             4.209536347973275}, {-4.34326907281219, 
             4.194289654893177}, {-4.119893025520756, 
             4.177328908929305}, {-3.8969937882382477`, 
             4.158723211519709}, {-3.748172558623381, 4.1450256995995245`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.724659947595512, 
             4.142861597941029}, {-3.6749537380102133`, 
             4.138286636424693}, {-3.4540741677452167`, 
             4.116037279546761}, {-3.234514473112091, 
             4.092350275537257}, {-3.016434049779669, 
             4.067600759047527}, {-2.800287288093421, 
             4.0419906181274134`}, {-2.7858015285330016`, 
             4.040221803554001}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7623636204142943`, 
             4.0373598677833735`}, {-2.5862925826575083`, 
             4.015860338107963}, {-2.3742553355287974`, 
             3.9897929495623226`}, {-2.1639809487641575`, 
             3.964371483063642}, {-1.9920443039432016`, 
             3.944485373372586}, {-1.824446186656112, 3.926326217713772}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8009538238017564`, 
             3.923953397642305}, {-1.651104091106034, 
             3.9089983038183562`}, {-1.4835087624195986`, 
             3.891845008799664}, {-1.31605159870866, 
             3.8770455276304148`}, {-1.1491388228568074`, 
             3.86415207132344}, {-0.9827704348640408, 
             3.8531646398787394`}, {-0.8597907052254671, 
             3.846429614036012}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8362140418128164, 
             3.8451384302137988`}, {-0.8169464347303602, 
             3.844083233296313}, {-0.651205079823271, 
             3.836826686111859}, {-0.4850846275102786, 
             3.8313138328610776`}, {-0.3185850777913828, 
             3.827544673543968}, {-0.151706430666584, 3.8255192081605305`}, {
             0.08509648833192143, 3.824205472958586}, {0.10792789181435869`, 
             3.824140079743141}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13153978796221227`, 3.8240724510573676`}, {
             0.32371188732646083`, 3.8235220358581445`}, {0.5641397663170351, 
             3.823468896859206}, {0.8063801253036441, 3.8240460559617704`}, {
             1.0498527447816515`, 3.824025353176939}, {1.0760172767073457`, 
             3.823827426895088}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0996285941436392`, 3.82364881486094}, {
             1.2939774052464217`, 3.8221786285158132`}, {1.538754106697954, 
             3.8185058819783935`}, {1.7841828491362492`, 
             3.8130071135646793`}, {2.0296287352511513`, 3.805977001466521}, {
             2.0439048153864237`, 3.805494960541935}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.067503359652026, 3.8046981406874023`}, {
             2.274456867732504, 3.79771022387577}, {2.518667246580307, 
             3.7882067807924256`}, {2.762259871794561, 3.7774666722164887`}, {
             2.889730868055376, 3.7715173303970166`}, {3.011173533713818, 
             3.7658675585938703`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.034760453504216, 3.7647797169499615`}, {
             3.1477319293046557`, 3.759583951436275}, {3.278341387677541, 
             3.7536807115596833`}, {3.408726834249435, 3.7478915032243405`}, {
             3.5388882690203376`, 3.7422163264302464`}, {3.5563126330137207`, 
             3.741463590462879}, {3.573733881960737, 3.74071369552351}, {
             3.718166085629589, 3.734723958601564}, {3.862301595003684, 
             3.7291898468808222`}, {3.978394898820163, 3.72494269213582}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.001991106664799, 3.7240794490131175`}, {
             4.020837206364182, 3.723389983737071}, {4.1790856249037045`, 
             3.7181754341669415`}, {4.337046850622253, 3.7135461981704343`}, {
             4.494720883519827, 3.7095022757475484`}, {4.652129397268011, 
             3.7060354606318398`}, {4.80929406553839, 3.703137546556862}, {
             4.946172698561828, 3.7011059989601307`}}]}, 
           {Arrowheads[{{0.014549562206563468`, 1.}}], 
            ArrowBox[{{4.969782259096221, 3.700768457614995}, {
             5.122891865645734, 3.6990484215291013`}, {5.277296732319389, 
             3.697837601956188}, {5.427401223188618, 3.6971564661837446`}, {
             5.573205338253423, 3.6970050142117716`}, {5.656854249492381, 
             3.6972286032194908`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.550923984033479, 0.0055729100908798145`}, {
             1.5716447785088181`, 0.0036945757338144687`}, {
             1.5918410746834792`, 0.0028989941312834526`}, {
             1.6203055965860522`, 0.002298099171029064}, {1.6597909162651436`,
              0.0018462272132732994`}, {1.6844948861935924`, 
             0.0016656679777996228`}, {1.7130449913155832`, 
             0.0015095711956088858`}, {1.8136688963648473`, 
             0.0011816788414542563`}, {1.9515937092733593`, 
             0.0009640857068555671}, {1.962163155518989, 
             0.0009524741819514023}, {1.9729134707370475`, 
             0.0009411799880479147}, {2.0277472843897217`, 
             0.0008962678782496757}, {2.086616676021875, 
             0.0008567578606740268}, {2.2119148504688297`, 
             0.0007866594555026459}, {2.3518088987938417`, 
             0.0007322986426863888}, {2.495292279599178, 
             0.0006926819201121068}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.518904271938079, 0.0006871681142977586}, {
             2.6288610445515626`, 0.0006648337548341789}, {
             2.7589000898407816`, 0.0006445280430958338}, {
             2.8945558708252817`, 0.0006277702050346873}, {3.035140921251295, 
             0.0006132808724187311}, {3.1801316949750444`, 
             0.0006007272699377613}, {3.329098314487033, 
             0.0005903175325226049}, {3.463383985093774, 
             0.0005826215423161262}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.48699597805554, 0.0005813169774782521}, {
             3.636771237666338, 0.0005740576414078852}, {3.7945740622605957`, 
             0.0005675774015775391}, {3.9546546016579094`, 
             0.0005621556657572351}, {4.116629133297334, 
             0.0005575866478852033}, {4.280113934617923, 
             0.000553664561899674}, {4.431475697432468, 
             0.0005506726589200751}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.455087690426295, 0.0005502313235328448}, {
             4.610814872138142, 0.0005475448986149389}, {4.777599236085424, 
             0.0005452127427584983}, {4.945047039210975, 
             0.0005432721538848602}, {5.0973841010772665`, 
             0.0005417678587095357}, {5.249982700840568, 
             0.0005404583152175796}, {5.399567410277066, 
             0.0005393318493969947}}]}, 
           {Arrowheads[{{0.0049482236895981545`, 1.}}], 
            ArrowBox[{{5.423179403274502, 0.00053917328144685}, {
             5.555520368160532, 0.0005383011892884012}, {5.656854249492381, 
             0.0005377308423426365}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.366654719025906}, \
{-5.478299157233761, -1.3638412745635364`}, {-5.27989864743143, \
-1.3601105199014336`}, {-5.0792272223551835`, -1.3555628423684791`}, \
{-4.878328527829216, -1.3501336499492784`}, {-4.712642036082624, \
-1.3448133326041483`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            
            ArrowBox[{{-4.689042206844269, -1.3440555244116075`}, \
{-4.677284514467435, -1.343677976103162}, {-4.4761771328837545`, \
-1.3360508542894611`}, {-4.449373184788325, -1.3349564040805395`}, \
{-4.422569168108892, -1.333838105432456}, {-4.251095618616869, \
-1.3254750549458545`}, {-4.079624732212994, -1.3159404320022174`}, \
{-3.890267096049435, -1.3045088494886141`}, {-3.7459244988139204`, \
-1.2944183200290773`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7223699906520635`, -1.2927716996753897`}, \
{-3.7009840944204107`, -1.2912766800479405`}, {-3.51177572732592, \
-1.2762439236801966`}, {-3.3226419947659642`, -1.2594105803853821`}, \
{-3.1330933214454526`, -1.2401251611188655`}, {-2.9426401320692945`, \
-1.2177361768360142`}, {-2.7829868452701167`, -1.196467269606378}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7595816296751745`, -1.1933492419781424`}, \
{-2.75128242663749, -1.1922436275368284`}, {-2.5590202051500395`, \
-1.1636475132213082`}, {-2.4360143776900895`, -1.143342593480659}, \
{-2.3117366679674523`, -1.1207144717406528`}, {-2.186187075982127, \
-1.09576314800129}, {-2.059365601734114, -1.0684886222625702`}, \
{-1.853244121400673, -1.0185653013952272`}, {-1.833080135142155, \
-1.0129498072661078`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.81033374721663, -1.0066151368186658`}, \
{-1.6400037230322655`, -0.9591797121681445}, {-1.487136144314, \
-0.9112675652042198}, {-1.3265819456399313`, -0.855676457385632}, \
{-1.1017731004246918`, -0.7702334565106316}, {-0.9233057718293667, \
-0.701338211182133}, {-0.9178977767524622, -0.6993567926313518}}]}, 
           {Arrowheads[{{0.0045135895569601925`, 1.}}], 
            ArrowBox[{{-0.8957270316596149, -0.6912337220688028}, \
{-0.873674090849855, -0.6831538134523267}, {-0.8215515641862711, \
-0.6653295311180458}, {-0.7755816759265441, -0.6504776754553477}, \
{-0.7449720350435602, -0.6408729685374104}, {-0.727400888573344, \
-0.6354450943022019}, {-0.7169866802966569, -0.6322518073962247}, \
{-0.7094981542949188, -0.6299626442221714}, {-0.7046444883445551, \
-0.6284783700828402}, {-0.698412644687675, -0.6265652842974241}, \
{-0.6931775469854418, -0.6249510288820387}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.3676324376398836`}, {-5.4782032054772465`, 
             1.3648154486755262`}, {-5.2798057924211, 
             1.3610821550710825`}, {-5.0791448661415375`, 
             1.356531654397834}, {-4.87825641096228, 
             1.3510991967791954`}, {-4.712642358104393, 
             1.3457778272448053`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689042544313056, 
             1.3450195381506167`}, {-4.677222429334221, 
             1.3446397442946247`}, {-4.476124923708255, 
             1.3370082590235797`}, {-4.449322253784444, 
             1.3359131872455783`}, {-4.422519514025412, 
             1.3347942551749359`}, {-4.251047530990595, 
             1.326426189906853}, {-4.07957828744002, 
             1.3168858863372879`}, {-3.8902307202386237`, 
             1.3054484138417193`}, {-3.7459263071083435`, 
             1.2953553920896435`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7223718575727562`, 
             1.293707933315765}, {-3.7009596470788435`, 
             1.2922103082495104`}, {-3.5117650679606793`, 
             1.2771715695606611`}, {-3.3226469828841307`, 
             1.2603321977751716`}, {-3.1331161514636636`, 
             1.2410406160160565`}, {-2.942683333313742, 
             1.2186452474063314`}, {-2.782992936133148, 1.197363336539159}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7595878751933163`, 
             1.194244148225043}, {-2.751348528434367, 
             1.193146091945996}, {-2.559111736825538, 
             1.1645431496350505`}, {-2.436036089560243, 
             1.144219472083682}, {-2.311690511400236, 
             1.121571352821946}, {-2.1860750023455178`, 
             1.0965987918498423`}, {-2.0591895623960883`, 
             1.069301789167371}, {-1.8531296875614711`, 
             1.0193776560328822`}, {-1.8330954406797293`, 
             1.0137964774921313`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.810349585609124, 
             1.007459893992864}, {-1.6399682237994453`, 
             0.9599947306708159}, {-1.4870032643084359`, 
             0.9120315719981167}, {-1.3263524672749674`, 
             0.8563748548653397}, {-1.1014976960226788`, 
             0.7708491262663908}, {-0.9229206374850878, 
             0.7018593414841938}, {-0.9179704200043018, 
             0.7000444241091165}}]}, 
           {Arrowheads[{{0.0045213012543739205`, 1.}}], 
            ArrowBox[{{-0.8958014439942731, 
             0.6919165267178514}, {-0.8732560501032643, 
             0.6836506217834568}, {-0.8211175349327249, 
             0.6658060850678299}, {-0.7751499100275387, 
             0.650940560108041}, {-0.7445414235504859, 
             0.6413267249177026}, {-0.726980786412249, 
             0.6358969614437112}, {-0.7165887054504956, 
             0.6327075293539709}, {-0.7091425727620648, 
             0.6304292080102207}, {-0.7043171245146009, 
             0.628952123910804}, {-0.6981278193860658, 
             0.6270502371833689}, {-0.6929304714124592, 
             0.6254461010382514}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.211070363482415}, \
{-5.572197842108291, -2.209181776817285}, {-5.403138603474138, \
-2.204911404419298}, {-5.2337961601992715`, -2.2000078494725215`}, \
{-5.064194635262762, -2.1944122362575516`}, {-4.8944464036125535`, \
-2.1879864968572176`}, {-4.712922937100899, -2.179710119432343}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689335448341043, -2.1786346719255656`}, \
{-4.666422840534369, -2.1775899949279283`}, {-4.43891227140037, \
-2.164857801611491}, {-4.212121414852437, -2.1495943411829517`}, \
{-3.9840519906857272`, -2.133690178983541}, {-3.757632512993544, \
-2.1143746589097305`}, {-3.7471756424337466`, -2.113342464687918}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.723677848468526, -2.1110230052456753`}, \
{-3.532346185171188, -2.092136720273907}, {-3.3081930072186587`, \
-2.066976363076072}, {-3.085172979135956, -2.038893587316224}, \
{-2.8635008975121674`, -2.0074349030398726`}, {-2.786501181996624, \
-1.9950902549199154`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7631869082826657`, -1.9913524942899676`}, \
{-2.643391558936382, -1.9721468202925265`}, {-2.4248449634085993`, \
-1.9330293390741864`}, {-2.207861110928819, -1.8900824593848518`}, \
{-2.0390082422140567`, -1.8533370561704308`}, {-1.8715225432381393`, \
-1.8135499496944352`}, {-1.837633591613645, -1.8048409684222286`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8147646775277604`, -1.7989639809398033`}, \
{-1.7053843731587188`, -1.7708547896950164`}, {-1.5408100393433732`, \
-1.7252739324857482`}, {-1.3782800724640885`, -1.676401535186999}, \
{-1.2180217864786547`, -1.6243095604046667`}, {-1.06019504252034, \
-1.5692448409164168`}, {-0.9143441976758077, -1.5156453709858018`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8922443206220914, -1.5073329454593145`}, \
{-0.7143077381305086, -1.4391913233943079`}, {-0.5267869595799007, \
-1.3663669721785017`}, {-0.33911394969446357`, -1.2970777086702063`}, \
{-0.23269807520331745`, -1.260907543476222}, {-0.12445331226712122`, \
-1.2273576837292954`}, {-0.013699938336076814`, -1.196693556620506}, \
{-0.0019961416370822375`, -1.1936964084866126`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.020879546539708662`, -1.1878458970059844`}, {
             0.05212727574186798, -1.1799731138060963`}, {
             0.17190580486917892`, -1.150744300263641}, {
             0.29496992381691634`, -1.1192395095290366`}, {
             0.44251403994107275`, -1.0717839605963662`}, {
             0.5860384793595488, -1.0067606534758329`}, {
             0.7432333410020512, -0.8936482090482043}, {
             0.7612215874035051, -0.8767896826473764}, {
             0.778468585124341, -0.8592943225329185}, {
             0.8040020381650598, -0.8266921573462406}, {
             0.8267379716970159, -0.7923158153400086}, {
             0.8380556594104156, -0.7713024932324495}}]}, 
           {Arrowheads[{{0.006630581035396984, 1.}}], 
            ArrowBox[{{0.849252265315616, -0.7505139812717585}, {
             0.8655490911909468, -0.7202559939406821}, {
             0.8898521677231798, -0.6405767622006556}, {
             0.896417067949104, -0.5559066332010054}, {
             0.8947193158916463, -0.5317754946941533}, {
             0.8917110683452422, -0.5091531839494675}, {
             0.8877575563897974, -0.48852872945999326`}, {
             0.8855627192649009, -0.47916708929748497`}, {
             0.8833462692458542, -0.4706338330807479}, {
             0.8812283716950962, -0.4631352143332108}, {
             0.8779364503881777, -0.4523027673405974}, {
             0.876407543493717, -0.447574027159103}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.20688156256961}, {-5.64945551265595, 
             2.206724490295957}, {-5.507483648916883, 
             2.203385305346039}, {-5.364527799704165, 
             2.199627768347408}, {-5.22138203966655, 
             2.1954024614489014`}, {-5.07808002876849, 
             2.19064217992266}, {-4.934670049646672, 
             2.1852953337591363`}, {-4.791219355945214, 
             2.179337122080579}, {-4.712912825091863, 2.1757247492922827`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689325916239847, 
             2.1746366573187457`}, {-4.6477865046378515`, 
             2.1727203951822722`}, {-4.50442135602794, 
             2.1653756545325367`}, {-4.361173770418838, 
             2.157233401599693}, {-4.2180936081139, 
             2.1482241378520612`}, {-4.075230729416481, 
             2.1382783647579626`}, {-3.9326349946299386`, 
             2.1273265837857176`}, {-3.7903562640576256`, 
             2.115299296403647}, {-3.747058426291098, 2.1112142227272996`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.723550828930566, 
             2.108996322893837}, {-3.607429907130366, 
             2.0980405212790534`}, {-3.4253252899119597`, 
             2.0786633115408213`}, {-3.2440998671003163`, 
             2.0570488057183147`}, {-3.0631982432823137`, 
             2.0343459980276766`}, {-2.8834343600116656`, 
             2.0088710176349047`}, {-2.7862944433447647`, 
             1.993683547904764}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.762965852998181, 
             1.990036208356898}, {-2.7046645805435983`, 
             1.9809210182165882`}, {-2.526888904878112, 
             1.9504959997727263`}, {-2.350107333015208, 
             1.9175959623033196`}, {-2.1745390131701026`, 
             1.8818806433662125`}, {-2.000403093558013, 
             1.8430097805192496`}, {-1.8374513889225803`, 
             1.8033564217148226`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8145730487901655`, 
             1.7975205481237737`}, {-1.6564284550328834`, 
             1.7558014230957566`}, {-1.4937209702711587`, 
             1.7094697980438913`}, {-1.3328908700281694`, 
             1.6602061354400275`}, {-1.1741617552012578`, 
             1.6081248034572833`}, {-1.0177572266877666`, 
             1.553340170268777}, {-0.9138463646188576, 
             1.514976722878867}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8916957851142069, 
             1.5067988233353222`}, {-0.8638675377280196, 
             1.496524753009109}, {-0.7126829415623409, 
             1.4383510688128787`}, {-0.5719794260591559, 
             1.3834836745063939`}, {-0.4322010055346514, 
             1.3301524969052914`}, {-0.2916760165651206, 
             1.2796725101213111`}, {-0.20314464709852903`, 
             1.2504739561256042`}, {-0.11321023273942166`, 
             1.2230967091521325`}, {-0.021242631588540697`, 
             1.197582720768357}, {-0.001679350646548814, 
             1.192526992901688}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.02119400278304178, 1.1866675875705441`}, {
             0.044102499107580254`, 1.1808669336545394`}, {0.162700003320568, 
             1.1517108216088086`}, {0.28461189761312716`, 
             1.1204967688049146`}, {0.43198492438685354`, 
             1.073805066108855}, {0.5759210511376979, 1.0100814493261945`}, {
             0.7367308523718151, 0.8967280229524619}, {0.7549323991861591, 
             0.8799744401877825}, {0.7723886471155749, 0.8625818674983324}, {
             0.7984434420776189, 0.8298881658844306}, {0.8217565424139508, 
             0.7952718696405129}, {0.8367655733571193, 0.7679137819913416}}]}, 
           {Arrowheads[{{0.006535084561592361, 1.}}], 
            ArrowBox[{{0.8481226012439461, 0.7472124745226333}, {
             0.8615867261391781, 0.7226704031258918}, {0.886638503335038, 
             0.6421710219110812}, {0.8936760988281711, 0.5568269738489419}, {
             0.8921851741451072, 0.5338015737583109}, {0.8895117140933017, 
             0.5122658949196025}, {0.8859828846531626, 
             0.49262124285534165`}, {0.8786226527528902, 
             0.46222046085946084`}, {0.8770036707406795, 
             0.45685618420520485`}, {0.8757273725780663, 
             0.45278062484665166`}, {0.8742539614717681, 
             0.4482207077440532}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.182060517532579}, \
{-5.5402582150770066`, -5.176555455977765}, {-5.37831993055287, \
-5.168817776153512}, {-5.207749285767293, -5.16039496562542}, \
{-5.034871378418729, -5.151399899264512}, {-4.90089390761785, \
-5.144012603542336}, {-4.76681947127802, -5.136135724335497}, \
{-4.713668784362548, -5.1328214320729195`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.6901025636114735`, -5.131351924384003}, \
{-4.632648069399238, -5.127769261643994}, {-4.498379701981506, \
-5.118913215467828}, {-4.364014369024822, -5.109567585806999}, \
{-4.229552070529187, -5.099732372661506}, {-4.0949928064946, \
-5.089407576031349}, {-3.9603365769210654`, -5.07859319591653}, \
{-3.825798768675607, -5.067361605761427}, {-3.7482949288670477`, \
-5.060676130484022}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.724770294414962, -5.0586468973205045`}, \
{-3.691594768625253, -5.05578517901042}, {-3.5577245767700054`, \
-5.04386391566351}, {-3.4241881931098637`, -5.031597815720697}, \
{-3.2909856176448278`, -5.01898687918198}, {-3.1581168503748986`, \
-5.006031106047359}, {-3.0255818913000754`, -4.992730496316834}, \
{-2.8933807404203584`, -4.979085049990406}, {-2.784684149380944, \
-4.967796726350747}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            
            ArrowBox[{{-2.7611984652962236`, -4.965357698591809}, \
{-2.6760682586142504`, -4.956516783570025}, {-2.460229303254039, \
-4.934451279002334}, {-2.2458638743397263`, -4.912888536287336}, \
{-2.032971971871313, -4.891828555425029}, {-1.8214318430847891`, \
-4.871991199221967}, {-1.8213508176491737`, -4.871984304928824}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7978238383618113`, -4.869982441060281}, \
{-1.6111217352161469`, -4.854096330484706}, {-1.4020416482653864`, \
-4.838143949213244}, {-1.1941915822325064`, -4.824134055407582}, \
{-0.9871582914923823, -4.812305636153278}, {-0.8555720086765218, \
-4.80631444608784}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8319844518419311, -4.805240492685166}, \
{-0.7805285304198883, -4.8028976785358894`}, {-0.5743022990150239, \
-4.795910182555418}, {-0.3684795972777887, -4.791343148211864}, \
{-0.20569787080987628`, -4.7890396648377695`}, {-0.04272034333784225, \
-4.787440907665656}, {0.11224648959411765`, -4.786591840301041}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13585834907213548`, -4.786529025655628}, {
             0.2838221146185941, -4.786357571927369}, {
             0.44738704510299643`, -4.786872993361196}, {
             0.6111477765915203, -4.7880931409970025`}, {
             0.7751043090841666, -4.790018014834789}, {
             0.9392566425809366, -4.792647614874556}, {
             1.080279541985736, -4.795064587499592}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1038880822038621`, -4.7954683202356}, {
             1.2675302816135023`, -4.797940052234862}, {
             1.431496979405964, -4.800082654224109}, {
             1.5953502627158778`, -4.801889511752752}, {
             1.759090131543244, -4.803360624820791}, {
             1.9227165858880628`, -4.804495993428226}, {
             2.0483131263496577`, -4.805110195369527}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0719248370144756`, -4.805225663187944}, {
             2.0862296257503337`, -4.805295617575056}, {
             2.2496292511300573`, -4.805759497261283}, {
             2.4687005684710264`, -4.806073268493964}, {
             2.6868852515014354`, -4.80621898028608}, {
             2.9041833002212845`, -4.806196632637629}, {
             3.016403409482505, -4.806097897067734}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0400153933412724`, -4.806077122335844}, {
             3.120594714630573, -4.806006225548614}, {
             3.3361194947293016`, -4.805647759019032}, {
             3.55075764051747, -4.805121233048884}, {
             3.764509151995078, -4.804426647638171}, {
             3.977374029162126, -4.803564002786891}, {
             3.9844912144886853`, -4.803538082517431}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.008103050897816, -4.803452089932707}, {
             4.1462592625428405`, -4.802948935094208}, {
             4.314595692566017, -4.80262399731027}, {
             4.519755156001672, -4.802665038524427}, {
             4.724073920475116, -4.803212896857286}, {
             4.737798404043437, -4.803266830451111}, {
             4.7515189666610045`, -4.8033232138868796`}, {
             4.932753092065877, -4.8047088602344745`}, {
             4.9525739934608, -4.80493500976144}}]}, 
           {Arrowheads[{{0.01441548518657982, 1.}}], 
            ArrowBox[{{4.97618444970313, -4.805204396778924}, {
             5.113371771850454, -4.806769655966238}, {
             5.273676126138758, -4.808851955579663}, {
             5.432181294826366, -4.811420293525796}, {
             5.584306858591671, -4.814296088335278}, {
             5.656854249492381, -4.815840239864883}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.1824511843694525`}, {-5.540747091328555, 
             5.176968877486216}, {-5.378803527508227, 
             5.169230976290388}, {-5.208209839301341, 
             5.160807494020273}, {-5.0352960779394085`, 
             5.151811485316568}, {-4.901321211683488, 
             5.144425298650897}, {-4.767249126203628, 
             5.1365496456298825`}, {-4.71366894446978, 
             5.133209055787816}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690102710490553, 
             5.1317397602516825`}, {-4.633079821499829, 
             5.1281845262535235`}, {-4.498813297572095, 
             5.11932994052182}, {-4.364449554420423, 
             5.109985888434773}, {-4.22998859204481, 
             5.10015236999238}, {-4.09543041044526, 
             5.089829385194645}, {-3.9607750096217726`, 
             5.079016934041564}, {-3.8262377847379594`, 
             5.0677872698849}, {-3.748294983792817, 5.0610649596190775`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.724770322730892, 
             5.059036034963574}, {-3.6920341309574294`, 
             5.056212646076413}, {-3.5581640482801835`, 
             5.044293062616102}, {-3.4246275367062227`, 
             5.032028519503968}, {-3.2914245962355464`, 
             5.01941901674001}, {-3.158555226868156, 
             5.006464554324229}, {-3.0260194286040507`, 
             4.9931651322566255`}, {-2.893817201443229, 
             4.979520750537199}, {-2.7846839834807526`, 4.968187835280957}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.761198282751182, 
             4.965748967802559}, {-2.6764898164396755`, 
             4.956952435563176}, {-2.460635859408987, 
             4.934886168060343}, {-2.2462553303511616`, 
             4.913321948028699}, {-2.0333482292661986`, 
             4.892259775468244}, {-1.8217930088398593`, 
             4.872419693460508}, {-1.821350017208993, 4.872381996346062}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7978230551405274`, 
             4.870379930122096}, {-1.6114681217579034`, 
             4.854521745087021}, {-1.4023735680203302`, 
             4.838565930347781}, {-1.1945093476271382`, 
             4.82455224924279}, {-0.987462302354259, 
             4.812719987519469}, {-0.8555711494221948, 
             4.806713005044187}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8319836081228359, 
             4.805638710490911}, {-0.7808192739776226, 
             4.803308430925243}, {-0.574580262497228, 
             4.796317579460112}, {-0.36874526791307427`, 
             4.791747433124074}, {-0.2059667118306175, 
             4.789442010618016}, {-0.04299258732483102, 4.787841756394626}, {
             0.1122473769808365, 4.7869901698837145`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1358592400720824, 4.7869284394406115`}, {
             0.2835423669567311, 4.786756752795852}, {0.44710319673250665`, 
             4.787272003420467}, {0.610859594931612, 4.788492422327751}, {
             0.7748115615540478, 4.790418009517703}, {0.9389590965998119, 
             4.793048764990324}, {1.080280336178334, 4.795472198015451}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1038888824837991`, 4.79587553984931}, {
             1.2672228697348284`, 4.798344372559059}, {1.4311846072674546`, 
             4.800488872599047}, {1.5950329121101592`, 4.802297836809448}, {
             1.7587677842629428`, 4.803771265190261}, {1.922389223725805, 
             4.804909157741488}, {2.0483138334750537`, 
             4.805527087462767}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.071925542189461, 4.80564295342903}, {
             2.0858972304987455`, 4.805711514463128}, {2.249291804581765, 
             4.806178335355181}, {2.4683464919382865`, 4.806496050661282}, {
             2.6865146832714633`, 4.806645445238859}, {2.903796378581297, 
             4.806626519087911}, {3.0164041024963097`, 
             4.806529079565329}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0400160866546035`, 4.806508648103049}, {
             3.120191577867786, 4.806439272208439}, {3.335700281130931, 
             4.806083704600442}, {3.550322488370732, 4.805559816263921}, {
             3.764058199587189, 4.804867607198876}, {3.9769074147803023`, 
             4.804007077405306}, {3.9844919333597026`, 
             4.803979520606297}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.008103770510169, 4.803893731819075}, {
             4.1457768602954, 4.803393524769089}, {4.314097523021895, 
             4.803069941783033}, {4.5192374974013205`, 4.80311242403006}, {
             4.723536855477662, 4.8036614862350415`}, {4.737260035668776, 
             4.803715492880655}, {4.750979295394323, 4.803771948330695}, {
             4.932195919537911, 4.805157035501121}, {4.9525746870838825`, 
             4.805389493032424}}]}, 
           {Arrowheads[{{0.014415472321178619`, 1.}}], 
            ArrowBox[{{4.9761851440802, 4.805658813958428}, {
             5.112797180410038, 4.807217126876022}, {5.272089401126467, 
             4.809284608283499}, {5.429641597202047, 4.811833159578817}, {
             5.580952825905122, 4.814687748343576}, {5.656854249492381, 
             4.81629984138871}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.4031177800559225`}, \
{-5.573170230447739, -3.4004763159606695`}, {-5.422134921969465, \
-3.3953136372574964`}, {-5.270271158494359, -3.389633834794589}, \
{-5.11785523858817, -3.3833621856088896`}, {-4.965163460816646, \
-3.3764239667373417`}, {-4.812247898216169, -3.3687412972626944`}, \
{-4.7132426716349896`, -3.363240908324938}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689667034066381, -3.36193112720973}, \
{-4.659160623823122, -3.3602362962676984`}, {-4.458036241426333, \
-3.347720433209106}, {-4.257529079919693, -3.3336235648063335`}, \
{-4.057639139303204, -3.3179456910593808`}, {-3.858366419576863, \
-3.3006868119682475`}, {-3.7479754650659514`, -3.2901973405770453`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7244693520946632`, -3.287963763554153}, \
{-3.660010650237067, -3.281838825944501}, {-3.4628715607802065`, \
-3.2613936313997067`}, {-3.266949151206282, -3.239351228333865}, \
{-3.072243421515295, -3.215711616746975}, {-2.879101150248114, \
-3.1908589011251847`}, {-2.7864275641818392`, -3.1784132005401973`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.763025659984072, -3.175270416224549}, \
{-2.6878691159456114`, -3.1651771859546405`}, {-2.4985473186077862`, \
-3.138666471235342}, {-2.311135758234637, -3.111326756967289}, \
{-2.1677918487490526`, -3.0900630302009113`}, {-2.025676375499951, \
-3.0691284511127335`}, {-1.8847893384873313`, -3.0485230197027553`}, \
{-1.8282453171968596`, -3.0403136963052004`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8048783115810507`, -3.036921165997757}, \
{-1.745130737711193, -3.0282467359709764`}, {-1.6065936948106494`, \
-3.008701925787549}, {-1.4690713314248127`, -2.990290915022625}, \
{-1.332563647553682, -2.9730137036762043`}, {-1.1970706431972566`, \
-2.9568702917482863`}, {-1.06222350092193, -2.9422055991596467`}, \
{-0.9276534032940968, -2.929364545831061}, {-0.8672803204969795, \
-2.9244115327227282`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8437473897808805, -2.9224808889835967`}, \
{-0.7933603503137562, -2.9183471317625282`}, {-0.6593443419809073, \
-2.9091533569540493`}, {-0.5250405579696048, -2.901692439223118}, \
{-0.3898841779539025, -2.895873596387229}, {-0.25387520193380025`, \
-2.8916968284463813`}, {-0.11701362990929848`, -2.8891621354005763`}, {
             0.021056178637507333`, -2.8876126438342387`}, {
             0.09981649084826243, -2.8869238471566425`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.12342758093518219`, -2.8867173568577877`}, {
             0.16068986422452064`, -2.886391480331795}, {
             0.30188742685174086`, -2.8854986448932443`}, {
             0.4446488665191693, -2.8849341375185875`}, {
             0.5887320743315423, -2.8838901186016805`}, {
             0.7338949413935967, -2.881558748536379}, {
             0.8801374677053334, -2.8779400273226847`}, {
             1.0274596532667521`, -2.873033954960596}, {
             1.067713654394762, -2.8712536939252007`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0913025897235733`, -2.870210456948613}, {
             1.2430775477375213`, -2.8634981044785626`}, {
             1.4586526098328494`, -2.851077858714743}, {
             1.6741848395527361`, -2.835773217669137}, {
             1.8896742368971822`, -2.8175841813417453`}, {
             2.0333571345737487`, -2.804326641676714}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.056869252741465, -2.802157191837812}, {
             2.1047318997355537`, -2.7977409324829523`}, {
             2.318968925937218, -2.7774736538431437`}, {
             2.5323853155021756`, -2.756782345422319}, {
             2.7449810684304263`, -2.735667007220479}, {
             2.957010834136864, -2.715043867162893}, {
             2.9969775534414484`, -2.7114166482755357`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.020492901213656, -2.70928248977901}, {
             3.1687292620363827`, -2.6958291531748313`}, {
             3.3801363521289827`, -2.6780228652562927`}, {
             3.5912321044146642`, -2.6616250034072784`}, {
             3.746285033380087, -2.6505593916815853`}, {
             3.901304580044908, -2.640484537223128}, {
             3.9621524348444352`, -2.636907374775147}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9857237305527815`, -2.635521650428151}, {
             4.053054720901785, -2.631563353277736}, {
             4.2048288858962035`, -2.6235082427057623`}, {
             4.356627075028162, -2.616319205507208}, {
             4.508449288297662, -2.6099962416820723`}, {
             4.528803953541868, -2.6092066470109874`}, {
             4.5491595513649115`, -2.6084309395365084`}, {
             4.72469704500296, -2.6028562870528593`}, {
             4.900286156133182, -2.5982192726495366`}, {
             4.929383453863097, -2.597511952197487}}]}, 
           {Arrowheads[{{0.01490675574966903, 1.}}], 
            ArrowBox[{{4.952988473577214, -2.5969381424447806`}, {
             5.044366222890693, -2.594716858820727}, {
             5.188399028590212, -2.5918206920255304`}, {
             5.332296646988596, -2.5895157962068303`}, {
             5.475971151842697, -2.5877871953075102`}, {
             5.617465509459843, -2.586582979832138}, {
             5.656854249492381, -2.5863731451552923`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.40432036556347}, {-5.580393885073273, 
             3.401913505367695}, {-5.429589272115312, 
             3.396777485805046}, {-5.277845140729099, 
             3.391126498405554}, {-5.125491878039432, 
             3.384886940240468}, {-4.9728598711711065`, 
             3.377985208381038}, {-4.820001045449071, 
             3.3703434142883593`}, {-4.713242594620743, 
             3.3644417786188225`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.6896665971826526`, 
             3.363138491184938}, {-4.66696732619827, 
             3.361883669423527}, {-4.466097256368936, 
             3.349444246277247}, {-4.265832393974518, 
             3.3354296677682034`}, {-4.066172739015019, 
             3.319839933896397}, {-3.8671182914904367`, 
             3.302675044661827}, {-3.7479748799881674`, 
             3.2913996440379987`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7244679188936014`, 
             3.2891750107120936`}, {-3.668968462809272, 
             3.2839226967665303`}, {-3.4720226643800247`, 
             3.2635705869125426`}, {-3.2762808962026946`, 
             3.2416187150998645`}, {-3.0817431582772836`, 
             3.218067081328496}, {-2.888756964621918, 
             3.1932993027432333`}, {-2.786429565045325, 
             3.1795903067800078`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7630266611658794`, 
             3.176454975322953}, {-2.697669829254725, 
             3.167698996488872}, {-2.508481752175707, 
             3.1412661625654126`}, {-2.321192733384862, 
             3.1140008009728546`}, {-2.175899837214864, 
             3.0924861296845543`}, {-2.03186822937065, 
             3.0712974002217934`}, {-1.8890979098522185`, 
             3.0504346125845716`}, {-1.8282311407988048`, 
             3.041601173188018}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8048639452257949`, 
             3.038209951521883}, {-1.7475888786595726`, 
             3.0298977667728897`}, {-1.6072303493058462`, 
             3.010106854701737}, {-1.4679115353041734`, 
             2.991481868286104}, {-1.3296324366545562`, 
             2.974022807525991}, {-1.1923930533569933`, 
             2.9577296724213977`}, {-1.0558076054754169`, 
             2.9429580348594486`}, {-0.9194903130737606, 
             2.9300634667272685`}, {-0.8672496838325489, 
             2.925832928570975}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8437147363537136, 
             2.9239270270770277`}, {-0.7834411761520238, 
             2.9190459680248573`}, {-0.6476601947102059, 
             2.9099055387522146`}, {-0.511561893537134, 
             2.902537224630384}, {-0.3745607974216337, 
             2.89683607138041}, {-0.23665690636370523`, 
             2.8928020790022915`}, {-0.0978502203633489, 
             2.8904352474960286`}, {0.04221160075243219, 2.889028696233472}, {
             0.09985433717902853, 2.8885594991799457`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.1234655480046773, 2.8883673099946927`}, {
             0.18388089715663453`, 2.887875544586471}, {0.32715766884925757`, 
             2.886975792555027}, {0.4720419158303024, 2.886329440139139}, {
             0.6182505104153999, 2.8851195976528548`}, {0.7655003249201808, 
             2.8825293754102232`}, {0.9137913593446463, 2.878558773411244}, {
             1.0631236136887956`, 2.873207791655917}, {1.0677571627127254`, 
             2.8729911105806796`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0913433803051407`, 2.8718881359574877`}, {
             1.2758532034303982`, 2.8632598066444297`}, {1.4885037199172246`, 
             2.850571009993828}, {1.7010751631492758`, 2.835141401704112}, {
             1.9135675331265518`, 2.8169709817752806`}, {2.033391683625235, 
             2.805829840659473}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.056902269494496, 2.803643847653934}, {
             2.125616209865825, 2.7972548876394954`}, {2.336856573383868, 
             2.7771882567289152`}, {2.547288623680681, 2.7567710890435406`}, {
             2.756912360756264, 2.7360033845833716`}, {2.9659842703152557`, 
             2.7157450364840767`}, {2.9970143112974656`, 
             2.7129375877838444`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0205302525437827`, 2.7108099786477635`}, {
             3.1747608380622956`, 2.6968559378813257`}, {3.3832420639973835`, 
             2.6793360887751176`}, {3.5914279481205194`, 2.663185489165453}, {
             3.7464877956191645`, 2.652125979593066}, {3.9015144990814576`, 
             2.64205491964461}, {3.9621942744822785`, 2.63848917392786}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9857656051297723`, 2.6371040440268474`}, {
             4.053237648313339, 2.6331391620312736`}, {4.204983901943316, 
             2.625089003288711}, {4.356753259971386, 2.617904443416923}, {
             4.50854572239755, 2.611585482415909}, {4.528896400808118, 
             2.6107963901024385`}, {4.54924799651328, 2.610021178189349}, {
             4.724787218118618, 2.604449284228392}, {4.900377051693097, 
             2.599814987361959}, {4.9294259455595215`, 2.59910925174065}}]}, 
           {Arrowheads[{{0.014905853924352879`, 1.}}], 
            ArrowBox[{{4.953030973329643, 2.598535773486505}, {
             5.044492030947713, 2.5963137499347484`}, {5.188561379382559, 
             2.5934184204000017`}, {5.332495993694034, 2.5911143812750073`}, {
             5.476206770578539, 2.5893870150770533`}, {5.617734706440326, 
             2.588184357712569}, {5.656854249492381, 2.587976521183534}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.7089704751464625`}, \
{-5.641540454413132, -4.7083368146192734`}, {-5.505819773326933, \
-4.702568278522222}, {-5.364700326236821, -4.696340999660003}, \
{-5.221671779105994, -4.689716654263187}, {-5.07748835472119, \
-4.682652071442826}, {-4.932904275869146, -4.675104080309966}, \
{-4.713527683866625, -4.662583459494712}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689963098692913, -4.661088139302722}, \
{-4.4929475898456985`, -4.648555229338445}, {-4.27286724370994, \
-4.633116600514381}, {-4.052718895491491, -4.6162351694647805`}, \
{-3.832982822655442, -4.597945371277806}, {-3.7481703027048052`, \
-4.590324718342559}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7246530526867554`, -4.588211624656823}, \
{-3.6141393026668815`, -4.578281641041617}, {-3.3961883355258107`, \
-4.5572439787562145`}, {-3.1791299212322293`, -4.534832384421598}, \
{-2.9633483170949675`, -4.511668306615877}, {-2.78507716668697, \
-4.492273405948111}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7616036836766433`, -4.489719622734899}, \
{-2.7492277804228564`, -4.488373193917159}, {-2.5367683112158965`, \
-4.464947046325444}, {-2.325969909474087, -4.441389863840732}, \
{-2.1167909835769367`, -4.418550824046977}, {-1.909189941903955, \
-4.39727910452813}, {-1.822522366683572, -4.388990072728049}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7990176317394904`, -4.386742040578672}, \
{-1.7031667844551421`, -4.377574705284194}, {-1.4987215112304968`, \
-4.359437626315167}, {-1.2954227521620212`, -4.343390587805411}, \
{-1.092839137181716, -4.32995630993929}, {-0.890970666289582, \
-4.319134792716803}, {-0.8571735008654333, -4.317755582596693}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.833581144225695, -4.316792814961406}, \
{-0.6898173394856182, -4.3109260361379516`}, {-0.4887747041795559, \
-4.3050069034020195`}, {-0.2872383077811256, -4.301054257708291}, \
{-0.08520815029032724, -4.299068099056767}, {
             0.11064328051284114`, -4.299049075561378}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.134255082220807, -4.299128923491138}, {
             0.15497062715691817`, -4.299227364279079}, {
             0.1926556731423859, -4.299430271480455}, {
             0.42971665044854335`, -4.300856841685385}, {
             0.6679526534896032, -4.303248825899192}, {
             0.6833863124377031, -4.303467412849311}, {
             0.6988243034004361, -4.303690238773973}, {
             0.7525818735129602, -4.304400856267697}, {
             0.8063751196973477, -4.305061151555013}, {
             0.9681448600043572, -4.306783882858643}, {
             1.0786936169125627`, -4.307602027538936}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1023049633081425`, -4.307776769417437}, {
             1.1299907060258072`, -4.30798166492018}, {
             1.2919126577616984`, -4.308654497739622}, {
             1.4539107152120303`, -4.308802381316968}, {
             1.6159848783768034`, -4.3084253156522205`}, {
             1.7781351472560176`, -4.307523300745378}, {
             1.9403615218496728`, -4.306096336596441}, {
             2.046765541856658, -4.304816680049498}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0703758274898556`, -4.304532733478836}, {
             2.102664002157769, -4.304144423205409}, {
             2.264803244073267, -4.301812623151622}, {
             2.426539903489128, -4.299245999014417}, {
             2.5878739804053525`, -4.296444550793794}, {
             2.7488054748219395`, -4.293408278489754}, {
             2.9093343867388892`, -4.290137182102296}, {
             3.014704544426348, -4.2878301324484385`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.038310879916478, -4.287313278442365}, {
             3.0694607161562026`, -4.286631261631422}, {
             3.229184463073879, -4.28289051707713}, {
             3.388505627491918, -4.27891494843942}, {
             3.547428361802165, -4.2749869092219095`}, {
             3.7059568183964644`, -4.271388752928218}, {
             3.8640909972748165`, -4.268120479558345}, {
             3.9825460561862562`, -4.265913890034532}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.0061539535089254`, -4.2654741203920175`}, {
             4.021830898437223, -4.265182089112289}, {
             4.179176521883681, -4.262573581590051}, {
             4.336127867614192, -4.260294956991632}, {
             4.4926849356287555`, -4.25834621531703}, {
             4.648847725927372, -4.2567273565662465`}, {
             4.804547437228929, -4.255524994391031}, {
             4.950566149474515, -4.254866972246274}}]}, 
           {Arrowheads[{{0.01445642899539179, 1.}}], 
            ArrowBox[{{4.974178037939179, -4.25480739772758}, {
             5.114351218997515, -4.254629600722554}, {
             5.268455289464546, -4.254936569229293}, {
             5.422027479653402, -4.25574664796335}, {
             5.575067789564083, -4.257059836924726}, {
             5.656854249492381, -4.258033872793902}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6076812191004528, -1.623314019472725}, \
{-0.4795585812077302, -1.5894012518780483`}, {-0.2515630500463421, \
-1.5405173176924298`}, {-0.01775009217479817, -1.5070381421974097`}, {
             0.10390096031092895`, -1.4943456137345852`}, {
             0.2297898636468475, -1.4824376367434215`}, {
             0.32307765056231896`, -1.472574570990648}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3465587692350217, -1.4700919757327349`}, {
             0.3595184959591029, -1.4687217788286813`}, {
             0.4926887353738417, -1.4506056075951264`}, {
             0.6274314528335847, -1.4264361049874248`}, {
             0.7618775192808532, -1.3945602529502445`}, {
             0.8940400967042761, -1.3553189712913412`}, {
             1.0219323470924817`, -1.309053179818471}, {
             1.0933570243681308`, -1.279554812203627}, {
             1.162722895174334, -1.2485283726311198`}, {
             1.2477883618752525`, -1.2065694787726544`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2689644014622206`, -1.196124309518529}, {
             1.3305103020446334`, -1.1657665390846046`}, {
             1.485910400219541, -1.081474254654363}, {
             1.5995109016238904`, -1.0188380797073704`}, {
             1.709064803006238, -0.9608066470201436}, {
             1.7254189660038124`, -0.9523309001649465}, {
             1.7417236726737841`, -0.9439532833136993}, {
             1.8278908411781736`, -0.9030831266922121}, {
             1.8970539651610758`, -0.8730783513257576}, {
             1.9667686057694638`, -0.8455147512862469}, {
             2.107874639420413, -0.7946579759024403}, {
             2.120240866393783, -0.7909911444603719}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.142878621936557, -0.784278601177699}, {
             2.2529579308620873`, -0.7516379039012764}, {
             2.4033536804658584`, -0.7156888899586286}, {
             2.6008627153472585`, -0.6789208949882003}, {
             2.807828404001968, -0.6501593934440755}, {
             3.0233858073711453`, -0.6277401922505936}, {
             3.0716871689537593`, -0.6239023968636962}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.095224980189909, -0.6220321948565488}, {
             3.2466699863959483`, -0.6099990983320941}, {
             3.476671100766117, -0.5960221110085279}, {
             3.7123793101713907`, -0.5848952295998461}, {
             3.8503832374141087`, -0.579609012933565}, {
             3.9895576585707118`, -0.5749274474710302}, {
             4.038340127184317, -0.57351035343688}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.061942163888899, -0.5728247320167591}, {
             4.129902573641199, -0.5708505332122417}, {
             4.271417982625572, -0.5673782701571994}, {
             4.413815632135577, -0.5643906027380423}, {
             4.556807268782963, -0.5617674753869092}, {
             4.70039289256773, -0.5595088881038002}, {
             4.844572503489878, -0.5576148408887152}, {
             4.989143301116121, -0.5560197880282142}, {
             5.006255467871351, -0.5558588310662516}}]}, 
           {Arrowheads[{{0.013277189869392858`, 1.}}], 
            ArrowBox[{{5.02986641642965, -0.5556367465924757}, {
             5.133902485013171, -0.5546581838088577}, {
             5.27885005518103, -0.5535300282306455}, {
             5.4239860116196965`, -0.5526353212935776}, {
             5.549431629595719, -0.552028301629272}, {
             5.656854249492381, -0.5516198101326705}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.47565396040517693`, 
             1.5890414200539125`}, {-0.24976309683718276`, 
             1.5408594332126668`}, {-0.01813706103033816, 
             1.5078142644189567`}, {0.10235173519532723`, 
             1.4952484599192655`}, {0.2269937179439241, 
             1.4834565975914489`}, {0.35543899014143576`, 
             1.4699610768055043`}, {0.45856002633489523`, 
             1.456141013781457}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.4819627885541801, 1.4530046251187156`}, {
             0.4873376547138464, 1.4522842969314285`}, {0.620881047040431, 
             1.4287437228675526`}, {0.7542605025004655, 
             1.3976568195122074`}, {0.8855221536943878, 
             1.3592971581529725`}, {1.0127121332226354`, 
             1.3139383100774271`}, {1.0838082007906484`, 
             1.2849714868289193`}, {1.1528566838037964`, 1.25448957474574}, {
             1.3221504566781934`, 1.171810733600214}, {1.369739221512097, 
             1.1461633095185617`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.3905247579719051`, 1.1349611808184374`}, {
             1.478931782107493, 1.0873152196821039`}, {1.5924097477122712`, 
             1.0250083262736358`}, {1.701794624078752, 0.9671171620722352}, {
             1.7182005280986457`, 0.9586063639832171}, {1.7345544799792707`, 
             0.9501941732922555}, {1.8203672856717585`, 0.9091489882682222}, {
             1.889321359021902, 0.8789554556823888}, {1.9587859116928097`, 
             0.8512114883490383}, {2.0993199637329547`, 0.8000103769423852}, {
             2.243699924866836, 0.7566772949837072}, {2.2519100412925206`, 
             0.7546847842880584}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2748559637775903`, 0.7491160452346151}, {
             2.3932441454636377`, 0.7203844528896036}, {2.592160176551122, 
             0.6827209476546748}, {2.8007046473516306`, 0.6533298999686502}, {
             3.018002366465497, 0.6304788044140294}, {3.2084951229735035`, 
             0.6152143542774833}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.2320316723182816`, 0.6133283377672197}, {
             3.243178142493056, 0.6124351555733121}, {3.47519850409287, 
             0.5982510669140398}, {3.7130299799235016`, 0.5869786519037546}, {
             3.850680002920025, 0.5816911643659456}, {3.989493621178646, 
             0.5770072141286305}, {4.129470834699363, 0.5729268011918094}, {
             4.1755215740721425`, 0.5717923830519329}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.199126405996219, 0.5712108994560531}, {
             4.270611643482177, 0.5694499255554824}, {4.41263006348411, 
             0.5664569828611201}, {4.555240110662185, 0.5638283687501936}, {
             4.698441785016403, 0.5615640832227028}, {4.842235086546762, 
             0.5596641262786476}, {4.986418620597185, 0.5580631058137}, {
             5.130790992511593, 0.556695629723532}, {5.14348247510929, 
             0.5565960782971509}}]}, 
           {Arrowheads[{{0.010371190636631694`, 1.}}], 
            ArrowBox[{{5.167093741745677, 0.5564108725692759}, {
             5.275352202289985, 0.5555616980081436}, {5.420102249932361, 
             0.5546613106675347}, {5.545368103546234, 0.5540488157747498}, {
             5.656854249492381, 0.5536197803831399}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.6868170509677107}, \
{-5.456806289988602, -0.6851533979675156}, {-5.250143912184961, \
-0.683060877180797}, {-5.222509452741458, -0.6827535181089397}, \
{-5.194869029703055, -0.6824379010835971}, {-4.998727844056526, \
-0.6796758158184742}, {-4.802409952947348, -0.6763716301271312}, \
{-4.7124593107108, -0.6746482435361072}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.68885165022696, -0.6741959385329221}, \
{-4.577452268474227, -0.6720616102392324}, {-4.352278936472634, \
-0.6667003532787151}, {-4.126889956942568, -0.6602878592455793}, \
{-3.9012853298840287`, -0.6528241281398249}, {-3.7447937617283293`, \
-0.646619791057846}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.72120030404326, -0.6456843939234653}, \
{-3.6748031134664583`, -0.6438449094490757}, {-3.4467813658592994`, \
-0.6328859526609552}, {-3.2172200870625516`, -0.6199472577754633}, \
{-2.9861192770762144`, -0.6050288247926002}, {-2.847214124186856, \
-0.5948740488046517}, {-2.7784664660080463`, -0.5892436097294819}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754933267025739, -0.5873162387233438}, \
{-2.70621559828337, -0.5833262574933684}, {-2.563123699365758, \
-0.5703854508587507}, {-2.4179384274340183`, -0.5560516289007984}, \
{-2.2060686455766922`, -0.5322073513946229}, {-1.9841008734937766`, \
-0.5031903222633604}, {-1.8234351758617695`, -0.4794158946380961}, \
{-1.8169684563627138`, -0.4783555732321425}}]}, 
           {Arrowheads[{{0.019457213945432584`, 1.}}], 
            ArrowBox[{{-1.7936676054882992`, -0.4745350285243225}, \
{-1.6528124197121978`, -0.4514395828907559}, {-1.5241502352588523`, \
-0.428664686735227}, {-1.385843168699112, -0.40276291544887494`}, \
{-1.1622896766158566`, -0.3602646471192491}, {-1.10007146640384, \
-0.3488406863566456}, {-1.034095130825766, -0.3376434094658546}, \
{-0.9680016321107073, -0.32788475023190977`}, {-0.9377372203292312, \
-0.32388785497660005`}, {-0.9229666952348526, -0.3219862273199341}, \
{-0.9144664465997129, -0.3209001644196786}, {-0.9094788885885648, \
-0.3202627754099006}, {-0.9029429476991282, -0.3194245120502798}, \
{-0.8967633791940249, -0.3186283397077795}, {-0.8926224348486109, \
-0.3180927881421131}, {-0.8884779093585305, -0.31755513162980126`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.6878353600700251}, {-5.456723531482535, 
             0.686168575041131}, {-5.250064737436521, 
             0.6840730151542745}, {-5.22243074964353, 
             0.6837652094384052}, {-5.194790797263748, 
             0.6834491337037262}, {-4.998652044512631, 
             0.6806830170327274}, {-4.802336569441489, 
             0.6773740053464257}, {-4.712459546347709, 0.6756496277429743}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688851897953367, 
             0.6751966921787992}, {-4.577446465618509, 
             0.6730592712250522}, {-4.352342767314388, 
             0.6676927759988653}, {-4.127025474529124, 
             0.6612745196678652}, {-3.901494587262718, 
             0.6538045022320518}, {-3.7447950859877976`, 
             0.6475851313901617}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7212016687928298`, 
             0.6466487135345267}, {-3.6750890191761236`, 
             0.644818511995051}, {-3.447147683930295, 
             0.6338523372604888}, {-3.2176705815252316`, 
             0.6209059780283653}, {-2.9866577119609348`, 
             0.6059794342986804}, {-2.847733464741957, 
             0.5958139179605588}, {-2.7784722826278494`, 
             0.5901361046075138}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754939230676029, 
             0.5882069392001169}, {-2.706718437860775, 
             0.5842539506286859}, {-2.563612631317389, 
             0.5712995323030614}, {-2.4184160451117984`, 
             0.5569506629836856}, {-2.2064371149749387`, 
             0.5330690832201247}, {-1.9843607540747539`, 
             0.5040043434061011}, {-1.8236518139028075`, 
             0.4801939670144431}, {-1.8169920223777472`, 
             0.47910054925309215`}}]}, 
           {Arrowheads[{{0.01947189361317882, 1.}}], 
            ArrowBox[{{-1.7936919759667411`, 
             0.47527510149091684`}, {-1.6529878275078727`, 
             0.4521740157524563}, {-1.5243050198077823`, 
             0.42936364454862475`}, {-1.3859789214603706`, 
             0.40342004043076435`}, {-1.1624297729765, 
             0.360851749913196}, {-1.100213880773125, 
             0.34940659683192893`}, {-1.0342429691695147`, 
             0.33818693183097526`}, {-0.9681760575589438, 
             0.328405470269557}, {-0.9375334040076205, 
             0.3243459216750618}, {-0.9225665447945491, 
             0.3224141600165199}, {-0.9139697106890569, 
             0.32131335260341726`}, {-0.9089303925346871, 
             0.32066807667309544`}, {-0.9023383168849851, 
             0.31982097964557193`}, {-0.896155117474735, 
             0.31902277969792303`}, {-0.8920094888331908, 
             0.31848557034829966`}, {-0.8878598006056003, 
             0.31794618532202434`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.8861306530753927`}, \
{-5.558399890587053, -1.884314819669655}, {-5.398423179137103, \
-1.8809684505358883`}, {-5.238271820496812, -1.8771142552389353`}, \
{-5.077998527586853, -1.8726444551041856`}, {-4.917656013327901, \
-1.867451271457029}, {-4.7572969906406275`, -1.8614269256228555`}, \
{-4.712774127820217, -1.8594931680839915`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689184374403791, -1.8584685964230685`}, \
{-4.59697417244571, -1.8544636389270546`}, {-4.431965027658744, \
-1.846169809754292}, {-4.267183376282629, -1.8366063376524853`}, \
{-4.102660641333216, -1.8256696856432217`}, {-3.9380930669906316`, \
-1.814360711184488}, {-3.773925812646068, -1.8012126404154418`}, \
{-3.7466639903540795`, -1.7987620330524303`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.723146821311455, -1.7966480383606676`}, \
{-3.6100803207599026`, -1.7864843157821142`}, {-3.4465565913321363`, \
-1.7701757372845053`}, {-3.2833546243627687`, -1.7522869049226146`}, \
{-3.120497127466052, -1.732572078820054}, {-2.9580068082562367`, \
-1.710785519100435}, {-2.7958836667333244`, -1.6869272257637575`}, \
{-2.7854342449948977`, -1.6852521481907101`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7621199081587635`, -1.6815147813064675`}, \
{-2.6341277028973145`, -1.6609971988100216`}, {-2.469292742937316, \
-1.631941503438114}, {-2.3046263965509493`, -1.5998233751241198`}, \
{-2.1400650217929487`, -1.5643428208316297`}, {-1.9755449767180482`, \
-1.5251998475242337`}, {-1.8379698311764674`, -1.48902179400109}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8151342149593481`, -1.4830167256983475`}, \
{-1.810967463228072, -1.481920997494257}, {-1.6462336832248439`, \
-1.4340328130340252`}, {-1.56766496539579, -1.4094565330813764`}, \
{-1.4890066308784147`, -1.383488528573686}, {-1.3593258303325237`, \
-1.3372750571277323`}, {-1.2289725986287705`, -1.2864896521105509`}, \
{-1.0164734825410175`, -1.194432532812135}, {-0.9312786042613906, \
-1.1539754003924583`}}]}, 
           {Arrowheads[{{0.013284581359618993`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAobpGTYQe7b/xb/Dk+kzyv5HCRFDQ
wum/1/MvcUZ08b9ndx4FTifmv14GoqCBg/C/VPkgU2JV5b/uKrpVfUzwv8g2
Zs4pf+S/0k0XGIwU8L/+GKAnT77iv+RmZLHiQ++/KKQO2Rdi4b8+6nHaRJXu
v2zAr39R39+/2sMjiq3f7b9QVGu4LGbev6S/IBfRg+2/EJ9+/d343L9sSxnE
6yvtv34dTIOM19u/xXbazMTm7L+U/y0b9uzavyv8puGuruy/RcGZ/pY82r8D
lcf5hYTsv5/CtCD3r9m/LygpnOpi7L+1dMsw583Yvw9CLuXnLOy/5pplB+M0
2L8YJLf5Wwjsv3Q9vRAux9e/zPr8jCju67808thNclLXv1sJwYVD0uu/5oDS
GCIG17+Tk8WeAcDrv9JPg3zhm9a/PzKfe42m67/XcRzP1VzWv29/dT1ul+u/
QETIgg==
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.314472600848429, 
             5.656854249492381}, {-4.303652396176749, 
             5.65608606564829}, {-4.177527445941312, 
             5.646702890329066}, {-4.0514087826534695`, 
             5.636916100099178}, {-3.9252822388705795`, 
             5.6267495225709885`}, {-3.799133647149996, 
             5.616226985356858}, {-3.6729488400490786`, 
             5.605372316069147}, {-3.5467136501251826`, 
             5.594209342320218}, {-3.4202629844460852`, 
             5.582664909865293}, {-3.373288217974373, 5.57823194009535}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.3497806666885923`, 
             5.576013551968226}, {-3.2934866320757745`, 
             5.5707011305894625`}, {-3.166452748565923, 
             5.558394731299892}, {-3.0392294894682044`, 
             5.545822438803745}, {-2.9118850103342915`, 
             5.533060979908186}, {-2.7844874667158557`, 
             5.52018708142038}, {-2.657105014164572, 
             5.507277470147491}, {-2.5298058082321115`, 
             5.494408872896685}, {-2.40995112462648, 5.482423737608683}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.3864533566234316`, 
             5.480104098995675}, {-2.276379104429169, 
             5.469299030977296}, {-2.1504041513120025`, 
             5.457216175005225}, {-2.0248824689201728`, 
             5.4455108507769925`}, {-1.8997848109055318`, 
             5.434230174606665}, {-1.7750819309199293`, 
             5.423421262808307}, {-1.650744582615216, 
             5.413131231695986}, {-1.5267435196432424`, 
             5.4034071975837685`}, {-1.4456055335719737`, 
             5.3977181998193355`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.4220513672249013`, 
             5.396066697160964}, {-1.2867598869249952`, 
             5.386580721895359}, {-1.048075111256753, 
             5.372692979649647}, {-0.8103244490228625, 
             5.361797608272991}, {-0.5733052648812941, 
             5.353924406335588}, {-0.4787080108309236, 5.35196529364304}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.455101079863374, 
             5.351476393214007}, {-0.33686332979047706`, 
             5.349027684958874}, {-0.10084441470884022`, 
             5.347061755264281}, {-0.0680865266606471, 
             5.347020780804327}, {-0.03534026310279234, 
             5.3470369815472045`}, {0.151982351023655, 5.347815873646509}, {
             0.33933303872580006`, 5.349640065978109}, {0.3514411981645797, 
             5.349791727090479}, {0.363549425906453, 5.3499473565024145`}, {
             0.4066683665389389, 5.350566094072773}, {0.4497861526634437, 
             5.351235283911605}, {0.4893164120362802, 5.35195633385186}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5129244779912451, 5.3523869557303}, {
             0.6899984693197267, 5.355616866003944}, {0.9300379390981864, 
             5.36130271934561}, {1.169826315449748, 5.36762574995784}, {
             1.4092853518253365`, 5.373918863861866}, {1.4571252541920694`, 
             5.375161120581832}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4807292906320915`, 5.375774045597045}, {
             1.6482714937505103`, 5.380124606894312}, {1.8866411867508273`, 
             5.3861855248918005`}, {2.048356126047123, 5.390119849998656}, {
             2.2096215037072264`, 5.393775543801615}, {2.3704373197311384`, 
             5.397152606300681}, {2.424940585049244, 5.398205662120592}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.4485481721047546`, 5.398661783543735}, {
             2.530803574118858, 5.400251037495852}, {2.690670904117353, 
             5.403126458625085}, {2.84998994697359, 5.40583449092634}, {
             3.0087607026875696`, 5.408375134399615}, {3.1669831712592913`, 
             5.410748389044912}, {3.3246335781530845`, 5.4130165884842985`}, {
             3.3929023764824504`, 5.413983963698207}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.4165119992932187`, 5.414318514246565}, {
             3.4816881488332774`, 5.4152420663398475`}, {3.638146883299871, 
             5.417424822611558}, {3.7940097815528637`, 5.41956485729943}, {
             3.9726783297564423`, 5.422144406460808}, {4.149965761129942, 
             5.424997591203432}, {4.325872075673363, 5.4281244115273015`}, {
             4.360879249989246, 5.428806492706315}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.38448676237832, 5.429266462418197}, {
             4.500397273386704, 5.431524867432415}, {4.6735413542699655`, 
             5.435198958918774}, {4.845304318323148, 5.439146685986378}, {
             5.015686165546252, 5.443368048635226}, {5.184686895939276, 
             5.4478630468653195`}, {5.328687736829566, 
             5.452032694692503}}]}, 
           {Arrowheads[{{0.006452928119292558, 1.}}], 
            ArrowBox[{{5.352289837503029, 5.452716110478006}, {
             5.35257577802081, 5.452724390091175}, {5.519622080309445, 
             5.458044787727311}, {5.656854249492381, 5.462839927864621}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.710625588318818}, {-5.620107089400714, 
             4.709105807482556}, {-5.4644938773621625`, 
             4.702457681320319}, {-5.304137376054286, 
             4.695204892417608}, {-5.142804995342462, 
             4.6873621574842765`}, {-4.980496735226691, 
             4.678929476520325}, {-4.817212595706968, 
             4.669906849525753}, {-4.713560214693895, 4.6636301130756825`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689991395414968, 
             4.6622028880992055`}, {-4.577098730429431, 
             4.655366600323328}, {-4.337164287658651, 
             4.639077994527945}, {-4.097409267394632, 
             4.621041032139605}, {-3.857833669637371, 
             4.601255713158307}, {-3.7481986899052906`, 4.591481357586259}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7246799795993994`, 
             4.589384579371062}, {-3.619025385794564, 
             4.5799650896225135`}, {-3.3815723072739057`, 
             4.5574122135706885`}, {-3.145474434075397, 
             4.53359708500283}, {-2.910731766199037, 
             4.50851970391894}, {-2.7849786016051716`, 
             4.494701682187844}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7615078771178636`, 
             4.492122669706865}, {-2.725321253904471, 
             4.488146407578174}, {-2.5412067355185575`, 
             4.467897945025691}, {-2.358388211041296, 
             4.447774316261491}, {-2.1768656804726856`, 
             4.4277755212855725`}, {-1.9965725631339237`, 
             4.40849318473981}, {-1.8224611157309416`, 
             4.391022530394518}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7989552125987083`, 
             4.388787667576547}, {-1.6394748261095375`, 
             4.37385276086437}, {-1.4626702064239108`, 
             4.358494673534691}, {-1.2867029476954688`, 
             4.344770334863549}, {-1.1112475783303504`, 
             4.333005410437451}, {-0.9363040983285557, 
             4.323199900256397}, {-0.8571220956557034, 
             4.319638219788413}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8335339533605094, 
             4.318577203107186}, {-0.7618725076900856, 
             4.315353804320388}, {-0.5175516328452967, 
             4.3071372257049445`}, {-0.272538051186673, 
             4.301723519276786}, {-0.14977149530217426`, 
             4.300067743132938}, {-0.026831762714216167`, 
             4.299112685035911}, {0.09628114657720044, 4.298858344985704}, {
             0.1106601495297239, 4.298910406582757}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13427198776160462`, 4.298995897211819}, {
             0.2195672325720745, 4.299304722982319}, {0.34306749882133725`, 
             4.300098865169482}, {0.4668229488759196, 4.300887817690922}, {
             0.5908335827358204, 4.301671580546639}, {0.715099400401039, 
             4.302450153736632}, {0.8396204018715763, 4.303223537260902}, {
             0.9643965871474329, 4.3039917311194476`}, {1.0787342694849433`, 
             4.304689477066423}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1023458270599362`, 4.30483287099363}, {
             1.214714509115102, 4.305512549839368}, {1.413334934308006, 
             4.306333710054993}, {1.6116638497059474`, 4.306403327808572}, {
             1.8097012553089273`, 4.3057214031001045`}, {2.0074471511169456`, 
             4.304287935929593}, {2.046813001936612, 4.303852317531989}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0704235493752945`, 4.303591045677638}, {
             2.204901537130001, 4.302102926297034}, {2.4020644133480946`, 
             4.299166374202431}, {2.598935779771227, 4.295478279645782}, {
             2.795515636399396, 4.291038642627087}, {2.9916440421531587`, 
             4.2863340604692075`}, {3.0147260157399387`, 
             4.285804823298259}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0383318045312953`, 4.285263575781837}, {
             3.1871610559530708`, 4.2818511304950055`}, {3.3820666777991315`, 
             4.27758985270448}, {3.5763609076913405`, 4.2735502270976315`}, {
             3.7700437456296987`, 4.26973225367446}, {3.9631151916142056`, 
             4.266135932434965}, {3.9826097260398567`, 
             4.265794107725338}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.0062180900652065`, 4.265380149535748}, {
             4.155575245644862, 4.262761263379147}, {4.347423907721666, 
             4.259608246507007}, {4.5287339120309875`, 4.257082219976318}, {
             4.709534767025615, 4.255268876376398}, {4.939586745679806, 
             4.253975305801183}, {4.950618615209474, 4.253967716395435}}]}, 
           {Arrowheads[{{0.014455472502543724`, 1.}}], 
            ArrowBox[{{4.974230602619914, 4.253951472462121}, {
             5.168841368563642, 4.253817589436974}, {5.184241807544115, 
             4.2538451938126896`}, {5.199638594293858, 4.253877864187139}, {
             5.3950673047807935`, 4.255173317771485}, {5.589850404697967, 
             4.257271351596269}, {5.656854249492381, 4.258144303850427}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.037446437807847}, {-5.518044929720773, 
             3.0334559863429287`}, {-5.356110869159577, 
             3.028351408754789}, {-5.193880535973932, 
             3.0226326213283086`}, {-5.031458882336793, 
             3.0161669801087694`}, {-4.868948013315926, 
             3.0088424483303338`}, {-4.7131086128023165`, 
             3.0009068089253113`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689532940511743, 
             2.999599368655443}, {-4.5440528138681415`, 
             2.99127160197782}, {-4.3818584580508295`, 
             2.9809042498164655`}, {-4.213603199068115, 
             2.9689417397801523`}, {-4.045746185333022, 
             2.955748762962546}, {-3.8783896503046615`, 
             2.941355378754102}, {-3.7477658068334847`, 
             2.9289977501073334`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7242587740447184`, 
             2.926773874480407}, {-3.711678843190026, 
             2.9255837539804035`}, {-3.5456954166378205`, 
             2.908563413871134}, {-3.380566263997108, 
             2.890205238027404}, {-3.2163824939646157`, 
             2.870593051158171}, {-3.0532352152370703`, 
             2.8498106779723917`}, {-2.8912273168256877`, 
             2.827883897293537}, {-2.786749178110282, 2.8129382337471824`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.763375131178094, 
             2.8095945616119353`}, {-2.7304522634900947`, 
             2.8048849246534675`}, {-2.570987027549635, 
             2.7809672398237235`}, {-2.412908581323652, 
             2.7562843225758464`}, {-2.2564170389110045`, 
             2.730729067906031}, {-2.1016140009869404`, 
             2.7044028386307497`}, {-1.9484286697353888`, 
             2.6777718162519593`}, {-1.8312939881298105`, 
             2.6573250712942404`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8080337103474804`, 
             2.6532648138116404`}, {-1.7967902473402784`, 
             2.6513021822716163`}, {-1.5835194590816417`, 
             2.614903539768837}, {-1.3739171765524247`, 
             2.579674386511528}, {-1.1671537319943748`, 
             2.547337347738383}, {-0.962768198875131, 
             2.5188494374709}, {-0.8748391190432478, 
             2.5085414183586567`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8513877238316865, 
             2.5057921864718713`}, {-0.7597305528777515, 
             2.4950471192907555`}, {-0.5570107696852961, 
             2.4767668567796295`}, {-0.352999320181242, 
             2.463787618578172}, {-0.14608667524906574`, 2.455888373327036}, {
             0.06491943754554483, 2.4512464815135564`}, {0.09102467064578836, 
             2.4508593928406532`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.11463406828848322`, 2.450509312442349}, {
             0.2812112906369026, 2.4480393036250705`}, {0.5025053183202707, 
             2.443849391268396}, {0.7285179548909132, 2.43625929605035}, {
             0.8785974453236097, 2.4289412207351084`}, {1.0291190098154839`, 
             2.419179499672618}, {1.0583385412257922`, 
             2.416817108951949}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.0818737385361978`, 2.4149142950103255`}, {
             1.180082648366536, 2.406974132862879}, {1.3314883609767665`, 
             2.3923251203058906`}, {1.4827460919872057`, 
             2.3757972715792786`}, {1.6332657857388846`, 
             2.3579553962606683`}, {1.7830474422318032`, 
             2.3387994943500585`}, {1.9320910614659619`, 2.31832956584745}, {
             2.0198900547375485`, 2.30599089799115}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0432722822514613`, 2.3027049202334986`}, {
             2.135476306922018, 2.289747199500813}, {2.337881517711394, 
             2.261942220952315}, {2.539306693834088, 2.2349146302019562`}, {
             2.739751835290101, 2.208664427249737}, {2.87045736765263, 
             2.1922247320670962`}, {2.97963248641749, 2.1792692967882505`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0030814138656647`, 2.1764994446048984`}, {
             3.132233690568056, 2.162089957428217}, {3.2633044811209526`, 
             2.1483948779719784`}, {3.3944970244039716`, 
             2.1356146704245407`}, {3.5258113204171124`, 
             2.1237493347859036`}, {3.6572473691603764`, 
             2.1127988710560675`}, {3.788805170633762, 2.102763279235032}, {
             3.94368413716897, 2.0920726232160707`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9672483749881358`, 2.090573549151593}, {
             4.111238177973705, 2.0816871757581312`}, {4.27189976251029, 
             2.072875836559801}, {4.4327191177500325`, 2.0651181663913705`}, {
             4.593696243692931, 2.0584141652528407`}, {4.754831140338988, 
             2.0527638331442106`}, {4.776438129806152, 2.0520771464529743`}, {
             4.798046966101453, 2.0514061152354977`}, {4.910731838538108, 
             2.0486392758693155`}}]}, 
           {Arrowheads[{{0.015301760477448155`, 1.}}], 
            ArrowBox[{{4.934336717058931, 2.0480596869172842`}, {
             4.98148717002643, 2.0469019651523053`}, {5.164967223012316, 
             2.043362700672609}, {5.405108393377947, 2.039477537241934}, {
             5.645171743083242, 2.0370104706993284`}, {5.656854249492381, 
             2.0369524832518366`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.813933658794763}, \
{-5.648589517501285, -3.8136534327910847`}, {-5.445074890877441, \
-3.8062073385893718`}, {-5.236993102058085, -3.797731781907807}, \
{-5.025325881386575, -3.7880885950416183`}, {-4.811054959206267, \
-3.777139610286033}, {-4.713353065796009, -3.7714424011170697`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689781114745335, -3.770067869560221}, \
{-4.5957783480980385`, -3.764586364490488}, {-4.380601034852752, \
-3.7502586308610537`}, {-4.165765211128749, -3.7342105962279053`}, \
{-3.9515130685843673`, -3.716496447421219}, {-3.7481137284709263`, \
-3.6979196063937887`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7246108364321207`, -3.695654641841197}, \
{-3.5259460182749787`, -3.675773474626376}, {-3.3150475486369233`, \
-3.6530333617928084`}, {-3.1056199925841828`, -3.629036287099491}, \
{-2.8980125632833142`, -3.6037139966252894`}, {-2.78617754143931, \
-3.5893183336819696`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7627587692452495`, -3.5863038151036806`}, \
{-2.692423629312162, -3.577250113044586}, {-2.488787581218324, \
-3.5502690430739143`}, {-2.287038809549393, -3.52339519342981}, \
{-2.146191401049043, -3.504917321786502}, {-2.006341432876187, \
-3.487076395326466}, {-1.8674021546082151`, -3.4700595315910405`}, \
{-1.8261531244068427`, -3.464646974566025}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.802741816781397, -3.4615750226453543`}, \
{-1.7302121536636719`, -3.4520579276806145`}, {-1.593542465722277, \
-3.435722415430825}, {-1.4576099668405518`, -3.420585200988324}, \
{-1.3224146570184947`, -3.4066462843531125`}, {-1.187956536256105, \
-3.393905665525189}, {-1.0539312021968286`, -3.382529807965216}, \
{-0.9200342524841112, -3.3726851751338542`}, {-0.8629692260114357, \
-3.3691387152300423`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8394027000753079, -3.367674109946022}, \
{-0.7862656871179516, -3.3643717670311046`}, {-0.6526255060983488, \
-3.357589583656966}, {-0.48013401125320415`, -3.3508195306567634`}, \
{-0.3065539572738833, -3.345999170977105}, {-0.1318853441603851, \
-3.34312850461799}, {0.04387182808729084, -3.3422075315794184`}, {
             0.10457678268282664`, -3.3421765290851817`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12818877260152767`, -3.342164470257591}, {
             0.22097485590592736`, -3.342117083680465}, {
             0.3996810357323099, -3.341737992740204}, {
             0.5799903675664367, -3.341070258758635}, {
             0.7619028514083079, -3.3401138817357587`}, {
             1.0059541490683819`, -3.337281920123681}, {
             1.072630726814171, -3.335768624691925}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0962366407616948`, -3.335232863515408}, {
             1.2509936341449437`, -3.3317204899198103`}, {
             1.3738839469644075`, -3.3279162240959526`}, {
             1.4970213066379936`, -3.3234295911241465`}, {
             1.620405713165702, -3.3182605910043925`}, {
             1.7440371665475314`, -3.31240922373669}, {
             1.8676800108054394`, -3.306066121318893}, {
             1.9910985899613827`, -3.299421915748857}, {
             2.0398705484859323`, -3.296672305821286}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.063445107100607, -3.295343246206582}, {
             2.1142929040153606`, -3.2924766070265803`}, {
             2.237262952967373, -3.285230195152064}, {
             2.4825302555655018`, -3.2698340619463115`}, {
             2.72690049775577, -3.2532335161315995`}, {
             2.9260819665497575`, -3.239563089276918}, {
             3.005948530064184, -3.234384714389546}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.029511047248098, -3.232856971841234}, {
             3.124919463306621, -3.226670896918001}, {
             3.3234129880263596`, -3.214556939054849}, {
             3.521562540708974, -3.2032212156874618`}, {
             3.7193681213544636`, -3.19266372681584}, {
             3.9168297299628296`, -3.1828844724399823`}, {
             3.9725155613486556`, -3.1803416798007142`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9961029757770543`, -3.1792646032393113`}, {
             4.11394736653407, -3.17388345255989}, {
             4.310721031068187, -3.1656606671755627`}, {
             4.490422192633437, -3.1590060962113498`}, {
             4.669859698187224, -3.153380658531568}, {
             4.810511832545903, -3.149657939589618}, {
             4.939995015339201, -3.1467537437283037`}}]}, 
           {Arrowheads[{{0.014680987795275784`, 1.}}], 
            ArrowBox[{{4.963602111233071, -3.146275240257801}, {
             5.091342005780818, -3.143927174712865}, {
             5.231520044657053, -3.141919128778062}, {
             5.2503466039949, -3.1416876898781085`}, {
             5.269170296745094, -3.1414657343286434`}, {
             5.46707384236604, -3.1402439548967394`}, {
             5.656854249492381, -3.1399969501480944`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.809927048095447}, {-5.64364134191467, 
             3.8094705156682727`}, {-5.606823920788656, 
             3.808185863021528}, {-5.56936494756303, 
             3.806864062542139}, {-5.531355898704742, 
             3.805505556247424}, {-5.5236982886848365`, 
             3.805229534224631}, {-5.516025322331551, 
             3.8049521814299383`}, {-5.510261219503242, 
             3.804743308547815}, {-5.375085353510731, 
             3.7996471307222524`}, {-5.238964605515609, 
             3.7941364729900933`}, {-5.102317667743687, 
             3.7881602499336746`}, {-4.965563232420768, 
             3.781667376135332}, {-4.828758773863638, 
             3.774619207658538}, {-4.71331980522314, 
             3.7681702583927543`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689745385594743, 
             3.7668394281793725`}, {-4.482121774693823, 
             3.7539427101312244`}, {-4.272689010656515, 
             3.7392201547125485`}, {-4.06366347427716, 
             3.722809434310738}, {-3.855045165555756, 
             3.7047105489257923`}, {-3.7480854484274966`, 
             3.6946090617247473`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.724578057289294, 
             3.6923889772192156`}, {-3.6473108698029377`, 
             3.685091711235254}, {-3.440937372329338, 
             3.664121133916664}, {-3.2359246731349574`, 
             3.6417988169700233`}, {-3.032272772219797, 
             3.6181247603953306`}, {-2.8302567002350596`, 
             3.593591580749694}, {-2.7859141592455376`, 3.588073906617706}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7624828693944017`, 
             3.5851582815992553`}, {-2.630151487831946, 
             3.5686918945902213`}, {-2.4319571350104585`, 
             3.5434257019169118`}, {-2.235673641770597, 
             3.5177930027297655`}, {-2.096573740561027, 
             3.4995917591397085`}, {-1.9585131604582915`, 
             3.481894266040547}, {-1.82565166112227, 3.465222499638225}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8022169291801176`, 
             3.4623347744184967`}, {-1.6855099635733248`, 
             3.4480105313149125`}, {-1.5504086706258438`, 
             3.4321768196451394`}, {-1.416029346454701, 
             3.417551918379663}, {-1.2823719910598939`, 
             3.4041358275184828`}, {-1.1494366044414241`, 
             3.3919285470615996`}, {-1.0168979408056722`, 
             3.3810834779420653`}, {-0.8844307543590196, 
             3.3717540210929333`}, {-0.8623715817671357, 
             3.370452113749146}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8388006046095279, 
             3.3690609814147887`}, {-0.752035045101467, 
             3.3639401765142027`}, {-0.6197108130330127, 
             3.357641944205874}, {-0.4486323895485522, 
             3.3514039847719497`}, {-0.2764130988558632, 
             3.3469723301927825`}, {-0.10305294095494444`, 
             3.344346980468373}, {0.07144808415420545, 3.3435279355987215`}, {
             0.1051858295073285, 3.3435122714256695`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.12879781996031192`, 3.3435013085619487`}, {
             0.24729937280344283`, 3.343446289211627}, {0.42471032132462605`, 
             3.3430331349348883`}, {0.6036809297177556, 
             3.3422884727685065`}, {0.7842111979828315, 
             3.3412123027124805`}, {1.0290618064877415`, 3.338166820997859}, {
             1.0732410978047355`, 3.3371262766524525`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0968465443549702`, 3.3365703031817056`}, {
             1.2748235751843402`, 3.332378452486026}, {1.398046144604523, 
             3.3284556856811545`}, {1.5214965040726278`, 
             3.3238471971769803`}, {1.6451746535886542`, 3.318552986973503}, {
             1.7690805931526037`, 3.3125730550707226`}, {1.8929882999243681`, 
             3.306107453855953}, {2.0166717510638406`, 3.299356235716508}, {
             2.0404796785803594`, 3.2979992492363674`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.064053410789869, 3.2966556112455105`}, {
             2.1401309465710217`, 3.2923194006523877`}, {2.263365886445911, 
             3.2849969486635917`}, {2.3863765706885087`, 3.27738887975012}, {
             2.509162999298815, 3.2694951939119736`}, {2.7540630896225524`, 
             3.252850971461654}, {2.949824132321762, 3.239434396039549}, {
             3.0065608127130776`, 3.2357608491415277`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.030123467532907, 3.2342352308479385`}, {
             3.145257873637893, 3.2267805888511676`}, {3.340364313570946, 
             3.21488954989651}, {3.535143452120921, 3.2037612791755765`}, {
             3.7295952892878175`, 3.1933957766883667`}, {3.9237198250716356`, 
             3.183793042434881}, {3.973117643590895, 3.1815397851141}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9967051103126776`, 3.1804638543612302`}, {
             4.117517059472375, 3.174953076415119}, {4.310986992490037, 
             3.166875878629081}, {4.490697270979993, 3.1602259528587697`}, {
             4.670144124056456, 3.154604043844778}, {4.810769850409031, 
             3.15088490314113}, {4.940597871446306, 3.147975482638879}}]}, 
           {Arrowheads[{{0.014668217278499486`, 1.}}], 
            ArrowBox[{{4.964205006962416, 3.147498924151554}, {
             5.091546233607008, 3.145160505173984}, {5.231696890452409, 
             3.1431552479104865`}, {5.250519788940173, 3.1429241655714177`}, {
             5.269339815524884, 3.142702562522078}, {5.467248013266694, 
             3.14148397687065}, {5.656854249492381, 
             3.1412402907014934`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.0358649526587573`}, \
{-5.57756033055079, -3.033692828896652}, {-5.454332519069914, \
-3.029900483181047}, {-5.3309537644974805`, -3.0257681057817942`}, \
{-5.207407699746156, -3.021213239136293}, {-5.083709077326597, \
-3.0161856236716087`}, {-4.959903769347452, -3.0106671978044752`}, \
{-4.836037647917363, -3.0046398999516244`}, {-4.713159208508761, \
-2.998138714777603}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689585668126954, -2.9967918785975507`}, \
{-4.588306453138934, -2.990986441955702}, {-4.4645331240078825`, \
-2.9833241586460955`}, {-4.3408824698604676`, -2.9750807570177025`}, \
{-4.2173914089428095`, -2.9661460385829246`}, {-4.094100115451035, \
-2.9564433091830113`}, {-3.9710593454188032`, -2.9460047637279665`}, \
{-3.8483198548797746`, -2.9348625971277946`}, {-3.7479280677806317`, \
-2.924893583543075}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7244316363019716`, -2.9225603623566463`}, \
{-3.6039477364159547`, -2.9105961801320834`}, {-3.3613898083288456`, \
-2.883901617475909}, {-3.201045013215914, -2.8648097794472696`}, \
{-3.04185863303302, -2.8446989112945977`}, {-2.8839242268814194`, \
-2.8237110275319743`}, {-2.7868451493896607`, -2.809395776708953}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7634857581243932`, -2.80595120807815}, \
{-2.7263373901156527`, -2.8004733211899464`}, {-2.570423543336823, \
-2.7769976645513332`}, {-2.4159487887917925`, -2.7529290213309316`}, \
{-2.2629131264805644`, -2.7282673915287416`}, {-2.111316556403138, \
-2.7030127751447632`}, {-1.961233774706526, -2.6775953347314494`}, \
{-1.8310831683118642`, -2.655552057149039}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8078027276900581`, -2.651609050963532}, \
{-1.6658336648967906`, -2.627562469474178}, {-1.5205163367836667`, \
-2.6029470446302203`}, {-1.3316638577857218`, -2.5718853632757264`}, \
{-1.1452932102663573`, -2.5431027639903894`}, {-0.9609496801910642, \
-2.517474086119273}, {-0.874536395461796, -2.5072617521387146`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8510875841103259, -2.5044905683592926`}, \
{-0.7781785535253336, -2.4958741690074406`}, {-0.595803713684236, \
-2.4787206094255514`}, {-0.412649044082842, -2.466431004144263}, \
{-0.18500534427919177`, -2.456728292339073}, {
             0.04784796855510584, -2.451792482479295}, {
             0.09140447345894548, -2.4511651134881243`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.11501401753389928`, -2.450825051862863}, {
             0.28657938808857475`, -2.4483538987324094`}, {
             0.5318574079897406, -2.443142865265897}, {
             0.6565659888679541, -2.439281518370614}, {
             0.7821404114175814, -2.4337947360110888`}, {
             0.9085806756386225, -2.4266825181873224`}, {
             1.0358867815310773`, -2.4179448648993147`}, {
             1.0586649168108717`, -2.416073708617608}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0821976423019921`, -2.4141405649872136`}, {
             1.2018605095614385`, -2.4043106152126077`}, {
             1.367540607921809, -2.388247773877877}, {
             1.5329270766121883`, -2.3697563408951234`}, {
             1.698019915632576, -2.3488363162643457`}, {
             1.8624807957153187`, -2.326561917019459}, {
             2.0201518720038987`, -2.3048101990215906`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0435362186354613`, -2.3015394353174563`}, {
             2.188491691264906, -2.2811726457890975`}, {
             2.350041706731752, -2.2580577738036234`}, {
             2.5477485874625696`, -2.230374934741414}, {
             2.7451235253601585`, -2.2044651765844394`}, {
             2.942166520424519, -2.180328499332701}, {
             2.9796108311038787`, -2.1760715476260812`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.003071696685845, -2.173404339445027}, {
             3.138877572655649, -2.157964902986197}, {
             3.2783531208239234`, -2.1433337483851536`}, {
             3.417970933722068, -2.1298724816760606`}, {
             3.5771355452027453`, -2.11585762610694}, {
             3.7366464108660287`, -2.10316385652774}, {
             3.896543893290334, -2.0917051820397927`}, {
             3.9436364186977824`, -2.0886769248684716`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.967199744102604, -2.087161699075844}, {
             4.0568683550540765`, -2.081395611744429}, {
             4.0783398517138005`, -2.0800935806117447`}, {
             4.09981931326945, -2.0788106647392257`}, {
             4.261274771346722, -2.0705677473397928`}, {
             4.422898040065772, -2.0634365755839608`}, {
             4.62247780232412, -2.055290265870798}, {
             4.822198897610605, -2.048456891177512}, {
             4.910732200338137, -2.0460114953073805`}}]}, 
           {Arrowheads[{{0.015302281274012937`, 1.}}], 
            ArrowBox[{{4.934335191331067, -2.0453595524235313`}, {
             5.022061325925226, -2.042936451504102}, {
             5.222065087267984, -2.038728946850569}, {
             5.421106790484533, -2.035616652394647}, {
             5.618083044420531, -2.033381843314071}, {
             5.656854249492381, -2.0331118476315977`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.318136000310458, -5.656854249492381}, \
{-4.298718013261092, -5.655473341876259}, {-4.172678609320841, \
-5.646081871138453}, {-4.046668763222628, -5.636289299530964}, \
{-3.9206725954540564`, -5.62611948987983}, {-3.794674226502733, \
-5.615596305011086}, {-3.6686577768562643`, -5.604743607750766}, \
{-3.5426073670022546`, -5.5935852609249075`}, {-3.4163552128383414`, \
-5.582049108777329}, {-3.3769437457544904`, -5.578327630910498}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.353436320057285, -5.576107912363807}, \
{-3.2897887682948794`, -5.5700979113999285`}, {-3.162975010908546, \
-5.557807905390859}, {-3.035980918216021, -5.545255327348275}, \
{-2.908873467753982, -5.532516413870329}, {-2.7817196370591097`, \
-5.519667401555175}, {-2.654586403668082, -5.506784527000967}, \
{-2.527540745117578, -5.493944026805858}, {-2.413603317981765, \
-5.482553402643365}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.390106510253467, -5.4802240719492765`}, \
{-2.274620802362626, -5.468890976764273}, {-2.1488964917234807`, \
-5.456835797136073}, {-2.0236237770232397`, -5.445157320391393}, \
{-1.8987735248469169`, -5.433902400996581}, {-1.7743166017795255`, \
-5.423117893417979}, {-1.6502238744060789`, -5.412850652121935}, \
{-1.5264662093115913`, -5.403147531574791}, {-1.4492672985209794`, \
-5.3977356476629845`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            
            ArrowBox[{{-1.4257131124795994`, -5.39608442591403}, \
{-1.286483697876748, -5.38632401062808}, {-1.0478002668951651`, \
-5.372439603306995}, {-0.8100506180990651, -5.3615476733716205`}, \
{-0.5730318080063489, -5.3536778673553345`}, {-0.48237797434791396`, \
-5.351801721945802}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.45877103638076666`, -5.351313159614648}, \
{-0.3365899250279914, -5.348784534823557}, {-0.10057105757496793`, \
-5.34682202534171}, {-0.06782130849932755, -5.346781531529422}, \
{-0.0350831778262104, -5.346798185104881}, {
             0.15225019730853004`, -5.347579374241925}, {
             0.3396120178447598, -5.3494052766846245`}, {
             0.3517210558250245, -5.34955703118901}, {
             0.36383016217018416`, -5.3497127542812315`}, {
             0.40695798083446877`, -5.350331919489754}, {
             0.450084644809014, -5.3510015542705585`}, {
             0.4856462934752806, -5.351650367766878}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5092543575800796, -5.352081091065364}, {
             0.6903643551757133, -5.355385398237992}, {
             0.9304712799645269, -5.361072522371845}, {
             1.1703270274051045`, -5.367396351638636}, {
             1.409853205727095, -5.3736903110048795`}, {
             1.4534558766343464`, -5.374822232773123}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.4770599173855739`, -5.375434991739235}, {
             1.6489059488627655`, -5.379896100652245}, {
             1.887341390744384, -5.3859554207624}, {
             2.0491019470470664`, -5.389888155770295}, {
             2.2104126838712217`, -5.393542305950687}, {
             2.3712736012168505`, -5.3969178713035735`}, {
             2.4212708493104302`, -5.397883144316023}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.4448784429495576`, -5.398338924861906}, {
             2.5316846990839528`, -5.4000148518289555`}, {
             2.69159651689537, -5.4028888303427935`}, {
             2.8509595940739443`, -5.405595389661049}, {
             3.0097739306196756`, -5.408134529783722}, {
             3.168039526532563, -5.410506250710813}, {
             3.3257326508961738`, -5.412773022099519}, {
             3.389232458098233, -5.413672098161497}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.412842084711141, -5.414006380280691}, {
             3.482829572794073, -5.414997313607041}, {
             3.63933029222626, -5.417179125233377}, {
             3.7952348091927366`, -5.419318456978528}, {
             3.973942449514437, -5.421897538040142}, {
             4.151271200801727, -5.424750927389423}, {
             4.327221063054606, -5.427878625026374}, {
             4.357209848926498, -5.428463040781912}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.38081735958199, -5.42892309945968}, {
             4.5017920362730734`, -5.431280630950995}, {
             4.67498412045713, -5.434956945163283}, {
             4.846797315606777, -5.438907567663241}, {
             5.017231621722012, -5.4431324984508676`}, {
             5.1862870388028375`, -5.447631737526163}, {
             5.3250192412865, -5.45165143810285}}]}, 
           {Arrowheads[{{0.00653064212194687, 1.}}], 
            ArrowBox[{{5.348621329109511, -5.452335297540924}, {
             5.354188435219271, -5.452496601832496}, {
             5.521160679341329, -5.457818408313233}, {
             5.656854249492381, -5.462562552683295}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8819746087462408, -1.1050479600902945`}, {
             0.9831208761161481, -1.0415969154544444`}, {
             1.0301117090647576`, -1.0072880694585344`}, {
             1.0743654350202818`, -0.9718912400312312}, {
             1.2136252410515642`, -0.8367512335974565}, {
             1.3171541959263582`, -0.7021634946985136}, {
             1.4019743787272916`, -0.5588204680405435}, {
             1.4079560558516075`, -0.5471473506179473}, {
             1.4137067971692887`, -0.5356444813191047}, {
             1.4333643999014472`, -0.48968950761721647`}, {
             1.4470669899254773`, -0.45470357851458115`}, {
             1.4594218296992254`, -0.4221898950366384}, {
             1.4703382839818486`, -0.392639963570111}}]}, 
           {Arrowheads[{{0.002368882196939157, 1.}}], 
            ArrowBox[{{1.478520632924838, -0.3704910272725972}, {
             1.481763225537233, -0.3617135994568026}, {
             1.4997902154263847`, -0.30959223573478895`}, {
             1.5142190032334, -0.2644836489546557}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.28416647297429803`, -1.7664499050317537`}, \
{-0.12081197823646031`, -1.7501225571843055`}, {
             0.04785264566547426, -1.738850239362673}, {
             0.22296994898493044`, -1.7299361562718232`}, {
             0.4050868552793022, -1.7187004847048841`}, {
             0.5928906595975033, -1.7016359209033844`}, {
             0.6570641326063141, -1.6920483496010919`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6804169394339714, -1.688559420452157}, {
             0.8304428774389849, -1.6661454180555761`}, {
             1.0662902915199857`, -1.6153221108503735`}, {
             1.1879765137870653`, -1.584386535441506}, {
             1.3072923441369004`, -1.5505947714959318`}, {
             1.5389270274778268`, -1.4784468030057059`}, {
             1.5953346971599378`, -1.4599880888404373`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.6177757000951203`, -1.452644547419618}, {
             1.7618707631008346`, -1.4054912153348436`}, {
             1.8563287282302086`, -1.3747868254646456`}, {
             1.9499750099598319`, -1.3451472923099475`}, {
             2.100263460888156, -1.3006180243747831`}, {
             2.2501754615490115`, -1.260257212314309}, {
             2.400553260868298, -1.2240292088871174`}, {
             2.5264017576455875`, -1.1973713614156758`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.5495012033252373`, -1.192478323235866}, {
             2.552239107771915, -1.1918983668518013`}, {
             2.5724572867960367`, -1.1879059219164598`}, {
             2.5927083120774546`, -1.1839874304913387`}, {
             2.707450874104991, -1.1645794003980219`}, {
             2.8233882200595257`, -1.147079495913138}, {
             3.026835335783997, -1.1189188951098874`}, {
             3.233946963992236, -1.09530170460978}, {
             3.4444934158893776`, -1.0756887565995044`}, {
             3.4858996028589706`, -1.0725607243240203`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.5094445054290473`, -1.0707820235898422`}, {
             3.658245002680556, -1.0595408832657496`}, {
             3.8748493101739045`, -1.0464241806846126`}, {
             4.093671992824063, -1.0355576217930693`}, {
             4.324009450352314, -1.02683694670585}, {
             4.452616717603747, -1.0231776181999082`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.476219158238647, -1.0225060458566733`}, {
             4.5562376478643865`, -1.0202292387496734`}, {
             4.789815180000526, -1.0151702393973514`}, {
             5.024200641400978, -1.011095690121697}, {
             5.259140232708608, -1.0078908332309247`}, {
             5.420547438281911, -1.006387137363909}}]}, 
           {Arrowheads[{{0.00450408262997761, 1.}}], 
            ArrowBox[{{5.444158406693552, -1.0061671737291338`}, {
             5.494544500853493, -1.0056977686534792`}, {
             5.656854249492381, -1.0047605647813618`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.7428297612087187`, -0.4984006861695355}, {
             1.8808889042450634`, -0.4240114156723762}, {
             1.8925210698513668`, -0.4189987201183945}, {
             1.9042677390147067`, -0.414109655535646}, {
             1.9575018711389016`, -0.3957202710300827}, {
             2.013223028083188, -0.3791855085193747}, {
             2.129662377708764, -0.34927664725703406`}, {
             2.2565516927506533`, -0.32525509587366264`}, {
             2.3941773024614283`, -0.30615609683603234`}, {
             2.5457913798275573`, -0.2903964071969452}, {
             2.65255192161924, -0.28208487377867913`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6760926826878553`, -0.28025217586398515`}, {
             2.7070488435374687`, -0.27784217343158063`}, {
             2.8768625570711635`, -0.2678630908536876}, {
             3.0541453839086423`, -0.259828854777015}, {
             3.2379087895477108`, -0.25337308495778393`}, {
             3.4271642394861757`, -0.2481294011522154}, {
             3.5663162254720215`, -0.24497667242729237`}, {
             3.6197717207834152`, -0.2439224798580974}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.6433791235859148`, -0.24345691970441413`}, {
             3.7073245882540666`, -0.24219585508805994`}, {
             3.8501893278323114`, -0.23978694913451812`}, {
             3.994910444206756, -0.23774995456666687`}, {
             4.141066933068975, -0.2360044410387601}, {
             4.288237790110546, -0.2344699782050516}, {
             4.436423015331469, -0.2331465660655415}, {
             4.585622608731743, -0.23203420462022967`}, {
             4.587783246973577, -0.23202062013547675`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.611394773299272, -0.2318721684358104}, {
             4.735549575384182, -0.23109157546875667`}, {
             4.885916920361599, -0.23027736021076312`}, {
             5.036724643663994, -0.22959155884624893`}, {
             5.1879727452913675`, -0.22903417137521412`}, {
             5.433001721427984, -0.22835894291329498`}, {
             5.555866111401097, -0.22813352679774337`}}]}, 
           {Arrowheads[{{0.0016384960613941065`, 1.}}], 
            ArrowBox[{{5.579478064659839, -0.2280902065583694}, {
             5.656854249492381, -0.2279482464751836}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0339291685348437`, 0.9428556560601621}, {
             1.1102739164756, 0.865655363331413}, {1.1736105279976097`, 
             0.7862442552378767}, {1.223962287202885, 0.707110792725739}, {
             1.2442980530001118`, 0.6679691378260881}, {1.2614675072776564`, 
             0.6291597238605533}, {1.2944290655370565`, 0.5239508314914795}, {
             1.3030601994142856`, 0.42709324660280434`}, {1.2942945957500192`,
              0.36334122196133667`}, {1.2725144983955907`, 
             0.304787259899639}, {1.2338924514335, 0.25018411288065123`}, {
             1.2247506100996253`, 0.24016225543539194`}, {1.214772066151362, 
             0.23023407585341568`}, {1.196147171314933, 0.2156172348902885}, {
             1.1746988991980647`, 0.20100338536675572`}, {1.1249671765766636`,
              0.17172743491825798`}, {1.108709201263879, 
             0.16445925048133564`}}]}, 
           {Arrowheads[{{0.002770975312434325, 1.}}], 
            ArrowBox[{{1.0871532131872068`, 0.1548225710026707}, {
             1.0587202672113396`, 0.1421115235652235}, {1.0392076900175637`, 
             0.13468498953221816`}, {1.0201179554587432`, 
             0.12783303291698925`}, {1.0035666454756846`, 
             0.12216675905195651`}, {0.9793690396259057, 
             0.11425252283833873`}, {0.9644749098208807, 
             0.1096196602177438}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.5759335011742466`, 0.6218909739673925}, {
             1.6853075815927347`, 0.5270560436658636}, {1.6951742331029929`, 
             0.519297642506965}, {1.705091971084063, 0.5117322985143364}, {
             1.741416246149261, 0.48774496745738155`}, {1.778844501446237, 
             0.4657788713380222}, {1.8562218278087428`, 
             0.42541742787340414`}, {1.9390934856133677`, 
             0.3916000360627357}, {2.028213927114665, 0.3632369892133172}, {
             2.1508115529219554`, 0.3341287407716714}, {2.285155408182858, 
             0.31113941102789844`}, {2.431353915964298, 
             0.29288122939852496`}, {2.4391457013319062`, 
             0.29216817991831523`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.4626594402375144`, 0.2900163676553476}, {
             2.5883998044482572`, 0.2785094925154624}, {2.755383831485317, 
             0.26713487428186256`}, {2.930936937152189, 0.2580949594798101}, {
             3.1139448181200353`, 0.2508296074339236}, {3.3033180187675337`, 
             0.24499440745082207`}, {3.4057286214916656`, 
             0.24245304384357969`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.429333347644674, 0.24186728230709334`}, {
             3.4528762163495816`, 0.24128305579006065`}, {3.6052953764570996`,
              0.23818105822890323`}, {3.76015352034544, 0.2355606092675777}, {
             3.9170286692699556`, 0.23329390340631198`}, {4.07565428163357, 
             0.2313368769793258}, {4.235852637066389, 0.22969331879740557`}, {
             4.373710131623846, 0.22850999085762055`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.397321254804344, 0.2283073199630212}, {
             4.397334988664542, 0.22830720207562924`}, {4.559812589524155, 
             0.22712250002907483`}, {4.723112031388119, 
             0.22611700597950923`}, {4.887125813797472, 
             0.22528783902395005`}, {5.05166405154557, 
             0.22460796104035144`}, {5.216536859425761, 
             0.22405033390666756`}, {5.341788655258878, 
             0.2237105781022051}}]}, 
           {Arrowheads[{{0.003826381243573924, 1.}}], 
            ArrowBox[{{5.365400561387592, 0.2236465288635631}, {
             5.381460394663432, 0.22360296524407267`}, {5.546097124445129, 
             0.2232624602412952}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.574848204798103}, {-5.499704667627695, 
             5.567057209102554}, {-5.303406009804531, 
             5.557216429749433}, {-5.110064862507064, 
             5.547126363858183}, {-4.913962815521031, 
             5.53622167691479}, {-4.713735704955135, 5.5242833651239}}]}, 
           {Arrowheads[{{0.00398832766358368, 1.}}], 
            ArrowBox[{{-4.690168401784991, 
             5.522831352280034}, {-4.685467211204028, 
             5.522540464383584}, {-4.502238430442219, 
             5.510339593573177}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.574406348060539}, \
{-5.503027803841868, -5.56678138331595}, {-5.306496205507393, \
-5.556933439105637}, {-5.113028517131211, -5.546844963787496}, \
{-4.916916418059769, -5.5359505873317065`}, {-4.715888841391421, \
-5.523977742550704}, {-4.713735488102431, -5.523845335323758}}]}, 
           {Arrowheads[{{0.003928234303531032, 1.}}], 
            ArrowBox[{{-4.69016823945995, -5.522392410363977}, \
{-4.688465559082721, -5.522287176182299}, {-4.505069874864629, \
-5.510088277223342}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.7854380078362087`}, {-5.598810298945935, 
             1.7843001957169369`}, {-5.4094728469467945`, 
             1.780027659218694}, {-5.215971286846466, 
             1.7751124644932372`}, {-5.1898162438518805`, 
             1.7744121936308368`}, {-5.163660453281088, 
             1.7736954906554077`}, {-4.968759423652566, 
             1.7672286161757833`}, {-4.773952334763361, 
             1.7596303414187286`}, {-4.712828614047415, 
             1.7569728186602287`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689238906524023, 
             1.755947190902699}, {-4.553414795182348, 
             1.7500418621233702`}, {-4.333216823817586, 
             1.738493404336392}, {-4.113358420669075, 
             1.724984968057794}, {-3.893839585736816, 
             1.7095165532875762`}, {-3.746643327955557, 
             1.6974435169975404`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7231103587078924`, 
             1.6955133429834595`}, {-3.6746971488326166`, 
             1.6915424917637911`}, {-3.455967939768284, 
             1.6705171152244906`}, {-3.2376519585438186`, 
             1.646440423669675}, {-3.0197492051592207`, 
             1.619312417099344}, {-2.839288813806382, 
             1.593948178059358}, {-2.7852548444437164`, 
             1.5853881132720804`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7619336826324172`, 
             1.5816935733673878`}, {-2.658867556165385, 
             1.5653658312018985`}, {-2.4784854322362304`, 
             1.5335653765269652`}, {-2.2981424420189187`, 
             1.4985468140345584`}, {-2.1641251744210974`, 
             1.4698779646802023`}, {-2.0296876693626014`, 
             1.4382297116083138`}, {-1.89482992684343, 
             1.403602054818893}, {-1.8381217349940842`, 
             1.3878372688394158`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.815372451568623, 
             1.3815130046953281`}, {-1.7595519468635838`, 
             1.3659949943119396`}, {-1.5503774503585952`, 
             1.3005373907005278`}, {-1.3382528834811735`, 
             1.2240330636663035`}, {-1.1770428321834043`, 
             1.1582714689319606`}, {-1.0106279929286532`, 
             1.082805446763734}, {-0.9342946045439016, 
             1.0453388185195813`}}]}, 
           {Arrowheads[{{0.010678231791773353`, 1.}}], 
            ArrowBox[{{-0.9130982103377796, 
             1.0349350170030758`}, {-0.8235140831692164, 
             0.9909645440524483}, {-0.6731400165330337, 
             0.9156462469913664}, {-0.6317977738183627, 
             0.89543218080665}, {-0.5882333300312785, 
             0.8749717939395755}, {-0.5489730544485143, 
             0.857083774739631}, {-0.5207987671470414, 
             0.8443896199741021}, {-0.502194308013748, 
             0.8360443467085122}, {-0.48987354747790984`, 
             0.8305282080593812}, {-0.4788577920337947, 
             0.8255998126635243}, {-0.47233656327402435`, 
             0.8226812135462246}, {-0.4681793129472883, 
             0.8208168805443455}, {-0.4629019282063096, 
             0.8184437238011238}, {-0.45865958682231744`, 
             0.8165305356550409}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.14349150468385033`, 
             1.7484884829203153`}, {-0.01302206125454966, 
             1.7389826114459856`}, {0.12114665045729217`, 
             1.731343587143941}, {0.25972164541463233`, 
             1.7240524748507915`}, {0.402345770232199, 1.7150958442444924`}, {
             0.5486618715247218, 1.7024602650029994`}, {0.6972543943460918, 
             1.6848855070420752`}, {0.7971165667734257, 
             1.6690000195986117`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8204353667864275, 1.6652906019502751`}, {
             0.8467077837502006, 1.6611113402774818`}, {1.0377560894018678`, 
             1.6222223698862}, {1.224390744908023, 1.5748559795015942`}, {
             1.4059266628073281`, 1.5219859092577328`}, {1.5816787556384464`, 
             1.466585899288684}, {1.7310137599792348`, 
             1.418115022196469}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7534737643935105`, 1.4108298469846035`}, {
             1.9202281345783008`, 1.3578168635471068`}, {2.019382344045799, 
             1.3275185495246662`}, {2.1181097769163615`, 
             1.2991163427243217`}, {2.268073063918852, 1.2593041512261243`}, {
             2.418669374408645, 1.2232969767520856`}, {2.5705047615377046`, 
             1.1912869991231354`}, {2.666856524534694, 
             1.1738445542112375`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.69009087511796, 1.1696384673944866`}, {
             2.7241852784579974`, 1.1634663981602036`}, {2.7447253292498512`, 
             1.1600485390471842`}, {2.76530241566285, 1.1566932192393078`}, {
             2.885662811690947, 1.1395876923193045`}, {3.0073325960304453`, 
             1.1241992261668803`}, {3.227223406389973, 1.0988582484767526`}, {
             3.451101930974724, 1.0779533532653052`}, {3.6283569491480727`, 
             1.064666152793478}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6519028808678295`, 1.0629011279254632`}, {
             3.678515803517939, 1.0609061985743098`}, {3.909012657752859, 
             1.0471384424455388`}, {4.142191344200083, 1.0361951389789843`}, {
             4.3773297937966875`, 1.0272573855546319`}, {4.534307425189945, 
             1.022628636043286}, {4.595385624133204, 
             1.0211952642630404`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.618991117801543, 1.020641294940625}, {
             4.692050999657045, 1.0189267392606673`}, {4.850415558703326, 
             1.0160179892879344`}, {5.009256143834127, 1.0137686802062444`}, {
             5.168427796554786, 1.012045106096756}, {5.327785558370643, 
             1.0107135610406266`}, {5.487184470787033, 1.0096403391190143`}, {
             5.563388227485428, 1.0091865446196102`}}]}, 
           {Arrowheads[{{0.0014792413694961638`, 1.}}], 
            ArrowBox[{{5.586999801827907, 1.0090459373448102`}, {
             5.646479575309297, 1.008691734413077}, {5.653397365589752, 
             1.0086517526940926`}, {5.656854249492381, 
             1.0086320964302733`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.006620594288572325, 1.}}], 
            ArrowBox[{{1.2266422685031206`, -0.29076289516648657`}, {
             1.1831215542592084`, -0.2423164817820642}, {
             1.1710932177309068`, -0.23139661849154533`}, {
             1.1579132626147328`, -0.22052687788890535`}, {
             1.1438737673515926`, -0.21085381126450342`}, {
             1.1285058218960675`, -0.20113106474394807`}, {
             1.0946550462210034`, -0.18152570291109796`}, {
             1.0537366682679306`, -0.16149646795518607`}, {
             1.0090916314937934`, -0.14260651786059297`}, {
             0.9807959694466458, -0.1317426051993112}, {
             0.9662112448043623, -0.12649357509052914`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.350345083730968}, {-5.61507477261222, 
             0.3501879515250515}, {-5.587339793114957, 
             0.3500743424892954}, {-5.559595957822884, 
             0.3499576627397146}, {-5.351751443657324, 
             0.3488627536007324}, {-5.143602820400158, 
             0.34752719719266545`}, {-5.007766529081831, 
             0.3465708757342421}, {-4.871842161898176, 
             0.3454444952044682}, {-4.7358297188491925`, 
             0.3441480556033435}, {-4.71239804373962, 
             0.3438955766215132}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688787421335003, 
             0.3436411694620924}, {-4.599729199934881, 
             0.34268155693086816`}, {-4.4635406051552415`, 
             0.3410449991870421}, {-4.327263934510273, 
             0.3392383823718654}, {-4.190899187999976, 
             0.33726170648533793`}, {-4.054446365624352, 
             0.3351149715274598}, {-3.9175895680978883`, 
             0.33268912789562105`}, {-3.7800128961350743`, 
             0.32987512598721186`}, {-3.7444257019566316`, 
             0.3290511292984989}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.720820035866435, 
             0.32850455654551214`}, {-3.6417163497359097`, 
             0.3266729658022322}, {-3.502699928900396, 
             0.3230826473406821}, {-3.362963633628532, 
             0.3191041706025615}, {-3.222507463920317, 
             0.3147375355878705}, {-3.0813314197757524`, 
             0.30998274229660894`}, {-2.939435501194838, 
             0.304839790728777}, {-2.796054243363998, 
             0.2991356569066043}, {-2.7768377662609187`, 
             0.2982861035003994}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7532488142153317`, 
             0.2972432445803364}, {-2.6504221814696587`, 
             0.2926973168523207}, {-2.501785961839615, 
             0.28537186061565556`}, {-2.3493922308016617`, 
             0.2770063782463382}, {-2.19206017720105, 
             0.26737667660309283`}, {-2.0276643409592303`, 
             0.2560792080316229}, {-1.9069681479797835`, 
             0.24705344606159996`}, {-1.8106116405984758`, 
             0.23927925522232407`}}]}, 
           {Arrowheads[{{0.00015201106154712752`, 1.}}], 
            ArrowBox[{{-1.787076125677968, 
             0.23738037377191412`}, {-1.7799208084637186`, 
             0.2368030718018562}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.0238740727006745`}, {-5.608530969176459, 
             1.0233630575832742`}, {-5.581265233912761, 
             1.0230476288829538`}, {-5.553992836685363, 
             1.0227238784839603`}, {-5.346429189512536, 
             1.0196452631855613`}, {-5.138664126310113, 
             1.0159035245452335`}, {-4.914084829501177, 
             1.0112787073274}, {-4.71255196657028, 1.0060872896892203`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688947880371476, 
             1.005476547969866}, {-4.4648265174694695`, 
             0.9985456981494275}, {-4.240147502246697, 
             0.9904375061892883}, {-4.01523688885511, 
             0.9807044572246337}, {-3.7898963185971732`, 
             0.9688828191650509}, {-3.745326449558992, 0.9661367698446868}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7217591457309505`, 
             0.9646847355431193}, {-3.564125791472885, 
             0.9549725920105399}, {-3.3379253074822466`, 
             0.9389737757611003}, {-3.1759079342401204`, 
             0.9258394352953289}, {-3.0126115568908256`, 
             0.9107314060278939}, {-2.8480361754343626`, 
             0.8936496879587954}, {-2.7806994075773037`, 
             0.8859132057155445}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.757241730729201, 
             0.8832180971414516}, {-2.682181789870731, 
             0.8745942810880333}, {-2.5547256250633628`, 
             0.8583890396591263}, {-2.425350450176361, 
             0.8402282212715022}, {-2.2940562652097256`, 
             0.8201118259251612}, {-2.1608430701634567`, 
             0.7980398536201032}, {-1.9646400831357138`, 
             0.7614918715721514}, {-1.8254059942231984`, 
             0.7317918491847246}}]}, 
           {Arrowheads[{{0.010073515107777648`, 1.}}], 
            ArrowBox[{{-1.8023135242399413`, 
             0.7268659945981035}, {-1.7592896531620963`, 
             0.7176885730041098}, {-1.611923501764032, 
             0.6825831328814672}, {-1.4555965657855061`, 
             0.6418349741556497}, {-1.3412249021981093`, 
             0.6101498181332848}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.0276728720802977`}, \
{-5.627430574379744, -1.027365902463698}, {-5.600173998594249, \
-1.0270549828089806`}, {-5.5729105474687515`, -1.0267358849968085`}, \
{-5.364734986395789, -1.0236904210401139`}, {-5.156346497272813, \
-1.0199856065802726`}, {-4.931568001653188, -1.01541294918382}, \
{-4.71255251552902, -1.009834458122768}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688950734352104, -1.0091420510828966`}, \
{-4.481898806781909, -1.0028069107760058`}, {-4.257008107530253, \
-0.9947735297646442}, {-4.0318951835769505`, -0.9851260268208188}, \
{-3.8063752114310345`, -0.9734038545503694}, {-3.745336132226843, \
-0.9696763388873487}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7217680441326526`, -0.9682370901525397}, \
{-3.5804481910925032`, -0.9596070129532959}, {-3.3541141225613575`, \
-0.9437355020295981}, {-3.1909428785396226`, -0.9306116928940608}, \
{-3.0265119248110337`, -0.9155045583941432}, {-2.8608212613755915`, \
-0.8984140985298458}, {-2.780726951771733, -0.8892634651370045}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.757267566084884, -0.8865832717611783}, \
{-2.6938708882332967`, -0.8793403133011682}, {-2.5656740473086908`, \
-0.8631236417660799}, {-2.4355775803185615`, -0.8449458211721719}, \
{-2.3035814872629095`, -0.8248068515194441}, {-2.169685768141734, \
-0.8027067328078966}, {-1.972772759601974, -0.7661449137865399}, \
{-1.8254876690228616`, -0.7348053213636602}}]}, 
           {Arrowheads[{{0.009973053151938213, 1.}}], 
            ArrowBox[{{-1.8023927133381354`, -0.7298911342226676}, \
{-1.7667980169162132`, -0.7223172292612554}, {-1.6183332023122587`, \
-0.6869957501981696}, {-1.4608932829435675`, -0.6459535708694569}, \
{-1.3459696705550959`, -0.6140657528684811}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.474736632671769}, {-5.585393180369041, 
             2.472964891302723}, {-5.443414628292574, 
             2.469125572506309}, {-5.3010066481184275`, 
             2.4648404264031285`}, {-5.158276621583668, 
             2.460046231484111}, {-5.015331930425363, 
             2.454679766240186}, {-4.80731349057835, 
             2.44562802230475}, {-4.713016005302809, 2.440768768823059}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68943530029388, 
             2.4395536290705984`}, {-4.599594095441849, 
             2.434924012637022}, {-4.392173745015861, 
             2.4225677372370016`}, {-4.185052439300387, 
             2.4085591961046893`}, {-3.9785178326969683`, 
             2.392613467301091}, {-3.7728575796071486`, 
             2.3744456288872136`}, {-3.7474568294379815`, 
             2.371916548629268}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7239610134768633`, 
             2.3695771372380356`}, {-3.568071680030929, 
             2.3540556808630577`}, {-3.3641601339683094`, 
             2.331443623228623}, {-3.161446962566783, 
             2.306511411749924}, {-2.960256186973844, 
             2.279161002192974}, {-2.786797248411175, 2.2532999665674667`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7634433826003506`, 
             2.249818132995028}, {-2.760587807189493, 
             2.2493923945577734`}, {-2.562441823213729, 
             2.217205588844322}, {-2.388091744546789, 
             2.186485302929231}, {-2.2153052860606097`, 
             2.153586235238643}, {-2.0442103241841942`, 
             2.1187473942963666`}, {-1.874934735346544, 
             2.082207788626209}, {-1.8357981956875915`, 2.073276761543495}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8127779963273256`, 
             2.068023511620849}, {-1.7077372917971014`, 
             2.044053038372015}, {-1.5428767657853089`, 
             2.0043687636776286`}, {-1.4664035423998285`, 
             1.9852223584883966`}, {-1.3905291392835395`, 
             1.965819072824268}, {-1.2310144827900418`, 
             1.9244777016532844`}, {-1.0741280603640875`, 
             1.8833908054226935`}, {-0.9198371610495639, 
             1.843449560832774}, {-0.8968628151680885, 
             1.8377101543349807`}}]}, 
           {Arrowheads[{{0.005492461287047903, 1.}}], 
            ArrowBox[{{-0.8739548369017128, 
             1.8319873276659806`}, {-0.7681090738903583, 
             1.8055451445838036`}, {-0.7491259810454682, 
             1.800890934885729}, {-0.7301753844398071, 
             1.7962918052311427`}, {-0.6757680277705831, 
             1.7836860840988817`}, {-0.6217026593514606, 
             1.7716787585740983`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.4632423582222955`, -5.398025064203132}, \
{-4.222182101348322, -5.380845445658659}, {-3.980599059481556, \
-5.361872536913859}, {-3.739236946426424, -5.341048659483492}, \
{-3.521932489832453, -5.321054005503506}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.4984198190004965`, -5.318890553705052}, \
{-3.4983510916678706`, -5.318884229954236}, {-3.258196824690838, \
-5.295889664912773}, {-3.112625744070433, -5.2816473233828205`}, \
{-2.967581387782396, -5.267302596775336}, {-2.823075806742334, \
-5.253013691198081}, {-2.678992508766039, -5.23725128094269}, \
{-2.558660997387958, -5.224676700011569}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.5351768081800863`, -5.222223327897115}, \
{-2.3925747986290586`, -5.20763419070798}, {-2.2502102591793522`, \
-5.193383995459256}, {-2.1084085968088364`, -5.179506033456286}, \
{-1.9671907806111553`, -5.166149902172222}, {-1.82657777967995, \
-5.153465199080216}, {-1.6865695940152223`, -5.141451924180268}, \
{-1.5948490354305385`, -5.133989547105327}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5713148056236852`, -5.132074804110986}, \
{-1.5471662236169745`, -5.130110077472379}, {-1.325284309113838, \
-5.113853675711103}, {-1.1042681984038998`, -5.100265051528073}, \
{-0.8841178914871599, -5.08934420492329}, {-0.6648333883636179, \
-5.081091135896755}, {-0.6283658088534797, -5.080120652754907}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6047621725429828, -5.079492507661831}, \
{-0.4460035533602232, -5.075267588826811}, {-0.22721725080392385`, \
-5.071635308091803}, {-0.0084744806947199, -5.070194293691731}, {
             0.21022475696738924`, -5.0709445456265945`}, {
             0.33961854830108074`, -5.07225236440187}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.36322933532590684`, -5.072491005145385}, {
             0.4289644392952038, -5.07315540799099}, {
             0.6478285434015234, -5.076096224879512}, {
             0.8668170692863488, -5.079766996292162}, {
             1.08593001694968, -5.08416772222894}, {
             1.3075633045451507`, -5.088765487251626}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3311708442932304`, -5.089223509891803}, {
             1.5441861123709604`, -5.093215260596001}, {
             1.7724126568110856`, -5.097031906030479}, {
             2.000038199070869, -5.1003771356322565`}, {
             2.22706273915031, -5.103250949401333}, {
             2.2755357588558334`, -5.10376525760264}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2991464228912863`, -5.104015771357003}, {
             2.4534862770494072`, -5.105653347337708}, {
             2.679308812768163, -5.107584329441382}, {
             2.904530346306575, -5.109043895712355}, {
             3.128910716816102, -5.110358239511186}, {
             3.2435980496648216`, -5.111126239445967}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.267209513268194, -5.111284352831787}, {
             3.352209763448201, -5.111853554198435}, {
             3.5744274862028727`, -5.1135298397741025`}, {
             3.795563885080116, -5.115387096238187}, {
             4.015618960079931, -5.117425323590691}, {
             4.211653699692364, -5.119412045501776}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.235264473946067, -5.119651921557341}, {
             4.452485138447279, -5.122044690960953}, {
             4.669296241814811, -5.124625830978711}, {
             4.862078355694211, -5.127244189301364}, {
             5.053973988798947, -5.130336834411138}, {
             5.179650094371381, -5.132733890368537}}]}, 
           {Arrowheads[{{0.009608198232587746, 1.}}], 
            ArrowBox[{{5.203257793635787, -5.133184166703123}, {
             5.2406255170435605`, -5.13389689187551}, {
             5.4236058776308385`, -5.138009263825196}, {
             5.435715706717159, -5.138303309309651}, {
             5.447764052800724, -5.138598510452758}, {
             5.5714319031943225`, -5.141928186475629}, {
             5.656854249492381, -5.144407036579404}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.240343532025131, 
             5.3824339160316645`}, {-3.9964436956651563`, 
             5.363391871436844}, {-3.7527437118176117`, 
             5.34245139139138}, {-3.509508982666783, 
             5.320133491748875}, {-3.2994826048726367`, 
             5.30006283910995}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.275977693704963, 
             5.297816650263054}, {-3.267004910396955, 
             5.296959188362931}, {-3.1206316773036016`, 
             5.282659768379433}, {-2.9747889866861255`, 
             5.268253874129001}, {-2.829489790429289, 
             5.253900454885383}, {-2.684608886980409, 
             5.238063001002338}, {-2.5403297613735907`, 
             5.2229932938579795`}, {-2.396620033896931, 
             5.208293960267934}, {-2.3363515923372677`, 5.202260831138869}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.3128570238770947`, 
             5.199908924209078}, {-2.2534797045504344`, 
             5.193965000232201}, {-2.110908773334097, 
             5.180006413750783}, {-1.9689281033369015`, 
             5.16657207307676}, {-1.8275585576478321`, 
             5.153815850463217}, {-1.686800136266887, 
             5.141737745910153}, {-1.5466528391940653`, 
             5.13033775941757}, {-1.3720122569389397`, 
             5.117545981791412}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3484633496362373`, 
             5.115821111307901}, {-1.3250723585910449`, 
             5.114107807606998}, {-1.1043559893814285`, 
             5.100538577089854}, {-0.8845037315652138, 
             5.089630067866137}, {-0.6655155851424012, 
             5.081382279935847}, {-0.4469817451479275, 
             5.075558722329473}, {-0.40497212454903597`, 
             5.074859652313707}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.38136340010982284`, 
             5.074466786319427}, {-0.22849240661672843`, 
             5.071922904077505}, {-0.010047569548804147`, 
             5.070474825179942}, {0.20835276605584568`, 5.071214485636785}, {
             0.4267931545463083, 5.073414204596087}, {0.5630657658982904, 
             5.0752423311011094`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5866756344812087, 5.075559062585949}, {
             0.6453581502716716, 5.0763463012059}, {0.8640477532319366, 
             5.080010775466225}, {1.082861963427101, 5.084407627377061}, {
             1.312383152419504, 5.089173185677891}, {1.5309872767025938`, 
             5.093273903847593}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.554595591655094, 5.093689983034434}, {
             1.7696255172624218`, 5.097290384245156}, {1.997346693112937, 
             5.100642024511592}, {2.224467864582823, 5.103522358766564}, {
             2.450989031672079, 5.105931387010071}, {2.498987669602861, 
             5.106343070566897}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.522598794144661, 5.106545582807891}, {
             2.6769101943807065`, 5.107869109242113}, {2.9022313527087045`, 
             5.109335525462691}, {3.1267113258198105`, 5.110656286798745}, {
             3.350108932877762, 5.112157044377218}, {3.467055798052051, 
             5.113041189295013}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.4906671162831158`, 5.11321969623477}, {
             3.5724241738825584`, 5.113837798198108}, {3.7936570488342007`, 
             5.115698548261415}, {4.013807557732688, 5.11773929456714}, {
             4.232875700578021, 5.119960037115282}, {4.43510369645409, 
             5.122187231023901}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.458714178019907, 5.122454207998963}, {
             4.6677648881092235`, 5.124941510938821}, {4.860494083769686, 
             5.12755714698686}, {5.0523375645255655`, 5.130646564116654}, {
             5.238979939415849, 5.1342027033790725`}, {5.403061257972347, 
             5.13788644475576}}]}, 
           {Arrowheads[{{0.004876214609825739, 1.}}], 
            ArrowBox[{{5.426667105778841, 5.138424844096332}, {
             5.434123314165597, 5.138605730378377}, {5.4461788849233255`, 
             5.138900849948929}, {5.5700900879246635`, 5.142235048798405}, {
             5.656854249492381, 5.144751706332759}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.35024669378929224`}, \
{-5.620033530528877, -0.35010876565365845`}, {-5.412427858474127, \
-0.3491696346375351}, {-5.384651957977336, -0.349031576983372}, \
{-5.356869281196664, -0.34888975925504057`}, {-5.155559216684709, \
-0.34761247971362935`}, {-4.954040319587491, -0.346071683422868}, \
{-4.820983817828758, -0.3449625188112327}, {-4.7123973062001046`, \
-0.3439076329948218}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688786427319785, -0.34367826029585324`}, \
{-4.687824844695764, -0.3436689188053111}, {-4.554563400188511, \
-0.342190883405103}, {-4.421199484306996, -0.34052841261060857`}, \
{-4.2877330970512215`, -0.3386815064218277}, {-4.1541642384211865`, \
-0.3366501648387604}, {-4.020492908416891, -0.3344343878614067}, \
{-3.886719107038335, -0.33203417548976666`}, {-3.752429381078779, \
-0.32932764633634914`}, {-3.744422851461658, -0.329142034344736}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7208172008263674`, -0.32859479452458074`}, \
{-3.6172102773314823`, -0.32619291901366304`}, {-3.481061795796446, \
-0.32262999352170835`}, {-3.34398393647367, -0.3186388698604852}, \
{-3.2059766993631538`, -0.31421954802999347`}, {-3.0670400844648977`, \
-0.30937202803023317`}, {-2.9271740917789018`, -0.3040963098612044}, \
{-2.786378721305166, -0.29839239352290703`}, {-2.7768496529947675`, \
-0.29796909006507616`}}]}, 
           {Arrowheads[{{0.018838986857754637`, 1.}}], 
            ArrowBox[{{-2.7532609228630185`, -0.29692122360999856`}, \
{-2.643711469185405, -0.2920547811588917}, {-2.498229831561333, \
-0.284877974912709}, {-2.348979091475319, -0.2766743096724823}, \
{-2.1950045319697318`, -0.2672561203263352}, {-2.0347199347747966`, \
-0.25634062774255756`}, {-1.8652701070049171`, -0.24341882948407106`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            
            ArrowBox[{{-5.656854249492381, -2.475291996166752}, \
{-5.564680900503761, -2.472975455086802}, {-5.431790822917281, \
-2.4693433235399063`}, {-5.298622893148328, -2.4653190978040906`}, \
{-5.165331973592577, -2.4607848946678903`}, {-5.032072926645709, \
-2.4556228309198413`}, {-4.898845752307722, -2.449832906559944}, \
{-4.765650450578615, -2.443415121588198}, {-4.713044955213628, \
-2.4406317772530466`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689465943201016, -2.43938421729646}, \
{-4.632487021458389, -2.4363694760046033`}, {-4.499355464947045, \
-2.4286959698091604`}, {-4.366255781044581, -2.420394603001869}, \
{-4.233187969750998, -2.411465375582728}, {-4.100322376369793, \
-2.401751167636292}, {-3.967829346204462, -2.391094859247112}, \
{-3.8357088792550056`, -2.3794964504151883`}, {-3.7475339139223283`, \
-2.3711034594133436`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.72402816546513, -2.368866049570895}, \
{-3.703960975521424, -2.3669559411405214`}, {-3.572585635003717, \
-2.3534733314231104`}, {-3.441582857701884, -2.339048621262956}, \
{-3.310952643615926, -2.3236818106600583`}, {-3.180694992745842, \
-2.3073728996144163`}, {-3.051684354804253, -2.290213699434294}, \
{-2.9233308743230575`, -2.2721071175642145`}, {-2.795634551302255, \
-2.2530531540041774`}, {-2.786966159745212, -2.251688382033819}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.763641484266094, -2.24801609022488}, \
{-2.6685953857418463`, -2.2330518087541824`}, {-2.5422849466671478`, \
-2.212016852962089}, {-2.416774803103475, -2.1898620577757573`}, \
{-2.2920649550508294`, -2.166587423195186}, {-2.168155402509211, \
-2.1421929492203757`}, {-2.0451544474035015`, -2.116830484275169}, \
{-1.9231703916585843`, -2.0906518767834084`}, {-1.8360521385553907`, \
-2.0712107694895616`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.813006990856153, -2.0660680677816576`}, \
{-1.8022032352744592`, -2.063657126745094}, {-1.6822529782511264`, \
-2.035846234160226}, {-1.6015746336537438`, -2.016531208828713}, \
{-1.5215144293829885`, -1.9968463570182626`}, {-1.3597711443175224`, \
-1.9560188113759274`}, {-1.200557103759649, -1.9147829758026813`}, \
{-1.0441296612037534`, -1.8738604836100838`}, {-0.8971196211750951, \
-1.8356303898115274`}}]}, 
           {Arrowheads[{{0.0030188002097174, 1.}}], 
            ArrowBox[{{-0.8742644737187658, -1.8297000959834782`}, \
{-0.8714507143100934, -1.8289706301665598`}, {-0.852181076882362, \
-1.8240091044108186`}, {-0.7938784813494102, -1.8094819097703632`}, \
{-0.7358778783889593, -1.7954676825847}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.149791110712916, -5.656854249492381}, \
{-1.0901051619620494`, -5.6534456367981845`}, {-0.9562276589956221, \
-5.646713528871232}, {-0.8226769288223278, -5.640913602645676}, \
{-0.6894529714421663, -5.636045858121516}, {-0.6391800741039007, \
-5.6344480306021865`}, {-0.5889247096864629, -5.632981298882373}, \
{-0.4136932850136592, -5.628896321479554}, {-0.23876590596523242`, \
-5.626422522629856}, {-0.22751490994184936`, -5.62631513323768}, \
{-0.21626548741774893`, -5.626214467310676}, {-0.2059056343094625, \
-5.626149107438433}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.1822941112108813, -5.626000143344342}, \
{-0.177823516480896, -5.625971938552503}, {-0.13940214394774028`, \
-5.625808207392793}, {-0.007885305337228865, -5.625559459872049}, {
             0.12354927449306491`, -5.625934475466397}, {
             0.25490159554314085`, -5.626933254175837}, {
             0.38617165781299895`, -5.628555796000369}, {
             0.5173393312740793, -5.630740657011304}, {
             0.6483844858978216, -5.6334263932799535`}, {
             0.7620911860177677, -5.636193974905931}}]}, 
           {Arrowheads[{{0.014020858564104708`, 1.}}], 
            ArrowBox[{{0.7856955420725801, -5.6367931056831555`}, {
             0.9101072386332933, -5.640300491590393}, {
             1.040768852639912, -5.644257593184433}, {
             1.1712759795989724`, -5.648253049140684}, {
             1.3016286195104747`, -5.6522868594591475`}, {
             1.4318267723744187`, -5.656359024139823}, {
             1.4475120068504739`, -5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1487493581392938`, 
             5.656854249492381}, {-1.0904485886872701`, 
             5.653523737060337}, {-0.9565506033962097, 
             5.646788384294456}, {-0.8229796672346288, 
             5.640985470286388}, {-0.6897357802025272, 
             5.636114995036134}, {-0.639454473528705, 
             5.634516174418021}, {-0.5891906983570284, 
             5.633048491655618}, {-0.4139618375216133, 
             5.628961125580947}, {-0.23903691899824508`, 
             5.626484868724968}, {-0.22778583734483007`, 
             5.626377316568421}, {-0.21653632878479637`, 
             5.626276487878159}, {-0.2048621893647502, 
             5.626202672931543}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.18125066835210693`, 
             5.626053378572415}, {-0.17808579698500976`, 
             5.626033367263435}, {-0.1396558679506556, 
             5.625869078210404}, {-0.008172550130019052, 5.625618646495451}, {
             0.1232284518278618, 5.625991893191534}, {0.25454713792298667`, 
             5.626988818298651}, {0.38578350815535567`, 5.628609421816802}, {
             0.516917484873594, 5.630792429984477}, {0.6479289904263272, 
             5.633476569040165}, {0.7631343076234974, 5.636280165505986}}]}, 
           {Arrowheads[{{0.013955803857904372`, 1.}}], 
            ArrowBox[{{0.7867385105310661, 5.636885123013188}, {
             0.9095845880352778, 5.640348239815581}, {1.0402127565342925`, 
             5.644304346772717}, {1.1706866067533972`, 5.648298735092684}, {
             1.3010061386925917`, 5.65233140477548}, {1.431171352351876, 
             5.656402355821107}, {1.4454842155772494`, 5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.3027686088852952`, 2.173725289468906}, {
             1.438219522971738, 2.1550100474247844`}, {1.5728098360689107`, 
             2.1351142092850566`}, {1.706539548176814, 2.114037775049723}, {
             1.839408659295448, 2.0917807447187826`}, {2.0398085737552654`, 
             2.05768893399129}, {2.2354630831322084`, 2.0253490858123846`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.258774257350654, 2.0215922623971117`}, {
             2.437160845418919, 1.992977936598482}, {2.6341132026227543`, 
             1.962358749933167}, {2.8307279102158884`, 1.9336904605273895`}, {
             3.027816504339613, 1.9077664242866277`}, {3.1936931587567114`, 
             1.888304303473078}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.2171442885950596`, 1.885552808853585}, {
             3.225378984993929, 1.8845866412108814`}, {3.4234153521788357`, 
             1.8641511113001508`}, {3.622091784379128, 1.8461828737009}, {
             3.8215744600795993`, 1.8304049675595933`}, {4.02186337928025, 
             1.816817392876231}, {4.158402594726068, 
             1.8090789141015877`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.181976756159069, 1.8077428280014616`}, {
             4.22295854198108, 1.8054201496508127`}, {4.398580286515985, 
             1.7970971662187514`}, {4.574653579813051, 1.7899989382261792`}, {
             4.7396551189154925`, 1.7843106035366578`}, {4.904908183233413, 
             1.7794369608359}, {5.0704127727668125`, 1.7753780101239058`}, {
             5.125820329356518, 1.7742935466694423`}}]}, 
           {Arrowheads[{{0.010745948750353253`, 1.}}], 
            ArrowBox[{{5.149427800987706, 1.7738314898343812`}, {
             5.236168887515692, 1.7721337514006754`}, {5.258417612088875, 
             1.7717532535973703`}, {5.280669001499187, 1.7713850556232529`}, {
             5.479355747436787, 1.7691335227156846`}, {5.656854249492381, 
             1.7678815156805339`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.585090582767398, 
             4.479430859437476}, {-5.449417996551811, 
             4.473858512618898}, {-5.209636621863715, 
             4.4630509663407825`}, {-4.969044980265766, 
             4.450703192001166}, {-4.727643071757961, 
             4.436815189600049}, {-4.641858352572357, 4.431350945635086}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.618294115123057, 
             4.429849970362407}, {-4.485430896340306, 
             4.421386959137432}, {-4.2432160092456614`, 
             4.4042705624751575`}, {-4.001805965706891, 
             4.38531806147507}, {-3.7612007657239985`, 
             4.364529456137169}, {-3.676702156456964, 4.356557172312603}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.653194558860448, 
             4.354339274980342}, {-3.52140040929698, 
             4.341904746461455}, {-3.2829298491277097`, 
             4.317949569251796}, {-3.0463140379180578`, 
             4.293169561312063}, {-2.8115529756680244`, 
             4.267564722642255}, {-2.7138138137953, 4.256473508757911}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.690352396110885, 
             4.253811161377579}, {-2.5786466623776096`, 
             4.24113505324237}, {-2.409550564703191, 
             4.221746514335861}, {-2.241632706242644, 
             4.2028491605799685`}, {-2.0748930869959685`, 
             4.184442991974694}, {-1.9093317069631657`, 
             4.1665280085200385`}, {-1.7515754650183684`, 
             4.150239650425301}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7280755205539475`, 
             4.147943554846554}, {-1.5812629738944237`, 
             4.133926812888233}, {-1.4186354481972985`, 
             4.1196794046674965`}, {-1.2569458163916694`, 
             4.106800789510205}, {-1.095860993707821, 
             4.095505898524476}, {-0.9350478953760393, 
             4.086009662818428}, {-0.7862449653204728, 
             4.078874913106328}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7626544830415808, 
             4.077875853279108}, {-0.6142368717686725, 
             4.072413157245373}, {-0.39590232785130475`, 
             4.066633698491545}, {-0.1765801722957579, 4.062897898281226}, {
             0.04372959489796835, 4.061205756614415}, {0.18160977391354335`, 
             4.06142477055006}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.20522173712349198`, 4.061462276658826}, {
             0.2650269737298742, 4.061557273491111}, {0.4873638365329753, 
             4.062797156319998}, {0.7107920556402856, 4.063770112509756}, {
             0.9353116310518061, 4.064476142060386}, {1.1496942898782214`, 
             4.064893391565763}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1733062588816514`, 4.0649070250094095`}, {
             1.3248859717454882`, 4.064806410496543}, {1.4887458755984533`, 
             4.064036590140057}, {1.6525022743264308`, 4.062605783902425}, {
             1.816155167929422, 4.06051399178365}, {1.9797045564074263`, 
             4.057761213783732}, {2.1177112551611894`, 
             4.054878777873538}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1413180996727217`, 4.0543857205295035`}, {
             2.143150439760443, 4.05434744990267}, {2.306492817988474, 
             4.0502727001404635`}, {2.4697316910915177`, 4.045536964497113}, {
             2.686482354741021, 4.038887816514081}, {2.9025413874737453`, 
             4.032420117587535}, {3.085401299175756, 4.027082712360545}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.109003240263612, 4.026393807271633}, {
             3.1179087892896917`, 4.026133867717476}, {3.3325845601888595`, 
             4.020029066903902}, {3.546568700171249, 4.0141057151468145`}, {
             3.75986120923686, 4.008363812446213}, {3.972462087385693, 
             4.002803358802097}, {4.053134454522128, 4.000755609406589}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.0767388443124, 4.000156446686564}, {
             4.184371334617747, 3.9974243542144667`}, {4.36003581172377, 
             3.993375118853067}, {4.5352802064455, 3.9900174388764937`}, {
             4.778733378204548, 3.986475774515402}, {5.021069076996291, 
             3.9842489513262063`}}]}, 
           {Arrowheads[{{0.012963294750052349`, 1.}}], 
            ArrowBox[{{5.044680579524952, 3.98409702977564}, {
             5.05402840836228, 3.984039628714279}, {5.244982065323651, 
             3.9837313734381956`}, {5.435424841880531, 3.984210096102787}, {
             5.439508093645313, 3.9842206273903362`}, {5.44359111095027, 
             3.984231517390423}, {5.449715255483625, 3.9842484351695013`}, {
             5.453797744361409, 3.984260131895686}, {5.4578799979611565`, 
             3.9842721869378446`}, {5.4986885719065235`, 3.98441329247573}, {
             5.539454472199479, 3.9845939658038043`}, {5.579989879895119, 
             3.9848137838537534`}, {5.656854249492381, 3.985424566367126}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.450169994260522, 
             4.932794559003786}, {-5.317491836040325, 
             4.92661454515282}, {-5.181260940259663, 
             4.920020807329148}, {-5.044364418160019, 
             4.913056540449544}, {-4.906990049682899, 
             4.905670928832824}, {-4.769325614769806, 
             4.897813156797804}, {-4.631549679371807, 
             4.8894359248973345`}, {-4.5071097360202135`, 
             4.881353731205362}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.4835502367908, 
             4.879780877405885}, {-4.356199004974291, 
             4.870981183158589}, {-4.218624265974773, 
             4.860903673320313}, {-4.081116592441416, 
             4.850259404169435}, {-3.9436759843742184`, 
             4.839048375705956}, {-3.8063024417731794`, 
             4.827270587929874}, {-3.668995964638303, 
             4.814926040841191}, {-3.5422161503598466`, 4.803128131930413}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.5187083918580226`, 
             4.800912080575294}, {-3.3954516207232506`, 
             4.789177570990703}, {-3.259430607432133, 
             4.775933873795071}, {-3.123910366585287, 
             4.76244386841918}, {-2.9888908981827127`, 
             4.74870755486303}, {-2.8543722022244102`, 
             4.73472493312662}, {-2.7203542787103796`, 
             4.720496003209952}, {-2.58683712764062, 
             4.706020765113024}, {-2.5791008730345117`, 4.705188976261845}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.555624187497366, 
             4.702664803223771}, {-2.3793561200981936`, 
             4.683712762378885}, {-2.1733573903314887`, 
             4.662407158121306}, {-1.968840938340507, 
             4.642103952340286}, {-1.7658067641252477`, 
             4.622803145035825}, {-1.6157569828232403`, 
             4.6096303239535725`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5922354563667716`, 
             4.607565376861321}, {-1.5639991714648798`, 
             4.605086522671647}, {-1.3631624641385713`, 
             4.589535871711474}, {-1.1632966421463227`, 
             4.576151192155307}, {-0.9644017054881333, 
             4.564932484003146}, {-0.7660194008658925, 
             4.555906862347715}, {-0.6495030789604072, 
             4.551908723852729}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6259049746584253, 
             4.551098979023202}, {-0.5676914749814879, 
             4.5491014422817395`}, {-0.36941792783491867`, 
             4.54451622380522}, {-0.1711987594261868, 
             4.542151206918157}, {-0.022787029455110602`, 
             4.541395340820587}, {0.12590619861153401`, 4.54100539308557}, {
             0.27488092477374876`, 4.5409813637131045`}, {
             0.31847081166124247`, 4.541081211491514}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.34208274271421024`, 4.541135297405196}, {
             0.4241371490315329, 4.541323252703191}, {0.5736748713848862, 
             4.542031060055829}, {0.7234940918338089, 4.543104785771021}, {
             0.8735948103783009, 4.544544429848764}, {1.0239770270183617`, 
             4.546349992289059}, {1.1595039116812915`, 4.547988417854324}, {
             1.2865229223904378`, 4.5492390093166115`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3101340672734207`, 4.549437514439498}, {
             1.4304729736511759`, 4.550352230674286}, {1.5659151509581295`, 
             4.551077617928983}, {1.701329092479758, 4.551498659080158}, {
             1.8367147982160614`, 4.551615354127811}, {1.9720722681670395`, 
             4.5514277030719406`}, {2.107401502332692, 4.550935705912548}, {
             2.242579409527359, 4.550188495684712}, {2.2546042736980647`, 
             4.550103522449492}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.2782156771871778`, 4.549936673384579}, {
             2.3774828985653804`, 4.549235205423514}, {2.512111969446756, 
             4.548075835128952}, {2.646466622171486, 4.546710384801026}, {
             2.780546856739571, 4.545138854439736}, {2.9143526731510097`, 
             4.543361244045083}, {3.047884071405803, 4.541377553617067}, {
             3.18114105150395, 4.539187783155687}, {3.222621403351727, 
             4.5384914702264645`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.2462300702525253`, 4.538095161630408}, {
             3.314104855275796, 4.536955776637886}, {3.446756724551683, 
             4.534845378040608}, {3.5790966593316123`, 4.532856587363852}, {
             3.711124659615583, 4.530989404607619}, {3.8428407254035952`, 
             4.529243829771908}, {3.9742448566956496`, 4.527619862856719}, {
             4.105337053491746, 4.526117503862053}, {4.190620333712383, 
             4.525217100554244}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.21423101084117, 4.5249678238879225`}, {
             4.236117315791883, 4.524736752787909}, {4.413730130763988, 
             4.523126125157675}, {4.590799682791601, 4.521948796161746}, {
             4.808434073511721, 4.521299309059892}, {5.025267136306512, 
             4.521646919786303}, {5.039834537367349, 4.521703872196902}, {
             5.05439833824619, 4.521765288659846}, {5.1586929879466, 
             4.522657694007552}}]}, 
           {Arrowheads[{{0.010049851259629206`, 1.}}], 
            ArrowBox[{{5.182304116615596, 4.522859724481311}, {
             5.245211066741807, 4.5233979927324794`}, {5.435365283203575, 
             4.525787274110517}, {5.448114822104867, 4.525950879413059}, {
             5.460861407307883, 4.526117860453835}, {5.473605031687535, 
             4.5262882140592895`}, {5.4863456879636106`, 4.526461937205298}, {
             5.499083368799885, 4.526639026646849}, {5.524551206356126, 
             4.526999883072759}, {5.549993763826255, 4.52737378120999}, {
             5.575389462057564, 4.527760051925018}, {5.656854249492381, 
             4.529195813169203}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.5185315848163308`, -2.1394019121715537`}, {
             1.6534901882265385`, -2.118493371627255}, {
             1.7875510219614117`, -2.096628273887303}, {
             1.9207140860209504`, -2.0738066189516973`}, {
             2.12105725444696, -2.0393077617739936`}, {
             2.320426985541987, -2.0063284936397285`}, {
             2.4504065624227227`, -1.9857176460303845`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.4737271839936685`, -1.9820196975611801`}, {
             2.5188232793060306`, -1.9748688145489022`}, {
             2.716246135739091, -1.944928724501514}, {
             2.9134805867867137`, -1.9171261713153294`}, {
             3.111311664394443, -1.8920791028081125`}, {
             3.30973936856228, -1.8697875189798632`}, {
             3.4101262307315348`, -1.8599336097344423`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.4336252853952582`, -1.8576269577781424`}, {
             3.508763699290223, -1.850251419830582}, {
             3.6602122567903934`, -1.8371481509538472`}, {
             3.8121636720646643`, -1.8254235820606373`}, {
             3.97529458111648, -1.8142638960907387`}, {
             4.138884170569885, -1.804366519371152}, {
             4.302932440424881, -1.7957314519018768`}, {
             4.375745841257128, -1.7924681514844822`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.399334156501694, -1.791410986757888}, {
             4.467439390681465, -1.7883586936829137`}, {
             4.489492938714105, -1.7874561828987978`}, {
             4.5115533065584765`, -1.786571958061255}, {
             4.686222717788365, -1.7807981073479147`}, {
             4.861213141368268, -1.7759944065341153`}, {
             5.080046203603188, -1.7705779676805378`}, {
             5.298921372960909, -1.7663419647929868`}, {
             5.3434356700269285`, -1.7657206505877465`}}]}, 
           {Arrowheads[{{0.006137319103466918, 1.}}], 
            ArrowBox[{{5.367045363369686, -1.765391115161556}, {
             5.517838649441432, -1.763286397871462}, {
             5.656854249492381, -1.762095891894221}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.736245450601495, -3.67656440278428}, \
{-1.5881658880316085`, -3.660368838470648}, {-1.4409342188499163`, \
-3.6452974891424}, {-1.294345508080555, -3.631686377284455}, \
{-1.1483997557235246`, -3.619535502896813}, {-1.0030969617788255`, \
-3.6088448659794743`}, {-0.8580604578462908, -3.599694062237062}, \
{-0.7953191798908184, -3.596438545645158}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7717389088429714, -3.595215013607887}, \
{-0.7129135755257516, -3.5921626873742007`}, {-0.5676563148172091, \
-3.58625074139089}, {-0.42228867572066237`, -3.5819582242871304`}, \
{-0.24107302461685715`, -3.5782640069490865`}, {-0.058578940951958536`, \
-3.5758307822036746`}, {0.12519357527403446`, -3.574658550050894}, {
             0.17242043916207522`, -3.5746812026081436`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.19603242944386295`, -3.5746925281952695`}, {
             0.3102445240611194, -3.5747473104907455`}, {
             0.49655571501226126`, -3.5751541819754786`}, {
             0.6841089577304236, -3.5749362829573434`}, {
             0.8729042522156045, -3.5740936134363404`}, {
             1.0629415984678046`, -3.572626173412469}, {
             1.1404985167179873`, -3.5717022995838708`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1641088346162038`, -3.5714210486615396`}, {
             1.2044945412199035`, -3.5709399658874634`}, {
             1.346051393570934, -3.5685241438701185`}, {
             1.487612155520896, -3.565378707360435}, {
             1.6291768270697902`, -3.5615036563584126`}, {
             1.770745408217616, -3.556898990864051}, {
             1.912317898964373, -3.5515647108773507`}, {
             2.053894299310062, -3.545500816398311}, {
             2.10810960490177, -3.5428993800469755`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.1316944625085696`, -3.541767697669651}, {
             2.195474609254683, -3.5387073074269324`}, {
             2.3369243151262085`, -3.5315110222768498`}, {
             2.478108903252612, -3.5242387992616977`}, {
             2.619028373633893, -3.5168906383814766`}, {
             2.7596827262700514`, -3.5094665396361857`}, {
             2.900071961161088, -3.501966503025826}, {
             3.0401960783070026`, -3.4943905285503964`}, {
             3.0748867180897372`, -3.492492547470948}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.098463450615533, -3.4912026262550397`}, {
             3.1800550777077943`, -3.4867386162098977`}, {
             3.319648959363464, -3.47901076600433}, {
             3.4590184102638237`, -3.471461869907728}, {
             3.5982041173986854`, -3.464346819894129}, {
             3.7372060807680487`, -3.457665615963532}, {
             3.876024300371914, -3.4514182581159374`}, {
             4.014658776210282, -3.4456047463513446`}, {
             4.041778087940638, -3.444550993666618}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.0653722763772855`, -3.4436342137845815`}, {
             4.15310950828315, -3.4402250806697543`}, {
             4.291376496590521, -3.4352792610711664`}, {
             4.429459741132395, -3.4307672875555806`}, {
             4.6131641140694395`, -3.425452744241599}, {
             4.796618470131813, -3.4209958365117705`}, {
             4.9312401819040685`, -3.41830454273765}, {
             5.00945543834515, -3.417032845297524}}]}, 
           {Arrowheads[{{0.013209620512118912`, 1.}}], 
            ArrowBox[{{5.033064311008266, -3.416648989969343}, {
             5.065645749841199, -3.416119250194205}, {
             5.199835173943204, -3.4144399588814345`}, {
             5.333808454210083, -3.4132666687993396`}, {
             5.351807336408235, -3.41314293103428}, {
             5.36980235852322, -3.4130276572193337`}, {
             5.568376377044297, -3.4128163266117473`}, {
             5.656854249492381, -3.4129724002730235`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8316569059904005, -4.060561987848879}, {
             0.956702503335545, -4.061278781886998}, {
             1.0819009847915615`, -4.061612696072706}, {
             1.2072523503584494`, -4.061563730406005}, {
             1.3327566000362103`, -4.061131884886891}, {
             1.4584137338248433`, -4.0603171595153675`}, {
             1.5842237517243483`, -4.059119554291434}, {
             1.7101866537347266`, -4.057539069215088}, {
             1.776107242570206, -4.056520094146353}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.7997164151741112`, -4.056155152650807}, {
             1.862170293906406, -4.055189764651424}, {
             2.013922722103865, -4.052418427598233}, {
             2.165443938327105, -4.049225058055514}, {
             2.3167339425761257`, -4.045609656023269}, {
             2.467792734850927, -4.041572221501497}, {
             2.6186203151515084`, -4.037112754490197}, {
             2.743900875358848, -4.033051853162284}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.767500473597968, -4.032286885000673}, {
             2.76921668347787, -4.03223125498937}, {
             2.9195818398300117`, -4.026927722999016}, {
             3.1326425839611964`, -4.019379636114711}, {
             3.345027842835158, -4.012399931471166}, {
             3.5567376164518967`, -4.005988609068382}, {
             3.7114811156732253`, -4.001704201006351}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.735084063644018, -4.001050702403291}, {
             3.7677719048114127`, -4.000145668906359}, {
             3.978130707913706, -3.9948711109850956`}, {
             4.187814025758777, -3.9901649353045934`}, {
             4.396821858346624, -3.986027141864852}, {
             4.605154205677248, -3.982457730665871}, {
             4.679353842695041, -3.98144136196862}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.702963620862277, -3.9811179609326763`}, {
             4.79508137155661, -3.9798561542442634`}, {
             4.984555320144795, -3.978053470996582}, {
             5.226909720073247, -3.976887770735139}, {
             5.468488489368827, -3.976996569761393}, {
             5.48471845819505, -3.9770467720863927`}, {
             5.500944218037336, -3.9771030949203845`}, {
             5.64741808403244, -3.9783177857440273`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5950260600507782, 2.650984094830927}, {
             0.724028584521226, 2.6476173138436705`}, {0.8967924475353184, 
             2.641370297832456}, {1.0702608773444477`, 2.6325390131285453`}, {
             1.2444338739486138`, 2.6211234597319395`}, {1.4193114373478173`, 
             2.607123637642638}, {1.5376984423630375`, 
             2.596311865191179}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5612125805751105`, 2.59416442078452}, {
             1.5941699046704727`, 2.591154571108179}, {1.7682856130449967`, 
             2.573831284376101}, {1.9416585624713885`, 2.5551537774464044`}, {
             2.114288752949647, 2.5351220503190888`}, {2.2498695299480054`, 
             2.519006381792868}, {2.3851984096955867`, 2.5032885169246253`}, {
             2.4999342522131656`, 2.4902754920710217`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.523396774481154, 2.487622985356621}, {
             2.6551004774384177`, 2.4730461981620717`}, {2.7896736654336682`, 
             2.458521744267761}, {2.9239949561781415`, 2.444395094031428}, {
             3.058064349671838, 2.4306662474530727`}, {3.191881845914758, 
             2.4173352045326943`}, {3.3256201543277473`, 
             2.4046041619339404`}, {3.4594519843316536`, 
             2.3926753163204575`}, {3.463038925181143, 
             2.3923773097816867`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.4865698473495454`, 2.3904223378533116`}, {
             3.5933773359264762`, 2.381548667692245}, {3.7273962091122153`, 
             2.3712242160493036`}, {3.861508603888871, 2.361701961391633}, {
             3.995714520256444, 2.352981903719233}, {4.130013958214933, 
             2.345064043032104}, {4.264406917764339, 2.3379483793302454`}, {
             4.429062964903826, 2.330258805257557}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.452652272416431, 2.3292267553821246`}, {
             4.619394368314974, 2.3225074004872988`}, {4.7764693680030055`, 
             2.3170701634439337`}, {4.933463860441847, 2.312428352704015}, {
             5.0903778456315, 2.3085819682675424`}, {5.247211323571963, 
             2.3055310101345157`}, {5.268256519207484, 2.305174884670905}, {
             5.289299443636563, 2.304830948601348}, {5.396745276177063, 
             2.303689189795325}}]}, 
           {Arrowheads[{{0.005008159603758004, 1.}}], 
            ArrowBox[{{5.42035593615873, 2.303438294266735}, {
             5.487935987401014, 2.30272016386751}, {5.656854249492381, 
             2.301691811449481}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.30937782470614, 
             3.63365648723627}, {-1.1634233483252843`, 
             3.621359165391771}, {-1.0181302302641442`, 
             3.6105108862201263`}, {-0.8731229862639887, 
             3.601201497898054}, {-0.7280261320660859, 
             3.59352084860227}, {-0.5828396676704357, 
             3.587468938332775}, {-0.43756359307703807`, 
             3.583045767089568}, {-0.36653065353749703`, 
             3.581541815525457}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3429239511378642, 
             3.5810420004083072`}, {-0.2559506538823222, 
             3.5792005501277573`}, {-0.07306372322980326, 
             3.5766533708131285`}, {0.11109719888051972`, 
             3.5754042291456822`}, {0.29653211244864824`, 
             3.5754531251254185`}, {0.4832324423446782, 3.575849094490736}, {
             0.6015138045550015, 3.5757182495786983`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6251257831057839, 3.575692129594968}, {
             0.6711896134387081, 3.575641172980034}, {0.8604036257307375, 
             3.574829360593312}, {1.050874479220766, 3.5734136573305704`}, {
             1.1928999687047996`, 3.571769903737855}, {1.3349375508506047`, 
             3.569391656446298}, {1.4769872256581813`, 3.566278915455901}, {
             1.569501031873561, 3.5637735100196206`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5931043710730393`, 3.5631342980277685`}, {
             1.6190489931275296`, 3.5624316807666623`}, {1.7611228532586496`, 
             3.5578499523785827`}, {1.9032088060515404`, 3.552533730291662}, {
             2.0453068515062025`, 3.5464830145059008`}, {2.187416989622636, 
             3.5396978050212984`}, {2.329399495635969, 3.5325051953402085`}, {
             2.4711146447813293`, 3.5252322789649844`}, {2.53665357509647, 
             3.5218252100629175`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.560233727100324, 3.520599385927369}, {
             2.612562437058717, 3.517879055895627}, {2.7537428724681323`, 
             3.510445526132135}, {2.8946559510095753`, 3.5029316896745093`}, {
             3.035301672683045, 3.49533754652275}, {3.175680037488542, 
             3.4876630966768563`}, {3.315791045426066, 3.4799083401368294`}, {
             3.4556757553498456`, 3.4723313706114296`}, {3.5033508001082025`, 
             3.469894341133818}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.526932004366966, 3.4686889287385605`}, {
             3.5953752261141076`, 3.465190281809419}, {3.734889457718853, 
             3.4584850737307984`}, {3.874218450164081, 3.4522157463755665`}, {
             4.013362203449792, 3.446382299743724}, {4.152320717575986, 
             3.4409847338352706`}, {4.291093992542662, 3.4360230486502066`}, {
             4.429682028349821, 3.4314972441885323`}, {4.4706136798272595`, 
             3.4303139381902383`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.4942158121619125`, 3.429631616716366}, {
             4.613393478782016, 3.42618627203361}, {4.7968550217552055`, 
             3.4217324250835626`}, {4.931460026672107, 3.4190434251918034`}, {
             5.065848758106851, 3.416860270898426}, {5.2000212160594375`, 
             3.4151829622034313`}, {5.333977400529867, 3.4140114991068193`}, {
             5.351973999017609, 3.4138879963646582`}, {5.369966735280637, 
             3.4137729551392475`}, {5.438530663237167, 
             3.413700659798177}}]}, 
           {Arrowheads[{{0.004123154784824473, 1.}}], 
            ArrowBox[{{5.462142643109162, 3.413675762797829}, {
             5.568520995145566, 3.413563595081185}, {5.656854249492381, 
             3.4137199047351126`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0464938368869208`, -2.6357015322282655`}, {
             1.2186355261122688`, -2.6247588544881912`}, {
             1.391566638150842, -2.611301373269474}, {
             1.5645328799901677`, -2.5958799384544884`}, {
             1.7367799586177735`, -2.5790453999256084`}, {
             1.9083078740336594`, -2.5607977576828347`}, {
             1.9871082657033816`, -2.551727528775287}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.010565379558293, -2.549027524528275}, {
             2.079116626237826, -2.5411370117261667`}, {
             2.2075447024370267`, -2.525933197418717}, {
             2.335714177091698, -2.511044888832829}, {
             2.463625050201841, -2.496472085968503}, {
             2.5912773217674543`, -2.482214788825738}, {
             2.718670991788539, -2.4682729974045343`}, {
             2.8458060602650948`, -2.4546467117048927`}, {
             2.949156702543022, -2.4438040574820903`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.972639817046161, -2.4413404125059195`}, {
             2.9726825271971213`, -2.441335931726812}, {
             3.0993003925846185`, -2.4283406574702937`}, {3.2258229601725996`,
              -2.4158623832416533`}, {
             3.352413533706077, -2.4041026033472073`}, {
             3.47907211318505, -2.393061317786956}, {
             3.6057986986095196`, -2.3827385265609}, {
             3.732593289979485, -2.3731342296690388`}, {
             3.8594558872949465`, -2.364248427111372}, {
             3.9136091723818986`, -2.3607639516637184`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9371724370143943`, -2.3592477810944414`}, {
             3.9863864905559043`, -2.3560811188879}, {
             4.1133850997623576`, -2.348632304998623}, {
             4.285582092901044, -2.339598190070222}, {
             4.458045324975913, -2.3316660836403367`}, {
             4.614970667939789, -2.325356984335238}, {
             4.7718787811816545`, -2.319884873707853}, {
             4.8806433689364646`, -2.3166715759257315`}}]}, 
           {Arrowheads[{{0.015939177550870095`, 1.}}], 
            ArrowBox[{{4.904245064112475, -2.3159742968174397`}, {
             4.928769664701509, -2.3152497517581803`}, {
             5.085643318499352, -2.3114516184862217`}, {
             5.106691312794442, -2.3109981419087413`}, {
             5.127737448211963, -2.3105578116347196`}, {
             5.3213144029551165`, -2.3076722520200836`}, {
             5.5146469248006245`, -2.305746798708734}, {
             5.644850279765775, -2.3046231182374877`}, {
             5.656854249492381, -2.3045526669453245`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5623145567563279, -3.1302068751470173`}, \
{-0.40149908016466107`, -3.1239375204743127`}, {-0.23972691618643543`, \
-3.1197327066252534`}, {-0.07699806482165072, -3.1175924335998393`}, {
             0.08708619503330312, -3.1165316880609852`}, {
             0.2529245844820376, -3.1155654566716064`}, {
             0.38196630470443593`, -3.1148942579043384`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.40557797830171505`, -3.1147714439323586`}, {
             0.4205171035245507, -3.114693739431703}, {
             0.5898637521608433, -3.1139165363412746`}, {
             0.7605678853724925, -3.1123860769621876`}, {
             0.9322328581410739, -3.1092545908563083`}, {
             1.1048586704665881`, -3.1045220780236362`}, {
             1.2784453223490355`, -3.0981885384641714`}, {
             1.349765050716129, -3.0949195698812213`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.373352279694508, -3.093838439705118}, {
             1.4917069987916443`, -3.0884136033066816`}, {
             1.7047633236789976`, -3.076578062932626}, {
             1.9176142970110956`, -3.062681917342004}, {
             2.1302599187879383`, -3.046725166534817}, {
             2.2844033185736454`, -3.034474180677418}, {
             2.3157455720886637`, -3.0320111610781924`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.339284992581529, -3.0301613242755976`}, {
             2.438193638420422, -3.0223886242967235`}, {
             2.5916308783282673`, -3.010468497392734}, {
             2.744715038297181, -2.9987137999654494`}, {
             2.8974461183271645`, -2.9871245320148696`}, {
             3.0498241184182167`, -2.9757006935409946`}, {
             3.2018490385703386`, -2.9644422845438245`}, {
             3.2810522630842534`, -2.9586495167745888`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.304601356019147, -2.956927182521341}, {
             3.353520878783529, -2.9533493050233592`}, {
             3.5049729932220495`, -2.9427023034018953`}, {
             3.6563387360501607`, -2.9327818281017297`}, {
             3.8076181072678623`, -2.9235878791228624`}, {
             3.958811106875155, -2.915120456465293}, {
             4.109917734872037, -2.9073795601290215`}, {
             4.247389498805087, -2.9009944708574884`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.270978177014412, -2.899946920096138}, {
             4.411871876034575, -2.8940773464203735`}, {
             4.56271938920023, -2.8885160290479965`}, {
             4.750694448980986, -2.8825951492066637`}, {
             4.938547630132243, -2.8777632187938633`}, {
             5.084647728369927, -2.8747000928209276`}, {
             5.215026768823162, -2.8724757130326504`}}]}, 
           {Arrowheads[{{0.008856466728146927, 1.}}], 
            ArrowBox[{{5.238635797038557, -2.872104102168555}, {
             5.3765871161486665`, -2.8702898843086957`}, {
             5.52242640568972, -2.868942801769399}, {
             5.542019557745387, -2.868800206395271}, {
             5.561610741462944, -2.868667106725775}, {
             5.656854249492381, -2.8685383225744268`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5629759945417083, 
             3.131360788091229}, {-0.4021790930319469, 
             3.125087526363995}, {-0.24042797602236216`, 
             3.1208779271873253`}, {-0.07772264351295516, 
             3.1187319905612205`}, {0.0863358750933508, 
             3.1176674537174605`}, {0.2521465503936287, 3.116702053887826}, {
             0.38130449128398836`, 3.116034335873099}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4049161687539566, 3.115912268717987}, {
             0.4197093823878797, 3.115835791072316}, {0.5890243710761051, 
             3.115068665270931}, {0.7596961032219933, 3.113551982222853}, {
             0.931329165589236, 3.110437047667263}, {1.1039235581778328`, 
             3.1057238616041607`}, {1.2774792809877846`, 
             3.0994124240335466`}, {1.3491050960358315`, 
             3.096138344131029}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.3726924591645706`, 3.0950601447203643`}, {
             1.4908900614628655`, 3.0896572268764135`}, {1.7040965011463232`, 
             3.0778385311476804`}, {1.9170986000381585`, 
             3.0639563368473466`}, {2.1298963581383723`, 
             3.0480106439754127`}, {2.284075896920643, 3.0357720157989583`}, {
             2.315092552071993, 3.0333374127165467`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.3386321401845382`, 3.031489710135535}, {
             2.437902404951019, 3.0236976483734597`}, {2.5913758822295003`, 
             3.0117875416989173`}, {2.7444963287560866`, 3.00004169577533}, {
             2.8972637445307785`, 2.988460110602699}, {3.0496781295535755`, 
             2.977042786181024}, {3.201739483824478, 2.965789722510304}, {
             3.2804041380938043`, 2.9600398939728167`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3039533083016495`, 2.958318616581428}, {
             3.3534478073434855`, 2.95470091959054}, {3.504936201208085, 
             2.9440573990385124`}, {3.6563377665157644`, 2.934140182471002}, {
             3.8076525032665227`, 2.924949269888008}, {3.9588804114603606`, 
             2.9164846612895317`}, {4.110021491097278, 2.908746356675572}, {
             4.24674231527531, 2.90239971963398}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.270330854657788, 2.901349009138201}, {
             4.412043164700351, 2.8954486594012034`}, {4.562923758666506, 
             2.889889266740795}, {4.750907149081662, 2.883971746766387}, {
             4.938767739363554, 2.8791431626780306`}, {5.084838457264341, 
             2.8760833014905756`}, {5.214379388275605, 
             2.873875439248582}}]}, 
           {Arrowheads[{{0.00887017653612653, 1.}}], 
            ArrowBox[{{5.2379883750843135`, 2.8735010660568205`}, {
             5.376717760258178, 2.8716788553933363`}, {5.5225263453512285`, 
             2.8703342704835517`}, {5.542115383687917, 2.870191993270413}, {
             5.561702446800273, 2.8700592078424925`}, {5.656854249492381, 
             2.8699320008275904`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.464102056847938, -4.941101937907021}, \
{-5.314658326551393, -4.934210772124754}, {-5.161964748111999, \
-4.926683200620375}, {-5.008718244630817, -4.918498965987418}, \
{-4.855009777151193, -4.909671607146775}, {-4.700930306716473, \
-4.900214663019339}, {-4.546570794370007, -4.890141672526002}, \
{-4.521117139792246, -4.888383452465141}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.497561277184615, -4.886756323046019}, \
{-4.392022201155143, -4.879466174587656}, {-4.23737548811523, \
-4.868201708125195}, {-4.082721616293619, -4.856361812059509}, \
{-3.933400513235375, -4.844211863893585}, {-3.7843804323475245`, \
-4.831266134507146}, {-3.6356987191069225`, -4.817627041475918}, \
{-3.5562392581189064`, -4.810002864194757}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.532735212281384, -4.80774763857327}, \
{-3.4873927189904244`, -4.803397002375622}, {-3.3394997774748854`, \
-4.788678434781982}, {-3.19205724003716, -4.7735737562707214`}, \
{-3.0451024521541044`, -4.7581853844175654`}, {-2.898672759302573, \
-4.742615736798235}, {-2.752944417661325, -4.726981844088034}, \
{-2.608043170426608, -4.711395423107873}, {-2.593351153889465, \
-4.709820884018431}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.5698735998875093`, -4.70730480146386}, \
{-2.463930593601512, -4.695950920651885}, {-2.3205682631891267`, \
-4.680742783514207}, {-2.1779177551925417`, -4.665865458488973}, \
{-2.035940645614847, -4.651413392370318}, {-1.8945985104591314`, \
-4.637481031952378}, {-1.753852925728485, -4.624162824029287}, \
{-1.6301063009453283`, -4.613249615905167}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6065806369485884`, -4.611234348680992}, \
{-1.474224916432053, -4.600662996554104}, {-1.3352713239943785`, \
-4.590693179183031}, {-1.1967946667257263`, -4.5818527530398345`}, \
{-1.0587224398975916`, -4.574098713362162}, {-0.9209821387814702, \
-4.567388055387661}, {-0.783501258648858, -4.561677774353981}, \
{-0.6637327395686123, -4.557531569824412}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.640133461266817, -4.556760770515113}, \
{-0.5088863699240436, -4.55321490622803}, {-0.37137601506303347`, \
-4.550586716795631}, {-0.2336808377303154, -4.548927156711029}, \
{-0.09580544546798497, -4.548123085483682}, {
             0.042245554181862266`, -4.548061362623044}, {
             0.18046755367713074`, -4.548628847638572}, {
             0.30425593681311264`, -4.549598085000449}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.3278669636835238, -4.549809077592476}, {
             0.45740612203554953`, -4.551198879335946}, {
             0.6299036062585943, -4.553110742378876}, {
             0.8027890503905198, -4.554750899228413}, {
             0.9759841733767523, -4.5561285100362605`}, {
             1.1494106941627182`, -4.557252734954122}, {
             1.2723101518843092`, -4.557875800098766}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.2959218414503633`, -4.55799550462023}, {
             1.322990331693843, -4.5581327341337}, {
             1.4966448049155519`, -4.558777667726701}, {
             1.670295832773271, -4.559196695884826}, {
             1.8438651342124273`, -4.559398978759781}, {
             2.0575986269763096`, -4.559182034909487}, {
             2.2403980093355136`, -4.558499816589829}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.264009837898045, -4.558411695821596}, {
             2.270727630402465, -4.558386624614817}, {
             2.483200683532557, -4.557154699396229}, {
             2.695515242297165, -4.554114061222644}, {
             2.9069422764531994`, -4.551275689967192}, {
             3.117610438396499, -4.548284706828733}, {
             3.208413702856439, -4.546924839952639}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.232023048454976, -4.546571267124209}, {
             3.3275197281270645`, -4.545141111807267}, {
             3.5366701456448957`, -4.541844904902793}, {
             3.7450631652463544`, -4.538678760421265}, {
             3.9527002612278026`, -4.5359253526686345`}, {
             4.15958143358924, -4.5335846816449035`}, {
             4.176409804924349, -4.533427282226728}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.2000207651698815`, -4.533206443778894}, {
             4.365706682330667, -4.531656747350071}, {
             4.54773486827459, -4.5303481748310235`}, {
             4.72919090667441, -4.529604958128734}, {
             4.945913578019233, -4.5296246634426085`}, {
             5.144484858879964, -4.530549267994614}}]}, 
           {Arrowheads[{{0.010350813791371724`, 1.}}], 
            ArrowBox[{{5.168096512561208, -4.530673572783738}, {
             5.176348201951686, -4.530730935436248}, {
             5.190853368599889, -4.5308362050513615`}, {
             5.3859362211748625`, -4.533114287538897}, {
             5.579455561608623, -4.53615000916533}, {
             5.656854249492381, -4.537470140616384}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.013018754270464165`, 1.}}], 
            ArrowBox[{{1.3588304932788844`, -5.6371168369917175`}, {
             1.5318635489721562`, -5.642528060023411}, {
             1.7045365781857362`, -5.648073170733497}, {
             1.7160710279275964`, -5.6484484436729945`}, {
             1.7276036313795122`, -5.648824474362507}, {
             1.813749313854088, -5.651688513104854}, {
             1.8997670610974438`, -5.654500125424208}, {
             1.9733109235171586`, -5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.013156803159055895`, 1.}}], 
            ArrowBox[{{1.3556506419510188`, 5.636911643629206}, {
             1.5286953236284642`, 5.642320565932996}, {1.7013809291398267`, 
             5.647862726400421}, {1.7129159803029388`, 5.648237771522181}, {
             1.724449189529989, 5.648613571530575}, {1.8104956487102524`, 
             5.651472179287983}, {1.8964154007475011`, 5.654283868285761}, {
             1.9766470608011286`, 5.656854249492381}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(tot\\)]\\)}\"", 
           TraditionalForm]}}], {194.4, -192.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8653708915789029, -0.44630982142919745`}, \
{-0.8673104423264305, -0.4498628625377095}, {-0.8691767408255738, \
-0.4533350183928894}, {-0.8733332851873676, -0.46120953485481686`}, \
{-0.8801707149078152, -0.4744205311010001}, {-0.8892856314801011, \
-0.49246887660456895`}, {-0.8997927318495247, -0.5139208964725761}, \
{-0.9400958769884391, -0.599508337316391}, {-0.981843036034582, \
-0.689613108889066}, {-1.028515585913944, -0.7856525634274093}, \
{-1.078677467318967, -0.8801105899302046}, {-1.1405049387249075`, \
-0.9848131623407466}, {-1.2159521206758563`, -1.099340136384632}, \
{-1.3080983847810659`, -1.2256904275711087`}, {-1.336658487361112, \
-1.2615502365446434`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3513686280078836`, -1.2800201573752361`}, \
{-1.419862317007485, -1.3660202197536686`}, {-1.5538803760493263`, \
-1.5225880105133693`}, {-1.7121736266962337`, -1.6973652655661602`}, \
{-1.8093353411239588`, -1.8010223160248529`}, {-1.8973278437852297`, \
-1.8932331237770594`}, {-1.9830299507879268`, -1.9816099536379002`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.999467673815327, -1.9985606903478677`}, \
{-2.0067967474393704`, -2.0061185009474283`}, {-2.105895267637026, \
-2.1069993658749344`}, {-2.1964995649034496`, -2.1982313136863536`}, \
{-2.2804857997638934`, -2.282169939508462}, {-2.3586550352279616`, \
-2.359763406010056}, {-2.4321711178903946`, -2.432377231968157}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.5234645651521124`, \
-2.5219596212980404`}, {-2.596886388040194, -2.5937010056282164`}, \
{-2.66935784749313, -2.6643220633080222`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.6862685410013976`, -2.6808009788793092`}, \
{-2.7367411578736562`, -2.7299848867830994`}, {-2.8641009864168105`, \
-2.8534629486719996`}, {-2.981474522537405, -2.9668115363772714`}, \
{-3.1073887559740836`, -3.088031058553483}, {-3.2242610472864324`, \
-3.2002177249106087`}, {-3.333408616817176, -3.3047209101279553`}, \
{-3.3663427006095596`, -3.336189729699976}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.383414347141543, -3.3525018447689416`}, \
{-3.4361486849090395`, -3.402889988884829}, {-3.5332691093235287`, \
-3.4955211218298334`}, {-3.625557747822149, -3.583410469611572}, \
{-3.772100038816027, -3.722735520129651}, {-3.9085109859180402`, \
-3.85218540835413}, {-4.03621967988793, -3.9731749251091917`}, \
{-4.067969082086974, -4.00321300280692}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.08512113862638, -4.019440546361173}, \
{-4.156655211485433, -4.0871188612190155`}, {-4.270687841031299, \
-4.194872096582205}, {-4.379187828846275, -4.297289511097358}, \
{-4.555608195371387, -4.463622383748481}, {-4.7198370736671915`, \
-4.618248352001736}, {-4.772199126627924, -4.667487678556521}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.789400363414129, -4.683663081684761}, \
{-4.873592108864354, -4.762833866882008}, {-5.018590946093543, \
-4.899045379414181}, {-5.1558667311001765`, -5.027883980931994}, \
{-5.286452609629679, -5.150350762769186}, {-5.392412698292727, \
-5.250008170145395}, {-5.477507528059466, -5.330616306262192}}]}, 
           {Arrowheads[{{0.004759075893747023, 1.}}], 
            ArrowBox[{{-5.494638948432597, -5.346865596107624}, \
{-5.5848930922881115`, -5.433055729861047}, {-5.656854249492381, \
-5.502413458532212}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7030433329172596, -0.6793345968888616}, \
{-0.700023596882426, -0.6912118582044918}, {-0.6972538048185548, \
-0.7010308468266311}, {-0.6919612249459764, -0.7177228556147296}, \
{-0.6875140565882096, -0.7309924041391505}, {-0.682359819641101, \
-0.7453615454942161}, {-0.6765299044922674, -0.7603733360640784}, \
{-0.6436323778598769, -0.8256902375314741}, {-0.5918186639422672, \
-0.8999796853637329}, {-0.5365110225771437, -0.9576822455002457}, \
{-0.47990254613280997`, -1.001843078777121}, {-0.35930144755926996`, \
-1.0636326163620506`}, {-0.2336154869921619, -1.0965360858162039`}, \
{-0.10245200467310409`, -1.1100302966862967`}, {-0.009538374122232874, \
-1.1105168660436209`}, {0.04394687950174718, -1.1087570466436307`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.06754610169445896, -1.1079805640390723`}, {
             0.08544911663757113, -1.1073915031132944`}, {
             0.17988704668674854`, -1.1026906526869558`}, {
             0.2726287513310849, -1.0981390312992378`}, {
             0.28173407139895357`, -1.09775459832015}, {
             0.2907882905793739, -1.097386410467047}, {
             0.29978677802740455`, -1.0970354068979382`}, {
             0.30427149827552724`, -1.0968643215752243`}, {
             0.30874087593030375`, -1.0966978333128743`}, {
             0.31319439820825357`, -1.0965360555637218`}, {
             0.3176316021735705, -1.0963790952300674`}, {
             0.3220521541832856, -1.0962270407953818`}, {
             0.5595075706698338, -1.098063317890461}, {
             0.7393991729733634, -1.1196535405100179`}, {
             0.8767570270095677, -1.15586925178585}, {
             0.9959526793875298, -1.2052019954965425`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0177698854586876`, -1.2142317093671366`}, {
             1.0191403213406998`, -1.2147989059115614`}, {
             1.1697807363263393`, -1.299115444783414}, {
             1.330688727512256, -1.4103023802083292`}, {
             1.50409550701635, -1.5483002373159394`}, {
             1.6034650067403737`, -1.6336250757723088`}, {
             1.6917576171714663`, -1.7122141228406533`}, {
             1.7683485106517813`, -1.7825470964604033`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.7857400829360153`, -1.7985176765005406`}, {
             1.800838741506068, -1.8123826871649489`}, {
             1.89781797560691, -1.9035849150581647`}, {
             2.0093220027195744`, -2.010619236206258}, {
             2.1092854831274956`, -2.108031263104289}, {
             2.283295932097122, -2.2803889986505035`}, {
             2.3604259375534107`, -2.3576775973247326`}, {
             2.4325881529748754`, -2.4303760326685557`}, {
             2.446513457451672, -2.4444459204077544`}, {
             2.46081090431101, -2.458959574330016}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.4773813448562714`, -2.475780594319069}, {
             2.521933999575827, -2.5210069776222768`}, {
             2.5930605137553746`, -2.5934613555272543`}, {
             2.72810405257146, -2.7313846272099105`}, {
             2.8503184922169535`, -2.8568062314442604`}, {
             2.962381833695188, -2.97222032397843}, {
             3.081939281033741, -3.0956802986831637`}, {
             3.136540881251575, -3.1521999009839767`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1529464540495242`, -3.169181755844602}, {
             3.192482214521418, -3.21010629742611}, {
             3.295362343339732, -3.3168183679724343`}, {
             3.3919313766701955`, -3.4171365580873028`}, {
             3.482987218347924, -3.5118519510639326`}, {
             3.5693277722080325`, -3.6017556301955413`}, {
             3.7058951646936684`, -3.744111345069154}, {
             3.8074604106312684`, -3.8501018449756743`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.8237969220207715`, -3.8671501472065946`}, {
             3.8326943497864345`, -3.8764352408236}, {
             3.9511323393437405`, -4.0001525343749735`}, {
             4.062616145222997, -4.116688442639368}, {
             4.167994450196176, -4.226909269148692}, {
             4.268115937035248, -4.331681317434851}, {
             4.430482458494177, -4.50167170631225}, {
             4.476466401702216, -4.549839168605822}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.492771006819583, -4.566917987806893}, {
             4.581360884412151, -4.659714500912063}, {
             4.7223937512029615`, -4.80750548195466}, {
             4.8552235952804015`, -4.946740430160412}, {
             4.980844875020409, -5.0784503155616045`}, {
             5.100252048798925, -5.203666108190521}, {
             5.144748382348155, -5.250268122118135}}]}, 
           {Arrowheads[{{0.011440289780806806`, 1.}}], 
            ArrowBox[{{5.161054305326608, -5.26734568310198}, {
             5.197744894615308, -5.3057725649742284`}, {
             5.291260230131551, -5.40343099738529}, {
             5.380798055347654, -5.4966414054237065`}, {
             5.466358370263618, -5.585403789089477}, {
             5.535431860263513, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8657489665169184, 
             0.4479059916010916}, {-0.8708767841480813, 
             0.45735987956011487`}, {-0.8865338910051719, 
             0.48783864100893565`}, {-0.8888481703680289, 
             0.49246916290069703`}, {-0.8912414353943953, 
             0.49729404241441916`}, {-0.8937015090993546, 
             0.5022923776689685}, {-0.8976177931530358, 
             0.5103308699197012}, {-0.9513128118961661, 
             0.6238929710353525}, {-0.9936040502757242, 
             0.7145320956978256}, {-1.0412491811392062`, 
             0.8107737131691861}, {-1.093826665578366, 
             0.9071100728610982}, {-1.1589499245657227`, 
             1.0142562384164677`}, {-1.2385014260577367`, 
             1.131721113548449}, {-1.3355467375676702`, 
             1.2615717404405156`}, {-1.336964575831127, 1.263316134009827}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.351857404744924, 
             1.28163906664302}, {-1.4529326367873439`, 
             1.405993860370751}, {-1.593199496474396, 
             1.5672495100572013`}, {-1.7582096947805306`, 
             1.7472301811523405`}, {-1.8592844087829976`, 
             1.8540220314749551`}, {-1.950738442544691, 
             1.9490663730971742`}, {-1.9838501414583267`, 
             1.982971394074972}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.000347541798, 
             1.9998640550663234`}, {-2.0635068791153994`, 
             2.0645366247908683`}, {-2.165589320202519, 
             2.1678352612961187`}, {-2.2589176583895667`, 
             2.2613338104884506`}, {-2.34542378626006, 
             2.3474038002433883`}, {-2.425933300344655, 
             2.4270053100433024`}, {-2.501645840084606, 
             2.5015221615626775`}, {-2.5146825017549803`, 
             2.514321402378059}, {-2.594344363090898, 
             2.592204849598462}, {-2.6697834722121976`, 
             2.665717967418158}, {-2.669967066899111, 2.6658964246814167`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.686898477562286, 
             2.6823540534988095`}, {-2.8134845097504972`, 
             2.8053979021576327`}, {-2.944352673943192, 
             2.932003324325907}, {-3.0649624639374333`, 
             3.0482563299321974`}, {-3.1944442990173996`, 
             3.17269876668129}, {-3.3146231996099558`, 
             3.2878843151669157`}, {-3.3668749728147516`, 
             3.337844457895904}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.383941219578754, 
             3.354162222287093}, {-3.4268546116233383`, 
             3.395193541609586}, {-3.532493980965784, 
             3.4960070122298132`}, {-3.6323520481828853`, 
             3.5911401571705386`}, {-3.727239553820236, 
             3.681408406574702}, {-3.8777583917933742`, 
             3.8243745158797333`}, {-4.017875095952637, 
             3.957224070112542}, {-4.068360839345689, 4.005015478345131}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.085508334449201, 
             4.021247841851756}, {-4.149056241302501, 
             4.081404308898462}, {-4.272768402847443, 
             4.198362471862827}, {-4.38990496076407, 
             4.308973810313264}, {-4.501359295228989, 
             4.4141135755574}, {-4.593417795601804, 
             4.500883985343719}, {-4.682353381046365, 
             4.584659505312364}, {-4.768166051562674, 
             4.665440135463338}, {-4.772434740577997, 4.669455664750468}}]}, 
           {Arrowheads[{{0.019999999999999987`, 1.}}], 
            ArrowBox[{{-4.789633136114679, 
             4.685634088786819}, {-4.8508558071507295`, 
             4.74322587579664}, {-5.00862449691257, 
             4.891515057455213}, {-5.1574173737023745`, 
             5.031229420733067}, {-5.297280238674904, 
             5.162686754833247}, {-5.428258892984917, 
             5.286204848958801}, {-5.4774835114117995`, 
             5.33286080412747}}]}, 
           {Arrowheads[{{0.004747274407504055, 1.}}], 
            ArrowBox[{{-5.4946208581596165`, 
             5.349103881415386}, {-5.531867572593847, 
             5.384406969470908}, {-5.632651086018278, 
             5.480570559976622}, {-5.656854249492381, 
             5.503826610027108}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7664537807158253, 
             0.8682889416169588}, {-0.7446157503784038, 
             0.9632683062557189}, {-0.7139336772592804, 
             1.061751973144212}, {-0.6754674347074985, 
             1.1581357867653188`}, {-0.6272572054595497, 
             1.2524839498729896`}, {-0.563590271889005, 
             1.3493627926905178`}, {-0.4845761141852967, 
             1.4388640488072415`}, {-0.41184764062946144`, 
             1.497784451897346}, {-0.34359668787667097`, 
             1.5386749163355327`}, {-0.2858467923357382, 
             1.5632184339667523`}, {-0.22861167187850662`, 
             1.579571331640567}, {-0.22528505635581503`, 
             1.580216269642431}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.2021046785147394, 
             1.5847102986233268`}, {-0.17163956693559296`, 
             1.5906166343733983`}, {-0.08378226452785163, 
             1.6006687913589195`}, {0.003904601398470396, 
             1.602543280050123}, {0.0924375421127414, 1.601809529798633}, {
             0.28063378377665327`, 1.6120282628985798`}, {0.4516889137654775, 
             1.6510948555685239`}, {0.596685244682681, 1.7229477762166203`}, {
             0.6916520830869246, 1.801143975447053}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.709880004405079, 1.8161529426918483`}, {
             0.7759488766999838, 1.8705544031143901`}, {0.9120819451612285, 
             2.030177225360304}, {1.041469590098129, 2.218141045073031}, {
             1.1111472697652178`, 2.332508300495535}, {1.172025461848723, 
             2.4388652919143574`}, {1.2494703840884556`, 
             2.5839327818141746`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2605903598333699`, 2.6047623846132844`}, {
             1.2745310314967737`, 2.6308756298363516`}, {1.318675425285843, 
             2.7179283672299968`}, {1.3593748646439596`, 2.800078389866058}, {
             1.3632937454160854`, 2.8080817541609067`}, {1.4051395850352464`, 
             2.895283842929446}, {1.4441212384069204`, 2.9778306111098565`}, {
             1.5174338520028066`, 3.1349504744459087`}, {1.5825818031170213`, 
             3.2777281750109757`}, {1.641455782406026, 3.4089236360634168`}, {
             1.6635589895684924`, 3.4587953933151043`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.673126306505578, 3.4803822564489995`}, {
             1.7028978274521793`, 3.5475561310251607`}, {1.7591365923962285`, 
             3.675884154396247}, {1.811010199924639, 3.795399246931019}, {
             1.8593567727238762`, 3.9075929493838224`}, {1.9473807913612944`, 
             4.113642357132948}, {2.014220701238613, 4.271310147246035}, {
             2.046514813224511, 4.3479059041213475`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0556880507062867`, 4.369663154118512}, {
             2.0759152859080574`, 4.41763847514456}, {2.1332440117148885`, 
             4.554245912874968}, {2.186986345004368, 4.682751032483703}, {
             2.2376013373034227`, 4.804139295330028}, {2.2855480401389814`, 
             4.919396162773206}, {2.3624562747978053`, 5.104712259451572}, {
             2.419059709729514, 5.2414428430167685`}}]}, 
           {Arrowheads[{{0.009018401637648112, 1.}}], 
            ArrowBox[{{2.42809123901327, 5.263259297635538}, {
             2.4337078339106553`, 5.276826677404898}, {2.5001300145613206`, 
             5.43758652499697}, {2.5625501138335904`, 5.588838910591574}, {
             2.5907592103579717`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.8587545308919433, 0.42481794994742195`}, {
             0.8621260519551621, 0.422760141743407}, {0.8666169233743081, 
             0.4200126508322312}, {0.8733662920325228, 0.4158756579811163}, {
             0.8860817387114869, 0.4081984744615917}, {0.9062540544479764, 
             0.3963867222327483}, {0.9193622634046436, 0.38891256194372}, {
             0.9345918514476592, 0.3804262243004381}, {0.9523481398958547, 
             0.3708143863529027}, {1.033973165447186, 0.3340269010021344}, {
             1.1160017495453178`, 0.31055189723142484`}, {1.2138953223324642`,
              0.2989785695507825}, {1.3378179926925582`, 
             0.2988672591242103}, {1.504514928537378, 0.31157617477193733`}, {
             1.7242722429385828`, 0.3389243853080019}, {1.7741227475165977`, 
             0.3464816312848591}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7974680038935522`, 0.3500207297619334}, {
             1.9550251758075547`, 0.37390611093613335`}, {2.085673007547065, 
             0.39521851951052356`}, {2.202508642115704, 0.4148266331259609}, {
             2.3464144956811483`, 0.4395523185321841}, {2.475088938740763, 
             0.462024740493153}, {2.61495439304399, 0.486784366180031}, {
             2.7287541188107736`, 0.50711370030461}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.751994944206669, 0.5112838139122586}, {
             2.964429366933841, 0.5496071861930997}, {3.0640372983956246`, 
             0.5677008745231719}, {3.157599532179761, 0.5847481618328274}, {
             3.201471362232225, 0.5927573786070661}, {3.299246992405735, 
             0.6106590084515909}, {3.3917791900804954`, 0.627633107548046}, {
             3.567940471387142, 0.6599939715100175}, {3.6811293773187055`, 
             0.6808409238430697}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.7043507999974774`, 0.6851178084697548}, {
             3.72817564391197, 0.6895058302581104}, {3.8756721623845123`, 
             0.716723438771042}, {4.034622484872463, 0.7460961677903668}, {
             4.181923626018929, 0.7733509075807999}, {4.3192847067518985`, 
             0.7987937608446936}, {4.448414847999354, 0.8227308302843998}, {
             4.633060409804164, 0.8569906811896559}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.656276165318886, 0.8612982221606544}, {
             4.68606599245448, 0.8668255417787543}, {4.867506432380787, 
             0.9005176243775361}, {5.0362929878002465`, 0.9318772675951228}, {
             5.194210919057981, 0.9612310496394578}, {5.343045486499112, 
             0.9889055487184844}, {5.483885634943559, 1.0151008235715344`}, {
             5.584853599102872, 1.0338840763121118`}}]}, 
           {Arrowheads[{{0.0010509427901049906`, 1.}}], 
            ArrowBox[{{5.608067320330555, 1.0382025668006483`}, {
             5.617820309211238, 1.0400169329379396`}, {5.656854249492381, 
             1.0473098815352888`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.982427898419386, 
             0.002656590621080105}, {-0.9868630161734118, 
             0.0026821792228437875`}, {-0.9909684565048212, 
             0.0027059635787961794`}, {-0.9950836932357664, 
             0.002729905751855775}, {-1.0019394609445786`, 
             0.002770019834866368}, {-1.006950115689085, 
             0.0027995579008435177`}, {-1.030259633492424, 
             0.0029371636184953058`}, {-1.0535292195641568`, 
             0.0030738099638354627`}, {-1.096022045653472, 
             0.003320268589640918}, {-1.1341768189602837`, 
             0.003537842011088166}, {-1.1689652803862882`, 
             0.003732850730080866}, {-1.2871359639032733`, 
             0.00437303068559252}, {-1.420273721242133, 
             0.005052550252310643}, {-1.5767069620554803`, 
             0.0058036707785049995`}, {-1.749357266328622, 
             0.006587099242680426}, {-1.9268958018836368`, 
             0.007355265162204578}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.9505075756613772`, 
             0.0074570047633065704`}, {-2.170967449985726, 
             0.008374721929892486}, {-2.3022749655143735`, 
             0.008908434004723477}, {-2.41968331607098, 
             0.00937977688703375}, {-2.567864090389678, 
             0.009967938129111089}, {-2.7004016499611696`, 
             0.010489139096630674`}, {-2.8505543138851746`, 
             0.011074721960650336`}, {-2.8949796872470697`, 
             0.011246870645907273`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.918591502971871, 
             0.01133836662502807}, {-2.9862360084563973`, 
             0.011600489637234538`}, {-3.224724045989048, 
             0.012517855956577102`}, {-3.3312863762985168`, 
             0.012925467723378076`}, {-3.431397442473221, 
             0.013307386687743956`}, {-3.4686273960667746`, 
             0.01344918159679065}, {-3.573131243553041, 
             0.013846147272092437`}, {-3.6720665515519646`, 
             0.014221243591749963`}, {-3.860491019093684, 
             0.014934556431854651`}, {-3.863064339054938, 
             0.014944270678151749`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.886676163813143, 
             0.015033404981183917`}, {-4.032021030454345, 
             0.01558207978798237}, {-4.190040181881379, 
             0.01617726975726349}, {-4.360680947145528, 
             0.016818845740511193`}, {-4.518926800242206, 
             0.01741279726805649}, {-4.6665916710280095`, 
             0.01796619061097911}, {-4.80548948935953, 
             0.018486092040358785`}, {-4.831149217149643, 
             0.01858203177474061}}]}, 
           {Arrowheads[{{0.016984986883223016`, 1.}}], 
            ArrowBox[{{-4.8547610451069225`, 
             0.018670314570295585`}, {-4.936703774831231, 
             0.01897669208873914}, {-5.061318047037576, 
             0.01944218128866381}, {-5.257046184375607, 
             0.02017256123240306}, {-5.439228258115992, 
             0.020851601580737133`}, {-5.609768697002778, 
             0.02148658579767921}, {-5.656854249492381, 
             0.021661750941006076`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.7728961846715653, -1.0594157825126849`}, \
{-0.7518472320703872, -1.1623295342929814`}, {-0.7277705071477614, \
-1.2659342221481018`}, {-0.6991447750335785, -1.371782709997111}, \
{-0.6662545015378596, -1.4809275125345298`}, {-0.6314837242515072, \
-1.5918114900352218`}, {-0.5925023797048147, -1.705436045735161}, \
{-0.55101602289659, -1.81307129083792}, {-0.5032178257521146, \
-1.9300946894935491`}, {-0.49109254244933465`, -1.9589840342025338`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.48195449173765553`, -1.9807560860701676`}, \
{-0.4555273849530127, -2.0437205363430664`}, {-0.3997905409230593, \
-2.16255041613422}, {-0.35399250147663225`, -2.2394703299636936`}, \
{-0.2995449173504019, -2.3161725630325836`}, {-0.23437318679025498`, \
-2.404448330294335}, {-0.17481549561384585`, -2.478791982059761}, \
{-0.12772248200345954`, -2.5294539988810594`}, {-0.09179966778693863, \
-2.5604305049300113`}, {-0.05904035541932643, -2.580864874660459}, \
{-0.02774188214440385, -2.5920147124133743`}, {
             0.008773216642364367, -2.59595343279562}, {
             0.0461256068234983, -2.6001534842484997`}, {
             0.08356234820947182, -2.612588625597108}, {
             0.12620835593547558`, -2.6459934034034416`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14479664616598584`, -2.6605536808610477`}, {
             0.1789580486793111, -2.6873124355806493`}, {
             0.2435148625053113, -2.8000774457581303`}, {
             0.27505750928893347`, -2.925061746554959}, {
             0.27918249595727085`, -3.081661761515887}, {
             0.25535161500491677`, -3.2149318182514564`}, {
             0.17624531369501378`, -3.3862615474991093`}, {
             0.12183392336677629`, -3.4425979047298227`}, {
             0.06184451614489177, -3.4761796838348946`}, {
             0.04769628503206699, -3.4789946989408502`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{
             0.024538226962948016`, -3.483602362101659}, \
{-0.002918471985486684, -3.4890653080829037`}, {-0.03503765954564108, \
-3.494176392521279}, {-0.0685432163209366, -3.5064021499673252`}, \
{-0.1035912466272444, -3.5290694406377816`}, {-0.13991125998309184`, \
-3.5585567660018715`}, {-0.22758762582419573`, -3.6428617688262435`}, \
{-0.3207029838169624, -3.757827992086157}, {-0.3983033143253658, \
-3.86846735912856}, {-0.4768579756953846, -3.990672526583548}, \
{-0.5552795351447423, -4.121148432394181}, {-0.5837766837027198, \
-4.171147559613822}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-0.5954686855443526, -4.191661537927923}, \
{-0.6324805598911629, -4.256600014503521}, {-0.7103182520000718, \
-4.399551234028847}, {-0.7906498135368941, -4.552526052087437}, \
{-0.8732133804903199, -4.714337300436213}, {-0.9577470888490385, \
-4.883797810832095}, {-1.0294781654294727`, -5.030330853039701}}]}, 
           {Arrowheads[{{0.014184875063788752`, 1.}}], 
            ArrowBox[{{-1.0398596188515883`, -5.051538201723132}, \
{-1.0430397204527577`, -5.05803454869523}, {-1.1278800571411853`, \
-5.234174479445765}, {-1.2116384559803075`, -5.410542550109502}, \
{-1.2936852740361116`, -5.585463707712243}, {-1.3267412547516229`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3249152433475832, -1.6482667117150278`}, \
{-0.23702768314902356`, -1.682692825753373}, {-0.17901612685899776`, \
-1.6966668695270863`}, {-0.12176090716612306`, -1.7062646726488107`}, \
{-0.06494035247570994, -1.7116660898894884`}, {
             0.007617753064443587, -1.7130290633475613`}, {
             0.08084524560662423, -1.7128343213750798`}, {
             0.154275031335957, -1.7153258038140191`}, {
             0.269723974144237, -1.725100446127829}, {
             0.3789628340530924, -1.7489171172664844`}, {
             0.48005267293859827`, -1.791482281380428}, {
             0.5462141231210127, -1.831812959862887}, {
             0.578837870390314, -1.8569427457380276`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5975437119074131, -1.8713516911010073`}, {
             0.6047603694283376, -1.8769106189806906`}, {
             0.6572791671658011, -1.9253903878714862`}, {
             0.7510979278683916, -2.027053990117202}, {
             0.8316759546189311, -2.1319178486645707`}, {
             0.9616963520304201, -2.3363801071540973`}, {
             1.0295947501592255`, -2.4585773756938596`}, {
             1.0887883133001641`, -2.572578766895968}, {
             1.1251277344766635`, -2.646936581546358}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.135495301154414, -2.6681507224556325`}, {
             1.1580718343855745`, -2.7143468813129075`}, {
             1.2185664325972914`, -2.8443450430698647`}, {
             1.2924841982922457`, -3.0103856611277773`}, {
             1.3570164082738418`, -3.1606793091960017`}, {
             1.4259228252571916`, -3.326351530763765}, {
             1.4871266687381106`, -3.4770358970892894`}, {
             1.510163549431516, -3.5349138476228266`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.5188954623438087`, -3.5568519402980865`}, {
             1.5421196156230823`, -3.6152003952200187`}, {
             1.5923933428185904`, -3.7433130122033966`}, {
             1.6385657683459764`, -3.862519054175011}, {
             1.682851460087752, -3.9779638673566007`}, {
             1.7265046949787304`, -4.093196018931446}, {
             1.7675203914349662`, -4.202202420561629}, {
             1.845164593776884, -4.409626295718339}, {
             1.8560795105990446`, -4.439069556691176}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8642869102941777`, -4.461209222532839}, {
             1.915027129708906, -4.598082232780031}, {
             1.9787765262813002`, -4.771330769315016}, {
             2.0469524815221254`, -4.957674577855812}, {
             2.109707010331767, -5.130114883759114}, {
             2.167877281917489, -5.290694829285107}, {
             2.1886503443029786`, -5.348240223297138}}]}, 
           {Arrowheads[{{0.006447152985549317, 1.}}], 
            ArrowBox[{{2.1966675623073506`, -5.370449465265438}, {
             2.2223004654865552`, -5.441457556693978}, {
             2.273376244974346, -5.583168960367668}, {
             2.299955252440327, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.6219709422913171, 
             1.663440607877524}, {-0.584980989507242, 
             1.7769190043215406`}, {-0.5452638554944272, 
             1.890222460734251}, {-0.5034684369670179, 
             2.0133642087308083`}, {-0.46401823547568305`, 
             2.1344501105538494`}, {-0.42253993438328613`, 
             2.2615842486712316`}, {-0.3855555810227375, 
             2.3661109643476954`}, {-0.3457563257913767, 
             2.47683975315695}, {-0.32307968860151803`, 
             2.5591737664562864`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.31680987500868174`, 
             2.581938116893917}, {-0.312819162013894, 
             2.596427541143013}, {-0.2953822794434657, 
             2.7237842591145034`}, {-0.29918770527508914`, 
             2.8621590527335146`}, {-0.33748187756176157`, 
             3.051473363062652}, {-0.3990095053700479, 
             3.232296382496075}, {-0.43772806137422726`, 
             3.328347723519913}, {-0.4788041225555422, 
             3.424370128470264}, {-0.5074389375785603, 3.48860177294728}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.5170531793822225, 
             3.5101677778595692`}, {-0.5385285423145104, 
             3.5583398326038647`}, {-0.5756659513265985, 
             3.639611036906535}, {-0.6148068929486069, 
             3.724036265127199}, {-0.6581362507730546, 
             3.815869846536641}, {-0.7032585318605656, 
             3.9109527648305367`}, {-0.7956690758735382, 
             4.105355863541385}, {-0.8909702947263916, 
             4.305825783589335}, {-0.9189096455209009, 
             4.364867307989741}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.9290094421065215, 
             4.386210230054567}, {-0.9866949849299883, 
             4.50811150146248}, {-1.078841888026404, 
             4.704009816842297}, {-1.1688198013530717`, 
             4.896740154539299}, {-1.2557751172498592`, 
             5.084581550275847}, {-1.3281789813744633`, 5.242184766863011}}]}, 
           {Arrowheads[{{0.009144478563519541, 1.}}], 
            ArrowBox[{{-1.3380360454858113`, 
             5.263640873230219}, {-1.339740221533738, 
             5.267350393848094}, {-1.4205605345612407`, 
             5.444590713885613}, {-1.4983375079670131`, 
             5.616342854888293}, {-1.5165502705736378`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAAfeZeDGjf4L8j4eOxYyjrP254kpH4
X+C/tRykzzeb6z/YqrpDJ6Xfv2VEgDGQDuw/hu3O90zJ3r9hREQOBGDsPxWu
PrgNv92/4cHB3/S47D8pLW2RZpncv50nqZ6pEu0/LI+kdq0O3L8tabyWqTrt
PwqMaJinitu/9EmWtIZf7T/xTJYr7Qnbvz64jG9Jgu0/L/TYyGMN2b+QmXfz
3P/tP1rju5uKA9e/jTAXleZs7j8kZfqvnyzWv/FnYoMtlO4/hl9oroFG1b+p
S5GEhrruP4SYqsgXL9S/Zluh7tjj7j+L//AukMLSv5dHA1BeFO8/g/QrAmyV
0b+LMFzefTjvP94a3+tHfNC/tuvYMg1X7z8hY+gjNdvOv0Mhz0nEce8/wSTy
bGLYxb/WWQnU+r7vP2VTFAn4J7a/xmkpHJPq7z8IcvHZKEmFv8oF6RA76u8/
Nge/IdFWnj99hTrNP+DvP2HWmwumnbE/D/O3O8/S7z/bXdNv6NK7P4bfd+I9
wu8/3P2ACy39wj8YKPXjoK7vP5sF51icesg/xyyHaSqX7z9JKdgOTCHOP4WV
pcMCfu8/RS/4tdgD0D+kG1ebZnXvP6+hJWWZAtE/DuYjikNs7z/kUuOWHBTS
P1oEhARHYu8/RzNmc1in0j/1T3B3z1zvP1Vs2EWzR9M/TmcDB8FW7z9U58Sl
NFDUP7J+JbSDTO8/dP70fdRo2D8lHFfbjSLvP4v/ISs=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4049350588381821, 0.9710844042845435}, {
             0.4197080565900637, 0.9699021315760562}, {0.5942856923042915, 
             0.9571968936993634}, {0.7340770925826713, 0.9530877703641404}, {
             0.8657979211242137, 0.9608298030978365}, {0.9996004645967169, 
             0.9853269848226447}, {1.1420401628449859`, 
             1.0311785776701436`}, {1.2994858174990638`, 
             1.1013286646652742`}, {1.3212225865227678`, 
             1.1132465009465902`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3419268095184937`, 1.1245982128650376`}, {
             1.4734559146017565`, 1.1967129939946948`}, {1.6642240463561784`, 
             1.3157905517776838`}, {1.7745342073920491`, 
             1.3893649294002985`}, {1.8728515013812124`, 
             1.4569461955349328`}, {1.9935189469153907`, 1.542055785811827}, {
             2.101198679510306, 1.6194686268867475`}, {2.1314060345858135`, 
             1.6415462201690076`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.150469249895692, 1.655478916799071}, {
             2.233515389262104, 1.7161746938378275`}, {2.3517307950574655`, 
             1.8036463198498476`}, {2.496695822521405, 1.9120660757921846`}, {
             2.6263972565226386`, 2.0098554177257775`}, {2.7881133503485054`, 
             2.132645345967618}, {2.9057922290090015`, 
             2.222480239043879}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.924560510095894, 2.236807759358977}, {
             2.9327884617732307`, 2.2430888963615025`}, {3.092127568302467, 
             2.365287631896117}, {3.2363626443398643`, 2.47626566608738}, {
             3.3681844669261367`, 2.577968295919626}, {3.4902838131019993`, 
             2.6723408183771893`}, {3.6038276438020556`, 
             2.7602432096634675`}, {3.6725371665549784`, 
             2.8134965214552596`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6911999899116843`, 2.8279611416608703`}, {
             3.7105160031040576`, 2.8429320166123206`}, {3.7212782716919577`, 
             2.8512780233631942`}, {3.8317028006414717`, 2.936991343546809}, {
             3.936240766958618, 3.01819464766609}, {4.038280682794766, 
             3.097477990879548}, {4.135324497668915, 3.172921412281361}, {
             4.316529669482516, 3.3138878928698765`}, {4.436900657055531, 
             3.4075922362297613`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.45553264853283, 3.42209654962013}, {4.48342685224061,
              3.4438111512420444`}, {4.663589285515506, 
             3.5841264187372084`}, {4.8306250699748645`, 
             3.7142697959593844`}, {4.986456046603757, 3.835721124297662}, {
             5.133004056387256, 3.9499602451411304`}, {5.20054183152481, 
             4.002616336799662}}]}, 
           {Arrowheads[{{0.011753756200986202`, 1.}}], 
            ArrowBox[{{5.219163067207707, 4.017134456339678}, {
             5.271417924712656, 4.0578751612382336`}, {5.402846476967251, 
             4.160353875337413}, {5.507500157254928, 4.241968754751093}, {
             5.608166305487606, 4.320492366435719}, {5.656854249492381, 
             4.358480557453142}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7983394305094924, -0.5770250433523318}, {
             0.8022255679895545, -0.5751998600553919}, {
             0.8088289171406715, -0.5721017746308815}, {
             0.8174553628532193, -0.568091159907427}, {
             0.8403805314514912, -0.5576428307323079}, {
             0.8672550800848488, -0.5456673202868062}, {
             0.8972600828945364, -0.5325735589638168}, {
             1.014436335471486, -0.49062571874075245`}, {
             1.1139953056210543`, -0.47100768777022584`}, {
             1.2275090368920714`, -0.46605692725486647`}, {
             1.3620753662647131`, -0.47649647958987507`}, {
             1.5526801645066397`, -0.5081411902076691}, {
             1.7168475114638548`, -0.5451527594066463}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7398813790501928`, -0.5503457505823763}, {
             1.7662115481001603`, -0.5562818937428528}, {
             1.9938420696148025`, -0.6148118660804033}, {
             2.124535010001746, -0.6503283112362892}, {
             2.241379998954827, -0.6828188237332808}, {
             2.3842615636704054`, -0.7233241210469745}, {
             2.512133562255028, -0.7600773294173042}, {
             2.650578869996327, -0.8003422481492448}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6732481480501367`, -0.8069475139538432}, {
             2.808485566190482, -0.8466223654911378}, {
             2.982909852891158, -0.898181745126253}, {
             3.1391556126046862`, -0.9446332382694619}, {
             3.308523297349683, -0.995233323635246}, {
             3.462186403447949, -1.041302295633142}, {
             3.578509600478268, -1.076278747945198}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6011215305683324`, -1.0830777795628772`}, {
             3.602894084144346, -1.083610756967254}, {
             3.7333954926837385`, -1.122929310341686}, {
             3.854896993736442, -1.1596029789353197`}, {
             3.969159462264792, -1.194136919431301}, {
             3.993629776504147, -1.2015380165601537`}, {
             4.111995959841423, -1.2373804034860405`}, {
             4.224134483388814, -1.2713673534090295`}, {
             4.437812907048174, -1.3361728251425578`}, {
             4.505123794694632, -1.3566128100857724`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.527717062201706, -1.3634736028016283`}, {
             4.632502833199826, -1.3952934116966518`}, {
             4.811955969809747, -1.449838705425789}, {
             5.006138119001937, -1.5089035791403276`}, {
             5.186239338815038, -1.5637218201445984`}, {
             5.354310612573613, -1.6149075194957}, {
             5.431307467289746, -1.6383667670096147`}}]}, 
           {Arrowheads[{{0.004493213343764717, 1.}}], 
            ArrowBox[{{5.453894365948648, -1.6452484980642714`}, {
             5.512402923602225, -1.6630747682507314`}, {
             5.656854249492381, -1.707141921867504}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.1594304599835965`, -0.3941821066808388}, \
{-1.2608065356356142`, -0.45520413380451763`}, {-1.3814638353815683`, \
-0.5229010167460374}, {-1.5173944737849574`, -0.5939665996526637}, \
{-1.6809844923050625`, -0.6742074746078125}, {-1.867467418852319, \
-0.7608013825776786}, {-2.0014207529937025`, -0.8203672898199331}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.022995805906818, -0.8299612100370511}, \
{-2.0845462932458623`, -0.8573312687448352}, {-2.212946557686533, \
-0.9129235288352133}, {-2.327767327773405, -0.9619655345792228}, \
{-2.4709504284250943`, -1.0223712273172867`}, {-2.599167411655725, \
-1.0759301637399366`}, {-2.7578226925156577`, -1.1416114291824817`}, \
{-2.893114425524599, -1.1972177692257049`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.91496775859336, -1.2061596593886565`}, \
{-3.078890782665267, -1.2730916898477609`}, {-3.239186382447282, \
-1.3381905863780286`}, {-3.414512297864103, -1.40905282094984}, \
{-3.5736731916468445`, -1.4731453542462374`}, {-3.7195083647408405`, \
-1.5316855000994376`}, {-3.790596018084353, -1.56015500047994}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.812515539536249, -1.568933428166949}, \
{-3.8548571180914233`, -1.5858905723416572`}, {-3.980959159487782, \
-1.636284021858894}, {-4.099622887344704, -1.6836275604041702`}, \
{-4.117458696076408, -1.6907373131991188`}, {-4.240114836442574, \
-1.7395565345470896`}, {-4.356393419636713, -1.7857803871910127`}, \
{-4.578086094506987, -1.8738225246997193`}, {-4.6900422806772655`, \
-1.9182010268198244`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.711992671115324, -1.9269019792362536`}, \
{-4.780302043848076, -1.9539792471063187`}, {-4.966868520962626, \
-2.027820680977813}, {-5.169262998765738, -2.1078265506522342`}, \
{-5.35711232505037, -2.181992431484118}, {-5.531911349668015, \
-2.250978949547044}, {-5.590356531455709, -2.274059988125158}}]}, 
           {Arrowheads[{{0.0010139638542474173`, 1.}}], 
            ArrowBox[{{-5.612317993035559, -2.282732958701203}, \
{-5.656854249492381, -2.300321116047326}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1578923545710098`, 
             0.39762477202476704`}, {-1.2581416718579, 
             0.4587036590659576}, {-1.3780718624296369`, 
             0.5268277898978649}, {-1.5132015747219085`, 
             0.5983438227797773}, {-1.675849889977429, 
             0.6790900242085656}, {-1.8610838687704545`, 
             0.7661288871273927}, {-1.9978976040480845`, 
             0.8276777543623718}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.019430907880926, 
             0.837365016069309}, {-2.077488942278457, 
             0.8634837843626102}, {-2.2055063134751256`, 
             0.9195459687331842}, {-2.3199811066971807`, 
             0.9689956454035372}, {-2.4627449025431716`, 
             1.0299026536958418`}, {-2.5905827816872624`, 
             1.0839003526777446`}, {-2.7487783033417945`, 
             1.150118915683072}, {-2.888107726054776, 1.2080177822602587`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.9099307369720213`, 
             1.217033440396959}, {-3.0689133213637567`, 
             1.2826623730135402`}, {-3.2287418761937166`, 
             1.3482829082471812`}, {-3.4036075776073353`, 
             1.4197309033264087`}, {-3.5623446220927013`, 
             1.4843487995555207`}, {-3.707786805573169, 
             1.5433653459140535`}, {-3.784225356700641, 
             1.5743097036802942`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.8061119259825573`, 
             1.5831699688232819`}, {-3.842767923972091, 
             1.5980092913815436`}, {-3.968525028404766, 
             1.6488088380924633`}, {-4.0868625625992605`, 
             1.696532565854102}, {-4.1046732812724285`, 
             1.7037090018294134`}, {-4.226997916411504, 
             1.7529214592049407`}, {-4.342960876176715, 
             1.7995165624261416`}, {-4.564049812659992, 
             1.8882641945428285`}, {-4.682348847899553, 
             1.9356609290847204`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.704267102407185, 
             1.944442519639674}, {-4.765711729137474, 
             1.9690604267617708`}, {-4.951764811733683, 
             2.0434889643604612`}, {-5.153591424187619, 
             2.124125543450948}, {-5.340912734360528, 
             2.1988747445163734`}, {-5.515326871573821, 
             2.268438721222678}, {-5.581364287639781, 2.2947884493282564`}}]}, 
           {Arrowheads[{{0.0012211065085189787`, 1.}}], 
            ArrowBox[{{-5.6032949355918245`, 
             2.3035390432360843`}, {-5.656854249492381, 
             2.324909857584595}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.923780697299038, -1.553131310762741}, \
{-0.9599007695162286, -1.6990849780399069`}, {-1.0099543577603687`, \
-1.861653287121891}, {-1.0767086109856274`, -2.044361061622522}, \
{-1.1632892476864787`, -2.251755616040975}, {-1.2192313025321515`, \
-2.3752191768541397`}, {-1.248846052602906, -2.4377790701414046`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.2589487626940223`, -2.4591206132475394`}, \
{-1.27158518473822, -2.485814514520694}, {-1.3425268275990145`, \
-2.6298161626344196`}, {-1.4082654739451304`, -2.758799956856814}, \
{-1.4917530122610139`, -2.9176831242785126`}, {-1.5687800120199948`, \
-3.060645265396446}, {-1.671051321340731, -3.2461655348837457`}, \
{-1.6984572347698776`, -3.2949213118783285`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-1.710027118258489, -3.3155044119703003`}, \
{-1.7647168017371693`, -3.4127986699589816`}, {-1.8712260214971206`, \
-3.5990408611820492`}, {-1.9693156908440244`, -3.7682559925211305`}, \
{-2.060333946023463, -3.9234636498073954`}, {-2.145628923281019, \
-4.067683418872014}, {-2.1841576950320554`, -4.1323214190198465`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.1962473044918456`, -4.1526036170379585`}, \
{-2.2258204041598573`, -4.202217085981759}, {-2.3018198225262063`, \
-4.328960343371872}, {-2.3040868672227326`, -4.332730182992637}, \
{-2.3829663296405803`, -4.4632078800912085`}, {-2.458171774882773, \
-4.587047191236487}, {-2.5317855658863446`, -4.708053135360059}, \
{-2.6022160484126737`, -4.823392345440214}, {-2.6697718395187087`, \
-4.933646253700035}, {-2.6860550552569435`, -4.960141994567576}}]}, 
           {Arrowheads[{{0.016852397051598352`, 1.}}], 
            ArrowBox[{{-2.6984180019944075`, -4.980258747817114}, \
{-2.7347615562613976`, -5.039396292362597}, {-2.857923924897003, \
-5.2390140037676955`}, {-2.9264676484559913`, -5.349718907368155}, \
{-2.992762628699071, -5.456574435251245}, {-3.056808865626242, \
-5.559580587416964}, {-3.1174327455663176`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.18825306821630777`, 
             2.1962127221743533`}, {-0.11768879700902406`, 
             2.229622929886024}, {-0.05099884478017056, 2.246665658773838}, {
             0.014859681838091825`, 2.2513551360215738`}, {
             0.10473516503739042`, 2.259541938092239}, {0.19242311120700029`, 
             2.2835640562101007`}, {0.27236107307548435`, 
             2.3213681723615274`}, {0.35741835315248094`, 
             2.383269154464311}, {0.4276417000351511, 2.4619448992145685`}, {
             0.4872405679660089, 2.5586313614381777`}, {0.5411202517265247, 
             2.673627266444472}, {0.5448073084331714, 2.6837018908300427`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.552922318393895, 2.7058755875600315`}, {
             0.5843159397733468, 2.791656460669642}, {0.6451574731992923, 
             3.019060424507206}, {0.6707747043287494, 3.150027817726103}, {
             0.6894613489249445, 3.270021702375234}, {0.7061289999413383, 
             3.4125162252616192`}, {0.7161837352370249, 3.539477476350054}, {
             0.7194424074217817, 3.6314378624533927`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.7202785879236852, 3.655035044817065}, {
             0.722452336935618, 3.7163786802291074`}, {0.7196479416230905, 
             3.865381991823987}, {0.6936985699973038, 4.096424343658411}, {
             0.63998031394642, 4.30351602247032}, {0.6095314561736725, 
             4.385999755366153}, {0.5787726170562446, 4.46110183473782}, {
             0.5443321281571332, 4.532790124002945}, {0.5259420644915475, 
             4.567198133819572}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.5148121074186807, 4.588022404968697}, {
             0.5097897678807115, 4.597419257055091}, {0.4405624963359265, 
             4.714274210939467}, {0.3709714868784663, 4.808298322078583}, {
             0.3008185794492153, 4.882764388766926}, {0.12107013902835181`, 
             4.996277453859422}, {-0.027660160600602585`, 
             5.0313471849920095`}, {-0.14324778042954667`, 
             5.065789264636595}, {-0.22242047978639468`, 
             5.114028732943465}}]}, 
           {Arrowheads[{{0.014929049764336816`, 1.}}], 
            ArrowBox[{{-0.24258444763057324`, 
             5.126314522055895}, {-0.26231094994763593`, 
             5.13833376595006}, {-0.3827446710739403, 
             5.244817243644833}, {-0.502912877445217, 
             5.380114577667668}, {-0.6206138029074175, 
             5.536585923476285}, {-0.7005248722429219, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8985120207026023, 
             1.3054181274549248`}, {-0.9184190604274555, 
             1.4289578913595238`}, {-0.9482198409209812, 
             1.5636849424371249`}, {-0.9905541556594375, 
             1.7124724956803343`}, {-1.0483061386009975`, 
             1.8787124963320878`}, {-1.1244659351849002`, 
             2.066065090059461}, {-1.1864331482409587`, 2.200955541463866}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.196289914155219, 
             2.2224117848220972`}, {-1.2222832513185777`, 
             2.2789941742915163`}, {-1.285157438013369, 
             2.405984351241951}, {-1.3438048187824887`, 
             2.5198128124443158`}, {-1.422439108207364, 
             2.667017407482865}, {-1.4951175055300596`, 
             2.7989867275634808`}, {-1.5890337820561826`, 
             2.96490249803946}, {-1.6412750232383053`, 
             3.0551290852850537`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.653106301629549, 
             3.0755630536946663`}, {-1.6753407062119783`, 
             3.113964408630255}, {-1.7876237693008898`, 
             3.3039578736191135`}, {-1.8902204915853291`, 
             3.474626831973972}, {-2.0053709142674316`, 
             3.6633240324950966`}, {-2.1112891673502627`, 
             3.834888573460944}, {-2.14176382179767, 
             3.8837636804102313`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.154256836091082, 
             3.9037999177616096`}, {-2.2094578756539716`, 
             3.992331084439945}, {-2.3013596639987073`, 
             4.13866219500053}, {-2.3876759291338274`, 
             4.275189168193947}, {-2.469408976238609, 
             4.403817995635704}, {-2.4718204860278474`, 
             4.407603948263409}, {-2.5564797191234394`, 
             4.539930052481936}, {-2.6371337973907774`, 
             4.665522207497645}, {-2.660171052174959, 4.701342953933898}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.6729431949886764`, 
             4.721202424754697}, {-2.7160563026169475`, 
             4.788239218456852}, {-2.7915156617607817`, 
             4.905205941303056}, {-2.863849551680163, 
             5.017010979434318}, {-2.9333956492329745`, 
             5.124242936248693}, {-3.0650876945400514`, 
             5.326639433407398}, {-3.138030742433927, 
             5.438345865698395}, {-3.18719719317469, 
             5.5134015165507675`}}]}, 
           {Arrowheads[{{0.0031347007617458966`, 1.}}], 
            ArrowBox[{{-3.200135723134014, 
             5.533152988795333}, {-3.2079432099605483`, 
             5.545071603957867}, {-3.274825097119916, 
             5.646816648185816}, {-3.2814485484135107`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4461525133633055, 1.2338086519291254`}, {
             0.6471812710361465, 1.2676923424962063`}, {0.8018052151034177, 
             1.3230013410561747`}, {0.948214555418899, 1.4023942515158907`}, {
             1.0877461369419776`, 1.50398318360608}, {1.2370918368693489`, 
             1.635685948448363}, {1.2642371380956803`, 
             1.6624613062576588`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.2810474935235163`, 1.679042565670803}, {
             1.3578875480412032`, 1.7548354233975434`}, {1.4108594369886993`, 
             1.8099577966110953`}, {1.460149123950853, 1.8624844643014575`}, {
             1.5187711400080186`, 1.9264864611932453`}, {1.677509521311742, 
             2.104491680576234}, {1.8101766746550636`, 2.258588976882588}, {
             1.897529353189105, 2.362218255160936}, {1.9128467342282451`, 
             2.380566143489998}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9279787759276943`, 2.3986920235332483`}, {
             1.977665971802343, 2.4582097125535047`}, {2.1198234018926216`, 
             2.6307909670540233`}, {2.2533739655597778`, 
             2.7950266537625783`}, {2.372100934692213, 2.9422556918110385`}, {
             2.479408496540963, 3.0761154970965463`}, {2.5237039703167827`, 
             3.1315745763857348`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.5384396984949538`, 3.1500240893439466`}, {
             2.5785275896835973`, 3.200215166365026}, {2.6714146826853913`, 
             3.316779913981187}, {2.758069775546346, 3.4258097399450307`}, {
             2.83849286826646, 3.5273046442565557`}, {2.9862242065018725`, 
             3.7142549463084276`}, {3.120189850609332, 3.8841960785225775`}, {
             3.124987376750421, 3.8902941263455757`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1395870431799353`, 3.9088514955956355`}, {
             3.242814203606078, 4.040061653164066}, {3.3565216685093486`, 
             4.18478528249795}, {3.4623713728018504`, 4.319666900430907}, {
             3.561908391204315, 4.446607112485434}, {3.5653502949631397`, 
             4.450998249734469}, {3.6677080017852397`, 4.581667366062124}, {
             3.722665126881079, 4.651859803070514}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.737221320938526, 4.670451291120106}, {
             3.764692709380443, 4.705538346699879}, {3.8593930445415383`, 
             4.826511574437784}, {3.9495246348344173`, 4.94168929637599}, {
             4.035563849872095, 5.051669922501129}, {4.117987059267586, 
             5.157051862799836}, {4.197126956048556, 5.2582546302694215`}, {
             4.27331623324267, 5.355697737907198}, {4.319191868475759, 
             5.414327749081568}}]}, 
           {Arrowheads[{{0.006026127200304587, 1.}}], 
            ArrowBox[{{4.333742419286961, 5.432923654126142}, {
             4.35857479254004, 5.464659941022592}, {4.439851761231715, 
             5.568353094184085}, {4.509354352951271, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5766245474191871, -0.8582044360030926}, {
             0.7243413118318561, -0.83570980317119}, {
             0.8477134341183992, -0.8222719730155096}, {
             0.9709153236489629, -0.8209185358446764}, {
             1.1060316659055813`, -0.8369499150294711}, {
             1.257683023388461, -0.876007479321804}, {
             1.4278141363318382`, -0.9393165749000874}, {
             1.4948521658732283`, -0.96958844267086}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5163718480275248`, -0.9793059265691854}, {
             1.6019177567708698`, -1.0179352606281502`}, {
             1.7456723678132193`, -1.0897570158655923`}, {
             1.8094788905388077`, -1.123085176217009}, {
             1.8692202507626121`, -1.1548805836865867`}, {
             1.9391078900726268`, -1.1927584255937413`}, {
             2.127328083369234, -1.296790396689028}, {
             2.2872846922792727`, -1.3874267126036917`}, {
             2.349528130163886, -1.4233317870945628`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.369981152574381, -1.435130095770469}, {
             2.4965718621144792`, -1.5081538394832668`}, {
             2.6755857845537725`, -1.6127335421438385`}, {
             2.843947320940817, -1.7119443911876953`}, {
             2.9943160787494536`, -1.8010336922994388`}, {
             3.130695439248477, -1.8821399742340101`}, {
             3.184074150415909, -1.9139574431478812`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.2043563448625427`, -1.9260470585993794`}, {
             3.2569536448669516`, -1.9573987514605007`}, {
             3.3754525887516067`, -2.028131238213837}, {
             3.486192270902443, -2.094337434494018}, {
             3.58917269131946, -2.1560173403010454`}, {
             3.778699366969293, -2.2697170879320714`}, {
             3.9508762357183635`, -2.37314928854335}, {
             4.01455837769689, -2.411447230315374}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.034793056038326, -2.423616207501431}, {
             4.1087190751354665`, -2.468074736797988}, {
             4.255243662789399, -2.556254227359092}, {
             4.391778246232873, -2.638470619967487}, {
             4.520263090284919, -2.715869179535534}, {
             4.530975175156977, -2.722323230433935}, {
             4.663460307627907, -2.802167417673114}, {
             4.7890506559466655`, -2.8778706301363037`}, {
             4.843858640601689, -2.9109094717796395`}}]}, 
           {Arrowheads[{{0.01961088366833407, 1.}}], 
            ArrowBox[{{4.864080638517442, -2.92309950925421}, {
             4.91170406250098, -2.95180742058153}, {
             5.028483585526405, -3.0222113669908297`}, {
             5.1399970541777655`, -3.089446077057564}, {
             5.246852297609885, -3.1538751584750933`}, {
             5.448290679400042, -3.275337241358419}, {
             5.557524397285233, -3.3413873702057617`}, {
             5.656854249492381, -3.401824118315422}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.002269561045007029, -2.2382338443519356`}, {
             0.08695273739192182, -2.243105943177237}, {
             0.17702555813968263`, -2.2638159430104254`}, {
             0.26018827283174367`, -2.2987935973698788`}, {
             0.33271269678797055`, -2.344986480123153}, {
             0.40160601097897203`, -2.4089993049479417`}, {
             0.4611233713224567, -2.4888635561797288`}, {
             0.512671465027672, -2.581938912485258}, {
             0.5664026842890666, -2.704777684937922}, {
             0.6089491381916695, -2.8280069059335182`}, {
             0.615512221398663, -2.853726809310966}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.6213503423974395, -2.8766056763401657`}, {
             0.668389516759752, -3.060946325604584}, {
             0.6940036936527374, -3.196428408941501}, {
             0.7127612592957775, -3.319983681718702}, {
             0.7295425377169168, -3.4651630238126088`}, {
             0.7399643003958165, -3.594455930366116}, {
             0.7475842275177915, -3.7896397646924274`}, {
             0.7472908539808808, -3.809825827699252}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.7469477260300661, -3.8334353274090196`}, {
             0.7452174979798147, -3.9524865983802595`}, {
             0.7348648468307711, -4.088309904717704}, {
             0.7185270091195459, -4.202423156992856}, {
             0.663701096198903, -4.417082191410127}, {
             0.6323731023213596, -4.50181405768096}, {
             0.600839232934277, -4.578968355112268}, {
             0.5656306811821208, -4.652778270750367}, {
             0.5303917377710093, -4.719389605495008}, {
             0.5195160841245922, -4.737992369736096}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.5075990354718152, -4.758376436178872}, {
             0.4598893907569399, -4.839983602194985}, {
             0.38923074319743384`, -4.937367963529788}, {
             0.3181719588067445, -5.014938702943627}, {
             0.13775969436845592`, -5.135326764471023}, \
{-0.051864283055370566`, -5.190498245065898}, {-0.1864787407088837, \
-5.2421827564130705`}, {-0.2399582488916416, -5.280621059871487}}]}, 
           {Arrowheads[{{0.010605489166900482`, 1.}}], 
            ArrowBox[{{-0.259131565963693, -5.294401848157748}, \
{-0.32455804807113825`, -5.341427018338229}, {-0.46303403326221226`, \
-5.481083845534178}, {-0.5782828745922479, -5.624383746949659}, \
{-0.6011158064592058, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7377417865524123, 0.7220566313605719}, {
             0.7791428672318457, 0.7099306569842153}, {0.8168647372390048, 
             0.6993357976492184}, {0.8521365718461129, 0.6900426519706305}, {
             0.971481101518034, 0.6665239195230683}, {1.0968481765401055`, 
             0.6590249288927182}, {1.2329571819980294`, 0.6708760912202973}, {
             1.4000174252838706`, 0.7066081565869435}, {1.5855762438718561`, 
             0.7634211322467392}, {1.6581230016406514`, 
             0.7890095834687503}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.6803904512873062`, 0.7968636842810556}, {
             1.7125331704341493`, 0.8082009573216101}, {1.824013072895032, 
             0.850003921841422}, {2.0136121110479848`, 0.9254122077343345}, {
             2.1734965665535193`, 0.991589330551866}, {2.2452320133570485`, 
             1.0218452484474685`}, {2.3127404853948343`, 1.050555814079393}, {
             2.3925714965274243`, 1.0847895984475004`}, {2.554250699250974, 
             1.1547745381496197`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.575919732992839, 1.1641542604285615`}, {
             2.6094571728270473`, 1.1786713762048793`}, {2.7952744456546426`, 
             1.2600794486714542`}, {2.9683024242435234`, 
             1.3365113028704172`}, {3.123132564679638, 1.4052599258957423`}, {
             3.263754397587608, 1.4679283729181092`}, {3.394056232511096, 
             1.5261284252877765`}, {3.4395526269493084`, 
             1.5464782364232414`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.4611067630321513`, 1.5561190575012644`}, {
             3.516419554400809, 1.5808595863195698`}, {3.73733065907891, 
             1.6799152343695338`}, {3.933442982812099, 1.768080454579001}, {
             4.111711796790565, 1.848340384458971}, {4.275222561517734, 
             1.9220439669399465`}, {4.322537883915768, 
             1.943388524886531}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.344061194124009, 1.953097970340108}, {
             4.427060737497031, 1.99054014495243}, {4.568589891501603, 
             2.054430494168953}, {4.70180303547924, 2.1145955363384634`}, {
             4.7153783743308475`, 2.120728212352018}, {4.852724010393441, 
             2.1827979020210644`}, {4.982944223580749, 2.2416643266098593`}, {
             5.110127244520513, 2.2991633031402414`}, {5.204774202683789, 
             2.341961684658806}}]}, 
           {Arrowheads[{{0.010008817205707062`, 1.}}], 
            ArrowBox[{{5.226288821344029, 2.3516903740484736`}, {
             5.231235880965186, 2.3539273835537986`}, {5.346896704910088, 
             2.4062370498501067`}, {5.457736288350538, 2.4563727840287415`}, {
             5.656854249492381, 2.546670583308755}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9574080016506445, -0.14383234850006715`}, {
             0.9614990717008919, -0.1418223255746379}, {
             0.9659228177260609, -0.13968836238071208`}, {
             0.9750710598235268, -0.13549386236003652`}, {
             0.9916779009668237, -0.1285540190339341}, {
             1.0179278563173308`, -0.11952737675729279`}, {
             1.0529454430705738`, -0.11032764683703675`}, {
             1.091883389873304, -0.10324070536769978`}, {
             1.2462965895973983`, -0.09166633756457919}, {
             1.387334981567625, -0.0918046738312349}, {
             1.5122437662617774`, -0.09487144245134924}, {
             1.6230160560843956`, -0.0987562800379525}, {
             1.8145479072791133`, -0.10660565823253235`}, {
             1.8945043320722759`, -0.11028420454234271`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9180913756988134`, -0.11136937102541382`}, {
             1.975516845963844, -0.11401133822541071`}, {
             2.1768902107514734`, -0.12392658037821176`}, {
             2.3478354558631858`, -0.13265969094627658`}, {
             2.562468185102925, -0.14389964782295955`}, {
             2.746628398389372, -0.15369797222577805`}, {
             2.8613232001160065`, -0.159865083460349}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.884901133613866, -0.16113286313626826`}, {
             2.9167028957932026`, -0.16284283605450728`}, {
             3.0690760612969514`, -0.1710882298719991}, {
             3.2075758639351157`, -0.17861594132325812`}, {
             3.3359678460555635`, -0.18561279329556005`}, {
             3.456567071931924, -0.19219560340641403`}, {
             3.6743872549523857`, -0.20411909804377823`}, {
             3.8279801236510447`, -0.21255157747812212`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.8515566115521644`, -0.21384596211358523`}, {
             3.8678368361239155`, -0.21473977092157834`}, {
             4.0437162385739285`, -0.22441096772604202`}, {
             4.205056036599704, -0.23329389665441763`}, {
             4.354886804498519, -0.24154976590395352`}, {
             4.4945505939740045`, -0.24925076122817025`}, {
             4.626009498910075, -0.25650259997671393`}, {
             4.648222549937939, -0.25772824480116235`}, {
             4.7839781298929145`, -0.26522132790942266`}, {
             4.794605855339066, -0.2658080641304485}}]}, 
           {Arrowheads[{{0.017786572007062747`, 1.}}], 
            ArrowBox[{{4.8181819465219755`, -0.2671096546464351}, {
             4.9126906470104075`, -0.2723272976933511}, {
             5.158104111085393, -0.2858779878950754}, {
             5.381970766885401, -0.29824168466976475`}, {
             5.588503796085841, -0.30964917493123667`}, {
             5.656854249492381, -0.3134722890345649}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.380934564425142, -0.8627039423859938}, \
{-1.4890437242436176`, -0.9530952684729477}, {-1.5822485424060024`, \
-1.0270763781945136`}, {-1.6650996769930442`, -1.0905467637802224`}, \
{-1.7401525433676779`, -1.1465663874229457`}, {-1.9311738487389034`, \
-1.2847425059779727`}, {-2.0901854209536714`, -1.396046693564311}, \
{-2.1369226122055878`, -1.42812467803232}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.1563903469036214`, -1.4414863216087348`}, \
{-2.2282241693793203`, -1.4907893323359513`}, {-2.3509828135482187`, \
-1.5739210547301352`}, {-2.462789169853962, -1.6490043468363473`}, \
{-2.565895880075799, -1.7178196078821104`}, {-2.750180937717878, \
-1.8397499943485272`}, {-2.922304416482257, -1.9526516535602023`}, \
{-2.942104509512184, -1.9655623674683746`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.9618832574880716`, -1.9784591632658772`}, \
{-3.0765567285857913`, -2.0532323663999215`}, {-3.2168573767160034`, \
-2.144308151766693}, {-3.3470134246309726`, -2.228548967502325}, \
{-3.46935795146565, -2.307574077632358}, {-3.5838909572200346`, \
-2.3813834821567927`}, {-3.690612441894127, -2.4499771810756283`}, \
{-3.755019874747741, -2.4912666112612123`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7748979525003903`, -2.5040097756325834`}, \
{-3.8874306847108224`, -2.5761507100610066`}, {-4.066622516625124, \
-2.690727912552995}, {-4.231215132664204, -2.7957320579772955`}, \
{-4.384235727855234, -2.893186415759611}, {-4.527025829306177, \
-2.983978977174563}, {-4.571136229449341, -3.0119911182930688`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.591068644094221, -3.0246491220756857`}, \
{-4.661547343058793, -3.069406350639394}, {-4.670018283986682, \
-3.0747823720777565`}, {-4.808391919610455, -3.162498441578303}, \
{-4.9396997738296005`, -3.24565252751198}, {-5.067989948728929, \
-3.3268633328372204`}, {-5.190244764988624, -3.4041875769455867`}, \
{-5.307081127083165, -3.4780265233473524`}, {-5.3890931702288976`, \
-3.5298207361287077`}}]}, 
           {Arrowheads[{{0.006216891016313439, 1.}}], 
            ArrowBox[{{-5.409057163386487, -3.5424288759811957`}, \
{-5.41911593948703, -3.548781435552791}, {-5.625579465688758, \
-3.67972201531985}, {-5.656854249492381, -3.6998742426777893`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.23433612828418035`, -1.3418699906693534`}, \
{-0.18027974308082914`, -1.3501857766581167`}, {-0.11730257404260044`, \
-1.3561527269863538`}, {-0.05385925314608411, -1.358914319099973}, {
             0.009883052998665418, -1.3586884527306329`}, {
             0.09379953703208199, -1.3568087757486327`}, {
             0.1775475466232978, -1.355435263590577}, {
             0.2595072909500629, -1.3557355479751205`}, {
             0.47486317073295387`, -1.3781093553776977`}, {
             0.6515830664354723, -1.4320042554471715`}, {
             0.6943004453650754, -1.4546623622188823`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7151597455279832, -1.4657265300615117`}, {
             0.7913800003622415, -1.5061551966950073`}, {
             0.9404257737009836, -1.6175847692871452`}, {
             1.0890999964598145`, -1.7581707855273072`}, {
             1.2413325783130236`, -1.9278268173466118`}, {
             1.3265504376538173`, -2.031930563248829}, {
             1.39126297696849, -2.11463220915813}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.405716972298293, -2.1333021879757172`}, {
             1.4932441832130539`, -2.249672172923467}, {
             1.5741389311019731`, -2.3605896850930166`}, {
             1.6728850654656469`, -2.499699503964574}, {
             1.7604866158758774`, -2.6257186084570865`}, {
             1.8697390054576513`, -2.7858110443488613`}, {
             1.9499476463669245`, -2.905037628005867}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.9631274990322944`, -2.9246288938418283`}, {
             1.9666906946538851`, -2.929925425936723}, {
             2.076403685451973, -3.095038657958631}, {
             2.1747430577451476`, -3.2443737938247788`}, {
             2.259041393498246, -3.3732564433975436`}, {
             2.3379966324493218`, -3.4943629010813915`}, {
             2.411608774598376, -3.607693166876323}, {
             2.4798778199454077`, -3.7132472407823367`}, {
             2.480760436434809, -3.7146171253210154`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.4935490575025256`, -3.7344659888784717`}, {
             2.6051977251996683`, -3.9077527849886926`}, {
             2.7187674531783674`, -4.084605505761537}, {
             2.8226676748526587`, -4.246838096679348}, {
             2.918979061193697, -4.397483251320603}, {
             3.0032988949539434`, -4.529572939096761}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0159984851855572`, -4.549478882760873}, {
             3.0928749287136714`, -4.670029274997276}, {
             3.095281799661124, -4.673805228705363}, {
             3.181891351595683, -4.809780279217173}, {
             3.263948299500148, -4.9386787857833765`}, {
             3.344071343243322, -5.064560778330087}, {
             3.4203265786639143`, -5.184409742837811}, {
             3.493118623422656, -5.298848462119131}, {
             3.5232296799381118`, -5.346196100338033}}]}, 
           {Arrowheads[{{0.007305445083763771, 1.}}], 
            ArrowBox[{{3.5359006114895393`, -5.366120299367234}, {
             3.5628520951802796`, -5.4084997189866275`}, {
             3.693169848743329, -5.612691199888563}, {
             3.7216236684047006`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.3756642855480248`, 
             0.861834995831614}, {-1.4832685440306175`, 
             0.9524498178174905}, {-1.5760267440468547`, 
             1.0265703085960824`}, {-1.6584783681475774`, 
             1.0901376645853627`}, {-1.7331690743949741`, 
             1.146229314183994}, {-1.9237887029330436`, 
             1.284916578882985}, {-2.0824069862621, 
             1.3965514015520024`}, {-2.130025837706551, 1.429406793828543}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.1494607077808103`, 
             1.4428161949536054`}, {-2.220076139006498, 
             1.491538447240675}, {-2.3424893562528917`, 
             1.5748636865577048`}, {-2.4539717629339344`, 
             1.6501106761922848`}, {-2.5567736320971903`, 
             1.7190689973218316`}, {-2.7404988192631725`, 
             1.8412356571866768`}, {-2.9122203819102506`, 
             1.954429419089662}, {-2.933975900408696, 1.9686846573251904`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.953725739456843, 
             1.9816256801173981`}, {-3.0660925652227164`, 
             2.055253705630884}, {-3.2060339531407624`, 
             2.1465390987131063`}, {-3.335848548213846, 
             2.230967371110706}, {-3.457867181465621, 
             2.3101645786154785`}, {-3.5720898528960885`, 
             2.3841307212274234`}, {-3.678516562505248, 
             2.4528657989465414`}, {-3.745738280996502, 2.496167455011141}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.765588393639632, 
             2.5089541371996993`}, {-3.8747815063605597`, 
             2.5792921576756247`}, {-4.0534614231324735`, 
             2.6940930527720575`}, {-4.21757748343784, 
             2.7992976725182164`}, {-4.3701508578935115`, 
             2.8969352051964794`}, {-4.512520107320386, 
             2.9878960012701583`}, {-4.560726128252621, 3.018656411520046}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.580630959851262, 
             3.03135774579507}, {-4.646642709917757, 
             3.0734800465801295`}, {-4.655112350437382, 
             3.078881114824699}, {-4.793082509043192, 
             3.1667623389208295`}, {-4.924005449972188, 
             3.250071682671293}, {-5.051918763168824, 
             3.331433621367474}, {-5.1738128209007375`, 
             3.4089007499550896`}, {-5.290303026767574, 
             3.4828752833576866`}, {-5.377563900587611, 
             3.5382496416122797`}}]}, 
           {Arrowheads[{{0.006516457238572831, 1.}}], 
            ArrowBox[{{-5.397500483611913, 
             3.550901079105754}, {-5.4020047843689785`, 
             3.5537594364988117`}, {-5.6085787609937725`, 
             3.68530940774479}, {-5.656854249492381, 3.7165348416697173`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.351495842567167, -0.23906262138950096`}, \
{-1.4092479230963038`, -0.2539095185007498}, {-1.5349048467079054`, \
-0.28495170380931095`}, {-1.6402486565572334`, -0.3098170353076976}, \
{-1.7322166414406917`, -0.33083742948761524`}, {-1.8144804543537116`, \
-0.34919108350624267`}, {-2.0131389624031226`, -0.3922362931427493}, \
{-2.177064968964605, -0.426666618276604}, {-2.272832660592777, \
-0.44639852812267394`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.2959588762147027`, -0.4511634378116778}, \
{-2.3186519510761565`, -0.45583910347390194`}, {-2.4441502480186212`, \
-0.4813546881124587}, {-2.663271408293881, -0.5254028755014819}, \
{-2.850650594700263, -0.5626219299264887}, {-3.027905425514242, \
-0.5975239456847738}, {-3.1863168087537717`, -0.6285298071878743}, \
{-3.22226471755215, -0.6355347380801241}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-3.2454407922492994`, -0.6400509062532911}, \
{-3.3301068128280296`, -0.6565492129114673}, {-3.46332364250272, \
-0.6824333492690335}, {-3.588435134674019, -0.7066955982908006}, \
{-3.8143421065064467`, -0.7503544343269374}, {-4.014957233346872, \
-0.7889794405340329}, {-4.172756796195173, -0.8192890310134356}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.195944919072548, -0.823742924900803}, \
{-4.1974100202168545`, -0.8240243364262427}, {-4.36484194618781, \
-0.8561180525513187}, {-4.520394490331155, -0.8858895194570124}, \
{-4.665453550439169, -0.9136134904181529}, {-4.802044440283701, \
-0.9396908448793241}, {-4.819418188073284, -0.9430058759016249}, \
{-4.960262678146965, -0.9698531556383725}, {-5.093854736611667, \
-0.995297104814646}, {-5.123647711218194, -1.0009696524574234`}}]}, 
           {Arrowheads[{{0.01099335560305422, 1.}}], 
            ArrowBox[{{-5.1468430123101685`, -1.0053860107523072`}, \
{-5.224353285270215, -1.020143876389336}, {-5.348664814316456, \
-1.0437962927608595`}, {-5.581269068499287, -1.0880133129348584`}, \
{-5.656854249492381, -1.1023670830693963`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.4033019032422815`, 
             0.2604315918906208}, {-1.528700062156474, 
             0.2924405459625018}, {-1.6337726421299548`, 
             0.318054817401884}, {-1.7254788971442545`, 
             0.3396946762520501}, {-1.8074949906065576`, 
             0.35858080782542434`}, {-2.0057275290157572`, 
             0.4028975115839433}, {-2.1692527061921085`, 
             0.4383197247640463}, {-2.31047120144203, 
             0.4683202477149935}, {-2.3238898812791606`, 
             0.4711327041042291}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.346999732523977, 
             0.4759763585901137}, {-2.435630166409931, 
             0.4945526442671538}, {-2.6541414531776324`, 
             0.539827360562927}, {-2.8409848550523598`, 
             0.5780730733941528}, {-3.0178362927781026`, 
             0.6139538125940691}, {-3.1758716717049604`, 
             0.6458226514400661}, {-3.2723295885893005`, 
             0.6651862704897593}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.295479721913001, 
             0.6698335858901868}, {-3.319310124938282, 
             0.6746174632626942}, {-3.4521951841667984`, 
             0.7012151569497025}, {-3.5769915802503935`, 
             0.7261445084065813}, {-3.8023183829828198`, 
             0.7709981846299505}, {-4.002407729879338, 
             0.8106747300596197}, {-4.1843768176837255`, 
             0.8466703828224066}, {-4.221817423300452, 0.8540609594811224}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.2449824207891, 
             0.8586336069294939}, {-4.351360665011211, 
             0.8796321072419959}, {-4.506494290477023, 
             0.9102068676420721}, {-4.651160508197952, 
             0.9386772089892506}, {-4.787380041051101, 
             0.9654553529533857}, {-4.804749422458412, 
             0.9688678251185318}, {-4.945216529844331, 
             0.9964361228729195}, {-5.078449486000987, 
             1.0225623614850283`}, {-5.171718881740598, 
             1.0408458552064592`}}]}, 
           {Arrowheads[{{0.009968018578727788, 1.}}], 
            ArrowBox[{{-5.194889871962359, 
             1.0453880381044982`}, {-5.208596804353151, 
             1.0480749924941972`}, {-5.332572847096333, 
             1.0723604082974865`}, {-5.564547283599575, 
             1.1177586633973249`}, {-5.656854249492381, 
             1.1358050590197684`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.2564122295613082, 
             1.8964447047254878`}, {-0.19770240494332963`, 
             1.9195445923993437`}, {-0.14113369029071463`, 
             1.9360049241823862`}, {-0.06888344248782427, 
             1.9484647783866857`}, {0.0027224216737482265`, 
             1.9513422399296212`}, {0.07507873369252852, 
             1.9521773377311518`}, {0.17849115576612318`, 
             1.962190064125364}, {0.2764259068116088, 1.9819408620633752`}, {
             0.3671302888193074, 2.014963277340989}, {0.43634196868755365`, 
             2.055620542220578}, {0.500115316261819, 2.1075501341284593`}, {
             0.5574104994945013, 2.1668964781281908`}, {0.5920064428888744, 
             2.215671669189555}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.605666899879589, 2.2349309040689835`}, {
             0.6912318960649377, 2.3555649619274566`}, {0.7844835987576875, 
             2.543971658344826}, {0.8696248202744874, 2.763955294428383}, {
             0.9133861341822768, 2.8970944142583304`}, {0.9500299106455214, 
             3.019597211371002}, {0.971740831015317, 
             3.0991501164988193`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{0.9779574679579651, 3.1219290462028124`}, {
             0.9928584916165253, 3.1765292059945622`}, {1.028510158425119, 
             3.3185137995512473`}, {1.0680221731149784`, 
             3.4891207143914795`}, {1.101101178030852, 3.642433912430693}, {
             1.126649423806716, 3.76799104439883}, {1.149806194400043, 
             3.8855445380954787`}, {1.1792633183291472`, 
             4.044420973328438}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1835678328508756`, 4.0676372901781965`}, {
             1.1889453100390874`, 4.096640610674314}, {1.2209802996081371`, 
             4.28250967538175}, {1.2483729377673447`, 4.44993927743234}, {
             1.2720723269025684`, 4.60210051902872}, {1.2930275693996662`, 
             4.742164502373524}, {1.311620128910338, 4.871553561167382}, {
             1.3285522420700153`, 4.993478083920983}, {1.3295049853978946`, 
             5.000701119567329}}]}, 
           {Arrowheads[{{0.013500943718596873`, 1.}}], 
            ArrowBox[{{1.332592743378258, 5.02411034774749}, {
             1.3450534011918207`, 5.118578367549443}, {1.360057651096527, 
             5.2361090491684426`}, {1.3876272617759475`, 5.458364395885112}, {
             1.4108074863733624`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.2873655593156164`, -0.6827580280874915}, \
{-2.4655486266927493`, -0.7378903319511422}, {-2.6207872577066507`, \
-0.7853353193158193}, {-2.759160112375748, -0.8272638007582924}, \
{-2.8853515410870854`, -0.8652929885698364}, {-3.0018195237539844`, \
-0.9002492409157234}, {-3.191217373924785, -0.9567699875430883}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.213845034777535, -0.9635164678359693}, \
{-3.4020405334024124`, -1.0193600644939127`}, {-3.5742956446442813`, \
-1.07027523991581}, {-3.731199243295858, -1.1165169442682545`}, \
{-3.87689072234875, -1.1593709460159813`}, {-4.01391003463254, \
-1.19962066322824}, {-4.119754576703698, -1.230665869311842}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.142412080021629, -1.2373114509951497`}, \
{-4.261932158892811, -1.2723072440463534`}, {-4.482767045221335, \
-1.3368590940518192`}, {-4.683916122762777, -1.3955586205738622`}, \
{-4.868741816580536, -1.4494163575852543`}, {-5.040606551738011, \
-1.4994428390587684`}, {-5.049072007458596, -1.5019044656159246`}}]}, 
           {Arrowheads[{{0.012901956373993379`, 1.}}], 
            ArrowBox[{{-5.071744887248196, -1.50849739632863}, \
{-5.20100598583581, -1.5460845698480352`}, {-5.352129002083995, \
-1.589994296380223}, {-5.364648665441669, -1.5936304992019337`}, \
{-5.52008144917474, -1.6387417248336282`}, {-5.656854249492381, \
-1.678413054962523}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0547172706274024`, -1.249877195329963}, \
{-1.0747471440761875`, -1.2975769236422217`}, {-1.1482988958997613`, \
-1.4559138973901975`}, {-1.2166667062752579`, -1.5844735038226285`}, \
{-1.2784490235442783`, -1.6917370641406964`}, {-1.3351306830884873`, \
-1.785014566104229}, {-1.387684627992853, -1.8681972472908426`}, \
{-1.5208365179919012`, -2.069342798230908}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.534216920660513, -2.0887964627978577`}, \
{-1.6403453182723235`, -2.2415711991306075`}, {-1.7438368960635495`, \
-2.386266383318301}, {-1.8372284541650383`, -2.514236542773311}, \
{-1.9231083403258395`, -2.6304231574492607`}, {-2.00288838289019, \
-2.7373396031447816`}, {-2.089893623523259, -2.8524048459774165`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.1041347004372315`, -2.8712388031204727`}, \
{-2.1469585788712897`, -2.927873782061928}, {-2.2863166200831047`, \
-3.1097293711496863`}, {-2.4118781020900766`, -3.2720382398712786`}, \
{-2.526567807638554, -3.419236105980433}, {-2.6332775242305497`, \
-3.555539867303174}, {-2.682352579308827, -3.6180198016601284`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.696937578020537, -3.636588701086739}, \
{-2.7337941068054445`, -3.6835126117259245`}, {-2.8281175553632387`, \
-3.8031543392486835`}, {-2.9162478699039327`, -3.9144650498714526`}, \
{-2.9995112009092577`, -4.019284241658153}, {-3.0792336988609468`, \
-4.1194514126727055`}, {-3.2280561956034153`, -4.30582969238537}, \
{-3.2844011767011296`, -4.376129986636216}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2991682047379762`, -4.39455445667731}, \
{-3.36510862050378, -4.476826746791668}, {-3.492784233934481, \
-4.63566943367382}, {-3.612153307113508, -4.783778451319312}, \
{-3.7247833214708175`, -4.923229361587496}, {-3.727579908388238, \
-4.92668831439919}, {-3.8435898407481957`, -5.069896503014793}, \
{-3.8921216360833477`, -5.12970420101679}}]}, 
           {Arrowheads[{{0.01388778047061653, 1.}}], 
            ArrowBox[{{-3.9069997404414814`, -5.14803909190942}, \
{-3.9538134373836225`, -5.205729507640747}, {-4.061558047303952, \
-5.338416879083655}, {-4.164344683794083, -5.464812984160474}, \
{-4.262674108181513, -5.585564080397296}, {-4.3207970365014665`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.182198094998513, 
             1.4926740273397254`}, {-1.2557778834893345`, 
             1.6228514351092924`}, {-1.3220857018445975`, 
             1.7319175162251779`}, {-1.382790809954228, 
             1.8270011216110302`}, {-1.438982015137025, 
             1.9119395839183433`}, {-1.5136514646342178`, 
             2.021562837170338}, {-1.5821951335833881`, 
             2.119425564580946}, {-1.6994939879530935`, 
             2.2820777039992137`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.7134471633855368`, 
             2.301125360357944}, {-1.8141588141651543`, 
             2.437097400119233}, {-1.912416725892245, 
             2.5673235879899794`}, {-2.002742187863187, 
             2.6856347481920544`}, {-2.0866305193564876`, 
             2.7945519391419404`}, {-2.164823774747247, 
             2.8952145809404928`}, {-2.2380640084105634`, 
             2.988762093688564}, {-2.287349149190963, 3.0511876383310814`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.301980517922732, 
             3.0697200224834553`}, {-2.3837711584356005`, 
             3.173317682951268}, {-2.515073051467237, 
             3.3381639343940193`}, {-2.6350184151045184`, 
             3.4877438734673}, {-2.746624977920439, 
             3.626299164560289}, {-2.8517575211704993`, 
             3.7564110697869024`}, {-2.892580107875845, 
             3.8067546538526122`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.907451748789617, 
             3.825094787708939}, {-2.9504160448546988`, 
             3.8780795891471405`}, {-3.042600548973037, 
             3.9913047226410017`}, {-3.1296962651499864`, 
             4.097945965564161}, {-3.2130884250100187`, 
             4.1998628132122935`}, {-3.368762075779331, 
             4.389523322683472}, {-3.505789317474405, 4.55586783029011}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.520816344050967, 
             4.574080859593473}, {-3.6456754224686216`, 
             4.725236373367941}, {-3.7705366013526516`, 
             4.876002149726833}, {-3.888346654717596, 
             5.017961984183251}, {-3.8911110090978687`, 
             5.021289659270264}, {-4.012293087104784, 
             5.166892599969159}, {-4.123986085281584, 5.300872349558228}}]}, 
           {Arrowheads[{{0.00932273917621017, 1.}}], 
            ArrowBox[{{-4.139110132865881, 
             5.319004900056035}, {-4.239988948998055, 
             5.439932415737793}, {-4.347366901603971, 
             5.5684675494848515`}, {-4.421393405738284, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1913856447714477`, 1.2813602100042336`}, {
             1.3566508682444267`, 1.3943921064130873`}, {1.4893899486114872`, 
             1.4979961045601486`}, {1.6017234837507386`, 
             1.5919785043199242`}, {1.6120714184051081`, 
             1.6008771785426474`}, {1.6222872376852888`, 
             1.6096922488850212`}, {1.6323749292600145`, 
             1.6184253627751317`}, {1.6373872059956038`, 
             1.6227716282963824`}, {1.6423686212513062`, 
             1.6270978703496293`}, {1.6473196044842178`, 1.63140427831086}, {
             1.652240591954818, 1.6356910466339716`}, {1.6571320367048628`, 
             1.6399583745526023`}, {1.8370876292625726`, 
             1.7998662150009266`}, {1.9220610266673694`, 
             1.8779132369909446`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.9394509223501608`, 1.8938856426168293`}, {
             1.9867449594096944`, 1.9373246348557553`}, {2.0927091911432583`, 
             2.036768082866027}, {2.1886031720822894`, 2.1277818614172084`}, {
             2.357823920580242, 2.2903073344271343`}, {2.5050107769722865`, 
             2.4332212763425214`}, {2.6214913727031806`, 
             2.547179357459154}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.6383636202759213`, 2.563697622484074}, {
             2.755124351552974, 2.678479797425383}, {2.864928243614594, 
             2.786810855328254}, {2.96647601137811, 2.8873453490428833`}, {
             3.0608893288170105`, 2.981117766375944}, {3.154302613145364, 
             3.0741138755887842`}, {3.242091940935157, 3.161696081631959}, {
             3.3090662001518534`, 3.2286734255469276`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.325762016025945, 3.245370010396369}, {
             3.4042570875843423`, 3.323868697278242}, {3.551556027207469, 
             3.4715672251267633`}, {3.6880530090949577`, 3.608678599103913}, {
             3.8162347946082886`, 3.737595576125806}, {3.9361013837474617`, 
             3.858318156192442}, {3.992058349242043, 
             3.9147651041278704`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.008681610887223, 3.931533925959235}, {
             4.047652776512477, 3.9708463393038205`}, {4.152707922497831, 
             4.076952145110106}, {4.253085771298024, 4.17840759326146}, {
             4.348786322913053, 4.275212683757886}, {4.439809577342919, 
             4.36736741659938}, {4.61105618132631, 4.540908215085823}, {
             4.67257243498669, 4.60331539846927}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.689148172054043, 4.6201311991938905`}, {
             4.770057569927343, 4.702212394489035}, {4.918242934292774, 
             4.852695523570517}, {5.0577016270616, 4.994428978149399}, {
             5.061000618556331, 4.997783078209733}, {5.204147331818621, 
             5.143426381356749}, {5.339800895112394, 5.281551991411141}, {
             5.351465783862157, 5.293463891225313}}]}, 
           {Arrowheads[{{0.008764647997919829, 1.}}], 
            ArrowBox[{{5.367986153572201, 5.31033408974162}, {
             5.471078987080776, 5.415609976263745}, {5.593606136398375, 
             5.541532710712773}, {5.656854249492381, 5.606761367306855}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.015587740378043273`, 1.}}], 
            ArrowBox[{{5.081030263970508, -4.006063036653453}, {
             5.227722815582235, -4.122874365409062}, {
             5.366836224555457, -4.2336520084192975`}, {
             5.5027181703460615`, -4.341855160019654}, {
             5.632137189771431, -4.444909328800251}, {
             5.656854249492381, -4.46463946764533}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8381344347719343, -2.8328436803445234`}, {
             0.8799730328430183, -2.968710881210758}, {
             0.9147893581453885, -3.093697911256442}, {
             0.9549333287879515, -3.2527524903239433`}, {
             0.9880735720454253, -3.3965704582681755`}, {
             1.0250118032017066`, -3.5720245416269796`}, {
             1.0554947385502491`, -3.729231713214145}, {
             1.0592547833269352`, -3.7504066542339185`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.0633829977990727`, -3.773654967261065}, {
             1.0978918379149634`, -3.967993784353229}, {
             1.1314311894659086`, -4.175449252362544}, {
             1.158365049994553, -4.358112748736285}, {
             1.1809456762923651`, -4.522498904968647}, {
             1.200054241511825, -4.6717029047588525`}, {
             1.2043551226240625`, -4.707405505149449}}]}, 
           {Arrowheads[{{0.019699509189052083`, 1.}}], 
            ArrowBox[{{1.207179103339932, -4.730848016667044}, {
             1.2165719188054123`, -4.808819931806121}, {
             1.2308545302770777`, -4.935249681674049}, {
             1.2435150877361283`, -5.054021645753877}, {
             1.255326898233333, -5.175819371093551}, {
             1.2656943504448694`, -5.289926029317741}, {
             1.2840753857989051`, -5.505105624520208}, {
             1.2953366837447067`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5703122133010207, -2.41536402539682}, \
{-0.5765971733482436, -2.496383288338426}, {-0.5855174669352856, \
-2.5699268561315303`}, {-0.6079344947245131, -2.703698608462283}, \
{-0.6349452515035303, -2.8237118043715976`}, {-0.6654223025425882, \
-2.9332204723997455`}, {-0.6987376801655513, -3.0391778332274586`}, \
{-0.7425363571038519, -3.1608944267897146`}, {-0.7870590530344893, \
-3.27753683480821}, {-0.8057281629815779, -3.325568475800162}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.8142823164701494, -3.3475764896003697`}, \
{-0.8334628611872827, -3.3969239432548}, {-0.8797194630750766, \
-3.5115583636098204`}, {-0.970695120341299, -3.728618579568227}, \
{-1.058432995983344, -3.931878426844642}, {-1.1362480123889505`, \
-4.109631953552481}, {-1.1835325753755848`, -4.216802832081819}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.1930638807458775`, -4.238405619662925}, \
{-1.210644978489316, -4.278253332566755}, {-1.2817487372441732`, \
-4.4386177453735165`}, {-1.3496841316132546`, -4.5916003734588156`}, \
{-1.414618379963331, -4.737735119989085}, {-1.4768524753545897`, \
-4.877983010663905}, {-1.5355783671474268`, -5.0103827356806185`}, \
{-1.5760621134139792`, -5.101744501327928}}]}, 
           {Arrowheads[{{0.0123443504768928, 1.}}], 
            ArrowBox[{{-1.5856278761492213`, -5.123332053218524}, \
{-1.5919291650964686`, -5.137552498141875}, {-1.646139045105012, \
-5.260137574953486}, {-1.698442183076353, -5.3787832430212665`}, \
{-1.7489768103451204`, -5.4937410846317976`}, {-1.7978263327781328`, \
-5.605037713717811}, {-1.8205398403196178`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3208975897378027, 1.4134699611503077`}, {
             0.5286777756604678, 1.4524625350313642`}, {0.6952490888271599, 
             1.5237330681120964`}, {0.825735099352041, 1.6120105696769889`}, {
             0.9660737996177029, 1.7384017347473546`}, {1.1047963314314693`, 
             1.8899979908493632`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1203756498864597`, 1.9077295136636958`}, {
             1.1964745777250505`, 2.0008789640439315`}, {1.2684013052744596`, 
             2.093974529564265}, {1.3545997111958812`, 2.211121800007156}, {
             1.4308140679091794`, 2.3187322651156705`}, {1.523479332787702, 
             2.454033751853234}, {1.6055532160147918`, 2.5770351836198504`}, {
             1.669672618779941, 2.675357417241515}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.6825705544730938`, 2.6951354218979877`}, {
             1.7059076669600146`, 2.7309211112063925`}, {1.79497258800418, 
             2.869931099254532}, {1.906043180478705, 3.04600991972233}, {
             2.004663637057168, 3.2042440339751455`}, {2.117030675500784, 
             3.386418601694993}, {2.183852665223012, 
             3.4955747722273633`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.196180642189219, 3.5157129746609677`}, {
             2.2177465215879617`, 3.550941629466297}, {2.3020841220944592`, 
             3.6894899612612946`}, {2.381173553798049, 3.8197590431763966`}, {
             2.4550148166987316`, 3.941748875211604}, {2.523607910796506, 
             4.055459457366917}, {2.6497199570683247`, 4.26516244916148}, {
             2.684944421505604, 4.323887835437036}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6970899617029187`, 4.344136590130883}, {
             2.764180057098499, 4.455987595683707}, {2.8690318266103008`, 
             4.631161065872859}, {2.966318881327004, 4.793909028668195}, {
             3.0569366246763927`, 4.945670214306186}, {3.144010262358555, 
             5.091598735597568}, {3.1816999957401686`, 
             5.154811913637018}}]}, 
           {Arrowheads[{{0.011882253749396545`, 1.}}], 
            ArrowBox[{{3.1937920327879965`, 5.175092664445854}, {
             3.231587549158173, 5.238483261593629}, {3.314609479037979, 
             5.3777712690411725`}, {3.3953837829865776`, 5.513115798467874}, {
             3.4716628350727614`, 5.640573371852893}, {3.481488608977621, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.76618615138471, 
             1.9715471922292318`}, {-0.7803356810900349, 
             2.0846670534455454`}, {-0.8139058602123258, 
             2.2661070269242325`}, {-0.8499946409506848, 
             2.414113688841082}, {-0.8868011439786787, 
             2.5417537368687415`}, {-0.9594614339895686, 
             2.7624906106366205`}, {-1.0043547581953427`, 
             2.882772687769797}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.01261121657606, 
             2.9048941051824233`}, {-1.029862603257347, 
             2.9511155124888115`}, {-1.1053114807891522`, 
             3.136599612880589}, {-1.177451977341823, 
             3.304009974583691}, {-1.24640287503201, 
             3.457662550794645}, {-1.3125170008301748`, 
             3.6013543677576143`}, {-1.3760847674427126`, 
             3.7373473486217095`}, {-1.3915076341806898`, 
             3.7697730756150882`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-1.4016495968718892`, 
             3.791095993007098}, {-1.4371061748696234`, 
             3.86564149338693}, {-1.4955812231109076`, 
             3.9862368020532775`}, {-1.5518736121335763`, 
             4.10073779993679}, {-1.6063470419046406`, 
             4.21074901235351}, {-1.7098370236919573`, 
             4.41730208078657}, {-1.8069661260626284`, 
             4.608761668585675}, {-1.8214667425805784`, 4.637108974230654}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.8322198729873946`, 
             4.658130306248158}, {-1.8986493066064243`, 
             4.787993436984045}, {-1.9853752480203957`, 
             4.956304890878537}, {-2.0689468506218702`, 
             5.117675092799134}, {-2.1610478669391466`, 
             5.294369586250792}, {-2.2487310529659266`, 
             5.4620315863927384`}, {-2.2668754209117483`, 
             5.496645240165566}}]}, 
           {Arrowheads[{{0.0033324491839753223`, 1.}}], 
            ArrowBox[{{-2.277837906303714, 
             5.51755815788087}, {-2.309074313031267, 
             5.57714723647557}, {-2.351066129681145, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2768281476485972`, -1.117377343264321}, {
             1.448321535160817, -1.21280286886001}, {
             1.6365391992694893`, -1.332294054288529}, {
             1.7454533030080885`, -1.4062885579127231`}, {
             1.8425174009557261`, -1.4743013676626573`}, {
             1.9617091207730786`, -1.5600541416083735`}, {
             2.0651176886980895`, -1.6359211439213996`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0840597787079673`, -1.650017905805161}, {
             2.19874675340476, -1.735590913558609}, {
             2.3154994492435, -1.823808446768985}, {
             2.4590495495132365`, -1.9334646190680618`}, {
             2.5874518363820362`, -2.032356853004707}, {
             2.745448421741114, -2.1549128802002206`}, {
             2.834069036360472, -2.2240251400236617`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.852688351516235, -2.2385457225349294`}, {
             2.88692841892491, -2.2652484084199758`}, {
             3.0604953857533865`, -2.401241109128131}, {
             3.216125205580841, -2.5236078262137656`}, {
             3.3158083938317584`, -2.6021850137776754`}, {
             3.4104560177648575`, -2.6768692220621637`}, {
             3.584644572677601, -2.8145587007928743`}, {
             3.5948779997039804`, -2.822663287746343}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.6133881340417164`, -2.8373227945639385`}, {
             3.773512686074599, -2.9641369450914676`}, {
             3.9449860556317367`, -3.1001144944350423`}, {
             4.102103664144509, -3.2248379142206955`}, {
             4.247904494408412, -3.340653769845526}, {
             4.3532532453365125`, -3.424384319920437}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.371737963426816, -3.4390758620606676`}, {
             4.383722526066302, -3.448601119962361}, {
             4.511505286959893, -3.5501990124714395`}, {
             4.518421699220759, -3.55569905012103}, {
             4.6501583670521205`, -3.6604850767473636`}, {
             4.775016495356103, -3.7598179274519277`}, {
             4.896946540840706, -3.856826317776934}, {
             5.013020420686553, -3.9491857873428255`}, {
             5.1108747342346375`, -4.02705439576573}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.47658843707435977`, 3.7442999968762516`}, {
             0.4349807812871389, 3.850844700894977}, {0.34691033886511075`, 
             4.02071372852859}, {0.25386795783544014`, 4.140139733159898}, {
             0.15628204340269333`, 4.215120608858319}, {0.054219943136452835`,
              4.252872497561709}, {-0.05310383995563706, 
             4.275845816888978}, {-0.08783339825080623, 
             4.286268991308964}, {-0.12337092152598392`, 
             4.3012551823607765`}, {-0.15931736647880143`, 
             4.32263630159749}, {-0.18310732458236323`, 4.339344562667598}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.20181813692142603`, 
             4.353685286600192}, {-0.34813361887019784`, 
             4.484746075655298}, {-0.5011596739093418, 
             4.6730367092240535`}, {-0.5764424606534853, 
             4.781100022005029}, {-0.6500002909427528, 
             4.8944333474311295`}, {-0.7698439778265048, 
             5.096800816987903}, {-0.7714821073719718, 
             5.0997939367787435`}}]}, 
           {Arrowheads[{{0.01282807093548144, 1.}}], 
            ArrowBox[{{-0.7828181825655546, 
             5.120506725401756}, {-0.8879711586841675, 
             5.312637716969141}, {-0.9467592886558913, 
             5.424667324303864}, {-1.006014081512516, 
             5.5405027672754175`}, {-1.0643125321366202`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4549957395257866`, -0.7165054110917979}, {
             1.6488659820319402`, -0.7790671755103941}, {
             1.8615207961989348`, -0.8578461236123415}, {
             1.984323354042437, -0.9062704895811947}, {
             2.094024025936002, -0.9506843077766463}, {
             2.2284459809663577`, -1.0063267271058907`}, {
             2.3373558029713535`, -1.0521274266571121`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.3590999899742067`, -1.0613314079150236`}, {
             2.4961870072570154`, -1.1197657668792573`}, {
             2.6282583552852716`, -1.176620492297739}, {
             2.790120878423002, -1.2468953025711143`}, {
             2.9351991925859555`, -1.31028165560444}, {
             3.115754531153708, -1.389602115383334}, {
             3.2252516398667086`, -1.437905132204917}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.246855002721659, -1.4474351336054156`}, {
             3.2775402731693863`, -1.4609714831221532`}, {
             3.4601575628453594`, -1.5418160207763851`}, {
             3.6251773477618214`, -1.6150559496467158`}, {
             3.766854373526464, -1.678055057474299}, {
             3.9000303915878543`, -1.7373277102387024`}, {
             4.024705401945993, -1.7928739079399258`}, {
             4.1099812321872555`, -1.8309114333359908`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.131545252500935, -1.8405301256196331`}, {
             4.140879404600879, -1.8446936505779699`}, {
             4.355095747130243, -1.9403457466123524`}, {
             4.5500507795052965`, -2.0274759742896844`}, {
             4.729046926433096, -2.107532237108868}, {
             4.895386612620698, -2.181962438568806}, {
             4.993780255163487, -2.226007284478782}}]}, 
           {Arrowheads[{{0.014887867714184207`, 1.}}], 
            ArrowBox[{{5.015331537924217, -2.235654482243067}, {
             5.0505368790274225`, -2.2514137709941116`}, {
             5.19664402265668, -2.316834009612603}, {
             5.207839143763107, -2.3218472911666144`}, {
             5.35821407116389, -2.3891991193795628`}, {
             5.500850234158509, -2.4530931380594696`}, {
             5.638338959907776, -2.514916846363943}, {
             5.656854249492381, -2.523313628595327}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3792768292055182`, 0.9161143465480653}, {
             1.5628112484088705`, 0.9952744208591109}, {1.7589579142061071`, 
             1.0916914808789187`}, {1.8952524732194107`, 
             1.1630767141161473`}, {2.0149302924069494`, 
             1.2277304244561422`}, {2.2185433581831004`, 
             1.3412253108197918`}, {2.221191432613183, 
             1.342734964339055}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2417041585816015`, 1.354429163186378}, {
             2.3903938012699784`, 1.4391963584783354`}, {2.467553637021458, 
             1.48367101876018}, {2.5401986298724526`, 1.5257505857035725`}, {
             2.626051809558107, 1.5757284580322657`}, {2.7473912812979857`, 
             1.6466342245486738`}, {2.859331085428663, 1.7123006690164022`}, {
             3.0580087741274737`, 1.8294711216929744`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0783228954741397`, 1.8415070058984453`}, {
             3.244314060350671, 1.9398902994620932`}, {3.4100185964545617`, 
             2.0384090893202407`}, {3.5607391387414364`, 2.128213332721942}, {
             3.7005405514360854`, 2.2116199646836217`}, {3.8319156453339085`, 
             2.290060882214928}, {3.8898524534695014`, 
             2.324684397099771}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.9101209259590775`, 2.3367970036019012`}, {
             3.9548644204349053`, 2.363536085315862}, {4.069386876739076, 
             2.4320455739864215`}, {4.280487517563924, 2.5584403926136794`}, {
             4.472552252415443, 2.6735183226739583`}, {4.648854376473319, 
             2.7792091758065736`}, {4.720380965344958, 
             2.822101508328472}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.740631032003761, 2.83424486098127}, {
             4.8126671849172435`, 2.8774427636508397`}, {4.965441960411542, 
             2.9690797281717827`}, {5.1093012225467875`, 
             3.0553799331755216`}, {5.117740446576493, 3.0604428235014014`}, {
             5.265775593508952, 3.1492572769497342`}, {5.406185193131988, 
             3.2334977436793544`}, {5.542108727482918, 3.3151530049498485`}, {
             5.550497021415763, 3.3202067293430115`}}]}, 
           {Arrowheads[{{0.0021293487618458382`, 1.}}], 
            ArrowBox[{{5.570722034852542, 3.3323917629834368`}, {
             5.656854249492381, 3.3842841355740165`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5055690643638617`, -1.896194381337736}, {
             1.6050858214415746`, -2.005181531048746}, {
             1.6935131460004613`, -2.1045801524885897`}, {
             1.802040291638989, -2.2293814044732687`}, {
             1.8986235440154067`, -2.342400697309395}, {
             2.017479100783272, -2.4836234606299095`}, {
             2.12313602823846, -2.610639676297087}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1381460980459766`, -2.6288666827817213`}, {
             2.2536253288283787`, -2.7691214177292123`}, {
             2.369873723202722, -2.911419563401424}, {
             2.5150872246410962`, -3.0904000954352893`}, {
             2.644732304956331, -3.251036887548411}, {
             2.7337631409369196`, -3.3618520401699734`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.748551761986927, -3.380259182826438}, {
             2.7917459723883575`, -3.434022274740413}, {
             2.924179363584514, -3.599399787276045}, {
             3.0365371278469753`, -3.740049461541914}, {
             3.1420758014557384`, -3.8723128463416696`}, {
             3.2407953844108035`, -3.9961899416753117`}, {
             3.332695876712171, -4.11168074754284}, {
             3.3379367618930007`, -4.118273876605238}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.35262951714384, -4.13675763045761}, {
             3.4192695534168656`, -4.2205920104738}, {
             3.502008689581912, -4.324730476997738}, {
             3.5809132852073104`, -4.424096147114653}, {
             3.6559833402930604`, -4.518689020824547}, {
             3.7972700841411804`, -4.696816280469812}, {
             3.928519176421836, -4.862372157380081}, {
             3.9397653359560634`, -4.876563878186719}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9544302233076496`, -4.895069750019774}, {
             4.0509021056955214`, -5.01680926619617}, {
             4.1661313623035365`, -5.162253778334397}, {
             4.168712709816774, -5.165512327106836}, {
             4.287084704428617, -5.314957972019837}, {
             4.399360020969486, -5.456716032752368}, {
             4.50791759336839, -5.5935504858621465`}, {
             4.541112293528379, -5.635235774708222}}]}, 
           {Arrowheads[{{0.00008520019627367797, 1.}}], 
            ArrowBox[{{4.555821069278012, -5.6537067825118905`}, {
             4.5583274504396405`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6824316691353833`, -1.3724459844175874`}, \
{-1.8611892607184384`, -1.531320221094203}, {-1.9702966872307837`, \
-1.6252548479280946`}, {-2.068799117217712, -1.708668444920146}, \
{-2.1942071090585897`, -1.8132872644264024`}, {-2.3071760988929935`, \
-1.9063904657109692`}, {-2.4021805854762164`, -1.9838324555212354`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.4204825106719574`, -1.9987510931086852`}, \
{-2.449926636677927, -2.0227521880899104`}, {-2.5783333695207786`, \
-2.1264959585946555`}, {-2.7392182957837523`, -2.255439402713049}, \
{-2.8838528158653003`, -2.370607421805214}, {-3.066156403210593, \
-2.5149138425168243`}, {-3.1587261791447387`, -2.587834946961558}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.177274435922397, -2.602446188655754}, \
{-3.229860174533445, -2.643870185839107}, {-3.415964303680583, \
-2.789836584482476}, {-3.5844156106494864`, -2.9215072997960774`}, \
{-3.7262789656080715`, -3.0321012571317025`}, {-3.859885233869775, \
-3.1361074979448937`}, {-3.921487659467141, -3.1839834977680206`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.9401312635172645`, -3.1984728815146943`}, \
{-3.9852344154345976`, -3.2335260222356506`}, {-4.102326510302539, \
-3.324356830003973}, {-4.212920638625872, -3.410023697349868}, \
{-4.318775920556871, -3.491950400373342}, {-4.419892356095536, \
-3.5701369390743953`}, {-4.516269945241866, -3.6445833134530283`}, \
{-4.687135588196128, -3.7764222923456927`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.705833234309898, -3.7908418691474965`}, \
{-4.867185545670674, -3.915187378334109}, {-5.02523882330725, \
-4.036850344683818}, {-5.174267105952436, -4.151463299129002}, \
{-5.179226552269493, -4.155275774170152}, {-5.332091371580647, \
-4.272692764577181}, {-5.454493452607392, -4.366645134033263}}]}, 
           {Arrowheads[{{0.00490423746242615, 1.}}], 
            ArrowBox[{{-5.473223892502596, -4.381022089019222}, \
{-5.477255582526099, -4.384116700053962}, {-5.617051571238257, \
-4.491513317181613}, {-5.656854249492381, -4.522150934161221}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.6245616232206483`, 0.5410466990565787}, {
             1.8441006772978277`, 0.5954499650288769}, {2.0785281954229533`, 
             0.6598616184630218}, {2.213127535574115, 0.6985256007849019}, {
             2.333504883380591, 0.733765011008695}, {2.480893717125499, 
             0.7776115577894568}, {2.5344605489409067`, 
             0.7937342935217295}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.5570706066326867`, 0.8005395491753065}, {
             2.612843149596561, 0.817326167701152}, {2.7743509698256905`, 
             0.8664302875035211}, {2.919111996733979, 0.9107753952881623}, {
             3.099110579312427, 0.9662800979394409}, {3.2603961600173377`, 
             1.016267508940231}, {3.442425926237138, 1.0729334807341457`}, {
             3.4597648503189107`, 1.0783487974158}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.482303170717947, 1.0853879967258466`}, {
             3.606905029942162, 1.124303821239511}, {3.7478800847515217`, 
             1.1684431797572163`}, {3.880399055160989, 1.209987907892594}, {
             4.004461941170563, 1.2489380056456432`}, {4.120068742780244, 
             1.2852934730163648`}, {4.333240471283551, 1.3524355264333194`}, {
             4.383425592867769, 1.3682654412944038`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.405943900484097, 1.3753684009192793`}, {
             4.52724061915453, 1.4136290779659533`}, {4.7053546321410025`, 
             1.4698819354068646`}, {4.870867955990788, 1.5222019065486516`}, {
             5.0252407335022005`, 1.5710402185050745`}, {5.170609313090835, 
             1.617057842200007}, {5.184846003669941, 1.6215659762461787`}, {
             5.3064814585661395`, 1.660103202771216}}]}, 
           {Arrowheads[{{0.0072832268101154386`, 1.}}], 
            ArrowBox[{{5.328990738632725, 1.667234719034971}, {
             5.334544525815023, 1.6689943010162176`}, {5.476532115976953, 
             1.713999210992445}, {5.6152290545919845`, 1.7579683430192008`}, {
             5.656854249492381, 1.7711688606210259`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6776543430581288`, 
             1.37218432567322}, {-1.8556712304129834`, 
             1.530983662399976}, {-1.9643533332182055`, 
             1.62487520374695}, {-2.06248281943428, 
             1.708249011415909}, {-2.1874351824846263`, 
             1.8128212635810281`}, {-2.3000036814981923`, 
             1.905881515284687}, {-2.3964266815074446`, 
             1.9847154097836766`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.414706711232584, 
             1.9996608681769203`}, {-2.442268914238816, 
             2.0221952822041187`}, {-2.5702477392378213`, 
             2.12589475780193}, {-2.7305966588176966`, 
             2.254773422724827}, {-2.8747581091539542`, 
             2.3698831506475804`}, {-3.056592041080833, 
             2.5142081474964653`}, {-3.1521808874445245`, 
             2.589707534322907}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.170710280062578, 
             2.6043426913955927`}, {-3.219872431646246, 
             2.6431726641469466`}, {-3.405473976907737, 
             2.789124170979355}, {-3.573471522319444, 
             2.9207768846022963`}, {-3.7150076413151893`, 
             3.0313949431319234`}, {-3.8483041251864574`, 
             3.1354205423695323`}, {-3.9142213739197382`, 
             3.1867773819590384`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.932847514095307, 
             3.2012892087047042`}, {-3.9733609739332483`, 
             3.232853682315123}, {-4.090178187555562, 
             3.323694362968695}, {-4.200511524014486, 
             3.4093678845265174`}, {-4.306116741271108, 
             3.4912995471848602`}, {-4.406993839325427, 
             3.569489350943723}, {-4.5031428181774436`, 
             3.6439372958031053`}, {-4.679187697552801, 
             3.7800959979850792`}}]}, 
           {Arrowheads[{{0.019999999999999987`, 1.}}], 
            ArrowBox[{{-4.697871421241532, 
             3.7945336100165226`}, {-4.853224029286844, 
             3.9145381073511523`}, {-5.010900891605589, 
             4.036195480990817}, {-5.159574190889733, 
             4.150801291762169}, {-5.1645366526751, 
             4.154624924447603}, {-5.3170399378184845`, 
             4.272033875952055}, {-5.445894010127975, 4.371164958974484}}]}, 
           {Arrowheads[{{0.0051387415143412316`, 1.}}], 
            ArrowBox[{{-5.464607761258595, 
             4.38556362981544}, {-5.6015230846492265`, 
             4.490978840277127}, {-5.656854249492381, 4.53365451226114}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8514897471258842`, -0.3376109384944052}, {
             2.0916281495180082`, -0.37400257230048706`}, {
             2.2287608350032917`, -0.3958708325267751}, {
             2.3514429302909416`, -0.4158466355179102}, {
             2.501044885898596, -0.4406356021054064}, {
             2.6350134056384147`, -0.4631110524071988}, {
             2.7838430269056387`, -0.48834587379649236`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.8071209062415434`, -0.49230394585559384`}, {
             2.9453462585448973`, -0.5159232616350592}, {
             3.127435807401074, -0.5472480182717196}, {
             3.2906339669613245`, -0.5754655993686683}, {
             3.475023640957663, -0.6074864376423291}, {
             3.6416406021830436`, -0.636512488529836}, {
             3.737777089797556, -0.6533001206115112}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.7610371101159363`, -0.65736185276968}, {
             3.7836909146610243`, -0.6613177257726344}, {
             3.917253207647534, -0.6846680624576018}, {
             4.158913735146141, -0.727004034154044}, {
             4.373953854549076, -0.7647586465947509}, {
             4.569705235726548, -0.7991701427553107}, {
             4.691308615699283, -0.8205695048436595}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.714563281097127, -0.824661784229343}, {
             4.749466103207604, -0.8308038678491798}, {
             4.9165346815212905`, -0.8602251670898144}, {
             5.072378992526582, -0.8876875363275327}, {
             5.219147429097286, -0.9135623916798701}, {
             5.235553352600345, -0.9164553741238104}, {
             5.386714292161237, -0.943120893744335}, {
             5.530100927339126, -0.968422465934437}, {
             5.6446982551746885`, -0.9886460924294256}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.501024208783865, -3.9539066989236766`}, {
             0.43823734691172767`, -4.095792471635378}, {
             0.3733671539003186, -4.208736876225715}, {
             0.27950686435424393`, -4.327379798636909}, {
             0.18267155892555537`, -4.407294759671721}, {
             0.1316323109677985, -4.43402234218308}, {
             0.07955899771738166, -4.45202046971751}, {
             0.02630432168749428, -4.461376612878723}, \
{-0.005747498867933406, -4.463811428949672}, {-0.03856323583877864, \
-4.467669658165816}, {-0.07187954769436807, -4.477296767187661}, \
{-0.10562022441059482`, -4.490740543454451}, {-0.17289950308698682`, \
-4.532669249927063}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.19293859296844623`, -4.545157688182464}, \
{-0.2622174026695877, -4.588332510116909}, {-0.4219652678259049, \
-4.750338457876784}, {-0.5014218495973417, -4.850283000668914}, \
{-0.5794792646778177, -4.958433060015479}, {-0.6502049579701439, \
-5.065582617542838}, {-0.7195189266666582, -5.177776196759124}, \
{-0.7771578758241438, -5.276139344940153}}]}, 
           {Arrowheads[{{0.008678061151856407, 1.}}], 
            ArrowBox[{{-0.7890294868411741, -5.296549256479003}, \
{-0.8520634012007013, -5.408702307137161}, {-0.8976764082491621, \
-5.4923016676105325`}, {-0.9352856020464706, -5.563019105497465}, \
{-0.9746648775914921, -5.638284264340447}, {-0.9842231868692023, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.774882663186038, 0.11929787026523318`}, {
             2.0110965414297333`, 0.1317293559372753}, {2.144971463341199, 
             0.13925963135600927`}, {2.264703477984827, 
             0.14616906472586463`}, {2.410280264114471, 0.1547493587346032}, {
             2.5406093155127536`, 0.16254300182146492`}, {2.699588190077782, 
             0.17216672772454025`}, {2.7178142445812346`, 
             0.1732796551608091}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.741382340199314, 0.17471878068460248`}, {
             2.8420801048992748`, 0.18086763232357358`}, {3.0188847267705157`,
              0.1917442244103077}, {3.177306213136296, 0.2015429787796703}, {
             3.356019457691533, 0.21264766688155534`}, {3.517489123872381, 
             0.22271315457517007`}, {3.6556450927526694`, 
             0.23134581589345957`}, {3.684054454409873, 
             0.23312292542128382`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.707620386145377, 0.2345970606843196}, {
             3.785515306084771, 0.23946967296134705`}, {4.020398466104417, 
             0.2541909743459161}, {4.229313003213997, 0.26731080376720345`}, {
             4.419433316696187, 0.2792629062635355}, {4.59397964892979, 
             0.29024513964611337`}, {4.650243575764249, 
             0.29378702263941076`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.673808921888288, 0.29527048999343086`}, {
             4.756172242293607, 0.3004553617261382}, {4.907442713022594, 
             0.3099822218272797}, {5.0498856445504074`, 0.3189555799012239}, {
             5.068484318238966, 0.32012737734781593`}, {5.215302616203643, 
             0.3293792854249818}, {5.354554597674318, 0.33815543123703945`}, {
             5.490577586138189, 0.34672831669361404`}, {5.616419564857534, 
             0.35466002262574464`}}]}, 
           {Arrowheads[{{0.0003579643354375019, 1.}}], 
            ArrowBox[{{5.6399839468548825`, 0.356158715590927}, {
             5.656854249492381, 0.35723347259077753`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8944766871397776, 4.20505743878416}, {
             0.897359803508585, 4.327709980213534}, {0.8966781740336021, 
             4.502587421957539}, {0.8902769399048268, 4.65182903153192}, {
             0.8648072640451774, 4.893598816901537}, {0.8256737811561481, 
             5.075937811627733}, {0.8051489395720859, 5.140700115995035}}]}, 
           {Arrowheads[{{0.01150007713957215, 1.}}], 
            ArrowBox[{{0.7980153749205533, 5.163208746977362}, {
             0.7963095010081439, 5.168591313516315}, {0.7661328532612501, 
             5.252207839260901}, {0.7291863980017438, 5.342695964510461}, {
             0.6925554764820383, 5.4251213998881145`}, {0.6198698372524659, 
             5.576008850119677}, {0.5736656604193184, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.2551014205472037`, -2.325836538671792}, {
             1.3252855336028735`, -2.439889065043899}, {
             1.4098692031566296`, -2.582687137329045}, {
             1.484385546922558, -2.7123944443604846`}, {
             1.5749013223383175`, -2.874359257700143}, {
             1.654775119314703, -3.02050168432307}, {
             1.722245195577384, -3.1464912675026833`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.7333921591399033`, -3.167306440254117}, {
             1.7537879436228085`, -3.2053923077669686`}, {
             1.8411631001534319`, -3.3713193451740566`}, {
             1.9402024324743625`, -3.562294037758974}, {
             2.0284306488473494`, -3.7345157332083208`}, {
             2.10075497800017, -3.877059657455949}, {
             2.166212677466934, -4.0067503978205234`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.176811394708571, -4.027849992056941}, {
             2.231356185686625, -4.13657024056123}, {
             2.28963306422026, -4.253536899418884}, {
             2.396323773344788, -4.469187963209952}, {
             2.4926533536632887`, -4.665326029412524}, {
             2.5804532277533605`, -4.845276457724786}, {
             2.5947843784855076`, -4.874801963352462}}]}, 
           {Arrowheads[{{0.017873069373672747`, 1.}}], 
            ArrowBox[{{2.60509484139109, -4.896043916370224}, {
             2.661554818192601, -5.0123646078449235`}, {
             2.736758637609521, -5.168077032915314}, {
             2.808418474022142, -5.3170603498384645`}, {
             2.8804365672832546`, -5.467665471205242}, {
             2.948444862410337, -5.6103848538260825`}, {
             2.97055651841223, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.1445960081943305`, -1.1366294849690914`}, \
{-2.2773254102384923`, -1.2099497774967183`}, {-2.3960985996572717`, \
-1.2747828383007995`}, {-2.5439809505110813`, -1.3546452898595869`}, \
{-2.676485565348354, -1.425603156763093}, {-2.840370142509287, \
-1.512705696546237}, {-2.9761437042069825`, -1.5844402948996974`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.997032097817256, -1.595449407213337}, \
{-3.1716445221931995`, -1.6872127801664307`}, {-3.3368993700105816`, \
-1.773689030019388}, {-3.52398835766156, -1.8712230250797832`}, \
{-3.6932362068092797`, -1.959203538549504}, {-3.8343564290649494`, \
-2.0324010207749947`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.855320884029982, -2.043264621652684}, \
{-3.9739747574407454`, -2.104738111120553}, {-4.101515019047764, \
-2.170729066900437}, {-4.220502604848975, -2.2322024690098936`}, \
{-4.332778347282681, -2.2901429772879127`}, {-4.440183078787188, \
-2.3455352515734837`}, {-4.640379509008602, -2.4486750981672802`}, \
{-4.694549483955028, -2.476550483676831}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.715544733230994, -2.4873544515209263`}, \
{-4.824407208337962, -2.543374109350411}, {-4.995581489600012, \
-2.6313843856820034`}, {-5.155380546875792, -2.713482151728335}, \
{-5.305968592043982, -2.7908026802650037`}, {-5.314656932647928, \
-2.7952624913654796`}, {-5.469373520170675, -2.874639816945212}, \
{-5.5556717135931075`, -2.9188963662363854`}}]}, 
           {Arrowheads[{{0.001907899174833461, 1.}}], 
            ArrowBox[{{-5.576681971965425, -2.9296711171135343`}, \
{-5.616219836747094, -2.9499474333628477`}, {-5.656854249492381, \
-2.97078272538471}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.43889140371700297`, -3.494901037678796}, {
             0.3589586470047995, -3.713395429131121}, {
             0.22157762298820163`, -3.914125180161444}, {
             0.0687678961274465, -4.005418161157338}, {
             0.03781355175942493, -4.011759267177878}, {
             0.006010052598599049, -4.014563511891579}, \
{-0.026440828489030684`, -4.019418169919311}, {-0.05950621568624993, \
-4.028887122826268}, {-0.16441810143696228`, -4.079484148450251}, \
{-0.19779447814208284`, -4.107183272669477}}]}, 
           {Arrowheads[{{0.00512118693948476, 1.}}], 
            ArrowBox[{{-0.2159643380300313, -4.122262477057922}, \
{-0.2736427333869059, -4.170129896936085}, {-0.385133553508623, \
-4.294314122939845}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.8442458818881122`, -2.5427274374754134`}, {
             3.020937654933789, -2.7005589176437437`}, {
             3.1786953112337137`, -2.8419567703415884`}, {
             3.3217537869607003`, -2.970483116975479}, {
             3.4541899186878657`, -3.0896348420541457`}, {
             3.547264858971123, -3.1734447690065033`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.56481153244014, -3.189244783674466}, {
             3.5784896483241035`, -3.2015613308523863`}, {
             3.6946529758694133`, -3.3062625833702}, {
             3.802679901323796, -3.4037385996075873`}, {
             3.9043666871886704`, -3.495565570781865}, {
             4.001509595965457, -3.5833196881103504`}, {
             4.182163782254766, -3.7466093612299423`}, {
             4.265784234335174, -3.822236814537779}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.283296408380088, -3.838075058555246}, {
             4.34780321148735, -3.896415872538662}, {
             4.501588634958838, -4.0355474756088086`}, {
             4.644911263511536, -4.165247882736275}, {
             4.779803202439736, -4.287335521678203}, {
             4.78447485430007, -4.291563953051246}, {
             4.923376116742321, -4.417293904748439}, {
             4.983599936027134, -4.471807569286767}}]}, 
           {Arrowheads[{{0.01879353916759629, 1.}}], 
            ArrowBox[{{5.001105393229968, -4.487653236879391}, {
             5.055068294691475, -4.536499615981907}, {
             5.1836892988219905`, -4.652923486496041}, {
             5.306167955315227, -4.763783675571504}, {
             5.421162402715067, -4.868204747560527}, {
             5.527330779565394, -4.965311266815339}, {
             5.623884574938579, -5.05460883457978}, {
             5.656854249492381, -5.085681287176607}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.375423050582262, 3.837453000783964}, {
             1.4277265970045623`, 4.0190995419547715`}, {1.4658881636169823`, 
             4.156414673926236}, {1.5009349674668842`, 4.285248671504203}, {
             1.5616842868791343`, 4.51747326347964}, {1.612770637597562, 
             4.7227981977707945`}, {1.6192172014051902`, 
             4.749834171266382}}]}, 
           {Arrowheads[{{0.019156101172189854`, 1.}}], 
            ArrowBox[{{1.6246938025356632`, 4.772802258983775}, {
             1.656990101978416, 4.908248354267378}, {1.6955574188915274`, 
             5.077130656003071}, {1.7296873272067277`, 5.232752026011555}, {
             1.7599037535944846`, 5.376608546664338}, {1.7874433319990433`, 
             5.512271161892681}, {1.815989090557195, 5.655951983954402}, {
             1.8161671083028932`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9346210853428016`, 1.9909280211673388`}, {
             3.084938070591472, 2.0925677731020365`}, {3.2721825193625036`, 
             2.219683851544966}, {3.4399726074419497`, 2.3339465734769025`}, {
             3.6297193736393103`, 2.4635093832761856`}, {3.715508248649228, 
             2.522204065451631}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.734995712241331, 2.535536918712754}, {
             3.801176945527929, 2.580816524644022}, {3.9478047553969944`, 
             2.681285922403815}, {4.085662828178255, 2.7758161999204183`}, {
             4.214751163871711, 2.864407357193832}, {4.335069762477362, 
             2.947059394224057}, {4.44851617772024, 3.0250453780028104`}, {
             4.513764910479916, 3.0699150971994484`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.533220621279024, 3.0832942425621996`}, {
             4.556987963325376, 3.099638375521811}, {4.7590076456224235`, 
             3.2386454117805545`}, {4.944534765191538, 3.3663867905847478`}, {
             5.116975277855751, 3.485168799518853}, {5.277843572538003, 
             3.5960217877669747`}, {5.311110324386364, 
             3.6189522287325446`}}]}, 
           {Arrowheads[{{0.008416260361891165, 1.}}], 
            ArrowBox[{{5.330551335869758, 3.632352724463626}, {
             5.429339036145657, 3.7004461030906244`}, {5.435501461873811, 
             3.7046945953263064`}, {5.556268073216804, 3.7885256801356526`}, {
             5.656854249492381, 3.8592670865688894`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.4911558144993315`, 1.8145301732017836`}, {
             3.683862965865628, 1.9155910344020846`}, {3.858009946719306, 
             2.00712784195837}, {4.006846860475954, 2.085496552090168}, {
             4.146785934888251, 2.1592440963696315`}, {4.277827169956196, 
             2.2283704747967605`}, {4.3269876985408215`, 
             2.2543326672497743`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.347866916555851, 2.2653592019917976`}, {
             4.39997056567979, 2.2928756873715552`}, {4.515139699612844, 
             2.353748077145352}, {4.62525814930917, 2.411975987169486}, {
             4.830342995991636, 2.520498367968769}, {5.018681480795835, 
             2.620237669968763}, {5.182663212535934, 
             2.7071249050568875`}}]}, 
           {Arrowheads[{{0.010865815192520766`, 1.}}], 
            ArrowBox[{{5.203526310651347, 2.718181909391449}, {
             5.357025987968248, 2.7995542898945516`}, {5.510819447172216, 
             2.8811100663770075`}, {5.5193990596349005`, 2.885660525349826}, {
             5.656854249492381, 2.9585840742146003`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7381796587103315`, 4.3211169289862355`}, {
             1.7801399304837917`, 4.440087210301322}, {1.8565680174065375`, 
             4.659121855455885}, {1.9252222449851977`, 4.857970845382486}, {
             1.9875190946019785`, 5.040089374680682}, {2.0448750476390862`, 
             5.208932637950031}, {2.0465300904995183`, 
             5.213836644373983}}]}, 
           {Arrowheads[{{0.009395491889641002, 1.}}], 
            ArrowBox[{{2.0540804587094943`, 5.236208907407256}, {
             2.0978987399102205`, 5.366045504169956}, {2.148018346171112, 
             5.515310065603506}, {2.195219330311011, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3301645141790455`, 1.2677651914382781`}, {
             3.5021480943830934`, 1.33265844260248}, {3.6969363263497668`, 
             1.4063639453638714`}, {3.8729988613343362`, 
             1.4731173950121277`}, {4.02244844712974, 1.5298645898847805`}, {
             4.163022350637371, 1.583278122479888}, {4.213366645541993, 
             1.602422160544332}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.235436825970751, 1.610814618419008}, {
             4.29472057185723, 1.6333579927974502`}, {4.417543110789317, 
             1.6801042008374674`}, {4.644201126141964, 1.7664366472751065`}, {
             4.8506363810471065`, 1.845116478983047}, {5.040295915811137, 
             1.91743862779491}, {5.118025263119906, 1.9470876026696595`}}]}, 
           {Arrowheads[{{0.01171243261131979, 1.}}], 
            ArrowBox[{{5.140086810346392, 1.955502728771489}, {
             5.216626770740451, 1.9846980255443178`}, {5.38116583803917, 
             2.0474749408029367`}, {5.536163022721605, 2.106619526561862}, {
             5.547264258298622, 2.1108558442939955`}, {5.656854249492381, 
             2.1526818347755476`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9700953193382755`, -3.317055769090223}, {
             3.121141518993672, -3.48771416458095}, {
             3.2121063510577943`, -3.5906954417219623`}, {
             3.2986456091227536`, -3.6887374869958087`}, {
             3.458447403255181, -3.8700038819420044`}, {
             3.576602008135164, -4.0041808595622115`}, {
             3.5950817628138316`, -4.025175187490962}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6106827620080355`, -4.042899042530953}, {
             3.688276631511714, -4.131051248550303}, {
             3.7934712733848315`, -4.250615048906281}, {
             3.8921859337545164`, -4.362872260630143}, {
             3.9857398637421544`, -4.469296682259641}, {
             4.075452314469132, -4.571362112332525}, {
             4.16132328593545, -4.669068550848795}, {
             4.2343549774478655`, -4.752176732632214}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.249941042631274, -4.7699137218162555`}, {
             4.398392796663524, -4.938858104949209}, {
             4.543077841929468, -5.1035126216460815`}, {
             4.6785545353457, -5.257677923042006}, {
             4.806174327276995, -5.402773548690946}, {
             4.808758484401881, -5.40570879136519}, {
             4.87382103893954, -5.479007278160416}}]}, 
           {Arrowheads[{{0.0045607172992379735`, 1.}}], 
            ArrowBox[{{4.889495654296266, -5.496666062001746}, {
             4.909575879197755, -5.51928813871309}, {
             5.002903411937135, -5.623128002914952}, {
             5.033460359093596, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.473547154983553, 0.8640535586376532}, {
             3.6672245356951585`, 0.9118064457100917}, {3.84227926709616, 
             0.9550629110183129}, {3.99070759094253, 0.9917998062196367}, {
             4.130324435947909, 1.0263820457275252`}, {4.261129802112298, 
             1.058809629541978}, {4.3831236894356955`, 1.0890825576629954`}, {
             4.3903835125153226`, 1.0908856482583273`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.413299295707796, 1.0965771413850636`}, {
             4.608257016994727, 1.1449979403334998`}, {4.813304408060211, 
             1.1959616872478145`}, {5.001688256725806, 1.2428108154072743`}, {
             5.176830957085168, 1.2863823418132148`}, {5.329873381045889, 
             1.3244671676844908`}}]}, 
           {Arrowheads[{{0.006635339247590493, 1.}}], 
            ArrowBox[{{5.3527864266408205`, 1.3301696719287541`}, {
             5.494206620389866, 1.3653686121295325`}, {5.507833938538896, 
             1.3687606758540776`}, {5.656854249492381, 
             1.4058611940622576`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.011354822648132753`, 1.}}], 
            ArrowBox[{{0.2605264712607025, -4.71647745906102}, {
             0.19347032065641104`, -4.763864961165305}, {
             0.12514837608880292`, -4.796794557500539}, {
             0.055244334279171206`, -4.815754461157427}, {
             0.024012906629925054`, -4.8197000269353145`}, \
{-0.007846663691722, -4.822063898445424}, {-0.04016559565939732, \
-4.827558894352296}, {-0.07288931025186995, -4.836429199711806}, \
{-0.23056951656918345`, -4.913987392577416}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.8608090936645714`, 0.4743601711379505}, {
             4.009771693927755, 0.4926964412573691}, {4.149902948501735, 
             0.5099625307838325}, {4.281202857386512, 0.5261584397173407}, {
             4.4036714205820875`, 0.5412841680578936}, {4.629702544830493, 
             0.5692334536381247}, {4.79817190877123, 0.5900876175966941}}]}, 
           {Arrowheads[{{0.017822474783069715`, 1.}}], 
            ArrowBox[{{4.821605051318163, 0.5929883147045087}, {
             4.835584356171814, 0.5947187582025172}, {5.024747067205631, 
             0.6181556707570605}, {5.200620890531526, 0.639959780307744}, {
             5.364736575961232, 0.6603176772879903}, {5.519335395733405, 
             0.6795028261673003}, {5.534524145055473, 0.6813880775398737}, {
             5.656854249492381, 0.6965770730154583}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.8906971623048943`, 0.016810842229545958`}, {
             4.0405851984786105`, 0.017446960966849886`}, {4.181600224363587, 
             0.018045664943864073`}, {4.313742239959822, 
             0.018606954160588517`}, {4.4370112452673185`, 
             0.019130828617023216`}, {4.66454530265808, 
             0.020098159296704703`}, {4.835168357577273, 
             0.020823650551732752`}}]}, 
           {Arrowheads[{{0.01689991446327893, 1.}}], 
            ArrowBox[{{4.858780137130384, 0.02092404811869429}, {
             4.87181747417786, 0.020979483030589854`}, {5.062274123392596, 
             0.021789343676641083`}, {5.239361613868228, 
             0.022542285092820812`}, {5.404618788230628, 
             0.023244830547468297`}, {5.560298969484019, 
             0.023906538708333563`}, {5.575960415668733, 
             0.023973099054661166`}, {5.656854249492381, 
             0.024316806447514428`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.00998830795447244, 1.}}], 
            ArrowBox[{{1.0284632429153369`, -5.187689390007329}, {
             1.015503380060962, -5.4157429959364745`}, {
             1.005850781283704, -5.513582817989109}, {
             0.994321950591513, -5.602900453129666}, {
             0.9842125559956999, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.8168409275007306, -4.736869460162513}, {
             0.7634529851113652, -4.943897525500631}, {
             0.6804566876963265, -5.159456380125712}, {
             0.6395594395515788, -5.249855345300623}, {
             0.5989745131431427, -5.330984758706025}, {
             0.5496762241032992, -5.41918187264489}, {
             0.5007847025492363, -5.491621974888867}, {
             0.4519078595994007, -5.555111875809463}, {
             0.4233847146145297, -5.5848418221778795`}}]}, 
           {Arrowheads[{{0.0016132352003785941`, 1.}}], 
            ArrowBox[{{0.4070379088695572, -5.60188025389187}, {
             0.35429542398647584`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.007685863552490582, 1.}}], 
            ArrowBox[{{0.07236477403974641, -5.539784267724255}, {
             0.040967107185561666`, -5.5448224058495565`}, {
             0.009070750390041491, -5.547473299169541}, \
{-0.02324540599354154, -5.5510958522482445`}, {-0.05593971048999841, \
-5.557711176832743}, {-0.16534791664404874`, -5.595459680299292}, \
{-0.26557806856652916`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.015679288144996348`, 1.}}], 
            ArrowBox[{{1.15619598787486, 2.952611989304452}, {
             1.2103766377555045`, 3.088288245842519}, {1.2583592686465837`, 
             3.2132141975706032`}, {1.301688436894644, 3.3292139574244}, {
             1.340998330019269, 3.437232800614156}, {1.3772040289245246`, 
             3.5386833952666668`}, {1.3785777652806022`, 3.542569689513598}, {
             1.4146457784167223`, 3.6463861551223054`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.7888753686145833, -1.9624005217284162`}, \
{-0.832287135611409, -2.2046569488824}, {-0.8802832744097948, \
-2.38879301155676}, {-0.9287681971424044, -2.5430769097719}, \
{-0.9765885233901992, -2.678293109658562}, {-1.0232009608645234`, \
-2.8011334679620754`}, {-1.0496974593371307`, -2.8675890283389043`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0584423375989997`, -2.8895219560395384`}, \
{-1.068466212560209, -2.9146627205214224`}, {-1.1551934989647832`, \
-3.1184409955216723`}, {-1.240033265315493, -3.3061116556250685`}, \
{-1.3201352232643353`, -3.476614377232081}, {-1.3959365681147606`, \
-3.6336405356340644`}, {-1.452008559519597, -3.7478658866082997`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.4624133921140137`, -3.7690617747005293`}, \
{-1.4681206142221674`, -3.780688068542762}, {-1.537185252523901, \
-3.9198931840228113`}, {-1.603130483019961, -4.051255882074213}, \
{-1.665956305710348, -4.174776162696967}, {-1.7261669183735067`, \
-4.292051034904113}, {-1.7842665187878828`, -4.404677507708692}, \
{-1.8912936389672128`, -4.610524866309443}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.9022385225805216`, -4.6314469718232765`}, \
{-1.996716440768631, -4.811661589788877}, {-2.0931794352939885`, \
-4.994668696632405}, {-2.184111554688944, -5.166369379595645}, \
{-2.271465263042802, -5.330782836964595}, {-2.343788544456618, \
-5.466354194453128}}]}, 
           {Arrowheads[{{0.004075566909407197, 1.}}], 
            ArrowBox[{{-2.3549022906720074`, -5.487187121717343}, \
{-2.369314188468527, -5.514202496435766}, {-2.445762828312012, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.07402088165125173, 
             2.6089387815595417`}, {-0.04417101553412346, 
             2.6263204316857216`}, {-0.01533855871070607, 
             2.6345803261798677`}, {0.017817667447677266`, 
             2.637109519657531}, {0.05185544794346537, 2.6435547440134113`}, {
             0.08563601205696074, 2.657965965272824}, {0.11751209537139774`, 
             2.679873679227093}, {0.20824371997031155`, 2.815244698100335}, {
             0.2391588403119423, 2.9770901642460603`}, {0.23409657990452892`, 
             3.0829799197196315`}, {0.21383497766150958`, 
             3.174951607101114}, {0.18297541021844113`, 
             3.2508076532140597`}, {0.16448874830757929`, 
             3.2824813685702554`}, {0.14418534830578605`, 
             3.3101941050007326`}, {0.11865390277198595`, 
             3.333540820843885}, {0.1009379534850865, 3.345191421468123}}]}, 
           {Arrowheads[{{0.011345321168664541`, 1.}}], 
            ArrowBox[{{0.08016808620113308, 3.3562303442587273`}, {
             0.035111039957913606`, 
             3.3755955364407737`}, {-0.026478660890267035`, 
             3.389621196959455}, {-0.09340251799585242, 
             3.4204337854557547`}, {-0.20324422362367348`, 
             3.5184619617053685`}, {-0.3260642059113639, 
             3.6796680167455786`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.2785317160957574`, 
             0.691282713272722}, {-2.4562029631181814`, 
             0.7472495145151372}, {-2.6109731570272134`, 
             0.7954031178675309}, {-2.748914906295413, 
             0.8379526150476349}, {-2.8747054842787314`, 
             0.8765424849342868}, {-2.990798305854628, 
             0.9120125908929361}, {-3.181006446902864, 0.9697959416317348}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.203601358505751, 
             0.9766513002586521}, {-3.3898387831837655`, 
             1.032908356817426}, {-3.5616283897360526`, 
             1.0846006055230788`}, {-3.718094467041246, 
             1.1315449298049407`}, {-3.8633713748515954`, 
             1.1750483773206115`}, {-3.9999957323677786`, 
             1.2159072399138433`}, {-4.108196633998216, 
             1.2482176322486347`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.130821827290096, 
             1.254972395633403}, {-4.247286796517649, 
             1.2896912103329903`}, {-4.467455223545623, 
             1.355215429352084}, {-4.667988577506466, 
             1.4147984852608266`}, {-4.852241710038026, 
             1.4694665119938952`}, {-5.023569472778149, 
             1.5202456434859664`}, {-5.036181741380643, 
             1.5239800434312276`}}]}, 
           {Arrowheads[{{0.013205848119694413`, 1.}}], 
            ArrowBox[{{-5.058822131209777, 
             1.530683696295225}, {-5.18346386560585, 
             1.56758919686583}, {-5.33410830849563, 
             1.6121598466624965`}, {-5.346636495827798, 
             1.6158650724003163`}, {-5.501584169933426, 
             1.6616590276043557`}, {-5.648622025048331, 
             1.7050896858970146`}, {-5.656854249492381, 
             1.707532247051808}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.5911084239352641, 
             2.531411083351144}, {-0.6039439739223204, 
             2.6169083881154567`}, {-0.6190629392261574, 
             2.695682406012205}, {-0.65311840025763, 
             2.840966283470347}, {-0.6908846401646289, 
             2.973340425521552}, {-0.7312864559509867, 
             3.0956448646651893`}, {-0.7728487799683462, 
             3.21150793494456}, {-0.8278346792577562, 
             3.355418532425744}, {-0.8599874385929898, 
             3.4340811512546754`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8689211918679248, 
             3.4559378267969154`}, {-0.8817175174588721, 
             3.4872443928019217`}, {-0.934789310048519, 
             3.6137500207405857`}, {-1.0022490092826608`, 
             3.7731597125420215`}, {-1.0676031520778482`, 
             3.924766544415991}, {-1.1307572271861444`, 
             4.069350885788999}, {-1.1916167233596127`, 
             4.207693106087551}, {-1.24271124874216, 4.323272952450404}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.25226206793112, 
             4.344867118288201}, {-1.3067013511540528`, 
             4.4677287340635825`}, {-1.3885271426504073`, 
             4.652201995605869}, {-1.4659800705270982`, 
             4.826879411039257}, {-1.5394422457111596`, 
             4.992757146053764}, {-1.6092957791296254`, 
             5.150831366339405}, {-1.6346974714945217`, 5.208455398060856}}]}, 
           {Arrowheads[{{0.00987230089855137, 1.}}], 
            ArrowBox[{{-1.6442217319229804`, 
             5.230061292548867}, {-1.6758034469193015`, 
             5.301704776794853}, {-1.7394382461264384`, 
             5.446462246237713}, {-1.801670746886908, 
             5.588223354612774}, {-1.831835482304381, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.078049748402574, 
             0.2105390752808691}, {-2.2914334174561617`, 
             0.23362959986922938`}, {-2.4699479023832853`, 
             0.25255323155620185`}, {-2.6252941289925595`, 
             0.2688095035719415}, {-2.7636579626691224`, 
             0.28315811394498674`}, {-3.0061560456267276`, 
             0.30810903240465615`}, {-3.0173549276617826`, 
             0.30925173372328163`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.040844953312236, 
             0.3116485875521993}, {-3.2142874000854236`, 
             0.3293461498635941}, {-3.406503087357873, 
             0.34884065869212477`}, {-3.579001490362814, 
             0.36626259493401864`}, {-3.7360564781315895`, 
             0.3820748558080179}, {-3.881846915462291, 
             0.3967223409955095}, {-3.9805371421186955`, 
             0.40662351059392376`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.00403119435671, 
             0.4089805686699221}, {-4.018933977765387, 
             0.4104757013797848}, {-4.147317665040879, 
             0.42333493696084373`}, {-4.266997977288767, 
             0.43530004773868636`}, {-4.487793007382668, 
             0.45733382213750134`}, {-4.688863598728031, 
             0.4773629518290085}, {-4.873584246979108, 
             0.49573439705657674`}, {-4.943848134991824, 
             0.5027142287176127}}]}, 
           {Arrowheads[{{0.014672386795661489`, 1.}}], 
            ArrowBox[{{-4.967344482566108, 
             0.505048294698818}, {-5.045329447790152, 
             0.5127951180635749}, {-5.205598618492923, 
             0.5286981897089507}, {-5.356585743916638, 
             0.5436673352018253}, {-5.371481669958155, 
             0.5451434857044235}, {-5.5268626752410395`, 
             0.5605290972622751}, {-5.656854249492381, 
             0.5733920585677104}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0842542633539596`, -0.20001557066473788`}, \
{-2.2979904716268735`, -0.22188502908496943`}, {-2.476843552055221, \
-0.23981412907069294`}, {-2.6325062262635965`, -0.25521893375666255`}, \
{-2.771164953613394, -0.2688175879678276}, {-3.0141985881067797`, \
-0.2924663777459569}, {-3.0241021401836785`, -0.2934220577474283}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.047604957622936, -0.2956900493155571}, \
{-3.222805699756366, -0.31259669495136133`}, {-3.415378336415215, \
-0.3310671575118044}, {-3.5882111725841455`, -0.34757503073866897`}, \
{-3.745580256469557, -0.3625583497362677}, {-3.8916680276548345`, \
-0.3764382893957837}, {-3.987799254009025, -0.38555861557132626`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.011305693022521, -0.38778875867008056`}, \
{-4.029038139519756, -0.3894711016722312}, {-4.157690592064321, \
-0.40165678656561016`}, {-4.2776253852885295`, -0.41299534407592053`}, \
{-4.498896665603642, -0.43387549563238587`}, {-4.700406652292856, \
-0.45285597502667746`}, {-4.8855353791605935`, -0.47026551840705627`}, \
{-4.9516126538805585`, -0.4764719293154525}}]}, 
           {Arrowheads[{{0.014499422661435998`, 1.}}], 
            ArrowBox[{{-4.975121176166814, -0.47868000387324916`}, \
{-5.057662880011276, -0.4864328619217833}, {-5.218291250375721, \
-0.5015030596198338}, {-5.369618451077043, -0.5156881170060174}, \
{-5.3844757529682665`, -0.5170801690586032}, {-5.5402007846803505`, \
-0.5316588689134953}, {-5.656854249492381, -0.5425722402904255}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.9952879959308167`, -2.3693833858770037`}, \
{-2.0991001030263376`, -2.488910758475348}, {-2.2301983237860683`, \
-2.6379385851576767`}, {-2.3487700384951475`, -2.771332935415444}, \
{-2.4971039979710135`, -2.9366476959450662`}, {-2.6225869006241576`, \
-3.075425895512697}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.6384461321031494`, -3.092919033135011}, \
{-2.717621626321409, -3.1799832124412757`}, {-2.7999939873822197`, \
-3.2703265980676077`}, {-2.9522824428188126`, -3.436607471784639}, \
{-3.042398309314653, -3.534580664502623}, {-3.1284116868008813`, \
-3.627916382487425}, {-3.2770941890537006`, -3.7887375487185393`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.293131992750496, -3.806067140510544}, \
{-3.418104217820281, -3.9408034132952814`}, {-3.5408117503238357`, \
-4.072865295167975}, {-3.656253572255169, -4.196861039875564}, \
{-3.7644296836142805`, -4.312790647418049}, {-3.8668455338070657`, \
-4.422356069483335}, {-3.936866465201396, -4.497186359246233}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.952999427536468, -4.514427407347531}, \
{-3.965006572239419, -4.52725925775933}, {-4.058912798911342, \
-4.627500212246034}, {-4.148564213822832, -4.723078932943446}, \
{-4.234662679018049, -4.814776416251332}, {-4.317910056541153, \
-4.903373658569458}, {-4.475851548571016, -5.07126742023643}, \
{-4.5997216396311105`, -5.202752538081523}}]}, 
           {Arrowheads[{{0.012778265849957128`, 1.}}], 
            ArrowBox[{{-4.615912739576479, -5.2199390006580755`}, \
{-4.623663667624762, -5.228166424074942}, {-4.763115211038385, \
-5.375995566854532}, {-4.765805655034868, -5.378845424031049}, \
{-4.877158664393979, -5.4960031575526305`}, {-4.9801821783411375`, \
-5.603193426598207}, {-5.03213103410496, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.6043148665198697`, -2.6497836855287553`}, \
{-1.694201578507605, -2.7896538666161983`}, {-1.7774119203465022`, \
-2.917100704214645}, {-1.8551044356069106`, -3.034719678153966}, \
{-1.927889124423771, -3.1436895709806154`}, {-1.9963759869320241`, \
-3.2451891652410465`}, {-2.126814106443367, -3.4365187151399414`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.140193233882626, -3.4559743913486796`}, \
{-2.2495199096669367`, -3.61467917679616}, {-2.360210040390775, \
-3.7741396844355384`}, {-2.4635832455842377`, -3.9223269776464615`}, \
{-2.5611894064110046`, -4.061788928497728}, {-2.653028522871076, \
-4.19252553698934}, {-2.6801066224615697`, -4.23091003424995}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.6937176119418873`, -4.250204260813947}, \
{-2.7391005949644516`, -4.314536803121294}, {-2.8205988979332752`, \
-4.429701742215198}, {-2.8987167070196893`, -4.539899369592658}, \
{-2.9734540222236943`, -4.645129685253673}, {-3.0448108435452905`, \
-4.745392689198243}, {-3.179608646427447, -4.934390581956184}, \
{-3.2408524546942687`, -5.02006290384212}}]}, 
           {Arrowheads[{{0.016110680636688357`, 1.}}], 
            ArrowBox[{{-3.254583964028709, -5.039271544208745}, \
{-3.3053357575523514`, -5.110266867884617}, {-3.4230042513993655`, \
-5.274525821581396}, {-3.5360531519318212`, -5.432089206287825}, \
{-3.6314003843934275`, -5.56422141195068}, {-3.6989029257236354`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6451121606355499, 4.837430500972301}, {
             0.5917225635234449, 4.955270316334621}, {0.5039915920453699, 
             5.116211184185627}, {0.41664937212395814`, 5.242164259244577}, {
             0.24077768742926642`, 5.4092026262633555`}, {0.2042921728000578, 
             5.431348908075092}, {0.16736885633093546`, 5.449892558627853}, {
             0.13007232202809535`, 5.462955274027831}, {0.09234208681435442, 
             5.4724533081484985`}, {0.020526200257987348`, 
             5.488364809355546}}]}, 
           {Arrowheads[{{0.007823822550361771, 1.}}], 
            ArrowBox[{{-0.0025267518226944584`, 
             5.493472412874022}, {-0.05159355309823592, 
             5.5043436351781425`}, {-0.20183970910881505`, 
             5.562657882384894}, {-0.32875179620934336`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.0410053128209045`, 2.649146246300986}, {
             3.1423921118429856`, 2.7374638149788066`}, {3.2375402601934113`, 
             2.8204767503925257`}, {3.4121356732556962`, 
             2.9730798622401715`}, {3.5708831606448808`, 3.112035933321748}, {
             3.7170422144903816`, 3.2400983374737553`}, {3.7520512179206222`, 
             3.270801076712743}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.769803486466101, 3.286369736732968}, {
             3.8521972354936307`, 3.358628685673219}, {3.97793262435606, 
             3.4689885888971634`}, {4.104074790289889, 3.5797571771491223`}, {
             4.224391489132606, 3.6854292399062474`}, {4.339505381007281, 
             3.7865455521522495`}, {4.443397418057563, 3.8778786223779265`}, {
             4.4794764491877395`, 3.909592105594459}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.497211080410091, 3.9251808537399437`}, {
             4.544888618693621, 3.9670894295191776`}, {4.642422332607779, 
             4.052826036116727}, {4.825617300270395, 4.213876647680718}, {
             4.995456443907567, 4.363192106169768}, {5.154413886381456, 
             4.502934060683746}, {5.206559596763793, 4.548772565559295}}]}, 
           {Arrowheads[{{0.0122465027639706, 1.}}], 
            ArrowBox[{{5.224293822571537, 4.564361774915003}, {
             5.3036492783829665`, 4.634118911627549}, {5.443938792950193, 
             4.757558037792464}, {5.44770490774722, 4.760875711912279}, {
             5.545858851397671, 4.848060685096327}, {5.634374755611225, 
             4.927657821669707}, {5.656854249492381, 4.948217546426834}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01786972778343862, 1.}}], 
            ArrowBox[{{-0.19511181589618032`, -2.8043089626603135`}, \
{-0.1976105521636876, -2.870368800196517}, {-0.20705266362847022`, \
-2.9338689968111242`}, {-0.21402595336995464`, -2.9652996427376057`}, \
{-0.22251243417432343`, -2.9974901533667793`}, {-0.23529707066598124`, \
-3.0368934975238973`}, {-0.24971927035285435`, -3.0770215293320016`}, \
{-0.2813338263714968, -3.1587663996796063`}, {-0.3179273228627623, \
-3.2436181948962814`}, {-0.35842958004808967`, -3.331613771554597}, \
{-0.41980316223652553`, -3.4585028864453258`}, {-0.4846283693411834, \
-3.589488867087162}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.238958359897698, 2.4690019608681766`}, {
             2.3762856984567433`, 2.6185063563644806`}, {2.498982481456046, 
             2.753044768583504}, {2.6499396738976455`, 2.9196063882520824`}, {
             2.7850105280968647`, 3.0693365083186848`}, {2.8712540295807285`, 
             3.1652636812356802`}, {2.8738949734257173`, 
             3.168205091025925}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.889669679963621, 3.1857745203558485`}, {
             2.9530858999093486`, 3.256405742054342}, {3.1035147471008537`, 
             3.42433452739666}, {3.1926981395031677`, 3.52410503143336}, {
             3.277581247170798, 3.6191386238184466`}, {3.434446608302009, 
             3.794995073633783}, {3.519066560549423, 
             3.8899763733538415`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.534773426711255, 3.90760647740091}, {
             3.5583255694191287`, 3.9340424782041894`}, {3.6751075687248527`, 
             4.065186751934728}, {3.7847926062191823`, 4.188427894825398}, {
             3.887380681902117, 4.3037659068762}, {3.984363458043651, 
             4.4128461499636815`}, {4.077232596913779, 4.517313985964387}, {
             4.162526492312865, 4.613274893799969}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.178211839730055, 4.630924145599878}, {
             4.250629962839819, 4.712412436705478}, {4.4103247015825655`, 
             4.892125944009228}, {4.559068735044345, 5.0595191927854}, {
             4.69810275630293, 5.215980508849771}, {4.805612081832045, 
             5.336906347804799}}]}, 
           {Arrowheads[{{0.00862612379910447, 1.}}], 
            ArrowBox[{{4.821300641242287, 5.354552744518221}, {
             4.829079272347749, 5.363302101727192}, {4.831734569195242, 
             5.3662872037250615`}, {4.936884179848737, 5.483650473710161}, {
             5.034435108780687, 5.591266439524533}, {5.094344918262943, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0894046690509454`, -2.1213718565175386`}, {
             3.18891188411514, -2.1898662077457423`}, {
             3.379405206167468, -2.3213745375493553`}, {
             3.550191376377729, -2.4396226432385184`}, {
             3.7055406416710595`, -2.5474117238897285`}, {
             3.8496387140520754`, -2.6475293780067566`}, {
             3.8659981272041444`, -2.6589056714614547`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.8853836500666827`, -2.672386313756322}, {
             3.985052348745853, -2.741695668186235}, {
             4.111781545752394, -2.829910594428164}, {
             4.229826305071697, -2.9121741567325437`}, {
             4.341075536318524, -2.989767399693663}, {
             4.447418149107635, -3.063971367905812}, {
             4.645383519312715, -3.2022114800831973`}, {
             4.660159497292009, -3.212538052738534}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.679513412352959, -3.2260640345938256`}, {
             4.827095926422331, -3.329205874432129}, {
             4.995928881171876, -3.4472659321200374`}, {
             5.153378479150901, -3.557422160499587}, {
             5.301632933368292, -3.6611830708494564`}, {
             5.307962591825213, -3.6656138689372995`}, {
             5.453400672592311, -3.767488393693384}}]}, 
           {Arrowheads[{{0.004780009560268024, 1.}}], 
            ArrowBox[{{5.472685581742567, -3.7811125585575716`}, {
             5.589750726124913, -3.8638642478768337`}, {
             5.656854249492381, -3.91163574270715}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1758404521442283`, 
             2.6378826711634433`}, {-1.2410720051020028`, 2.777556627083929}, 
             {-1.302573683174286, 2.904859070218162}, {-1.3607839701198754`, 
             3.0225111318646194`}, {-1.4685737919590838`, 
             3.2335165422936765`}, {-1.569341820841732, 
             3.42510596571286}, {-1.5996722914053976`, 
             3.4817608268076996`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.6108165704493411`, 
             3.5025774369526506`}, {-1.6620544201270897`, 
             3.5982855879421902`}, {-1.7480341805029156`, 
             3.7569421260083904`}, {-1.828792602683828, 
             3.9048851789505465`}, {-1.9053163758561316`, 
             4.044457249705709}, {-1.977605500019827, 
             4.175658338273878}, {-2.045659975174914, 
             4.298488444655053}, {-2.063896679464036, 4.331276553799341}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.0753738171077716`, 
             4.351911512603345}, {-2.110298882220117, 
             4.41470393543481}, {-2.1723413020541624`, 
             4.526061177198725}, {-2.2886366800887767`, 
             4.734200913679029}, {-2.3961775384875033`, 
             4.926125879099518}, {-2.496595306459088, 
             5.10505429846375}, {-2.536544253261856, 5.176145823011799}}]}, 
           {Arrowheads[{{0.011179123881105339`, 1.}}], 
            ArrowBox[{{-2.548111491083566, 
             5.196730410025197}, {-2.5906559886567875`, 
             5.272440871393394}, {-2.6807550203327275`, 
             5.432668874708628}, {-2.7880667615562853`, 
             5.623390056957827}, {-2.806932845076494, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3542254724991829, 3.4610049750813694`}, {
             0.26905807444468743`, 3.6409808175503136`}, {0.08936372962770442,
              3.8045479804874414`}, {0.05798055943599601, 
             3.814469416656106}, {0.02561399678559697, 
             3.820215097965129}, {-0.007578277729962751, 
             3.82257199376023}, {-0.041557288649949675`, 
             3.8305180861994406`}, {-0.0919345426940642, 
             3.847980354103776}, {-0.14389614296022699`, 
             3.8770291114309585`}, {-0.197297467089572, 
             3.9171800176829885`}, {-0.2930826442122456, 
             4.009822066149075}, {-0.32845636639640574`, 
             4.052594456324797}}]}, 
           {Arrowheads[{{0.008964636762754023, 1.}}], 
            ArrowBox[{{-0.34350452062661757`, 
             4.070790040063713}, {-0.39098122722608686`, 
             4.128196840749225}, {-0.4892808033692911, 
             4.266052734044728}, {-0.5862689598800538, 4.417138138596876}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.2645535654769713`, 
             2.648832895757055}, {-2.3785298196373996`, 
             2.775465196471704}, {-2.4833943322846777`, 
             2.8911150016204528`}, {-2.5808261763189972`, 
             2.9979623343803214`}, {-2.6720393102008178`, 
             3.0975309938295514`}, {-2.757945273008079, 
             3.19095365768715}, {-2.90142551504409, 3.346269229200531}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.9174504598650755`, 
             3.363610716729385}, {-3.060879351515729, 
             3.5182134046858713`}, {-3.1944495642349215`, 
             3.661727686884973}, {-3.318372585108284, 
             3.7944632973895684`}, {-3.434019745288941, 
             3.9179801717273945`}, {-3.5557115935182235`, 
             4.0476986228567755`}, {-3.5617872925486047`, 
             4.054167203645023}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.577952648195995, 
             4.071377883182146}, {-3.6717548185413547`, 
             4.171245719616741}, {-3.7827587193952072`, 
             4.28929975295749}, {-3.8828334053900138`, 
             4.395303910360431}, {-3.9806106128814673`, 
             4.498867313620051}, {-4.074567094277387, 
             4.598294235360854}, {-4.164702849577772, 
             4.693584675582837}, {-4.226068386358548, 4.758390441821262}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.242303308642494, 
             4.775535514342846}, {-4.251017878782624, 
             4.784738634286001}, {-4.4145855663115245`, 
             4.957272944605106}, {-4.567669964269889, 
             5.118533003787394}, {-4.711392084489968, 
             5.269740532661147}, {-4.849529549637737, 
             5.414775637095419}, {-4.893075875751071, 5.460031015173741}}]}, 
           {Arrowheads[{{0.005309204221801996, 1.}}], 
            ArrowBox[{{-4.909447714102109, 
             5.477045395043241}, {-4.957400816432662, 
             5.526880501002571}, {-5.057287257538334, 
             5.629446176488185}, {-5.084174677080968, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.2225905944890694`, -3.390753354179601}, {
             1.2739092666745941`, -3.5549277493842304`}, {
             1.334669453131231, -3.7592959726160196`}, {
             1.3862757313233072`, -3.941335910667964}, {
             1.4454128367194476`, -4.160533504076071}, {
             1.4809948127376205`, -4.299050383334076}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.4868694921123806`, -4.3219198904468215`}, {
             1.4954639718108969`, -4.35537729332059}, {
             1.5465965622712865`, -4.56500183745502}, {
             1.590190709889157, -4.753130544413779}, {
             1.627635760164686, -4.923467708748191}, {
             1.6603210585980506`, -5.079717625009584}, {
             1.6892437045780044`, -5.223813773990597}, {
             1.693122031994005, -5.243480346853342}}]}, 
           {Arrowheads[{{0.00841758689480118, 1.}}], 
            ArrowBox[{{1.697690428249691, -5.266646183099573}, {
             1.7160665109362048`, -5.359829282493184}, {
             1.7432223299626988`, -5.499552626199668}, {
             1.76861633084545, -5.631298149376069}, {
             1.7735390871533332`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5549052376812742`, 
             2.4643379583138607`}, {-1.6563682873111036`, 
             2.6201148405522585`}, {-1.7486278268544777`, 
             2.7585086186261436`}, {-1.833876387692241, 
             2.884561152908171}, {-1.9133530340672158`, 
             3.000852531524095}, {-1.9877018247914662`, 
             3.1085550107100284`}, {-2.057566818677057, 
             3.2088408467020826`}, {-2.084095279509318, 3.246571468732291}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.0976760465330235`, 
             3.2658869801255728`}, {-2.193191051067256, 
             3.4017350625711327`}, {-2.3161042456618532`, 
             3.5749531482083037`}, {-2.428845744316073, 
             3.73278042256363}, {-2.5340132078092075`, 
             3.879381970720147}, {-2.6332308429276563`, 
             4.017306951639479}, {-2.6459478677105137`, 4.034929916490111}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.6597648451455, 
             4.054077170807565}, {-2.726498649671419, 
             4.146555365321625}, {-2.813816628040496, 
             4.267127211766585}, {-2.896425905922056, 
             4.380896895521463}, {-2.975567611203267, 
             4.489738821133363}, {-3.0512417438841286`, 
             4.593652988602283}, {-3.1234483039646417`, 
             4.692639397928224}, {-3.215087095750268, 4.818051021912208}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.229017754266481, 
             4.83711572664742}, {-3.259758270505887, 
             4.879185443942564}, {-3.3867970750082685`, 
             5.052733460967776}, {-3.5056062983280882`, 
             5.214777621953818}, {-3.619791650354117, 
             5.370332746156058}, {-3.7251560960631425`, 
             5.513415133436982}, {-3.7881533759857478`, 
             5.5983027130851255`}}]}, 
           {Arrowheads[{{0.0010444395674875308`, 1.}}], 
            ArrowBox[{{-3.8022248391428715`, 
             5.617263729354141}, {-3.8236217274789572`, 
             5.646095610112856}, {-3.8316409474743596`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.1311556043996847`, -1.6248110712319863`}, {
             3.3213620136959623`, -1.7238022949838419`}, {
             3.4918363380130653`, -1.8128421409764792`}, {
             3.684568568101542, -1.913820411162836}, {
             3.858737844578104, -2.0052827895144976`}, {
             3.9679681779489293`, -2.0627431995920507`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9888651658151084`, -2.073736020497393}, {
             4.007593910386416, -2.0835882411223325`}, {
             4.147550798824594, -2.1572764178953894`}, {
             4.278608509892637, -2.2263473198336676`}, {
             4.4007670435905455`, -2.2908009469371677`}, {
             4.515950277229232, -2.35162479639687}, {
             4.626082088119607, -2.409806365403754}, {
             4.82417353582304, -2.5145324669576725`}}]}, 
           {Arrowheads[{{0.019452347010119955`, 1.}}], 
            ArrowBox[{{4.845045483724817, -2.5255727563922785`}, {
             5.019552006932792, -2.617903158629226}, {
             5.194620686686495, -2.7105811768403254`}, {
             5.357935212773288, -2.7970787761702574`}, {
             5.511745877966897, -2.878570707018102}, {
             5.5203329473690435`, -2.8831210552473086`}, {
             5.656854249492381, -2.955484759669807}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.4287961432129537`, -3.087862701639653}, \
{-3.545067794142161, -3.187578196691823}, {-3.654384915069267, \
-3.2811247537027066`}, {-3.7577304986877538`, -3.369397007589558}, \
{-3.8562596449356072`, -3.4534390013922454`}, {-3.950668509090455, \
-3.5338774278399363`}, {-4.12807423359021, -3.6847809483441885`}, \
{-4.147192474967069, -3.701007627973995}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.165194446776019, -3.7162868695888767`}, \
{-4.291845357125168, -3.8237823084500375`}, {-4.44387956463348, \
-3.9525562475052065`}, {-4.608300269243532, -4.091600115147703}, \
{-4.7618582326111945`, -4.22125341434985}, {-4.886327520951845, \
-4.3262114472242645`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.904378463342204, -4.341432803673547}, \
{-4.906596551201161, -4.343303193884034}, {-5.043650278604927, \
-4.458742258623796}, {-5.173882827882853, -4.568322030902159}, \
{-5.298157612095299, -4.672793933052142}, {-5.421872304509021, \
-4.77679571358597}, {-5.536641779870677, -4.873700727197927}, \
{-5.540003549443253, -4.876551713470671}, {-5.626222300752309, \
-4.950509829519336}}]}, 
           {Arrowheads[{{0.00035955482591306384`, 1.}}], 
            ArrowBox[{{-5.644047809027001, -4.965994457169211}, \
{-5.656854249492381, -4.977143551681329}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.068034004504615, -1.14538670523337}, {
             3.2560719130900924`, -1.214596540135666}, {
             3.4246416849231918`, -1.2768709920630037`}, {
             3.6153720353930785`, -1.3475551258933054`}, {
             3.7877494670035246`, -1.4115819685934974`}, {
             3.9344973835299104`, -1.4661805336340559`}, {
             3.9537441736423466`, -1.4733470740866117`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.975871991030978, -1.4815863647691618`}, {
             4.072503600260793, -1.517567135198698}, {
             4.201768117196174, -1.5657417732874237`}, {
             4.322290934336053, -1.610704447900233}, {
             4.544651325793413, -1.6937337976498636`}, {
             4.747124631196985, -1.7693950753993513`}, {
             4.8607192884435575`, -1.8118696263919456`}}]}, 
           {Arrowheads[{{0.017500316834789885`, 1.}}], 
            ArrowBox[{{4.882835778110655, -1.8201392756070778`}, {
             4.933106378955151, -1.8389361209055597`}, {
             5.105992097476295, -1.9036047739253525`}, {
             5.267294160181775, -1.9639599261990246`}, {
             5.419226221470249, -2.0208203487450045`}, {
             5.430969018695312, -2.0252154773500664`}, {
             5.5872652332822295`, -2.0837221742630225`}, {
             5.656854249492381, -2.109776528329961}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.013129956252794051`, 1.}}], 
            ArrowBox[{{0.25150266649987985`, 4.534099791612939}, {
             0.09707666133787757, 4.620966163325407}, {0.06506233981393503, 
             4.629086546109965}, {0.03240208866982947, 
             4.634203017381859}, {-0.0007478444651056876, 
             4.635580645093957}, {-0.03441942706572431, 
             4.640834328713951}, {-0.0888004876412885, 
             4.654122040085655}, {-0.1442960641519545, 
             4.6771209473722966`}, {-0.20068014828180372`, 
             4.709548860513202}, {-0.3020598892124148, 4.788386483599541}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.015229551659288607`, 1.}}], 
            ArrowBox[{{1.050600470283226, 4.9390335361396565`}, {
             1.05235353660986, 5.081263127419324}, {1.0481696683907689`, 
             5.325566410671523}, {1.0429396920514977`, 5.431200041903279}, {
             1.0359479415194115`, 5.528377075687192}, {1.0250657545499373`, 
             5.624639788243887}, {1.0203795782258787`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.4908483005321007`, -0.8312063572559223}, {
             3.685481293690292, -0.8771174653659922}, {
             3.8614030777596584`, -0.9187037258019614}, {
             4.0104312854950255`, -0.9539883209340182}, {
             4.150619506558114, -0.987204109556843}, {
             4.281967740948926, -1.0183510916704352`}, {
             4.404475988667459, -1.0474292672747956`}, {
             4.409938374293387, -1.0487268691388774`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.432911075557582, -1.0541840854587798`}, {
             4.630572619059639, -1.101139025089574}, {
             4.836509492706603, -1.1500932091349334`}, {
             5.025719998440103, -1.1950954927094684`}, {
             5.201637525091886, -1.2369495491117737`}, {
             5.351770218781556, -1.2726784737191925`}}]}, 
           {Arrowheads[{{0.0061409108809437445`, 1.}}], 
            ArrowBox[{{5.374740622438415, -1.27814535299497}, {
             5.520431388018461, -1.3128225453615494`}, {
             5.534099030803568, -1.3160759292132405`}, {
             5.656854249492381, -1.3453086543813733`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.476860104847354, -0.39991278593693363`}, {
             3.67095258401367, -0.4221365121239934}, {
             3.84638173121108, -0.4422753130896299}, {
             3.9948909015584517`, -0.4593569821643355}, {
             4.134592008260156, -0.47544092341378685`}, {
             4.26548505131619, -0.49052713683798377`}, {
             4.3875700307265575`, -0.5046156224369264}, {
             4.415157285910524, -0.507802797704797}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.438613260291975, -0.5105126831549381}, {
             4.612885892779991, -0.5306465246853309}, {
             4.818109688590158, -0.5543807446852829}, {
             5.006662652296243, -0.5762057723671292}, {
             5.181966018037428, -0.5965090976612168}, {
             5.345546349687932, -0.6154646741790099}, {
             5.376831048352419, -0.6190912727235239}}]}, 
           {Arrowheads[{{0.005469410773105818, 1.}}], 
            ArrowBox[{{5.400285973480826, -0.6218102248299391}, {
             5.4996387211069715`, -0.6333274375670228}, {
             5.514991050964698, -0.6351074467404899}, {
             5.656854249492381, -0.6515606736225258}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.031487506140407, -4.085960008242263}, {
             3.1229808301775095`, -4.2153834074018315`}, {
             3.208056334020035, -4.336107656426083}, {
             3.288117929111696, -4.449997800689573}, {
             3.3645695268962035`, -4.558918885566855}, {
             3.4374111273735575`, -4.6628709110579285`}, {
             3.506642730543758, -4.761853877162794}, {
             3.5743404037737987`, -4.85884379726082}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.58785481802815, -4.878205791494317}, {
             3.6367751558130994`, -4.948293571864665}, {
             3.7574660135546267`, -5.121618910323228}, {
             3.869820226158429, -5.283340052475357}, {
             3.977476170861649, -5.438588304185093}, {
             4.08566835816283, -5.5950226866952075`}, {
             4.126441617656264, -5.6540693287539}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.616960257244933, -2.656248533525909}, \
{-3.7923098059553992`, -2.781813833169519}, {-3.939961645149953, \
-2.8873728365154903`}, {-4.07897974805901, -2.986678910341076}, \
{-4.20936411468257, -3.079732054646275}, {-4.331114745020633, \
-3.1665322694310887`}, {-4.385481666498692, -3.205262405430047}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.4047128160627995`, -3.2189623725752305`}, \
{-4.446073375077402, -3.2484269814233695`}, {-4.5560817408570795`, \
-3.326763617350972}, {-4.661139842359665, -3.401542177213895}, \
{-4.761247679585158, -3.47276266101214}, {-4.949958256423549, \
-3.6069459111138}, {-5.125559166590931, -3.7317298783551576`}, \
{-5.174365923443436, -3.766388969863209}}]}, 
           {Arrowheads[{{0.012029262221584049`, 1.}}], 
            
            ArrowBox[{{-5.19361756875417, -3.780060120735242}, \
{-5.289548157058815, -3.8481832096862187`}, {-5.444121690715192, \
-3.9578800446161675`}, {-5.449463967401425, -3.9616701277742177`}, \
{-5.604808664293166, -4.071837904986261}, {-5.656854249492381, \
-4.108868431227462}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.604729467681997, 
             2.657632997655137}, {-3.7796090525300863`, 
             2.7832401880842395`}, {-3.9269135810455036`, 
             2.888864063762919}, {-4.065604296787645, 
             2.9882280011019287`}, {-4.195681199756509, 
             3.08133200010127}, {-4.317144289952097, 
             3.1681760607609415`}, {-4.372487529173115, 3.207713815494321}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.391700270179631, 
             3.221439586742331}, {-4.43183126802142, 
             3.2501095665304294`}, {-4.541579834611489, 
             3.3284819008592184`}, {-4.646389989722303, 
             3.403293063747308}, {-4.7462617333538635`, 
             3.474543055194699}, {-4.934528698362414, 
             3.6087866519923173`}, {-5.109719441820334, 
             3.7336398194770055`}, {-5.160619071359831, 3.769897131267032}}]}, 
           {Arrowheads[{{0.012399410296488566`, 1.}}], 
            ArrowBox[{{-5.179850717318848, 
             3.783596401577643}, {-5.273329071073651, 
             3.8501837981534157`}, {-5.427548193347001, 
             3.960001450949447}, {-5.43289124749594, 
             3.963805569790467}, {-5.591132472587739, 
             4.076438618326249}, {-5.656854249492381, 
             4.123207841364094}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.135852728017974, 
             1.1409189459685811`}, {-2.2681472889802112`, 
             1.2145588519346193`}, {-2.3865300783796286`, 
             1.2796618297148075`}, {-2.5339453427847327`, 
             1.3598533205935208`}, {-2.6660303169156783`, 
             1.431092722603222}, {-2.829407242324961, 
             1.51853515703929}, {-2.966049629148124, 
             1.5912273499663905`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.9869084232953567`, 
             1.6022924397518918`}, {-3.159670390649482, 
             1.6937003139828806`}, {-3.3244266949891035`, 
             1.7804931452952788`}, {-3.5109332158027375`, 
             1.8783658110851476`}, {-3.6796561555232685`, 
             1.966646018307447}, {-3.8230497133966863`, 
             2.0415034412643775`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.8439862754101, 
             2.052420701872639}, {-3.9596164160477074`, 
             2.112712506558397}, {-4.086801693812191, 
             2.1789396221881803`}, {-4.2054570699115175`, 
             2.2406293188208357`}, {-4.317418760266921, 
             2.2987709984592612`}, {-4.4245229807996385`, 
             2.3543540631063546`}, {-4.6241590123970076`, 
             2.457844347426547}, {-4.6821062114587475`, 
             2.4878471559961186`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.703074351070919, 
             2.4987036441272146`}, {-4.807671579005513, 
             2.5528600254095237`}, {-4.978367094927038, 
             2.6411609506833966`}, {-5.137719696913684, 
             2.7235266324499037`}, {-5.287887576044789, 
             2.8010970801196735`}, {-5.296566900535684, 
             2.805579089331105}, {-5.450853319578092, 
             2.8852096740248596`}, {-5.542140867476592, 2.932303835682894}}]}, 
           {Arrowheads[{{0.002233280174564139, 1.}}], 
            ArrowBox[{{-5.56312503216421, 
             2.943129316997786}, {-5.597292134815656, 
             2.960755719422824}, {-5.656854249492381, 
             2.9914777577206895`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.5013652772289343`, -4.199662851557925}, {
             2.5770555886827933`, -4.331682065110149}, {
             2.647458178160093, -4.454821202324475}, {
             2.7137366194058643`, -4.570980685403371}, {
             2.777054486165137, -4.682060936549305}, {
             2.8948084962241887`, -4.888983743042285}, {
             2.969284183991827, -5.020084894624573}}]}, 
           {Arrowheads[{{0.015003096258180406`, 1.}}], 
            ArrowBox[{{2.980947120277442, -5.040615411679286}, {
             3.002778967217406, -5.079046480405062}, {
             3.1030246580249474`, -5.255706007239283}, {
             3.1964527303865045`, -5.420507512229502}, {
             3.2857800960553245`, -5.578170439013606}, {
             3.330561581723069, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.899927155118615, -2.3170879317229445`}, \
{-4.051362034036475, -2.4038959160302897`}, {-4.193970271553589, \
-2.4855377652970145`}, {-4.327751867669955, -2.5620134795231193`}, \
{-4.452706822385574, -2.6333230587086036`}, {-4.570716260065453, \
-2.7005811165221525`}, {-4.6836613050745965`, -2.7649022666324505`}, \
{-4.7200213801433515`, -2.7855816638664823`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.740546067396552, -2.797254856510078}, \
{-4.894358217080679, -2.884733843743294}, {-5.088217727825155, \
-2.9948221531974957`}, {-5.268660006729357, -3.097171558151417}, \
{-5.4372173421353605`, -3.1926745442651936`}, {-5.562020288369526, \
-3.263325284459179}}]}, 
           {Arrowheads[{{0.0018085904461144708`, 1.}}], 
            ArrowBox[{{-5.582568253310845, -3.2749574532211283`}, \
{-5.596134660549785, -3.2826373737849086`}, {-5.603008788306129, \
-3.286527162778236}, {-5.656854249492381, -3.317103148270909}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.8889006579975063`, 
             2.325909560733063}, {-4.040017443595271, 
             2.4130866586251596`}, {-4.182323971000601, 
             2.4950728579508783`}, {-4.315820240213497, 
             2.571868158710218}, {-4.440506251233956, 
             2.6434725609031795`}, {-4.558260060833539, 
             2.7110064042660675`}, {-4.670959725783801, 
             2.775590028535188}, {-4.707720138369646, 2.7966276656991496`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.728213475474611, 
             2.8083558091003202`}, {-4.8811966217363665`, 
             2.8959066197921275`}, {-5.074630755074837, 
             3.006436348201377}, {-5.254675941782399, 
             3.109193227290318}, {-5.422861453432469, 
             3.2050738868928454`}, {-5.548447411084823, 3.276605541931971}}]}, 
           {Arrowheads[{{0.0021430950553494137`, 1.}}], 
            ArrowBox[{{-5.56896465172392, 
             3.288291818066547}, {-5.5814281333853515`, 
             3.295390808172271}, {-5.588282283198371, 
             3.2992931208768184`}, {-5.656854249492381, 
             3.3384711620534953`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.008971435422350892, 1.}}], 
            ArrowBox[{{-5.087027872267193, -5.358695035947787}, \
{-5.211339450180885, -5.482920259971112}, {-5.329893738330462, \
-5.600383474765498}, {-5.388009843457661, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.154233934750624, -4.517587540515945}, {
             2.2378697718081444`, -4.714547012308422}, {
             2.314185823190543, -4.895072954136294}, {
             2.3847911634955126`, -5.06258442409983}, {
             2.4503798572713076`, -5.218601398525979}, {
             2.5128626677607144`, -5.367494857839896}, {
             2.521362436531869, -5.387792364003151}}]}, 
           {Arrowheads[{{0.005678142909413858, 1.}}], 
            ArrowBox[{{2.5304827916123984`, -5.4095718345325565`}, {
             2.57613465829676, -5.51858880550412}, {
             2.634178925955244, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.155878272077581, -4.56900838846105}, \
{-2.2196539374573967`, -4.68391496084347}, {-2.339252010686964, \
-4.8988423583374665`}, {-2.4499019360141947`, -5.097178857786664}, \
{-2.5532599089101717`, -5.282181224174056}, {-2.6157766749806273`, \
-5.3939534733726076`}}]}, 
           {Arrowheads[{{0.005880051880923301, 1.}}], 
            ArrowBox[{{-2.62730294877989, -5.414561026008488}, \
{-2.6501062534598954`, -5.455330515754192}, {-2.7427553291977875`, \
-5.6208768139514955`}, {-2.7629490867870987`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.258733179424064, -1.9958056164369646`}, \
{-4.480044582615948, -2.096701764991802}, {-4.6817155743807755`, \
-2.1884783034640773`}, {-4.867090691687741, -2.272705504059778}, \
{-5.039514471506037, -2.350953638984889}, {-5.118499517872755, \
-2.3867574217259304`}}]}, 
           {Arrowheads[{{0.012015722727022272`, 1.}}], 
            ArrowBox[{{-5.140005177488571, -2.3965058994442634`}, \
{-5.200477414354589, -2.4239178581657064`}, {-5.352161565072296, \
-2.492614734340102}, {-5.3617112474567605`, -2.496937782009657}, \
{-5.517596972310032, -2.5674476442586065`}, {-5.656854249492381, \
-2.630694057127209}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.411135394102628, -1.5627060508011594`}, \
{-4.638961144565929, -1.6414553804650902`}, {-4.846601461505128, \
-1.7131217408476564`}, {-5.037488231373739, -1.7789214899787884`}, \
{-5.2150533406252775`, -1.840070985888415}, {-5.303994776113676, \
-1.8706733523087637`}}]}, 
           {Arrowheads[{{0.0074012646891171725`, 1.}}], 
            ArrowBox[{{-5.3263221019524964`, -1.8783555872845557`}, \
{-5.380827753382614, -1.8971095224766839`}, {-5.537053169574927, \
-1.950825958534431}, {-5.547887850648243, -1.9545500718008584`}, \
{-5.656854249492381, -1.9919812123385476`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.464362001789712, 
             2.1072088747544275`}, {-4.665396132419667, 
             2.199534218980934}, {-4.850178556244892, 
             2.284262944881406}, {-5.0220461387168545`, 
             2.362975777686679}, {-5.182485645861655, 
             2.4363723424762984`}, {-5.323013494287426, 2.500603322108342}}]}, 
           {Arrowheads[{{0.00727305502092786, 1.}}], 
            ArrowBox[{{-5.344489604013351, 
             2.510416727013864}, {-5.498595420907922, 
             2.5807653458891933`}, {-5.64465921407108, 
             2.6476044038035784`}, {-5.656854249492381, 
             2.6532272518525364`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.354807509594941, 
             1.5560051944849813`}, {-4.479854785382257, 
             1.5995977646026658`}, {-4.710794754370545, 
             1.6799874072011551`}, {-4.921312652561682, 
             1.753161999821406}, {-5.1148753504103786`, 
             1.8203583468332696`}, {-5.246911994233323, 
             1.8661524053767713`}}]}, 
           {Arrowheads[{{0.008686945102840623, 1.}}], 
            ArrowBox[{{-5.269220343085507, 
             1.8738895744214168`}, {-5.29494971837134, 
             1.8828132526065966`}, {-5.4630838139192495`, 
             1.9410757257939606`}, {-5.621544751014802, 
             1.99594899998163}, {-5.632010725616227, 
             1.9995720156840733`}, {-5.656854249492381, 
             2.008166847352936}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.004710427148794346, 1.}}], 
            ArrowBox[{{-0.24170296380675152`, -1.9637759442271645`}, \
{-0.2031725523343845, -1.9804756383343043`}, {-0.1658047311106075, \
-1.9939100164648624`}, {-0.1602249792489604, -1.9956763592704754`}, \
{-0.12403634048011028`, -2.0042649686879783`}, {-0.08811971167623259, \
-2.0101043285447546`}, {-0.027108930506219264`, -2.016126860200998}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.6364324675192099, -3.6792116105037462`}, \
{-0.6890025409639096, -3.794114403679944}, {-0.7443547741799292, \
-3.9128696129512544`}, {-0.8008802429727216, -4.033522829080997}, \
{-0.8617738055840171, -4.163457134239251}, {-0.9229504292244802, \
-4.293910478080907}, {-0.9839492169453699, -4.424115151494566}, \
{-1.0358021430779731`, -4.5350956844947525`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.0029968075987085313`, 1.}}], 
            ArrowBox[{{-0.019837014082914415`, 
             3.0453664262018525`}, {-0.03499834355170936, 
             3.0543437785168863`}, {-0.05174770053672846, 
             3.0682253659025576`}, {-0.06627822081863456, 
             3.0837610363021706`}, {-0.08216157872518168, 
             3.1025877319681916`}, {-0.11678452417262764`, 
             3.1469114867309327`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.0011806825627083079`, 1.}}], 
            ArrowBox[{{-5.367275196847357, 
             5.61799853720319}, {-5.407263007730282, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.301525583954285, 
             2.9831106721742504`}, {-3.425911254375335, 
             3.0902310721214086`}, {-3.542281114432957, 
             3.1901976188528476`}, {-3.6516796776113085`, 
             3.283969712126759}, {-3.755093629901161, 
             3.3724469142245366`}, {-3.8536822036642158`, 
             3.4566788048297323`}, {-3.9481438835335396`, 
             3.5372952538679936`}, {-4.018835549941936, 
             3.5975256070797994`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.036808573075559, 
             3.6128388906197326`}, {-4.125637509208717, 
             3.6885224679146877`}, {-4.289476402162138, 
             3.8278098377065692`}, {-4.441562457629246, 
             3.9568386445855874`}, {-4.606593178799251, 
             4.096626121461689}, {-4.757024671624616, 4.2238457889291485`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.775061527295485, 
             4.239083833893765}, {-4.905883293077309, 
             4.349576838143536}, {-5.043354766895188, 
             4.465554253035521}, {-5.1739639356319165`, 
             4.5756273690092435`}, {-5.298581825859747, 
             4.680555495268798}, {-5.421797831281127, 
             4.78431097675888}, {-5.497065300040258, 4.847977911505722}}]}, 
           {Arrowheads[{{0.003959152172466937, 1.}}], 
            ArrowBox[{{-5.515092842584879, 
             4.863226974530644}, {-5.536057923663449, 
             4.880960830484576}, {-5.539405253449559, 
             4.883804940562084}, {-5.628241994740588, 
             4.960163334818869}, {-5.656854249492381, 
             4.985126965710013}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.349321874769512, -0.20363558242360622`}, \
{-4.473961666888635, -0.20930117931171674`}, {-4.704040800458518, \
-0.21973932719365719`}, {-4.91367918736725, -0.22923130515199489`}, \
{-5.106358494154607, -0.2379401403572198}, {-5.28556038736037, \
-0.24602885997982188`}, {-5.292834900268348, -0.2463567932905523}}]}, 
           {Arrowheads[{{0.007216174295243621, 1.}}], 
            ArrowBox[{{-5.316422937803254, -0.24742013640923338`}, \
{-5.452836290376424, -0.25356961788009524`}, {-5.610457430128949, \
-0.26066792669793465`}, {-5.624331811430964, -0.26129241632866346`}, \
{-5.656854249492381, -0.2627548776211205}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.385231238996673, 3.3114537987850836`}, {
             2.503231481964078, 3.4832632509411274`}, {2.6365706275724854`, 
             3.678534553588933}, {2.756485951626034, 3.854886830504611}, {
             2.855853965934674, 4.001481366077918}, {2.917084520136132, 
             4.091946563217256}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.9303195096540526`, 4.111500623301972}, {
             2.949224649597752, 4.139432057767297}, {3.036598002615268, 
             4.2687389055727465`}, {3.117974024987222, 4.389401909494267}, {
             3.1946589446799956`, 4.5032666503389835`}, {3.26795898965997, 
             4.612178708914023}, {3.404404455481524, 4.815144779255068}, {
             3.457934800794907, 4.894867156054135}}]}, 
           {Arrowheads[{{0.018937426093435454`, 1.}}], 
            ArrowBox[{{3.471097350497868, 4.914470051214116}, {
             3.5296424026736015`, 5.001660796611904}, {3.6460048114579218`, 
             5.175087437079032}, {3.754524832373565, 5.33692876731109}, {
             3.858576835625417, 5.492149739660191}, {3.9498147811242825`, 
             5.627542036352812}, {3.9697334599345746`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8376446212130364`, 3.3207168909178852`}, {
             1.9292807978852105`, 3.493205546726036}, {2.032327699533361, 
             3.689703527350244}, {2.124356678289333, 3.8669938475767167`}, {
             2.200121393664835, 4.014124795010056}, {2.2710616270529522`, 
             4.152484424368399}, {2.274038654078418, 4.158319462112079}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.2847695100852925`, 4.17935217336612}, {
             2.337177378453685, 4.282072735651748}, {2.3984686478670323`, 
             4.402889728860099}, {2.456007138850035, 4.516811246427021}, {
             2.5108645549597344`, 4.625713130786076}, {2.6125361625592203`, 
             4.828457999880591}, {2.70536852065111, 5.014542993782585}, {
             2.7095319101967834`, 5.022922493104264}}]}, 
           {Arrowheads[{{0.014473560638981631`, 1.}}], 
            ArrowBox[{{2.7200382649496, 5.044068242633286}, {
             2.7912466792210218`, 5.187386770130999}, {2.8709971300908435`, 
             5.348517856401501}, {2.946977193634358, 5.502510269970874}, {
             3.0227976602286883`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.009469484859151807, 1.}}], 
            ArrowBox[{{-0.28344241830240746`, 
             1.2739366271439285`}, {-0.2294368940594283, 
             1.2858084345232157`}, {-0.17486144256290462`, 
             1.2934872692841437`}, {-0.11961939424020947`, 
             1.2982589825231516`}, {-0.086493417149511, 
             1.299997244502515}, {-0.05323812908312651, 
             1.3009058567704874`}, {0.03267794239470864, 1.300405747330083}, {
             0.03848579445350517, 1.3002550360304808`}, {0.07150649598406757, 
             1.2994082207724258`}, {0.10452704038018404`, 
             1.2985751409117745`}, {0.16161176793163212`, 
             1.2971763022453067`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01294338339643543, 1.}}], 
            ArrowBox[{{-5.052216373051789, 
             0.761836411087558}, {-5.2297057036025585`, 
             0.7881574402265702}, {-5.3953742044910165`, 
             0.8127066858262695}, {-5.551474510282139, 
             0.8358246743388839}, {-5.565054795712206, 
             0.8378352809784994}, {-5.656854249492381, 
             0.8514194325764405}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012775550721294528`, 1.}}], 
            ArrowBox[{{-5.059595055419489, -0.7356137945142175}, \
{-5.237321350165952, -0.7610050551856392}, {-5.4032124716287555`, \
-0.784686679974207}, {-5.559523554363343, -0.8069872582404559}, \
{-5.573098866194072, -0.8089234249317611}, {-5.656854249492381, \
-0.8208624730914881}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sca\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(sca\\)]\\)}\"", 
           TraditionalForm]}}], {583.2, -192.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.5406056949254805`}, \
{-5.511312994300675, -2.534748543569309}, {-5.352203272978967, \
-2.5285261961043166`}, {-5.1921832354948485`, -2.522437348460743}, \
{-5.03125288184832, -2.516482000638588}, {-4.869412212039381, \
-2.5106601526378522`}, {-4.713039502623332, -2.5052112337397463`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689441106362918, -2.5044101435243964`}, \
{-4.543533802943005, -2.499504254188001}, {-4.3796295334077495`, \
-2.494192028260726}, {-4.215081887214449, -2.489056951198552}, \
{-4.049859729701197, -2.484096397367122}, {-3.883931926206086, \
-2.4793077411320796`}, {-3.7454067022247175`, -2.4754697510616888`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7218037666085984`, -2.474815806387043}, \
{-3.717298476729116, -2.4746909824934247`}, {-3.549959381270287, \
-2.470246121451157}, {-3.4151924611755278`, -2.4668039245755446`}, \
{-3.2800135886956188`, -2.463480709110332}, {-3.0854264018880686`, \
-2.4589353232659295`}, {-2.8901503761852725`, -2.454652811298459}, \
{-2.7775933032440627`, -2.452344036719495}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7539862759762292`, -2.4518598085584684`}, \
{-2.69418551158723, -2.45063317320792}, {-2.4975318080939406`, \
-2.4468764089943122`}, {-2.4717381081787684`, -2.4464017313555955`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.336825357213909, \
-2.444053256271173}, {-2.227582362199846, -2.4422634060844444`}, \
{-2.101272705093369, -2.4402539337156144`}, {-1.974837575071162, \
-2.4383624056511684`}, {-1.8482769721332266`, -2.4365888218911067`}, \
{-1.8096403515601125`, -2.4360838862616476`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7860303747026274`, -2.435775331363491}, \
{-1.7215908962795614`, -2.434933182435429}, {-1.594779347510167, \
-2.4333954872841352`}, {-1.4678423258250435`, -2.431975736437225}, \
{-1.3407798312241908`, -2.430673929894699}, {-1.2135918637076086`, \
-2.429490067656557}, {-1.0862784232752971`, -2.428424149722799}, \
{-0.9588395099272564, -2.427476176093425}, {-0.841596067434252, \
-2.4267133025494663`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8179844995799191, -2.4265720292591415`}, \
{-0.7035852644839873, -2.425934061747829}, {-0.5757699323887587, \
-2.4253399210316067`}, {-0.4478291273778013, -2.424863724619769}, \
{-0.3197628494511146, -2.4245054725123145`}, {-0.19157109860869825`, \
-2.424265164709244}, {-0.05426103571853691, -2.4241403547556555`}, {
             0.08300619914120178, -2.4241542636310207`}, {
             0.12649036372911768`, -2.4242026288480303`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15010234212192897`, -2.4242288912465337`}, {
             0.22023060597051713`, -2.42430689133534}, {
             0.35741218476941017`, -2.424598237868613}, {
             0.4945509355378805, -2.42502830323084}, {
             0.6316468582759276, -2.4255970874220214`}, {
             0.7686999529835524, -2.4263045904421565`}, {
             0.9057102196607545, -2.427150812291246}, {
             1.0426112901862568`, -2.4281335802624753`}, {
             1.0945701538662478`, -2.428558119901101}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1181813587337657`, -2.428751039677863}, {
             1.179336796438783, -2.429250721649031}, {
             1.3158867384183321`, -2.4305022364509123`}, {
             1.4522611161249046`, -2.4318881246681197`}, {
             1.5884599295585013`, -2.4334083863006537`}, {
             1.724483178719121, -2.435063021348513}, {
             1.860330863606764, -2.436852029811699}, {
             1.9960029842214313`, -2.438775411690211}, {
             2.062594286809071, -2.439808525509626}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0862034387131785`, -2.440174803689343}, {
             2.1322598409574782`, -2.440889334022617}, {
             2.2671065390497755`, -2.443046424359759}, {
             2.401749072227302, -2.4453357752455727`}, {
             2.536173140169162, -2.44775633024673}, {
             2.6703644425544564`, -2.4503070329299046`}, {
             2.8043086790622898`, -2.452986826861769}, {
             2.937991549371765, -2.455794655608995}, {
             3.03051619704374, -2.457830092886034}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0541224786016903`, -2.4583494042983363`}, {
             3.0713987531619846`, -2.4587294627382565`}, {
             3.2044112021273445`, -2.4617853913885965`}, {
             3.3371105126331653`, -2.4649607259611086`}, {
             3.4694813787823082`, -2.468253826662074}, {
             3.601508494677633, -2.471663053697775}, {
             3.7331765544220006`, -2.4751867672744927`}, {
             3.864470252118272, -2.4788233275985094`}, {
             3.9953742818693074`, -2.482571094876106}, {
             3.998287561424809, -2.482657206560801}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.021889246336786, -2.483354833002304}, {
             4.125873337777969, -2.4864284293135652`}, {
             4.255952113947116, -2.4903936911171685`}, {
             4.385595304479612, -2.494465240493197}, {
             4.514787603478314, -2.4986414376479327`}, {
             4.643513705046083, -2.502920642787658}, {
             4.7717583032857815`, -2.5073012161186536`}, {
             4.899506092300272, -2.511781517847202}, {
             4.965864338313311, -2.5141693226406714`}}]}, 
           {Arrowheads[{{0.01414296259282904, 1.}}], 
            ArrowBox[{{4.989461059554642, -2.515018416272217}, {
             5.026741766192412, -2.516359908179585}, {
             5.1534500190650645`, -2.5210347473220835`}, {
             5.279485365782822, -2.525795864317432}, {
             5.404627933074127, -2.5306282132577653`}, {
             5.528750832837611, -2.535522841923467}, {
             5.651727176971904, -2.540470798094921}, {
             5.656854249492381, -2.5406834968510954`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.541327997760137}, {-5.493135721953781, 
             2.534757143107525}, {-5.335322938556127, 
             2.528601705224157}, {-5.176621937617196, 
             2.5225786611068477`}, {-5.017032719136988, 
             2.516688010755597}, {-4.856555283115502, 
             2.510929754170405}, {-4.713039233869085, 2.505940749434661}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689441252132533, 
             2.505127534319824}, {-4.533446093708006, 
             2.499893593814283}, {-4.370941924136823, 
             2.4946364829223744`}, {-4.207804704654016, 
             2.489553351554567}, {-4.044003887920054, 
             2.484641651932145}, {-3.8795089265954026`, 
             2.479898836276392}, {-3.7454068784253742`, 
             2.4761856761118817`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7218039316976177`, 
             2.4755321326145934`}, {-3.7143198206800623`, 
             2.4753249045873083`}, {-3.548436570174033, 
             2.470919856864893}, {-3.4137112228597464`, 
             2.467478961280519}, {-3.2785758608533784`, 
             2.4641572114648973`}, {-3.0840021505383923`, 
             2.459612944587385}, {-2.888738964100607, 
             2.455331490242708}, {-2.7775936733130235`, 2.453052097317336}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753986644202684, 
             2.45256795899027}, {-2.692786301540022, 
             2.4513128484308653`}, {-2.496144162856638, 
             2.447557019151857}, {-2.4703524670333374`, 
             2.4470824696924187`}, {-2.444546998600464, 
             2.446612201231679}, {-2.3354877643520204`, 
             2.444735490842686}, {-2.226290728434438, 
             2.442946927042012}, {-2.027118072428805, 
             2.4398333223404696`}, {-1.8275784036895666`, 
             2.4370110879166984`}, {-1.8096408308037686`, 
             2.4367839941560074`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7860307298596547`, 
             2.4364850848973343`}, {-1.6276717222167232`, 
             2.4344802237706986`}, {-1.4273980280102743`, 
             2.43224072990247}, {-1.2267573210702198`, 
             2.4302926063120123`}, {-1.0257496013965604`, 
             2.428635852999326}, {-0.8415967391855209, 
             2.427387239576538}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8179852325963006, 
             2.427236453449907}, {-0.6226331238484252, 
             2.4261964572072667`}, {-0.4710990209844548, 
             2.42558456854329}, {-0.31956279892376194`, 
             2.425142213274926}, {-0.16802445766634688`, 
             2.4248693914021744`}, {-0.0164839972122095, 
             2.4247661029250356`}, {0.12648954354708564`, 
             2.424828601996738}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1501015175197435, 2.4248557521453384`}, {
             0.28660328128623214`, 2.4250681261575964`}, {0.4381500993305367, 
             2.4254734378672955`}, {0.5896990365715633, 
             2.4260482829726078`}, {0.7411656956338584, 2.426791364674479}, {
             0.8924656791419686, 2.4277013861738577`}, {1.0435989870958937`, 
             2.4287783474707427`}, {1.0945693132579082`, 
             2.429198321364885}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1181805047802829`, 2.4293928675802157`}, {
             1.194565619495633, 2.4300222485651344`}, {1.3453655763411867`, 
             2.4314330894570326`}, {1.495998857632556, 2.4330108701464375`}, {
             1.6464654633697404`, 2.434755590633349}, {1.7967653935527386`, 
             2.436667250917767}, {1.9481117505654844`, 2.4388330098192514`}, {
             2.0625926590916177`, 2.4405141787840465`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.086202106496355, 2.440860886988618}, {
             2.0973215667109506`, 2.4410241778958857`}, {2.2463190733567546`, 
             2.44337900706835}, {2.3950814535301577`, 2.445895857985807}, {
             2.543585890258421, 2.4485730912974177`}, {2.6918095665688058`, 
             2.451409067652345}, {2.8397296654885738`, 2.45440214769975}, {
             2.9873233700449875`, 2.457550692088795}, {3.0305147707450852`, 
             2.4585185912604994`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.05412083715455, 2.459047592213341}, {
             3.1345709069130394`, 2.460850440804047}, {3.281452989751357, 
             2.464296714523737}, {3.4279475320626593`, 2.467887244937525}, {
             3.574032447349664, 2.4716197637350694`}, {3.7196856491150863`, 
             2.4754920026060296`}, {3.8648850508616435`, 2.479501693240065}, {
             3.9982867478546145`, 2.4833223110305935`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.02188869798754, 2.484010801117518}, {
             4.153834108309032, 2.487924356555996}, {4.297539591015296, 
             2.49233279261721}, {4.440702927713564, 2.4968696072001357`}, {
             4.583302031906552, 2.5015325319944313`}, {4.725314817096977, 
             2.5063192986897564`}, {4.866719196787555, 2.5112276389757704`}, {
             4.965865681474388, 2.5147685895904295`}}]}, 
           {Arrowheads[{{0.014142935937732673`, 1.}}], 
            ArrowBox[{{4.9894626301534934`, 2.5156113388839954`}, {
             5.0074930844810055`, 2.5162552845421318`}, {5.147614393680042, 
             2.5213999670784997`}, {5.2870610378873835`, 
             2.5266594182745337`}, {5.424944477705057, 2.5319942372252005`}, {
             5.5598810577918405`, 2.537343804399929}, {5.656854249492381, 
             2.541282752932847}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.376283275407309}, {-5.460535168844498, 
             4.362059158185276}, {-5.2538710908085156`, 
             4.347617500494767}, {-5.045716135515288, 
             4.333611606926242}, {-4.83611660504006, 
             4.320056619767851}, {-4.71453535272136, 4.312514505572886}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690968660371194, 
             4.311052580469198}, {-4.6251188014580755`, 
             4.306967681307745}, {-4.412769026844581, 
             4.294359933834073}, {-4.199113583274819, 
             4.2822485196349875`}, {-3.984198772824036, 
             4.270648580998637}, {-3.768006922489746, 
             4.259581565053311}, {-3.7479518022437155`, 4.258611845738155}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.724367363171664, 
             4.257471474310575}, {-3.550543622934095, 
             4.249066626258154}, {-3.3318900717292705`, 
             4.239115467897605}, {-3.1121274664474594`, 
             4.2297397932561065`}, {-2.8913370046608504`, 
             4.2209513056180965`}, {-2.7807671860044216`, 
             4.216867540613254}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7571712811858897`, 
             4.215996053877304}, {-2.669599883941631, 
             4.212761708268016}, {-2.446997301861989, 
             4.205182704490307}, {-2.2236104559941112`, 
             4.1982259975694065`}, {-2.069035476140791, 
             4.193799050811214}, {-1.9141717642209264`, 
             4.189687031037946}, {-1.8131367431633876`, 4.187215279602089}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7895318129096074`, 
             4.1866378014203915`}, {-1.7590419555879242`, 
             4.1858918882922005`}, {-1.6034272418255078`, 
             4.182394772162184}, {-1.44764829044029, 
             4.179223308251389}, {-1.2916485130487514`, 
             4.176372621453318}, {-1.135427909650891, 
             4.173842711767969}, {-0.9789864802467092, 
             4.171633579195342}, {-0.8452046020730251, 
             4.170023286169843}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8215943013380711, 
             4.169740737123171}, {-0.6656510538953255, 
             4.168190804335902}, {-0.5088095345671099, 
             4.166960451785998}, {-0.35185214447054447`, 
             4.1660574558226395`}, {-0.3116508958297744, 
             4.165879003153829}, {-0.27144602630106673`, 
             4.165722203963496}, {-0.12317367708081581`, 4.165330909835761}, {
             0.025094561174700714`, 4.165233680665486}, {0.12286895690868357`,
              4.165363486172068}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14648092909828472`, 4.165394833479187}, {
             0.17335868846548275`, 4.1654305164526715`}, {0.3216187047915304, 
             4.165921417197316}, {0.33967017167167923`, 4.165999090128927}, {
             0.3577208959661671, 4.16608112907948}, {0.40065128185795107`, 
             4.1663113769707785`}, {0.4435770178293942, 
             4.1665663569168165`}, {0.611127127931116, 4.167748288014785}, {
             0.7785234709239464, 4.169302664233143}, {0.9457660468078851, 
             4.17122948557189}, {1.0909218573635147`, 4.173226937639482}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1145315597614285`, 4.1735555479342015`}, {
             1.279725114421894, 4.176195554771819}, {1.4463120404975767`, 
             4.179224984955532}, {1.6126156338099804`, 4.182617042582168}, {
             1.778635894359105, 4.186371727651726}, {1.9444466922986006`, 
             4.190497829373902}, {2.058792826888315, 4.193576715093578}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0823962650689656`, 4.194212261620887}, {
             2.1096294300911147`, 4.194945542227084}, {2.2744697389974293`, 
             4.199748851155431}, {2.438938070956084, 4.204904240475064}, {
             2.567157212949006, 4.209172097563038}, {2.695112515248817, 
             4.213645038985868}, {2.8227893694834334`, 4.218320719844363}, {
             2.9501731672807705`, 4.22319679523933}, {3.026326639759404, 
             4.226237588438734}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0499198318828276`, 4.227179659966481}, {
             3.077249300268746, 4.228270920271577}, {3.204003160075273, 
             4.233540750041914}, {3.3304201383282703`, 4.239003939651148}, {
             3.4564856266556525`, 4.244658144200088}, {3.5821850166853357`, 
             4.2505010187895405`}, {3.707503700045235, 4.256530218520314}, {
             3.832427068363268, 4.262743398493218}, {3.9569405132673494`, 
             4.26913821380906}, {3.993373257491014, 4.271068383939655}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.016952183320295, 4.2723175717051385`}, {
             4.081029426385395, 4.275712319568648}, {4.204679199345321, 
             4.28246337087279}, {4.327875223775044, 4.289389022822295}, {
             4.450602891302479, 4.29648693051797}, {4.694631678901405, 
             4.311164777167288}, {4.936722608643939, 4.326427438859652}, {
             4.959786564063328, 4.3279478052614}}]}, 
           {Arrowheads[{{0.014296095679757865`, 1.}}], 
            ArrowBox[{{4.983347421971383, 4.329500927269676}, {
             5.176871006757553, 4.3422579219353565`}, {5.415128957564976, 
             4.358679032844183}, {5.651500771156397, 4.375692424960325}, {
             5.656854249492381, 4.376094410273262}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.3693221130258815`}, \
{-5.603572178397411, -4.3653688740560375`}, {-5.39064358267865, \
-4.35016685679128}, {-5.176231886443473, -4.335466811738689}, \
{-4.960384906437659, -4.321288174013187}, {-4.743102642661206, \
-4.307630943614775}, {-4.714511782249149, -4.3059138226611}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.690942258740125, -4.304498275101418}, \
{-4.524385095114116, -4.294495120543454}, {-4.30423226379639, \
-4.281880704799223}, {-4.082644148708026, -4.269787696382081}, \
{-3.8596207498490234`, -4.258216095292029}, {-3.747888802409233, \
-4.252715485316696}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7243053709147436`, -4.251554463232113}, \
{-3.635162067219384, -4.247165901529068}, {-3.409492749725439, \
-4.236701020812507}, {-3.1828374462735187`, -4.226885358861659}, \
{-2.9551961568636242`, -4.217718915676522}, {-2.7806940911866826`, \
-4.21121805853849}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.757098466014273, -4.210339032907858}, \
{-2.726568881495756, -4.209201691257096}, {-2.4969556201699126`, \
-4.201333685603382}, {-2.2663563728860936`, -4.194114898715379}, \
{-2.0347711396443007`, -4.187545330593089}, {-1.8130526405321368`, \
-4.18190124884438}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7894476703375548`, -4.18132588706855}, \
{-1.7189766191863294`, -4.179673043042404}, {-1.6356706674507846`, \
-4.177811336745257}, {-1.4889395381306476`, -4.174757092085135}, \
{-1.3420038493593605`, -4.171986371313065}, {-1.1948636011369231`, \
-4.169499174429049}, {-1.0475187934633357`, -4.167295501433086}, \
{-1.0285728984095224`, -4.167030560625578}, {-1.0096244893607684`, \
-4.166770392901004}, {-0.9460470836068825, -4.165967523849967}, \
{-0.8824424422568995, -4.165218124010164}, {-0.8451187725133211, \
-4.164820613867847}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8215081185550651, -4.164569152141826}, \
{-0.7134751332458755, -4.1634185630475535`}, {-0.5444657428815807, \
-4.16200098291379}, {-0.37541427116401505`, -4.1609653836088745`}, \
{-0.20632071809317887`, -4.160311765132806}, {-0.03718508366907214, \
-4.160040127485586}, {0.12295484209485533`, -4.160144575928061}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14656677148941388`, -4.160192872318031}, {
             0.3012124292389533, -4.160642794677688}, {
             0.47047430772287213`, -4.1615170995170105`}, {
             0.6396428230625084, -4.162769206924329}, {
             0.8085825307603092, -4.1643949386387895`}, {
             0.9772934308162744, -4.1663942946603925`}, {
             1.0910079981233816`, -4.167995903635241}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.114617649488387, -4.168328432970881}, {
             1.1457755232304039`, -4.168767274989139}, {
             1.3140288080026976`, -4.171513879625027}, {
             1.4820532851331558`, -4.174634108568059}, {
             1.649848954621778, -4.178127961818234}, {
             1.8174158164685652`, -4.181995439375551}, {
             1.9862985022842257`, -4.186408895926322}, {
             2.058877536891689, -4.188377823224368}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0824808462856805`, -4.18901813485763}, {
             2.152444169880159, -4.190916103030288}, {
             2.318302924569904, -4.195790450879531}, {
             2.483845713721284, -4.201028697693114}, {
             2.649043484702123, -4.206627601690106}, {
             2.8138671848802446`, -4.212583921089571}, {
             2.9782877616234726`, -4.218894414110577}, {
             3.0264171741653416`, -4.220849494250143}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.050009710265705, -4.221807854145596}, {
             3.1422761622996305`, -4.2255558389721894`}, {
             3.275998551879442, -4.231252461286431}, {
             3.409371101125008, -4.2371620238828624`}, {
             3.5423750819565853`, -4.2432807879428065`}, {
             3.6749917662944296`, -4.249605014647586}, {
             3.8072024260587964`, -4.2561309651785235`}, {
             3.9389883331699416`, -4.26285490071694}, {
             3.993461916119724, -4.265724180328801}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.017041222200034, -4.266966169904931}, {
             4.070330759548121, -4.269773082444159}, {
             4.20121097711359, -4.276881771541501}, {
             4.331610257786606, -4.28417722919029}, {
             4.461509873487422, -4.2916557165718485`}, {
             4.590891096136296, -4.299313494867498}, {
             4.719735197653483, -4.3071468252585605`}, {
             4.848023449959238, -4.315151968926359}, {
             4.9598924525667165`, -4.322311184724734}}]}, 
           {Arrowheads[{{0.014293805450128646`, 1.}}], 
            ArrowBox[{{4.983455449053074, -4.323831415457377}, {
             5.10285749461748, -4.3316627408174515`}, {
             5.229365830810477, -4.340160891403391}, {
             5.355284370505244, -4.348820648492759}, {
             5.480658759244035, -4.357645735197657}, {
             5.605505381831827, -4.366636482843466}, {
             5.656854249492381, -4.370418099553683}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.0003864859356329797}, {-5.605325356244599, 
             0.0003861692591299577}, {-5.381407981851238, 
             0.00038484452433847153`}, {-5.155968680445485, 
             0.0003835631666651788}, {-4.929045827131806, 
             0.0003823267221612424}, {-4.712374529588443, 
             0.0003811976769879919}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688762536590781, 
             0.00038107710014673114`}, {-4.5321870469250465`, 
             0.0003802935600237211}, {-4.362959243292901, 
             0.0003794768144884722}, {-4.140519160651131, 
             0.0003784501057882934}, {-3.9169452324238954`, 
             0.0003774720913494177}, {-3.744282816681917, 
             0.00037675801428775266`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7206708236841495`, 
             0.0003766603625636792}, {-3.692237458611193, 
             0.000376542771171845}, {-3.4663958392130256`, 
             0.0003756621452555754}, {-3.4365800184983457`, 
             0.0003755493816005175}, {-3.4067463592295093`, 
             0.00037543750597576953`}, {-3.2670141749555466`, 
             0.0003749389650169995}, {-3.126916588528299, 
             0.0003744602491483866}, {-2.930237798822244, 
             0.000373809867199827}, {-2.7761911037712683`, 
             0.00037333427243228627`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752579110773411, 
             0.000373261374144418}, {-2.7330178946265673`, 
             0.00037320098198837014`}, {-2.5352568759412684`, 
             0.00037263359351401607`}, {-2.3369547427663466`, 
             0.00037210770177676473`}, {-2.1381114951018034`, 
             0.0003716233067766161}, {-1.9387271329476377`, 
             0.00037118040851357034`}, {-1.80809939085758, 
             0.00037091813991286133`}}]}, 
           {Arrowheads[{{0.0168774269632949, 1.}}], 
            ArrowBox[{{-1.784487397859658, 
             0.0003708707327980752}, {-1.7388016563038498`, 
             0.0003707790069876273}, {-1.5383350651704397`, 
             0.00037041910219878695`}, {-1.3009837892384037`, 
             0.0003701414952165304}, {-1.0636325133063673`, 
             0.0003698638882342739}, {-1.0584884273312694`, 
             0.0003698578864745869}, {-1.036296359501513, 
             0.0003698323268790148}, {-1.0161191182724092`, 
             0.00036980955674517944`}, {-0.9993240590830063, 
             0.00036979077244645293`}, {-0.9923382312457297, 
             0.0003697829268335679}, {-0.9874680232983247, 
             0.00036977741024229023`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0288490397368746`, 0.0008499518104741905}, {
             1.1700172278656646`, 0.0008503142518874442}, {
             1.3461855680171075`, 0.0008508667537814877}, {
             1.5221164597001033`, 0.0008514955783717411}, {1.697763409254558, 
             0.0008521998011302828}, {1.873100586869308, 
             0.0008529789084304896}, {1.973328759648866, 
             0.0008534675980937301}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.9969407526465548`, 0.0008535827247750462}, {
             2.0480980081377935`, 0.0008538321558607879}, {
             2.2227256886534534`, 0.0008547587990096042}, {2.331775414441622, 
             0.0008553756009872962}, {2.440662008241045, 
             0.0008560205870200982}, {2.670669739463428, 
             0.0008574767506169317}, {2.899790578933497, 
             0.0008590535489605626}, {2.9414204725474278`, 
             0.000859363160916531}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.9650324655447444`, 0.0008595387692282891}, {
             3.128024526651252, 0.0008607509820509908}, {3.355371582616692, 
             0.0008625690498882165}, {3.385255627513307, 
             0.0008628164401696904}, {3.41512216641045, 
             0.0008630658317356592}, {3.554347725760219, 
             0.0008642849087025278}, {3.6931679619021587`, 
             0.0008655465371984417}, {3.895547236484798, 
             0.0008674309465459551}, {3.9095121854291746`, 
             0.0008675672550074419}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.933124178426019, 0.0008677977259136269}, {
             4.096914779324318, 0.0008693964460309272}, {4.297270590420718, 
             0.0008714430356533578}, {4.496614669773998, 
             0.0008735707154132471}, {4.694947017384159, 
             0.000875779485310595}, {4.877603898290592, 
             0.0008778991760982615}}]}, 
           {Arrowheads[{{0.016001155817980024`, 1.}}], 
            ArrowBox[{{4.901215891286921, 0.000878177419282177}, {
             5.088576517375122, 0.0008804402955176667}, {5.283873669755923, 
             0.0008828923358273903}, {5.4780905801492095`, 
             0.0008854195761232389}, {5.656854249492381, 
             0.0008878237469269954}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.2156439935837364`}, {-5.440892529948433, 
             1.2116010958299965`}, {-5.2057531684585365`, 
             1.2073755399354689`}, {-4.968919687186176, 
             1.2032984788803454`}, {-4.837654972623195, 
             1.2011185776114248`}, {-4.712519865637228, 
             1.1990961221228364`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688910834307729, 
             1.198722183142573}, {-4.573700480827438, 
             1.1969118749785999`}, {-4.441043762162898, 
             1.1948876040047531`}, {-4.307956100699407, 
             1.1929177401859883`}, {-4.174454025721084, 
             1.1910035487173343`}, {-4.040554066512045, 
             1.1891462947938196`}, {-3.904862253445042, 
             1.1872392803013565`}, {-3.769684421654475, 
             1.18545899994645}, {-3.74452910941451, 1.185139634998635}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7209190190942274`, 
             1.1848398877646862`}, {-3.6341417642014284`, 
             1.1837381875267403`}, {-3.4982342810859013`, 
             1.1820768430422277`}, {-3.361961972307893, 
             1.1804749664929117`}, {-3.2253248378674035`, 
             1.1789325578787926`}, {-3.0883228777644343`, 
             1.1774496171998703`}, {-2.950956091998984, 
             1.1760261444561448`}, {-2.813224480571053, 
             1.1746621396476165`}, {-2.7764983554498093`, 
             1.1743156442358818`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7528874132478514`, 
             1.1740928850116863`}, {-2.675172046733854, 
             1.1733596734945584`}, {-2.536842793740599, 
             1.1721208167172443`}, {-2.3982367215912888`, 
             1.1709455693156743`}, {-2.259353830285922, 
             1.1698339312898485`}, {-2.1201941198245002`, 
             1.1687859026397667`}, {-1.9807575902070222`, 
             1.167801483365429}, {-1.8410442414334884`, 
             1.1668806734668355`}, {-1.8084371975611817`, 
             1.1666810110514723`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.784825647212962, 
             1.1665364306598411`}, {-1.7010540735038986`, 
             1.166023472943986}, {-1.556593533571855, 
             1.1652086941302704`}, {-1.4119458529880398`, 
             1.1644650799477902`}, {-1.2671110317524525`, 
             1.1637926303965453`}, {-1.1235861950792687`, 
             1.162622028426653}, {-0.978470662866024, 
             1.1620563258222611`}, {-0.8403601936585592, 
             1.1615179309934454`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8167483800704296, 
             1.1614258852679638`}, {-0.6882395984395342, 
             1.1609249206134773`}, {-0.5431240662262891, 
             1.1603592180090856`}, {-0.4972398192485827, 
             1.1602728377281373`}, {-0.4513503823645356, 
             1.1601938804620548`}, {-0.22307227901107948`, 
             1.1598373975648082`}, {0.005205824342376764, 
             1.1594809146675615`}, {0.1277285548224462, 
             1.1594831023105714`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15134054781665196`, 1.1594835239026402`}, {
             0.23364898074991264`, 1.15948499351948}, {0.4620921371574485, 
             1.1594890723713986`}, {0.4878160535368051, 
             1.1595301668509723`}, {0.5135379807380042, 
             1.1595735488117163`}, {0.561394988971947, 1.1596666967736866`}, {
             0.6092443792771737, 1.1597678113996521`}, {0.7553082273793453, 
             1.1603723473243626`}, {0.9013720754815169, 
             1.1609768832490728`}, {1.0474359235836883`, 
             1.1615814191737832`}, {1.095815833310396, 
             1.161781656219733}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.119427624073597, 1.161879381809936}, {
             1.19349977168586, 1.1621859550984937`}, {1.3378305642248078`, 
             1.1633982945687302`}, {1.483588578992293, 1.1641100899426513`}, {
             1.6291427048699867`, 1.1648933916160458`}, {1.7744929418578899`, 
             1.165748199588914}, {1.913865349527117, 1.1666350636467917`}, {
             2.0529574090685663`, 1.167584868323642}, {2.063888903338213, 
             1.1676646225409566`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0875002679399617`, 1.1678368868130764`}, {
             2.1917691204822374`, 1.1685976136194653`}, {2.33030048376813, 
             1.1696732995342611`}, {2.4685514989262445`, 1.17081192606803}, {
             2.6065221659565805`, 1.1720134932207715`}, {2.744212484859138, 
             1.1732780009924861`}, {2.8816224556339174`, 
             1.1746054493831732`}, {3.0187072107567303`, 
             1.1759936457266404`}, {3.031943127996604, 
             1.1761337117822392`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.055553799017609, 1.176383566287977}, {
             3.1554218827033877`, 1.1774403973566945`}, {3.29176647147389, 
             1.1789457042733358`}, {3.427740977068237, 1.180509566476564}, {
             3.563345399486429, 1.1821319839663789`}, {3.6985797387284656`, 
             1.183812956742781}, {3.8334439947943473`, 1.1855524848057704`}, {
             3.9679381676840735`, 1.1873505681553465`}, {3.999963985725414, 
             1.1878068467877434`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.023573582670831, 1.1881432177304556`}, {
             4.102901086633642, 1.1892734135297598`}, {4.2361318109830846`, 
             1.1911473060703415`}, {4.36896089745157, 1.193077263361902}, {
             4.501372568686697, 1.1950620401366374`}, {4.633351047336063, 
             1.1971003911267435`}, {4.7648805560472685`, 
             1.1991910710644162`}, {4.895945317467912, 1.2013328346818515`}, {
             4.967943187768149, 1.202541178679226}}]}, 
           {Arrowheads[{{0.014090513364474895`, 1.}}], 
            ArrowBox[{{4.991551856063591, 1.2029374041856449`}, {
             5.026529554245592, 1.2035244367112452`}, {5.150738997828238, 
             1.2056616216312512`}, {5.274490852542233, 1.2078407270974203`}, {
             5.397774221862363, 1.210060240733625}, {5.520578209263414, 
             1.212318650163737}, {5.656854249492381, 1.214906806013154}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.2137864260074134`}, \
{-5.437511955919041, -1.2096888413720646`}, {-5.201846881598805, \
-1.2054631118546506`}, {-4.96448181014819, -1.2013864101995215`}, \
{-4.833347554609729, -1.199213903572769}, {-4.7125193880800165`, \
-1.197265741768072}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688910372304663, -1.1968908288371043`}, \
{-4.569658377620869, -1.1950215029216353`}, {-4.437136352061697, \
-1.1930041231717672`}, {-4.3041846323868445`, -1.1910409666553734`}, \
{-4.1708196665419255`, -1.1891332905097107`}, {-4.037057902472552, \
-1.1872823518720352`}, {-3.901512230098744, -1.1853821321670508`}, \
{-3.7664771378334336`, -1.183608002042036}, {-3.7445283323777345`, \
-1.1833300123034}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.72091823297066, -1.1830309816624573`}, \
{-3.631078143234893, -1.1818931236995218`}, {-3.495315246303123, \
-1.180237497139508}, {-3.3591884470381244`, -1.1786411223619944`}, \
{-3.2226977454398957`, -1.1771039993669812`}, {-3.085843141508438, \
-1.1756261281544684`}, {-2.9486246352437506`, -1.174207508724456}, \
{-2.811042226645834, -1.1728481410769436`}, {-2.7764973864856644`, \
-1.1725229761536953`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752886439447024, -1.1723007301758288`}, \
{-2.6731398929491137`, -1.1715500889932073`}, {-2.5349616113880145`, \
-1.1703154162545226`}, {-2.396507381962537, -1.1691441228608892`}, \
{-2.257777204672681, -1.1680362088123073`}, {-2.1187710795184467`, \
-1.166991674108777}, {-1.9794890064998332`, -1.166010518750298}, \
{-1.8399309856168413`, -1.1650927427368707`}, {-1.8084361323834461`, \
-1.164900306679204}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.78482458012725, -1.1647560382173734`}, \
{-1.7000970168694716`, -1.1642383460684946`}, {-1.5555449022448444`, \
-1.1634248368291895`}, {-1.4108054033399482`, -1.162682463077167}, \
{-1.2658785201547829`, -1.1620112248124268`}, {-1.1222633269315017`, \
-1.1608420381367097`}, {-0.9770553673259326, -1.1602775031028931`}, \
{-0.8403590787331083, -1.1597460594815312`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8167472641777944, -1.159654262196006}, \
{-0.6866394481147944, -1.1591484330352602`}, {-0.5414314885092253, \
-1.1585838980014436`}, {-0.49559757928012815`, -1.1584980180384377`}, \
{-0.44975848087675596`, -1.1584195308284764`}, {-0.22145830864795707`, \
-1.1580648140408552`}, {0.006841863580841767, -1.157710097253234}, {
             0.12772967626581277`, -1.1577129312055574`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15134166925729411`, -1.157713484737472}, {
             0.23530545769464603`, -1.1577154530862084`}, {
             0.46376905180845024`, -1.1577208089191826`}, {
             0.4895031578887226, -1.157762004411332}, {
             0.5152352955316448, -1.15780548794868}, {
             0.5631460398018776, -1.157898901187185}, {
             0.6110486916269007, -1.1580002497755233`}, {
             0.7577096420217894, -1.1586082818542327`}, {
             0.904370592416678, -1.1592163139329423`}, {
             1.0510315428115669`, -1.1598243460116517`}, {
             1.0958169550312147`, -1.160010018934229}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.119428745110963, -1.1601079095163205`}, {
             1.1976924932064557`, -1.1604323780903614`}, {
             1.342601422323012, -1.1616522275754275`}, {
             1.4889531924923127`, -1.1623682274317293`}, {
             1.6350988425112214`, -1.1631562058064262`}, {
             1.7810383723797378`, -1.1640161626995178`}, {
             1.9208116081114, -1.1649073253720512`}, {
             2.0603022832996065`, -1.1658616841150564`}, {
             2.063890047353401, -1.1658879092140162`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0875014095802955`, -1.1660604986880425`}, {
             2.199510397944358, -1.1668792389285334`}, {
             2.3384359520456535`, -1.1679599898124822`}, {
             2.477078945603494, -1.1691039367669027`}, {
             2.615439378617879, -1.170311079791795}, {
             2.753517251088809, -1.1715814188871592`}, {
             2.891312563016283, -1.1729149540529953`}, {
             3.0287794505766508`, -1.17430943435176}, {
             3.031944401739908, -1.174342982671121}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.055555068340772, -1.1745932545213302`}, {
             3.1658720499462603`, -1.1757626088459097`}, {
             3.3025903611251115`, -1.177274477535445}, {
             3.438934384113205, -1.1788450404203652`}, {
             3.5749041189105406`, -1.180474297500671}, {
             3.710499565517118, -1.182162248776362}, {
             3.8457207239329376`, -1.1839088942474383`}, {
             3.9805675941579994`, -1.1857142339138997`}, {
             3.9999655812724257`, -1.1859909580046588`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023575172027183, -1.1863277631843028`}, {
             4.115870658184757, -1.1876444144604101`}, {
             4.249450877054953, -1.1895258785983693`}, {
             4.3826255670324805`, -1.1914635486551748`}, {
             4.5153791077663845`, -1.193456180492557}, {
             4.64769587890571, -1.1955025299722464`}, {
             4.779560260099499, -1.1976013529559733`}, {
             4.9109566309968, -1.1997514053054683`}, {
             4.967945040737525, -1.200709116851674}}]}, 
           {Arrowheads[{{0.01409046725234969, 1.}}], 
            ArrowBox[{{4.991553700184968, -1.2011058692061636`}, {
             5.041869371246657, -1.2019514428824618`}, {
             5.169402254107746, -1.20414935111441}, {
             5.296452223011514, -1.2063913543825038`}, {
             5.42300769396464, -1.2086758405124696`}, {
             5.549057082973801, -1.2110011973300325`}, {
             5.656854249492381, -1.2130564793686354`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.45584789110883}, \
{-5.588803517854278, -3.452024822683879}, {-5.431767593888155, \
-3.4434108898585127`}, {-5.273240613192466, -3.4349479728027084`}, \
{-5.11322257576721, -3.4266360715164654`}, {-4.951713481612388, \
-3.418475185999785}, {-4.929963484085672, -3.417391352819777}, \
{-4.908196717856004, -3.4163108887935887`}, {-4.720107053476283, \
-3.4073218121864177`}, {-4.713640683821566, -3.4070252368239986`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690053486001559, -3.4059434270736353`}, \
{-4.531056162818036, -3.3986511299633917`}, {-4.322835666249573, \
-3.389324972793536}, {-4.113521315760446, -3.3803960971036346`}, \
{-3.9031131113506543`, -3.371864502893687}, {-3.7464287510527456`, \
-3.3658384642034593`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722834201558403, -3.364931024125451}, \
{-3.6916110530201984`, -3.3637301901636936`}, {-3.4790749159675447`, \
-3.356007012750589}, {-3.265564475391161, -3.348708824491309}, \
{-3.051079731291048, -3.3418356253858534`}, {-2.8356206836672038`, \
-3.3353874154342225`}, {-2.7788712022445887`, -3.3338035949984883`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7552683997039464`, -3.3331448647322843`}, \
{-2.619050952101536, -3.3293431740065214`}, {-2.402143358963242, \
-3.3238220180054863`}, {-2.1843705666356925`, -3.318742667662191}, \
{-1.965787127286125, -3.314113531228594}, {-1.8110482338758254`, \
-3.311168761711244}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7874405154076647`, -3.3107194933457604`}, \
{-1.7493655129643109`, -3.3099949043035544`}, {-1.5323703901545347`, \
-3.306331995266308}, {-1.3148763045887206`, -3.3031330705378443`}, \
{-1.0969578019987927`, -3.300406396539153}, {-0.8786894281166759, \
-3.2981602396912217`}, {-0.8430518934800499, -3.2978736679384824`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8194406638484867, -3.2976838031925384`}, \
{-0.6601457286742942, -3.296402866415041}, {-0.44140124940357206`, \
-3.2951425431316}, {-0.22253053603643388`, -3.2943875362618873`}, \
{-0.003596647994092317, -3.2941299913269804`}, {
             0.12502875234057606`, -3.2942634134773763`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14864073263559255`, -3.2942879060051187`}, {
             0.21534088955168929`, -3.294357093571061}, {
             0.43421283224316154`, -3.2950696689997736`}, {
             0.6529499357225744, -3.296268543618764}, {
             0.8714829556321783, -3.297954543433678}, {
             1.0897426476142233`, -3.30012849445016}, {
             1.0930983906435205`, -3.300169498257883}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1167086211582118`, -3.3004579915494925`}, {
             1.3076597673109596`, -3.302791222673855}, {
             1.5251650703646373`, -3.305943554110409}, {
             1.74220227199844, -3.3095745952858895`}, {
             1.958719074998914, -3.313669846732646}, {
             2.061059381109437, -3.315828606063976}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0846661227354426`, -3.316326565037368}, {
             2.1746522163533557`, -3.318224725465751}, {
             2.389938433049062, -3.3232346485002737`}, {
             2.604514462073328, -3.328695032851286}, {
             2.81831704041345, -3.3346012955338575`}, {
             3.0288230282197497`, -3.3408755356583644`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0524231136633295`, -3.341625157011506}, {
             3.2433487929904476`, -3.3477331239539643`}, {
             3.454476713514242, -3.354939351950922}, {
             3.6646364520238315`, -3.362549653022681}, {
             3.873776409650662, -3.370554749520903}, {
             3.996291741396758, -3.375495326815737}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.019884558842837, -3.376446735398924}, {
             4.081844987526181, -3.37894536379725}, {
             4.288790586781836, -3.387712218203385}, {
             4.494561608549073, -3.39684603509097}, {
             4.69910645395934, -3.4063375368116677`}, {
             4.902373524144083, -3.41617744571714}, {
             4.963390095808481, -3.419253049082951}}]}, 
           {Arrowheads[{{0.014205262862435123`, 1.}}], 
            ArrowBox[{{4.986972149545095, -3.4204417268776326`}, {
             5.117441832357081, -3.4270181861025124`}, {
             5.330893915029666, -3.4381878926196965`}, {
             5.539516779035461, -3.449484637098834}, {
             5.656854249492381, -3.456053248461777}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.297392094794825}, \
{-5.567203837355306, -5.289067484996478}, {-5.366987586813732, \
-5.271120235902769}, {-5.156967010580467, -5.252966399664791}, \
{-4.944388766948028, -5.2353168429465144`}, {-4.729876499466871, \
-5.218246963568993}, {-4.715796339771828, -5.217175600420326}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.692252404909404, -5.215384136066757}, \
{-4.513774499161362, -5.201803704082234}, {-4.296147704529765, \
-5.186005551765198}, {-4.077061054070346, -5.170870993896844}, \
{-3.8565794862813707`, -5.1564185177561335`}, {-3.750061088094536, \
-5.14981457336163}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            
            ArrowBox[{{-3.726494344245542, -5.148353478672004}, \
{-3.634767939661107, -5.142666610622028}, {-3.4116913527078183`, \
-5.129633759773485}, {-3.187414663919773, -5.117338452489467}, \
{-2.9619456130741892`, -5.105811542008274}, {-2.7834024400983255`, \
-5.097356663593982}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7598168773468745`, -5.096239773700785}, \
{-2.735312739483212, -5.095079384855716}, {-2.507612180947498, \
-5.0851537232420245`}, {-2.2789400752677014`, -5.07604629937743}, \
{-2.0493925602444767`, -5.067768855472162}, {-1.8190657736784797`, \
-5.060333133736449}, {-1.8160325571437752`, -5.060246707093728}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7924301432911027`, -5.059574194147132}, \
{-1.5880558533703653`, -5.053750876380524}, {-1.356458937120789, \
-5.048033825614614}, {-1.1637018262674481`, -5.043956500855859}, \
{-0.9706042610222689, -5.040494729640791}, {-0.8481912702605153, \
-5.038696897038161}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8245818233650646, -5.038350154154954}, \
{-0.7772440581549553, -5.037654922569639}, {-0.5836644492042311, \
-5.035440641086971}, {-0.38992017440488924`, -5.033854667857256}, \
{-0.19606597399172307`, -5.032899785544962}, {-0.1604948504136728, \
-5.032793135177254}, {-0.12492230568923945`, -5.0327077457575955`}, {
             0.11320224408691992`, -5.032684310189443}, {
             0.11987097048042077`, -5.032710347864426}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14348278350168842`, -5.032802538888158}, {
             0.3512800771676501, -5.033613871978698}, {
             0.3663080609567632, -5.033702612943319}, {
             0.3813354478046465, -5.033795145968252}, {
             0.425011141953485, -5.034107194320791}, {
             0.46868021453037445`, -5.034451281713676}, {
             0.7069408002665168, -5.036804691937699}, {
             0.944898302970317, -5.040107819357617}, {
             1.0879005279434761`, -5.042663053508376}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1115087523896807`, -5.043084896884275}, {
             1.1824557169325232`, -5.044352612171408}, {
             1.4195160364438846`, -5.049531018577053}, {
             1.65599836502082, -5.055632709395101}, {
             1.8917570889928845`, -5.062639092102543}, {
             2.055648189398992, -5.068059610750196}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0792455199245126`, -5.068891184869845}, {
             2.2290239034063752`, -5.0742551655842565`}, {
             2.3970492571835393`, -5.080730000689486}, {
             2.5646228361299594`, -5.087641026009445}, {
             2.731709835837366, -5.094981985022993}, {
             2.89827545189749, -5.10274662120899}, {
             3.022868760354066, -5.108887414196432}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0464521266199722`, -5.110049760489182}, {
             3.064284879902064, -5.110928678046297}, {
             3.2297033154428196`, -5.119521899013773}, {
             3.3944959541114885`, -5.12852002759028}, {
             3.5586279914998022`, -5.137916807254677}, {
             3.722064623199492, -5.147705981485824}, {
             3.884771044802291, -5.157881293762583}, {
             3.989340251540212, -5.164697019663334}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.012902248202065, -5.16623276920119}, {
             4.046712451899929, -5.168436487563812}, {
             4.207854040084139, -5.179365306368372}, {
             4.368161004946652, -5.190661493655124}, {
             4.5275985420791995`, -5.202318792902927}, {
             4.686169561187604, -5.214331383506468}, {
             4.8438985229000275`, -5.226693693955187}, {
             4.954815688617944, -5.235676930161398}}]}, 
           {Arrowheads[{{0.014422476014529048`, 1.}}], 
            ArrowBox[{{4.978350619557516, -5.237583035878747}, {
             5.0007829491917075`, -5.239399841370081}, {
             5.156820362037881, -5.252443942872146}, {
             5.309875267123657, -5.265607050956634}, {
             5.456593303682646, -5.278548466904086}, {
             5.595143694012828, -5.291079681013432}, {
             5.656854249492381, -5.296807803130046}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.829494327345963}, \
{-5.523126271042988, -4.818641269060372}, {-5.315013818664949, \
-4.802240523224843}, {-5.100331830944196, -4.785914529322418}, \
{-4.884050195093433, -4.770119206009801}, {-4.715069546640322, \
-4.758280507116606}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.6915152889512886`, -4.756630307718119}, \
{-4.6661689111126625`, -4.754854553286996}, {-4.446687979001883, \
-4.740120571154}, {-4.282090616131864, -4.729505343445263}, \
{-4.116676998802059, -4.719231999487915}, {-3.9504749891273505`, \
-4.709307674307029}, {-3.783512449222619, -4.699739502927672}, \
{-3.7488744748678218`, -4.697838205391707}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7252979728352402`, -4.696544078178549}, \
{-3.6158172412027456`, -4.690534620374916}, {-3.447417227182612, \
-4.681700161673832}, {-3.2783402692770993`, -4.673243261849489}, \
{-3.1086142296010886`, -4.665171055926957}, {-2.938244258861101, \
-4.65749464206877}, {-2.78193194118942, -4.650848220533497}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7583403335247048`, -4.649867700217701}, \
{-2.5956530025464133`, -4.643363134924065}, {-2.4235122172833217`, \
-4.636917988265003}, {-2.250861660824138, -4.630893210633104}, \
{-2.0777415833246673`, -4.625293775342096}, {-1.9041922349407137`, \
-4.620124655705709}, {-1.814417032590361, -4.617681373017227}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7908137792843404`, -4.617038997186434}, \
{-1.7302538658280824`, -4.615390825037668}, {-1.487680347350771, \
-4.609543607061378}, {-1.2444378577816384`, -4.604559202721619}, \
{-1.0006692126948924`, -4.6004507279458045`}, {-0.8465260714111564, \
-4.5984150194258016`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8229161372817494, -4.59810321220776}, \
{-0.7564537540762034, -4.5972254693602705`}, {-0.5119123539563537, \
-4.59489209425467}, {-0.26716588436612587`, -4.593459269918652}, \
{-0.22948220620855808`, -4.593318718638351}, {-0.19179568130531022`, \
-4.593199493033719}, {-0.058002610912213676`, -4.5929484827718134`}, {
             0.07577945262163438, -4.592966284909483}, {
             0.12154166833522256`, -4.593064333894115}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.1451536071364391, -4.593114924246627}, {
             0.20955050929623392`, -4.593252899446729}, {
             0.3433105591115851, -4.5938083263835505`}, {
             0.3599204616512474, -4.5938939912187085`}, {
             0.37652966316856595`, -4.593983801710933}, {
             0.4200539255752498, -4.594258538941387}, {
             0.463572388168439, -4.594561769369248}, {
             0.604960430738848, -4.595696207643514}, {
             0.7462398185862522, -4.597128422027716}, {
             0.8874105517106514, -4.598858412521856}, {
             1.0284726301120457`, -4.600886179125932}, {
             1.0895843482200132`, -4.601893817953138}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1131931321796302`, -4.602283090716486}, {
             1.1693888214944277`, -4.603209671742651}, {
             1.3101218935617895`, -4.605826840274722}, {
             1.4506718463141317`, -4.608737684722144}, {
             1.5910386797514537`, -4.611942205084918}, {
             1.7312729947222973`, -4.615447102818589}, {
             1.8710880530849279`, -4.619214403008396}, {
             2.0106795114537053`, -4.623270017949116}, {
             2.057398060299918, -4.624725492118184}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0809986029951606`, -4.625460745697699}, {
             2.1500271294892137`, -4.6276112670585325`}, {
             2.3954918483415826`, -4.635958319538725}, {
             2.6400145786439535`, -4.645149471923578}, {
             2.883482470194947, -4.655165181295143}, {
             3.024783516518874, -4.661475450653998}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.04837199918948, -4.662528872997927}, {
             3.125782672793184, -4.66598590473547}, {
             3.3668023362372863`, -4.677592099326609}, {
             3.606428610325875, -4.689964222150612}, {
             3.844548644857571, -4.703082730289529}, {
             3.991563302722338, -4.711689332153215}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.015134937664768, -4.713069273991478}, {
             4.081049589630996, -4.716928080825411}, {
             4.315908132687321, -4.73148926875806}, {
             4.549190500310269, -4.746763827005032}, {
             4.7808382243545715`, -4.762717060407251}, {
             4.957544183433176, -4.775453938951496}}]}, 
           {Arrowheads[{{0.014352611006110703`, 1.}}], 
            ArrowBox[{{4.981095076879652, -4.777151475757839}, {
             5.010712911367245, -4.779286314687885}, {
             5.237858736725843, -4.796349020264046}, {
             5.460462481984602, -4.813708712687911}, {
             5.656854249492381, -4.8295227119279724`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.9090864191999692`}, \
{-5.515667597112305, -3.899989723470262}, {-5.352364029768171, \
-3.889773307498018}, {-5.183757763701663, -3.879534544656983}, \
{-5.014364475139571, -3.8695731397926965`}, {-4.8441333755663045`, \
-3.859905676565488}, {-4.714058930663372, -3.8527830176249394`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.69048225823187, -3.8514919984950255`}, \
{-4.67309403304463, -3.8505398483806617`}, {-4.501276015637315, \
-3.841483348643523}, {-4.328708891407125, -3.832743870759376}, \
{-4.155422228416825, -3.8243291081335253`}, {-3.981445594729183, \
-3.816246754171276}, {-3.804285417050909, -3.8078479983586018`}, \
{-3.7471327788322237`, -3.805369512032172}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7235429571318015`, -3.8043465137533574`}, \
{-3.6280664401378986`, -3.8002060707355025`}, {-3.4512166286530785`, \
-3.7929119385866135`}, {-3.273735982596448, -3.785965601911935}, \
{-3.095624501968008, -3.779367060711467}, {-2.9168821867677575`, \
-3.77311631498521}, {-2.779744902762078, -3.768603295248337}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7561456851330512`, -3.7678266739545236`}, \
{-2.7375090369956974`, -3.767213364733163}, {-2.557505052651827, \
-3.7616582099553266`}, {-2.3768702337361463`, -3.7564508506517007`}, \
{-2.1957329923477813`, -3.751608001531263}, {-2.014221740585857, \
-3.7471463773029923`}, {-1.8323364784503733`, -3.7430659779668876`}, \
{-1.8120063009377998`, -3.7426533521944925`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7883991697596338`, -3.742174216646837}, \
{-1.6500772059413307`, -3.739366803522949}, {-1.4674439230587284`, \
-3.736048853971177}, {-1.2844366298025671`, -3.7331121293115714`}, \
{-1.101055326172846, -3.730556629544132}, {-0.9173000121695659, \
-3.728382354668859}, {-0.8603046014182875, -3.72778683922276}, \
{-0.8440361917367714, -3.727627759992447}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8204253275161039, -3.7273968832084967`}, \
{-0.803289499617689, -3.72722932200453}, {-0.640027142347181, \
-3.7258446159340632`}, {-0.4766749121207895, -3.7247733526030835`}, \
{-0.3132328089385145, -3.7240155320115913`}, {-0.149700832800356, \
-3.7235711541595866`}, {-0.13113010335752714`, -3.7235384967960314`}, \
{-0.11255863841683561`, -3.7235098947656198`}, {-0.0773738243015328, \
-3.7234779385924317`}, {-0.04218634045212898, -3.7234605223642503`}, {
             0.12168557386552864`, -3.7235375095284584`}, {
             0.12404173341678588`, -3.7235431647682695`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14765365840152023`, -3.723599837966873}, {
             0.28550762355002407`, -3.723930714214793}, {
             0.4492798086013575, -3.7246401364232535`}, {
             0.6130021290195287, -3.72566577615384}, {
             0.7766131203696487, -3.7270054621631035`}, {
             0.9400513182168289, -3.7286570232075937`}, {
             1.0921034081388097`, -3.730485607533516}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1157133839685212`, -3.730793405574351}, {
             1.2664093334023696`, -3.7328957704022554`}, {
             1.4293938231872594`, -3.7354869765627066`}, {
             1.5919037147187396`, -3.7383712977104127`}, {
             1.7541890747900566`, -3.7415642778851224`}, {
             1.9162240344225983`, -3.7450643090827236`}, {
             2.0600224104835094`, -3.748483022224138}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0836277333260558`, -3.7490442234672936`}, {
             2.1261863505727674`, -3.750056026994199}, {
             2.335560371684627, -3.7555390368136368`}, {
             2.544276293431798, -3.76150577417238}, {
             2.7522643114879015`, -3.767948674701774}, {
             2.9594546215265596`, -3.774860174033162}, {
             3.027679819498638, -3.777298065440578}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0512767524574333`, -3.7781412547872057`}, {
             3.165777419221393, -3.7822327077978883`}, {
             3.371162900246024, -3.790058711627297}, {
             3.5755412602740746`, -3.798330621152732}, {
             3.778907829900213, -3.8070365656018827`}, {
             3.981277981233275, -3.8161633491551603`}, {
             3.9949597126492544`, -3.8168115125435165`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.018545253602594, -3.8179288626562857`}, {
             4.182611972218136, -3.825701419872991}, {
             4.382870060799671, -3.835641225815802}, {
             4.582012504922752, -3.845973215044019}, {
             4.779999562532254, -3.856687835618069}, {
             4.961748631527456, -3.8669279870233715`}}]}, 
           {Arrowheads[{{0.014246943906299676`, 1.}}], 
            ArrowBox[{{4.985322154092471, -3.868275065288455}, {
             5.1723485499900175`, -3.879226763045373}, {
             5.366159496558525, -3.8909982514359345`}, {
             5.557241590884437, -3.9030130196633963`}, {
             5.656854249492381, -3.909492304765543}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQzXavpq+s5pG9p0StjOmy5/tvuOTdVl34yD7yRchD
JyCfR91/3b7jj+yLX2QnBQL5RrsjSphfP7K/mJu0PA7Iv33jgOlC2cf2yW8N
dhYC+a//VDu7FD62V5vekTIRyP/q3qDYyPTEPv/NeY6TQL6C4I4FcUVP7C9y
/Iv6AuRfiSnf9ZftqX3f9jsT9ZY/338q84JNzcWn9u8tJzPWA/nWswRMz0c+
s7/+1vfQViD/Tt8N+Q0sz+2fclfz/Aby645O+zPnxHP7Z45OIj4rnu9fVXTy
xE6JF/ZMl54/ywXyXRieul/NeGE/33uR8gQg/wSzBM+nAy/sPzR8d98G5G9g
3Z7498kL+ymfpdiPgeRnKu2YfPSl/V/+hzkaK5/vj9h7u0Rh2Sv7CO07yn1A
vo+/q/WRhjf2s7RWrahe9Xx/TZXSGdfod/ZlkvxPK1Y/3/9gRXLYa4bP9pY7
jxbzb3i+/0DpvlOyl77Z29dLpSzb+nx/isc9rfNRP+xF1e4+893xfD8AXZLZ
kA==
             "]]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.5457820846799366`, -0.7413278840974238}, {
             1.6643622038193306`, -0.7417286449157112}, {
             1.9019172174914316`, -0.7426554739831226}, {
             2.1388080431958447`, -0.7437015194994087}, {
             2.3748797400267363`, -0.7448637457736762}, {
             2.4902524454428723`, -0.7454907029168616}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.513864089812582, -0.745619013066533}, {
             2.6101323079841077`, -0.7461421528059251}, {
             2.844565747067958, -0.7475367405961555}, {
             3.0783347662663116`, -0.7490533186869359}, {
             3.310562681313698, -0.7506589663370435}, {
             3.4583236977337735`, -0.7517560212940118}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.481935039970434, -0.7519313242302595}, {
             3.541847700297143, -0.7523761471110776}, {
             3.7721279396214387`, -0.7542025371920105}, {
             3.8991953206551218`, -0.7552596933099989}, {
             4.025918062969367, -0.7563483611975744}, {
             4.152284878055947, -0.7574680492058626}, {
             4.278284477406628, -0.7586182656859887}, {
             4.403905572513182, -0.7597985189890778}, {
             4.42637998888562, -0.7600156333541902}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.4499908801603105`, -0.7602437266485339}, {
             4.529136874867378, -0.7610083174662553}, {
             4.653967095960985, -0.7622471694686466}, {
             4.778384947285772, -0.7635145833473768}, {
             4.90237914033351, -0.7648100674535712}, {
             5.025938386595968, -0.766133130138355}, {
             5.149051397564916, -0.7674832797528537}, {
             5.271706884732123, -0.7688600246481924}, {
             5.394417055985851, -0.7702845430326106}}]}, 
           {Arrowheads[{{0.00505767847572692, 1.}}], 
            ArrowBox[{{5.4180274581172725`, -0.7705586315743842}, {
             5.515600133628394, -0.7716913336858912}, {
             5.656854249492381, -0.7734031156424529}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.878124125284057}, {-5.532693172760044, 
             1.8744201183819513`}, {-5.31444900379624, 
             1.868166838598606}, {-5.094916892457493, 
             1.8621329851378259`}, {-4.874065750043239, 
             1.8563190566486187`}, {-4.712729863517557, 
             1.8522576949903398`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689125348385461, 
             1.8516634907200797`}, {-4.651762137611758, 
             1.8507229342516194`}, {-4.427978587295646, 
             1.845346822721244}, {-4.202793602301818, 
             1.8401972504856912`}, {-3.9762856858371856`, 
             1.8352807459731593`}, {-3.7485333411086628`, 
             1.830603837611847}, {-3.7448829564715562`, 
             1.8305331832902723`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7212753850878464`, 
             1.8300762514581608`}, {-3.5196150713231624`, 
             1.8261730538299523`}, {-3.2896093796875983`, 
             1.8219949230556742`}, {-3.058594769408884, 
             1.818075973717211}, {-2.846225455995137, 
             1.8147234436128228`}, {-2.77693850180098, 
             1.8137092529722196`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7533290379211968`, 
             1.8133636684740262`}, {-2.6331530149050564`, 
             1.8116045869963453`}, {-2.4194327243894325`, 
             1.808722691348063}, {-2.2045302280239625`, 
             1.8060459776918953`}, {-1.9892286343615038`, 
             1.8036210186652015`}, {-1.808921154738173, 
             1.8017987015331935`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7853103675805508`, 
             1.8015600739286848`}, {-1.7733897477750808`, 
             1.801439595567271}, {-1.557013568264694, 
             1.799501708398104}, {-1.3401000958303437`, 
             1.7978073571577005`}, {-1.1227873896768896`, 
             1.7963622635991132`}, {-0.9052135090091924, 
             1.7951721494753958`}, {-0.8408552042697621, 
             1.7948958684919378`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8172434288369986, 
             1.7947945065221942`}, {-0.6873784538272517, 
             1.7942370147865478`}, {-0.46928222413106785`, 
             1.7935568595325697`}, {-0.42559076197470636`, 
             1.7934513986021139`}, {-0.38189418413695936`, 
             1.793356263856264}, {-0.16480004091215267`, 
             1.7930363050778424`}, {0.0522791941948999, 
             1.7929705941754632`}, {0.12723352906568036`, 
             1.7930356977493922`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15084551315691438`, 1.7930562065639197`}, {
             0.2693435211841984, 1.7931591311491266`}, {0.4863929400557429, 
             1.793601915998832}, {0.5113132342923331, 1.793667351707039}, {
             0.5362322535211833, 1.7937361877548303`}, {0.5848083945466602, 
             1.7938900820245505`}, {0.6333701253741411, 
             1.7940562235908466`}, {0.7828757620569601, 
             1.7950507123670403`}, {0.9323813987397793, 
             1.7960452011432337`}, {1.0818870354225987`, 
             1.7970396899194274`}, {1.0953138080487579`, 
             1.7971290027705913`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.118925278683163, 1.7972860626852296`}, {
             1.231392672105418, 1.7980341786956209`}, {1.3791453632667687`, 
             1.8000358921978419`}, {1.52834165662227, 1.8012081265139226`}, {
             1.6773317210928926`, 1.8024988578565946`}, {1.8261155566786367`, 
             1.8039080862258583`}, {1.9775054893533666`, 1.805462196802917}, {
             2.063358867755864, 1.806410547176666}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.086969420345025, 1.8066713531785845`}, {
             2.1285396548554036`, 1.807130544746445}, {2.2792180531847475`, 
             1.8089131300564427`}, {2.429540684341399, 1.81080995273291}, {
             2.579507548325357, 1.8128210127758468`}, {2.729118645136622, 
             1.8149463101852534`}, {2.8783739747751946`, 
             1.8171858449611296`}, {3.027273537241074, 1.8195396171034752`}, {
             3.031359549520043, 1.8196073815643186`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.054968296000775, 1.81999892076372}, {
             3.175753689051314, 1.8220020858251518`}, {3.323750786722968, 
             1.8245677103390205`}, {3.471264830256036, 1.8272364906450813`}, {
             3.618295819650518, 1.8300084267433343`}, {3.7648437549064138`, 
             1.8328835186337795`}, {3.9109086360237244`, 
             1.8358617663164167`}, {3.9992805498145216`, 
             1.8377322574888628`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.022887255444215, 1.8382319200241273`}, {
             4.056490463002449, 1.8389431697912462`}, {4.2015892358425875`, 
             1.8421277290582678`}, {4.346169531326489, 1.8454094341791558`}, {
             4.4901959262365025`, 1.8487822752155847`}, {4.633668420572629, 
             1.8522462521675547`}, {4.776587014334868, 1.8558013650350653`}, {
             4.918951707523218, 1.8594476138181169`}, {4.96709835474091, 
             1.860716505552536}}]}, 
           {Arrowheads[{{0.014111808690369394`, 1.}}], 
            ArrowBox[{{4.990702151897904, 1.8613385771783753`}, {
             5.060762500137681, 1.8631849985167095`}, {5.202019392178255, 
             1.8670135191308428`}, {5.342722383644942, 1.870933175660517}, {
             5.4826235230947145`, 1.874934812571174}, {5.621866375249313, 
             1.8790203296102443`}, {5.656854249492381, 
             1.8800729601388555`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.6060677551802771}, \
{-5.567265395035259, -0.6052175233576628}, {-5.367643838897561, \
-0.6033902834018109}, {-5.166762105093317, -0.601618327352878}, \
{-4.964620193622525, -0.5999016552108639}, {-4.761218104485185, \
-0.5982402669757687}, {-4.712410318707831, -0.597857243777551}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688799052743551, -0.5976719523848035}, \
{-4.556555837681298, -0.5966341626475924}, {-4.350633393210862, \
-0.595083342226335}, {-4.14345077107388, -0.5935878057119963}, \
{-3.9352084684618798`, -0.5921553604189184}, {-3.744343614894317, \
-0.5909125599606719}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.720732110044127, -0.5907607738083563}, \
{-3.516146313387416, -0.58950316543957}, {-3.3053264609249537`, \
-0.5882834157532996}, {-3.093647425179004, -0.5871345646026316}, \
{-2.8811092061495662`, -0.5860566119875661}, {-2.776266802528595, \
-0.585561845091986}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752655072450082, -0.5854504178260446}, \
{-2.6677118038366414`, -0.5850495579081031}, {-2.45345521824023, \
-0.5841134023642426}, {-2.350966637357977, -0.583692253284919}, \
{-2.24832260590278, -0.5832881466340486}, {-2.018255777085553, \
-0.5824479081705826}, {-1.8081826522913924`, -0.5817638839103692}}]}, 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAOFRQF5qN/L/r/vqNMJ3ivyuI8PnA
5vi/vCpHndaX4r9c9yLwFTH1v8d/foolk+K/UPBD6/+79L8hhpEpnZLivylV
cWDiRvS/9TVMoheS4r8bkrNJBSHzv7mf5MThkOK/5YHXVvv68b/EH7TXvY/i
v7Sve7NE6vG/pJkATK2P4r+B+QT6jdnxv4k+edCcj+K/G8Xxv3vA8b8d2lsx
hI/ivxJuptTEr/G/B2wP2nOP4r+MZ/7SDZ/xv+Ff2ZJjj+K/ZQ7e2eL38L/g
d2U4xI7iv/BIRr+uUPC/hUrUDSuO4r+EoRlD4lLvvyKE2/2XjeK/zJ2a3jq5
7L9upi/LkIziv7N3f42hGOy/NXg2XVKM4r8/M8N6i4LrvwJWjNQYjOK/Jkzg
1Qvi6r/pK8ft24viv2hjuzg=
             "]]}, 
           {Arrowheads[{{0.0004326515547452361, 1.}}], 
            ArrowBox[{{-0.8164815667257624, -0.5795379334599718}, \
{-0.8057812517543896, -0.5795223633348375}, {-0.800102082611497, \
-0.5795141792483087}, {-0.7960500572170837, -0.5795083252223603}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.7882695929853896, 0.563578026677293}, {
             0.7923724210718712, 0.5635839087216221}, {0.796440920054088, 
             0.5635897266347856}, {0.8044724372505476, 0.5636011997244008}, {
             0.8109949877789396, 0.5636105161422685}, {0.8200691605890275, 
             0.5636235262066202}, {0.8353564821134785, 0.5636456935055526}, {
             0.854041901063634, 0.5636730648819722}, {0.8960545518491406, 
             0.56373554388318}, {0.9435091004120842, 0.5638086868601786}, {
             0.9917573776622203, 0.5638867156227614}, {1.1904154256054174`, 
             0.5642826395160612}, {1.3887360928089516`, 0.5647423959039946}, {
             1.634473845701958, 0.5653613692342709}, {1.7327469518598368`, 
             0.5656484979633308}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7563588440756144`, 0.5657174858366939}, {
             1.879508450860195, 0.5660772972994911}, {2.1238399082836628`, 
             0.566890180099655}, {2.3674682179723603`, 0.5678000176347626}, {
             2.61026954789525, 0.5688044275864854}, {2.700831978817746, 
             0.5692150562965171}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.724443729099701, 0.5693221168343263}, {
             2.852120066021293, 0.5699010276364951}, {3.0930197723504893`, 
             0.5710898177847914}, {3.3329686668828393`, 0.5723707980313746}, {
             3.572180033189385, 0.5737494893900837}, {3.6689100169331375`, 
             0.5743386448963292}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6925215719773874`, 0.5744824563302502}, {
             3.809445264367557, 0.5751946061158297}, {4.04558905689205, 
             0.576727496128791}, {4.280526097334446, 0.5783459510234319}, {
             4.521339724618215, 0.5800993232676235}, {4.636978798226823, 
             0.5809850504182246}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.660590098637931, 0.5811658990637776}, {
             4.760537632921757, 0.581931438271143}, {4.99803364505352, 
             0.5838383306819701}, {5.2338233227377495`, 0.5858182096561233}, {
             5.467866458078036, 0.5878681813526823}, {5.605036243133953, 
             0.5891185379227465}}]}, 
           {Arrowheads[{{0.0005973270894070676, 1.}}], 
            ArrowBox[{{5.628647255228089, 0.5893337615894289}, {
             5.656854249492381, 0.5895908794422107}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.7246855702395545}, {-5.472939556986484, 
             0.7226224351508159}, {-5.254905902307756, 
             0.7202747841296598}, {-5.035471613889758, 
             0.7180096478385984}, {-4.814636691732492, 
             0.7158270262776318}, {-4.712425780001672, 0.7148611419795518}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688814841218849, 
             0.7146380206449792}, {-4.592401135835956, 
             0.7137269194467598}, {-4.368764946200152, 
             0.7117093273459825}, {-4.143728122825079, 
             0.7097742499752998}, {-3.9172906657107363`, 
             0.7079216873347118}, {-3.744369597577155, 0.7065841553409205}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207583108897504`, 
             0.7064015237408509}, {-3.6896719229594823`, 
             0.706161072771649}, {-3.4610912426736737`, 
             0.7045018396335417}, {-3.2315486248533105`, 
             0.7029439879203901}, {-3.001044069498393, 
             0.7014875176321941}, {-2.776299281965511, 0.7001717800718441}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752687649856861, 
             0.7000413253408466}, {-2.537149146184894, 
             0.6988787213306686}, {-2.303758778226312, 
             0.6977263953173393}, {-2.0694064727331765`, 
             0.6966754507289655}, {-1.978279434922164, 
             0.6962873022731878}, {-1.887067631249006, 
             0.6959164644643493}, {-1.808218438759488, 0.6956109973277003}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7846066229486794`, 
             0.6955195235466877}, {-1.6566280417800359`, 
             0.6950237258155038}, {-1.426188452311066, 
             0.6941309871666583}, {-1.1946369061466977`, 
             0.6934508322038034}, {-0.9630853599823294, 
             0.6927706772409487}, {-0.9354156472350736, 
             0.6927156929304714}, {-0.9077416287528304, 
             0.692662294119784}, {-0.8473976994642005, 
             0.6925571893507516}, {-0.8401317981291817, 
             0.6925451862802571}}]}, 
           {Arrowheads[{{0.002574961461968259, 1.}}], 
            ArrowBox[{{-0.8165198373498728, 
             0.6925061799661496}, {-0.7990930541245238, 
             0.6924773913963767}, {-0.7743352279916733, 
             0.6924373529335491}, {-0.7524323821524276, 
             0.6924025636063628}, {-0.7161774038559184, 
             0.6923456935973649}, {-0.7096681474169824, 
             0.6923357102850936}, {-0.7044318566982204, 
             0.6923277287903689}, {-0.7004698926142111, 
             0.6923217099120137}, {-0.6949200464305961, 
             0.6923132789217343}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.36388838082965497`}, {-5.6122035931680045`, 
             0.36363653900279086`}, {-5.606129137207883, 
             0.36360246564593346`}, {-5.600053479636039, 
             0.36356841988986566`}, {-5.590937891563244, 
             0.36351739961668605`}, {-5.584859532535689, 
             0.36348341607459966`}, {-5.578779973921548, 
             0.36344946023508945`}, {-5.384827164002918, 
             0.3623846448681059}, {-5.189682716986377, 
             0.36134889814327215`}, {-4.973756189793615, 
             0.36024565189174873`}, {-4.756483689980273, 
             0.35918144769509575`}, {-4.712387344400631, 
             0.3589746678032782}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688775611003981, 
             0.3588639458916729}, {-4.537865217546351, 
             0.35815628555331325`}, {-4.317900772491848, 
             0.3571701654664012}, {-4.288606094540762, 
             0.357041827278361}, {-4.259289075286739, 
             0.35691422539560724`}, {-4.092270058576441, 
             0.3562191954828349}, {-3.9245643531352106`, 
             0.3555488145569893}, {-3.744304463104944, 
             0.35484921710796474`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720692647933267, 
             0.3547575784985205}, {-3.703079594035048, 
             0.3546892213749549}, {-3.480635614173648, 
             0.353877318344179}, {-3.2572324135510105`, 
             0.3531131054646618}, {-3.032869992167136, 
             0.3523965827364031}, {-2.807548350022024, 
             0.35172775015940305`}, {-2.776218104283798, 
             0.35164174843311047`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752606200244222, 
             0.3515769336044805}, {-2.581267487115674, 
             0.35110660773366154`}, {-2.3540274034480873`, 
             0.3505331554591786}, {-2.125828099019263, 
             0.3500073933359543}, {-1.896871741034159, 
             0.34953238400724257`}, {-1.8081290972627542`, 
             0.34936952549662403`}}]}, 
           {Arrowheads[{{0.019478189481090962`, 1.}}], 
            ArrowBox[{{-1.7845171440258256`, 
             0.3493261933693227}, {-1.667360496697732, 
             0.34911119011629743`}, {-1.4373331397853146`, 
             0.3487435882339171}, {-1.2068284440722388`, 
             0.3484293549308999}, {-1.0914032292629727`, 
             0.3482922300672707}, {-0.978645634641036, 
             0.3481709845864367}, {-0.954346321108592, 
             0.3481462982316332}, {-0.9360364805499988, 
             0.3481277421734077}, {-0.9224506473273392, 
             0.3481139618837429}, {-0.9043537515703863, 
             0.3480955686093989}, {-0.8933152685268033, 
             0.34808431453377275`}, {-0.8858825865100826, 
             0.34807671984808397`}, {-0.8796725077892825, 
             0.3480703589037134}, {-0.8753952194450884, 
             0.34806596281462615`}, {-0.8688468105843139, 
             0.34805920285943653`}, {-0.8646803077244664, 
             0.34805488254387923`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.472643962373634, -5.656854249492381}, \
{-4.466055500618909, -5.656305336174792}, {-4.292167297301829, \
-5.642324952660251}, {-4.11747433468051, -5.628811448453273}, \
{-3.9417878337587453`, -5.615771610716078}, {-3.7651563411054756`, \
-5.603217649117057}, {-3.587628403289638, -5.591161773324604}, \
{-3.53072684225003, -5.587478754613115}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.507164155295376, -5.585953632712039}, \
{-3.409252566880172, -5.579616193007111}, {-3.2300773784460155`, \
-5.568593117832973}, {-3.0501513845561075`, -5.55810475747058}, \
{-2.869523131779387, -5.5481633215883255`}, {-2.7200629035907475`, \
-5.540393376731205}, {-2.570170289140209, -5.533024599064732}, \
{-2.564196144027672, -5.532747765162596}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.540609460959479, -5.5316547897846595`}, \
{-2.4198764214918347`, -5.526060182053674}, {-2.2688803476930204`, \
-5.519469255538595}, {-2.1176231194846507`, -5.513297060270393}, \
{-1.9660269042065688`, -5.507535612587146}, {-1.8140917018587752`, \
-5.502184912488854}, {-1.6618175124412704`, -5.497244959975515}, \
{-1.5968411916381047`, -5.495320222433542}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.573239551247811, -5.494621091384726}, \
{-1.5092481549727121`, -5.4927255294130495`}, {-1.3564274484717584`, \
-5.488636395167373}, {-1.2033553929384102`, -5.484977557238485}, \
{-1.050031988372667, -5.481749015626388}, {-0.9890945180024906, \
-5.480586740448429}, {-0.9281329819888178, -5.4794928157144325`}, \
{-0.7192940741025469, -5.476273106448308}, {-0.6289719948862484, \
-5.475234516063859}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6053615627352554, -5.474963025770261}, \
{-0.5101831381148271, -5.473868593517643}, {-0.4966914433005065, \
-5.473739837688481}, {-0.48319896880439556`, -5.473614479780554}, \
{-0.4362881715630319, -5.473231613726023}, {-0.38937064853564946`, \
-5.472889828344099}, {-0.1786016029924485, -5.471770193496544}, {
             0.032197082766479534`, -5.471481899198603}, {
             0.2429846473493368, -5.472024532695618}, {
             0.3391019512683169, -5.4726508306914035`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.3627134430239981, -5.47280468259279}, {
             0.4537203293643256, -5.473397681232928}, {
             0.6642956800179411, -5.475600234438869}, {
             0.8746022505166788, -5.478631081941777}, {
             1.112436139182856, -5.483050449823368}, {
             1.3070654389861094`, -5.487522830394226}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3306712004960632`, -5.4880652664469896`}, {
             1.3496801872016202`, -5.488502073355813}, {
             1.5863343945729704`, -5.49498595253911}, {
             1.8223987612969075`, -5.5025020873732595`}, {
             2.0576856548901814`, -5.511019031655655}, {
             2.2746056845458176`, -5.519800844597801}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.298197212988518, -5.520782675139415}, {
             2.525364125234988, -5.530961009957363}, {
             2.7577557019865213`, -5.542386043976676}, {
             2.9882964930748894`, -5.5546723347496}, {
             3.2161008184508404`, -5.5677117757841055`}, {
             3.241420812429522, -5.569263433711139}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.264988592803873, -5.5707077126186}, {
             3.4411686781143738`, -5.5815043670801945`}, {
             3.6635000720654904`, -5.596050108637865}, {
             3.8840234425248563`, -5.611360046137347}, {
             4.103667231713137, -5.627445225258871}, {
             4.207236343045039, -5.635427421294129}}]}, 
           {Arrowheads[{{0.005240279862497903, 1.}}], 
            ArrowBox[{{4.230778519650491, -5.637241845173457}, {
             4.322431439630334, -5.644305646002437}, {
             4.477466602452956, -5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.002740649690485, -0.3658952783503807}, {
             1.1182692404639658`, -0.36602089104550534`}, {
             1.233725940952841, -0.36616138040592455`}, {
             1.464422464670051, -0.36647042421653375`}, {
             1.6951189883872613`, -0.366779468027143}, {
             1.9049600082592826`, -0.3671866679308977}, {
             1.9472193083021556`, -0.3672778898186214}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9708312462884785`, -0.36732885908582985`}, {
             2.1141334883459852`, -0.36763819456990704`}, {
             2.3226394286473693`, -0.3681340479441709}, {
             2.5304778291634347`, -0.3686742280536892}, {
             2.737648689894181, -0.36925873489846217`}, {
             2.9153076925012407`, -0.369799733203584}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9389195760236944`, -0.3698716349298063}, {
             2.944152010839609, -0.36988756847848964`}, {
             3.1499877919997186`, -0.37056072879377167`}, {
             3.3551560333745094`, -0.3712782158443083}, {
             3.5029251298199386`, -0.371823183875448}, {
             3.650219140638841, -0.3723890449295692}, {
             3.873769819162298, -0.37328997113053497`}, {
             3.883392922039652, -0.3733309191135067}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.90700470127512, -0.3734313913568557}, {
             4.096091454193449, -0.3742359885057546}, {
             4.317184045732295, -0.3752270970552283}, {
             4.537047593778835, -0.3762632967789559}, {
             4.566222284532133, -0.3764041802645152}, {
             4.59537365228546, -0.37654581312625085`}, {
             4.771441933387671, -0.3774377808813722}, {
             4.851474002939369, -0.37785732095009955`}}]}, 
           {Arrowheads[{{0.016554738384213608`, 1.}}], 
            ArrowBox[{{4.875085671513697, -0.37798109684533665`}, {
             4.946618481666796, -0.3783560825261518}, {
             5.187453492544823, -0.3796469570747298}, {
             5.426525510824878, -0.3809853526141153}, {
             5.656854249492381, -0.3823371709451032}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.5839366105438075`}, \
{-5.59397635249701, -1.582350669607639}, {-5.567143058556228, \
-1.5816873324322371`}, {-5.540284335469112, -1.5810262666689303`}, \
{-5.331954447382631, -1.5760961102992355`}, {-5.1221198800159, \
-1.5713086415672541`}, {-4.982637716290315, -1.568172399756908}, \
{-4.842669489495194, -1.5651172794539194`}, {-4.712621537181027, \
-1.5623636259063545`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.68901465711994, -1.5618723323540826`}, \
{-4.561274846696349, -1.5592504033700165`}, {-4.419848430692624, \
-1.556438647589102}, {-4.277935951619364, -1.5537080133155454`}, \
{-4.135537409476569, -1.5510585005493467`}, {-3.99265280426424, \
-1.548490109290506}, {-3.849282135982376, -1.546002839539023}, \
{-3.744699989371541, -1.5442535981509382`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7210912985169307`, -1.5438587190965327`}, \
{-3.705425404630977, -1.5435966912948982`}, {-3.561082610210043, \
-1.5412716645581312`}, {-3.416253752719574, -1.5390277593287223`}, \
{-3.2709388321595703`, -1.536864975606671}, {-3.1251378485300316`, \
-1.534783313391978}, {-2.978850801830958, -1.5327827726846426`}, \
{-2.8320776920623496`, -1.5308633534846652`}, {-2.7767112323012655`, \
-1.5301834607242502`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753101019388787, -1.5298935304505732`}, \
{-2.6157850647681347`, -1.5282073087950996`}, {-2.398914973118634, \
-1.5257602112489934`}, {-2.1814674171138493`, -1.5235220608463467`}, \
{-1.9634423967537786`, -1.5214928575871594`}, {-1.8086717845782077`, \
-1.5202041158159283`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785060610110757, -1.520007510618234}, \
{-1.7448399120384228`, -1.5196726014714312`}, {-1.5256599629677823`, \
-1.5180612924991626`}, {-1.3059025495418557`, -1.5166589306703533`}, \
{-1.0855676717606446`, -1.5154655159850035`}, {-0.9184152173364011, \
-1.5147043097879493`}, {-0.8405982060729987, -1.5144093137261614`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8169863827357517, -1.5143198038004648`}, \
{-0.7511917392055216, -1.514070383263579}, {-0.5838972373680046, \
-1.5135637364118915`}, {-0.41653171182385107`, -1.5131843692328877`}, \
{-0.24909516257306163`, -1.5129322817265671`}, {-0.08158758961563473, \
-1.5128074738929298`}, {0.08599100704842877, -1.512809945731976}, {
             0.12749141857357296`, -1.5128420647497278`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15110340449986967`, -1.5128603391177944`}, {
             0.2536406274191281, -1.5129396972437055`}, {
             0.42124535674348684`, -1.5131959690769263`}, {
             0.5886892802685295, -1.513578001880447}, {
             0.7559723979942549, -1.5140857956542675`}, {
             0.9230947099206623, -1.5147193503983876`}, {
             1.0900562160477532`, -1.5154786661128072`}, {
             1.0955786860120096`, -1.5155079694034879`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1191903466111075`, -1.5156332574283145`}, {
             1.256856916375527, -1.5163637427975265`}, {
             1.4234968109039827`, -1.5173745804525456`}, {
             1.5899758996331221`, -1.5185111790778643`}, {
             1.7576871406162258`, -1.5198214982242517`}, {
             1.922975656453303, -1.5211797004497212`}, {
             2.06364481389194, -1.5224427243857441`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0872558551861555`, -1.5226547204682686`}, {
             2.0880509668150777`, -1.5226618595244585`}, {
             2.2528868718635584`, -1.5242670733879473`}, {
             2.417457171760749, -1.5259944399796714`}, {
             2.581735666668659, -1.5278430572391153`}, {
             2.7456961567492963`, -1.5298120231057626`}, {
             2.9093124421646657`, -1.5319004355190973`}, {
             3.0316720102996015`, -1.5335487005184287`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0552818612862978`, -1.5338667409595155`}, {
             3.059205133766433, -1.5339195900567328`}, {
             3.2087371435471015`, -1.5360318832311814`}, {
             3.3578850655049086`, -1.538235938384659}, {
             3.5066254936380954`, -1.5405303788593812`}, {
             3.654935021944903, -1.5429138279975625`}, {
             3.80279024442357, -1.5453849091414191`}, {
             3.95016775507234, -1.5479422456331664`}, {
             3.9996423370493424`, -1.5488322626679545`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.023250510344029, -1.5492569590585632`}, {
             4.097044147889449, -1.5505844608150194`}, {
             4.243396016873138, -1.553310178029194}, {
             4.389199956021649, -1.5561180206179053`}, {
             4.53443255933322, -1.5590066119233688`}, {
             4.679070420806092, -1.5619745752877998`}, {
             4.823090134438505, -1.565020534053414}, {
             4.966468294228699, -1.5681431115624267`}, {
             4.967540230858074, -1.5681671307839067`}}]}, 
           {Arrowheads[{{0.01410077067284759, 1.}}], 
            ArrowBox[{{4.991146298440973, -1.568696079370983}, {
             5.109181494174916, -1.5713409311570534`}, {
             5.2512063282753925`, -1.5746126161795093`}, {
             5.392230660535344, -1.5779490607761284`}, {
             5.531777366392544, -1.5813367424098834`}, {
             5.656854249492381, -1.5844509226554162`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.056298224000441}, \
{-5.646204171661844, -2.0559477524687635`}, {-5.459878896226755, \
-2.050008940650466}, {-5.26831181112072, -2.0440903907988384`}, \
{-5.242336432377579, -2.043300056556627}, {-5.2163410436987885`, \
-2.0425128974118407`}, {-5.018612459020053, -2.036771555335781}, \
{-4.819721999828933, -2.031214315199445}, {-4.712791429503978, \
-2.028281488359286}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689188312699995, -2.02763411638452}, \
{-4.654409587385885, -2.026680226596429}, {-4.48847104402759, \
-2.0222985236767808`}, {-4.321906369754046, -2.0180692064405004`}, \
{-4.1547155645652545`, -2.0139922748875874`}, {-3.9868986284612147`, \
-2.010067729018042}, {-3.818455561441927, -2.006295568831865}, \
{-3.7449878500328686`, -2.00472262383782}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721381266912299, -2.004217206477815}, \
{-3.649386363507391, -2.0026757943290554`}, {-3.4796910346576064`, \
-1.9992084055096133`}, {-3.3093695748925747`, -1.995893402373539}, \
{-3.138421984212294, -1.9927307849208324`}, {-2.9668482626167654`, \
-1.9897205531514937`}, {-2.7946484101059883`, -1.9868627070655225`}, \
{-2.777067248560896, -1.9865874872435425`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753458148154586, -1.986217904585749}, \
{-2.6218224266799637`, -1.9841572466629191`}, {-2.4483703123386906`, \
-1.9816041719436834`}, {-2.27429206708217, -1.9792034829078153`}, \
{-2.0995876909104005`, -1.976955179555315}, {-1.9051218574991748`, \
-1.9746553622423435`}, {-1.8090634207800655`, -1.9736313592699402`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785452769301759, -1.973379664800199}, \
{-1.7103381177120696`, -1.9725789269459717`}, {-1.5152364715490854`, \
-1.9707258736662}, {-1.3198169190102225`, -1.9690962024030279`}, \
{-1.1240794600954804`, -1.9676899131564558`}, {-0.9280240948048597, \
-1.9665070059264835`}, {-0.8410025712771849, -1.9660817986402666`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.817390860145353, -1.9659664263598662`}, \
{-0.7316508231383607, -1.9655474807131113`}, {-0.5349596450959822, \
-1.9648113375163387`}, {-0.3849494707412655, -1.9644022301765243`}, \
{-0.23494633230434814`, -1.9641266614313164`}, {-0.08495022978523237, \
-1.963984631280715}, {0.06503883681608302, -1.9639761397247202`}, {
             0.12708555866608998`, -1.9640278709807084`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15069754345731737`, -1.964047557397544}, {
             0.21502086749959792`, -1.964101186763332}, {
             0.3649958622653124, -1.9643597723965505`}, {
             0.5149638211132271, -1.9647518966243755`}, {
             0.6649247440433406, -1.965277559446807}, {
             0.8147929968849759, -1.9659351072024265`}, {
             0.9644829454674533, -1.9667228862298158`}, {
             1.0951696052841247`, -1.967525310015718}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1187811255093527`, -1.9676744954943417`}, {
             1.2633279298549338`, -1.968689138099903}, {
             1.4124829656599371`, -1.969867610942601}, {
             1.5614596972057833`, -1.9711763150570687`}, {
             1.7102581244924715`, -1.9726152504433059`}, {
             1.858878247520002, -1.9741844171013125`}, {
             2.008386610751072, -1.975943626854292}, {
             2.0632172477173993`, -1.97660944733308}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.086827500021745, -1.9768961518173491`}, {
             2.1559847887459402`, -1.9777359439780404`}, {
             2.3033645416868156`, -1.9796562423990178`}, {
             2.450505809176281, -1.981703397129954}, {
             2.597388530816918, -1.9838762831835786`}, {
             2.743992646211309, -1.9861737755726214`}, {
             2.8902980949620365`, -1.9885947493098122`}, {
             3.031199888376362, -1.9910494915484604`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.054808016884816, -1.9914765900210933`}, {
             3.1819284716120153`, -1.9937997103559424`}, {
             3.3272040353618557`, -1.9965751177593347`}, {
             3.4720904204843936`, -1.99946247330512}, {
             3.6165665395428164`, -2.002459948680361}, {
             3.7606113051003076`, -2.005565715572119}, {
             3.904203629720052, -2.0087779456674575`}, {
             3.9990852630657434`, -2.0109768851199514`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.022690917512791, -2.0115239604920254`}, {
             4.047322425965237, -2.0120948106534384`}, {
             4.189946606399044, -2.0155144822171236`}, {
             4.332055083584662, -2.019035132045576}, {
             4.4736267700852785`, -2.022654931825858}, {
             4.614640578464075, -2.026372053245032}, {
             4.755075421284239, -2.0301846679901594`}, {
             4.894910211108956, -2.034090947748304}, {
             4.966848220961197, -2.0361569559480546`}}]}, 
           {Arrowheads[{{0.014118234857750853`, 1.}}], 
            ArrowBox[{{4.990450482424331, -2.0368347960191886`}, {
             5.03412386050141, -2.0380890642065266`}, {
             5.172695282024786, -2.0421771890518903`}, {
             5.310603388242273, -2.046353493971458}, {
             5.318704011786524, -2.0466023437678906`}, {
             5.326802679463407, -2.046851501532199}, {
             5.3348993918993735`, -2.047100967168491}, {
             5.342994149708065, -2.0473507405797253`}, {
             5.3510869534784335`, -2.047600821671038}, {
             5.3672686546370345`, -2.0481015989690134`}, {
             5.383442545369109, -2.04860360611971}, {
             5.399608630400804, -2.0491068423702172`}, {
             5.560841512766215, -2.054206584595767}, {
             5.656854249492381, -2.0573311968422736`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.602521307923698, -5.55872914284084}, {
             4.793841121589273, -5.574633616785719}, {
             4.806523789709248, -5.57570759176419}, {
             4.819169414416937, -5.576780867872912}, {
             4.997015626507674, -5.592426739675412}, {
             5.171469116634273, -5.608330021159341}, {
             5.357369919888257, -5.62563129598991}, {
             5.543168426362307, -5.643613811200308}}]}, 
           {Arrowheads[{{0.0019191418444276208`, 1.}}], 
            ArrowBox[{{5.566666135375148, -5.645934058301909}, {
             5.656854249492381, -5.6548680015714075`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.635317045918636}, \
{-5.5993956719697175`, -5.629595074143353}, {-5.39694201588566, \
-5.609884859230327}, {-5.200217795480562, -5.59151286487335}, \
{-5.017249624101876, -5.575087280804594}, {-4.829988291212114, \
-5.558882056446429}, {-4.817233638384321, -5.5577982226142995`}, \
{-4.804445999365569, -5.556714132527285}, {-4.716293453828789, \
-5.549508740884263}}]}, 
           {Arrowheads[{{0.001686465548790482, 1.}}], 
            ArrowBox[{{-4.692759944372346, -5.547585164527665}, \
{-4.613383038491493, -5.5410970740159255`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.0057449239544036`}, \
{-5.557681820584556, -3.0008973827458663`}, {-5.329593426945185, \
-2.9902058392769484`}, {-5.0999918215493665`, -2.979894553415918}, \
{-4.86882602511689, -2.969963103642048}, {-4.713318798264368, \
-2.963584584625267}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689726643071703, -2.9626168931964565`}, \
{-4.635918021969901, -2.9604097976169688`}, {-4.401234390040308, \
-2.9512406290983475`}, {-4.164886300869782, -2.942469277939894}, \
{-3.9269849259999963`, -2.9341094239953183`}, {-3.7458802580834116`, \
-2.928105471154687}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7222812297147807`, -2.927323119959436}, \
{-3.68764143697262, -2.9261747471183286`}, {-3.4469670053293235`, \
-2.9186789271626346`}, {-3.2050728026117787`, -2.911635643981945}, \
{-2.9620700003616562`, -2.90505857742997}, {-2.8139741961526203`, \
-2.9013020500322835`}, {-2.7781867182444477`, -2.9004419920629094`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754581540905281, -2.899874703668317}, \
{-2.6655696448676034`, -2.897735536701795}, {-2.5168751061244814`, \
-2.8943603411530603`}, {-2.367909339541132, -2.8911777671006353`}, \
{-2.218691104735431, -2.8881891182590773`}, {-2.0692391613252563`, \
-2.885395698342942}, {-1.9195722689284853`, -2.8827988110667855`}, \
{-1.8102933820678824`, -2.880987667159667}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7866846313205507`, -2.880596385309173}, \
{-1.7681083664375103`, -2.880288509836367}, {-1.6174644205461377`, \
-2.8780466628322787`}, {-1.4666430449039225`, -2.876003955897281}, \
{-1.3156442395108616`, -2.8741603890313754`}, {-1.1644680043669566`, \
-2.8725159622345604`}, {-1.0131143394722075`, -2.871070675506837}, \
{-0.8615832448266145, -2.8698245288482047`}, {-0.8422706567683738, \
-2.869691244268195}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186592260677041, -2.8695282915031446`}, \
{-0.7098747204301774, -2.868777522258664}, {-0.5579887662828962, \
-2.867929655738214}, {-0.406018820744377, -2.8672831359988393`}, \
{-0.2540583221742262, -2.866840169752522}, {-0.10210727057244373`, \
-2.866600756999263}, {0.04983433406096971, -2.866564897739062}, {
             0.12581327673308967`, -2.8666487590538785`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1494252553484031, -2.866674820637555}, {
             0.2017664917260148, -2.866732591971919}, {
             0.3536892024226924, -2.867103839697834}, {
             0.5056024661510015, -2.867678640916807}, {
             0.6575062829109423, -2.8684569956288377`}, {
             0.8940428446184656, -2.870065879850836}, {
             1.0938881555268345`, -2.8718294203512778`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1174992292185029`, -2.872037776927296}, {
             1.1300038852573135`, -2.872148124612054}, {
             1.3653894048274853`, -2.874703729912492}, {
             1.60019940332898, -2.8777326957521496`}, {
             1.8344338807617984`, -2.8812350221310274`}, {
             2.0618859495009683`, -2.8851050993934253`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0854938744039773`, -2.8855428563789354`}, {
             2.3011762724214067`, -2.889659756506442}, {
             2.5336841866481974`, -2.894582164502979}, {
             2.76533940736528, -2.8999465695573656`}, {
             2.9958647621316237`, -2.9057216081882316`}, {
             3.0297354659809304`, -2.906634935091588}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.053338879321423, -2.9072714034835894`}, {
             3.2252602509472275`, -2.911907280395577}, {
             3.453525873812093, -2.9185035861794013`}, {
             3.680661630726219, -2.9255105255397047`}, {
             3.906667521689606, -2.932928098476488}, {
             3.9973761301846054`, -2.936085774888589}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.020973829425715, -2.9369072393505604`}, {
             4.131543546702254, -2.9407563049897503`}, {
             4.355289705764163, -2.948995145079492}, {
             4.537647033078994, -2.956026815803893}, {
             4.718995483530221, -2.963284284153439}, {
             4.893936453848888, -2.9705392490131697`}, {
             4.964738720408334, -2.9735776970583094`}}]}, 
           {Arrowheads[{{0.01417150111169713, 1.}}], 
            ArrowBox[{{4.988329000768051, -2.97459006353648}, {
             5.0679841157407175`, -2.9780084276671097`}, {
             5.24113846920571, -2.9856918201152602`}, {
             5.4133995142438645`, -2.99358942635762}, {
             5.436442231354233, -2.994662970544093}, {
             5.459469344039452, -2.9957403946593653`}, {
             5.656854249492381, -3.0053686862396405`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.4606679849072783`}, {-5.515664308623704, 
             3.4528132809756684`}, {-5.360557674453249, 
             3.444410988818125}, {-5.202852835008463, 
             3.4360907805760355`}, {-5.042549790289345, 
             3.427852656249399}, {-5.020881302017439, 
             3.4267535471962067`}, {-4.999196240146687, 
             3.4256577995693753`}, {-4.808196434099449, 
             3.4163664080556573`}, {-4.713636164065978, 
             3.4119377994646816`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.690050023780782, 
             3.410833172929055}, {-4.61602285692923, 
             3.4073662058088434`}, {-4.470456603398349, 
             3.4006587640084835`}, {-4.32434186500497, 
             3.394145567437689}, {-4.177678641749093, 
             3.3878266160964587`}, {-4.03046693363072, 
             3.3817019099847934`}, {-3.8827067406498474`, 
             3.375771449102693}, {-3.7464352593786527`, 3.370500802669667}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7228402738014634`, 
             3.369604935548086}, {-3.58554090010061, 
             3.3644932630271875`}, {-3.4361352525322446`, 
             3.359145537833782}, {-3.286247447837501, 
             3.354005040865589}, {-3.1359438137524975`, 
             3.3490847551182568`}, {-2.985224350277235, 
             3.3443846805917854`}, {-2.8340890574117132`, 
             3.3399048172861745`}, {-2.7788814353785996`, 
             3.3383530949446496`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755278763656599, 
             3.337689693919901}, {-2.6825379351559318`, 
             3.335645165201424}, {-2.5305709835098913`, 
             3.3316057243375345`}, {-2.3781882024735914`, 
             3.327786494694506}, {-2.2253895920470326`, 
             3.324187476272338}, {-2.071110085631612, 
             3.320690757570347}, {-1.9181442310111236`, 
             3.3176057176671288`}, {-1.8110610379714143`, 
             3.3156082167071204`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7874531519355716`, 
             3.31516784157745}, {-1.7648026122015765`, 
             3.314745324527117}, {-1.611105261803572, 
             3.312111795921484}, {-1.457072212417711, 
             3.309707349621403}, {-1.3027234966445937`, 
             3.3075342033980464`}, {-1.1480791470848215`, 
             3.3055945750225866`}, {-0.9931591963389943, 
             3.3038906822661964`}, {-0.8506142359512388, 
             3.3025332270048953`}, {-0.8430622414497113, 
             3.3024719257849404`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.819451026302168, 
             3.3022802682972574`}, {-0.7079326711925604, 
             3.301375048992056}, {-0.5651371128082121, 
             3.30041749705495}, {-0.42225017154344635`, 
             3.2996619200208497`}, {-0.2792944581435137, 
             3.299109666717027}, {-0.13629258335366634`, 3.298762085970753}, {
             0.006732842080843016, 3.2986205266093003`}, {
             0.12501823982470733`, 3.298674953376181}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14863023032310638`, 3.2986858179826917`}, {
             0.149759207414764, 3.2986863374599404`}, {0.2927639019028444, 
             3.298960867349945}, {0.4357243147998314, 3.299445465106586}, {
             0.578617835360475, 3.3001414795571353`}, {0.7214218528395222, 
             3.3010502595288647`}, {0.8641137564917223, 
             3.3021731538490458`}, {1.0066709355718215`, 
             3.3035115113449507`}, {1.0930884247369121`, 
             3.304455289370052}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1166990097427192`, 3.304713144018498}, {
             1.1490707793345691`, 3.305066680843851}, {1.2912906770347137`, 
             3.3068400111730187`}, {1.4333278531283846`, 
             3.3088225477554056`}, {1.575182705703934, 3.3110036874692717`}, {
             1.7168373844644413`, 3.3133823063248524`}, {1.8582740391129875`, 
             3.3159572803323827`}, {1.9994748193526515`, 3.318727485502097}, {
             2.0610509459216315`, 3.320022516968188}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0846577186309707`, 3.3205190001861964`}, {
             2.1404218748865116`, 3.321691797844231}, {2.281097355417649, 
             3.324849093369019}, {2.4214834106491434`, 3.328198248086697}, {
             2.561562190284075, 3.331738138007499}, {2.701315844025525, 
             3.3354676391416604`}, {2.8407265215765722`, 3.339385627499416}, {
             2.979776372640294, 3.3434909790910012`}, {3.0288161472712516`, 
             3.3450086603862093`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.052416840877855, 3.3457390538578395`}, {
             3.1184475469197728`, 3.3477825699266504`}, {3.256722194118088, 
             3.352259276016599}, {3.3945824639383195`, 3.356919973371082}, {
             3.532010506083548, 3.361763538000334}, {3.668922204970344, 
             3.3667764451729245`}, {3.805222842569436, 3.3719431860387563`}, {
             3.940878664915142, 3.3772596604300644`}, {3.996289287043477, 
             3.3795019551982146`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.019881970630979, 3.3804566773966473`}, {
             4.075855918041781, 3.382721768179084}, {4.210120847983671, 
             3.3883254091180506`}, {4.343639700775129, 3.394066483079199}, {
             4.476378722450473, 3.3999408898947645`}, {4.608304159044019, 
             3.4059445293969826`}, {4.739382256590088, 3.4120733014180877`}, {
             4.869579261122995, 3.418323105790316}, {4.963402340892877, 
             3.4229435951372613`}}]}, 
           {Arrowheads[{{0.014204870785645987`, 1.}}], 
            ArrowBox[{{4.9869857533693205`, 3.424105003464288}, {
             4.998861418677059, 3.4246898423459027`}, {5.127194975286598, 
             3.431169410917082}, {5.254546176985931, 3.43775771133609}, {
             5.380881269809372, 3.4444506434351614`}, {5.506166499791242, 
             3.4512441070465316`}, {5.630368112965856, 3.458134002002436}, {
             5.635862014462614, 3.458442194826589}, {5.641341170144288, 
             3.458749835139294}, {5.646805270713927, 3.4590569037613905`}, {
             5.652254009048892, 3.4593633816282865`}, {5.656854249492381, 
             3.4596223635264622`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.303012623453794}, {-5.5135157539111495`, 
             5.28970011607248}, {-5.3904603559681386`, 
             5.278690973015417}, {-5.264047320667872, 
             5.267638337335853}, {-5.134820269894497, 
             5.256599144899344}, {-5.003322825532157, 
             5.245630331571438}, {-4.87053539063835, 
             5.234832445488842}, {-4.737088943331895, 
             5.224271144971338}, {-4.715810990329644, 5.222633457686915}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.692268624802357, 
             5.22082148673909}, {-4.603002968088913, 
             5.213951031159093}, {-4.468296949385532, 
             5.203876705192271}, {-4.332990371697876, 
             5.194052768211041}, {-4.1971027195020705`, 
             5.184483821355567}, {-4.060653477274242, 
             5.175174465766015}, {-3.923662129490514, 
             5.1661293025825525`}, {-3.786148160627013, 
             5.1573529329453445`}, {-3.7500854049131167`, 
             5.155131174218745}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7265180951361216`, 
             5.153679236475138}, {-3.6481310551598636`, 
             5.148849957994559}, {-3.5096302975651916`, 
             5.140624978870359}, {-3.370665372319122, 
             5.132682596712912}, {-3.2312557638977797`, 
             5.125027412662385}, {-3.0914209567772906`, 
             5.117664027858944}, {-2.9511804354337796`, 
             5.110597043442754}, {-2.8105536843433727`, 
             5.103831060553982}, {-2.7834303241954164`, 5.102594743897718}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759842821774544, 
             5.101519596056024}, {-2.645995496086544, 
             5.096330292656615}, {-2.480965907259013, 
             5.0892666424602595`}, {-2.315496386950018, 
             5.082645081274276}, {-2.1492827339635987`, 
             5.076417553108167}, {-1.9827707603972824`, 
             5.070654484844558}, {-1.8160655612570438`, 5.065349296392578}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7924635402793219`, 
             5.064663157912865}, {-1.6486158333556804`, 
             5.060484443204625}, {-1.480972879880394, 
             5.056077469828302}, {-1.313020323883818, 
             5.052131683362294}, {-1.144825556147652, 
             5.048656239087824}, {-0.9763885766718962, 
             5.04565113700489}, {-0.8482259388919158, 5.0437252236098855`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8246166114004001, 
             5.043370443770374}, {-0.8077093854565501, 
             5.043116377113494}, {-0.7539688169746931, 
             5.042408680384601}, {-0.70021151448578, 
             5.041749709394647}, {-0.4624321430769932, 
             5.039421353923672}, {-0.22445460193816907`, 
             5.038045631633221}, {-0.2097312429285723, 
             5.037989994513623}, {-0.1950075378909846, 
             5.0379380028412815`}, {-0.1572164381429179, 
             5.037837945778961}, {-0.11942412260854285`, 5.037761921720894}, {
             0.07959747414737989, 5.037694935226894}, {0.1198365256111718, 
             5.037816219202276}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.14344841135574127`, 5.037887387464578}, {
             0.278596555249374, 5.038294735639068}, {0.47751284131295235`, 
             5.039560723396103}, {0.6762860529536278, 5.041492298936684}, {
             0.8748682200521576, 5.044085508152438}, {1.073172996393906, 
             5.04733323364829}, {1.0878676494044661`, 5.047626718898389}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.11147493450888, 5.048098209444511}, {
             1.3051307143583473`, 5.051965950652236}, {1.5366089114414643`, 
             5.057477634277905}, {1.7675085184718056`, 5.0638579030662765`}, {
             1.9977304662779192`, 5.071096375558324}, {2.0556125907621605`, 
             5.073136304390874}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.079209933699447, 5.0739679411121985`}, {
             2.227175685688353, 5.079182670295027}, {2.4557451075316563`, 
             5.088106405817362}, {2.6833396626363757`, 5.097857200666305}, {
             2.9098602818310604`, 5.108424673382834}, {3.022825247612291, 
             5.114115892953824}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0464073317403915`, 5.115303967661645}, {
             3.13527436993708, 5.11978112412784}, {3.3595697853120576`, 
             5.131893524329878}, {3.5826781390889213`, 5.1447434994314225`}, {
             3.804531042400598, 5.15831267487495}, {3.98927684047492, 
             5.170267211468966}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.012839554939063, 5.1717919082969965`}, {
             4.025060106380016, 5.1725826761029365`}, {4.244196942160102, 
             5.187535128557856}, {4.461873160873783, 5.203151657682185}, {
             4.678020373653989, 5.2194138889184}, {4.892599152139004, 
             5.236312554430605}, {4.954739231771441, 5.241428155924394}}]}, 
           {Arrowheads[{{0.014424279110359541`, 1.}}], 
            ArrowBox[{{4.978271617669147, 5.243365429084693}, {
             5.105599028472472, 5.2538474931045425`}, {5.314780838333657, 
             5.271783225320638}, {5.515691201190123, 5.2896535063148225`}, {
             5.656854249492381, 5.302659545242439}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.843459525238695}, {-5.614116877029507, 
             4.839957415580064}, {-5.605566636516047, 
             4.839261371634704}, {-5.5969713517116375`, 
             4.838562522709586}, {-5.588331757696855, 
             4.837860941678531}, {-5.584000975977044, 
             4.837509477305397}, {-5.579659363147421, 
             4.837157353757611}, {-5.575307013184114, 
             4.83680458031731}, {-5.570944020650482, 
             4.836451166315331}, {-5.566570480711864, 
             4.8360971211328225`}, {-5.407533347777653, 
             4.823407848607831}, {-5.245402441951357, 
             4.810843363208974}, {-5.080386649849985, 
             4.798431585188906}, {-4.912694858090548, 
             4.78620043480028}, {-4.742535953290055, 
             4.774177832295749}, {-4.715065672131017, 4.772300011788229}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.691508654204374, 
             4.770689695129926}, {-4.570118822065517, 
             4.762391697927966}, {-4.3956523510339425`, 
             4.750869951949586}, {-4.219345426812342, 
             4.73964051461326}, {-4.041723262911969, 
             4.7287675602325265`}, {-3.863196044882537, 
             4.718302079826057}, {-3.748867730796607, 4.711897343135682}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7252927016204156`, 
             4.710576656693758}, {-3.6838001173987402`, 
             4.708252218704203}, {-3.5035718251352703`, 
             4.698626122177318}, {-3.322547512766824, 
             4.689431935555754}, {-3.140763524968094, 
             4.6806778041498625`}, {-2.9582562064137736`, 
             4.672371873269999}, {-2.7819296183967914`, 4.664816558977762}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.758337390884726, 
             4.663851069770627}, {-2.591186305811694, 
             4.657142658748345}, {-2.40664625868986, 
             4.650244607503126}, {-2.221494823228906, 
             4.643833299209255}, {-2.0357850622446785`, 
             4.637913898585128}, {-1.8495700385530252`, 
             4.632491570349144}, {-1.814417534624456, 4.631565036384387}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.790813739224062, 
             4.630942898109968}, {-1.6629028149697949`, 
             4.627571479219698}, {-1.4758364543108342`, 
             4.623158789915189}, {-1.2884240193919914`, 
             4.619258667154014}, {-1.0825436651944527`, 
             4.615581441331887}, {-0.8763080779802983, 
             4.612536544951981}, {-0.8465283938790438, 
             4.612189447690103}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8229180045717562, 
             4.611914256675565}, {-0.6698145169431571, 
             4.6101297581846055`}, {-0.4631170149683785, 
             4.608364292235491}, {-0.2562721287744766, 
             4.6072422031360905`}, {-0.04933641507996567, 
             4.606765546917858}, {-0.01724499079331291, 
             4.6067494431464615`}, {0.01484714767859907, 4.606748868061211}, {
             0.12154009958749154`, 4.606879858501845}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14515207478997302`, 4.606908847699169}, {
             0.14804334674988281`, 4.606912397408697}, {0.2811995506576357, 
             4.607343291475777}, {0.4143157594018577, 4.608041550262449}, {
             0.5473919729825488, 4.609007173768715}, {0.5642414734635186, 
             4.609146383760371}, {0.5810899821919939, 4.6092898887246285`}, {
             0.6310787973173827, 4.609766370954421}, {0.681057383308944, 
             4.610280737866097}, {0.842385603863347, 4.612135565844796}, {
             1.0035222854957957`, 4.614377380378908}, {1.0895819217730875`, 
             4.615783037373583}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1131907657507072`, 4.616168652954927}, {
             1.1644674282062901`, 4.617006181468433}, {1.3252210319948303`, 
             4.6200219691133695`}, {1.4857250454397832`, 4.623418477859977}, {
             1.645921417119515, 4.627189442254515}, {1.8058101470340262`, 
             4.631334862296982}, {1.9653912351833167`, 4.63585473798738}, {
             2.0573937745030566`, 4.638685821077189}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0809945962975926`, 4.639412060678641}, {
             2.124728959942827, 4.64075784546105}, {2.2834590771850602`, 
             4.645994453284384}, {2.4418301299617196`, 4.651598495847374}, {
             2.5998164069226295`, 4.657566462695883}, {2.840485490250365, 
             4.667369722399125}, {3.024775599213238, 4.675523309038132}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0483645162945257`, 4.676566958533078}, {
             3.0800745389981925`, 4.677969911838029}, {3.318485899351852, 
             4.689347977724054}, {3.5556219174970844`, 4.701484866768658}, {
             3.791384939619631, 4.714361525683302}, {3.9915432968480533`, 
             4.7259779019032155`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.015115625423162, 4.727345943892066}, {
             4.0256773119052305`, 4.727958901179443}, {4.258401380539626, 
             4.742257939968541}, {4.489459491708556, 4.757239588762055}, {
             4.718809753651235, 4.77288096637407}, {4.946466036660349, 
             4.789155363721298}, {4.957509115536468, 4.789979349796546}}]}, 
           {Arrowheads[{{0.01435382770749607, 1.}}], 
            ArrowBox[{{4.98105565196949, 4.791736288994281}, {
             5.17203310051059, 4.805986187962638}, {5.394734475485394, 
             4.8232450485505}, {5.607485492804434, 4.840274537881672}, {
             5.656854249492381, 4.844341557847591}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.002853998224591}, {-5.49083499469964, 
             2.9948857772675184`}, {-5.318866570425514, 
             2.986890129515746}, {-5.146026172243998, 
             2.979110738849354}, {-4.972313800155091, 
             2.9715476052683423`}, {-4.948993921355434, 
             2.970549319583078}, {-4.925657960458283, 
             2.9695548822203275`}, {-4.737223434256107, 
             2.961853724371776}, {-4.713309299712142, 2.960913068510246}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689715552023918, 
             2.959985014976986}, {-4.54771548049967, 
             2.954399481477065}, {-4.3087828517144375`, 
             2.945259016077458}, {-4.068490183203429, 
             2.936580820699519}, {-3.826837474966644, 
             2.928364895343249}, {-3.7458579051130982`, 2.925781130997333}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7222579216472016`, 
             2.9250281411265093`}, {-3.5838247270040835`, 
             2.9206112400086477`}, {-3.3394519393157465`, 
             2.913319854695714}, {-3.093719111901634, 
             2.9064907394044495`}, {-2.970342683297411, 
             2.9032495330169428`}, {-2.8466262447617448`, 
             2.900123894134853}, {-2.7781544729189718`, 
             2.8984625139883096`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754549427377578, 
             2.8978897676876767`}, {-2.7225697962946342`, 
             2.8971138227581807`}, {-2.5981733378960796`, 
             2.8942193188869254`}, {-2.3929711843266848`, 
             2.8897349273977095`}, {-2.187265865007513, 
             2.8856163264821197`}, {-1.9810573799385647`, 
             2.8818635161401556`}, {-1.8102600833204512`, 
             2.8790649616429467`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7866512593117232`, 
             2.8786781254229847`}, {-1.7743457291198392`, 
             2.8784764963718175`}, {-1.567130912551338, 
             2.8754552671771054`}, {-1.359412930233059, 
             2.872799828556019}, {-1.1511917821650037`, 
             2.8705101805085587`}, {-0.9424674683471723, 
             2.8685863230347244`}, {-0.8422365576250337, 
             2.8678218353999143`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186252514128204, 
             2.8676417457298626`}, {-0.7837332227248108, 
             2.8673756150093768`}, {-0.6249530806361624, 
             2.8663879142546898`}, {-0.4661270420812266, 
             2.865623220770664}, {-0.3072551070600036, 
             2.865081534557298}, {-0.14833727557249315`, 2.864762855614593}, {
             0.010626452381304607`, 2.864667183942549}, {0.12584723202602333`,
              2.8647594532438734`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1494592174529573, 2.8647783618244693`}, {
             0.16963607680138895`, 2.8647945195411655`}, {
             0.32869159768776135`, 2.865144862410443}, {0.4876909592071266, 
             2.8657164670760853`}, {0.646532105526188, 2.8665075880637967`}, {
             0.8052150366449478, 2.867518225373577}, {0.9637397525634048, 
             2.8687483790054267`}, {1.0939221021469356`, 
             2.869940054264184}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1175331059383353`, 2.870156186859291}, {
             1.1221062532815593`, 2.8701980489593453`}, {1.2803145387994115`, 
             2.8718672352353334`}, {1.4383646091169617`, 2.87375593783339}, {
             1.5962564642342079`, 2.8758641567535164`}, {1.755198746771942, 
             2.878267909670121}, {1.9120201906687182`, 2.8807677395503495`}, {
             2.061917825922361, 2.883367667626734}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0855258411109463`, 2.883800806642808}, {
             2.225029301231038, 2.886415939680383}, {2.381171501716489, 
             2.88956145033115}, {2.537041821551408, 2.892919328306393}, {
             2.692617527645747, 2.8964881438065935`}, {2.8478758869094585`, 
             2.9002664670322322`}, {2.9901777626423685`, 2.903914716361648}, {
             3.029765297761306, 2.9049772044318467`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.053368791143328, 2.905610697526531}, {
             3.132139336614267, 2.907724816644947}, {3.273739019181324, 
             2.9116942579298297`}, {3.4149552206997096`, 
             2.9158205302639963`}, {3.5557663515255946`, 
             2.9201011236951473`}, {3.69615082201515, 2.924533528270983}, {
             3.8360870425245457`, 2.9291152340392026`}, {3.9755534234099534`, 
             2.933843731047508}, {3.9974006983351784`, 
             2.9346097462599277`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.020998190842837, 2.935437128086617}, {
             4.114528375027543, 2.9387165093435983`}, {4.252990307733485, 
             2.943731058975174}, {4.390917631883951, 2.9488848699899357`}, {
             4.528288757835112, 2.9541754324355836`}, {4.665082095943136, 
             2.9596002363598175`}, {4.8012760565641965`, 
             2.9651567718103378`}, {4.936849050054463, 2.970842528834845}, {
             4.964765677862233, 2.972045107939974}}]}, 
           {Arrowheads[{{0.014170772109336672`, 1.}}], 
            ArrowBox[{{4.988355793237582, 2.973061311617342}, {
             5.071779486770107, 2.9766549974810395`}, {5.2060989606557735`, 
             2.982594697423236}, {5.3398694562780955`, 2.988663879550957}, {
             5.473114969926223, 2.994862630734715}, {5.6058594978893055`, 
             3.0011910378450235`}, {5.656854249492381, 
             3.00368141630713}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.9185141795636915`}, {-5.606130300315846, 
             3.915166112205929}, {-5.563614720256003, 
             3.912427284681209}, {-5.520478374647779, 
             3.9096703268967827`}, {-5.476960149217833, 
             3.906909395025333}, {-5.472596085736951, 
             3.9066335929229865`}, {-5.468231261666951, 
             3.906357927622764}, {-5.461682693682928, 
             3.905944669131622}, {-5.457316156688618, 
             3.9056693117236354`}, {-5.452948857652304, 
             3.905394091187669}, {-5.433232718159144, 
             3.9041522362338847`}, {-5.413501018835564, 
             3.90291317101933}, {-5.209337813000087, 
             3.8906077200305775`}, {-5.003955976272913, 
             3.8787324630624838`}, {-4.852008109129706, 
             3.87008123672717}, {-4.714043717805879, 
             3.8624686766138607`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.6904667475900315`, 
             3.861183260907326}, {-4.546039611971727, 
             3.853465683593795}, {-4.392018981956954, 
             3.845501356795732}, {-4.237307430984993, 
             3.8377659965100865`}, {-4.081904959055844, 
             3.8302596027368576`}, {-3.925811566169506, 
             3.822982175476046}, {-3.7690272523259796`, 
             3.815933714727651}, {-3.7471216204698607`, 
             3.8149878367172314`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7235316088317454`, 
             3.8139692277393853`}, {-3.6116412127136814`, 
             3.809137837074173}, {-3.453742642521028, 
             3.8026181590981114`}, {-3.29533154174802, 
             3.7963746807994663`}, {-3.1364079103946567`, 
             3.790407402178238}, {-2.976971748460939, 
             3.784716323234426}, {-2.8170230559468656`, 
             3.7793014439680306`}, {-2.779737956468923, 
             3.7781074098209295`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7561380619740783`, 
             3.7773516365954487`}, {-2.6565618328524376`, 
             3.774162764379052}, {-2.4955880791776544`, 
             3.76930028446749}, {-2.332935842264628, 
             3.764549039512256}, {-2.171664377206313, 
             3.760341867982162}, {-2.009924241855714, 
             3.7564171016989305`}, {-1.847737366356866, 
             3.752777843447283}, {-1.8120030824295308`, 
             3.7520415311310775`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7883961003616835`, 
             3.75155510437966}, {-1.6851256808538049`, 
             3.749427196011943}, {-1.522111115490567, 
             3.746368262177633}, {-1.358715600411187, 
             3.7436041447290753`}, {-1.1949610657597003`, 
             3.741137946450993}, {-1.050910379650072, 
             3.739219499012222}, {-0.9066912159382936, 
             3.737533558827123}, {-0.8440347421672167, 
             3.7369035727855127`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8204239426067405, 
             3.7366661755421138`}, {-0.7623269427092665, 
             3.7360820332054643`}, {-0.617840928047894, 
             3.7348668294570158`}, {-0.4732565400390787, 
             3.7338898548915473`}, {-0.328597146767722, 
             3.7331530168188274`}, {-0.18388611631872753`, 
             3.7326582225486264`}, {-0.039146816776998605`, 
             3.732407379390713}, {0.10559738377256345`, 
             3.7324023946548572`}, {0.12404146396653262`, 
             3.7324333350553776`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14765342374144505`, 3.732472944701661}, {
             0.25032311724505574`, 3.732645175650828}, {0.3950070155555767, 
             3.7331376296883954`}, {0.5396257106192218, 3.733881664077328}, {
             0.6841558343510894, 3.734879186127396}, {0.8285740186662782, 
             3.736132103148369}, {0.9728568954798834, 3.7376423224500153`}, {
             1.0921044798786674`, 3.7391063383429093`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1157146935898223`, 3.7393962035697985`}, {
             1.1169810967070035`, 3.7394117513421055`}, {1.260939323904568, 
             3.7414289277930717`}, {1.4047268497721985`, 
             3.7436802506767326`}, {1.5483241629390334`, 3.746164418660937}, {
             1.6917117520342075`, 3.748880130413533}, {1.8348701056868593`, 
             3.75182608460237}, {1.9777797125261265`, 3.755000979895296}, {
             2.0600263948998383`, 3.7569628739981207`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0836316731190383`, 3.75752594906446}, {
             2.120421061181144, 3.75840351496016}, {2.2627746402810502`, 
             3.7620323884648097`}, {2.404820938454982, 3.765886299077095}, {
             2.5465404443320767`, 3.7699639454648635`}, {2.687913646541471, 
             3.7742640262959646`}, {2.828921033712302, 3.7787852402382462`}, {
             2.9695430944737073`, 3.783526285959557}, {3.0276896531756807`, 
             3.785582968303347}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.051286889727233, 3.786417618209742}, {
             3.109760317454823, 3.788485862127746}, {3.249553191284788, 
             3.7936626674106617`}, {3.3889022045927373`, 
             3.7990554004761523`}, {3.527792348439165, 3.804654852917189}, {
             3.6662093342735815`, 3.810450551194763}, {3.8041347313086487`, 
             3.8164392962787517`}, {3.9415501087570295`, 
             3.8226178891390328`}, {3.994969292990542, 
             3.825101881009792}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.0185557997998, 3.8261986534898376`}, {
             4.078437035831386, 3.828983130745485}, {4.214777081744381, 
             3.835531822067986}, {4.350551815708678, 3.842260764076414}, {
             4.485742806936938, 3.8491667577406465`}, {4.620331624641825, 
             3.856246604030562}, {4.754299838036, 3.8634971039160377`}, {
             4.887629016332128, 3.8709150583669527`}, {4.96176141567142, 
             3.875151737070801}}]}, 
           {Arrowheads[{{0.014246654802101086`, 1.}}], 
            ArrowBox[{{4.985334942819235, 3.876498967989156}, {
             5.0203007287428685`, 3.8784972683531844`}, {5.152296544480886, 
             3.8862405348446103`}, {5.283598032758843, 3.8941416588111095`}, {
             5.414186762789402, 3.902197441222559}, {5.544044303785223, 
             3.9104046830488373`}, {5.656854249492381, 3.917700722117545}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.473589118107576, 
             5.656854249492381}, {-4.438236290556041, 
             5.653954189217845}, {-4.313222076426436, 
             5.643981267029249}, {-4.187758144946064, 
             5.63425368732125}, {-4.061844496114922, 
             5.624771450093847}, {-3.935481129933014, 
             5.615534555347041}, {-3.808668046400336, 
             5.60654300308083}, {-3.68140524551689, 
             5.597796793295217}, {-3.5536927272826775`, 
             5.589295925990199}, {-3.5316421636642272`, 5.587879189815935}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.5080787553289654`, 
             5.586365254228837}, {-3.4253490862263902`, 
             5.581049920030102}, {-3.296192916876722, 
             5.57306829427925}, {-3.1662242192336745`, 
             5.565351048737644}, {-3.0354429932972478`, 
             5.557898183405282}, {-2.9038492390674406`, 
             5.550709698282165}, {-2.771442956544253, 
             5.543785593368293}, {-2.638224145727687, 
             5.537125868663667}, {-2.56508379413744, 5.53363595542368}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.5414986346202255`, 
             5.532510582648232}, {-2.50419280661774, 
             5.530730524168285}, {-2.327304637347456, 
             5.5227875437569685`}, {-2.149977437293007, 
             5.515419816178167}, {-1.972211206454392, 
             5.508627341431882}, {-1.7940059448316112`, 
             5.50241011951811}, {-1.6153616524246648`, 
             5.496768150436855}, {-1.597726869168057, 5.49626921820086}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5741243207988938`, 
             5.495601442926184}, {-1.436278329233553, 
             5.491701434188115}, {-1.2567559752582755`, 
             5.4872099707718895`}, {-1.0767945904988323`, 
             5.483293760188179}, {-0.9206814303996215, 
             5.480377433350605}, {-0.7644032886743224, 
             5.477912919346074}, {-0.629856315848355, 5.476184338712634}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6062462134984549, 
             5.475886086545127}, {-0.4514142218950843, 
             5.474351374979071}, {-0.2947635895680052, 
             5.473257762556902}, {-0.1380685610685586, 
             5.472622798848378}, {-0.10421960896095939`, 
             5.4725459124760825`}, {-0.07037114355234923, 
             5.4724904874145235`}, {0.13906552297513472`, 
             5.4726252417595465`}, {0.3382185459162075, 5.473534289591616}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.36183014802171437`, 5.473668208316746}, {
             0.36188301400377565`, 5.473668553135194}, {0.37528724516860823`, 
             5.473759339812964}, {0.41877179562943057`, 5.474100093680554}, {
             0.46224953784708755`, 5.474476135307343}, {0.6638538542911339, 
             5.476600638965905}, {0.8652109584711715, 5.479484635891178}, {
             1.066295299466184, 5.483119824923374}, {1.267081326355156, 
             5.487497904902707}, {1.306181420939443, 5.488496500818356}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3297857170663343`, 5.489099342165793}, {
             1.4674776867967507`, 5.492615922881323}, {1.6673930284496319`, 
             5.498470925911371}, {1.806126931772463, 5.502968724093627}, {
             1.9445342149685771`, 5.507803779675597}, {2.0826148780379734`, 
             5.512976092657279}, {2.220368920980652, 5.518485663038676}, {
             2.2737222598759117`, 5.520755572330983}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.2973129122376745`, 5.521759232872504}, {
             2.3577963437966134`, 5.524332490819786}, {2.494897146485857, 
             5.5305165760006085`}, {2.6316713290483835`, 5.537037918581145}, {
             2.7681188914841925`, 5.543896518561395}, {2.903958292787414, 
             5.551055588052925}, {3.038907991952175, 5.558478339167304}, {
             3.1729679889784768`, 5.566164771904531}, {3.240537893319031, 
             5.57019861794549}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.26410792242922, 5.571605721737324}, {
             3.3061382838663196`, 5.5741148862646055`}, {3.438418876615703, 
             5.582328682247528}, {3.5698097672266274`, 5.590806159853299}, {
             3.7003109556990923`, 5.5995473190819185`}, {3.829922442033098, 
             5.608552159933385}, {3.9633517614687195`, 5.618798346656116}, {
             4.088247167937171, 5.627720659889848}, {4.206346942957294, 
             5.6364465953380805`}}]}, 
           {Arrowheads[{{0.005056649003532767, 1.}}], 
            ArrowBox[{{4.229891560933006, 5.638228895889099}, {
             4.334749073580691, 5.64622761054111}, {4.467958856192093, 
             5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.594627245432151, 5.560807715543952}, {
             4.78593103036367, 5.576696111107809}, {4.798614650223308, 
             5.577769179463855}, {4.811260536319223, 5.578841480602533}, {
             4.988728547813864, 5.594436130337809}, {5.162658395943445, 
             5.610270397442773}, {5.348141037189027, 5.627508295856498}, {
             5.535283269887309, 5.645594492164017}}]}, 
           {Arrowheads[{{0.0019218179362676681`, 1.}}], 
            ArrowBox[{{5.55878075826214, 5.647917015586335}, {
             5.649095540194834, 5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.648261183292325}, {-5.4990139189136364`, 
             5.632626076589236}, {-5.297376458607603, 
             5.613347869033959}, {-5.117119340695163, 
             5.596790896919815}, {-4.934260585688904, 
             5.580608178175722}, {-4.921856461976379, 
             5.579530790240207}, {-4.909425860627728, 
             5.578453671410176}, {-4.716304236847748, 
             5.5623411819793676`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.5535451550372117`}, {-5.639973971633887, 
             1.5531230922676285`}, {-5.438600233225042, 
             1.5482926914339536`}, {-5.235818184962862, 
             1.5435950906243538`}, {-5.031627826847347, 
             1.5390302898388293`}, {-4.826029158878497, 
             1.53459828907738}, {-4.798512791507864, 
             1.5340160116643597`}, {-4.7709715429039905`, 
             1.5334362554899863`}, {-4.712615018708969, 
             1.5322606642076646`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689007815367527, 
             1.5317850974594558`}, {-4.587576096416484, 
             1.5297417570413174`}, {-4.4034215968458925`, 
             1.5261851164090974`}, {-4.275273119556577, 
             1.5237468788032777`}, {-4.146750430515565, 
             1.5213748919467374`}, {-4.017853529722856, 
             1.519069155839476}, {-3.8885824171784504`, 
             1.5168296704814936`}, {-3.7589370928823467`, 
             1.5146564358727905`}, {-3.744688199665752, 
             1.5144255306647378`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721079306386726, 
             1.5140429454118611`}, {-3.6289175568345464`, 
             1.5125494520133667`}, {-3.498523809035049, 
             1.5105087189032218`}, {-3.367755849483854, 
             1.508534236542356}, {-3.236646456481565, 
             1.506628990395811}, {-3.1052284083287827`, 
             1.5047959659286279`}, {-2.9735017050255075`, 
             1.5030351631408068`}, {-2.84146634657174, 
             1.5013465820323477`}, {-2.7766965816717852`, 
             1.5005555283430627`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7530863495197, 
             1.500267169086585}, {-2.7091223329674787`, 
             1.4997302226032507`}, {-2.5764696642127256`, 
             1.498186084853516}, {-2.4435083403074795`, 
             1.4967141687831431`}, {-2.3102383612517405`, 
             1.4953144743921323`}, {-2.175946454468308, 
             1.4939495535106866`}, {-2.042504121985762, 
             1.49271766356238}, {-1.908779965923026, 
             1.491559404002017}, {-1.8086553067743276`, 
             1.4907494515700814`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7850440863115318`, 
             1.490558450016644}, {-1.7747874020652494`, 
             1.490475479183889}, {-1.6405398461975853`, 
             1.4894665934622862`}, {-1.506050714105184, 
             1.4885334511914998`}, {-1.371333421573196, 
             1.4876767567258207`}, {-1.2364013843867734`, 
             1.4868972144195396`}, {-1.0109835426971179`, 
             1.485769778017057}, {-0.8405809083574739, 
             1.4850832166026569`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8169691070071716, 
             1.4849880833801312`}, {-0.7851946840309086, 
             1.4848600625143455`}, {-0.5591223825839678, 
             1.4841709165156798`}, {-0.332854212552118, 
             1.4837051886253332`}, {-0.10647774813118105`, 
             1.4834657274475804`}, {0.1199194364830215, 
             1.4834553815866953`}, {0.1275086948076048, 1.483462812834218}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15112067648607752`, 1.4834859332068355`}, {
             0.3462497670946658, 1.483676999646952}, {0.5724256695079305, 
             1.4841334302326248`}, {0.7983929449039937, 
             1.4848194303340352`}, {1.0241076638108004`, 
             1.4857272672141346`}, {1.0955960788311225`, 
             1.4860852921679655`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1192077757213663`, 1.486203543169706}, {
             1.2494976560526831`, 1.4868560548861427`}, {1.4744907514539731`, 
             1.4882049073632782`}, {1.6990147798390016`, 
             1.4897729386587606`}, {1.9229975710321006`, 
             1.4915592627858087`}, {2.0636635605134517`, 
             1.4928211044714514`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0872746035456213`, 1.4930329069010888`}, {
             2.146366954857601, 1.4935629937576418`}, {2.369050761139835, 
             1.495783245587479}, {2.591004209386843, 1.4982140938529651`}, {
             2.8121909467016546`, 1.5008480638438755`}, {3.031693733765193, 
             1.5036709138117101`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0553034868780564`, 1.5039961118225942`}, {
             3.2520261734019416`, 1.5067125233276306`}, {3.470555605221043, 
             1.5099365899833066`}, {3.6880802109752002`, 
             1.5133509326900687`}, {3.904540461881226, 1.5169523400293325`}, {
             3.9996692228912063`, 1.5186245477993499`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.023277568695632, 1.519039543841265}, {
             4.119876829155932, 1.5207376005825137`}, {4.333901513378416, 
             1.5246966865235791`}, {4.546387247239247, 1.528817472670358}, {
             4.757215300122445, 1.5330936015700591`}, {4.9662669414120275`, 
             1.5375187157698904`}, {4.967575288182161, 
             1.5375475644450745`}}]}, 
           {Arrowheads[{{0.014099856358366074`, 1.}}], 
            ArrowBox[{{4.991181543314976, 1.538068075675112}, {
             5.173423440492018, 1.5420864578170608`}, {5.378566066746437, 
             1.546790470258779}, {5.581576089559306, 1.5516243956422533`}, {
             5.656854249492381, 1.553483294204972}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.610481433967546, 0.8541634566298831}, {
             0.6218465701350152, 0.8541813175873837}, {0.6264958193463008, 
             0.8541887184625565}, {0.7737826978446863, 0.8544514895839685}, {
             0.9209471503447273, 0.8547689459127279}, {1.0679891768464236`, 
             0.8551410874488347}, {1.2149087773497753`, 0.8555679141922888}, {
             1.3616665221856563`, 0.8560487927014221}, {1.5082229816849402`, 
             0.8565830895345663}, {1.5549573276576727`, 
             0.8567707595889053}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5785691302784057`, 0.8568655769697553}, {
             1.6545781558476271`, 0.8571708046917214}, {1.8007320446737165`, 
             0.8578119381728875}, {1.9465993439104103`, 0.8585037002874288}, {
             2.0920947493049105`, 0.8592433013447099}, {2.237218260857217, 
             0.8600307413447307}, {2.38196987856733, 0.860866020287491}, {
             2.5230361259293774`, 0.8617288708509105}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.5466476328069603`, 0.8618803573571908}, {
             2.670357432460973, 0.8626800950012307}, {2.813993368644504, 
             0.86365889077221}, {2.957257410985841, 0.864685525485929}, {
             3.1001495594849837`, 0.8657599991423875}, {3.2426698141419332`, 
             0.8668823117415858}, {3.3848181749566884`, 0.8680524632835238}, {
             3.4911005576796144`, 0.8689655268801109}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.5147116793968656`, 0.8691683681710407}, {
             3.52659464192925, 0.8692704537682013}, {3.6679992150596172`, 
             0.8705362831956186}, {3.8090318943477914`, 0.8718499515657754}, {
             3.9496926797937713`, 0.8732114588786719}, {4.089981571397557, 
             0.8746208051343081}, {4.2629427219456275`, 0.8764267307225126}, {
             4.43518190721807, 0.8782979396843382}, {4.459144377608878, 
             0.8785695735331345}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.482754853677362, 0.8788372172435616}, {
             4.6510986375915415`, 0.8807455292497843}, {4.865815026994992, 
             0.8832921505523635}, {5.079331075428419, 0.8859378035920759}, {
             5.291646782891824, 0.8886824883689212}, {5.319931704411096, 
             0.8890557899560061}, {5.348194541240777, 0.8894308018890983}, {
             5.427162009719386, 0.8905238947562366}}]}, 
           {Arrowheads[{{0.0043643709249240005`, 1.}}], 
            ArrowBox[{{5.45077174089791, 0.890850708180087}, {
             5.547819424574829, 0.8921940731485141}, {5.656854249492381, 
             0.8937559231285419}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.2299205742510666`}, {-5.637936106688844, 
             2.229243188776849}, {-5.612708252439426, 
             2.228353632165053}, {-5.587459951611667, 
             2.2274671629734075`}, {-5.377745306218484, 
             2.2203965535479173`}, {-5.166614130289887, 
             2.2135403845966914`}, {-5.006337161676349, 
             2.2084224636699727`}, {-4.845407959057491, 
             2.203457029924725}, {-4.712865403327463, 2.1995090501847088`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689263878069465, 
             2.1988060431916803`}, {-4.683826522433312, 
             2.1986440833609486`}, {-4.521592851803812, 
             2.193983623978643}, {-4.358706947168992, 
             2.189475651777809}, {-4.195168808528852, 
             2.1851201667584452`}, {-4.030978435883391, 
             2.1809171689205527`}, {-3.8661358292326096`, 
             2.176866658264131}, {-3.745110963242634, 2.1740160692861825`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721505517239152, 
             2.173460072601975}, {-3.7006409885765077`, 
             2.172968634789181}, {-3.534493913915085, 
             2.1692230984957015`}, {-3.367694605248342, 
             2.165630049383693}, {-3.2002430625762783`, 
             2.1621894874531558`}, {-3.0321392858988943`, 
             2.1589014127040893`}, {-2.8633832752161896`, 
             2.155765825136494}, {-2.777222473537866, 2.1542486243578143`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753614140432302, 
             2.1538329065293658`}, {-2.6939750305281644`, 
             2.1527827247503692`}, {-2.523914551834819, 
             2.149952111545716}, {-2.3179401448154433`, 
             2.1467613546971203`}, {-2.111497169781336, 
             2.143840832088113}, {-1.9045856267324974`, 
             2.1411905437186944`}, {-1.8092358437200244`, 
             2.1400962360549878`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785625405610418, 
             2.139825264453894}, {-1.6972055156689272`, 
             2.1388104895888644`}, {-1.4893568365906247`, 
             2.1367006696986235`}, {-1.281039589497592, 
             2.134861084047971}, {-1.0722537743898275`, 
             2.1332917326369074`}, {-0.8629993912673316, 
             2.1319926154654323`}, {-0.8411805467401559, 
             2.1318825989662336`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8175688538978317, 
             2.1317635424422536`}, {-0.7038003605258373, 
             2.1311898910124403`}, {-0.5445628584029307, 
             2.130550646657636}, {-0.3852868848986105, 
             2.1300748824010185`}, {-0.22597244001287853`, 
             2.1297625982425887`}, {-0.06661952374573371, 
             2.129613794182346}, {0.09277186390282438, 2.129628470220291}, {
             0.12690702859573297`, 2.129666614825605}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15051900685142813`, 2.1296930002143775`}, {
             0.25220172293279447`, 2.1298066263564235`}, {
             0.41167005334417717`, 2.130148262590743}, {0.5710730394640868, 
             2.1306521753484766`}, {0.7303068656196382, 2.131317161054851}, {
             0.8893715318108316, 2.1321432197098655`}, {1.048267038037666, 
             2.133130351313521}, {1.0949896786809736`, 
             2.133468336468129}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.118601053909965, 2.133639137908232}, {
             1.2069933843001415`, 2.1342785558658166`}, {1.3655505705982596`, 
             2.135587833366753}, {1.5239385969320174`, 2.13705818381633}, {
             1.6821574633014182`, 2.1386896072145474`}, {1.8413533088798633`, 
             2.1405375351133937`}, {1.9985188656794575`, 2.142456524851382}, {
             2.063029726712987, 2.143310614140239}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.086639650587353, 2.143623196901789}, {
             2.1554721475614613`, 2.1445345023385634`}, {2.3121915970492615`, 
             2.1467704249752133`}, {2.46865565666624, 2.149163250161608}, {
             2.624842768935782, 2.1517119352980236`}, {2.7807313763812704`, 
             2.1544154377847367`}, {2.9362999215260888`, 2.1572727150220223`},
              {3.0309910273561824`, 2.159098180163559}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0545986339329736`, 2.1595532900970977`}, {
             3.0645093758630075`, 2.159744350427014}, {3.1924383270286483`, 
             2.16231230839967}, {3.3200707040265343`, 2.164975194081193}, {
             3.4473904358601937`, 2.1677316126127857`}, {3.574381451533153, 
             2.170580169135652}, {3.701027680048937, 2.173519468790994}, {
             3.8273130504110733`, 2.176548116720015}, {3.9532214916230872`, 
             2.179664718063918}, {3.998837352440542, 
             2.1808288369558535`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.022441660268046, 2.181431219990628}, {
             4.078736932688505, 2.182867877963906}, {4.203843302610854, 
             2.1861562015611824`}, {4.32852453039366, 2.1895282939969496`}, {
             4.452764545040448, 2.192982760412411}, {4.576547275554744, 
             2.1965182059487693`}, {4.699856650940076, 2.2001332357472276`}, {
             4.822676600199968, 2.203826454948989}, {4.944991052337947, 
             2.2075964686952565`}, {4.966538199301528, 2.20828431469309}}]}, 
           {Arrowheads[{{0.014126041703465835`, 1.}}], 
            ArrowBox[{{4.990138170381663, 2.209037692654632}, {
             5.1881498139307505`, 2.2153587855013956`}, {5.429425633083651, 
             2.223403997525817}, {5.656854249492381, 2.2312978789968443`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9182522715369822, 0.28729609675268697`}, {
             0.9227508968674226, 0.2872999679359213}, {0.9283928325346531, 
             0.2873047998554224}, {0.9341015786365265, 
             0.28730966315215994`}, {0.9458663596645205, 
             0.2873196590305137}, {0.9670519027780486, 0.2873376731692203}, {
             0.9987733904445472, 0.28736482045027034`}, {1.0114380904314764`, 
             0.2873757040941901}, {1.0281837786467243`, 0.2873902233668884}, {
             1.0484335106300138`, 0.2874081336353916}, {1.0686872519069555`, 
             0.28742638956360217`}, {1.090963022690584, 0.287446864629667}, {
             1.0961264480599573`, 0.28745166998574906`}, {1.3260304240010412`,
              0.287666129763845}, {1.555934399942125, 0.2878805895419409}, {
             1.7597569366141197`, 0.28816713139646316`}, {1.8627313946567101`,
              0.2883290090869422}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.88634335847928, 0.28836612751654045`}, {
             1.9629790028845766`, 0.2884866001207232}, {2.165600598753496, 
             0.288838995714721}, {2.367621724220879, 0.28922431817845656`}, {
             2.5690423792867243`, 0.2896425675119299}, {2.769862563951032, 
             0.290093743715141}, {2.8308211905461467`, 
             0.29024113308968935`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.854433114526056, 0.2902982233967003}, {
             2.970082278213802, 0.2905778467880899}, {3.1697015220750355`, 
             0.2910948767307765}, {3.3111040963525142`, 
             0.29148154942160887`}, {3.4520989757990743`, 
             0.2918834289563826}, {3.6769286177116363`, 0.2925571567441455}, {
             3.7989091011204503`, 0.2929444485015123}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.8225209751052085`, 0.29301941692199013`}, {
             3.900581909031903, 0.29326726276943477`}, {4.1230588497598735`, 
             0.29401374703225036`}, {4.344359439895549, 0.2947966095325923}, {
             4.373692077656558, 0.2949030691397157}, {4.403002271919937, 
             0.295010133702649}, {4.573084108818675, 0.2956584245412458}, {
             4.742371840364574, 0.2963263960249047}, {4.766994521897121, 
             0.2964257709648547}}]}, 
           {Arrowheads[{{0.01834355988406457, 1.}}], 
            ArrowBox[{{4.790606322594593, 0.29652106608018647`}, {
             4.975645206258068, 0.2972678664612971}, {5.20733752739667, 
             0.29824515038219207`}, {5.437410655425881, 
             0.29925687511363486`}, {5.656854249492381, 
             0.30026062842449147`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.903462672227936}, \
{-5.567143280377249, -0.9021871680984431}, {-5.417916673890868, \
-0.90012214128386}, {-5.268049189556687, -0.8981046688956681}, \
{-5.117540827374705, -0.896134750933867}, {-4.936840680309042, \
-0.893844318094174}, {-4.7552736721469575`, -0.8916253876892553}, \
{-4.712455368178562, -0.8911235484468771}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688844996722685, -0.8908468300852057}, \
{-4.539904076718352, -0.8891012121712116}, {-4.323382520922611, \
-0.8866812872946517}, {-4.105709004759735, -0.8843656130595755}, \
{-3.886883528229723, -0.8821541894659831}, {-3.8578358220496485`, \
-0.8818683086759262}, {-3.828768700381698, -0.8815843169615344}, \
{-3.7444189783717143`, -0.8807980150470207}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.720808011228088, -0.8805779153451349}, \
{-3.675539764808622, -0.8801559280762012}, {-3.52178893236243, \
-0.8787807168393493}, {-3.390077584252112, -0.8776255857465327}, \
{-3.2580935272676275`, -0.8765139151362377}, {-3.1258367614089773`, \
-0.8754457050084643}, {-2.993307286676161, -0.8744209553632126}, \
{-2.860505103069179, -0.8734396662004825}, {-2.7763601455075895`, \
-0.8728466651239845}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752748738838445, -0.8726802666851691}, \
{-2.7274302105880306`, -0.8725018375202741}, {-2.5940826092327165`, \
-0.8716074693225874}, {-2.460462299003236, -0.8707565616074222}, \
{-2.3265692798995907`, -0.8699491143747788}, {-2.1924035519217786`, \
-0.8691851276246569}, {-2.0579651150698, -0.8684646013570568}, \
{-1.9232539693436563`, -0.8677875355719783}, {-1.8082848648834713`, \
-0.8672478781853088}}]}, 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAZMaNaAWO/L8SlKCvmL/rv8G2aFa+
cvq//OXM+eO6678fgWKYnUf4v8Wr4X5ptuu/Mimh5V4b9r/CraEoSrLrv890
QaWJ/vW/bLgYIRay67/t7sDts+H1v2Ut71viseu/PtGnvt3E9b+9VQfZrrHr
vz7gYxcHqPW/LRpKmHux678sz233L4v1v5uOnZlIseu/bhyNxIBR9b87sxUg
47Drv6AxfKnPF/W/YVfSrX6w67+rHNOhHN70v7Q2DUIbsOu/sfJPn7ic8r8j
1tSycazrv3IeM1S/WvC/rEA5iDKp678Av9QjizDsvzIXvTBepuu/5bBEUuUA
7L9MtKagQqbrvzXO58hcweu/FCytHx6m67/HRGRk04Hrv+UMDOj5peu/ZMMu
4uji6r+tWdz/o6Xrv5NGuXU=
             "]]}, 
           {Arrowheads[{{0.0062932985557515, 1.}}], 
            ArrowBox[{{-0.8165869968921856, -0.8639203779160208}, \
{-0.7820210572650002, -0.8638509483014722}, {-0.6850215168361569, \
-0.8636681768123503}, {-0.5894448660042232, -0.8635111114989721}, \
{-0.5853192521821082, -0.8635048470246955}, {-0.5780477341031285, \
-0.863493876975851}, {-0.5710754664568007, -0.8634834447485009}, \
{-0.5643837336245171, -0.8634735113799119}, {-0.5193928000274693, \
-0.8634086083031473}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.0023655801903823413`, 1.}}], 
            ArrowBox[{{-0.5624723704361158, 
             0.8627005419373066}, {-0.524828422380134, 
             0.8626461832826842}, {-0.49548328299277344`, 
             0.8626057193952555}, {-0.4733974738937274, 
             0.8625764801388941}, {-0.46415278723140957`, 
             0.8625645128864771}, {-0.45696541087190373`, 
             0.8625553650705441}, {-0.45076034961298705`, 
             0.8625475730577624}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.30281304779688295`}, \
{-5.537386326406652, -0.3022537423353476}, {-5.378970171134497, \
-0.30153432171032907`}, {-5.219766518012572, -0.30083102664301076`}, \
{-5.059787774668274, -0.3001443145953068}, {-4.8990463487289935`, \
-0.2994746430291314}, {-4.7375820174339855`, -0.2988231115860189}, \
{-4.712383400692092, -0.29872484994359894`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688771587213913, -0.29863277601761146`}, \
{-4.5754345580225015`, -0.29819081990750357`}, {-4.412603970494543, \
-0.2975777679935854}, {-4.249090254850108, -0.29698395584426446`}, \
{-4.084893411089198, -0.29640938345954065`}, {-3.9200134392118127`, \
-0.2958540508394141}, {-3.754450339217952, -0.29531795798388466`}, \
{-3.7442978187787, -0.295286394190652}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7206859398924204`, -0.29521298577276606`}, \
{-3.588204111107615, -0.29480110489295247`}, {-3.421357271910911, \
-0.2943050779727416}, {-3.253992338657948, -0.2938314636293762}, \
{-3.0861093113487263`, -0.2933802618628562}, {-2.917708189983245, \
-0.29295147267318167`}, {-2.776209829374766, -0.29261106365363126`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525979047050098`, -0.2925542593762392}, \
{-2.748788974561504, -0.2925450960603526}, {-2.5793516650835047`, \
-0.29216113202436905`}, {-2.4093962615492455`, -0.2917995805652309}, \
{-2.2389227639587275`, -0.2914604416829383}, {-2.142775090872801, \
-0.29127967121456955`}, {-2.0464992262020747`, -0.29110648409295925`}, \
{-1.813965673829792, -0.29072117044478274`}, {-1.808120003903793, \
-0.29071266292249875`}}]}, 
           {Arrowheads[{{0.01833918921319906, 1.}}], 
            ArrowBox[{{-1.7845080359115555`, -0.29067829913761095`}, \
{-1.5809178767764636`, -0.290382003274594}, {-1.347355835042089, \
-0.290088982582393}, {-1.1132795486266684`, -0.28984210836817975`}, \
{-1.084982332504597, -0.28981508300889475`}, {-1.0566793739790201`, \
-0.28978872922428994`}, {-1.0117042116242134`, -0.28974949926498716`}, \
{-1.0009226254413106`, -0.2897401531337038}, {-0.9907959361342339, \
-0.2897314145322127}, {-0.9722699026155739, -0.2897154702848129}, \
{-0.9574285649844985, -0.28970275297276127`}, {-0.9463524382647927, \
-0.28969327829840313`}, {-0.9345147244084289, -0.28968315149866714`}, \
{-0.9283166020898832, -0.2896778357976881}, {-0.922765707327023, \
-0.2896730480846203}, {-0.9184590276918367, -0.28966931659192824`}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(inc\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(inc\\)]\\)}\"", 
           TraditionalForm]}}], {972., -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.01941982371346445, 1.}}], ArrowBox[CompressedData["

1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAIdtsvB8I8L9Ln7mhAhotP/z/cQ0D
APC/YelY6HgULT8Ep2l4o4Xvv532ODCb6iw/oz5/tltM77/Pza/07dYsP2Ws
fKPdau6/fea0n7GJLD8MlJwnYR/rv2C8yB7Pays/kzlTBC0m6L+iBRyGOW0q
PxAdIEi3c+W/5YtB0HOIKT9mYfjLUobZvyVPUAZKpSY/QgEF0yUL0L8kgD1j
WgElP0VmLofeEcG/Sg6yCZqcIz8RH9Pd1ZikvwX5idpUZCI/lJEEeAYJlL9V
1gXQtRoiP2z0ADC1hRq/MH1HLvrSIT+w1Wq/QPmUP17Svp0LgiE/rxzenStV
pD9kBtgvPjMhP7zE8y4LXLM/LII6f86ZID8gJsquwVS7P9lR9J0uCCA/1tk8
3lAewT+28Zku+foeP3JV5w1Iycg/4R7pT+ILHD+Rpak6K8jNP8oGPYMpcRk/
YEW5guWA0D+HS0BOeBsXP3JRCHbMhtE/oOAnzscAFT9+i/rjD0jSPyDNRcT2
tRI/FwvYuNy40j90uHOAtawQP6EkuQI=
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.014414972161054328`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAvuic9tzD3r/+NGzA0FDsP9Rw149x
N96/EPjKI4E17D+J63+H46Ldv95M7WZ8GOw/UAnlueEZ3b8YCdURhv3rP7rY
19PwTdy/GfUw9RDV6z9eVN3gNu/bv9RpWS01wus/tu56wuSy0r8YJ7GhTuTp
PwlwZuKWg8a/441v0wVS6D+mSMuLisHCvz8JfLhF6ec/UzfIGMpvvr9bIlMT
sITnP6HmPA5czre/kdLy0CAi5z9EOzDc1o6xv+3SHYfpwuY/yx7dudYfl78i
jzPgtwrmP3dVxSKPkJI/A5q8jBRe5T/eBxUojLqrP0YZ5HFVu+Q/3Ymf6NQ6
wT87SqqpQxzjP4EpTiTAgsg/hVvRMRWv4T/jTXVy65rNPz/xy/6faOA/FWhB
jX2P0D9/S53dWoLeP10hdFIuTdI/f5b8yyYt2z+7UcQySjfTP21FS9G3Q9g/
j8+2tA==
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.013622928574334489`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAA17uZKJ3J1r/pVCq/twPuvxiELr79
g9a/aLm5+ET07b/Kvr4EXE7UvxWzgH96de2/bykuuhRy0r8pnLlwiwjtv3fK
Pu8eY8a/S3KUdLNS67+aOgX/rYrCv228LTo32+q/bfHF6K3avb/KzYCBvmjq
v7LuLg4eOre/FzMWAgn76b+IIQ2BNvuwv30V1wUmkem/d/orFTXTlL9naqWe
fMTov5wBB6CW4ZQ/u9on5O8E6L9oSds/gOisP2qgii+KUOe/WfBWzA2KwT+S
BNOzKIblvzF4Pf0J3Mg/OzP01Nfz47+eC22fOQDOPyBEAbWfjOK/d8Oc6+3H
0D+8PZ52vEfhv+FxZMGYldI/M/kndCfN3r+FKzoq1YLTP2qm7qTdhtu/XXXM
egbw0z+5y0G2hKbYv0l7qts=
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.011961175661051109`, 1.}}], 
            ArrowBox[{{-0.8480647792439302, -0.5578593331721807}, \
{-0.832189202761891, -0.5544806609177144}, {-0.8140738600139452, \
-0.5506061137061733}, {-0.7958179026478102, -0.5466707570459332}, \
{-0.7735572139481747, -0.5418485820760256}, {-0.7616632952727073, \
-0.5392676848677646}, {-0.7499281435104523, -0.5367243553560339}, \
{-0.697756876902744, -0.5254806197709939}, {-0.6484808652006594, \
-0.514892329090767}, {-0.5115818135509363, -0.48544665055362696`}, \
{-0.39556293950191057`, -0.4602668679829893}, {-0.29639940457379393`, \
-0.43823507264257405`}, {-0.17057235855129851`, -0.4089157003747327}, \
{-0.07010696598507765, -0.3834582034752906}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0029773876057170605`, 1.}}], 
            ArrowBox[{{0.8269720396422747, 0.5670063001400728}, {
             0.824122179330463, 0.5664079538503484}, {0.8073826797211693, 
             0.5628612145567791}, {0.7931764052172232, 0.5597804211523189}, {
             0.7851253809075304, 0.5580188783501743}, {0.7763706606956149, 
             0.5560788978135265}, {0.7416950119141301, 0.5482604343099562}, {
             0.7120977488465284, 0.5405941072307943}, {0.6848731612208585, 
             0.533062489545706}, {0.634677593750564, 
             0.5182490809229026}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.00978319134756282, 1.}}], 
            ArrowBox[{{-0.8858288267470165, 
             0.5039259949685118}, {-0.8659388195963524, 
             0.5001481435267559}, {-0.8384023501449044, 
             0.4948848316121719}, {-0.8033861056066712, 
             0.4881414001920705}, {-0.7635890438452247, 
             0.48045962841694234`}, {-0.7152878713023544, 
             0.47114370553979307`}, {-0.6695507832083407, 
             0.46236038703774}, {-0.61978691258357, 
             0.45284233399383916`}, {-0.5727715034622736, 
             0.44385296269272306`}, {-0.4458386267518427, 
             0.4194621429474153}, {-0.33793453669455215`, 
             0.39835780379196706`}, {-0.24562737674005508`, 
             0.3797180686322631}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.00493064806727922, 1.}}], 
            ArrowBox[{{0.9400296248306893, -0.3621793810765735}, {
             0.9324014702453411, -0.3614172399897409}, {
             0.9185355579317405, -0.360016694321332}, {
             0.90408763187849, -0.35853106984602595`}, {
             0.8961789018244274, -0.3577113166328484}, {
             0.8875936960199302, -0.3568125217413452}, {
             0.8253164223003516, -0.34954350130840267`}, {
             0.7922130061674051, -0.3454438645394076}, {
             0.7616123363166811, -0.34141891260590346`}, {
             0.7048909957561068, -0.3335003679478519}, {
             0.6562996088223172, -0.325823985572575}, {
             0.6143816880816275, -0.3183512979055771}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0009996470517530218, 1.}}], 
            ArrowBox[{{0.5715320246090861, -0.824145753620186}, {
             0.5693151097337568, -0.8221017190969717}, {
             0.5430893534362335, -0.797293657535656}, {
             0.5237686030234168, -0.7776958032120698}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.007235551419015093, 1.}}], 
            ArrowBox[{{0.9382390252772566, 0.11528983657263348`}, {
             0.9042925524368527, 0.11425693974309116`}, {0.872156411746349, 
             0.11323047178469633`}, {0.7623274405455602, 
             0.10928668213436832`}, {0.7269925796979204, 
             0.10787395105685782`}, {0.6948270334156837, 
             0.1064866272191415}, {0.6662836236725107, 
             0.10506392770099277`}, {0.6400535553219923, 
             0.1036607181250148}, {0.5917495352416888, 0.1008894778605832}, {
             0.550975604560588, 0.09818546709022623}, {0.5163609503535059, 
             0.09554386467505784}, {0.4566950770559727, 
             0.08985094289211802}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sp\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(sp\\)]\\)}\"", 
           TraditionalForm]}}], {1360.8000000000002`, -192.}, 
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.282007800816898}, \
{-5.548728896461246, -2.280948803221868}, {-5.3850113408909, \
-2.28066155796573}, {-5.2206959171774665`, -2.281819316175295}, \
{-5.055782625320946, -2.284422077850562}, {-4.89027146532134, \
-2.288469842991532}, {-4.724213813930336, -2.2939286832127888`}, \
{-4.712553590773591, -2.2944072650750913`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688961461153646, -2.2953755797614757`}, \
{-4.557661047899627, -2.300764670128915}, {-4.390613167229211, \
-2.308977803739911}, {-4.2230701719190895`, -2.318568084045777}, \
{-4.05502188636405, -2.329263527697503}, {-3.8864581349588785`, \
-2.34079215134608}, {-3.746176551005454, -2.3510484881333706`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722627414335389, -2.352770224300951}, \
{-3.717378917703577, -2.353153954991508}, {-3.547784234598145, \
-2.3663489386337857`}, {-3.4132312096179906`, -2.377237707262017}, \
{-3.2781972346115076`, -2.3883177104019473`}, {-3.084406276619915, \
-2.4038179610298083`}, {-2.889824292021033, -2.418448853577641}, \
{-2.780987089392491, -2.425844560332598}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.757429422233162, -2.4274453511829095`}, \
{-2.6942794441154185`, -2.4317365191701534`}, {-2.497599896203627, \
-2.443207088932052}, {-2.4717766603395632`, -2.444589851268135}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.3367417456254254`, \
-2.450393158221454}, {-2.2273245388171317`, -2.4537432732888727`}, \
{-2.082689536808637, -2.456884267996474}, {-1.9377042169244993`, \
-2.457461164542653}, {-1.8136905612750371`, -2.45576550241451}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7900816770204682`, -2.4554025189973965`}, \
{-1.646682623529297, -2.450922663150745}, {-1.50099161252487, \
-2.4432366995217536`}, {-1.3556408086580756`, -2.431845506349533}, \
{-1.210630211928914, -2.4167490836340826`}, {-1.0659598223373856`, \
-2.397947431375403}, {-0.9222937687249267, -2.375126019521786}, \
{-0.8514064655614512, -2.3615694904198277`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8282147589716082, -2.357134294957754}, \
{-0.7802961799329737, -2.347970318021523}, {-0.6399670559615266, \
-2.3164803268746152`}, {-0.5013063968105858, -2.2806560460810616`}, \
{-0.31098136983723457`, -2.223258781690965}, {-0.12713638317643558`, \
-2.157778194259008}, {0.04888814566967911, -2.085130147390317}, {
             0.07084143368014735, -2.074749776689525}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.09218746014041412, -2.0646565429315187`}, {
             0.21575179919897627`, -2.0062305046900204`}, {
             0.37267846648805686`, -1.922261766009823}, {
             0.5182711478748028, -1.8353524310827942`}, {
             0.6830604029589483, -1.7243323694785146`}, {
             0.8304715723628495, -1.6131902974809635`}, {
             0.8897503376619827, -1.564131336639469}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9079407816429097, -1.549076969794167}, {
             0.9612799787304573, -1.504933581043912}, {
             1.0782041755721012`, -1.4017037133560433`}, {
             1.1836493338480438`, -1.3052100285165293`}, {
             1.280678857401671, -1.216296765152484}, {
             1.4615887866429116`, -1.0635955640836374`}, {
             1.5894136405146924`, -0.9764552275159812}, {
             1.6368059077150763`, -0.9520907479867887}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.6578053302792999`, -0.9412948939073126}, {
             1.727395905434577, -0.9055182104111124}, {
             1.8819283858221, -0.8495553240849134}, {
             2.0572441197147935`, -0.8062409571646052}, {
             2.2554428491791647`, -0.7735301342015204}, {
             2.4754111371197, -0.7491103043267723}, {
             2.574224923441173, -0.7417053066137992}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.597770893793853, -0.7399407971956085}, {
             2.7158209173194137`, -0.7310942567809009}, {
             2.842650302394677, -0.723998119156228}, {
             2.9735229048588416`, -0.7178863332037633}, {
             3.130575166805083, -0.711880874628497}, {
             3.292012765125514, -0.7069876844842755}, {
             3.4573007976396073`, -0.7030014956729954}, {
             3.5413256901713224`, -0.7013646622905892}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.56493320426191, -0.7009047799155596}, {
             3.6259043621668376`, -0.6997170410965534}, {
             3.797429381366048, -0.6970526736104213}, {
             3.9715622492328606`, -0.6949973860435424}, {
             4.147888770591924, -0.6934518712580209}, {
             4.325994750267884, -0.6923168221159606}, {
             4.505555225615509, -0.691544055037406}, {
             4.509356472095318, -0.6915350229703692}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.532968398439773, -0.6914789191363385}, {
             4.68629622400678, -0.6911145999040826}, {
             4.8678800352921625`, -0.6909729697706148}, {
             5.04996894932212, -0.6910636776916271}, {
             5.232396666953417, -0.6913658232662657}, {
             5.415094838189271, -0.6918782698334031}, {
             5.477446185591138, -0.6921160067628235}}]}, 
           {Arrowheads[{{0.00329911992555951, 1.}}], 
            ArrowBox[{{5.501058006956607, -0.6922060353210401}, {
             5.597872676599831, -0.6925751760572536}, {
             5.656854249492381, -0.6928514178572515}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.2825287544134887`}, {-5.520053595080689, 
             2.2813714911550984`}, {-5.358507805547019, 
             2.2813158038864008`}, {-5.196381459699141, 
             2.2826706848609306`}, {-5.033674557537055, 
             2.2854361340786875`}, {-4.870387099060762, 
             2.289612151539671}, {-4.712552450413695, 2.294956765982164}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688959316177079, 
             2.295896704982165}, {-4.542278332791115, 
             2.302038178997062}, {-4.377508979904153, 
             2.310248760944905}, {-4.212262980515764, 
             2.3197910550388454`}, {-4.046526713744821, 
             2.3304018160086413`}, {-3.880286558710195, 
             2.3418177985840507`}, {-3.7461783931961405`, 
             2.351647014912681}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7226295663688194`, 
             2.3533729837400372`}, {-3.7135425154118877`, 
             2.354039002765073}, {-3.546294583849898, 
             2.3670654285517085`}, {-3.4117829763168275`, 
             2.3779551531539287`}, {-3.2767918324467162`, 
             2.3890326937812514`}, {-3.08300731765812, 
             2.404528834018369}, {-2.8884307828147042`, 
             2.4191534275909823`}, {-2.7809894599271803`, 
             2.4264496372423765`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7574317239115667`, 
             2.4280494144627487`}, {-2.6928903872196317`, 
             2.4324323381929283`}, {-2.4962142901760656`, 
             2.4438914295180423`}, {-2.4703920398316472`, 
             2.445272478789898}, {-2.444546998600464, 
             2.446612201231679}, {-2.335405997872479, 
             2.4510608608872784`}, {-2.2260368062657228`, 
             2.4543980181989618`}, {-2.079642642200022, 
             2.457541144353057}, {-1.9328962995340453`, 
             2.458047484981094}, {-1.8136944409732474`, 
             2.4563210706757737`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.790084924019127, 
             2.455979131310873}, {-1.7857977782677932`, 
             2.4559170400830728`}, {-1.6383470784012655`, 
             2.4511498096589928`}, {-1.4909056391991173`, 
             2.4431580772025425`}, {-1.343834899926004, 
             2.43135412620741}, {-1.197134860581925, 
             2.415737956673595}, {-1.050805521166881, 
             2.396309568601098}, {-0.9055411149810035, 
             2.372750293446155}, {-0.8514045642820404, 2.362184118362714}}]}, 
           
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8282298523487925, 
             2.357660962368594}, {-0.7620358753244247, 
             2.3447414626650023`}, {-0.6202898021971445, 
             2.31228307625764}, {-0.4803028955991631, 
             2.2753751342240687`}, {-0.2921147795044033, 
             2.217572446502141}, {-0.11044536483375986`, 
             2.1518777646937854`}, {0.06340787329326403, 2.079211359507904}, {
             0.07096415529090679, 2.0756007256282967`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.092268896709258, 2.065420636904059}, {
             0.22814745975716533`, 2.000493501653399}, {0.3830356733091191, 
             1.9168901343720492`}, {0.5267446157012392, 
             1.8304999554990575`}, {0.6895227188772328, 
             1.7202563592429538`}, {0.8352561557148509, 
             1.6100604091272042`}, {0.8898599333813291, 1.564843485388354}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9080459643724151, 1.5497837878440002`}, {
             0.9647407653446409, 1.5028353054952373`}, {1.0806233383095347`, 
             1.40060460136675}, {1.1852658556160438`, 1.3050198134000501`}, {
             1.2816709644404527`, 1.2169105982301904`}, {1.4616378615002092`, 
             1.06545241148801}, {1.589978011302253, 0.97819387559947}, {
             1.6376730379345883`, 0.9537461577052686}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.658685417302923, 0.942975543673685}, {
             1.728505022507562, 0.9071871159894808}, {1.8836244674065092`, 
             0.8511958223197584}, {2.059565847520591, 0.8078792453683461}, {
             2.258421675624709, 0.7751826851857143}, {2.479059440362729, 
             0.7507852716529243}, {2.5751952405937986`, 
             0.7436108014701862}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.59874175451171, 0.7418535605505139}, {
             2.720136847317434, 0.7327940273529745}, {2.8472945356708945`, 
             0.7257105033409252}, {2.9784893069450065`, 0.7196107824860957}, {
             3.135927080600736, 0.7136181763378353}, {3.297742927298846, 
             0.7087378493298795}, {3.4634006968784563`, 0.7047643165370839}, {
             3.5422949967216324`, 0.7032364142531495}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.5659025630163055`, 0.7027792195694846}, {
             3.6323642391786835`, 0.7014920930343046}, {3.8042396042293642`, 
             0.6988396019557566}, {3.978714099312176, 0.6967960710410025}, {
             4.155373460143995, 0.6952622222729203}, {4.333803422441697, 
             0.6941387776343881}, {4.510325611443434, 
             0.6933918084012691}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.533937520482963, 0.6933308714326233}, {
             4.694728058099281, 0.6929598512335727}, {4.876611996160079, 
             0.6928300529199671}, {5.058993819613972, 0.6929327928137553}, {
             5.241704227887772, 0.6932471376633808}, {5.424669974978575, 
             0.6937718659523145}, {5.478415310720035, 
             0.6939801343926835}}]}, 
           {Arrowheads[{{0.003278598082015132, 1.}}], 
            ArrowBox[{{5.502027126436622, 0.6940716324913693}, {
             5.607697746670625, 0.694481116495243}, {5.656854249492381, 
             0.6947143823246373}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.7312598438642754`}, \
{-5.619878517714344, -3.7296074664359775`}, {-5.4781572696061405`, \
-3.72444947242611}, {-5.331251146743564, -3.720478326404202}, \
{-5.183201129767483, -3.7181178950216913`}, {-4.991648311514058, \
-3.717521824890538}, {-4.798943539359363, -3.7197301049813793`}, \
{-4.712620176986938, -3.7219622024264223`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6890160735809285`, -3.7225725430973267`}, \
{-4.605086813303399, -3.7247427352942153`}, {-4.410078133346164, \
-3.7325597158290456`}, {-4.213971352263637, -3.7429086608624424`}, \
{-4.016820322831795, -3.7555171846709774`}, {-3.818625045050636, \
-3.770385287254651}, {-3.7462206072978637`, -3.776609554913174}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.722695380350075, -3.778631907600319}, \
{-3.6193855189201622`, -3.787512968613463}, {-3.4192826874833453`, \
-3.806082509996649}, {-3.218497493783159, -3.8252761926534435`}, \
{-3.0170299378196033`, -3.845094016583847}, {-2.8148800195926786`, \
-3.8655359817878594`}, {-2.782531138729456, -3.868717267227174}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7590325039794625`, -3.871028193063836}, \
{-2.612428212686224, -3.8854456963834765`}, {-2.410054990684082, \
-3.9036667684886934`}, {-2.207760353586253, -3.9201991981035103`}, \
{-2.0055443013927348`, -3.935042985227927}, {-1.8176430707052285`, \
-3.9464500188778735`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.794065568753061, -3.9477099582225574`}, \
{-1.603758021266325, -3.955982869820278}, {-1.4047903107203543`, \
-3.961158526741892}, {-1.20710621985254, -3.9628046600804643`}, \
{-1.0112899711875, -3.9606831402277827`}, {-0.8499322225405326, \
-3.9555700539204026`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8263320752862846, -3.9548222150915286`}, \
{-0.8179257872498524, -3.954555837575634}, {-0.6270136680395968, \
-3.944422752124018}, {-0.4385536135567343, -3.930283883872936}, \
{-0.25283395797719077`, -3.912583725730089}, {-0.07014303547689316, \
-3.8917667706031804`}, {0.1095191539441579, -3.86783301849221}, {
             0.11368559373591125`, -3.867194948635726}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13702547295714546`, -3.8636205603979485`}, {
             0.28615261028596206`, -3.8407824693971775`}, {
             0.4598869547769667, -3.8114439928290023`}, {
             0.6308518086456179, -3.780646458298603}, {
             0.7990471718919159, -3.7483898658059798`}, {
             0.9644730445158616, -3.7146742153511325`}, {
             1.065867441771835, -3.693333223281218}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0889731911505163`, -3.6884700392433953`}, {
             1.1276118916212043`, -3.680337556358221}, {
             1.288946178311695, -3.6462179382514046`}, {
             1.4484759045873337`, -3.6123153610306833`}, {
             1.60620107044812, -3.578629824696057}, {
             1.836731322260405, -3.5307375261935383`}, {
             2.013664892329546, -3.4962428369363803`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.036840553407838, -3.491724546671212}, {
             2.066405467919876, -3.4859606176519273`}, {
             2.2952235074265315`, -3.444299099071224}, {
             2.523185440780373, -3.405752970451429}, {
             2.641467837543986, -3.3871446257944386`}, {
             2.760165264889335, -3.36968832219409}, {
             2.8835662634776753`, -3.3527407339886905`}, {
             2.9691780205535783`, -3.3417858826173408`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.992599047937872, -3.338788935904382}, {
             3.0074191588924934`, -3.3368925595378647`}, {
             3.1317239511337895`, -3.322143798841612}, {
             3.2564806402015636`, -3.3084944518999326`}, {
             3.273219344611199, -3.3067400401885956`}, {
             3.289965940303304, -3.3050036765994997`}, {
             3.426373552736023, -3.2923698631403653`}, {
             3.5635342989843015`, -3.2809715238897703`}, {
             3.692153734635488, -3.27074319464013}, {
             3.8213042917575777`, -3.261391147261331}, {
             3.933120708834593, -3.254083023697792}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.956684887620479, -3.252582781359858}, {
             4.081198770414469, -3.245315898116256}, {
             4.21194269194927, -3.238592696349981}, {
             4.343217734954975, -3.232745776454547}, {
             4.4750238994315845`, -3.2277751384299536`}, {
             4.607361185379097, -3.223680782276202}, {
             4.740068733673832, -3.220318753408256}, {
             4.872985685192106, -3.2175450972410795`}, {
             4.900417612731249, -3.217094799192889}}]}, 
           {Arrowheads[{{0.0155186998718147, 1.}}], 
            ArrowBox[{{4.924026425178154, -3.2167072579911355`}, {
             5.00611203993392, -3.2153598137746733`}, {
             5.139447797899273, -3.213762903009037}, {
             5.272992959088167, -3.2127543649441708`}, {
             5.4067475235005995`, -3.212334199580074}, {
             5.540711491136572, -3.2125024069167476`}, {
             5.656854249492381, -3.213157315501832}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.7322610931878883`}, {-5.614361280204128, 
             3.7303741273423037`}, {-5.4730422436639214`, 
             3.725273465989201}, {-5.3266916652519445`, 
             3.721362265160093}, {-5.179256806775118, 
             3.719053874560369}, {-4.987631959845272, 
             3.718510984672582}, {-4.794856627341015, 
             3.7207735816691}, {-4.712620874491153, 3.722922742093302}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689016940779382, 
             3.723539610528634}, {-4.600930809262349, 
             3.7258416655499227`}, {-4.405854505609276, 
             3.73371523631505}, {-4.209681629856918, 
             3.7441179480593187`}, {-4.012466095480402, 
             3.7567734548775658`}, {-3.8142079024797266`, 
             3.771681756769791}, {-3.7462187095863766`, 3.777536067588758}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7226937663525224`, 
             3.779561717899177}, {-3.614907050854895, 
             3.788842853735994}, {-3.414743072424041, 
             3.8074397806898634`}, {-3.213895499005301, 
             3.826655572545087}, {-3.0123643305986754`, 
             3.8464902293016645`}, {-2.8101495672041663`, 
             3.8669437509595963`}, {-2.7825307367992345`, 
             3.8696593159339328`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759032056210285, 
             3.8719697756099904`}, {-2.6076349939242323`, 
             3.886855581907131}, {-2.4052043958613334`, 
             3.9050651665325185`}, {-2.2028577730154706`, 
             3.921572504835758}, {-2.0005951253866456`, 
             3.9363775968168495`}, {-1.8176469866712166`, 
             3.9474357669276574`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7940735907138763`, 
             3.9487750745328873`}, {-1.5987519564998558`, 
             3.9572049515873804`}, {-1.3997789854218305`, 
             3.9623081918205174`}, {-1.2021050899207173`, 
             3.963871140618903}, {-1.006309243152957, 
             3.9616622834849577`}, {-0.8499404664078345, 
             3.9566379920256693`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8263406525353731, 
             3.955879705456264}, {-0.8129704182749897, 
             3.9554501059211047`}, {-0.6220886152868144, 
             3.9452346079273437`}, {-0.4336638341884314, 
             3.9310157895036744`}, {-0.24798227707291132`, 
             3.913240817891663}, {-0.06533014603332415, 
             3.8923568603328755`}, {0.11369438883450225`, 
             3.868443816867336}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.1370348002785289, 3.8648736445786214`}, {
             0.29088583781805155`, 3.8412619873749714`}, {0.4645816499396501, 
             3.8118809362444876`}, {0.6355119546049357, 
             3.7810506277044924`}, {0.8036767518139084, 3.748771061754986}, {
             0.969076041566568, 3.7150422383959687`}, {1.0658913539708992`, 
             3.6946600168979975`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.088996862214227, 3.6897956873292213`}, {
             1.1321939107908847`, 3.680701549322714}, {1.2935144464148285`, 
             3.6465863862304975`}, {1.453037648438399, 3.6126967491193183`}, {
             1.6107635168615966`, 3.579032637989177}, {1.8413309054554603`, 
             3.5311797393777002`}, {2.0136996086305867`, 
             3.4976220163626954`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.036876456042275, 3.493109815415101}, {
             2.0710609665422317`, 3.4864545797857214`}, {2.299953700121911, 
             3.4448571592132406`}, {2.528009106194498, 3.4063874776602576`}, {
             2.6464527998643894`, 3.3878050147450365`}, {2.7653125298454713`, 
             3.3703753626056216`}, {2.8887093024784662`, 
             3.3534789350874594`}, {2.9692194768892146`, 
             3.343208110241286}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9926416464052714`, 3.340220102795302}, {
             3.012557267828296, 3.337679431869724}, {3.136856425894961, 
             3.3229768529524155`}, {3.26160677667846, 3.3093711983355343`}, {
             3.278344924715703, 3.3076224360700266`}, {3.2950909439440763`, 
             3.305891680315892}, {3.431669083288511, 3.2932904757615793`}, {
             3.5690003235384644`, 3.281924937703612}, {3.693819077349654, 
             3.2720298691918397`}, {3.819140153341933, 3.262963099975586}, {
             3.9331604940796283`, 3.2554974524000446`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.956726992234531, 3.254034595573952}, {
             4.071289271869762, 3.247314459429636}, {4.198117314405311, 
             3.240732588099939}, {4.325447679121951, 3.2349790160657608`}, {
             4.453280366019681, 3.230053743327102}, {4.581615375098501, 
             3.2259567698839615`}, {4.71031775132821, 3.2225555286063963`}, {
             4.839252539678609, 3.219717452364462}, {4.90046329972658, 
             3.218639399705028}}]}, 
           {Arrowheads[{{0.015517739655681583`, 1.}}], 
            ArrowBox[{{4.924071631502779, 3.218223606389667}, {
             4.968419740149697, 3.217442541158159}, {5.097819352741475, 
             3.2157307949874863`}, {5.227451377453942, 3.214582213852445}, {
             5.357315814287099, 3.2139967977530346`}, {5.487412663240945, 
             3.213974546689255}, {5.61774192431548, 3.2145154606611066`}, {
             5.656854249492381, 3.214818135169097}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.000301042739701199}, {-5.494741693861904, 
             0.000301148990286657}, {-5.330205724022385, 
             0.0003014751514031049}, {-5.165482338161477, 
             0.00030201975754951725`}, {-5.000571536279184, 
             0.000302782808725894}, {-4.835523767692187, 
             0.000303763583176922}, {-4.712374529582777, 
             0.000304656827104465}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688762536585429, 
             0.0003048280930390811}, {-4.670389481717173, 
             0.00030496135914728794`}, {-4.50516867835414, 
             0.00030637613663699184`}, {-4.339861357603091, 
             0.0003080079156460336}, {-4.17434170376519, 
             0.00030982106895338456`}, {-4.008483901141603, 
             0.0003117799693380157}, {-3.8422879497323312`, 
             0.00031388461679992717`}, {-3.7442828167250157`, 
             0.0003152089714868905}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720670823729202, 
             0.00031552804307664303`}, {-3.675753849537374, 
             0.0003161350113391188}, {-3.5376243466297015`, 
             0.00031807461498060957`}, {-3.3988740002768636`, 
             0.00032003410727919065`}, {-3.2665914555800377`, 
             0.000321865929510498}, {-3.1333655716560873`, 
             0.0003236448085821789}, {-2.9989018560232497`, 
             0.00032531931906711135`}, {-2.8629058161997625`, 
             0.00032683803553817335`}, {-2.776191103888842, 
             0.0003276058691355807}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752579110891798, 
             0.0003278149464771496}, {-2.6899803379942844`, 
             0.00032836924043380645`}, {-2.5129238586434184`, 
             0.0003293627612649525}, {-2.4827992234689575`, 
             0.0003294846373431698}, {-2.452515032802536, 
             0.0003295841120093276}, {-2.3408492260933875`, 
             0.00032949421391230616`}, {-2.226128901617202, 
             0.0003289478587213244}, {-2.051487154749163, 
             0.00032731515645265346`}, {-1.8664379379046214`, 
             0.00032403094566311097`}, {-1.8080993910383332`, 
             0.00032244519766915083`}}]}, 
           {Arrowheads[{{0.01696840901736136, 1.}}], 
            ArrowBox[{{-1.7844873980490865`, 
             0.00032180338067974387`}, {-1.7229936189819584`, 
             0.0003201318677258778}, {-1.568947578923792, 
             0.0003144031592931778}, {-1.4473346522769202`, 
             0.0003085563908985084}, {-1.3153557225401336`, 
             0.0003007245263743099}, {-1.2449092807075028`, 
             0.00029592301636457546`}, {-1.1704508534854492`, 
             0.0002902574902816665}, {-1.0913857071690258`, 
             0.0002835297892746597}, {-1.0499710173213201`, 
             0.0002797060186308524}, {-1.0077528516876508`, 
             0.00027558089340633284`}, {-0.9831714899113135, 
             0.00027309359914942904`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.752248477576202}, {-5.628488841326881, 
             4.749831228509128}, {-5.41055189123862, 
             4.734938495353614}, {-5.18494920543736, 
             4.723997027643388}, {-4.952781810083919, 
             4.717179844281658}, {-4.715150731339112, 
             4.714659964171635}, {-4.713364294454337, 4.714679322096877}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689753687595002, 
             4.714935167890472}, {-4.473857071601296, 
             4.717274635121558}, {-4.230141872278791, 
             4.7253297218156405`}, {-4.107457737359461, 
             4.73120240363461}, {-3.984266068047376, 
             4.7382011684710585`}, {-3.860599481177008, 
             4.746248009352135}, {-3.746321578688655, 4.7545506666099095`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722780050557887, 
             4.756371113985723}, {-3.6118856181012546`, 
             4.7653183038296065`}, {-3.486762187204352, 
             4.776422054799505}, {-3.3612000471800823`, 
             4.78841939480209}, {-3.235278944316403, 
             4.801153546424773}, {-3.1090786249012727`, 
             4.814467732254964}, {-2.98267883522265, 
             4.828205174880073}, {-2.8561593215684935`, 
             4.842209096887509}, {-2.7830371565856145`, 
             4.85036351288606}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759570629914382, 
             4.852980446076742}, {-2.7295998302267592`, 
             4.856322720864686}, {-2.5141788523082376`, 
             4.879854634909764}, {-2.299376977582931, 
             4.902043147299564}, {-2.085507633236714, 
             4.922432787775322}, {-1.8695410231394833`, 
             4.945426435505072}, {-1.820089671385213, 4.9498583136777015`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7965719357665737`, 
             4.951965995984867}, {-1.6559173657577686`, 
             4.964571595156353}, {-1.4438530931268883`, 
             4.981006942376068}, {-1.233348205246842, 
             4.994732477164218}, {-1.0244027021176305`, 
             5.005748199520803}, {-0.8541564766322212, 
             5.0123362841603845`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8305621431413504, 
             5.013249323293024}, {-0.817505804733071, 
             5.013754569516672}, {-0.6131467340869798, 
             5.018452047222672}, {-0.41132549017935793`, 
             5.019840632638805}, {-0.2120420730102056, 
             5.017920325765068}, {-0.08058656332056341, 5.014938841721822}, {
             0.04961210654060677, 5.010763408194338}, {0.11368352475821042`, 
             5.008095352494902}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1372750721781993, 5.0071129555962}, {
             0.17855393657330487`, 5.005394025182618}, {0.30623892677753084`, 
             4.99883069268666}, {0.4326670771532848, 4.991073410706466}, {
             0.5578383877005668, 4.982122179242035}, {0.6817528584193767, 
             4.971976998293368}, {0.8044104893097148, 4.960637867860463}, {
             1.0464848397991957`, 4.935906938974565}, {1.0785978995057466`, 
             4.932339883903526}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1020655605119063`, 4.929733142597578}, {
             1.2845910473632318`, 4.909458573016963}, {1.5187291120018225`, 
             4.881292769987656}, {1.748899033714967, 4.851409529886647}, {
             1.9760628646787735`, 4.820983628773447}, {2.039223609548059, 
             4.812624533820427}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.062631491365529, 4.809526585764776}, {
             2.201182657069348, 4.7911898427075705`}, {2.4242584108866905`, 
             4.762028171689018}, {2.6452901261308015`, 4.733498615717789}, {
             2.7914364656210537`, 4.715203811300832}, {2.937463490395251, 
             4.69781758781975}, {2.9996044397132255`, 4.690799889098597}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0230672885393153`, 4.688150183775318}, {
             3.0833712004533926`, 4.6813399452745434`}, {3.22915959579548, 
             4.665770883665212}, {3.374828676421512, 4.651110402991756}, {
             3.5203784423314897`, 4.637358503254175}, {3.665808893525412, 
             4.62451518445247}, {3.8111200300032797`, 4.612580446586639}, {
             3.9634678632053153`, 4.6011599637087635`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.987021512122203, 4.599503648337943}, {
             4.135575761893763, 4.5895473543046705`}, {4.334446218974168, 
             4.577851700792413}, {4.533396686737611, 4.567878329399208}, {
             4.546789992971955, 4.5672650191767}, {4.560183123231156, 
             4.566659049648237}, {4.7364755229976465`, 4.560284116736759}, {
             4.913174413833311, 4.555337565136972}, {4.930357218385354, 
             4.554918109454414}}]}, 
           {Arrowheads[{{0.014885770452279143`, 1.}}], 
            ArrowBox[{{4.9539621791598165`, 4.554341880183843}, {
             5.080412328837391, 4.551255059654527}, {5.247919235461146, 
             4.548363410486673}, {5.415348000485782, 4.546603908450351}, {
             5.582351490692503, 4.5459178443625}, {5.656854249492381, 
             4.546014333184944}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.749937426475491}, \
{-5.590922029886474, -4.744457843891378}, {-5.369942927307269, \
-4.7299302814679915`}, {-5.142450604479938, -4.719606069931189}, \
{-4.909324136943738, -4.713595055289528}, {-4.7133948564130845`, \
-4.712287134698342}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689783389495613, -4.712129516992169}, \
{-4.671442600237929, -4.7120070835515735`}, {-4.430196472387496, \
-4.715583366973594}, {-4.18656710942884, -4.7245600248136945`}, \
{-4.0639416499578, -4.730871058675309}, {-3.9408199039183525`, \
-4.738289263583184}, {-3.817235045380043, -4.7467336653512335`}, \
{-3.7463724562268323`, -4.752098937201172}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722827852343609, -4.7538815872841305`}, \
{-3.6932202484124192`, -4.756123289793372}, {-3.568722846988887, \
-4.7665128899681175`}, {-3.4437213896632666`, -4.777907863572315}, \
{-3.3182958723757294`, -4.790153203377365}, {-3.1925262910664465`, \
-4.803093902154671}, {-3.0664926416755933`, -4.816574952675634}, \
{-2.9402749201433407`, -4.830441347711656}, {-2.8139531224098633`, \
-4.84453808003414}, {-2.7831002302627312`, -4.847998811156229}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7596353912013516`, -4.850630833412919}, \
{-2.687607244415331, -4.858710142414488}, {-2.476085024576929, \
-4.881891396390067}, {-2.265207973089942, -4.9036924657438155`}, \
{-2.0552724345742712`, -4.923691019240391}, {-1.8434137443708645`, \
-4.945969592154774}, {-1.8202072813770946`, -4.948026399758713}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7966874866073743`, -4.950110978211638}, \
{-1.6338301179283328`, -4.964545158652941}, {-1.425780693696921, \
-4.980473546823248}, {-1.2192654716766307`, -4.993754756665696}, \
{-1.014284451867459, -5.004388788180287}, {-0.8542728247598279, \
-5.010470242957181}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8306778668483892, -5.011367000724694}, \
{-0.811296924810788, -5.012103599212353}, {-0.6107621810479988, \
-5.016627147607231}, {-0.4126802205790894, -5.017959433364921}, \
{-0.217051043404061, -5.016100456485423}, {-0.09004342633250625, \
-5.01326929390199}, {0.03578963054973938, -5.009310621602898}, {
             0.11356501921375706`, -5.00613731377786}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13715738309055403`, -5.005174723501073}, {
             0.16044812724267687`, -5.004224439588148}, {
             0.2839320637463071, -4.998010747857738}, {
             0.527376256185641, -4.982200835249941}, {
             0.7661222078677437, -4.961880883779507}, {
             1.0006164756622244`, -4.938402190923679}, {
             1.0784468671659222`, -4.9298711004816544`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1019182808947925`, -4.927298368294979}, {
             1.231305616438695, -4.913116054159696}, {
             1.4581896301971558`, -4.88602247348756}, {
             1.6812685169376056`, -4.85712144890727}, {
             1.9014064228938987`, -4.82752894140124}, {
             2.0389416800752445`, -4.809132111531862}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.062345233576596, -4.806001632839147}, {
             2.1194674942998866`, -4.7983609119518835`}, {
             2.3354517311555703`, -4.769617360559202}, {
             2.5493591334609498`, -4.741298287223194}, {
             2.6958098984784917`, -4.722397465952452}, {
             2.842101912750316, -4.704390149546952}, {
             2.9882351762764245`, -4.687276338006695}, {
             2.9991608761794324`, -4.6860623027638955`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0226284357936897`, -4.683454648820703}, {
             3.1342096890568163`, -4.671056031331683}, {
             3.280025451091491, -4.655729229521913}, {
             3.425682462380449, -4.641295932577386}, {
             3.571180722923691, -4.627756140498104}, {
             3.716520232721216, -4.615109853284063}, {
             3.8754168830873383`, -4.60241971169395}, {
             3.9629953901893042`, -4.596128824210411}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.98654670190733, -4.594437100327343}, {
             4.0345286803230325`, -4.590990487254807}, {
             4.233538318355061, -4.578367708950758}, {
             4.432686957451321, -4.5675223774066005`}, {
             4.446093940561478, -4.566852317552909}, {
             4.459501020471293, -4.566189834470264}, {
             4.632314849674124, -4.559078042092083}, {
             4.805573341788143, -4.553382897821722}, {
             4.9298830345974824`, -4.54979355390063}}]}, 
           {Arrowheads[{{0.01489601086124044, 1.}}], 
            ArrowBox[{{4.953485190851797, -4.549112060332738}, {
             4.999294098123324, -4.547789364417954}, {
             5.193055376681858, -4.543742942509582}, {
             5.386857177463747, -4.541243632096605}, {
             5.580699500468991, -4.540291433179022}, {
             5.656854249492381, -4.540445914925983}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.8284570409222227`}, \
{-5.512014710740324, -2.8254987325530085`}, {-5.3874825551965255`, \
-2.8243190910066884`}, {-5.2626016333405845`, -2.824123130220861}, \
{-5.1373674861848, -2.82505072238032}, {-5.011779170283562, \
-2.8271397334833126`}, {-4.885839257733345, -2.8303260233415384`}, \
{-4.759550320630623, -2.8345454517666977`}, {-4.712581460385458, \
-2.8364698308386833`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688989260655479, -2.83743643584433}, \
{-4.6329149310718725`, -2.8397338785704904`}, {-4.505935661153568, \
-2.8458271635646173`}, {-4.378615082972185, -2.8527611665607777`}, \
{-4.250955768624198, -2.8604717473706724`}, {-4.075451750283556, \
-2.8723672754392413`}, {-3.8993331225225036`, -2.885707847629991}, \
{-3.746543113786381, -2.8982251656535087`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7230099624677853`, -2.900153118545109}, \
{-3.7226011723662946`, -2.900186608664964}, {-3.5452571868401845`, \
-2.9154967032662022`}, {-3.367241978019152, -2.9314614089767197`}, \
{-3.188544737938398, -2.947799897082753}, {-3.0092393235635115`, \
-2.964049152921179}, {-2.8293995918600805`, -2.9797461618288765`}, \
{-2.7822253583173095`, -2.983583172217477}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.758691084914126, -2.9854973792910124`}, \
{-2.648985889840318, -2.994420470172818}, {-2.468049372479138, \
-3.0076075754959004`}, {-2.286800108686179, -3.018853389898887}, \
{-2.105448167371081, -3.0277038254825417`}, {-1.9239691198920919`, \
-3.0334707120116238`}, {-1.8157173865126546`, -3.0347727858720077`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7921071013934982`, -3.035056775182203}, \
{-1.7425261356485735`, -3.0356531451196966`}, {-1.561610680611834, \
-3.034077935710728}, {-1.3817142207531816`, -3.0285718946886875`}, \
{-1.2327059325292447`, -3.020678169579261}, {-1.0851290298967688`, \
-3.009606523456218}, {-0.9392035885283345, -2.9954107260564355`}, \
{-0.8496966801346973, -2.9845038722191446`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8262580613997415, -2.9816477620788424`}, \
{-0.7928022102556576, -2.9775710032567644`}, {-0.6490426337736388, \
-2.9568490929963027`}, {-0.5073746699008244, -2.933110570932857}, \
{-0.3677983186372155, -2.906355437066427}, {-0.23031357998281138`, \
-2.8765836913970126`}, {-0.09522156397926473, -2.8442803603367546`}, {
             0.03717661933177224, -2.809930470297793}, {
             0.09823527946559271, -2.792796747334378}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12096916979259045`, -2.786417370880821}, {
             0.16688096995029994`, -2.773534021280128}, {
             0.293891487876318, -2.7350910132837596`}, {
             0.41821275216280235`, -2.6953110212229645`}, {
             0.5398493418627299, -2.654903620012019}, {
             0.6588012569761004, -2.613868809650924}, {
             0.7750684975029136, -2.5722065901396793`}, {
             1.00104158738092, -2.4897652179049503`}, {
             1.0156175820733093`, -2.4844603262965337`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0378057623260295`, -2.476385001509941}, {
             1.2192612440807993`, -2.410344797546043}, {
             1.4321929785592042`, -2.335768309745653}, {
             1.642302301772787, -2.2678587351864783`}, {
             1.7311056248727372`, -2.2411403966519967`}, {
             1.820141420836686, -2.215877765101324}, {
             1.9358726984232664`, -2.1854315091226777`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9587651265215271`, -2.1796527892775197`}, {
             2.078249708773968, -2.151069892699286}, {
             2.209244783392413, -2.122797126909227}, {
             2.3415338117773943`, -2.0972784747264748`}, {
             2.3592179407894136`, -2.0940669814491004`}, {
             2.376936055571534, -2.0909006181212058`}, {
             2.484984229849696, -2.073697131300218}, {
             2.5943125190536778`, -2.0579794485513507`}, {
             2.741097889835805, -2.0381177488140154`}, {
             2.8889859556391517`, -2.020549322933232}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9124720759527425`, -2.0181159037146927`}, {
             3.041612956285302, -2.004842202247816}, {
             3.195342651952672, -1.9914283554189518`}, {
             3.3512061051023636`, -1.9798353641220252`}, {
             3.5090222982549504`, -1.969734799586149}, {
             3.668791231410432, -1.9611266618113234`}, {
             3.8305129045688084`, -1.9540109507975485`}, {
             3.854533239680971, -1.9532380512089111`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.878133018800242, -1.9524786838025847`}, {
             3.9946802835582065`, -1.9487285557311982`}, {
             4.158499895352574, -1.9433477712228195`}, {
             4.323877874487336, -1.9391867021263924`}, {
             4.490617034631241, -1.936108992767367}, {
             4.734379864977674, -1.9333423460193464`}, {
             4.822366811226, -1.932961738922455}}]}, 
           {Arrowheads[{{0.017171068973335223`, 1.}}], 
            ArrowBox[{{4.845978583314756, -1.9328596009530135`}, {
             4.979940349836298, -1.9322801195500978`}, {
             5.103201820968873, -1.9322717144586468`}, {
             5.226681235642926, -1.9325496750832487`}, {
             5.3503014371629325`, -1.9330674216393575`}, {
             5.47398526883337, -1.9337783743424264`}, {
             5.597724060071992, -1.9346879110857804`}, {
             5.656854249492381, -1.935244323444829}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.8284564877049476`}, {-5.443897867720706, 
             2.824946111422931}, {-5.3213508558639715`, 
             2.824410635333293}, {-5.198476646997943, 
             2.8249486082201876`}, {-5.075274377911093, 
             2.8265184955065696`}, {-4.951743185391895, 
             2.8290787626153935`}, {-4.827882206228825, 
             2.8325878749696134`}, {-4.712564929260408, 
             2.8366887139788814`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688971782386679, 
             2.837628660690337}, {-4.579167435124955, 
             2.84228649710606}, {-4.454311916761102, 
             2.8483929377341957`}, {-4.2807366887628655`, 
             2.8583398958677155`}, {-4.106491661091291, 
             2.869975815663862}, {-3.9315892072338885`, 
             2.8830329650010893`}, {-3.7560417006781686`, 
             2.8972436117578537`}, {-3.7465094028736283`, 
             2.898067580446281}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7229851308469, 
             2.900101010786533}, {-3.579829391241363, 
             2.912475345854771}, {-3.4029582276769266`, 
             2.9284874995787287`}, {-3.2254791318767024`, 
             2.9448499543575886`}, {-3.0474430257325382`, 
             2.9611325916192115`}, {-2.868827519752547, 
             2.9769263736936606`}, {-2.782253192662131, 
             2.9841163227180756`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7587222092719563`, 
             2.986070557613751}, {-2.6896688735518266`, 
             2.991805398189237}, {-2.510105982682698, 
             3.0053142494511613`}, {-2.330277742697483, 
             3.016997511824654}, {-2.150043241225603, 
             3.02628540172183}, {-1.9694854122347993`, 
             3.0326996299012885`}, {-1.8157443469178516`, 
             3.0354457285876086`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7921361196678822`, 
             3.0358674150232}, {-1.7890789207848674`, 
             3.0359220222279775`}, {-1.6092984319356047`, 
             3.0356344045668435`}, {-1.4494141709518327`, 
             3.031924508634765}, {-1.2908166336987077`, 
             3.024640068622918}, {-1.1337926722047946`, 
             3.0137815383517155`}, {-0.975569383527295, 
             2.999344530890481}, {-0.849742197622768, 2.9847587615052364`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8262872634371923, 
             2.9820398875312413`}, {-0.8202105047375519, 
             2.98133547536176}, {-0.666998905764152, 
             2.959753237214514}, {-0.5159345866070947, 
             2.9345978164487434`}, {-0.3670175472663795, 
             2.9058692130644483`}, {-0.2206568652456391, 
             2.8740687013360557`}, {-0.07726161804850673, 
             2.839697555537992}, {0.06316819432501863, 2.802755775670258}, {
             0.09814268644390302, 2.792702795876638}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1208358248522514, 2.786179937414606}, {
             0.20063257187493638`, 2.7632433617328536`}, {0.3350722783091636, 
             2.721976059785211}, {0.4664280773356166, 2.679769615886764}, {
             0.5946999689542951, 2.636624030037512}, {0.7198879531651999, 
             2.592539302237455}, {0.8423879935282338, 2.54834694683033}, {
             0.9625960536032999, 2.504878478159874}, {1.015939780201436, 
             2.485541375905928}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0381382662075789`, 2.4774944241618675`}, {
             1.0805121333903989`, 2.462133896226087}, {1.1961362328895304`, 
             2.420113201028968}, {1.4233933125846892`, 2.3404899041768763`}, {
             1.6472521142495744`, 2.26825502093574}, {1.736204527216182, 
             2.241581803755508}, {1.8254041324463997`, 2.2163718956059837`}, {
             1.9364547699658896`, 2.187276993043156}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9593263879081986`, 2.181414863724522}, {
             2.0836147117686292`, 2.151810184503211}, {2.2146735941925075`, 
             2.123650413911637}, {2.347034871791562, 2.098238033293271}, {
             2.3647297254663115`, 2.095040130057575}, {2.382458559516795, 
             2.091887202605097}, {2.490683217150777, 2.0747421211954182`}, {
             2.600189284433739, 2.0590806068811847`}, {2.7472292292479943`, 
             2.039289331977424}, {2.8895756350051682`, 
             2.0224716363930284`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.913053103957072, 2.0199605300820127`}, {
             3.0482544036945938`, 2.0061433884271453`}, {3.202239633326937, 
             1.9927887197806273`}, {3.358356800599977, 1.9812516567851473`}, {
             3.516422748215047, 1.9712042696726613`}, {3.676437476172148, 
             1.9626465584431696`}, {3.8384009844712788`, 
             1.9555785230966722`}, {3.8551145810857577`, 
             1.9550460835445962`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.878714601909367, 1.9542942654406805`}, {
             4.0028085577763965`, 1.950341045089535}, {4.166853582991744, 
             1.9450024628356841`}, {4.332451160817956, 1.9408808512997346`}, {
             4.49940317738945, 1.93783985789914}, {4.7436457504394145`, 
             1.9351214305642492`}, {4.822949745649067, 
             1.9347944309704956`}}]}, 
           {Arrowheads[{{0.017158724958073298`, 1.}}], 
            ArrowBox[{{4.8465615379220655`, 1.9346970708506095`}, {
             4.989677271146889, 1.9341069519480178`}, {5.113170522514002, 
             1.9341222965806204`}, {5.236878973565662, 1.9344239521983533`}, {
             5.3607252785585935`, 1.9349653600697045`}, {5.484632091749519, 
             1.9356999614631631`}, {5.608590832234269, 1.936633150215911}, {
             5.656854249492381, 1.9370957174946917`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.132451749230169}, {-5.592261069471006, 
             1.1323762452697284`}, {-5.4686793822889195`, 
             1.1326724979315779`}, {-5.344935781843609, 
             1.1334092705250494`}, {-5.221030268135076, 
             1.1345865630501422`}, {-5.09696284116332, 
             1.1362043755068567`}, {-4.972733500928342, 
             1.138262707895193}, {-4.848342247430141, 
             1.1407615602151506`}, {-4.723789080668717, 
             1.14370093246673}, {-4.712474230202989, 1.144007087456657}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688870875923248, 
             1.1446457423565735`}, {-4.594647346588124, 
             1.1471952240100747`}, {-4.4653423309192934`, 
             1.1511344263676067`}, {-4.3358740336622255`, 
             1.155518539539326}, {-4.206242454816918, 
             1.1603475635252323`}, {-4.076381068479325, 
             1.1655564279691337`}, {-3.9462233487453955`, 
             1.1710800625148385`}, {-3.81576929561513, 
             1.1769184671623467`}, {-3.745080144910162, 
             1.1802451318761031`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.721494255160027, 
             1.181355094952358}, {-3.685018909088529, 
             1.183071641911658}, {-3.5538405381057756`, 
             1.1893556713799085`}, {-3.422102531607055, 
             1.195586640184234}, {-3.2898048895923666`, 
             1.2017645483246349`}, {-3.1569476120617104`, 
             1.2078893958011105`}, {-3.034545853008429, 
             1.2133337061972571`}, {-2.911312218268061, 
             1.21842996172169}, {-2.7802343893463646`, 
             1.2232395985960094`}, {-2.7779535398070134`, 
             1.2233104007608941`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754352914930941, 
             1.2240430117047694`}, {-2.6478334987300527`, 
             1.2273495889862496`}, {-2.513835709868822, 
             1.2305250032915775`}, {-2.377967186212371, 
             1.2325309119111598`}, {-2.2006518830536352`, 
             1.232642166937445}, {-2.0190286103900896`, 
             1.2293366858283266`}, {-1.989057152825093, 
             1.2285189983192555`}, {-1.9589407652477897`, 
             1.2275829619166487`}, {-1.8637791197222813`, 
             1.2229952367598695`}, {-1.810249290655773, 
             1.2196243385638315`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.786683975728895, 
             1.2181403757161753`}, {-1.766804909617295, 
             1.2168885445546886`}, {-1.5882575782429464`, 
             1.2022916282244367`}, {-1.4023813775117944`, 
             1.1805264470813877`}, {-1.2071505927005002`, 
             1.1483440343791753`}, {-1.0005395090857254`, 
             1.102495423371434}, {-0.876834338673407, 
             1.0682358708912505`}, {-0.8574604128829083, 
             1.0618220362245765`}}]}, 
           {Arrowheads[{{0.010487876037894455`, 1.}}], 
            ArrowBox[{{-0.8350448354849171, 
             1.0544012476377194`}, {-0.7479240822520145, 
             1.0255594881866756`}, {-0.6815499914966088, 
             1.0006730557268768`}, {-0.6139477282356772, 
             0.9726662815113175}, {-0.545119522952785, 
             0.9409748216559981}, {-0.510444720751856, 
             0.9236712424433452}, {-0.477239426982245, 
             0.9061612129449157}, {-0.4511912996347802, 
             0.8917675341118656}, {-0.436768366149509, 
             0.8835080666638013}, {-0.43266161547705173`, 
             0.8811470629632333}, {-0.4290275503067999, 
             0.879050441137359}, {-0.41658196300785166`, 
             0.8718109474206996}, {-0.4101336540500329, 
             0.8680195443663322}, {-0.40533492332118154`, 
             0.8651803067394848}, {-0.39914954970737504`, 
             0.8614999243151925}, {-0.39495356718885866`, 
             0.858988043984163}, {-0.3883882615404934, 
             0.8550343434305614}, {-0.3842288005894324, 
             0.8525140757486747}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.1318380757076725`}, \
{-5.592339352665944, -1.1317626590136705`}, {-5.468756522805313, \
-1.132058686946992}, {-5.3450119270886365`, -1.1327950197027772`}, \
{-5.221105565515913, -1.1339716572810261`}, {-5.097037438087143, \
-1.1355885996817388`}, {-4.972807544802326, -1.1376458469049149`}, \
{-4.848415885661463, -1.1401433989505547`}, {-4.723862460664555, \
-1.1430812558186583`}, {-4.712474151834016, -1.1433892388639009`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688870788614656, -1.144027563288575}, \
{-4.594722346613914, -1.1465736940884776`}, {-4.465419112285138, \
-1.1505107854616117`}, {-4.335952757678225, -1.1548925299380601`}, \
{-4.206323282793175, -1.159718927517823}, {-4.076464147204543, \
-1.1649249293960542`}, {-3.9463088104868853`, -1.1704454867679073`}, \
{-3.8158572726402005`, -1.1762805996333818`}, {-3.745079382065018, \
-1.179609609814389}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7214934636769073`, -1.1807189641876874`}, \
{-3.685109533664489, -1.1824302679924783`}, {-3.5539337564339686`, \
-1.1887108158299997`}, {-3.4221981038228577`, -1.1949385671307495`}, \
{-3.289902575831157, -1.2011135218947273`}, {-3.1570471724588667`, \
-1.2072356801219335`}, {-3.034642657803172, -1.2126778565304268`}, \
{-2.911406136638558, -1.2177720133543752`}, {-2.78030707595807, \
-1.2225801015191509`}, {-2.777951809547496, -1.2226531718727685`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7543511716667517`, -1.2233853637589194`}, \
{-2.6478842040137183`, -1.2266884206615576`}, {-2.513862968312867, \
-1.2298623433634674`}, {-2.3779688163628796`, -1.231867242206753}, \
{-2.2006774199363233`, -1.2319774772228207`}, {-2.019076828614881, \
-1.2286721242677807`}, {-1.9891030949568205`, -1.2278543909988984`}, \
{-1.9589843271697087`, -1.2269183023472228`}, {-1.8638203093566175`, \
-1.2223306814643469`}, {-1.8102474702670623`, -1.2189572762658278`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7866821497825458`, -1.2174734016760502`}, \
{-1.7668425080851164`, -1.2162241277608303`}, {-1.5883125999595784`, \
-1.2016300762399625`}, {-1.4024470674612313`, -1.1798695547843503`}, \
{-1.2072157272832118`, -1.1476915930045717`}, {-1.0005883961186566`, \
-1.1018452205112048`}, {-0.8769332787562543, -1.0676055166288325`}, \
{-0.8574577183945927, -1.0611595682389732`}}]}, 
           {Arrowheads[{{0.010483822244637932`, 1.}}], 
            ArrowBox[{{-0.8350416146468467, -1.0537403697575705`}, \
{-0.7480716710824773, -1.0249553819433823`}, {-0.6817190188861798, \
-1.0000836715627235`}, {-0.6141352687025148, -0.9720927536001515}, \
{-0.5453249031513352, -0.9404197815535313}, {-0.5106821962769788, \
-0.9231396055409172}, {-0.47761909632891997`, -0.9057173854796533}, \
{-0.4508243853918136, -0.8909218144854296}, {-0.43522690106064066`, \
-0.8820208859961794}, {-0.43147165710422214`, -0.8798602681246158}, \
{-0.4252161961343134, -0.8762423087644029}, {-0.41530458011127463`, \
-0.8704645556820371}, {-0.4086611109156134, -0.8665540752342595}, \
{-0.40383663754270993`, -0.8636961531595331}, {-0.39824243563570505`, \
-0.8603642459506725}, {-0.3944009716283796, -0.8580636703104523}, \
{-0.3882743559054878, -0.854374285802134}, {-0.3843608829975128, \
-0.8520040545294535}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.011321305601608253`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAbXjsIr9H+D/ig7XYa7RvPyIdzncV
LPg/Na+IxA34aj/dx2Bnfwr4P8bg6mDX0mc/jeahKBbX9z9sSxslJP1kP0oR
KeM4hvc/W4Gsy9toYj89u6IOHE73PwZD0HEsM2E/nk9AAFYH9z8jnW3aVghg
P0eiWR2stvY/LctP6nUAXj/iSw6zh1H2PyZekD0z+ls//GL3TwGU9T8pjYdW
WjBZP4gBrvYpAvU/tQM3EmiMVz8RNHPFkkn0P+Ke2Jca3FU/M32RtKZY8z8w
VUxd5xJUP0H8sXdiGPM/vcY8RxOkUz/8RuQMftPyP/wHnRPNMlM/jdGPJF2H
8j9XhEOG7MBSPzSl3nm2NPI/INS6ywdLUj/FR0+8n3/xP5bR6p8cVVE/lvaX
maCk8D+eGF221EVQP6N8inOPZvA/TzDrhdP5Tz9Qq+5DDSfwPwdW6KSXZ08/
NNZ41JHp7z/Pn1tYF/VOP2iPLmHgue8/xy5GM+i+Tj/TjDbNIJXvP6oBFXs1
lU4/cBL29xp07z/ucJUaxG9OPwn0vqE=
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.7810161146119272`}, \
{-5.61278621308942, -1.7806501033265374`}, {-5.393938688242313, \
-1.7806278916769673`}, {-5.1743882928329406`, -1.7825587232822993`}, \
{-4.954223626115033, -1.7866635266815367`}, {-4.733489522719932, \
-1.7930396532351363`}, {-4.712530185749937, -1.7938409493393521`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688935429600883, -1.7947430001155398`}, \
{-4.512137334716611, -1.8015021654873447`}, {-4.290127411447128, \
-1.8119109774805673`}, {-4.067434172785807, -1.824187049820436}, \
{-3.843963922340512, -1.8380500296217122`}, {-3.7458172021971183`, \
-1.8446367979825935`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7222582038261933`, -1.846217876442036}, \
{-3.606444304184309, -1.8539903147751453`}, {-3.367680708830596, \
-1.870556032969206}, {-3.1273584643015053`, -1.8870112862840491`}, \
{-2.885097882831306, -1.9023745141825559`}, {-2.7798320193453705`, \
-1.908353863922097}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7562558658602727`, -1.909652807548604}, \
{-2.640452909406507, -1.9155499994462848`}, {-2.5170917542683053`, \
-1.9208872398291117`}, {-2.3929569720091712`, -1.9250912763358619`}, \
{-2.267909062739575, -1.928120128772304}, {-2.141871417579372, \
-1.9297856796735608`}, {-2.0148774869148416`, -1.9296440713511256`}, \
{-1.8869607211322603`, -1.9272514461164918`}, {-1.8122540002503826`, \
-1.9239915700304058`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.788664454641329, -1.9229622249500056`}, \
{-1.718865695406047, -1.919916510944845}, {-1.5491794101305427`, \
-1.9080113238980796`}, {-1.3780573924998931`, -1.890317056568966}, \
{-1.2055860465108457`, -1.8661565820645987`}, {-1.0322283163377222`, \
-1.8345118918280463`}, {-0.8584471461548441, -1.794364977302377}, \
{-0.8548316874823415, -1.7934046048271448`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.8320110729062953, -1.787342776414223}, \
{-0.802999486744787, -1.7796364433217584`}, {-0.747677309090121, \
-1.7639140874382704`}, {-0.5299696517729573, -1.6910743641920918`}, \
{-0.3178953967359468, -1.599499799278563}, {-0.17562384023541805`, \
-1.522355817324973}, {-0.04132144528881665, -1.4334766816949385`}, {
             0.015273058939392667`, -1.3865964439416256`}}]}, 
           {Arrowheads[{{0.012702206073298604`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA407DUD4hoT+W+z6OzfH1v4MK25w4
8LQ/BOlmTM9N9b+L8T8R8ei5P/6Ctw2IA/W/Nx4o8vLEvj+rl4JMi7f0v8Vz
iRdjscM/Gis22EUb9L8puSarkr/HP+tGpvNtdvO/uxnKsYkM0T+ag0aH1nLx
v1lDO1l3HtI/I6rHe5Lk8L//JACE5BLTPzPGk4HoTvC/P2NjMu/k0z8nbfra
OWPvv/03DG9GPdQ/aCvVMq3F7r/zXHU8Fn3UP12rrKBESu6/oY6Drtik1D8A
REZxzPntvz+LXxV3v9Q//YTocvnB7b/aZ2ixRtXUP+D5SPQHk+2/a3/1Lnvn
1D8OW6B26mrtvyirsPw7FdU/T0w3TWYC7b/I3Ogi3DHVP1JG03lCvey/UGbA
t4NF1T9v2E4nDYzsv9u7jpx9WtU/3sEeyRNW7L8+aE2hNmjVP3IbjSLQMey/
MY/GFZ981T8JUECZdPrrvzlKQK0ZidU/le6zcq3X678TVMkx
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.7817033868158025`}, {-5.625349765508304, 
             1.7814250850798214`}, {-5.405086509462862, 
             1.7812883143961054`}, {-5.1840992841373446`, 
             1.7831260842285908`}, {-4.962482050571298, 
             1.7871671090020678`}, {-4.740283650746073, 
             1.7935134008801583`}, {-4.712530903200921, 
             1.7945674737740123`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688935922478719, 
             1.7954636311569818`}, {-4.5174587039801075`, 
             1.8019764813761818`}, {-4.293968820481513, 
             1.8124149859919818`}, {-4.069787611919983, 
             1.8247513773188575`}, {-3.8448195201618467`, 
             1.8387011928024661`}, {-3.745817476911978, 1.845345957666597}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7222584879936744`, 
             1.8469271769693512`}, {-3.606962028572041, 
             1.8546655815252042`}, {-3.3678581072954836`, 
             1.8712585755271876`}, {-3.1271910613328635`, 
             1.887742466984792}, {-2.8845799627710367`, 
             1.9031314680442166`}, {-2.7798334834444645`, 
             1.9090810262569344`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7562575407702092`, 
             1.9103838793209904`}, {-2.6395781246234327`, 
             1.9163232645079193`}, {-2.516036116519866, 
             1.921662810983731}, {-2.3917189718963012`, 
             1.9258638347947106`}, {-2.2664866101432595`, 
             1.9288837813918853`}, {-2.140262368838752, 
             1.9305335669689776`}, {-2.0130805673888985`, 
             1.9303676815194237`}, {-1.8849755251998195`, 
             1.927940615036661}, {-1.8122555741345963`, 1.924746822201738}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7886663206546503`, 
             1.9237108040575859`}, {-1.716913392409887, 
             1.9205594819684482`}, {-1.547259276403739, 
             1.9086039567240596`}, {-1.376175766971306, 
             1.8908557752222868`}, {-1.2037531917736601`, 
             1.8666381240846806`}, {-1.0304565650760873`, 
             1.8349355498549615`}, {-0.8567509011438731, 
             1.794732599076851}, {-0.8548217925806265, 
             1.7942193173199377`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8320036852043103, 
             1.7881480580519549`}, {-0.8013527639035748, 
             1.77999270638539}, {-0.7460807853883533, 
             1.7642597272577951`}, {-0.5286159769812173, 
             1.6914085791040219`}, {-0.3168001468018944, 
             1.5998565711801218`}, {-0.17453458217771453`, 
             1.5226551653974585`}, {-0.04025883084880566, 
             1.4337218323176133`}, {0.015383991605264886`, 
             1.387591504739127}}]}, 
           {Arrowheads[{{0.01274526829553957, 1.}}], ArrowBox[CompressedData["

1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAdTBcqfkuoT84rSQm2fX1PycljVHB
MrU/ra9la6BO9T8kqzGaySq6P/LwvrdTBPU/ExV44BIGvz+T82mLUbj0P0W+
QLC70sM/6hzRZMIb9D9+oRRNauHHPxzu9kiZdvM/CPV3Pn0b0T9SFNSS+3Lx
P2V+MtviLNI/4KoVWrvk8D9MM3P/xCDTP6kU3OoUT/A/haVUCb/y0z+MlO4t
cGLvP6ASbA50StQ/uf8/ornF7j9jKcFkqonUPzi/I4JbS+4/rh6Cwsix1D/f
PQYD+fntPxddZxbLztQ/j9BgleW87T9SQPmiKubUPx/2TWY/iu0/Y1DAe2z5
1D9vJB8Pbl/tP7n3a9BOJtU/ulVy5NT37D/qvQkuYULVPzEQi5hKs+w/UrNW
Ip9V1T9BKhIIlYLsP4q5rrcMatU/OepRD3BN7D9xpE5sZ3fVP03U6xjDKew/
ui6GujWL1T/RpxBodvPrP6BU95BPl9U/N5qVu2LR6z9keruy
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.5431144584928287`, 0.004190956198022493}, {
             1.5703582017696758`, 0.003291433975213169}, {1.631390972291715, 
             0.0026349403297187676`}, {1.753124510456163, 
             0.002180616218243607}, {1.9714306152183738`, 
             0.001884063077885357}, {2.1214627324882347`, 
             0.001785010597266313}, {2.2985523944750823`, 
             0.0017102198687073463`}, {2.487574696887108, 
             0.001658094016827048}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.511186689221193, 0.0016525974517955665`}, {
             2.7230066150995094`, 0.0016133576732856975`}, {2.872671068987554,
              0.0015933416800238424`}, {3.0278783105745504`, 
             0.001576264768849681}, {3.188628339860498, 
             0.0015621269397632135`}, {3.3549211568453967`, 
             0.0015509281927644396`}, {3.455666402088814, 
             0.0015456196914668385`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.4792783950540045`, 0.0015443755206378152`}, {
             3.5255027935217194`, 0.0015419398495681402`}, {
             3.6991192818819383`, 0.0015344332318890958`}, {3.875770621926054,
              0.0015284083397273064`}, {4.055456813654065, 
             0.0015238651730827718`}, {4.223828709389938, 
             0.0015207774456349175`}, {4.393709074119501, 
             0.0015184933093588867`}, {4.423758114541138, 
             0.0015182083809174816`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.447370107538045, 0.0015179844892966952`}, {
             4.56991149009304, 0.0015168225378783104`}, {4.746952103404659, 
             0.0015157437733269083`}, {4.92483091405436, 
             0.0015152570157046807`}, {5.103547922042143, 
             0.0015153622650116274`}, {5.127539609723906, 
             0.0015154160047704942`}, {5.151538845831753, 
             0.0015154780798007673`}, {5.346419018185855, 
             0.001516555024911346}, {5.391849827442816, 
             0.001516911816927823}}]}, 
           {Arrowheads[{{0.005111648751648156, 1.}}], 
            ArrowBox[{{5.415461820440058, 0.0015170972543156291`}, {
             5.541458084498519, 0.0015180867691813615`}, {5.656854249492381, 
             0.0015194270466671288`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.259972299293431}, {-5.426614956963529, 
             3.254387437942978}, {-5.193499062374062, 
             3.2527853999093446`}, {-4.958567843580775, 
             3.2553509511237704`}, {-4.721940904763141, 
             3.2617993431755536`}, {-4.712557956614356, 
             3.2621950796747026`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688966936459267, 
             3.2631900577540325`}, {-4.483737850100626, 
             3.271845827653992}, {-4.2441017684019275`, 
             3.285636817945793}, {-4.003156960772363, 
             3.3029737979997367`}, {-3.7609948498363233`, 
             3.3230546252482305`}, {-3.746579199017284, 3.324359536056019}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.723063353261121, 
             3.326488200357528}, {-3.5177068582182054`, 
             3.345077157123681}, {-3.3955989376232774`, 
             3.3566283256601936`}, {-3.2731288118143578`, 
             3.3684662798441365`}, {-3.1503462481287015`, 
             3.3804566975367143`}, {-3.0273010139035654`, 
             3.3924652565991322`}, {-2.904042876476205, 
             3.4043576348925946`}, {-2.782818351733545, 3.415792299056231}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7593044325620992`, 
             3.4179420298763925`}, {-2.6570869613638353`, 
             3.4272565606174727`}, {-2.5334887183533388`, 
             3.4379944637712976`}, {-2.366983203031393, 
             3.4512977358554346`}, {-2.2004721810683865`, 
             3.462941221410976}, {-2.03412886641521, 
             3.4726716471978536`}, {-1.868126473022754, 
             3.480235739975999}, {-1.817130900221038, 3.4817780314701277`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7935296984996483`, 
             3.482491817602262}, {-1.7026115930669783`, 
             3.4852415116044515`}, {-1.5377521161437873`, 
             3.4874079458629637`}, {-1.3737532023339882`, 
             3.4866482273925397`}, {-1.210820011718389, 
             3.482875540834183}, {-1.0491909052087052`, 
             3.475818116322065}, {-0.8890776830519257, 
             3.4653521475958224`}, {-0.8497943546486852, 
             3.461945458124013}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8262706513425241, 
             3.4599054590799287`}, {-0.7306456643317691, 
             3.4516127647046586`}, {-0.5740601681319537, 
             3.434735097697776}, {-0.41957835002174093`, 
             3.414702840759159}, {-0.26738389638195764`, 
             3.3916208367649663`}, {-0.11753192251367128`, 
             3.365805938802663}, {0.029922456282050657`, 
             3.3375749999597133`}, {0.1072825052443793, 
             3.3210683235435483`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13037467036717265`, 3.3161410399838362`}, {
             0.23353322392509432`, 3.2941296156636497`}, {
             0.43176515477897215`, 3.2473312425337464`}, {0.6252612030783742, 
             3.19821392808165}, {0.8146643230579884, 3.1478117198190083`}, {
             1.0203282245751049`, 3.0921400768103235`}, {1.04599820083043, 
             3.085073889923131}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0687634367787664`, 3.078807292317354}, {
             1.221473195052538, 3.0367708026561453`}, {1.4194079608977963`, 
             2.9830527133729765`}, {1.614859592337274, 2.9317351511922065`}, {
             1.8087868722622096`, 2.8834214996942173`}, {1.9832485755402325`, 
             2.843084934724657}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0062663590904237`, 2.8378225791987632`}, {
             2.103021979686462, 2.816849966280521}, {2.2041557487369268`, 
             2.7961121720119326`}, {2.333570374723625, 2.7713278962106274`}, {
             2.4637443693864647`, 2.7482824351032704`}, {2.594677732725445, 
             2.7269757886898613`}, {2.726370464740567, 2.707407956970401}, {
             2.743993438898395, 2.7049129481062697`}, {2.7616372018650805`, 
             2.7024486043826297`}, {2.8815276316982588`, 2.687404590539878}, {
             2.9372032977952682`, 2.681060873026978}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9606634963836402`, 2.6783878044662557`}, {
             3.002349081649027, 2.6736381248338152`}, {3.1899784981952246`, 
             2.653632612171324}, {3.3796779512322153`, 2.6361374209512993`}, {
             3.5714474407599996`, 2.621152551173742}, {3.7652869667785778`, 
             2.6086780028386523`}, {3.9018285740221326`, 
             2.6014567672077025`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9254076147161445`, 2.600209749450694}, {
             3.96092838201895, 2.5983311731275944`}, {4.158103539212116, 
             2.5897294592221334`}, {4.3568124383580775`, 
             2.5828728611222695`}, {4.557055079456833, 2.577761378828003}, {
             4.759332525022773, 2.5747336310835247`}, {4.8694328961020945`, 
             2.5731691469460727`}}]}, 
           {Arrowheads[{{0.01617460249319743, 1.}}], 
            ArrowBox[{{4.893042505674179, 2.572833663429488}, {
             4.960805420807685, 2.571870778338415}, {5.163411208533879, 
             2.570482146403549}, {5.366949463195598, 2.5704322877812493`}, {
             5.527609427517483, 2.5711898613974533`}, {5.656854249492381, 
             2.5722150779258155`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.4112636835907075`, 
             2.6636124429016945`}, {-1.2813872934649355`, 
             2.6540083945180952`}, {-1.152059017934834, 
             2.64165225602535}, {-1.0234783239814618`, 
             2.6264866126663193`}, {-0.8958187616414767, 
             2.6083337066994554`}, {-0.7692746145070584, 
             2.587112054770737}, {-0.6440764498925509, 
             2.562908653704319}, {-0.5204548351122991, 
             2.5358105003243545`}, {-0.4781906868841923, 
             2.5253827255014256`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.45526615183945746`, 
             2.5197265866842744`}, {-0.3986809375355171, 
             2.5057653950406142`}, {-0.2789934444875242, 
             2.4728324953943757`}, {-0.04660506097190164, 
             2.3993194431000626`}, {0.17486118806224712`, 
             2.3170340256795128`}, {0.3843448740112445, 2.228278081237274}, {
             0.4338616383896531, 2.205381935510224}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4552934051607447, 2.1954720623321404`}, {
             0.510414355806218, 2.1699845868390404`}, {0.6310888422920876, 
             2.110998091178023}, {0.7469899595808657, 2.051970083700116}, {
             0.8587393337845644, 1.9935520538512133`}, {0.9866840622395693, 
             1.9263036407172531`}, {1.1093056119001985`, 1.861412733159794}, {
             1.22817005901936, 1.7998045942650125`}, {1.2962876982831544`, 
             1.7658499434548462`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3174198175379417`, 1.7553162000965898`}, {
             1.3441474459597806`, 1.7419932590807847`}, {1.458446022040243, 
             1.6883197651836028`}, {1.5722740365795305`, 1.639125150149959}, {
             1.6576479480578843`, 1.6052051826070584`}, {1.7438494897718133`, 
             1.5738348253261651`}, {1.9775422199559718`, 
             1.5028127008684506`}, {2.098814017441272, 1.4731810751254009`}, {
             2.20811321111878, 1.4503686821639235`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.2312518104440087`, 1.4456677693023376`}, {
             2.240576753243678, 1.4438804777238277`}, {2.257506537996657, 
             1.4407059018636987`}, {2.363114271452451, 1.4237993054169358`}, {
             2.4713037369640083`, 1.408720341389359}, {2.69415124974381, 
             1.3812449689341757`}, {2.9267158344529505`, 
             1.3595835096480677`}, {3.168037044145818, 1.342748207456573}, {
             3.1695932603233468`, 1.3426603348228112`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.1931677013202413`, 1.3413291905706344`}, {
             3.291621215756545, 1.3357699567433825`}, {3.417154431876801, 
             1.3297513062852295`}, {3.5443818987867055`, 
             1.3245418130085147`}, {3.6730488227663796`, 1.319991033839638}, {
             3.803155203815823, 1.3160989687785989`}, {3.9347010419350354`, 
             1.3128656178253981`}, {4.133626320751245, 1.308953644425903}, {
             4.1370225488127055`, 1.3089022239352248`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.1606318359418895`, 1.3085447682205995`}, {
             4.334168851937093, 1.3059173361542658`}, {4.536328635492582, 
             1.3037566930104867`}, {4.74010567141771, 1.3024717149945657`}, {
             4.944929806452482, 1.301891216352748}, {5.105075242585527, 
             1.3018543940003362`}}]}, 
           {Arrowheads[{{0.01118441281111916, 1.}}], 
            ArrowBox[{{5.128687234959336, 1.3018489648783746`}, {
             5.150230887336903, 1.3018440113312788`}, {5.356008914070973, 
             1.3023300999301581`}, {5.5622638866546925`, 
             1.3033494821493858`}, {5.656854249492381, 
             1.3040296909099334`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01821859577765615, 1.}}], ArrowBox[CompressedData["

1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAcm5btHup8D+Fn0OjaE3yPwf5Tu/W
Y/E/yGasBGTn8D9cXlounq7xP/xQ3KUFOPA/ZRNE7nrt8T/m9vuOfxbvPwxZ
+EvHQvI/q6oQL6927D/0nmiie13yP/biVGgh4Ok/TMYPfC9G8j9rNewErvfn
P1puwySVAfI/rDGdd+UJ5j9Id0N0ZX/xP5YtG8f9CuQ/u74rgGhg8T/q0BIi
aanjP5rlnP9fPvE/pIzgTJ9G4z+5DdeQEPzwPy7R3tXEqOI/loVbNvKu8D+k
NmlAMgXiP7FuXEHJ8u8/oRLJrH+u4D/NHK00RP3tP/F5jgkzWt4/1vhviMhj
7T+W64q1+4bdP+V+D3zI1ew/Qmwaq9HJ3D/vyHZUNHPsP375FYnWSNw/jaJ2
9Lwu7D9H+mwxM/DbP9FSGWW2Bew/ENmS12C72z89reRGp+nrP9t9099Ql9s/
R5X1F3XA6z/aiJxVdWLbP6tXb4OTous/clBByS882z9GduPkGYTrP37eG882
Fds/5qTOOw==
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.018228445442420402`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAucdmwR648D+uiN9CRTzyv0UPtF2t
cPE/t1LqSwbX8L+/TMhnq7rxPyUCT2AcKPC/ThgABrv48T/O8+Tbkvfuv4yp
mPJ4TPI/C+KBXBlY7L/6y2q7f2XyP8WECLQKwum/Mpt+mhhN8j81bss+ydzn
v9EIxvmHB/I/J0kjNyvy5b+1aydOkYTxPwZA22R79uO/mL29H15l8T+irUGa
PZXjv5iY9oQdQ/E/zSs5lcoy478asahTlwDxP5QM6eTMleK/bNG5zEWz8D/P
IKZkHfPhvzZLOi24+u8/waW1wUOe4L+5V9HwFgXuP9zVDvslPt6/8tBsXtFs
7T+xuP7XjW3dv2QzQBw24ew/BDTKuEa03L/XSP1op37sP+lznprIM9y/UOPp
z/Yu7D+WK3yxC83bvy3hK+9DAOw/QtZqIUOR27+tAg2xH+HrP7CGhaN8adu/
8a8wxLi16z9UfUewJjLbvxoPN35Vl+s/QqDArXoL27+o1ewJdnjrP+k74i5A
5Nq/sj/Vkw==
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.5801780180212559}, \
{-5.52895482528163, -0.5802124193220334}, {-5.324007172404673, \
-0.5808794841173326}, {-5.169448117477117, -0.5817983864171434}, \
{-5.014701621824668, -0.58309020310282}, {-4.859767685447327, \
-0.5847549341743623}, {-4.712405399686877, -0.5866906576560792}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688795956162601, -0.5870367182518735}, \
{-4.549335821323789, -0.589184784394944}, {-4.393834555189227, \
-0.5919131933837832}, {-4.238142509941412, -0.594977806598288}, \
{-4.08225968558034, -0.5983786240384583}, {-3.9260239157435706`, \
-0.6020232731844274}, {-3.7692730340686618`, -0.6058193815163283}, \
{-3.7445202252008047`, -0.6064407070939636}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            
            ArrowBox[{{-3.720915667305502, -0.6070332101770447}, \
{-3.6120070405556133`, -0.6097669490341612}, {-3.4542259352044242`, \
-0.613865975737926}, {-3.290014812263046, -0.6181115612840449}, \
{-3.12451339451329, -0.6222067857705053}, {-2.9572255283982734`, \
-0.6259755045136777}, {-2.787655060361113, -0.6292415728299324}, \
{-2.776704038163302, -0.62939820244038}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7530944599279343`, -0.6297358840718332}, \
{-2.614952641148169, -0.6317116904277289}, {-2.438268921505802, \
-0.6330925570155265}, {-2.3387795682947337`, -0.6333006749890214}, \
{-2.2374168747884466`, -0.6329482262463763}, {-2.1015781056870444`, \
-0.6314283581438278}, {-1.9609566664104594`, -0.6283881804157241}, \
{-1.8087851489767792`, -0.6226356819656335}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785190009232664, -0.6217437213208509}, \
{-1.7585847064750868`, -0.6207379683030836}, {-1.5399266017285822`, \
-0.6071677346554766}, {-1.3910726945593441`, -0.594243522367166}, \
{-1.2292833750314778`, -0.5760264621411441}, {-1.0494642121081406`, \
-0.5496775605047954}, {-1.009698557707916, -0.5431330875941378}, \
{-0.968889249270354, -0.5360219244066575}, {-0.9081919453495109, \
-0.5238753889022343}, {-0.8943231757431017, -0.5210549686606079}, \
{-0.8819034755023045, -0.5184955737081393}, {-0.8601138809476264, \
-0.5139607311845783}, {-0.8482813904932979, -0.5114484089421557}}]}, 
           {Arrowheads[{{0.0008980959858161119, 1.}}], 
            ArrowBox[{{-0.8251999662681335, -0.5064712550596849}, \
{-0.8172582301552601, -0.5047387453846482}, {-0.8083829645966094, \
-0.5027779370349132}, {-0.802497994899253, -0.5014682613869577}, \
{-0.7976089626671939, -0.5003753463006376}, {-0.7919354192820275, \
-0.49910177928504207`}, {-0.7876578281586475, -0.4981379656732664}, \
{-0.7837994830085773, -0.4972658835037255}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.65057884320895, 
             2.038626292384503}, {-5.470877195617435, 
             2.037923858137411}, {-5.294308566657271, 
             2.0387581010875917`}, {-5.117247429121624, 
             2.0411855787694355`}, {-4.939693783010492, 
             2.045206291182942}, {-4.7615071422689725`, 
             2.0504939847677646`}, {-4.706286151665255, 
             2.0526758500897713`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.682692568167758, 
             2.053608068456234}, {-4.582831387741451, 
             2.057553735569496}, {-4.403593443207, 
             2.0662500249660027`}, {-4.2237839666911805`, 
             2.076356031466477}, {-4.043393616219557, 
             2.0876449335801106`}, {-3.8624989237494654`, 
             2.1000336862841036`}, {-3.7398906713142503`, 
             2.109017195475971}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7163418047035366`, 
             2.1107426214196057`}, {-3.6811077220928214`, 
             2.1133242233812486`}, {-3.4991076205570604`, 
             2.1271171916191296`}, {-3.3163862284496166`, 
             2.1410132377453297`}, {-3.1327896766205163`, 
             2.1548242430548137`}, {-2.9481972786857114`, 
             2.1681931012046416`}, {-2.774387725303732, 2.179684116909796}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.750820190278071, 
             2.1811278421438174`}, {-2.575774478324288, 
             2.1909930371882282`}, {-2.4505628841991713`, 
             2.1967850933892437`}, {-2.324726220271503, 
             2.2014197509878155`}, {-2.1982861941446563`, 
             2.2046522503647514`}, {-2.0712645134220047`, 
             2.2062378319008573`}, {-1.9435914892647066`, 
             2.20594624117816}, {-1.815270549987693, 
             2.2035356196177105`}, {-1.806917412267789, 
             2.2032249435580606`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7833217335778884`, 
             2.202347355671215}, {-1.6864330789249953`, 
             2.1987438013588516`}, {-1.5572104594106444`, 
             2.1913086205409256`}, {-1.42758687026307, 
             2.180921104569439}, {-1.297664253913183, 
             2.1673097262369674`}, {-1.1677506391137378`, 
             2.1502684877634572`}, {-1.0381540546174872`, 
             2.129591391368856}, {-0.9088519951302146, 
             2.104906325306824}, {-0.8468816450894989, 
             2.0909822502742594`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8238440225043286, 
             2.0858059428104956`}, {-0.78008638259528, 
             2.075974069004051}, {-0.6525618866218024, 
             2.0427879614400277`}, {-0.526983176818901, 
             2.005341341594245}, {-0.300442811617016, 
             1.9236800563564858`}, {-0.08516020418363719, 
             1.8264259082022913`}, {0.05420382597652974, 
             1.748284170934669}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.07479926244322015, 1.7367362615964952`}, {
             0.11429436801263321`, 1.7145912636424667`}, {0.1532953523809372, 
             1.6895550932260746`}, {0.19136536687256783`, 
             1.6639215185572651`}, {0.3022049414263402, 1.581809666084622}, {
             0.4027004862873409, 1.494858146493803}, {0.5038295512215907, 
             1.3886389575458604`}, {0.5869337438438319, 
             1.2762649479609256`}, {0.6489625612467794, 
             1.1570043344466425`}, {0.6566802299045907, 
             1.1382253372345044`}, {0.6638080163700177, 
             1.1192573033880417`}, {0.6734830376889602, 1.083414187029145}, {
             0.6807065754795576, 1.0465334047044927`}}]}, 
           {Arrowheads[{{0.004771921181903082, 1.}}], 
            ArrowBox[{{0.683357300881452, 1.0230707502817793`}, {
             0.689349074471052, 0.9699959459947572}, {0.6847796182512328, 
             0.886920872091365}, {0.6655360596414142, 0.8002960517381899}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0158959070893343`, -2.2277398695506974`}, \
{-1.7895057046780332`, -2.224322008704496}, {-1.5615828585102662`, \
-2.2133864587257466`}, {-1.3325416737366345`, -2.1933852063813815`}, \
{-1.103363498091348, -2.1629568413245774`}, {-1.0750681455753923`, \
-2.157716723005199}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0518509327573886`, -2.1534170436799838`}, \
{-0.8749712672159753, -2.1206600608784276`}, {-0.6495388261045822, \
-2.0655865527986763`}, {-0.5272837424304887, -2.0294144235147993`}, \
{-0.40696530273592957`, -1.9891181186287499`}, {-0.2893350249274629, \
-1.9446805004129946`}, {-0.1748104189531765, -1.896092047907793}, \
{-0.1498021913548566, -1.8834998744547224`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.1287127705999683, -1.8728809034330345`}, {
             0.04250437063282242, -1.7866694383435615`}, {
             0.07871144809034954, -1.7658983601027352`}, {
             0.11427568224055917`, -1.744713355312216}, {
             0.24216667132213265`, -1.6608880680031202`}, {
             0.35903907410625285`, -1.5713865207998972`}, {
             0.46268413479406256`, -1.4773807261431224`}, {
             0.5525917408758806, -1.3787872908860423`}, {
             0.608922704712211, -1.3008465463365382`}}]}, 
           {Arrowheads[{{0.010641440434221792`, 1.}}], 
            ArrowBox[{{0.6227538261101652, -1.2817095064867805`}, {
             0.6270596672191502, -1.2757518512454953`}, {
             0.6379033260108671, -1.2584661907941077`}, {
             0.6482507791662434, -1.2410249604420536`}, {
             0.6671695494018813, -1.202854650475884}, {
             0.6836794439972083, -1.1639655472777777`}, {
             0.7111732488685962, -1.0844037950560015`}, {
             0.7262646025143907, -1.0003474967159944`}, {
             0.7259908014817712, -0.9098508135252377}, {
             0.7182880442341136, -0.8581440413303639}, {
             0.7034599622584696, -0.8028038942539876}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.4543725802607221`}, {-5.623379661105996, 
             1.4542616097474856`}, {-5.46535773050698, 
             1.4545275333401146`}, {-5.303592989493865, 
             1.4556244696140892`}, {-5.14011228904849, 
             1.457697445898355}, {-4.97621622111784, 
             1.4608213501172893`}, {-4.8119344243378865`, 
             1.4649483262372756`}, {-4.71252075057206, 
             1.4680171179077701`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688919999351365, 
             1.4687456473546758`}, {-4.647296537344605, 
             1.4700305182246969`}, {-4.48243419366599, 
             1.47608753252343}, {-4.317397430916421, 
             1.4830850055953566`}, {-4.1520934938614475`, 
             1.4908941264338684`}, {-3.986429627266622, 
             1.4993860840323576`}, {-3.8204473649337993`, 
             1.5086772552886054`}, {-3.745516841500896, 1.513185976145719}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721947478415099, 
             1.5146041923020357`}, {-3.6540808094357917`, 
             1.518687866776882}, {-3.4870760586945853`, 
             1.5289948820053108`}, {-3.319179210632166, 
             1.5391752644820154`}, {-3.1411014952315117`, 
             1.5493372083074426`}, {-2.9617706341720207`, 
             1.5591787778017145`}, {-2.78079639035339, 
             1.5678753032770232`}, {-2.778986371731128, 
             1.5679455256235322`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7553921286904575`, 
             1.568860899139606}, {-2.5979619653865624`, 
             1.574968634906808}, {-2.4127694145068004`, 
             1.5798516687152795`}, {-2.224720792949366, 
             1.5819173007266483`}, {-2.129960796464468, 
             1.58166238647872}, {-2.034357423963601, 
             1.580308809695881}, {-1.81125588230027, 
             1.5724207097575411`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7876713514509346`, 
             1.5713561029998797`}, {-1.563704436204269, 
             1.55452842929233}, {-1.327297215115801, 
             1.5257302167259668`}, {-1.2064520498511844`, 
             1.5058228641713411`}, {-1.0836190071786473`, 
             1.4814845844471076`}, {-1.0537536995416141`, 
             1.4750801990375337`}, {-1.023788815630774, 
             1.4683768436619018`}, {-0.9593762556662543, 
             1.4519627397461712`}, {-0.8945373282475482, 
             1.4339182491633582`}, {-0.8572819621592817, 
             1.4223571832448383`}}]}, 
           {Arrowheads[{{0.019913183232811965`, 1.}}], 
            ArrowBox[{{-0.8347308326557786, 
             1.4153591284113578`}, {-0.7568803342674009, 
             1.391200602052356}, {-0.6177860747134982, 
             1.339266779922883}, {-0.4784502057763496, 
             1.2756730059272112`}, {-0.34006838364646447`, 
             1.1979755032176125`}, {-0.2717117870377008, 
             1.1531758785610433`}, {-0.20472875854716832`, 
             1.1030325139720023`}, {-0.13972098136051148`, 
             1.0465014390815632`}, {-0.1114166761920525, 
             1.0191439343699789`}, {-0.09042342098066175, 
             0.9977145820070069}, {-0.0757405799013073, 
             0.9820706307962251}, {-0.06482731732134057, 
             0.9700633350668779}, {-0.05729521239018848, 
             0.961573771395828}, {-0.05203000668222328, 
             0.9555367279988535}, {-0.04576503111568285, 
             0.9482536413532351}, {-0.0423592144019065, 
             0.9442409836922288}, {-0.03868412568871358, 
             0.9398787731845927}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.4783102883088386`}, \
{-5.456833547668115, -1.4782733740581848`}, {-5.2312154495765135`, \
-1.4800909766245598`}, {-5.00470259277959, -1.4836833845930788`}, \
{-4.7774514003239, -1.4891569617441487`}, {-4.712511058996765, \
-1.491283564562694}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688911716192207, -1.4920563727724812`}, \
{-4.549635162037306, -1.4966172652250027`}, {-4.321308790721429, \
-1.5059856251143837`}, {-4.082276566422385, -1.5175380374953638`}, \
{-3.8425596895653875`, -1.530524008943685}, {-3.745495573649963, \
-1.5362087094367793`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7219239716831547`, -1.537589214436593}, \
{-3.601831584386096, -1.544622598987062}, {-3.359671414365817, \
-1.559266223148064}, {-3.2379200638144043`, -1.5665772837524732`}, \
{-3.1156496075816618`, -1.5737664357620471`}, {-2.9927551703633677`, \
-1.5806627102735649`}, {-2.8691318768553007`, -1.5870951383838061`}, \
{-2.7789878280446345`, -1.5914344633780237`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75540314487142, -1.5925697752097474`}, \
{-2.74474612132134, -1.5930827795540714`}, {-2.619507282370884, \
-1.598492670554044}, {-2.493224961217992, -1.6029258084430784`}, \
{-2.365708759076722, -1.6059831902805277`}, {-2.2144842056839393`, \
-1.6072609743314468`}, {-2.061302207681349, -1.6062654250551398`}, \
{-1.9057811748988038`, -1.6020729585860491`}, {-1.8113500553895845`, \
-1.5973520700750299`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7877675138442792`, -1.5961731096854836`}, \
{-1.7477091127973337`, -1.5941704727766428`}, {-1.5868240376394798`, \
-1.5817027886423345`}, {-1.4228639656877842`, -1.5638147271985374`}, \
{-1.3516750520763627`, -1.5543672359054352`}, {-1.2798869645628517`, \
-1.5436181680229928`}, {-1.1050877151300553`, -1.5116587598650035`}, \
{-0.9268747938123809, -1.4696392190371388`}, {-0.8568884116982532, \
-1.4493324736918032`}}]}, 
           {Arrowheads[{{0.01941251935183315, 1.}}], 
            ArrowBox[{{-0.8342116927753604, -1.4427527600028742`}, \
{-0.8069034518095762, -1.4348291971843685`}, {-0.6857731961839764, \
-1.3935474813994597`}, {-0.541368045801186, -1.3350090522591815`}, \
{-0.39751847786670846`, -1.263345722919094}, {-0.25650976779436996`, \
-1.175076631832083}, {-0.231233945938087, -1.1573167767526582`}, \
{-0.20617856275279042`, -1.1388097703026783`}, {-0.16867091896710537`, \
-1.106998515799232}, {-0.13206782487775215`, -1.0729823255137199`}, \
{-0.10832772569581697`, -1.0502351112789914`}, {-0.08712369150325422, \
-1.028770654977667}, {-0.0697898863632941, -1.0103790450881251`}, \
{-0.05109190746468893, -0.9896346581785193}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.5808006217459427}, {-5.528625176822331, 
             0.5808357344011142}, {-5.323764614760993, 
             0.5815039603053267}, {-5.16920731735656, 
             0.5824243146505692}, {-5.0144625368643805`, 
             0.5837179873411347}, {-4.859530273284458, 
             0.5853849783770232}, {-4.7124054657308845`, 
             0.5873201293265901}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688796021141404, 
             0.5876661015211129}, {-4.549101599519511, 
             0.5898205302589863}, {-4.393601794650753, 
             0.592552320653495}, {-4.237911112010517, 
             0.5956206589417605}, {-4.082029551598802, 
             0.5990255451237833}, {-3.925795061097455, 
             0.6026743818871168}, {-3.7690455881883227`, 
             0.6064745719193148}, {-3.744520723980927, 0.6070908018402649}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7209161812082363`, 
             0.607683907082515}, {-3.6117811328714047`, 
             0.6104261152203773}, {-3.454001695146701, 
             0.6145290117903043}, {-3.2897900859449747`, 
             0.6187784716407423}, {-3.1242877889672247`, 
             0.6228773081009497}, {-2.9569986588433124`, 
             0.6266491839455003}, {-2.7874265502031017`, 
             0.6299177619489679}, {-2.776705080291498, 0.6300712017128136}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753095504997498, 
             0.6304090889323345}, {-2.614722144249056, 
             0.6323894121502173}, {-2.438036122183639, 
             0.6337705045881136}, {-2.338553295388848, 
             0.6339780934398076}, {-2.237197388952828, 
             0.6336245538624019}, {-2.1013802691319734`, 
             0.6321024230951655}, {-1.960782382164745, 
             0.6290588332922848}, {-1.8087864953906794`, 
             0.6233056877205768}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.78519139837167, 
             0.6224125975797185}, {-1.7583864709102066`, 
             0.6213980132182738}, {-1.5397068788677917`, 
             0.6078094925253741}, {-1.3908705255688907`, 
             0.5948716417892491}, {-1.2291050543045936`, 
             0.576637087442905}, {-1.049327862663092, 
             0.5502667241243633}, {-1.0095683337405394`, 
             0.5437164754185986}, {-0.9687657523900328, 
             0.5365991946416522}, {-0.9080656535605485, 
             0.5244395364613802}, {-0.8941883140543471, 
             0.5216144211248586}, {-0.8817547114334231, 
             0.5190494104078884}, {-0.8599324910820701, 
             0.514502776036473}, {-0.8482952351302043, 0.5120290682563933}}]}, 
           {Arrowheads[{{0.0009034333728236562, 1.}}], 
            ArrowBox[{{-0.8252147474519705, 
             0.5070475767531735}, {-0.8169353547089171, 
             0.5052391667154946}, {-0.808040905914379, 
             0.5032715254944697}, {-0.8021564682336699, 
             0.5019602263275152}, {-0.7973003184505691, 
             0.5008732413171897}, {-0.791661092836233, 
             0.4996057638952192}, {-0.7874059253178718, 
             0.49864580075841514`}, {-0.783570380446311, 
             0.49777780016300366`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.29560563351355473`}, {-5.489634216579032, 
             0.29573708965274936`}, {-5.316546473708218, 
             0.29609648485149276`}, {-5.142724798323129, 
             0.29667978331006406`}, {-4.968456254713963, 
             0.2974927775094839}, {-4.794027907170918, 
             0.29854125993077285`}, {-4.712383188461749, 
             0.29914169828300163`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688771833970818, 
             0.299315342861715}, {-4.619439755693995, 
             0.29982523057393096`}, {-4.444691800283196, 
             0.30134468943895826`}, {-4.269683380377731, 
             0.30306708741631777`}, {-4.094313835416814, 
             0.3049598753964727}, {-3.9185831654004444`, 
             0.3070230533794229}, {-3.7443454113251975`, 
             0.30923310450220215`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720735493336688, 
             0.30954610659684123`}, {-3.6023101157495563`, 
             0.31112188301254007`}, {-3.461551486760315, 
             0.31302109943755574`}, {-3.3381265101490025`, 
             0.31467278634039275`}, {-3.21398105589059, 
             0.3162981730754405}, {-3.0889148346810655`, 
             0.3178620037419521}, {-2.962727557216419, 
             0.3193290224391806}, {-2.776327875988507, 0.3211415597566244}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7527164682028875`, 
             0.32130719581803135`}, {-2.583572789769339, 
             0.32247130503207333`}, {-2.5538310173413907`, 
             0.3226351001309689}, {-2.5239536328754304`, 
             0.3227806655805192}, {-2.4102633332938113`, 
             0.3229339469683825}, {-2.293816525859013, 
             0.32268796465428545`}, {-2.1084873327044695`, 
             0.3214993705633762}, {-1.9128136747699136`, 
             0.31869471566005886`}, {-1.8082945174992573`, 
             0.3162458565980783}}]}, 
           {Arrowheads[{{0.018682610923165813`, 1.}}], 
            ArrowBox[{{-1.7846890027806601`, 
             0.315692784987659}, {-1.7599161003955697`, 
             0.31511236176112845`}, {-1.596259367037705, 
             0.309672215651618}, {-1.4688204225453991`, 
             0.3040809005352543}, {-1.331022307705155, 
             0.2965200645769915}, {-1.2576576879183587`, 
             0.29186080390526503`}, {-1.1802393325382712`, 
             0.28634157712618}, {-1.0981021069159846`, 
             0.2797567276957874}, {-1.0550760589488493`, 
             0.27599875955785397`}, {-1.0119613295996044`, 
             0.2720071856028987}, {-0.9748867661952401, 
             0.26840881376337733`}, {-0.9502806006949811, 
             0.2659372025438697}, {-0.9335286906075663, 
             0.2642235636818492}, {-0.9240094963503847, 
             0.2632363421857507}, {-0.9180449579640014, 
             0.2626135257611797}, {-0.9139665226333147, 
             0.2621861150330914}, {-0.9091443706735385, 
             0.2616792188414374}, {-0.9043491409869884, 
             0.2611734936292219}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.282605280682145}, \
{-5.542101959412694, -5.270497782789376}, {-5.303164030338342, \
-5.249066209226792}, {-5.18180926444692, -5.2401373804910545`}, \
{-5.059529781102117, -5.232871822112313}, {-4.936367821423866, \
-5.227212368566714}, {-4.8123656265321095`, -5.223101854330406}, \
{-4.714733976200384, -5.2210532039710795`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.691127179735415, -5.220557851573612}, \
{-4.687565437546787, -5.220483113879537}, {-4.562009495587832, \
-5.219298981690252}, {-4.435740041775184, -5.219492292238701}, \
{-4.308799317228785, -5.22100588000103}, {-4.132272522271892, \
-5.225292839279254}, {-3.954649862114419, -5.232029603763275}, \
{-3.776045705108683, -5.240966534618287}, {-3.747147349355306, \
-5.243133660451571}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7236014709902525`, -5.244899396942178}, \
{-3.5953544905156134`, -5.254516807247428}, {-3.4141964366597093`, \
-5.269143871490926}, {-3.2322856226601777`, -5.285471824435802}, \
{-3.049622048517018, -5.303500666082052}, {-2.866205714230227, \
-5.323230396429681}, {-2.7832703503139977`, -5.332549883899694}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.759806036027142, -5.335186580390345}, \
{-2.682415952397698, -5.343882941998119}, {-2.498632095617323, \
-5.3646802293068045`}, {-2.3148541438891, -5.385622258355735}, \
{-2.131082097213027, -5.406709029144912}, {-1.8977097300219592`, \
-5.433055634437658}, {-1.8213114621406454`, -5.441335850971663}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7978369408451675`, -5.443880072519469}, \
{-1.6651489966958706`, -5.458261091088043}, {-1.4339952454944662`, \
-5.481534221759362}, {-1.2048438246774502`, -5.502083849114907}, \
{-0.9778262769387844, -5.519770541722893}, {-0.8571676728526172, \
-5.527653849940366}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8336059158906899, -5.5291932726254105`}, \
{-0.7530741449724261, -5.534454868151531}, {-0.6221758743706971, \
-5.541627076647143}, {-0.49237345070333205`, -5.547645280877419}, \
{-0.3636668739703311, -5.55250948084236}, {-0.2360561441716933, \
-5.556219676541965}, {-0.10954126130741948`, -5.558775867976234}, {
             0.015877774622489516`, -5.560178055145168}, {
             0.11018666412796334`, -5.560366321342501}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1337986100779735, -5.560413457209533}, {
             0.14020096361803436`, -5.560426238048765}, {
             0.26342830567921494`, -5.559520416687028}, {
             0.5066220288070208, -5.554906244299568}, {
             0.7454855238144436, -5.546995021114811}, {
             0.9800187907014828, -5.5357867471327555`}, {
             1.0776389738211918`, -5.529635601306195}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.101204231569192, -5.52815073073726}, {
             1.210221829468137, -5.521281422353404}, {
             1.4366206493363203`, -5.50443460953659}, {
             1.6597412595279448`, -5.48620187144215}, {
             1.8795836600430105`, -5.466583208070083}, {
             2.042460135521768, -5.450785797820047}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0659618459781885`, -5.448506363908144}, {
             2.096147850881519, -5.445578619420391}, {
             2.2440435477040253`, -5.430727131432466}, {
             2.3911253330990974`, -5.41611616517303}, {
             2.537393207066735, -5.401745720642082}, {
             2.682847169606938, -5.387615797839623}, {
             2.827487220719706, -5.373726396765653}, {
             2.9713133604050395`, -5.36007751742017}, {
             3.0059796685945517`, -5.3568273180272366`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0294885622840315`, -5.35462320123521}, {
             3.114325588662939, -5.346669159803176}, {
             3.256523905493404, -5.333501323914671}, {
             3.398212415237144, -5.320818319193439}, {
             3.539695222234868, -5.308864455078264}, {
             3.6809723264865766`, -5.297639731569147}, {
             3.82204372799227, -5.287144148666086}, {
             3.962909426751948, -5.277377706369084}, {
             3.97072785626628, -5.27687537800087}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.994291264848846, -5.2753614462629015`}, {
             4.103569422765609, -5.268340404678138}, {
             4.244023716033257, -5.260032243593251}, {
             4.384272306554888, -5.252453223114421}, {
             4.566207350210096, -5.243795625211419}, {
             4.748049223690927, -5.236522273179447}, {
             4.917920407592101, -5.230900599169607}, {
             4.937644241255482, -5.230374643595167}}]}, 
           {Arrowheads[{{0.014731734720325967`, 1.}}], 
            ArrowBox[{{4.961247843777911, -5.229745230138563}, {
             5.087535442609043, -5.22637764614239}, {
             5.098957114003935, -5.226109867028006}, {
             5.110377231293852, -5.225846836448614}, {
             5.303426801120489, -5.222932317571001}, {
             5.4859652291653695`, -5.221256659987314}, {
             5.656854249492381, -5.220075945915206}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.282842740047349}, {-5.58220381640509, 
             5.274627719826569}, {-5.352757417663612, 
             5.252967570495135}, {-5.231480260230804, 
             5.243523782836009}, {-5.109138561741709, 
             5.235719366685816}, {-4.985785615584896, 
             5.229502616352885}, {-4.861474715148943, 
             5.224821826145547}, {-4.736259153822425, 
             5.221625290372133}, {-4.714748660114742, 5.221324305551715}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.6911389782624076`, 
             5.2209939479156215`}, {-4.6101922249939165`, 
             5.2198613033409735`}, {-4.483327222051995, 
             5.219478159360399}, {-4.3557174383852315`, 
             5.220424152738741}, {-4.176165770767282, 
             5.2240351749682645`}, {-3.9954565573652885`, 
             5.230234849444129}, {-3.8137092867909854`, 
             5.238756950665352}, {-3.7471903326468503`, 5.243609360138912}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7236409141850153`, 
             5.245327237738031}, {-3.629768902464272, 
             5.252174991808079}, {-3.445328159718057, 
             5.266717444941754}, {-3.260088337023001, 
             5.283049873818828}, {-3.0740494343791065`, 
             5.3011722784393}, {-2.8872114517863747`, 
             5.321084658803171}, {-2.78328594269507, 5.332686660866434}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7598197262788076`, 
             5.335306374675478}, {-2.699965976679225, 
             5.341988308037366}, {-2.5127045964920782`, 
             5.36308451926881}, {-2.325427311224935, 
             5.384373292497503}, {-2.1381341208777975`, 
             5.4058546277234445`}, {-1.8958270907441133`, 
             5.433191292066933}, {-1.8213010940695125`, 5.441241790718335}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7978256700311672`, 
             5.443777669176787}, {-1.6544168161620898`, 
             5.4592690793717145`}, {-1.4145303580004538`, 
             5.4832484127727605`}, {-1.1767947771279368`, 
             5.504289715405041}, {-0.9414218081277842, 
             5.522204784270604}, {-0.8571514763429666, 
             5.527490039389221}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8335857860352309, 
             5.5289680291239796`}, {-0.7086231855832431, 
             5.536805416371498}, {-0.5771490475771146, 
             5.543606954012742}, {-0.44678978979528783`, 
             5.549248242318683}, {-0.31754541223776217`, 
             5.55372928128932}, {-0.1894159149045368, 
             5.557050070924655}, {-0.06240129779561232, 5.559210611224685}, {
             0.0634984390890102, 5.5602109021894135`}, {0.11020751274593216`, 
             5.560151027077055}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13381948634432342`, 5.560120759519564}, {
             0.18828329574933178`, 5.560050943818838}, {0.31195327218535385`, 
             5.558730736112958}, {0.5560033205979136, 5.553308947895471}, {
             0.7957033205401091, 5.544644912737135}, {1.031053272011941, 
             5.532738630637949}, {1.0776742523898217`, 
             5.5296813164748135`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1012356370610212`, 5.528136206215988}, {
             1.2620531750134096`, 5.5175901015979125`}, {1.489258157702072, 
             5.5001794480112}, {1.7132233482354855`, 5.481486792271983}, {
             1.9339487466136502`, 5.461512134380263}, {2.0425058651768877`, 
             5.450901952838804}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.066005879925916, 5.4486051027932785`}, {
             2.1514343528365667`, 5.4402554743360385`}, {2.2995138177218353`, 
             5.425331804260382}, {2.44680836666803, 5.410683112676717}, {
             2.593317999675152, 5.396309399585045}, {2.7390427167432003`, 
             5.382210664985364}, {2.883982517872176, 5.3683869088776754`}, {
             3.0060223821223824`, 5.356916669913539}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.029530951522158, 5.354709110641936}, {
             3.171507372312905, 5.341564332138275}, {3.3140924256246604`, 
             5.328565511506563}, {3.4561927972203916`, 5.316078804367902}, {
             3.598108721323148, 5.304341345723352}, {3.7398401979329297`, 
             5.2933531355729135`}, {3.8813872270497374`, 5.283114173916585}, {
             3.970783696573645, 5.277112961688061}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9943426652580674`, 5.27553144094442}, {
             4.02274980867357, 5.273624460754369}, {4.163927942804428, 
             5.264883996086263}, {4.304921629442312, 5.256892779912268}, {
             4.44573086858722, 5.249650812232384}, {4.629803383023583, 
             5.241379651141993}, {4.813743308374937, 5.234501516312725}, {
             4.937703552559931, 5.230711919520592}}]}, 
           {Arrowheads[{{0.014730600586284693`, 1.}}], 
            ArrowBox[{{4.961304519518832, 5.229990412804735}, {
             4.983513108690703, 5.2293114725619425`}, {5.152994334745804, 
             5.225199964005906}, {5.164406382384836, 5.224959221588704}, {
             5.175816729985471, 5.224723139901451}, {5.3692177525302425`, 
             5.222286995056471}, {5.5094160986288765`, 5.221086216244442}, {
             5.6379352555799835`, 5.220356499650418}, {5.656854249492381, 
             5.22027656201232}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.242743459154126}, \
{-5.561904574722917, -4.23652126376186}, {-5.318215096800279, \
-4.225592351016313}, {-5.1954341306725365`, -4.221948503479387}, \
{-5.072044790631219, -4.219515056483442}, {-4.94805890982436, \
-4.218289506016287}, {-4.823488321399989, -4.218269348065733}, \
{-4.712913565774475, -4.219451965922308}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689304630436542, -4.219808243740265}, \
{-4.572522701483656, -4.222402642433324}, {-4.4461483949675795`, \
-4.226565272946282}, {-4.319219065505037, -4.2320083972422315`}, \
{-4.191764194165138, -4.238644393993835}, {-4.06381326201699, \
-4.246385641873753}, {-3.935395750129699, -4.2551445195546505`}, \
{-3.8065411395723725`, -4.2648334057091875`}, {-3.7463222875588085`, \
-4.269922502893946}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7227941633735044`, -4.271910865450693}, \
{-3.591284606162814, -4.283024742500674}, {-3.3748865616046344`, \
-4.30349331897793}, {-3.157589285824255, -4.3255866032414065`}, \
{-2.939635058748095, -4.34865206339156}, {-2.782975056640339, \
-4.365361653426511}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7594962413535504`, -4.367865938966344}, \
{-2.7211878973723005`, -4.371951964207198}, {-2.5024744290372394`, \
-4.394816733124444}, {-2.2838308491856587`, -4.416696082229731}, \
{-2.0655933532603057`, -4.437039723609487}, {-1.8481292597545218`, \
-4.454997411917668}, {-1.8192729800340535`, -4.456992953423881}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7957172456718975`, -4.458621938382593}, \
{-1.6317809887211734`, -4.469958867754206}, {-1.4168473879422971`, \
-4.481733752124506}, {-1.203627305199933, -4.490131726033966}, \
{-0.9925414401630146, -4.4947055459376015`}, {-0.8521666350362027, \
-4.495047315369908}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8285547120206314, -4.495104803132882}, \
{-0.7839130109909573, -4.495213491930736}, {-0.5778946432015266, \
-4.491773510479235}, {-0.37463896231248345`, -4.484503548048965}, \
{-0.23866553265273815`, -4.477279902792513}, {-0.10431065132653455`, \
-4.468122697981119}, {0.028496819205778567`, -4.45720436706265}, {
             0.11442591032107566`, -4.4490211083178774`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13793155443429503`, -4.446782602530787}, {
             0.15982801648385386`, -4.444697343484974}, {
             0.2897540780473438, -4.430774060695961}, {
             0.4183461414358997, -4.415606952143476}, {
             0.5456753441891742, -4.3993684512753894`}, {
             0.6718128238468195, -4.382230991539569}, {
             0.8514892979361398, -4.356501618197187}, {
             1.0289737824656497`, -4.330052183792245}, {
             1.0741700432144932`, -4.3231505142725775`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.0975114593965305`, -4.319586176472496}, {
             1.2045237412600946`, -4.303244926295363}, {
             1.375650357346939, -4.272578211990528}, {
             1.5460010349100703`, -4.243183745461554}, {
             1.7149321143876268`, -4.214155931781887}, {
             1.8824435957796082`, -4.185494770951527}, {
             2.028492980161422, -4.160614593848616}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0517717558431046`, -4.156661897775965}, {
             2.213727788776822, -4.129719983435377}, {
             2.3785405493220084`, -4.103501507942893}, {
             2.542973760721574, -4.078544836493018}, {
             2.7070274229755182`, -4.054849969085754}, {
             2.8322531478180073`, -4.037574954290525}, {
             2.957404969496876, -4.021052852841898}, {
             2.9858867011246764`, -4.017592158429145}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0093263010610634`, -4.0147441120534175`}, {
             3.1812338623867973`, -3.993856353374829}, {
             3.4060576259213464`, -3.969835196449562}, {
             3.421175687563615, -3.9683300082085347`}, {
             3.4362978255738286`, -3.966838159357148}, {
             3.576904227068872, -3.9542431972233603`}, {
             3.7178014685755976`, -3.942718108633184}, {
             3.8529086347541392`, -3.9321428335184967`}, {
             3.9494224104499356`, -3.925265934414028}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9729746917396156`, -3.923587762972267}, {
             3.9883871515238876`, -3.922489578489026}, {
             4.124237018884842, -3.9137583435447723`}, {
             4.260458236837003, -3.905949128685735}, {
             4.3970508053803705`, -3.8990619339119146`}, {
             4.534014724514943, -3.8930967592233103`}, {
             4.671349994240723, -3.8880536046199228`}, {
             4.809056614557709, -3.883932470101752}, {
             4.916423603230712, -3.8813855470128833`}}]}, 
           {Arrowheads[{{0.015180123983342585`, 1.}}], 
            ArrowBox[{{4.940028955594991, -3.8808255888944663`}, {
             4.947061225215526, -3.8806587717928127`}, {
             5.085290465963797, -3.87815792581712}, {
             5.223702743724127, -3.876398408828217}, {
             5.3622564654181195`, -3.875348697479646}, {
             5.499183578951024, -3.874919258623117}, {
             5.6327160322280925`, -3.8750205591103413`}, {
             5.656854249492381, -3.8751183309221435`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4188709725942448`, 0.6983257180200686}, {
             1.4384498897906064`, 0.6611562013995497}, {1.4576104878577711`, 
             0.6262704181777374}, {1.5079931541357667`, 0.5446175650959187}, {
             1.563871456849302, 0.4769178698801115}, {1.5679471766666864`, 
             0.47281551935118044`}, {1.5720904841218113`, 
             0.46877098417348223`}, {1.5996423932098338`, 
             0.44738652899774095`}, {1.63072040841926, 0.4278809006490461}, {
             1.7009389168707718`, 0.3923548740593762}, {1.7889806419358552`, 
             0.36342538225300397`}, {1.8978378475537447`, 
             0.3403205847601441}, {2.039722165446109, 0.32114109944693353`}, {
             2.208507550288562, 0.30667904697621295`}, {2.2090771214659237`, 
             0.30664752080949637`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.232653027323853, 0.3053425777784696}, {
             2.403625035792853, 0.29587915642377216`}, {2.6216979603036816`, 
             0.28791870362209043`}, {2.8598061081833155`, 
             0.2820698187125136}, {2.98513515417697, 0.27978233002891395`}, {
             3.114081862128064, 0.2778157595235988}, {3.1766130383058093`, 
             0.27701967502514147`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.200223118039333, 0.2767190950643588}, {
             3.246287126193446, 0.2761326541069064}, {3.3814290597960674`, 
             0.27471860935330034`}, {3.51913925227625, 0.2735304100070875}, {
             3.659049292974314, 0.2725248408125748}, {3.8881608711444864`, 
             0.2712710729987625}, {4.121677169104504, 0.2704273257850646}, {
             4.144677953983621, 0.2703751676920298}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.168289886271753, 0.27032162372092233`}, {
             4.358467154289958, 0.26989036523602544`}, {4.597399794136442, 
             0.26955695741618935`}, {4.83794814504056, 0.2694006472709071}, {
             5.079930457090919, 0.26943885339170476`}, {5.11276882017194, 
             0.26946526696996964`}}]}, 
           {Arrowheads[{{0.01102138736527081, 1.}}], 
            ArrowBox[{{5.136380805531659, 0.26948425929981723`}, {
             5.3227334882611235`, 0.2696341523123893}, {5.565743996524773, 
             0.26994912056676773`}, {5.656854249492381, 
             0.2701055174182301}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.3898954202976221`, -0.7586699837718556}, {
             1.4322301315369177`, -0.67993516315367}, {
             1.4521525288233517`, -0.6440982954898171}, {
             1.4718947422111657`, -0.6105211434558856}, {
             1.5251097485292022`, -0.5323136200003304}, {
             1.5866596753129376`, -0.4679713132703132}, {
             1.591235373490228, -0.46409154273707626`}, {
             1.5958918710569174`, -0.46026895940555923`}, {
             1.6246314608679258`, -0.44142575098481324`}, {
             1.6567926354209779`, -0.42419693264479824`}, {
             1.728702347680569, -0.392723591837314}, {
             1.817050039424935, -0.3668972216518021}, {
             1.9239993542732594`, -0.34605769648933693`}, {
             2.0652824261820286`, -0.32805734056353414`}, {
             2.151682282220064, -0.3209257855257266}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.1752142489007382`, -0.3189834267854851}, {
             2.2311836396747444`, -0.31436364141730494`}, {
             2.42096118276177, -0.30402604973323305`}, {
             2.6315970302843565`, -0.29631384809211686`}, {
             2.860463760573986, -0.29057446313890994`}, {
             3.1041864488678153`, -0.28634338153182853`}, {
             3.1189711505897266`, -0.2861460238220085}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.142581040159583, -0.2858308606335821}, {
             3.2307371537874645`, -0.2846540841913189}, {
             3.3600210334978673`, -0.28322285765783456`}, {
             3.4917111497622573`, -0.282010033588207}, {
             3.625480564343869, -0.28097594363926737`}, {
             3.8526044087527507`, -0.27963024404766534`}, {
             4.084224767430304, -0.2787143092955504}, {
             4.08702959607876, -0.27870721789035674`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.110641513610526, -0.27864752024190703`}, {
             4.319208913681276, -0.2781202024876101}, {
             4.556424120810415, -0.27773998672853184`}, {
             4.79533757903802, -0.2775457069455414}, {
             5.035759288250419, -0.2775551119644579}, {
             5.055120178022669, -0.2775690489593338}}]}, 
           {Arrowheads[{{0.01224213717518721, 1.}}], 
            ArrowBox[{{5.078732164902911, -0.27758604611928}, {
             5.277070736251403, -0.2777288207378587}, {
             5.518653410844765, -0.27802745221832126`}, {
             5.656854249492381, -0.27825899703136653`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.2809475654323537`}, \
{-5.606319029031815, -3.279304883960883}, {-5.448309058321885, \
-3.2758764637227666`}, {-5.2881542415908225`, -3.2740861243924924`}, \
{-5.125854578838625, -3.2739338659700605`}, {-5.103947859602979, \
-3.2740232754104004`}, {-5.082026125448744, -3.2741465808370482`}, \
{-4.888575014908737, -3.278176027840325}, {-4.7125958276535735`, \
-3.284251681355166}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688998585669356, -3.2850853710410983`}, \
{-4.5465611989345955`, -3.290545759847792}, {-4.398612836812938, \
-3.2973389314225554`}, {-4.250139340263745, -3.305273751746501}, \
{-4.101140709287018, -3.314350220819629}, {-3.951616943882754, \
-3.324568338641939}, {-3.801568044050956, -3.3359281052134317`}, \
{-3.7462359471682496`, -3.3405220548083743`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7227049164375594`, -3.3424757195921795`}, \
{-3.6509940097916225`, -3.348429520534107}, {-3.4998948411047537`, \
-3.362072584603964}, {-3.2967423815403203`, -3.381036005054628}, \
{-3.092987457428686, -3.399828068095469}, {-2.888630068769851, \
-3.418448773726487}, {-2.782111773973885, -3.428036959324196}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7585948628357526`, -3.430153821118775}, \
{-2.6836702155638155`, -3.436898121947682}, {-2.4784490512840063`, \
-3.4539575308827097`}, {-2.27330772940385, -3.4684084186552266`}, \
{-2.068246249923348, -3.480250785265233}, {-1.8632646128424997`, \
-3.4894846307127283`}, {-1.816217903964297, -3.4912764121802544`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7926230167154042`, -3.492175027252573}, \
{-1.6574992892027784`, -3.4973212361278208`}, {-1.4558436097691676`, \
-3.4968966751065653`}, {-1.2549585959020317`, -3.4928945680187122`}, \
{-1.0551896591847805`, -3.4848304024122188`}, {-0.8488614251129806, \
-3.4717034261282493`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.825311624678058, -3.470014303681358}, \
{-0.6132914549077606, -3.4510118750161194`}, {-0.397883551672334, \
-3.425472840845953}, {-0.1871982974835362, -3.3936779721182297`}, \
{-0.026499518849978088`, -3.3649347256793503`}, {
             0.10921570442506001`, -3.337943883167813}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.13237047411739777`, -3.3333205117981226`}, {
             0.2863866842427176, -3.2998155239486957`}, {
             0.4384346270178825, -3.264114171109181}, {
             0.5876464146926172, -3.226869641150564}, {
             0.7342460669820439, -3.1885788755157387`}, {
             0.8783240760753256, -3.1496662519127057`}, {
             1.0199709341616259`, -3.1105561480494663`}, {
             1.04808116327724, -3.1027155980582}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0708250198916145`, -3.096371845253989}, {
             1.1594945047515326`, -3.0716400109496624`}, {
             1.297326863539305, -3.033290470103018}, {
             1.4337448209896129`, -2.9959036769166545`}, {
             1.5690251875671268`, -2.9598757827976945`}, {
             1.7034765412144854`, -2.9253674669960357`}, {
             1.8374256127188828`, -2.8924048532431623`}, {
             1.9711764418118194`, -2.8611822596685754`}, {
             1.984669761332133, -2.8582298784746243`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.007736061602774, -2.853182898668762}, {
             2.105033068224796, -2.831894004401777}, {
             2.2892636086239198`, -2.7947779418544485`}, {
             2.4745113209731966`, -2.761083351458058}, {
             2.6613819375239594`, -2.730949089487669}, {
             2.8504811905275416`, -2.704514012218346}, {
             2.938290184436996, -2.6939777370132423`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9617340107894696`, -2.691164692525282}, {
             3.041888511688917, -2.6815468863894414`}, {
             3.2353825895437165`, -2.661604999005615}, {
             3.4311180415892526`, -2.644509986739892}, {
             3.6292494853228368`, -2.6300834862652978`}, {
             3.8295985823302154`, -2.618097171632811}, {
             3.902899905997206, -2.614543364520132}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9264841975816647`, -2.613399946925641}, {
             4.031796733676241, -2.608294166823668}, {
             4.235713166076879, -2.6004532834062832`}, {
             4.441217106248103, -2.59435333294907}, {
             4.648097608234552, -2.5898563507630703`}, {
             4.856097913125824, -2.5868719285836854`}, {
             4.870528303324883, -2.586759914773087}}]}, 
           {Arrowheads[{{0.016151238791762886`, 1.}}], 
            ArrowBox[{{4.894139584994664, -2.586576635624258}, {
             5.06501852820532, -2.5852502126158674`}, {
             5.274659960756444, -2.5848413490645687`}, {
             5.456834341035187, -2.5853528283023777`}, {
             5.638149792934427, -2.586563827781951}, {
             5.656854249492381, -2.586747443286796}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.23425932674912}, {-5.635639394697933, 
             4.2327464960504555`}, {-5.414099192199284, 
             4.221053879580494}, {-5.1904427474629715`, 
             4.213564488299747}, {-4.964747566741349, 
             4.210222762330912}, {-4.7370911562867715`, 
             4.210973141796686}, {-4.7128942636446185`, 4.211520107007834}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689288300912621, 
             4.21205371438383}, {-4.507463369183564, 
             4.216163825283024}, {-4.275924181050475, 
             4.225820004605276}, {-4.04265628194149, 
             4.239401609730228}, {-3.807842361910594, 
             4.25636857062467}, {-3.746290304978667, 
             4.2616570272273036`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7227649840232613`, 
             4.263678286063109}, {-3.571400674721028, 
             4.276683271125065}, {-3.333461023168626, 
             4.299906131972136}, {-3.0945234208562686`, 
             4.324894138489062}, {-2.8550878813868352`, 
             4.350504275999018}, {-2.7830311194914725`, 4.357999826374846}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7595458487903777`, 
             4.360442831375344}, {-2.6562685873645315`, 
             4.371186027368791}, {-2.4577743973001356`, 
             4.390530857833717}, {-2.2598651002645145`, 
             4.408113757643758}, {-2.0600294019059446`, 
             4.4280431543826175`}, {-1.861947647395055, 
             4.44429807659142}, {-1.8191031328520522`, 
             4.447265558448506}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7955475723458467`, 
             4.448897055483336}, {-1.6649703640546751`, 
             4.457941048645262}, {-1.4690975518848053`, 
             4.468972070544143}, {-1.274329210885447, 
             4.477391142288063}, {-1.081151658953474, 
             4.482852134311596}, {-0.8900512139857615, 
             4.485008917049315}, {-0.851962974056116, 4.4847777103733195`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8283514160785025, 
             4.484634381360344}, {-0.7010278759823109, 
             4.483861490501222}, {-0.5140816449431224, 
             4.479409854667316}, {-0.2968967600802612, 
             4.470279847593911}, {-0.08332833818296953, 4.457269836558828}, {
             0.11484501663835178`, 4.441327375474293}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13835964808919937`, 4.439198456672731}, {
             0.3329591167149035, 4.419609802603625}, {0.5358505768005011, 
             4.395876419086257}, {0.7354704280905615, 4.370096310412713}, {
             0.9318186705850844, 4.342269476582993}, {1.0751472376983466`, 
             4.320093129699416}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0984815767591967`, 4.316482751058684}, {
             1.1248953042840693`, 4.3123959175970965`}, {1.3152784470723018`, 
             4.2814524691914455`}, {1.5035462168345677`, 4.250415967102459}, {
             1.6896986135708665`, 4.219286411330139}, {1.8737356372811977`, 
             4.188063801874484}, {2.0078526070844713`, 4.16547881805401}, {
             2.030208228640686, 4.161825973756855}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.053511192225231, 4.158018336495571}, {
             2.1416461220408127`, 4.143617342322924}, {2.2751161821502217`, 
             4.122479374681227}, {2.4082627874126983`, 4.102064915128918}, {
             2.5410859378282424`, 4.082373963665997}, {2.673585633396854, 
             4.063406520292466}, {2.805761874118533, 4.045162585008322}, {
             2.93761465999328, 4.027642157813568}, {2.987991897653788, 
             4.0213101842346495`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.011419557604622, 4.018365534414342}, {
             3.069977548040682, 4.011005312506694}, {3.2027016526905037`, 
             3.995517549191658}, {3.427439729142051, 3.9718040429751444`}, {
             3.653069455678553, 3.951037503727692}, {3.6682472470467884`, 
             3.949742246575027}, {3.683428554862114, 3.948459350321653}, {
             3.8318263097793333`, 3.937209773557144}, {3.9515260493094613`, 
             3.9290827892158147`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9750838076659427`, 3.9274833410129073`}, {
             3.980594302789781, 3.927109207303342}, {4.2244724503624465`, 
             3.9120312857787787`}, {4.469550688221716, 3.8998321349276055`}, {
             4.592539841008827, 3.8948120985045405`}, {4.715829016367589, 
             3.8905117547498227`}, {4.839418214298002, 3.886931103663452}, {
             4.918531422019465, 3.8851041521604057`}}]}, 
           {Arrowheads[{{0.015135486815862766`, 1.}}], 
            ArrowBox[{{4.942137121621687, 3.8845590286644582`}, {
             4.963307434800066, 3.8840701452454294`}, {5.087419590006024, 
             3.8818680089955118`}, {5.211677592048121, 3.8802638244134573`}, {
             5.336056385666442, 3.879231269650331}, {5.4605309156010735`, 
             3.878744022857198}, {5.656854249492381, 3.8789578054627003`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8085396572674286`, -2.675817070217156}, \
{-1.6157872931825175`, -2.672036955478235}, {-1.476352486923767, \
-2.666072061769225}, {-1.3372199304104182`, -2.657103300864795}, \
{-1.1986287279456427`, -2.6450486077001467`}, {-1.0608179838326104`, \
-2.6298259172104816`}, {-0.9239907054624624, -2.611202391574509}, \
{-0.8678790341661662, -2.602043016407849}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8445754687038125, -2.5982390645051616`}, \
{-0.788378777755963, -2.5890658111761318`}, {-0.6542646213107202, \
-2.563515038258342}, {-0.5219306567243415, -2.5346489350641317`}, \
{-0.39171984617347627`, -2.5023595163756167`}, {-0.26392671857154015`, \
-2.4667042749436137`}, {-0.13876104462129252`, -2.4280302899641653`}, \
{-0.016432595025492328`, -2.3866846406333124`}, {
             0.06671014432028635, -2.356048139945843}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.08886586619259043, -2.347884182470864}, {
             0.10257742461243176`, -2.3428317368543112`}, {
             0.21800495660958566`, -2.2967821239646464`}, {
             0.43857636239375863`, -2.2003579002428695`}, {
             0.6179611235759354, -2.115934874308699}, {
             0.786638262836134, -2.030590224922907}, {
             0.9440315802317765, -1.948381913292677}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9649270531522395, -1.9373862435460318`}, {
             1.0982637573458962`, -1.8671545961169242`}, {
             1.244178999913857, -1.7918362938572034`}, {
             1.3861196554160473`, -1.7223940400068596`}, {
             1.5574830340847092`, -1.6462901250571538`}, {
             1.7299170621083446`, -1.5803294373415016`}, {
             1.819663416876418, -1.550291231621721}, {
             1.8242510063293818`, -1.5489093499809417`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8468595773929593`, -1.5420991570468665`}, {
             1.9109112130158112`, -1.5228054124263832`}, {
             2.0304550393701852`, -1.4910600446225657`}, {
             2.153341565665784, -1.4630315724104965`}, {
             2.279856812494407, -1.4384173262764886`}, {
             2.410286800447853, -1.4169146367068541`}, {
             2.4279082565630152`, -1.4142595975412928`}, {
             2.445598931222801, -1.4116537709296821`}, {
             2.557174106333873, -1.3977161929949247`}, {
             2.6713047226395292`, -1.38538126139356}, {
             2.774675072929863, -1.375533972648958}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.7981806515372356`, -1.3732947791180699`}, {
             2.91154774158313, -1.362495178781206}, {
             3.0352592331678485`, -1.352973196810705}, {
             3.1613640461611796`, -1.3447319210639879`}, {
             3.289570474672283, -1.3375563221900497`}, {
             3.419586812810319, -1.3312313708378853`}, {
             3.551413060575287, -1.3257570670074947`}, {
             3.685049217967188, -1.3211334106988781`}, {
             3.740944652953326, -1.3196536282997988`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.7645483757235976`, -1.3190287405336178`}, {
             3.8208737319053876`, -1.317537576349631}, {
             3.956742069846813, -1.3139655754800446`}, {
             4.094117559879678, -1.3111024825821553`}, {
             4.232848823236238, -1.3088774278809252`}, {
             4.453836571334343, -1.3064875449970923`}, {
             4.676804929762095, -1.3052149939584163`}, {
             4.708897124921192, -1.30515228353788}}]}, 
           {Arrowheads[{{0.019573769343788634`, 1.}}], 
            ArrowBox[{{4.7325090728393615`, -1.3051061441206075`}, {
             4.901020122731004, -1.30477686160343}, {
             5.125748374452583, -1.3048902347706661`}, {
             5.348098270114268, -1.3054735914609286`}, {
             5.563945458318309, -1.3065604903391772`}, {
             5.656854249492381, -1.3072255995501187`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.617781624560406, -5.656854249492381}, \
{-5.515432644126144, -5.643963139969983}, {-5.326761111642082, \
-5.622479414633542}, {-5.139311960795244, -5.604801919506122}, \
{-4.965152258895433, -5.59180807768502}, {-4.785553416682722, \
-5.581902763167461}, {-4.676986029334825, -5.578071791956808}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.653388722769426, -5.577239123838791}, \
{-4.597597194315037, -5.57527043190903}, {-4.403091971131801, \
-5.572217833701322}, {-4.389782599664386, -5.572132859545635}, \
{-4.376464601157198, -5.572066408895076}, {-4.205169091183923, \
-5.574505679761552}, {-4.032684878424344, -5.579997628502896}, \
{-3.89502376564044, -5.585082973183234}, {-3.7567179429233213`, \
-5.591593193261744}, {-3.7093970270792895`, -5.594295564948301}}]}, 
           {Arrowheads[{{0.015669047948209402`, 1.}}], 
            ArrowBox[{{-3.68582344244979, -5.595641789688824}, \
{-3.6177674102729873`, -5.599528288738424}, {-3.478172167689438, \
-5.608888259613275}, {-3.337932215172674, -5.619673105886296}, \
{-3.1970475527226947`, -5.631882827557488}, {-3.0555181803395, \
-5.645517424626851}, {-2.9484890214421084`, -5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.649870032487952, 
             5.656854249492381}, {-5.591636039971541, 
             5.649659975471718}, {-5.348750375703421, 
             5.622017389345347}, {-5.228415653716322, 
             5.60998069349129}, {-5.106505566861286, 
             5.599468974499821}, {-4.983020115138312, 
             5.590482232370936}, {-4.857959298547401, 
             5.583020467104639}, {-4.709149524743606, 5.576410163537404}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.685556201365238, 
             5.575490689107106}, {-4.521592984077767, 
             5.571042234307977}, {-4.324123110547457, 
             5.569435551134604}, {-4.124640758209493, 
             5.5719382391275625`}, {-4.111155404179355, 
             5.572244779243325}, {-4.097662172806277, 
             5.572570321069846}, {-3.9372247178545305`, 
             5.578917236416904}, {-3.778244084293312, 
             5.587177927523576}, {-3.741565512966948, 5.589260753582394}}]}, 
           {Arrowheads[{{0.0168303768221458, 1.}}], 
            ArrowBox[{{-3.7179914982278124`, 
             5.590599425467205}, {-3.6524551234083096`, 
             5.594320968164709}, {-3.5253307201573008`, 
             5.602747400528891}, {-3.396870874540285, 
             5.612457224616121}, {-3.2670755865572625`, 
             5.623450440426402}, {-3.1365135030394464`, 
             5.635518738697457}, {-3.005753270818048, 
             5.648453810167015}, {-2.9260459592545156`, 
             5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.57431328309818, 5.656854249492381}, {
             3.634256783807513, 5.65230456393923}, {3.8196218729498383`, 
             5.638938183385242}, {4.002771949908018, 5.624943343229179}, {
             4.191459557326563, 5.612519652078303}, {4.3801471647451065`, 
             5.600095960927426}, {4.516614467626819, 5.593206334264197}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.540196427011449, 5.592015786105652}, {
             4.57116987184214, 5.590452074748781}, {4.760268410140146, 
             5.582469885111131}, {4.908757742839626, 5.577385687899936}, {
             5.057247075539106, 5.572301490688741}, {5.066932427446832, 
             5.572089802818925}, {5.076614139150804, 5.5718819734624105`}, {
             5.269501308113155, 5.569240029157728}, {5.468192120388205, 
             5.567793514809024}, {5.4842660927623585`, 
             5.567698622186373}}]}, 
           {Arrowheads[{{0.0031547316178158853`, 1.}}], 
            ArrowBox[{{5.507877674317247, 5.567559231322276}, {
             5.643154861730728, 5.566760623062926}, {5.656854249492381, 
             5.5667170497940095`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.020132352498942}, \
{-5.44138552660875, -5.001667039645391}, {-5.314394709328764, \
-4.992386476962571}, {-5.184075748719708, -4.984253834063129}, \
{-5.051975267903099, -4.977859910661323}, {-4.918893189515676, \
-4.973448523653144}, {-4.784882735709409, -4.97091650711631}, \
{-4.714009256703322, -4.970519377828684}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690397634376475, -4.9703870735184426`}, \
{-4.649997128636268, -4.970160695128539}, {-4.51428959044822, \
-4.971077921767548}, {-4.3778133432972375`, -4.973565021111058}, \
{-4.240621609335286, -4.977518827236784}, {-4.102767610714333, \
-4.982836174222447}, {-3.938374706426226, -4.990872851304346}, \
{-3.773192649151648, -5.000667365177271}, {-3.746651912163765, \
-5.002477740177862}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            
            ArrowBox[{{-3.723094658750835, -5.0040846082418815`}, \
{-3.6073189860239983`, -5.011981803548742}, {-3.439810761420409, \
-5.0271159852460805`}, {-3.27204989306405, -5.042699486125797}, \
{-3.10379251312142, -5.059327086919096}, {-2.935038621592519, \
-5.076998787625977}, {-2.7829578346969237`, -5.093815962848916}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759490540088308, -5.096425886124508}, \
{-2.5963425401345104`, -5.114852807762838}, {-2.4270028229226264`, \
-5.133791765157523}, {-2.2577690668416914`, -5.152531460430495}, \
{-2.088641271891705, -5.171071893581756}, {-1.9273346683682362`, \
-5.188203997400401}, {-1.8205959647684515`, -5.198926542128293}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.797102216735941, -5.2012866304150025`}, \
{-1.7666119657959565`, -5.2043495594973574`}, {-1.6064731641748669`, \
-5.219508579872626}, {-1.4469182635049673`, -5.233681058526207}, \
{-1.2881550670864854`, -5.246584047963737}, {-1.1303913782196489`, \
-5.257934600690856}, {-0.9736271969044576, -5.267732716707563}, \
{-0.8555225665243231, -5.273984794814705}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8319435881227654, -5.2752329898615775`}, \
{-0.8178625231409129, -5.275978396013858}, {-0.663369870922822, \
-5.282552174401213}, {-0.510421754243993, -5.2873345876611}, \
{-0.3590181731044271, -5.290325635793516}, {-0.2091591275041242, \
-5.291525318798463}, {-0.023757146756116954`, -5.29071354118306}, {
             0.11224497978061548`, -5.288336672156443}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1358533676373618, -5.28792407532951}, {
             0.159145192114239, -5.287517010987339}, {
             0.3395478891069435, -5.281935728211301}, {
             0.5174509442219959, -5.273969692854946}, {
             0.6929644878684037, -5.264009558483915}, {
             0.8661986504551746, -5.252445978663849}, {
             1.037153431982308, -5.239278953394749}, {
             1.0787316351859833`, -5.235638057145323}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1022536164946408`, -5.233578297777987}, {
             1.2058288324498037`, -5.224508482676614}, {
             1.3724607775646909`, -5.2085394396420535`}, {
             1.5372851930339988`, -5.191776697423674}, {
             1.7003020788577279`, -5.174220256021476}, {
             1.8615114350358786`, -5.15587011543546}, {
             2.0211677038559066`, -5.137122057248579}, {
             2.041500629076461, -5.134714555243874}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0649488277434567`, -5.131938192045506}, {
             2.1795253276052686`, -5.118371863043787}, {
             2.3372336288192974`, -5.099620600830041}, {
             2.4925573387527633`, -5.0808214988073175`}, {
             2.7093057276483896`, -5.05458805976665}, {
             2.9238208410639523`, -5.030928805862279}, {
             3.0030210595355005`, -5.0221936727135486`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0264907381776176`, -5.01960516005723}, {
             3.058259399166768, -5.016101337857588}, {
             3.192697957269584, -5.001273869852896}, {
             3.3271365153723997`, -4.986446401848204}, {
             3.458924518709927, -4.97622432843145}, {
             3.6094177396067653`, -4.9623748897325255`}, {
             3.759811304952506, -4.949453722204059}, {
             3.9441052861323627`, -4.93520786592737}, {
             3.966958818555397, -4.933650317749945}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9905161641886457`, -4.93204480224027}, {
             4.128642045593864, -4.922631040251289}, {
             4.141070593609512, -4.921840715700628}, {
             4.153499796180301, -4.921057572901873}, {
             4.316514721978564, -4.912086628209393}, {
             4.479509574292469, -4.904264476582713}, {
             4.694449548418798, -4.894917059585266}, {
             4.909346573383058, -4.887506884045729}, {
             4.9338526457523, -4.886882645859064}}]}, 
           {Arrowheads[{{0.014812155866790912`, 1.}}], 
            ArrowBox[{{4.957456981997825, -4.886281377412887}, {
             5.124200649185247, -4.882033949964103}, {
             5.339011775825368, -4.878498257340388}, {
             5.547159320069292, -4.87667161001191}, {
             5.656854249492381, -4.876316535218367}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.5802837283692788`, -5.656854249492381}, {
             3.7088700390588323`, -5.647275024556992}, {
             3.8795952928270268`, -5.635243158579033}, {
             4.053149040693757, -5.623682365010634}, {
             4.2283889643508195`, -5.61301425698028}, {
             4.404172745490011, -5.603660447616459}, {
             4.5228812118652, -5.597796581141945}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.546464449854175, -5.596631635095325}, {
             4.59739268160668, -5.594115922780115}, {
             4.7875339875781995`, -5.58630363916632}, {
             4.934850341315623, -5.581433764916316}, {
             5.082166695053046, -5.576563890666311}, {
             5.091809649956719, -5.576363357399458}, {
             5.101450158859396, -5.5761665952420545`}, {
             5.295693535758392, -5.573701593602206}, {
             5.490536954438563, -5.5724496283991565`}}]}, 
           {Arrowheads[{{0.0030219315499723123`, 1.}}], 
            ArrowBox[{{5.514148576838177, -5.572317892355487}, {
             5.656854249492381, -5.571566045837729}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.506450527944735, 
             3.9830460943707084`}, {-5.303407870556768, 
             3.9765381429089897`}, {-5.095713234530945, 
             3.9731724596985107`}, {-4.883366619867265, 
             3.9729490447392717`}, {-4.667908198632229, 
             3.9761058189107272`}, {-4.562177091463598, 3.979406357184186}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.538576594535015, 
             3.980143078339117}, {-4.4508781428923365`, 
             3.982880703092332}, {-4.232276452647589, 
             3.993273697284086}, {-4.012103127897989, 
             4.007284801485989}, {-3.7906226602612954`, 
             4.024059295544729}, {-3.596150446402808, 4.040387289851976}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.5726212408483318`, 
             4.0423628149242985`}, {-3.5680995413552696`, 
             4.042742459306995}, {-3.3445337711799135`, 
             4.063334292772785}, {-3.119925349735226, 
             4.085834795942101}, {-2.894679032257753, 
             4.108870813235733}, {-2.6691995739840384`, 
             4.131069189074476}, {-2.6326561875024432`, 4.134527540869352}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.6091492256524504`, 
             4.1367521662129}, {-2.4434869749140824`, 
             4.152429923458328}, {-2.2175412350478862`, 
             4.17295301638729}, {-1.9920855012080767`, 
             4.191284818422898}, {-1.767842920217281, 
             4.206071680126687}, {-1.667698055644976, 4.211119537275891}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6441160013369136`, 
             4.21230820373363}, {-1.5448134920755001`, 
             4.217313601498658}, {-1.3229972167827344`, 
             4.225010582538811}, {-1.1032133627822194`, 
             4.228635078087112}, {-0.8862811985171929, 
             4.227659542983523}, {-0.6999911003941066, 
             4.222807756785078}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6763871113679012, 
             4.222193008554552}, {-0.6722007239876525, 
             4.222083977228048}, {-0.46097193919359974`, 
             4.211908380820684}, {-0.25942195231631604`, 
             4.19808596051789}, {-0.06118486518379135, 4.180785421081461}, {
             0.1337393222039735, 4.160006762511395}, {0.2644715704265278, 
             4.1434568863384005`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.2878966051659981, 4.140491425026771}, {
             0.32535060984697894`, 4.135749984807692}, {0.5138122452232956, 
             4.108898246018217}, {0.6992874758109942, 4.080334704190836}, {
             0.8817763016100749, 4.050059359325546}, {1.061278722620537, 
             4.018072211422351}, {1.2199668241974773`, 
             3.9886821882532444`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2431827366222519`, 3.984375513530592}, {
             1.413475599350448, 3.952592430284316}, {1.5867078673386072`, 
             3.920007277994997}, {1.7580293550755695`, 3.887525284558809}, {
             1.8830215332559435`, 3.8640923242197425`}, {2.0077749585505256`, 
             3.841425214672424}, {2.132289630959316, 3.8195239559168526`}, {
             2.171931042734645, 3.812782204068632}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.195208800924478, 3.808823392758173}, {
             2.256565550482314, 3.7983885479530293`}, {2.3806027171195208`, 
             3.7780189907809536`}, {2.5044011308709346`, 3.758415284400626}, {
             2.627960791736557, 3.7395774288120456`}, {2.751281699716387, 
             3.7215054240152132`}, {2.8773021106484, 3.7040234321333396`}, {
             3.003715345989688, 3.6876869741197806`}, {3.1297448227102755`, 
             3.6729747148099157`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.153197556017426, 3.6702369212165578`}, {
             3.2402420323958108`, 3.6600756403694636`}, {3.4780462098546465`, 
             3.636021714657368}, {3.494036377288991, 3.6345279210062555`}, {
             3.5100318572601217`, 3.6330488965613665`}, {3.6531010231856604`, 
             3.6211683681448408`}, {3.796843339946864, 3.6105383451591297`}, {
             3.9588157757581444`, 3.5992802919824456`}, {4.094210180282342, 
             3.591065456876615}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.117778831986299, 3.589635467298426}, {
             4.121511604646954, 3.5894089873932735`}, {4.28493082661329, 
             3.5809244313916135`}, {4.449073441657155, 3.5738266239774656`}, {
             4.613801226455856, 3.56797809555237}, {4.778975957686705, 
             3.5632413765178663`}, {4.944597635349701, 3.5596164668739547`}, {
             5.061653431358319, 3.5578450729565025`}}]}, 
           {Arrowheads[{{0.012104107103237808`, 1.}}], 
            ArrowBox[{{5.085262721191515, 3.557487795881536}, {
             5.1106662594448435`, 3.5571033666206353`}, {5.246351889537304, 
             3.555764769321031}, {5.380217567009644, 3.554964335438854}, {
             5.512263291861862, 3.5547020649741063`}, {5.642489064093959, 
             3.5549779579267864`}, {5.656854249492381, 3.555053559574878}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.485289843581057}, {-5.529340086435731, 
             4.476566101277092}, {-5.400194452843693, 
             4.469242590127686}, {-5.270235232317863, 
             4.463502218136437}, {-5.1394876413650765`, 
             4.45931376873694}, {-5.00797689649217, 
             4.456646025362789}, {-4.875728214205981, 
             4.455467771447581}, {-4.74276681101335, 
             4.45574779042491}, {-4.71310888020813, 4.456126606250206}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689498813067204, 
             4.456428173717201}, {-4.609117903421114, 
             4.457454865728372}, {-4.474806707936108, 
             4.460557780791561}, {-4.3397602822353445`, 
             4.465343465715056}, {-4.203941378115769, 
             4.471983160902351}, {-4.0674287532641245`, 
             4.480272115241414}, {-3.9303011653671565`, 
             4.490005577620212}, {-3.79263737211161, 
             4.500978796926715}, {-3.746515510384028, 4.504988619709654}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.72299225053018, 
             4.507033725864478}, {-3.6545161311842285`, 
             4.512987022048888}, {-3.5160162002717583`, 
             4.5258255018747}, {-3.3772163370609425`, 
             4.539289485292119}, {-3.167110128884654, 
             4.560193391632365}, {-2.9567844962175633`, 
             4.581107091754446}, {-2.782904213088699, 4.597947248058744}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.759402184484225, 
             4.600223399374153}, {-2.746502715926638, 
             4.601472701841593}, {-2.5337197782978658`, 
             4.626683098789236}, {-2.32216543894661, 
             4.648834928526487}, {-2.111181505705453, 
             4.669322900595267}, {-1.9007679785743945`, 
             4.688147014995577}, {-1.8197309550899379`, 
             4.6947739471580965`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7961975198637614`, 
             4.69669843145045}, {-1.6909248575534366`, 
             4.705307271727415}, {-1.4822501616492216`, 
             4.720045749523244}, {-1.2753419098683936`, 
             4.731604527115525}, {-1.0702001022109529`, 
             4.739983604504259}, {-0.8668247386768971, 
             4.745182981689443}, {-0.8531496585772269, 
             4.745299616695502}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8295385243495875, 
             4.745500996487329}, {-0.6442589044406722, 
             4.747081249724101}, {-0.4249228644925469, 
             4.744783779010765}, {-0.20881661883252, 4.73829056954944}, {
             0.004059832539408226, 4.7276016213401215`}, {0.1143029295671478, 
             4.720117004541595}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13786069241679577`, 4.718517622518466}, {
             0.21358110114222612`, 4.713376817711476}, {0.4196217984949222, 
             4.6962760419921645`}, {0.622181924597496, 4.676299294182189}, {
             0.8212614794499471, 4.653446574281549}, {1.0172604147732769`, 
             4.628605342713179}, {1.077063610643925, 4.620580072052787}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1004658278080104`, 4.617439619037513}, {
             1.2105786822884872`, 4.602663059900013}, {1.4012162819955774`, 
             4.575619725842052}, {1.5891732138945471`, 4.547475340539295}, {
             1.7506291584094966`, 4.522902800968247}, {1.9112702291765065`, 
             4.498962697877007}, {2.0350122991676947`, 
             4.480917227441278}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0583771516773415`, 4.477509899963824}, {
             2.071096426195577, 4.475655031265578}, {2.230107749466708, 
             4.452979801133957}, {2.3883041989899, 4.430937007482147}, {
             2.5456857747651522`, 4.409526650310144}, {2.702252476792465, 
             4.3887487296179515`}, {2.8580043050718382`, 4.368603245405567}, {
             2.988554217722021, 4.352269931283735}, {2.9944057388847565`, 
             4.351566973101811}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.017849172033942, 4.348750653603632}, {
             3.1189047216292733`, 4.3366105923372915`}, {3.3301122267753436`, 
             4.313071518132139}, {3.5419463465104064`, 4.292094284071058}, {
             3.5561950885649085`, 4.290771394128983}, {3.570446685043244, 
             4.289459717306474}, {3.7152309226493347`, 4.277397978607689}, {
             3.8602339260737066`, 4.2664133419389385`}, {3.957964964009647, 
             4.259348693197092}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9815155071573667`, 4.257646303469814}, {
             4.002920565970053, 4.256099003604757}, {4.145890984104115, 
             4.246752814314103}, {4.2891451804758916`, 4.238374774066975}, {
             4.4326831550853845`, 4.230964882863375}, {4.576504907932592, 
             4.2245231407033}, {4.7206104390175145`, 4.219049547586753}, {
             4.864999748340153, 4.214544103513733}, {4.924862028676407, 
             4.213080455020026}}]}, 
           {Arrowheads[{{0.015001796276272928`, 1.}}], 
            ArrowBox[{{4.9484669670312345`, 4.212503308070845}, {
             5.009672835900506, 4.211006808484239}, {5.154569712900321, 
             4.208371617090513}, {5.2996303905413455`, 4.2065724839247975`}, {
             5.444804597613484, 4.205576591505791}, {5.5900420629066385`, 
             4.20535112235219}, {5.656854249492381, 4.205562542565238}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.237152652341791, -3.0726360102322543`}, \
{-4.05042496444341, -3.0856130095185814`}, {-3.8629828477076393`, \
-3.1001828168924908`}, {-3.6748429117528194`, -3.1160105900063724`}, \
{-3.48595257798853, -3.132912389482576}, {-3.296314618391361, \
-3.150583553567484}, {-3.2959312468792286`, -3.1506196664916084`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.272423320094455, -3.1528340719689045`}, \
{-3.106028668430171, -3.168508156349533}, {-2.915194363573824, \
-3.1861702719171605`}, {-2.7236693057953487`, -3.203133493337024}, \
{-2.5315047238644386`, -3.2188977984932046`}, {-2.339090693444953, \
-3.2328518387002747`}, {-2.3314101883459157`, -3.233312510117122}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.307840553378628, -3.2347262006224926`}, \
{-2.1468172902007483`, -3.2443842652728074`}, {-1.9766813304245645`, \
-3.251868949818214}, {-1.8072668353037318`, -3.2562423092239805`}, \
{-1.6388213144073491`, -3.2573140375989715`}, {-1.468952175234141, \
-3.2569237585574973`}, {-1.3639136521160702`, -3.254076415832617}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3403103296483925`, -3.2534365863061128`}, \
{-1.3011658033463203`, -3.2523754719751374`}, {-1.1348434248211436`, \
-3.2441449425797315`}, {-0.9699850396586115, -3.232232170371279}, \
{-0.806590647858723, -3.21663715534978}, {-0.6451486153012904, \
-3.197494276446149}, {-0.4861473078661246, -3.1749379125913}, \
{-0.4011058802056723, -3.1608314690282575`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3778121789853383, -3.1569675724465704`}, \
{-0.3295867255532248, -3.1489680637852335`}, {-0.17546686836259257`, \
-3.1195847300279493`}, {-0.038115678585739554`, -3.09048932084409}, {
             0.09680630357925651, -3.0595541112759124`}, {
             0.22929907813239492`, -3.0267791013234184`}, {
             0.3593626450736757, -2.9921642909866075`}, {
             0.4870782078546517, -2.956354508670719}, {
             0.5410174450986317, -2.940720821766656}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.563696068534257, -2.9341476754575226`}, {
             0.6125269699268752, -2.9199945827809928`}, {
             0.7357089312903466, -2.8830845133174288`}, {
             0.8566240919450661, -2.8456243002800266`}, {
             0.975637076251338, -2.808217604570163}, {
             1.0931125085694666`, -2.771468087089212}, {
             1.3234507172412955`, -2.6999405868140514`}, {
             1.4665604308673086`, -2.6569406716873654`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.489217654567485, -2.6502966678446467`}, {
             1.6351730949416166`, -2.6089327050732956`}, {
             1.7901045497736394`, -2.5676902801005976`}, {
             1.9444161819269037`, -2.529288865726353}, {
             2.0431307707329647`, -2.5063143463771445`}, {
             2.1422714605220334`, -2.484682060511787}, {
             2.2733119079863866`, -2.4582007746662162`}, {
             2.405535527837388, -2.433823209277078}, {
             2.4079655519003627`, -2.433417487962192}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.4312551625428345`, -2.429529011466412}, {
             2.538942320075038, -2.411549364344373}, {
             2.673532284699336, -2.3913792398680997`}, {
             2.6915535084390934`, -2.388830559848924}, {
             2.7096014875763084`, -2.386316485977987}, {
             2.828035926865719, -2.371628020749403}, {
             2.9475906167388266`, -2.358266686574945}, {
             3.1198912989503507`, -2.340233130619938}, {
             3.2943664996275928`, -2.3244018064669687`}, {
             3.3688566740434145`, -2.3186546506193633`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.392398702660657, -2.3168383076118038`}, {
             3.4710162187705516`, -2.310772714116036}, {
             3.6498404563792275`, -2.299345853567141}, {
             3.8305794906179376`, -2.2897848653074937`}, {
             4.012973599650998, -2.2817533898243028`}, {
             4.19702278347841, -2.2752514271175697`}, {
             4.3356861012245025`, -2.2715385537038113`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.359289634301467, -2.2709065413457004`}, {
             4.382727042100171, -2.2702789771872935`}, {
             4.5706643801889175`, -2.2671814949351803`}, {
             4.7575594379330575`, -2.2640014025848982`}, {
             4.945647166733442, -2.262074459089709}, {
             5.134696364721017, -2.2612624824889305`}, {
             5.27778541146537, -2.2612833806301462`}, {
             5.303696629727354, -2.261365881107789}}]}, 
           {Arrowheads[{{0.006978488219011329, 1.}}], 
            ArrowBox[{{5.327308503041182, -2.2614410605457738`}, {
             5.421063488494483, -2.261739573375355}, {
             5.564119653399006, -2.262578820536505}, {
             5.656854249492381, -2.263366658430996}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.989413992247587}, \
{-5.583992400489839, -3.985489341707304}, {-5.448173814152473, \
-3.979463305590535}, {-5.310073669995017, -3.9749739504655794`}, \
{-5.171225877122529, -3.972253829972694}, {-5.031653450625306, \
-3.971234203162651}, {-4.891379405593647, -3.971846329086225}, \
{-4.750426757117844, -3.9740214667941895`}, {-4.712747851095385, \
-3.974997817483598}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            
            ArrowBox[{{-4.689143781270002, -3.975609455460378}, \
{-4.608818520288195, -3.9776908753373172`}, {-4.466577710194997, \
-3.982785813766382}, {-4.323727341928543, -3.989237541132157}, \
{-4.180217655289603, -3.9971972495825567`}, {-4.03602535382059, \
-4.006736155593807}, {-3.891213148224269, -4.0176655547091515`}, \
{-3.7463788993608214`, -4.029752083781044}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.722861888839799, -4.031867713153552}, \
{-3.599979867460773, -4.042941014425089}, {-3.4536842136991313`, \
-4.056909666112165}, {-3.307019498621251, -4.071513993076303}, \
{-3.1600484329298957`, -4.0865652908607455`}, {-2.9625609151052266`, \
-4.107131296307899}, {-2.7830772016507104`, -4.125814277163215}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759590921768347, -4.1282474618060405`}, \
{-2.56652320828703, -4.147902448049961}, {-2.3684179311130635`, \
-4.167172068753454}, {-2.170519597834034, -4.184916860003444}, \
{-1.9730442547314158`, -4.2006376238813825`}, {-1.8188208504439212`, \
-4.21115284526849}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.795263549966973, -4.212759023208487}, \
{-1.7762528154848203`, -4.214055208328604}, {-1.5804061937738572`, \
-4.224890461286445}, {-1.3858182400850425`, -4.232623620617562}, \
{-1.1927604554593672`, -4.236927412247556}, {-1.0014302294081556`, \
-4.237811416212172}, {-0.8513444277815859, -4.235809638298652}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8277345346771694, -4.235494740006843}, \
{-0.812024951442732, -4.23528521254716}, {-0.6248506585330269, \
-4.2291405895777645`}, {-0.4401264696820857, -4.219343568997635}, \
{-0.2579193974509054, -4.2061650808951185`}, {-0.07829645440048323, \
-4.18987605535856}, {0.04537931894144592, -4.1767485976776815`}, {
             0.11399359154353317`, -4.1686016552101615`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.13744088196722062`, -4.16581763201999}, {
             0.16755413047396372`, -4.162242123692192}, {
             0.40771001341191043`, -4.129648925555158}, {
             0.6427894850156529, -4.093210058443018}, {
             0.8734108358874864, -4.05403911985133}, {
             1.0166642333922897`, -4.028596408514742}, {
             1.070289075981728, -4.018919027657062}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.0935257215059742`, -4.014725637844905}, {
             1.1585605282852431`, -4.002989163408473}, {
             1.2992488345953908`, -3.977404026042189}, {
             1.4372877167086358`, -3.9500367951557585`}, {
             1.5747896233697758`, -3.923531558802824}, {
             1.7113817695061995`, -3.897421713209214}, {
             1.8470641551179066`, -3.871707258374928}, {
             1.9818367802048977`, -3.8463881942999656`}, {
             2.0215224397770726`, -3.8391148787209506`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0447475988346486`, -3.834858330813731}, {
             2.116072756653142, -3.821786344934462}, {
             2.250145196348608, -3.7982235342285504`}, {
             2.384054099291297, -3.775699762182232}, {
             2.5177994654812075`, -3.754215028795506}, {
             2.6364960123237746`, -3.7359665609739414`}, {
             2.7551990441878225`, -3.718523659873082}, {
             2.977710640861565, -3.6885564606985826`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.001134012471669, -3.685584427489348}, {
             3.2269826467013822`, -3.6590149823073137`}, {
             3.242880346368991, -3.657278983284603}, {
             3.258783833479877, -3.6555589942145676`}, {
             3.3938489486505183`, -3.6422508898482846`}, {
             3.529285704287908, -3.6300111949035463`}, {
             3.6560215335487616`, -3.6190161580424247`}, {
             3.783203921336857, -3.6088974401359915`}, {
             3.9108328676521946`, -3.5996550411842465`}, {
             3.9413857611910155`, -3.597659281325236}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9649475398884566`, -3.596120191350943}, {
             4.038908372494775, -3.59128896118719}, {
             4.167430435864596, -3.583799200144822}, {
             4.29639905776166, -3.577185758057142}, {
             4.425814238185967, -3.5714486349241503`}, {
             4.555675977137516, -3.566587830745847}, {
             4.685613486337541, -3.5624648057914516`}, {
             4.815255977507276, -3.558941020330184}, {
             4.908526969517465, -3.55683216348894}}]}, 
           {Arrowheads[{{0.015347369705968696`, 1.}}], 
            ArrowBox[{{4.932132929461849, -3.5562984328075142`}, {
             4.944603450646721, -3.556016474362045}, {
             5.073655905755875, -3.5536911678870333`}, {
             5.20241334283474, -3.55196510090515}, {
             5.330875761883315, -3.550838273416394}, {
             5.459043162901601, -3.5503106854207664`}, {
             5.586915545889596, -3.5503823369182665`}, {
             5.656854249492381, -3.550737286170845}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.4802803257774615`}, \
{-5.527833293816935, -4.472173619604724}, {-5.394851016392371, \
-4.4652854627001055`}, {-5.259811085019061, -4.459752004798471}, \
{-5.12288325038471, -4.455600449328352}, {-4.9842372631770235`, \
-4.45285799971828}, {-4.844042874083706, -4.451551859396786}, \
{-4.7130173473639285`, -4.451968197891837}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689407325974398, -4.452226846252762}, \
{-4.560496139116526, -4.454418320163144}, {-4.417503500771212, \
-4.458671853103796}, {-4.273762700209917, -4.464629659021576}, \
{-4.1293222512015175`, -4.472159791370592}, {-3.9842306675148897`, \
-4.481130303604952}, {-3.8385364629189094`, -4.4914092491787665`}, \
{-3.746250912136081, -4.498637851498525}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7227110217631103`, -4.500481699259236}, \
{-3.6922881511824537`, -4.502864681546144}, {-3.545414525767404, \
-4.5155386919213605`}, {-3.3978879147927286`, -4.52941008506045}, \
{-3.2498221340129394`, -4.544251984730158}, {-3.101330999182545, \
-4.559837514697228}, {-2.9525283260560555`, -4.575939798728404}, \
{-2.8035279303879808`, -4.592331960590433}, {-2.7829712067512533`, \
-4.594600906697206}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759501740729235, -4.597191346423874}, \
{-2.65444362793283, -4.608787124050057}, {-2.5053892344451127`, \
-4.625078412874021}, {-2.361303759269003, -4.64032270507951}, \
{-2.2175413544088265`, -4.654740320332635}, {-2.074178029017539, \
-4.668206881091852}, {-1.9304790279499027`, -4.681924703592107}, \
{-1.819760290223722, -4.69137889579766}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7962339107185938`, -4.693387796172702}, \
{-1.7875211475394566`, -4.694131772661494}, {-1.6451143649038102`, \
-4.70513903215388}, {-1.5032586800429646`, -4.714946482069265}, \
{-1.3619540929569212`, -4.723554122407647}, {-1.2213804743361734`, \
-4.730774050687256}, {-1.081717694871216, -4.736418364426323}, \
{-0.9429657545620498, -4.740487063624847}, {-0.8531848343900575, \
-4.742110900294659}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8295767025067469, -4.742537892468324}, \
{-0.8051246534086761, -4.742980148282827}, {-0.5850857903491926, \
-4.743701752476027}, {-0.36833202640062707`, -4.7403633962264955`}, \
{-0.1548633615629792, -4.732965079534232}, {
             0.055320204163750664`, -4.721506802399237}, {
             0.1142800556674945, -4.717273051668232}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13783140786847908`, -4.7155818914625325`}, {
             0.2621704778517433, -4.706653432265165}, {
             0.46563926657317894`, -4.6890698365756736`}, {
             0.6657265703280577, -4.668756015330761}, {
             0.8624323891163795, -4.645711968530428}, {
             1.056158297048766, -4.62080189329108}, {
             1.0770726266207404`, -4.617966753140936}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1004706125763493`, -4.6147949292874895`}, {
             1.2473058682358382`, -4.594889986729126}, {
             1.4358751026775967`, -4.567976248844564}, {
             1.621866000374041, -4.540060679637395}, {
             1.750037483322793, -4.5204717834898185`}, {
             1.8776388019950017`, -4.501231352342193}, {
             2.0046699563906674`, -4.48233938619452}, {
             2.034961331082706, -4.477897635890029}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.058323498133674, -4.474471944132319}, {
             2.13113094650979, -4.4637958850468}, {
             2.2570217723523696`, -4.44560084889903}, {
             2.382342433918406, -4.427754277751212}, {
             2.5070929312078993`, -4.410256171603347}, {
             2.63127326422085, -4.393106530455433}, {
             2.7541375886616866`, -4.376584350128505}, {
             2.8768223462690057`, -4.360699741862915}, {
             2.9940526406050036`, -4.346393060687658}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0174907404815126`, -4.343532695760774}, {
             3.088491329566814, -4.334867846823455}, {
             3.3000981982582034`, -4.311149348015173}, {
             3.3143005156661927`, -4.309628143467439}, {
             3.328506201626362, -4.308118954502991}, {
             3.4656654649996983`, -4.294786130682873}, {
             3.6030777019241844`, -4.282501324917976}, {
             3.743739783730665, -4.270429302444476}, {
             3.8846759308298817`, -4.259339424258248}, {
             3.9576234859294757`, -4.254117886360695}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.981175221154067, -4.2524320686816734`}, {
             4.025886143221834, -4.249231690359293}, {
             4.167370420906524, -4.24010610074761}, {
             4.309128763883948, -4.2319626554231995`}, {
             4.451161172154109, -4.224801354386061}, {
             4.593467645717006, -4.218622197636194}, {
             4.736048184572638, -4.213425185173601}, {
             4.878404880728604, -4.209092943318696}, {
             4.924522974342611, -4.207925673381292}}]}, 
           {Arrowheads[{{0.015009359915758804`, 1.}}], 
            ArrowBox[{{4.948127407825175, -4.207328234427631}, {
             5.0200398261924954`, -4.205508098391897}, {
             5.160953020964316, -4.2026706503932045`}, {
             5.301144465044064, -4.200580599322619}, {
             5.440614158431739, -4.199237945180138}, {
             5.579362101127343, -4.198642687965763}, {
             5.656854249492381, -4.198728103879203}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.019912691241266}, {-5.545222233625177, 
             5.0099495235607225`}, {-5.416244752895082, 
             4.999529596900805}, {-5.282898307508737, 
             4.990519411459526}, {-5.147846014685797, 
             4.983464443628085}, {-5.011198454642257, 
             4.978281802208475}, {-4.873066207594109, 
             4.974888596002691}, {-4.733559853757344, 
             4.973201933812726}, {-4.71387679765371, 
             4.9731931235686355`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690264807021079, 
             4.9731825547118556`}, {-4.592789973347955, 
             4.973138924440577}, {-4.450867146581933, 
             4.9746166766882345`}, {-4.307901953675273, 
             4.977552299357696}, {-4.137829789330436, 
             4.983031665902704}, {-3.9668042768196567`, 
             4.990674667077467}, {-3.7949384577835845`, 
             5.00018523669383}, {-3.746507102349032, 5.004153432352917}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.722973969140217, 
             5.006081606284991}, {-3.621139596362616, 
             5.01442534790395}, {-3.4470091157992733`, 
             5.029200729708977}, {-3.272264411991934, 
             5.045251547579295}, {-3.0969054849405975`, 
             5.062577801514905}, {-2.9209323346452667`, 
             5.081179491515807}, {-2.782855688788151, 5.09629160595663}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759383858409337, 
             5.098860534138643}, {-2.7446247660295917`, 
             5.100475876774618}, {-2.568262584017226, 
             5.119886216483954}, {-2.391845788608169, 
             5.139410510643815}, {-2.2153743798024204`, 
             5.159048759254202}, {-1.9796064026697175`, 
             5.184733609280327}, {-1.8204707201623325`, 5.201224077188202}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7969844901712713`, 
             5.203657842613041}, {-1.7444735768017572`, 
             5.209099296836817}, {-1.5106885875569351`, 
             5.231287458377546}, {-1.2789641202936446`, 
             5.2504397303563906`}, {-1.0493148394914236`, 
             5.26641840943773}, {-0.8554819469942472, 5.277208362019925}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8319064528208033, 
             5.2785207216558785`}, {-0.8217554096298121, 
             5.279085792285943}, {-0.69809945645332, 
             5.284566897576401}, {-0.5754304816688838, 
             5.288939456829675}, {-0.33305346727617446`, 
             5.29435893722467}, {-0.09462436645168515, 5.2953442334709315`}, {
             0.1122732328949552, 5.292301061283911}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1358826721666856, 5.291953799695716}, {
             0.1398568208045856, 5.291895345568457}, {0.3703834459171284, 
             5.284640653857309}, {0.5969488603104329, 5.2742085386775495`}, {
             0.819553063984501, 5.260599000029178}, {1.0381960569393316`, 
             5.243812037912194}, {1.078789618605996, 5.24021511783405}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1023094602539463`, 5.238131068364507}, {
             1.253330986896527, 5.224749331480386}, {1.4654110015776918`, 
             5.204312559887541}, {1.6744361009828248`, 5.182501723133657}, {
             1.8804062851119265`, 5.159316821218736}, {2.0416928199318702`, 
             5.140563375814689}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0651468002341247`, 5.137836285548927}, {
             2.1246596620991194`, 5.130916481567338}, {2.3664951121531983`, 
             5.103038714097611}, {2.605912635274164, 5.075683518809554}, {
             2.8429122314620154`, 5.0488508957031675`}, {2.9857919005940543`, 
             5.033120552008866}, {3.0035912723958442`, 
             5.0312535231002755`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.027074431664894, 5.0287903048637785`}, {
             3.128462641418625, 5.018155394783332}, {3.2709244539357294`, 
             5.0039554240265645`}, {3.413177338145366, 4.990520639738563}, {
             3.5552212940475356`, 4.977851041919327}, {3.697056321642238, 
             4.965946630568858}, {3.838682420929473, 4.954807405687156}, {
             3.9678119853361284`, 4.94533475783174}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9913659356957867`, 4.9436820301842275`}, {
             4.1480611970567365`, 4.933232237073258}, {4.316134646658145, 
             4.923339749760485}, {4.500353654292359, 4.913911254931016}, {
             4.684519799724959, 4.9059082196011605`}, {4.6969207743655135`, 
             4.905417250583705}, {4.709321045585948, 4.90493240488961}, {
             4.889631911824277, 4.899220382514689}, {4.934669745188876, 
             4.898162995894531}}]}, 
           {Arrowheads[{{0.01479480748711923, 1.}}], 
            ArrowBox[{{4.958275233359129, 4.897608792339679}, {
             5.070288387696558, 4.894978976430926}, {5.196364779241567, 
             4.892289356873068}, {5.320212141451835, 4.890192808694356}, {
             5.441830474327362, 4.888689331894791}, {5.561219777868147, 
             4.887778926474372}, {5.656854249492381, 4.887411876136126}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6997677410145676, 2.3247664125311}, {
             0.8898280761374607, 2.2432257385697}, {1.0718452394023628`, 
             2.16406008286653}, {1.2477824419645236`, 2.088866814600569}, {
             1.419602894979194, 2.019243302950795}, {1.5721383003290843`, 
             1.9633433858505034`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5943084376985561`, 1.955218656787026}, {
             1.6427306109116457`, 1.9374732981785199`}, {1.8669071401562898`, 
             1.867449792174246}, {1.9617414958828336`, 1.8415806262255494`}, {
             2.0577970551983578`, 1.8177407760532291`}, {2.185903922407446, 
             1.789303502326579}, {2.3164710533759028`, 1.7639559410750034`}, {
             2.449685602073998, 1.7414710248672989`}, {2.510494011391703, 
             1.7325991798862967`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.5338586403318883`, 1.7291903196920932`}, {
             2.5857347224720004`, 1.721621686272261}, {2.604039672944951, 
             1.7191540353724668`}, {2.6223962769413376`, 1.71672860316951}, {
             2.7389340075278197`, 1.703446053682434}, {2.8574060699870616`, 
             1.6915927478751958`}, {2.994625667036998, 1.678713824903106}, {
             3.1340820508190523`, 1.6673113111270013`}, {3.2757752213332245`, 
             1.6573852065468817`}, {3.4197051785795147`, 1.648935511162747}, {
             3.474387213816442, 1.6462217414799842`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.497970182768651, 1.6450513617401894`}, {
             3.5655403049984526`, 1.6416979798045443`}, {3.7129489830305675`, 
             1.6354083673022208`}, {3.8619312126758603`, 
             1.6300666736557765`}, {4.01248699393433, 1.6256728988652114`}, {
             4.164348964915431, 1.6220827809190823`}, {4.317249763728615, 
             1.6191520578059466`}, {4.441988698372314, 
             1.6173115760790164`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.465598121621279, 1.6169632268471008`}, {
             4.471189390373882, 1.616880729525804}, {4.626167844851233, 
             1.615268796078655}, {4.749164557590961, 1.6143811227145946`}, {
             4.872354435315169, 1.613744972531351}, {4.995737478023858, 
             1.6133603455289243`}, {5.119313685717028, 1.613227241707314}, {
             5.243083058394678, 1.6133456610665204`}, {5.367045596056809, 
             1.6137156036065434`}, {5.41006218590013, 1.6139309246545919`}}]}, 
           {Arrowheads[{{0.004726114393402492, 1.}}], 
            ArrowBox[{{5.4336738830999165`, 1.6140491138324364`}, {
             5.491201298703421, 1.6143370693273833`}, {5.615550166334514, 
             1.6152100582290396`}, {5.656854249492381, 
             1.6155965805437384`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4085747246375184, -2.4370396531611846`}, {
             0.6239534996727117, -2.351205272187235}, {
             0.8279742172621072, -2.2641696345362647`}, {
             1.0231229690471102`, -2.1794649176721688`}, {
             1.2107809170507235`, -2.0990534424082226`}, {
             1.279190599207547, -2.0710544387718093`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3010431267455502`, -2.0621105440085103`}, {
             1.39340314256585, -2.024309046657834}, {
             1.5734447268853924`, -1.9566055683344115`}, {
             1.803812353528792, -1.8808729882940225`}, {
             2.0384053707391985`, -1.8175911884634068`}, {
             2.138610905926855, -1.794623551287474}, {
             2.201340962277095, -1.7816692165509715`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2244650279090523`, -1.776893883893964}, {
             2.240310631248753, -1.773621620776293}, {
             2.371952332043609, -1.749520711501673}, {
             2.506337917194322, -1.7281915696462677`}, {
             2.643545515421584, -1.7094021008839564`}, {
             2.7836532554460853`, -1.692920210888618}, {
             2.80251542540438, -1.690877785698562}, {
             2.82142754045443, -1.688872191561973}, {
             2.9442651484149684`, -1.6777383847290839`}, {
             3.06901937208217, -1.6679065300744942`}, {
             3.1611371968143156`, -1.6611187370747575`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.1846853475415964`, -1.6593835683044555`}, {
             3.216058975085826, -1.6570717715372143`}, {
             3.365246112191001, -1.6475745708193341`}, {
             3.516580783397694, -1.639414927920854}, {
             3.6700629887059053`, -1.632592842841774}, {
             3.8253400990405386`, -1.626875263070475}, {
             3.9820594853265, -1.6220291360953383`}, {
             4.128180391212783, -1.6183570515748604`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.151786396843644, -1.6178295957302902`}, {
             4.299825085752404, -1.6149512405335513`}, {
             4.460596269233149, -1.6125897222683723`}, {
             4.622259667346829, -1.6108401574422981`}, {
             4.784815280093441, -1.6097025460553285`}, {
             4.948263107472987, -1.6091768881074635`}, {
             5.08036692942009, -1.6091356186186532`}, {
             5.096206471062373, -1.6091631773718449`}}]}, 
           {Arrowheads[{{0.011372269728398717`, 1.}}], 
            ArrowBox[{{5.119818428321904, -1.609204259122642}, {
             5.212629293656913, -1.609365738020772}, {
             5.344995795253345, -1.6098495142119147`}, {
             5.477412029279277, -1.6105692150901751`}, {
             5.60954029993175, -1.6115073186454147`}, {
             5.656854249492381, -1.6119171191917987`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.525933528422966, 
             3.661689160834921}, {-2.315548838796018, 
             3.6792955103184983`}, {-2.1288615971782, 
             3.692562323274018}, {-1.942995959766199, 
             3.702916977152399}, {-1.758212959280716, 
             3.710111234982784}, {-1.583192650836716, 3.7161576769599307`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5595881930820619`, 
             3.7166900573193993`}, {-1.3880228837322448`, 
             3.7187007442339506`}, {-1.2056611904107644`, 
             3.717199897661396}, {-1.024904199457203, 
             3.71204218109913}, {-0.8457519108715611, 
             3.7032275945471533`}, {-0.6686528582207686, 
             3.6908369147147573`}, {-0.6160668610389618, 
             3.6860522986712594`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5925520018210864, 
             3.6839127638387175`}, {-0.49405557507175285`, 
             3.674950918311233}, {-0.3219600614245145, 
             3.6555696053365816`}, {-0.1523663172790538, 3.632692975790802}, {
             0.014560893734196306`, 3.60690736955475}, {0.17865680798480132`, 
             3.5787991265092813`}, {0.33992142547276194`, 
             3.548368246654396}, {0.34164468039379886`, 
             3.5480119916790245`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3647677171031338, 3.54323167927554}, {
             0.49835474619807874`, 3.5156147299900935`}, {0.6541765586490089, 
             3.4813681762019173`}, {0.80760665131381, 3.4464581849754103`}, {
             0.9586450241924824, 3.410884756310572}, {1.1072916772850272`, 
             3.374647890207403}, {1.2540808683535187`, 3.3384927484191453`}, {
             1.2850102445986267`, 3.3309811579969537`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3079552572483857`, 3.325408671313384}, {
             1.3995468551600332`, 3.3031644926990427`}, {1.5436896377045706`, 
             3.268663123047095}, {1.686509215987131, 3.2349886394633014`}, {
             1.8956158837742214`, 3.187933942383603}, {2.1048834311833344`, 
             3.1445825807975196`}, {2.2298922532959504`, 
             3.1209164858400626`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2530921600736824`, 3.1165243862463927`}, {
             2.3143118582144706`, 3.1049345547050513`}, {2.5239011648676297`, 
             3.068989864106199}, {2.6420566997576245`, 3.050442334655671}, {
             2.7607225121415344`, 3.033118310620794}, {2.8892793409185864`, 
             3.015749933256647}, {3.0185953557786545`, 2.9996968324448874`}, {
             3.148670556721738, 2.984959008185514}, {3.187523017352494, 
             2.98097306062078}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.2110117234486952`, 2.978563309749331}, {
             3.2795049437478383`, 2.9715364604785273`}, {3.2970651567065805`, 
             2.969828147630397}, {3.314640884046597, 2.9681421389271407`}, {
             3.4519840063632254`, 2.956533925371036}, {3.590196011707919, 
             2.9461539866644224`}, {3.8092523951979107`, 2.931008005496859}, {
             4.030102415092214, 2.918338314076202}, {4.15307452012122, 
             2.9127082230057155`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.176661805085889, 2.9116283149857196`}, {
             4.25274607139083, 2.9081449124024514`}, {4.477183364093758, 
             2.900427800475607}, {4.703016675633653, 2.894815333606321}, {
             4.929848388443172, 2.8909358671052447`}, {5.1208178129849315`, 
             2.889136678249773}}]}, 
           {Arrowheads[{{0.010851089183495023`, 1.}}], 
            ArrowBox[{{5.144428758131821, 2.8889142313869973`}, {
             5.157678502522313, 2.8887894009723776`}, {5.386507017871079, 
             2.88837593520772}, {5.61609347185051, 2.889543678590844}, {
             5.656854249492381, 2.889973009515789}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.344506098731797, 
             3.2289950581545908`}, {-2.152355082533753, 
             3.240580158787659}, {-1.9823125739016287`, 
             3.2481205076899236`}, {-1.812981969934258, 
             3.2525560872731325`}, {-1.644610594787654, 
             3.253694753522748}, {-1.4748076482870216`, 
             3.2533938985793065`}, {-1.4006308546750026`, 
             3.2514204517406786`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.377027213608614, 
             3.250792485383893}, {-1.307076889309216, 
             3.248931482236849}, {-1.1408000074642035`, 
             3.2407878645317214`}, {-0.9759770027519844, 
             3.2289630454639235`}, {-0.8126078751725585, 
             3.2134570250334553`}, {-0.6511827211620348, 
             3.194400157243251}, {-0.49219163715652164`, 
             3.1719227960962453`}, {-0.4373763044902619, 
             3.1628551761046935`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.41408089038601864`, 
             3.159001619948623}, {-0.3356346231560191, 
             3.146024941592438}, {-0.1815116791605268, 
             3.116706593731829}, {-0.04410088709304166, 
             3.0876494509834282`}, {0.09087844872901563, 
             3.0567398914346535`}, {0.22342632830564374`, 
             3.0239779150855046`}, {0.3535427516368438, 
             2.9893635219359815`}, {0.48130549345946394`, 
             2.9535418543715712`}, {0.5055949904626543, 
             2.9464993292266817`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5282729934261725, 2.939924042546785}, {
             0.6067923285103518, 2.917158054777762}, {0.7300032567895081, 
             2.880212123154553}, {0.850938278296933, 2.8427040595019437`}, {
             0.9699598978446182, 2.80523974838241}, {1.0874306202445547`, 
             2.7684250743584276`}, {1.3177193736011839`, 
             2.6967446375971127`}, {1.4311044579665504`, 
             2.6626238401488003`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.4537148595321627`, 2.6558197271002157`}, {
             1.479305637015297, 2.648118734152738}, {1.6402605842512163`, 
             2.6025535197906633`}, {1.8005842153089422`, 
             2.5600489945108884`}, {1.9602765301884744`, 
             2.5206051583134137`}, {2.120439298196667, 2.484345541770044}, {
             2.282174288640374, 2.451393675452585}, {2.3715612231889236`, 
             2.4351678357109896`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.3947935561127514`, 2.4309506185891667`}, {
             2.4454815015195956`, 2.4217495593610363`}, {2.6103609368343315`, 
             2.395413193495398}, {2.730371142409866, 2.3783949445829493`}, {
             2.851572433127371, 2.3628802964225653`}, {2.9894908962487667`, 
             2.3470109441717333`}, {3.1288810895915735`, 
             2.3327077944415264`}, {3.269743013155792, 2.3199708472319447`}, {
             3.3317579362351397`, 2.3151037419887386`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.3552975438206234`, 2.313256287508214}, {
             3.412076666941422, 2.3088001025429876`}, {3.4312032894066933`, 
             2.307411403288973}, {3.4503548417389704`, 2.306046430670204}, {
             3.592376157676645, 2.2974198896336286`}, {3.735613021969051, 
             2.289926087500085}, {3.9342177717232207`, 2.2804370408006833`}, {
             4.134635639263209, 2.2726560715676767`}, {4.298594637116033, 
             2.2677324677662205`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.322195991017884, 2.267023731330206}, {
             4.336866624589016, 2.2665831798010645`}, {4.54091072770064, 
             2.262218365500847}, {4.746193996954599, 2.2592344008871974`}, {
             4.952142480707405, 2.257304058180289}, {5.15875617895906, 
             2.256427337380121}, {5.266589786270239, 
             2.2565193674096404`}}]}, 
           {Arrowheads[{{0.007764253401787927, 1.}}], 
            ArrowBox[{{5.290201770669103, 2.256539518934526}, {
             5.366035091709564, 2.2566042384866947`}, {5.573778562002797, 
             2.2577308348828367`}, {5.656854249492381, 2.258486058765039}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.420028612311908, 1.407486554770093}, {
             1.537686400035295, 1.3440962325393069`}, {1.6816823113881807`, 
             1.277665205459099}, {1.8316610099590647`, 1.2216758416767997`}, {
             1.9219517750794164`, 1.1938072434748386`}, {2.015587674661456, 
             1.1689418641212694`}, {2.2515103352099204`, 
             1.1205338700070802`}, {2.310763340772834, 
             1.1114214679062324`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.334100970255526, 1.1078324201962206`}, {
             2.3772580690705443`, 1.1011953756417312`}, {2.508276585712074, 
             1.0845830885785652`}, {2.526074813063315, 1.0825524077156914`}, {
             2.54396205730821, 1.0805635870053742`}, {2.6594275237043337`, 
             1.0699359082009916`}, {2.778102140725952, 1.0606620131194116`}, {
             3.0100686490114654`, 1.0447956151416808`}, {3.251853205879443, 
             1.032683492275538}, {3.275086040394793, 
             1.0317797354344143`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.298680188706962, 1.03086192349315}, {
             3.376025704749494, 1.027853184322409}, {3.5018496202004377`, 
             1.0235972457733713`}, {3.629324952232273, 1.019915676628425}, {
             3.7584517008450007`, 1.0168084768875696`}, {3.8889347188470325`, 
             1.014178796736893}, {4.02047885904678, 1.0119297863624823`}, {
             4.153084121444243, 1.0100614457643373`}, {4.242874480184814, 
             1.0090621032805187`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.26648501089924, 1.0087993244394562`}, {
             4.286750506039421, 1.0085737749424584`}, {4.491089929562269, 
             1.0068869186341673`}, {4.696655985569364, 1.0057653544049765`}, {
             4.903448674060707, 1.0052090822548856`}, {5.111467995036298, 
             1.0052181021838946`}, {5.210952448733608, 
             1.0054440017643689`}}]}, 
           {Arrowheads[{{0.008942359987441004, 1.}}], 
            ArrowBox[{{5.234564380859044, 1.0054976174335823`}, {
             5.320226797210605, 1.0056921312816969`}, {5.529237929298096, 
             1.0065308866379858`}, {5.656854249492381, 
             1.0072648126355337`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4074877977033777`, -1.4054172603222923`}, {
             1.5241402107638622`, -1.3412954647114317`}, {
             1.6070184107486407`, -1.3004284060257507`}, {
             1.6912976206508976`, -1.2632492361600347`}, {
             1.8978550996445092`, -1.1900321619821914`}, {
             2.1223992748532488`, -1.133921631745757}, {
             2.138015861725779, -1.1307048838697775`}, {
             2.1537238285144444`, -1.1275501494647129`}, {
             2.2573425408197414`, -1.1103468459452401`}, {
             2.296202037368299, -1.1048819291594232`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.3195839438742754`, -1.1015936679955338`}, {
             2.364874821106032, -1.0952242886362589`}, {
             2.550533328282379, -1.0721025073542274`}, {
             2.7461183852873883`, -1.053560488337978}, {
             2.950734137449376, -1.0388757841898986`}, {
             3.163484730096659, -1.027325947512377}, {
             3.2603881298934607`, -1.023409400321362}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.2839808609671928`, -1.0224558523054106`}, {
             3.3833827039751645`, -1.0184383254711518`}, {
             3.6086506324275622`, -1.0113621429645527`}, {
             3.8147768502115023`, -1.0068015308767118`}, {
             4.024510723373024, -1.0035685443515683`}, {
             4.228181377341587, -1.0013972444737897`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.251792428451564, -1.0011890127183727`}, {
             4.451221568681449, -0.9996474581980538}, {
             4.666972409426881, -0.9985392780923104}, {
             4.884200815416786, -0.9980893708335401}, {
             5.102495078869074, -0.998194451332445}, {
             5.196262550090034, -0.9984329008780135}}]}, 
           {Arrowheads[{{0.009253441276399613, 1.}}], 
            ArrowBox[{{5.219874466741503, -0.9984929456965655}, {
             5.321443492001655, -0.9987512344997268}, {
             5.540770895899368, -0.9997047766893923}, {
             5.656854249492381, -1.000419020853444}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.517869666535179, -3.5650840811345463`}, \
{-3.3095640495664784`, -3.585145886493324}, {-3.100336008915167, \
-3.605976017904796}, {-2.890259546305733, -3.6270536751854974`}, \
{-2.67974466342596, -3.647562198318654}, {-2.577858870724761, \
-3.656816040098792}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.5543436704415186`, -3.6589518230875697`}, \
{-2.469201361963634, -3.6666849272874917`}, {-2.283255501334222, \
-3.6815336371186693`}, {-2.0979274218445143`, -3.6937527151885217`}, \
{-1.9134732022838246`, -3.7030463092791344`}, {-1.7274174143554442`, \
-3.7122743241636837`}, {-1.6117136089944017`, -3.7153998342374575`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5881102261633462`, -3.716037433066497}, \
{-1.5433878409079984`, -3.7172455200883765`}, {-1.3607442849682019`, \
-3.7186995275979995`}, {-1.1794867465360537`, -3.7166363466925536`}, \
{-0.9996152256115525, -3.711055977372038}, {-0.8216057381519724, \
-3.7019304242745887`}, {-0.6459343001145845, -3.6892316920383426`}, \
{-0.6444495522364788, -3.6890923092796033`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6209409201572245, -3.6868854039580246`}, \
{-0.47260091149938876`, -3.6729597806632985`}, {-0.30160557230638607`, \
-3.6531146901494576`}, {-0.13317275155441224`, -3.6301977867757684`}, {
             0.03247308173769475, -3.604710436821181}, {
             0.195331927569935, -3.576652640285695}, {
             0.31369120055783634`, -3.554005707682971}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.33688247916059305`, -3.549568274854693}, {
             0.3554037859423079, -3.546024397169311}, {
             0.5128296225169433, -3.5136080708356228`}, {
             0.6677504029559713, -3.480186024648226}, {
             0.820166127259391, -3.4457582586071194`}, {
             0.9700767954272027, -3.4103247727123045`}, {
             1.1179423582261079`, -3.3746346253121127`}, {
             1.2579463969622942`, -3.34094708442273}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.2809060799109089`, -3.335435359284622}, {
             1.4089180200173033`, -3.3047315210405963`}, {
             1.552028119009593, -3.270518564169272}, {
             1.762937293929543, -3.22183005757546}, {
             1.9734023233340134`, -3.1765454396234434`}, {
             2.1834232072230053`, -3.1346647103132206`}, {
             2.20289812838415, -3.1310892493896323`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.226121968799661, -3.126825512801729}, {
             2.392999945596518, -3.0961878696447926`}, {
             2.506817119682495, -3.0768442758724026`}, {
             2.6210925120358084`, -3.0586982118249004`}, {
             2.748891249401919, -3.0398247835799492`}, {
             2.877367642605443, -3.0222933372742244`}, {
             3.0065216916463804`, -3.006103872907727}, {
             3.136353396524731, -2.9912563904804554`}, {
             3.153765774429299, -2.989360059403694}, {
             3.160175233103332, -2.9886713144413863`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.183667031872058, -2.9862959871653287`}, {
             3.303980027488385, -2.974805106625375}, {
             3.4376218539903207`, -2.9633585065398536`}, {
             3.6518065793327006`, -2.9463793157820173`}, {
             3.867856535780768, -2.9319723968533156`}, {
             4.085771723334522, -2.920137749753749}, {
             4.125601704481375, -2.918459164215298}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.149192756771329, -2.917464948348995}, {
             4.305552141993963, -2.910875374483317}, {
             4.526823555091842, -2.903795721170625}, {
             4.749211725960911, -2.8985092399442767`}, {
             4.97271665460117, -2.895015930804272}, {
             5.093326877192669, -2.8941030451797634`}}]}, 
           {Arrowheads[{{0.01143323486307113, 1.}}], 
            ArrowBox[{{5.116938193876465, -2.8939243336981555`}, {
             5.197338341012618, -2.893315793750612}, {
             5.422843690979276, -2.8932489382000903`}, {
             5.6489089326940345`, -2.894603256159901}, {
             5.656854249492381, -2.8946922045249095`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.29499104232484474`}, \
{-5.490038468712804, -0.2951214889382171}, {-5.31693726771909, \
-0.2954797315266243}, {-5.143099305341935, -0.29606143114953054`}, \
{-4.96881309327757, -0.2968723857911015}, {-4.794367143222222, \
-0.29791839343550264`}, {-4.712383153752091, -0.2985198999716777}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688771796242661, -0.29869313362329286`}, \
{-4.619761455175893, -0.299199454082734}, {-4.444996029138582, \
-0.3007155677327956}, {-4.2699702697447055`, -0.30243425936155094`}, \
{-4.09458358162868, -0.30432305394486336`}, {-3.918835964790507, \
-0.3063819514827329}, {-3.744345154033112, -0.3085904763550761}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207352291720275`, -0.3089029626335139}, \
{-3.6025388701504832`, -0.31047236506781883`}, {-3.4617731349315717`, \
-0.3123677008919923}, {-3.3383484249842055`, -0.3140159639835432}, \
{-3.214203477251732, -0.3156380179081857}, {-3.089138041373603, \
-0.3171986877480304}, {-2.962951866989271, -0.318662798585188}, \
{-2.77632730947007, -0.320474109931063}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75271589436604, -0.32063882260365645`}, \
{-2.583803941009374, -0.3217994037261483}, {-2.554062605057869, \
-0.3219629541604044}, {-2.524185688916364, -0.32210831882294794`}, \
{-2.4104881834078777`, -0.32226176637749476`}, {-2.29403428122008, \
-0.3220168290261782}, {-2.1086913923123833`, -0.3208317376227118}, \
{-1.9130014714981747`, -0.3180343634598123}, {-1.8082937008731181`, \
-0.315587192482093}}]}, 
           {Arrowheads[{{0.018685275624978095`, 1.}}], 
            ArrowBox[{{-1.784688153953487, -0.315035496948991}, \
{-1.7601021638812546`, -0.3144608870513292}, {-1.5964430015564477`, \
-0.3090334906263704}, {-1.4690046065941378`, -0.3034550050895975}, \
{-1.3312065868900358`, -0.29591120482669103`}, {-1.2578418037064716`, \
-0.29126234297373194`}, {-1.1804230718906403`, -0.28575536412464725`}, \
{-1.0982852308397468`, -0.2791850647189745}, {-1.0552587843324004`, \
-0.27543538146890567`}, {-1.01215232959922, -0.27145349823867865`}, \
{-0.9750911539912712, -0.2678645546019929}, {-0.9504637694122223, \
-0.26539644121603645`}, {-0.9335941679098166, -0.2636746210474216}, \
{-0.9240109548907497, -0.2626828765822567}, {-0.9180059155674857, \
-0.2620571249770306}, {-0.9139008093479224, -0.26162778972908374`}, \
{-0.9090460444081658, -0.2611184875763715}, {-0.9042155290467252, \
-0.26061004926298287`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.8492970024745926}, {-5.526591345862779, 
             0.8492539582513482}, {-5.293219260169332, 
             0.8503534052607943}, {-5.059500483364507, 
             0.8526712793547682}, {-4.825435015448306, 
             0.8562075805332696}, {-4.7124385742214, 0.858499557941575}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688831437012341, 
             0.8589783962533876}, {-4.591022856420728, 
             0.8609623087962988}, {-4.466421963073292, 
             0.8639557817225538}, {-4.341713224585958, 
             0.8672405143636543}, {-4.216896640958726, 
             0.8708165067196004}, {-4.091972212191597, 
             0.8746837587903921}, {-3.9668504564629026`, 
             0.8787813858171404}, {-3.8414418919509754`, 
             0.8830485030409566}, {-3.7447619587667105`, 
             0.8864609668236025}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.721164660461254, 
             0.8872938689904067}, {-3.7157465186558154`, 
             0.8874851104618408}, {-3.5897643365774226`, 
             0.8920912080797928}, {-3.4632907724087816`, 
             0.896748244397857}, {-3.3361212528428763`, 
             0.901337667919078}, {-3.2082557778797063`, 
             0.9058594786434556}, {-3.079694347519272, 
             0.9103136765709899}, {-2.959921363855873, 
             0.914276170773669}, {-2.8390939752715094`, 
             0.9179304774823916}, {-2.7772384421757113`, 
             0.9194881650311199}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7536339325911405`, 
             0.9200825896336332}, {-2.6720120047682006`, 
             0.9221380478005861}, {-2.5020073278823074`, 
             0.925060624900648}, {-2.3600203444198375`, 
             0.9260926761385609}, {-2.214945121292624, 
             0.9256298223569234}, {-2.0659179242208388`, 
             0.9231807854989518}, {-1.9120750189246511`, 
             0.9182542875078626}, {-1.8804597372081857`, 
             0.9170068347694923}, {-1.8485927099351425`, 
             0.9156253359210674}, {-1.8094338960003176`, 
             0.9132714496553527}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785864447121646, 
             0.9118546600125839}, {-1.7562044278834201`, 
             0.9100717584149539}, {-1.6612398776025838`, 
             0.9029730535874637}, {-1.5062714507841797`, 
             0.888857799939929}, {-1.3422546274642422`, 
             0.8690037828837093}, {-1.203223233118164, 
             0.8474096948042787}, {-1.0546754779974394`, 
             0.818833972513012}, {-0.9385527166917709, 
             0.7918048317642361}, {-0.854182917928228, 0.7685501154922426}}]}, 
           {Arrowheads[{{0.0003635693982836631, 1.}}], 
            ArrowBox[{{-0.8314197682092197, 
             0.7622759439767217}, {-0.8148677989164581, 
             0.7577137504514689}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.8486731194835503}, \
{-5.527247940248638, -0.8486286187426327}, {-5.293832750295357, \
-0.8497245557256198}, {-5.0600695498776025`, -0.8520386165741921}, \
{-4.825958338995376, -0.8555708012883497}, {-4.712438505365764, \
-0.8578707928884426}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688831357191472, -0.8583490902992736}, \
{-4.591499117648677, -0.8603211098680926}, {-4.466877606043446, \
-0.8633120295220502}, {-4.342148437599404, -0.8665941676130857}, \
{-4.21731161231655, -0.8701675241411992}, {-4.092367130194888, \
-0.8740320991063906}, {-3.9672254992501625`, -0.878127035691776}, \
{-3.8417972274981227`, -0.8823914770804713}, {-3.7447613464569867`, \
-0.8858139181136868}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.721164025986716, -0.8866461920827061}, \
{-3.7160823149387685`, -0.8868254232724767}, {-3.5900807615720995`, \
-0.891428874267792}, {-3.463587913627023, -0.8960833219964285}, \
{-3.3363991173324443`, -0.9006702583883973}, {-3.2085143726883634`, \
-0.9051896834436982}, {-3.07993367969478, -0.9096415971623314}, \
{-2.9601536196214173`, -0.9136017566828819}, {-2.839319132625601, \
-0.9172539618949036}, {-2.7772369960524834`, -0.9188167824549196}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7536324809815356`, -0.9194109891542757}, \
{-2.6722730015844376`, -0.9214590866292108}, {-2.502304641523306, \
-0.9243816387787441}, {-2.3602967202805267`, -0.9254153213051785}, \
{-2.2151993214307084`, -0.9249546974208794}, {-2.066147992923237, \
-0.9225085462995242}, {-1.9122782827074973`, -0.9175856471147895}, \
{-1.8806615341017148`, -0.9163391613445311}, {-1.8487929398929812`, \
-0.9149586937546359}, {-1.8094323297239947`, -0.9125946943802347}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7858628085307595`, -0.9111791082621199}, \
{-1.7563944931575184`, -0.909409240396558}, {-1.6614180395694167`, \
-0.9023150058564879}, {-1.506602282190168, -0.888226790173823}, \
{-1.3427536198906558`, -0.8684152560822227}, {-1.2036965357016758`, \
-0.8468408129655784}, {-1.0551114332027183`, -0.8182871242554635}, \
{-0.9389877006975403, -0.7912848057789208}, {-0.8541709830191158, \
-0.7679302456263265}}]}, 
           {Arrowheads[{{0.0003537668517222177, 1.}}], 
            ArrowBox[{{-0.8314062293222411, -0.7616618963654131}, \
{-0.8152993988310909, -0.757226827998356}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.554132578552968}, {-5.586571147098856, 
             2.5528615178105536`}, {-5.458312431038295, 
             2.55171136912207}, {-5.329436541692904, 
             2.5514946114612007`}, {-5.200134255268395, 
             2.552444050937774}, {-5.07050060176558, 
             2.5546290633361015`}, {-4.9405348649803615`, 
             2.5579555941149796`}, {-4.810236328708649, 
             2.5623295887332045`}, {-4.712610369525285, 
             2.5663109463669556`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689017987227191, 
             2.567273085045506}, {-4.679604276746349, 
             2.5676569926495727`}, {-4.548637992889367, 
             2.57384375132288}, {-4.417336760933611, 
             2.580795810211923}, {-4.285699864674987, 
             2.588419114775498}, {-4.1587449208470595`, 
             2.5963615287854194`}, {-4.03145913391983, 
             2.6048592019035555`}, {-3.903847865454109, 
             2.61379520518579}, {-3.775859287028716, 
             2.6242998517585905`}, {-3.74646773151638, 2.62668636678149}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722933192694172, 
             2.628597307848649}, {-3.6475693540884855`, 
             2.63471664824696}, {-3.518964662731388, 
             2.645337917011193}, {-3.390045212957424, 
             2.656163658051288}, {-3.260811004766593, 
             2.667193871367246}, {-3.1312228662295922`, 
             2.6781697670031317`}, {-3.0012416254171193`, 
             2.6888325550030103`}, {-2.870867282329174, 
             2.6991822353668815`}, {-2.7816361504828384`, 
             2.7060308416226393`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7580933980588647`, 
             2.707837778710541}, {-2.740099836965756, 
             2.7092188080947457`}, {-2.629097477666646, 
             2.717274775344187}, {-2.5179234246656024`, 
             2.72463233147334}, {-2.3268298978406587`, 
             2.735165346476557}, {-2.1352064758312874`, 
             2.742851458409054}, {-1.9432909482298908`, 
             2.74706372633109}, {-1.814692137342784, 
             2.7471384077359557`}}]}, 
           {Arrowheads[{{0.005506798817000018, 1.}}], 
            ArrowBox[{{-1.7910801483263774`, 
             2.7471521199662576`}, {-1.7513211046288713`, 
             2.747175209302924}, {-1.7265771098094274`, 
             2.7469253284907014`}, {-1.7018383536201016`, 
             2.7465967441201435`}, {-1.616455473494626, 
             2.7442068411865215`}, {-1.5311322944755426`, 
             2.740793563912192}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.010773378083883754`, 1.}}], 
            ArrowBox[{{2.8778895765948116`, 5.656854249492381}, {
             2.9426411210313117`, 5.650900172410663}, {3.1045821182500495`, 
             5.636395060884511}, {3.115455882472363, 5.635434115145539}, {
             3.1263269682889385`, 5.634476537693715}, {3.2564115780666074`, 
             5.623495551971652}, {3.3847589139057197`, 5.613055498084943}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0064929082562311825`, 1.}}], 
            ArrowBox[{{-2.6676635408764717`, 
             5.620906718819012}, {-2.6534171526318593`, 
             5.622568698984985}, {-2.639179914559651, 
             5.6242318281175105`}, {-2.5246362008850958`, 
             5.637758982486538}, {-2.410223103206185, 
             5.651384635979956}, {-2.363157189523098, 
             5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0051757271758035295`, 1.}}], 
            ArrowBox[{{-2.6896256933055875`, -5.628178761585262}, \
{-2.675420354704107, -5.6298313506645155`}, {-2.661225310359603, \
-5.631485082192513}, {-2.5461078018836427`, -5.645053791468382}, \
{-2.44689525383178, -5.656854249492381}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.012162322491652694`, 1.}}], 
            ArrowBox[{{2.8582007664475295`, -5.656854249492381}, {
             2.950964350786437, -5.6482150889882625`}, {
             3.113248254836844, -5.63318936467364}, {
             3.274961882333332, -5.61892398820792}, {
             3.2857992885427367`, -5.618013312484658}, {
             3.2966286353551126`, -5.61710620639343}, {
             3.430323539342334, -5.606363222736549}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.556456334690399}, \
{-5.6291836427774316`, -2.555982542409051}, {-5.493836406060306, \
-2.5545407964056963`}, {-5.3572875575258445`, -2.5541198314091127`}, \
{-5.21987148661395, -2.5547716705144574`}, {-5.081922582764527, \
-2.5565483368168875`}, {-4.92313810433145, -2.559946758413841}, \
{-4.763909929721502, -2.5647751700826205`}, {-4.712548891712651, \
-2.5667882861567914`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688955015146033, -2.5677130574232927`}, \
{-4.604238058934683, -2.571033571823226}, {-4.444122491970994, \
-2.5787219636356578`}, {-4.283526871851867, -2.5876937715851493`}, \
{-4.122414841598739, -2.597802421736934}, {-3.96078640121161, \
-2.609047914091013}, {-3.79864155069048, -2.6214302486473846`}, \
{-3.746323733920371, -2.625636771952883}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.722787694905671, -2.6275291463436092`}, \
{-3.635979196324961, -2.6345088330916178`}, {-3.4727982444046677`, \
-2.6478430751092796`}, {-3.3090986949295997`, -2.6614329747003698`}, \
{-3.1448805478997577`, -2.675278531864888}, {-3.0221051763962885`, \
-2.685592186705432}, {-2.898987804211327, -2.695647537918319}, \
{-2.7814579064884692`, -2.7045641140211543`}}]}, 
           {Arrowheads[{{0.018381949005716363`, 1.}}], 
            
            ArrowBox[{{-2.7579135735452747`, -2.706350338977918}, \
{-2.7092864723516663`, -2.7100395045166774`}, {-2.5188880836201863`, \
-2.722806639837073}, {-2.3278763993231086`, -2.733338900999048}, \
{-2.1363351807666544`, -2.741026245122144}, {-2.111355728985178, \
-2.7418421394087233`}, {-2.086366119269293, -2.7426011554366174`}, \
{-1.988598407620837, -2.744404365659011}, {-1.8909002270382318`, \
-2.745092247557183}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(tot\\)]\\)}\"", 
           TraditionalForm]}}], {194.4, -576.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.6930607398396748, -0.6913636221759953}, \
{-0.6961306441602209, -0.6942411069805087}, {-0.699470432353798, \
-0.6973707766155542}, {-0.7038155047560184, -0.701440760414903}, \
{-0.7128804798033452, -0.7099305545526713}, {-0.7195023973577679, \
-0.716135011697177}, {-0.726853483491823, -0.7230311565641744}, \
{-0.7342473703848931, -0.7299809024175569}, {-0.7619091192803819, \
-0.7561101738881713}, {-0.7869284631744141, -0.7799187782481067}, \
{-0.8710001938373114, -0.860807224819667}, {-0.9670263574741521, \
-0.9546582744322188}, {-1.0764080451795597`, -1.0628475493224112`}, \
{-1.200912538016711, -1.1870647800232164`}, {-1.3406305395619071`, \
-1.3272995435881698`}, {-1.3665623248577043`, -1.3534323978330254`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.383193921977459, -1.370192952435494}, \
{-1.501051858075867, -1.4889647311821876`}, {-1.595917909048385, \
-1.5847763570085722`}, {-1.6802950659214875`, -1.6700801909208187`}, \
{-1.7867239902049334`, -1.7777718777319993`}, {-1.8815137392694183`, \
-1.8737477668457865`}, {-1.9933280784454845`, -1.9870234007930434`}, \
{-2.0473197664513227`, -2.041741913616472}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.063903967138715, -2.0585493673467803`}, \
{-2.0936658639808488`, -2.0887119126228186`}, {-2.1847140734199906`, \
-2.18101512423865}, {-2.2686596843073903`, -2.2661348575440767`}, \
{-2.3464042450590217`, -2.344980825539916}, {-2.4192504750682646`, \
-2.4188679739978682`}, {-2.4459306482055423`, -2.4459313358002763`}, \
{-2.522439996011821, -2.523547978145984}, {-2.5947076500197284`, \
-2.596866971304127}, {-2.7270123484802, -2.7311035975068663`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.743586529605802, -2.747920931810238}, \
{-2.8567323495608568`, -2.8627300928391803`}, {-2.971257325203066, \
-2.9789469103638084`}, {-3.0940497146378476`, -3.1035599468064494`}, \
{-3.207742533310197, -3.2189441550018056`}, {-3.3136884717795048`, \
-3.3264706930745342`}, {-3.406498781376119, -3.420668496852657}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.423070518368828, -3.4374882396080464`}, \
{-3.507198495728005, -3.522876153121446}, {-3.5963640130888734`, \
-3.6133789148863675`}, {-3.737100619220271, -3.7562292415427523`}, \
{-3.8679308938672397`, -3.889027465682607}, {-3.990266520925537, \
-4.0132056676316985`}, {-4.085918197378131, -4.1102994282348}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.102489016206911, -4.127120075567168}, \
{-4.105519184290921, -4.130195927715791}, {-4.214544493146066, \
-4.240866349695412}, {-4.318198056673647, -4.346085037331087}, \
{-4.4864418320976, -4.516871057499965}, {-4.642904174161639, \
-4.675699487229565}, {-4.76530996196201, -4.79995760064926}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.781880314787382, -4.8167787070510055`}, \
{-4.789256344269033, -4.824266355506099}, {-4.927169603823053, \
-4.964267691315777}, {-5.057659666756779, -5.096734337845949}, \
{-5.18174224700329, -5.222697138283969}, {-5.283350478398116, \
-5.325777729976034}, {-5.381167360595829, -5.424874284710668}, \
{-5.4449382843437695`, -5.489382433987589}}]}, 
           {Arrowheads[{{0.004490575959071288, 1.}}], 
            ArrowBox[{{-5.461538256771062, -5.506174310855566}, \
{-5.47519289359643, -5.519986802487874}, {-5.565427077399917, \
-5.611115283307648}, {-5.610756964776709, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6877526419886628, -0.6779886022800542}, {
             0.6903229711115645, -0.6809466339602495}, {
             0.6929094484190175, -0.6839250309691438}, {
             0.6967740138719686, -0.6883784974717708}, {
             0.7009129800383712, -0.6931524929401847}, {
             0.7041584805373764, -0.6968991423109087}, {
             0.7097440021304283, -0.7033501893480432}, {
             0.7181132803202367, -0.7130007365524517}, {
             0.728874865283722, -0.7253212426538471}, {
             0.7402606748096348, -0.7381963179699387}, {
             0.7856729538678866, -0.7882276741853098}, {
             0.8299484445301581, -0.8355023428231331}, {
             0.9864804597040959, -0.9978569692854851}, {
             1.1376663138808578`, -1.1504022441117032`}, {
             1.2977760549532729`, -1.3101721102556942`}, {
             1.344462060787482, -1.356493767409482}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.3612235383209834`, -1.3731244343903966`}, {
             1.4714596225416874`, -1.4825002100217717`}, {
             1.5718049486153889`, -1.581796268825421}, {
             1.6612278809223904`, -1.6701838785810725`}, {
             1.772509437730999, -1.780070654072268}, {
             1.8717096743965609`, -1.8779604350787686`}, {
             1.9847493491741741`, -1.9894422673685446`}, {
             2.0330054469807552`, -2.0370144993171104`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0498203693457024`, -2.053591127418053}, {
             2.086461752150947, -2.089713243398379}, {
             2.1789454779272397`, -2.1808567900726636`}, {
             2.264299121103411, -2.2649563342957917`}, {
             2.3434100176489485`, -2.34289064710691}, {
             2.4175648802388356`, -2.415933574068036}, {
             2.446513457451672, -2.4444459204077544`}, {
             2.524280495697791, -2.521032106392988}, {
             2.5977446484640856`, -2.593374960739335}, {
             2.722676704165564, -2.716392958845074}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.739501400523727, -2.73295966659337}, {
             2.8641101277324856`, -2.8556461462943568`}, {
             2.980516065650915, -2.9702474288347593`}, {
             3.105196987194332, -3.09298834539823}, {
             3.220623605813075, -3.2066130879743087`}, {
             3.328169354895139, -3.3124753547072334`}, {
             3.4125669096297564`, -3.3955491020869113`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.429394564991637, -3.4121128042200923`}, {
             3.5245530011488353`, -3.50577603158009}, {
             3.615019811391709, -3.59481939472753}, {
             3.757654933506356, -3.7352070237761748`}, {
             3.890224373575734, -3.8656843982276543`}, {
             4.014162940886029, -3.9876645636157164`}, {
             4.102528635215537, -4.074632588509567}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.1193573943488815`, -4.091195169207273}, {
             4.130905444723428, -4.10256056547411}, {
             4.241321815476252, -4.211229002098139}, {
             4.346281983532824, -4.314526471783106}, {
             4.516507658258627, -4.4820536007662115`}, {
             4.6747852112109785`, -4.637820021699656}, {
             4.7925201671526425`, -4.753685789963291}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.809349425668511, -4.770247863237559}, {
             4.822810894055864, -4.783495614206523}, {
             4.96228095845927, -4.920750257909897}, {
             5.094226174165767, -5.05059861627018}, {
             5.219677310919926, -5.174055352747777}, {
             5.322225554263846, -5.275065169493343}, {
             5.420611206660419, -5.372162978207226}, {
             5.482190703327904, -5.433064572936863}}]}, 
           {Arrowheads[{{0.004707687993880564, 1.}}], 
            ArrowBox[{{5.498979055810071, -5.449668109736915}, {
             5.514834268109645, -5.465348778889427}, {
             5.604894738611525, -5.554622571539947}, {
             5.656854249492381, -5.606191980668935}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6930601421319604, 
             0.6919303765455209}, {-0.6962210934028678, 
             0.6948955747223806}, {-0.6992133426585169, 
             0.6977018602071634}, {-0.703338269174781, 
             0.7015688387172725}, {-0.7123512012652266, 
             0.7100160913569556}, {-0.7190262218419397, 
             0.7162745860729295}, {-0.7264085688586083, 
             0.7232051248177589}, {-0.7337990772718371, 
             0.7301571840062202}, {-0.7614472473767717, 
             0.7562944577165981}, {-0.78645409075721, 
             0.7801102307277541}, {-0.8704822068577867, 
             0.861022022538498}, {-0.9664548281168333, 
             0.9548978740637174}, {-1.0757754828166497`, 
             1.0631167278463034`}, {-1.200213864615155, 
             1.187372084523143}, {-1.3398580537809852`, 
             1.3276509069399212`}, {-1.366272788307207, 1.354292971237886}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3828972987140098`, 
             1.3710605550551886`}, {-1.5001979974567128`, 
             1.489370763889465}, {-1.5950172122188986`, 
             1.5852162306072077`}, {-1.6793518453882943`, 
             1.6705493647408083`}, {-1.7857148010232298`, 
             1.7782655981656066`}, {-1.8804463603716384`, 
             1.874263952866993}, {-1.992195297787408, 
             1.9875694000189301`}, {-2.0467370674523546`, 
             2.042892309450347}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.063314138545871, 
             2.0597067950891246`}, {-2.092474345377432, 
             2.089284630415224}, {-2.1834692081536122`, 
             2.1816120482853596`}, {-2.26736559112785, 
             2.26675405785882}, {-2.3450646862591924`, 
             2.345620786019942}, {-2.417868518782988, 
             2.4195275939361034`}, {-2.444546998600464, 
             2.446612201231679}, {-2.5210082238374825`, 
             2.5242458383571456`}, {-2.59323031469537, 
             2.597580767362828}, {-2.7261369124351362`, 
             2.7325425019517033`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7427039102761372`, 
             2.7493669126576}, {-2.855087325870611, 
             2.863499533695567}, {-2.9695304697494374`, 
             2.9797326479303194`}, {-3.0920837573849975`, 
             3.1042096066564056`}, {-3.205566110713573, 
             3.2194789225166756`}, {-3.311324717095676, 
             3.3269073393290967`}, {-3.405328279857132, 
             3.4223980297570855`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.4218927905835694`, 
             3.4392248891701978`}, {-3.5045100709004413`, 
             3.523151380430193}, {-3.593532457919979, 
             3.6135863510506794`}, {-3.734179388291567, 
             3.756468098011563}, {-3.8649248763704094`, 
             3.889294109415972}, {-3.9871800678211318`, 
             4.013497142208973}, {-4.084451917286, 4.11232023511288}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.101015521173481, 
             4.1291479871788805`}, {-4.102356108308359, 
             4.130509953335633}, {-4.211308243620823, 
             4.241201019716172}, {-4.314891719547255, 
             4.346438818270809}, {-4.483000742723857, 
             4.517234552671841}, {-4.63933801339719, 
             4.6760722869658595`}, {-4.763547690042985, 
             4.80226986804647}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.780110822608851, 
             4.819098084022673}, {-4.785573390842296, 
             4.824648077518867}, {-4.923376734334212, 
             4.964657980696865}, {-5.053762920834502, 
             5.09713287215234}, {-5.177746827304726, 
             5.223103627537777}, {-5.27925271923051, 
             5.326159475536726}, {-5.376924769043778, 
             5.425166046677358}, {-5.442919295334904, 5.491947604079142}}]}, 
           {Arrowheads[{{0.004413869594077208, 1.}}], 
            ArrowBox[{{-5.459516237296461, 
             5.508742476238848}, {-5.470762976744531, 
             5.520123340959673}, {-5.560767342332768, 
             5.611031358383672}, {-5.606180293256048, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6873942660672164, 0.678182581103443}, {
             0.6900464093573722, 0.6812371344800388}, {0.6931797739993666, 
             0.684848344225408}, {0.6970204344512498, 0.6892782811263365}, {
             0.7010418667308177, 0.6939208478281385}, {0.704071205558301, 
             0.6974209423997955}, {0.7092569463624414, 0.7034164502125219}, {
             0.7176662387689872, 0.7131254084288966}, {0.7284656909659414, 
             0.7255035777264996}, {0.7398442183947771, 0.7383825051435822}, {
             0.7852237600762848, 0.7884267474112622}, {0.8294662908619409, 
             0.8357124114015486}, {0.9858933419613581, 0.998107606946362}, {
             1.136981561756638, 1.1506880990960422`}, {1.2969908465182503`, 
             1.310494818931032}, {1.3438014927826964`, 
             1.3569795790833614`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3605559117039256`, 1.3736173571786516`}, {
             1.4705643750620836`, 1.4828599641924818`}, {1.5708446339064017`, 
             1.5821754234982364`}, {1.6602102766736655`, 
             1.6705808043115427`}, {1.7714345483488243`, 
             1.7805033132571844`}, {1.8705829724376377`, 
             1.8784240468416915`}, {1.9835678281437947`, 
             1.9899451556928778`}, {2.032059152875419, 
             2.037789281402535}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.048867142041467, 2.0543729394287418`}, {
             2.085229978780498, 2.0902504524010226`}, {2.1776673469135446`, 
             2.1814244686106212`}, {2.262977855108732, 2.265551735966168}, {
             2.3420482781880927`, 2.343511216697007}, {2.416164433579437, 
             2.416576953696107}, {2.4451078456962634`, 2.4451080079266476`}, {
             2.5228739915377223`, 2.5217575334634676`}, {2.596339581708866, 
             2.5941626637902973`}, {2.721446165843414, 
             2.7174561710898275`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.738263903399771, 2.734029943039387}, {
             2.8626950105499667`, 2.8566446505371794`}, {2.9790893196951744`, 
             2.971330933532592}, {3.1037217181557493`, 3.09412736327904}, {
             3.2191027493122593`, 3.2078028511033536`}, {3.3266054574178017`, 
             3.313711848732166}, {3.4110506248175, 3.396902454964597}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.4278713096983346`, 3.413473235678677}, {
             3.5229092780081195`, 3.507096666386699}, {3.61333887203858, 
             3.5961783620194487`}, {3.7559104023874084`, 3.736621597247964}, {
             3.8884206215297583`, 3.867150550137944}, {4.012303716946192, 
             3.9891788411467495`}, {4.100726436439321, 
             4.076276313139589}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.117548220296432, 4.0928459782297715`}, {
             4.128993876117274, 4.1041200907317394`}, {4.239360644915868, 
             4.212831238508942}, {4.344273569214837, 4.3161692240943825`}, {
             4.5144263167052845`, 4.4837657127822785`}, {4.6726357178542814`, 
             4.639596300937635}, {4.790431910932878, 
             4.7556200575017975`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.80725419099168, 4.772189218825154}, {
             4.820597401411644, 4.785331658806362}, {4.960006996127185, 
             4.92264245663437}, {5.091894856767242, 5.052543802686234}, {
             5.217291338098147, 5.176050805226529}, {5.319827619573474, 
             5.277125027910116}, {5.418267186821569, 5.374330854013005}, {
             5.479848864938562, 5.43525624854005}}]}, 
           {Arrowheads[{{0.0047778855492057225`, 1.}}], 
            ArrowBox[{{5.496634267792276, 5.451862767271401}, {
             5.512610039842431, 5.467668283535196}, {5.602856178636061, 
             5.557137316476688}, {5.656854249492381, 5.610730023597275}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.001962083583396427, -0.9804238769229957}, {
             0.0017185979200324197`, -0.9843877415524537}, {
             0.0014671492002598938`, -0.9884822343698674}, {
             0.00014054156728405789`, -1.009373654413476}, \
{-0.0015996361263462184`, -1.0387874193401876`}, {-0.0030777561928020895`, \
-1.0670734501680526`}, {-0.005394912509581912, -1.1194105609367426`}, \
{-0.007076221349658864, -1.1669990857135697`}, {-0.00832806102269629, \
-1.2107785583355295`}, {-0.011270368667090119`, -1.3609585768574264`}, \
{-0.012649854262103931`, -1.5287922271443644`}, {-0.012841809993322049`, \
-1.7156605908833924`}, {-0.012116653786145817`, -1.9231785318824848`}, \
{-0.012107513533030667`, -1.9246215709664798`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.011957957456730227`, -1.948233090322849}, \
{-0.010658984645795568`, -2.1533114958780164`}, {-0.0096119015399716, \
-2.287467217459708}, {-0.008595374580827335, -2.407480308529101}, \
{-0.007234734707387751, -2.557902970454989}, {-0.005960417525877082, \
-2.692470873253963}, {-0.004489006560034481, -2.842172256928381}, \
{-0.003980030787910906, -2.89267832243329}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.0037420925908824947`, -2.916289116548494}, \
{-0.0031241545854674264`, -2.9776075900177745`}, {-0.0006585900741926568, \
-3.2159210109324077`}, {0.00046367169031045954`, -3.3224625499870855`}, {
             0.0015263259501046727`, -3.422567109749506}, {
             0.0019449572176843248`, -3.4618183151414357`}, {
             0.0030666380069665038`, -3.5662442687148017`}, {
             0.004133892472888113, -3.665102354773245}, {
             0.006173939307638734, -3.853366514781707}, {
             0.006254121352266418, -3.860715911048425}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.006511713287964522, -3.8843264989218946`}, {
             0.008043423775415616, -4.024721364012173}, {
             0.00977390708210331, -4.182547534997913}, {
             0.01164818735734301, -4.352857331052004}, {
             0.01339178832127355, -4.510764745252031}, {
             0.015023089815621655`, -4.6580848590989214`}, {
             0.016560471682114053`, -4.796632754093607}, {
             0.01691749167811969, -4.828748892508273}}]}, 
           {Arrowheads[{{0.01703678506322809, 1.}}], 
            ArrowBox[{{0.017179958874832906`, -4.852359426689159}, {
             0.01801518670333641, -4.927493292713783}, {
             0.019398487661874398`, -5.051751337437149}, {
             0.021572080794041725`, -5.246708079891283}, {
             0.02359812222725979, -5.428141411387222}, {
             0.025496981275978915`, -5.597953768188586}, {
             0.026156296993079295`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAARduVatq+1z/zNlC88brrv30WiOrn
09c/uFAvUhva67+bBWcAm/HXP9pUDoATBuy/gieftn0i2D8ltlSkWE7sv/Hi
Nu8Jd9g/e+rSV+DK7L9eL76thdDYP11T5WQFTu2/XW/6qN1S2T+fld3vjwvu
v2rtZZOrAdo/ceGm8ZgG779Bag1aPzvaPwQhB7q4WO+/QKK0AgJ32j8qJW9t
a63vvymcC3NQfts/b6TSbEmJ8L8E9ip8JHzcPyL0jg/mMPG/tJH95ptj3j+w
ke08ZW3yv77exM9MEuA/v/MhHIuI87/LsXS2uOHgP6zoB1tgifS/t6E1K+56
4j/v9cmEiXn2v0CRBZA64OM/glcDvGMl+L+O/YisSh7lPwI9lRQdn/m/NLI8
QvI95j/8wySi2fL6v9w9jkF8Dec/W4eS+IPm+7+b7LEP
             "]]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.729647761070176, -1.7655022468584411`}, {
             0.7625978664456825, -1.8428737093261982`}, {
             0.8206536884383094, -1.978611398077165}, {
             0.8719102869196909, -2.098129854671496}, {
             0.9180358221068651, -2.2054900623667937`}, {
             1.0019813965162363`, -2.400507585929304}, {
             1.074379195036159, -2.5684572242399777`}, {
             1.1023682766982843`, -2.6333269049281656`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1117224910220085`, -2.655006962301752}, {
             1.1384666704356128`, -2.7169913603527878`}, {
             1.1962627767356109`, -2.850859468336983}, {
             1.2517988284201094`, -2.9794277007340297`}, {
             1.3028928477384065`, -3.0976683810094743`}, {
             1.3949563318502118`, -3.3106469708583464`}, {
             1.4765268565556127`, -3.4992849646932465`}, {
             1.486355436454817, -3.5220087174442694`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4957289807506753`, -3.5436804243606557`}, {
             1.550144145355855, -3.6694887058291124`}, {
             1.6206072446634825`, -3.8323675802722788`}, {
             1.685491543576792, -3.9823284500536804`}, {
             1.745936477242916, -4.122015433401391}, {
             1.8025128286175265`, -4.252750118991548}, {
             1.8558401752266456`, -4.375968494279497}, {
             1.8707855112284153`, -4.410499053190681}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{1.8801643539201873`, -4.432168467652063}, {
             1.906302563070915, -4.492559680723831}, {
             2.0000448235042145`, -4.709131060524461}, {
             2.089521336441123, -4.915829106903932}, {
             2.1719770161654997`, -5.106295468076407}, {
             2.24883276197501, -5.2838180272924795`}, {
             2.2553719693997167`, -5.298921711479451}}]}, 
           {Arrowheads[{{0.007761824967169783, 1.}}], 
            ArrowBox[{{2.2647533612630597`, -5.320590022443681}, {
             2.3208064887562885`, -5.450056589317066}, {
             2.3883174384052697`, -5.6057061749714325`}, {
             2.410633403128192, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.0010530108465240948`, 0.9864290749976253}, {
             0.0007744027982721364, 
             0.9909064973889989}, {-0.00042200349783164326`, 
             1.0096308313920364`}, {-0.002156853722046681, 
             1.0387488033224683`}, {-0.003651102402915085, 
             1.0670336132722016`}, {-0.005997846585470788, 
             1.1193672463797972`}, {-0.007705971435382924, 
             1.1669517726517902`}, {-0.008982327969004587, 
             1.2107267248629157`}, {-0.01200834389333219, 
             1.3608888459685904`}, {-0.013480683101118236`, 
             1.5286969179951138`}, {-0.013775474695803704`, 
             1.7155440372405277`}, {-0.013164019374594044`, 
             1.9230411090754387`}, {-0.01312008433828177, 
             1.930630826092531}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.012983402511214482`, 
             1.9542424234847937`}, {-0.011831963106749516`, 
             2.1531519948825304`}, {-0.010857927802464383`, 
             2.2872958501706138`}, {-0.009906669164731593, 
             2.4072982312325317`}, {-0.008627724426887378, 
             2.55770963531743}, {-0.007426419696252087, 
             2.6922675191809433`}, {-0.00603602358124803, 
             2.841972382405722}, {-0.0054951176595270925`, 
             2.8986916688165016`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.005269951108409816, 
             2.922302588183617}, {-0.004744422699823311, 
             2.977409391652848}, {-0.002407658926134998, 
             3.2157231331481615`}, {-0.001342943357865225, 
             3.322264187215225}, {-0.0003343367729413345, 
             3.4223683111847016`}, {0.00006311607352559396, 
             3.4616203192481816`}, {0.0011285763673125817`, 
             3.5660688395600264`}, {0.0021423271227848464`, 
             3.664954228615741}, {0.004080266368527554, 3.853272881195691}, {
             0.004219772733274048, 3.8667346085560155`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.0044644550353184365`, 3.8903453337440994`}, {
             0.00585656685635884, 4.024677769572276}, {0.007501166682383855, 
             4.182546286402015}, {0.0092823004298145, 4.352858750580175}, {
             0.010939512328541073`, 4.510768242409886}, {
             0.012490196946142885`, 4.658090075878259}, {0.01395174885019925, 
             4.796639564972409}, {0.014354783935106346`, 
             4.834773265967059}}]}, 
           {Arrowheads[{{0.01690910321195, 1.}}], 
            ArrowBox[{{0.014604325151584347`, 4.858383940301297}, {
             0.015334829530924604`, 4.927501584447501}, {0.01665010047853338, 
             5.051761009058702}, {0.018716931699379324`, 5.246719200546122}, {
             0.020643596886957574`, 5.428153808974107}, {0.02244942839546564, 
             5.5979673508502765`}, {0.02307632320103052, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.9780508127650513, 
             0.0034919183554737504`}, {-0.982110751625738, 
             0.003505842708626839}, {-0.9866226145370197, 
             0.0035213143300910697`}, {-0.9926081156080424, 
             0.0035418350884320895`}, {-1.0067682022425124`, 
             0.003590365459958242}, {-1.0296047934081485`, 
             0.003668726606234112}, {-1.0528629312600153`, 
             0.0037487519513712867`}, {-1.095330027318794, 
             0.003895493314141771}, {-1.1334601371502875`, 
             0.004027904839854216}, {-1.1682258402256014`, 
             0.004149122540146107}, {-1.2863103074775981`, 
             0.004563378335747514}, {-1.4193489770884362`, 
             0.005034186202898265}, {-1.57564532111608, 
             0.005591033302174907}, {-1.7481536638660091`, 
             0.006208726655816644}, {-1.9225246138670589`, 
             0.006835283386965349}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.9461364544348432`, 
             0.006920126404924856}, {-1.946569605153012, 
             0.00692168281955739}, {-2.169433738071339, 
             0.0077244497641509174`}, {-2.3006457385152133`, 
             0.008197717834234458}, {-2.4179673033606894`, 
             0.00862115389763786}, {-2.5660421938694276`, 
             0.009155883181778502}, {-2.698483608715402, 
             0.009634359905829275}, {-2.848545725405111, 
             0.010176693594614053`}, {-2.8906100234465457`, 
             0.010328756309465576`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.9142218621620457`, 
             0.010414113262152117`}, {-2.9841432565984394`, 
             0.010666879564200685`}, {-3.222478685040317, 
             0.011528710444279222`}, {-3.328971447496778, 
             0.01191387137755927}, {-3.429016732230429, 
             0.012275746178727207`}, {-3.4663122372395248`, 
             0.012410655618172891`}, {-3.5707528188762536`, 
             0.012788481904551731`}, {-3.6696277537906794`, 
             0.013146195042550502`}, {-3.8579364154502858`, 
             0.013827494866101563`}, {-3.858695404093018, 
             0.01383024110886074}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.8823072425279372`, 
             0.01391567564197751}, {-4.029359680205333, 
             0.01444775434441652}, {-4.187279683494218, 
             0.015019190234247965`}, {-4.357809001008503, 
             0.01563628203368402}, {-4.515951122030935, 
             0.016208573153972256`}, {-4.663518913105518, 
             0.01674261728876178}, {-4.8023252407762556`, 
             0.017244968131701698`}, {-4.8267807784054115`, 
             0.017333476820551197`}}]}, 
           {Arrowheads[{{0.01707748505186708, 1.}}], 
            ArrowBox[{{-4.850392616765543, 
             0.01741893202036206}, {-4.93345292838649, 
             0.017719541207061616`}, {-5.057984799279565, 
             0.018170252039111143`}, {-5.253589449884559, 
             0.018878207673719997`}, {-5.435655984508551, 
             0.01953718016359564}, {-5.606087806384545, 
             0.020154054738270578`}, {-5.656854249492381, 
             0.020337805896013757`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.9876763157681075, 0.00020876877823495087`}, {
             0.9933672624280835, 0.00021018083190822248`}, {
             0.9993884944993942, 0.00021167618805589851`}, {1.017397959948644,
              0.0002161309562007385}, {1.0419279052820463`, 
             0.0002221074201707662}, {1.0675087606901432`, 
             0.00022820076454253542`}, {1.0779669174758502`, 
             0.00023065906283349278`}, {1.0885209540022545`, 
             0.0002331236830863339}, {1.1002152297519103`, 
             0.000235837770415931}, {1.1050196541521644`, 
             0.0002369481820339989}, {1.2539054534276026`, 
             0.0002708200035609138}, {1.392370229891738, 0.000301461875308}, {
             1.6310323677636047`, 0.00035316105169221263`}, {
             1.8618244667347104`, 0.0004026836145577024}, {
             1.9321560125399107`, 0.0004177101646327752}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9557680049989645`, 0.0004227549391076735}, {
             2.1047534532594616`, 0.0004545861362342691}, {2.242771228264297, 
             0.0004840154502166957}, {2.366284936861468, 
             0.0005103296035203475}, {2.518761189464064, 
             0.0005427902659947178}, {2.655187766651602, 
             0.0005718185686861473}, {2.8031435722042657`, 
             0.0006032857243177057}, {2.9002477034921794`, 
             0.0006239312827412472}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.9238596959564696`, 0.0006289514890234323}, {
             2.937199080100383, 0.0006317876097015595}, {3.173396339431203, 
             0.000681988733915775}, {3.279056581342453, 
             0.0007044400420151192}, {3.3783457164059816`, 
             0.0007255351970152089}, {3.420442940076371, 
             0.0007344786124648074}, {3.524000956671342, 
             0.0007564767757518517}, {3.6220430083528354`, 
             0.0007773016619666763}, {3.8087524748013983`, 
             0.0008169579445957517}, {3.868339394559339, 
             0.0008296126162380595}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.8919513870248297`, 0.0008346271733369202}, {
             3.9786825747901218`, 0.0008530465631421945}, {4.135175859539979, 
             0.0008862788992501191}, {4.304041237505731, 
             0.0009221363022504315}, {4.4605756159797165`, 
             0.0009553733806462333}, {4.606583307351568, 
             0.000986373759934001}, {4.7438686240109185`, 
             0.001015521065610211}, {4.836431085652297, 
             0.0010351724960222938`}}]}, 
           {Arrowheads[{{0.016873018499476356`, 1.}}], 
            ArrowBox[{{4.8600430781181325`, 0.0010401854291120676`}, {
             4.873511086703886, 0.0010430447484173135`}, {4.996590216176589, 
             0.0010691742590977586`}, {5.1893934224357245`, 
             0.0011101048208160842`}, {5.368793062620651, 
             0.0011481886084952029`}, {5.536675495746708, 
             0.0011838263874920725`}, {5.656854249492381, 
             0.001209337089770738}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8536133811356985, -0.35128060467038374`}, \
{-0.857424945883064, -0.3527802949906451}, {-0.8610661543498108, \
-0.3542126841540585}, {-0.8648224865227367, -0.3556900814898425}, \
{-0.8705895393036028, -0.3579577640183553}, {-0.8746363712973101, \
-0.35954865315737516`}, {-0.8805988995529263, -0.3618924372046213}, \
{-0.8900477443677238, -0.36560711273582164`}, {-0.9039011378513135, \
-0.37105528351136935`}, {-0.9278713189871217, -0.38049030671560147`}, \
{-0.9644131988182442, -0.3948985661976304}, {-1.11462003361377, \
-0.4546521895635499}, {-1.2298713064824431`, -0.5011809705892414}, \
{-1.3615829281221767`, -0.5548378703128364}, {-1.5101864368434237`, \
-0.6157896325066656}, {-1.6820277783248516`, -0.6866206528574392}, \
{-1.7289264823599417`, -0.7060190790144094}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7507456652372622`, -0.7150440151306492}, \
{-1.8755371503696348`, -0.7666607593278393}, {-2.092438984935591, \
-0.8565875854752621}, {-2.2203211571810493`, -0.9096749239714528}, \
{-2.3345981188298697`, -0.9571428474791754}, {-2.4769204375499267`, \
-1.0162911486112196`}, {-2.604282523566262, -1.0692429220746484`}, \
{-2.623088932545373, -1.0770645207269651`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.6448905424956317`, -1.0861318255587744`}, \
{-2.7618080343042277`, -1.1347578922032941`}, {-2.9029956533688073`, \
-1.193493085090326}, {-3.0802811647754345`, -1.2672619873574684`}, \
{-3.2391479279762208`, -1.3333782095126119`}, {-3.413556951193001, \
-1.4059734485530757`}, {-3.516886891852651, -1.448987579932281}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.5386855732101545`, -1.4580619231267045`}, \
{-3.571755968523144, -1.4718284492630216`}, {-3.7166063621835983`, \
-1.5321320071751343`}, {-3.8509695143913123`, -1.588072917822099}, \
{-3.9760909491449485`, -1.6401689549153697`}, {-4.093786643117832, \
-1.6891751016507663`}, {-4.114516534385926, -1.6978067974120843`}, \
{-4.236330141504256, -1.7485303933241747`}, {-4.351769442159406, \
-1.796601003728337}, {-4.410605353320496, -1.8211016418660704`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.432402922865736, -1.8301786554309283`}, \
{-4.5717996221923025`, -1.8882266744110998`}, {-4.772390812991259, \
-1.9717607177138161`}, {-4.957377679066455, -2.0487987937655494`}, \
{-5.15782298956619, -2.13227651257693}, {-5.304297527396829, \
-2.19327883412924}}]}, 
           {Arrowheads[{{0.007588701313934926, 1.}}], 
            ArrowBox[{{-5.3260947311318745`, -2.202356726102}, \
{-5.343808788279571, -2.209734108042397}, {-5.516904524794171, \
-2.2818750435412105`}, {-5.656854249492381, -2.340292482774878}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.35174082089123915`, -0.8539597689465136}, \
{-0.35352290754866245`, -0.8577466257008172}, {-0.35538056228987946`, \
-0.8616918198000215}, {-0.3570694499477377, -0.8652766508772904}, \
{-0.3599404486805267, -0.8713662911204575}, {-0.3620471137535253, \
-0.8758319024539843}, {-0.36506801584100923`, -0.8822351025785259}, \
{-0.3708480592960926, -0.8944955071960295}, {-0.382045947311373, \
-0.9183002744123911}, {-0.40222796308926106`, -0.9614635343598552}, \
{-0.42053955192478637`, -1.0010097017404094`}, {-0.43810090232105753`, \
-1.0394717000075815`}, {-0.4539494439383735, -1.0746864311789783`}, \
{-0.5069780131325041, -1.1949847559075106`}, {-0.5658736549023882, \
-1.332455304839484}, {-0.6307928530005422, -1.4870896950896593`}, \
{-0.7042737319442894, -1.6645740261650177`}, {-0.7271954113096761, \
-1.720462749431476}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.736155142036686, -1.7423087888582378`}, \
{-0.7857201432116936, -1.8631605201041934`}, {-0.8759395083424272, \
-2.084498052379228}, {-0.9287033159834331, -2.214371022064534}, \
{-0.9758067819202016, -2.330488249160057}, {-1.0341609371715998`, \
-2.474531131062812}, {-1.0863495322519734`, -2.6034823771337936`}, \
{-1.0919070765465153`, -2.6172262028974327`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1007586899425126`, -2.639116272646613}, \
{-1.1506571847575375`, -2.7625154184310325`}, {-1.2082738805450726`, \
-2.9050937805960033`}, {-1.2804426311530017`, -3.083783829652979}, \
{-1.3450977977771923`, -3.2439392738567383`}, {-1.4156267690981759`, \
-3.418709117819542}, {-1.4544264036826031`, -3.5148793866409114`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.463260712867751, -3.5367764456799096`}, \
{-1.4796169489896132`, -3.577317642564702}, {-1.5382187374780243`, \
-3.7226022757006714`}, {-1.592582534589929, -3.8574004448359007`}, \
{-1.6432104442542772`, -3.9829523973597984`}, {-1.6908348447654515`, \
-4.1010675885287835`}, {-1.6994217392290596`, -4.122365419337888}, \
{-1.7486891896942565`, -4.244572811892094}, {-1.795379337844022, \
-4.360395102788538}, {-1.8164727860381462`, -4.41272345690422}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8253005138059617`, -4.434623170048312}, \
{-1.8843723818319211`, -4.581167898055288}, {-1.9655030677203909`, \
-4.7824554152288234`}, {-2.040320937042395, -4.968094557299877}, \
{-2.1214042072517176`, -5.1692913574041786`}, {-2.1783616124439256`, \
-5.310631047299315}}]}, 
           {Arrowheads[{{0.007405828236891859, 1.}}], 
            ArrowBox[{{-2.1871871644408483`, -5.332531637366383}, \
{-2.1966343656720433`, -5.355974848795837}, {-2.2666738453457276`, \
-5.5296493285548385`}, {-2.3180604359780532`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3517885096693236, 
             0.8539425014578278}, {-0.3535729670246691, 
             0.8577338771553112}, {-0.3554329854474703, 
             0.8616835485081515}, {-0.3571245317820294, 
             0.8652735274652115}, {-0.3600018378707974, 
             0.8713756974636513}, {-0.362114988652584, 
             0.8758544397748309}, {-0.36515082800719795`, 
             0.8822884523693018}, {-0.37093391678063037`, 
             0.8945537436065378}, {-0.3821074208265282, 
             0.9183035830715156}, {-0.402197943681027, 
             0.9612641096525539}, {-0.4204947526339051, 
             1.0007703629977003`}, {-0.4380549714900478, 
             1.0392209627983218`}, {-0.4539022484995715, 
             1.0744249308755633`}, {-0.5069254864083146, 
             1.1946851662553144`}, {-0.5658156608307829, 
             1.3321152913611565`}, {-0.6307290491704505, 
             1.4867066440980912`}, {-0.7042037141815904, 
             1.6641441477123704`}, {-0.7272902230308992, 
             1.7204250598373811`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7362512764127352, 
             1.7422705567560608`}, {-0.7856435700505852, 
             1.8626804184648738`}, {-0.875856010028892, 
             2.0839638196125008`}, {-0.9286160023852301, 
             2.2138059297318806`}, {-0.9757158520004325, 
             2.3298951824019984`}, {-1.0340658411637, 
             2.4739042832645683`}, {-1.086250523900626, 
             2.60282492381802}, {-1.0920514640236039`, 
             2.6171683480682657`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.1009043080068421`, 
             2.6390579201688027`}, {-1.1505536795130011`, 
             2.7618211247828386`}, {-1.2081661702580124`, 
             2.9043660915351093`}, {-1.2803298053001437`, 
             3.083014737000146}, {-1.3449802277874157`, 
             3.243132723071883}, {-1.415505864198102, 
             3.417866296810243}, {-1.4546203729801215`, 
             3.5148015064455764`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.4634558984422745`, 
             3.5366980747416314`}, {-1.4794927672636273`, 
             3.576441312979786}, {-1.5380913616992764`, 
             3.7216947963127476`}, {-1.5924520722203328`, 
             3.8564637715413626`}, {-1.6430770028923947`, 
             3.9819882850032684`}, {-1.690698530254075, 
             4.1000774941228}, {-1.6992902981284153`, 
             4.121384010952063}, {-1.7485550952719882`, 
             4.243565324149522}, {-1.7952426723853179`, 
             4.359362762910873}, {-1.8167162415637033`, 4.412625620312019}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8255451805802503`, 
             4.4345248451653845`}, {-1.8842307252491342`, 
             4.5800879684282645`}, {-1.9653567097305158`, 
             4.78133173200319}, {-2.040170138998445, 
             4.96693027033632}, {-2.1212482868372957`, 
             5.168082299590564}, {-2.178654596371658, 5.310513247403848}}]}, 
           {Arrowheads[{{0.007408668889977043, 1.}}], 
            ArrowBox[{{-2.1874813582537387`, 
             5.332413349869664}, {-2.1964736304584584`, 
             5.354724100438756}, {-2.2665131033465915`, 
             5.528374128585012}, {-2.318419978762305, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.8522024703391508, 
             0.35448806527638504`}, {-0.856007498139546, 
             0.3560012187529738}, {-0.8596430057371319, 
             0.3574466825219348}, {-0.8633938897100278, 
             0.35893773669881196`}, {-0.8691522000071592, 
             0.36122622988566006`}, {-0.8732032431530682, 
             0.36283582860271285`}, {-0.8791790211465539, 
             0.3652099774060824}, {-0.8886725457574636, 
             0.3689821995178079}, {-0.9024268903068765, 
             0.37444935974442517`}, {-0.926112806789275, 
             0.38387227820737346`}, {-0.9621835598293537, 
             0.39824655368419803`}, {-1.111101819087222, 
             0.4581187693928726}, {-1.2259553302316288`, 
             0.5049780697864129}, {-1.357222086354962, 
             0.559023285168186}, {-1.5053313257950791`, 
             0.6204222702954768}, {-1.6766241543829237`, 
             0.6917852567178555}, {-1.726180082775445, 0.7125034145378656}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7479648506888354`, 
             0.7216111091032251}, {-1.8695275166861318`, 
             0.7724335753721293}, {-2.0857663355304843`, 
             0.8630522463367377}, {-2.213267797693837, 
             0.9165528279915796}, {-2.3271996019267926`, 
             0.9643883981836883}, {-2.4691026005509866`, 
             1.0239994847196707`}, {-2.596084632937155, 
             1.0773636980914036`}, {-2.6189181985728913`, 
             1.0869628306264858`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.640684957393322, 
             1.0961134821764773`}, {-2.7531502348733774`, 
             1.1433933998795727`}, {-2.8939208803907515`, 
             1.2025881630402686`}, {-3.0706876323299106`, 
             1.2769364114531738`}, {-3.2290850512914573`, 
             1.3435700692861412`}, {-3.4030403153116873`, 
             1.4167593946221817`}, {-3.5112850074872224`, 
             1.4623067157855978`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.5330487684279137`, 
             1.4714644951590377`}, {-3.5608198032065883`, 
             1.4831500218549192`}, {-3.705279941440788, 
             1.5439415070330698`}, {-3.839277156478914, 
             1.6003334062053503`}, {-3.9640545138057166`, 
             1.6528480554735834`}, {-4.081424310606385, 
             1.7022470511215833`}, {-4.102181775048596, 
             1.7109837069655953`}, {-4.223665947121994, 
             1.7621172412703987`}, {-4.338791135942405, 
             1.8105755466857818`}, {-4.4035708388622625`, 
             1.8378430769719944`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.425333464082394, 
             1.8470035549542967`}, {-4.558219771540571, 
             1.9029389984638416`}, {-4.758257722016356, 
             1.9871436374938312`}, {-4.942730998811118, 
             2.0647987385773305`}, {-5.14260621087585, 
             2.1489393396189502`}, {-5.295830032184672, 2.213442726034189}}]}, 
           {Arrowheads[{{0.00779612185235864, 1.}}], 
            ArrowBox[{{-5.31759228498163, 
             2.222604088735091}, {-5.328061239135082, 
             2.227011255906327}, {-5.50076492359109, 
             2.299758933484596}, {-5.656854249492381, 
             2.3655936165457154`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.36022862149667323`, 0.8513444703242872}, {
             0.3615257659533996, 0.8552386293359704}, {0.3630006579220257, 
             0.8596718621819829}, {0.36437098561340564`, 
             0.8637959183738954}, {0.36672596314983186`, 
             0.8708951059719104}, {0.3684553008751017, 0.8761130847746719}, {
             0.3709957563054567, 0.8837715097594725}, {0.3753411196554192, 
             0.8968313112146223}, {0.38361605594199355`, 
             0.9215075495501077}, {0.39761052474294895`, 0.962652674783028}, {
             0.4155919969479443, 1.0141200833329864`}, {0.4340130408578747, 
             1.064980082697879}, {0.45162004224851643`, 
             1.1121001351548552`}, {0.5143990260176644, 
             1.2741421026521906`}, {0.5838503615734845, 
             1.4463551995232407`}, {0.6607794162026265, 
             1.6331145348701868`}, {0.701837652363809, 
             1.7315950736116719`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.7109238413578286, 1.7533888200289613`}, {
             0.7459474550952253, 1.8373949701225065`}, {0.8401757774608158, 
             2.061788107428021}, {0.8951497835545708, 2.1922268170934456`}, {
             0.9443688686205752, 2.308820243160917}, {1.005142582975419, 
             2.4525822870834384`}, {1.0595859117082649`, 2.58123638288254}, {
             1.0776062215548354`, 2.6237816552442244`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.086815234246688, 2.6455237871216983`}, {
             1.1265391839945196`, 2.739310535279362}, {1.186579475261395, 
             2.8809689983696836`}, {1.2616630945839666`, 
             3.0580174031613576`}, {1.32895951380348, 3.2166334262527574`}, {
             1.4023343622399111`, 3.389510814039438}, {1.455619325805837, 
             3.5150210107185993`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.4648465937684594`, 3.5367554014227833`}, {
             1.4689141485697879`, 3.5463363332458178`}, {1.5298902173041453`, 
             3.6899302850654148`}, {1.5864539129540194`, 3.823112970691748}, {
             1.6391269974694285`, 3.9471177042411956`}, {1.6886708398273713`, 
             4.06374375632857}, {1.6981223486613681`, 4.085991366743771}, {
             1.7494277087078707`, 4.206746578436927}, {1.798042120697995, 
             4.32116029651033}, {1.834115890080963, 4.4060551897197815`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8433500777464977`, 4.427786641385371}, {
             1.8906900830151403`, 4.539195145696367}, {1.9751298185112005`, 
             4.737893337886867}, {2.052981011219606, 4.921073829180872}, {
             2.1372648340311313`, 5.119378142235435}, {2.212771640285972, 
             5.297021735848954}}]}, 
           {Arrowheads[{{0.007780819115167806, 1.}}], 
            ArrowBox[{{2.222009806725038, 5.31875149638116}, {
             2.2883699997315996`, 5.474828255367304}, {2.3568419075140796`, 
             5.635774732528029}, {2.365883213046264, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAs9KwrQCZ6z/hA8O8hKTVPzOkgWeM
t+s/kJdWX2bA1T9Qs00yIdvrP12Mqxbn4NU/jevDFEoD7D9kj2LengXWP4bx
pBp5NOw/0no4aKIy1j/9nLa5dl7sPzJ/gaARWdY/HDDZw7mc7D8DJkXP/JHW
P9ZZBCvI9+w/Ph3z6xnl1j9T1vpdr43tPwlakGt0bdc/JrVJLPqj7j8CFf8h
+mfYP6QuSvqXnO8/9N6FbLlE2T/gAX+Q91fwP6fj4q8PNdo/+IczVfbj8D89
rJGiOCXbP2wycqB3b/E/5lhVeEER3D+MQoXPY4LzPwOSumwLgt8/wvS6GpBf
9T/9nHUyg0XhP91ThSCnB/c/YAtJwpyb4j8kFcYwcuP5P5b+X2u25uQ/f+nU
Us/B+z+/FrHJq2TmP5K5oQQ=
             "]]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.756745830161908, 0.7085437431321786}, {
             1.7676157911355495`, 0.7128834043469386}, {1.9474311036782836`, 
             0.7844493521076584}, {2.1003276223373524`, 0.8451928759878496}, {
             2.297243342006316, 0.923325782669254}, {2.465773300640521, 
             0.9901384069381213}, {2.6240758070436003`, 1.052859770343413}, {
             2.634586392673517, 1.0570226873678659`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.656539209078107, 1.065717517167381}, {
             2.765443606159156, 1.1088511716191427`}, {2.8936246355083943`, 
             1.159606904691001}, {3.0122588083327604`, 1.2065751303622776`}, {
             3.1235764000424, 1.2506424264209983`}, {3.3242618401175017`, 
             1.3300742297007735`}, {3.502139138625467, 1.4004657931858684`}, {
             3.5347134617976526`, 1.4133551370533601`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.556669123515941, 1.422042779532667}, {
             3.663666478458065, 1.4643805955318254`}, {3.811689575863339, 
             1.5229468440800775`}, {3.9490541470893348`, 
             1.5772927461720567`}, {4.077013161982088, 1.6279147667846159`}, {
             4.197396613290575, 1.6755379411828064`}, {4.219251115769701, 
             1.6841833050372832`}, {4.343752498260161, 1.7334327389583992`}, {
             4.434917124662604, 1.76949405488378}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.456873745610429, 1.7781792727791297`}, {
             4.4617453055193135`, 1.780106279644141}, {4.6866436154041375`, 
             1.8690657708511187`}, {4.891667134220293, 1.9501605179327661`}, {
             5.080724913642184, 2.024937923098293}, {5.285562597879008, 
             2.1059547562636802`}, {5.335147312600464, 
             2.125565920063439}}]}, 
           {Arrowheads[{{0.006827527547796901, 1.}}], 
            ArrowBox[{{5.357104341638624, 2.134250106217223}, {
             5.475594753439508, 2.181114041758281}, {5.650497129513148, 
             2.250483661977475}, {5.656854249492381, 2.25302126709601}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAARHRW6VKc6z/5YWnj3JrVv1JKVRrE
uus/RFGra5a21b+FIV73Od7rP8YNv1jo1tW/5Dlx9DoG7D/Xw1ewZvvVvySP
PKEdN+w/jTA7sAoo1r/jrsg40GDsP6867pYfTta/vsbbtdee7D/x0aB0tIbW
v+yG30OI+ew/wJpfk03Z1r+qbKVsvI7tP946HKa6YNe/7ZZZxUek7j9w9pDF
DFrYv11S9HeHnO8/sc1D4QI22b8c3ZK83lfwP2FNVd68Jdq/PMbZ5trj8D9W
4Qq3YBXbv8xoZLteb/E/rrsie+0A3L8N/iVAboLzP8zu03YJcN+/hHwP/stf
9T9uCaqMzzvhv3xuBawSCPc/vacLjU2R4r/NkXF3LuT5P2KFxhta2+S/X2lN
KqfE+z/rwXjLI1rmv9O4rjg=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.757446656990582, -0.7072413853547411}, {
             1.7678563088740111`, -0.7113880291232377}, {
             1.9477653877165304`, -0.782831808592759}, {
             2.1007348371036025`, -0.8434688811376867}, {
             2.297679600380558, -0.9214391337259239}, {
             2.4662359662814004`, -0.9881132812377799}, {
             2.6245562939328884`, -1.050701886574194}, {
             2.6355538343445435`, -1.0550479624808446`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.6575132814431335`, -1.0637260323388478`}, {
             2.765941246207856, -1.1065752647701033`}, {
             2.894138649233222, -1.1572243356832919`}, {
             3.0127884503896922`, -1.2040940463369645`}, {
             3.1241209781841617`, -1.2480690196806101`}, {
             3.3248342136871005`, -1.3273347544378211`}, {
             3.5027369591722852`, -1.3975794714927707`}, {
             3.5359526110899946`, -1.410693288806151}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.5579148931367235`, -1.4193641815304383`}, {
             3.6642878180699636`, -1.4613611023833055`}, {
             3.8123327839778627`, -1.5198054493673154`}, {
             3.94971785049371, -1.5740383147026906`}, {
             4.077696123961352, -1.6245551106941392`}, {
             4.198097801151721, -1.6720793371272713`}, {
             4.219965627894929, -1.6807106915239618`}, {
             4.344485822634795, -1.7298577850608008`}, {
             4.436427655059438, -1.7661454777463612`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.45839089261125, -1.7748139499057924`}, {
             4.462496548996075, -1.7764343743984972`}, {
             4.68742915306236, -1.865209133206793}, {
             4.892484167265691, -1.9461355733152106`}, {
             5.081571146088551, -2.020757846264823}, {
             5.2864409926713956`, -2.101606812132987}, {
             5.336929102109039, -2.1215307733194497`}}]}, 
           {Arrowheads[{{0.00678470087616552, 1.}}], 
            ArrowBox[{{5.358892745997567, -2.1301982158761725`}, {
             5.4765030735006945`, -2.1766104033476315`}, {
             5.651444336112939, -2.2458379823619024`}, {
             5.656854249492381, -2.247992382361518}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0618553319017243`, 0.7064407127461073}, {
             1.1628028675233872`, 0.7744773889614412}, {1.3350719976204135`, 
             0.8892511617633815}, {1.4767267489137332`, 0.9827850158600874}, {
             1.6547767570975196`, 1.0996945112645866`}, {1.8028649338066116`, 
             1.1966533505393924`}, {1.8497350760852143`, 
             1.2272755771673816`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.8695021612282876`, 1.2401902416338961`}, {
             1.9935394682136527`, 1.3212290083236518`}, {2.154214763181606, 
             1.4260798837953086`}, {2.2943887823848415`, 1.517490395522194}, {
             2.4193281734643493`, 1.598930141440451}, {2.5331952361859833`, 
             1.6731331465067665`}, {2.6382015951529207`, 
             1.7415492930156637`}, {2.660601238409342, 
             1.7561398790424265`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6803861157874813`, 1.7690272697972746`}, {
             2.8258518551432856`, 1.8637801352657493`}, {3.0000995418342367`, 
             1.9772532154868732`}, {3.1561536794544014`, 2.078862633908017}, {
             3.2979821656636603`, 2.1711992952078605`}, {3.429462177417762, 
             2.256792711656034}, {3.4718643307309582`, 
             2.284395263239957}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.4916528753163085`, 2.297277022301893}, {
             3.552971821478841, 2.3371938482711134`}, {3.6685110978468973`, 
             2.4124027050530987`}, {3.7760800065219313`, 2.48241928200199}, {
             3.9742687849279754`, 2.6114133230898267`}, {4.154500220832016, 
             2.728713698223961}, {4.283230685782926, 2.812492035831859}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.303020734387354, 2.825371484172939}, {
             4.319870625471948, 2.8363374654150624`}, {4.473476310085664, 
             2.936301682673801}, {4.616687855432994, 3.0294989704476487`}, {
             4.751509100000365, 3.1172343197682357`}, {4.763943186507643, 
             3.125325755866543}, {4.902860102393668, 3.2157237701104306`}, {
             5.034590817878262, 3.3014441810594892`}, {5.094641540605608, 
             3.340520433754269}}]}, 
           {Arrowheads[{{0.013719462914452548`, 1.}}], 
            ArrowBox[{{5.114432344735627, 3.3533987211102567`}, {
             5.1632568340068135`, 3.3851698304958506`}, {5.285793451423281, 
             3.464905956906817}, {5.4025265781637515`, 3.540911355368559}, {
             5.5137821222643115`, 3.6134448209572483`}, {5.656854249492381, 
             3.707707326122043}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0625579839066541`, -0.7024996692746267}, {
             1.163915832221538, -0.7704050205387633}, {
             1.3368703997532179`, -0.8849368419163699}, {
             1.479048890656313, -0.9782423924863097}, {
             1.6574103955312671`, -1.0946369063425083`}, {
             1.8057591197906113`, -1.191169115810948}, {
             1.851893636164316, -1.2211252994575301`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.871697088620984, -1.2339841284918025`}, {
             1.9966020244349523`, -1.3150877248815205`}, {
             2.1574383548673364`, -1.4193978573365982`}, {
             2.297762923948815, -1.5103433562937605`}, {
             2.4228426054511734`, -1.5913726902647964`}, {
             2.53684092583094, -1.665203906122178}, {
             2.6419705793924035`, -1.7332786793557695`}, {
             2.6642482322112806`, -1.7477004538569725`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.6840693877456245`, -1.7605319777968447`}, {
             2.8298467079114924`, -1.8549031243406309`}, {
             3.0042605200170636`, -1.9677849427762404`}, {
             3.1604706790753716`, -2.0688695440220504`}, {
             3.3024458278600517`, -2.160732386010268}, {
             3.4340647088406024`, -2.2458884379378183`}, {
             3.476998476176776, -2.2736648982847822`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.496823288001648, -2.2864907725023387`}, {
             3.557706557024591, -2.325879855099441}, {
             3.673371372412017, -2.400706637495137}, {
             3.7810591550028816`, -2.4703687851249057`}, {
             3.979470351413277, -2.598712003100155}, {
             4.159906875874131, -2.7154223360386824`}, {
             4.289851820961223, -2.799469998293445}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.309678136437736, -2.8122935480345252`}, {
             4.325467650865871, -2.822506117480249}, {
             4.479251598868926, -2.921969680964616}, {
             4.622630573657267, -3.0147009758736782`}, {
             4.757610279170733, -3.1019981669258607`}, {
             4.77008027215304, -3.110062963155858}, {
             4.909158893455183, -3.2000084769418025`}, {
             5.041043640662672, -3.2853002331347474`}, {
             5.1027497251854355`, -3.3252062074712274`}}]}, 
           {Arrowheads[{{0.013488732411138463`, 1.}}], 
            ArrowBox[{{5.122576798948457, -3.3380285847598525`}, {
             5.169860372080547, -3.3686073691785943`}, {
             5.2925410719191905`, -3.447945264924245}, {
             5.409383984303377, -3.5235564422863423`}, {
             5.520687353357879, -3.5956834231795276`}, {
             5.656854249492381, -3.684876769850143}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6852328042449546, 1.0419790007675682`}, {
             0.7830201089063923, 1.1937104626677078`}, {0.8645963349456144, 
             1.317562500927385}, {0.9347411815508504, 1.4230077152905813`}, {
             0.9964382692956415, 1.5152331592099693`}, {1.103306932139585, 
             1.674370466205433}, {1.193597545822501, 1.8083342348717584`}, {
             1.207494744104848, 1.8288941919164086`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.22071757849881, 1.848456473581031}, {
             1.3238230548167533`, 2.0009939938132812`}, {1.4331264249158309`, 
             2.162411894531298}, {1.5282818778609641`, 2.3027952358620407`}, {
             1.612983466296919, 2.4276749224140204`}, {1.690122136353203, 
             2.5413608351113735`}, {1.750517814962106, 
             2.630347298687001}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.7637784367543359`, 2.649883985213557}, {
             1.888207800062105, 2.8331490301560236`}, {2.007223296434743, 
             3.008378560800185}, {2.1136764034386246`, 3.165077327364511}, {
             2.2103367342344313`, 3.307338756490203}, {2.2944789166886097`, 
             3.4311642963659974`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.3077501264651796`, 3.450693792117055}, {
             2.3839907532334914`, 3.5628842677072967`}, {2.4626304199218754`, 
             3.6785968348334652`}, {2.5358118580694944`, 3.786269276304714}, {
             2.670588951063131, 3.984553027489419}, {2.7931109345350906`, 
             4.164794766468375}, {2.8386757358102863`, 
             4.231821141681678}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.851950379484155, 4.25134830349972}, {
             2.905497644018639, 4.330116978966062}, {3.0098689150470417`, 
             4.483642150706963}, {3.107161027706766, 4.62674890688711}, {
             3.1987423461814646`, 4.7614519812495155`}, {3.2068341821865793`, 
             4.773353755058711}, {3.301227532148545, 4.912187670419482}, {
             3.382969756291335, 5.032411913122007}}]}, 
           {Arrowheads[{{0.015505493307857027`, 1.}}], 
            ArrowBox[{{3.3962459053721217`, 5.051938051473439}, {
             3.478144855051816, 5.172391895348531}, {3.5613896528625046`, 
             5.294823179923991}, {3.6407517195607744`, 5.411471291975377}, {
             3.7165194149469634`, 5.522689721289862}, {3.808842869875938, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6875645903501489, -1.037288837384483}, {
             0.7856985241059056, -1.1884164452951063`}, {
             0.8676023748860079, -1.3118239908216218`}, {
             0.9380384103251872, -1.416901949542317}, {
             0.9999938183234314, -1.50880832253835}, {
             1.107308924971253, -1.66739276446254}, {
             1.197974021889453, -1.8008867441621108`}, {
             1.2125981257144622`, -1.8223571533332072`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.22589043909015, -1.8418722915202321`}, {
             1.3288813345931882`, -1.993078594060721}, {
             1.4387327589937458`, -2.1540690396606106`}, {
             1.5343515836931934`, -2.2940607400448916`}, {
             1.6194568106678464`, -2.4185793467362844`}, {
             1.6969578280717514`, -2.531929039789936}, {
             1.7584711731499054`, -2.621871851980433}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7718014365621804`, -2.641361087151386}, {
             1.8959547529198375`, -2.822826963088048}, {
             2.0155864835052593`, -2.9976227592825526`}, {
             2.1225781763616776`, -3.1539155181804253`}, {
             2.219718893022001, -3.295795917194623}, {
             2.305277961678611, -3.4207484884716113`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.318618568845829, -3.4402306447600104`}, {
             2.394222517564157, -3.550637763028912}, {
             2.473241983459729, -3.6660246460423562`}, {
             2.546773218438298, -3.7733888357866663`}, {
             2.6821881919931574`, -3.971095913766699}, {
             2.8052846345774674`, -4.150805775267822}, {
             2.8523175394940625`, -4.219465749007111}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.8656614842188635`, -4.238945619451178}, {
             2.9181940506572768`, -4.315634155668856}, {
             3.023047944698633, -4.468696790348621}, {
             3.1207875546751493`, -4.611369042010606}, {
             3.212788442927184, -4.745660807787307}, {
             3.220940702529113, -4.757560330589253}, {
             3.3157709294669395`, -4.895976943540493}, {
             3.399452178516298, -5.018117895350217}}]}, 
           {Arrowheads[{{0.015908220056906522`, 1.}}], 
            ArrowBox[{{3.4127975946859386`, -5.037596757755236}, {
             3.493503719974316, -5.1553943721134745`}, {
             3.577130843082344, -5.277453534386135}, {
             3.6569080969128227`, -5.3938454663800455`}, {
             3.7331770299047324`, -5.5050225794275205`}, {
             3.8055026313498357`, -5.609966666887792}, {
             3.8381138465759004`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0280310893596865`, -0.6773072779467818}, \
{-1.091431904539491, -0.7186615820294896}, {-1.2848142106901377`, \
-0.8460338757042506}, {-1.370471875503193, -0.9029363115219383}, \
{-1.4454395774786193`, -0.9528906382784955}, {-1.51256142468584, \
-0.9977117349016246}, {-1.6319294554757895`, -1.0775528262265652`}, \
{-1.7352072659034146`, -1.1467564472805627`}, {-1.8146276703633881`, \
-1.2000819469750466`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8342308035149044`, -1.213244142231921}, \
{-1.9274502439232484`, -1.275834773377855}, {-2.0862673112933834`, \
-1.3826165870207188`}, {-2.223438131046997, -1.4749145845600038`}, \
{-2.344976310664821, -1.5567337311635212`}, {-2.4554001294878622`, \
-1.6310918841174964`}, {-2.5570382115288384`, -1.6995474122953838`}, \
{-2.6178351780263753`, -1.7405068185241437`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.6374176712144397`, -1.7536997019798395`}, \
{-2.7382121546230125`, -1.8216057576498539`}, {-2.910387612991829, \
-1.9376320942788503`}, {-3.064057244418317, -2.0412046965903676`}, \
{-3.2033944811398842`, -2.135128165938385}, {-3.3323893561871762`, \
-2.222086293247533}, {-3.420616536838786, -2.281564713078828}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.4401950128664027`, -2.2947635573377854`}, \
{-3.4534723410268993`, -2.3037144780487884`}, {-3.5666434356590524`, \
-2.3800127203421515`}, {-3.671902640083636, -2.4509810201276223`}, \
{-3.865676152552783, -2.5816347885573174`}, {-4.041783652677027, \
-2.700382779720304}, {-4.203293654920751, -2.809292196516489}, \
{-4.223292853882266, -2.8227784356881567`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.242869621878043, -2.8359798131986933`}, \
{-4.353274673748337, -2.9104302418457784`}, {-4.493077283179741, \
-3.004707012101883}, {-4.62467430095281, -3.093451961785187}, \
{-4.636581238008342, -3.101481707314059}, {-4.772237165107459, \
-3.1929662359067628`}, {-4.90086761395903, -3.27971404463011}, \
{-5.025927334819417, -3.364054201288928}}]}, 
           {Arrowheads[{{0.015627895047233012`, 1.}}], 
            ArrowBox[{{-5.045503492301204, -3.377256484106078}, \
{-5.146150558907038, -3.445133516114726}, {-5.260426229677037, \
-3.5222025312152447`}, {-5.369948249794159, -3.596066250994265}, \
{-5.474530966350963, -3.666703608919936}, {-5.573988726440011, \
-3.7340935384604084`}, {-5.656854249492381, -3.7906681482613678`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7091016844542418, -1.0451672323619765`}, \
{-0.8473731905563764, -1.2478495645849834`}, {-0.912386021646394, \
-1.344681179559247}, {-0.9682603034165883, -1.4283735410704825`}, \
{-1.017670824558254, -1.5026584088514974`}, {-1.1046842061966784`, \
-1.6338353887134314`}, {-1.1791714247166833`, -1.7464535214651098`}, \
{-1.2343338039352618`, -1.830115039692356}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.2473313854231511`, -1.8498277028508903`}, \
{-1.30523426805829, -1.9376455805351476`}, {-1.4098414089746163`, \
-2.0966096647946815`}, {-1.5004030260926207`, -2.2343818471072474`}, \
{-1.5807624891173833`, -2.35672073015751}, {-1.6538342517340285`, \
-2.4680116753991945`}, {-1.7211289958700131`, -2.570534339688302}, \
{-1.7661026210928368`, -2.6390792144682442`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.7790556915512612`, -2.6588211540648303`}, \
{-1.8411733582024798`, -2.753495480653677}, {-1.9540924949497813`, \
-2.9256642393763443`}, {-2.055025023763216, -3.0795950418191484`}, \
{-2.146642113237825, -3.219343521821922}, {-2.2315161327931357`, \
-3.3488205654293814`}, {-2.2969501913315464`, -3.448648483475509}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.309894274594083, -3.4683963168206806`}, \
{-2.311217227786812, -3.470414648953099}, {-2.385745398218854, \
-3.584125772393075}, {-2.4551006440892613`, -3.689953935749309}, \
{-2.5828401198061868`, -3.8848861702708644`}, {-2.6989834125986043`, \
-4.062136140578076}, {-2.8055373187190797`, -4.224762075174324}, \
{-2.8275592105185954`, -4.258374134961635}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.840499283847909, -4.278124596109874}, \
{-2.90450863442018, -4.375822202562986}, {-2.996782846536085, \
-4.516666491080593}, {-3.08365397309299, -4.6492678579332205`}, \
{-3.091581325556805, -4.661368478305305}, {-3.1810889011803054`, \
-4.798000143149359}, {-3.265971724027416, -4.927575179941092}, \
{-3.348882520490225, -5.054141000155272}, {-3.3580690464736724`, \
-5.068164773349507}}]}, 
           {Arrowheads[{{0.014418330936513308`, 1.}}], 
            ArrowBox[{{-3.3710075965596498`, -5.08791623240976}, \
{-3.4278492641844296`, -5.174688387214346}, {-3.5032778587543074`, \
-5.289836558186509}, {-3.5755742078441357`, -5.400204730139957}, \
{-3.709930229846799, -5.604335363173839}, {-3.745064609570092, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0471417364812092`, 
             0.6836856172694021}, {-1.1149797043728464`, 
             0.7276290437968307}, {-1.320345677136347, 
             0.8619271388693484}, {-1.4168033131816167`, 
             0.925529187286932}, {-1.5003861701203403`, 
             0.9808078365291181}, {-1.5747133619776097`, 
             1.0300638147422514`}, {-1.7061821821323657`, 
             1.11731925019294}, {-1.8192645861331218`, 
             1.1924931324801624`}, {-1.8357275374384432`, 
             1.2034565766612555`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.8553804333806465`, 
             1.2165443531882705`}, {-2.0161593731913414`, 
             1.3236145193704487`}, {-2.179585974970432, 
             1.4325721583755602`}, {-2.321109790093929, 
             1.5269873426707028`}, {-2.4467231181826494`, 
             1.610822654843778}, {-2.560968373785553, 
             1.687089300276264}, {-2.6411267687698743`, 
             1.7406096929813195`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.6607639188595273`, 
             1.7537210830560825`}, {-2.6662003467396067`, 
             1.7573508931977584`}, {-2.8539685197421996`, 
             1.8827500549944411`}, {-3.030889827049087, 
             2.000931695243107}, {-3.189046169564372, 
             2.10659346861987}, {-3.3326192441428693`, 
             2.20252196470508}, {-3.4461241169254317`, 
             2.278365051318483}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.465756645851192, 
             2.2914833599485704`}, {-3.590551728352048, 
             2.3748737437476053`}, {-3.707368544418292, 
             2.45293638290279}, {-3.8160857431256385`, 
             2.5255901884805905`}, {-4.0163396842562475`, 
             2.6594227356693025`}, {-4.19843194753648, 
             2.7811228220790074`}, {-4.251020607768433, 
             2.8162713652337037`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.270651551020794, 
             2.82939204663212}, {-4.365504220737697, 
             2.8927884735457865`}, {-4.5206981916312605`, 
             2.9965177159057217`}, {-4.665400317455491, 
             3.0932366405500376`}, {-4.801636820109762, 
             3.1842987211105553`}, {-4.812772977853084, 
             3.1917423247679486`}, {-4.953111162382031, 
             3.285548266214347}, {-5.055875616078456, 3.354239747192701}}]}, 
           {Arrowheads[{{0.014824437100834564`, 1.}}], 
            ArrowBox[{{-5.075505934846843, 
             3.3673613628854295`}, {-5.086204297755103, 
             3.3745125359397146`}, {-5.216207830252976, 
             3.4614120223322526`}, {-5.340032157000456, 
             3.544181942059131}, {-5.4576686084343216`, 
             3.6229214580016413`}, {-5.569108514991352, 
             3.6977297330410743`}, {-5.656854249492381, 
             3.7573961030900147`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.708813895593676, 
             1.0451594629114804`}, {-0.8469960865321624, 
             1.247785533289639}, {-0.9119443460963179, 
             1.3445576286632315`}, {-0.9677666599561151, 
             1.4282041335501994`}, {-1.017133307748384, 
             1.5024516644885426`}, {-1.104072242305004, 
             1.6335673432432165`}, {-1.1784982665000336`, 
             1.7461370778631045`}, {-1.2339045786242455`, 
             1.8302018618178326`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.2468985701572315`, 
             1.8499168915509285`}, {-1.3045009749766363`, 
             1.9373136795840382`}, {-1.4090558971581373`, 
             2.0962619057145457`}, {-1.499571157542319, 
             2.234018841908825}, {-1.5798888131271382`, 
             2.356343302132821}, {-1.6529221952670101`, 
             2.4676206463018446`}, {-1.72018135606486, 
             2.5701304676645247`}, {-1.7655233160151034`, 
             2.6392646703932665`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7784727257526938`, 
             2.6590090113745237`}, {-1.8401616582720373`, 
             2.75306791777363}, {-1.9530237446713532`, 
             2.925219383832184}, {-2.0539046482088583`, 
             3.0791338249153637`}, {-2.145474448591982, 
             3.2188668369544815`}, {-2.2303044044875198`, 
             3.348329183232121}, {-2.2962201306365317`, 
             3.4489327721937024`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.3091605389661516`, 
             3.4686830138529547`}, {-2.3099639715494305`, 
             3.46990924932192}, {-2.3844531497777144`, 
             3.5836070352238774`}, {-2.4537719391723716`, 
             3.6894225409379944`}, {-2.581443975274653, 
             3.8843310395485577`}, {-2.6975257036701223`, 
             4.0615590728994615`}, {-2.804022937567641, 
             4.22416460695816}, {-2.826678142620996, 4.258757357790627}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.8396145344931067`, 
             4.278510230459364}, {-2.9029414901760697`, 
             4.375205607692108}, {-2.995166406732805, 
             4.516031916470014}, {-3.0819910543987374`, 
             4.648616256625936}, {-3.089920241522705, 
             4.660724602068264}, {-3.179380195305721, 
             4.797339142363523}, {-3.2642178021957475`, 
             4.926897860957913}, {-3.3470844117377347`, 
             5.053447711266821}, {-3.3570368980423373`, 
             5.0686469518786845`}}]}, 
           {Arrowheads[{{0.014404332520126946`, 1.}}], 
            ArrowBox[{{-3.3699717639914666`, 
             5.088400823808366}, {-3.4260090265836434`, 
             5.1739798250047615`}, {-3.5013973426454563`, 
             5.289113353505955}, {-3.573655055835157, 
             5.399467448104618}, {-3.707952049236285, 
             5.60359967030576}, {-3.743562478546208, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.24078601219888585`, -1.2429164713518575`}, {
             0.26214252430892504`, -1.3585574471060158`}, {
             0.2812293335729399, -1.4576342248092928`}, {
             0.2984471058562482, -1.544826775124042}, {
             0.32887366522775424`, -1.6962334839212312`}, {
             0.3551129434108108, -1.8246252784854644`}, {
             0.3953542569099926, -2.0188639085484756`}, {
             0.42671196977106796`, -2.1688875484065324`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4315533614240741, -2.191997870851393}, {
             0.4590523745173042, -2.322910309718336}, {
             0.48556491368624827`, -2.4487245869952443`}, {
             0.5320703010453192, -2.6688624387848217`}, {
             0.5720001487944901, -2.8574023857658943`}, {
             0.6093981590266451, -3.0336846609483423`}, {
             0.6268920655588675, -3.116056465880746}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.6317973148135395, -3.1391533215776954`}, {
             0.6428955640821473, -3.191410535948945}, {
             0.673343411571537, -3.3346681466133257`}, {
             0.7015728395057705, -3.467425499445497}, {
             0.728093785590781, -3.5921110744243827`}, {
             0.7760102322131329, -3.817266890822296}, {
             0.8185846180505936, -4.017208871652253}, {
             0.8283295272313864, -4.062959041287157}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.8332485936491412, -4.086052958211617}, {
             0.8573088097151638, -4.199010292759441}, {
             0.8928462435893885, -4.3658051129927475`}, {
             0.9258603560558126, -4.52072729120106}, {
             0.9566448730293533, -4.665161866356578}, {
             0.9856292482988468, -4.80113333214186}, {
             0.9896676041547203, -4.820076805313304}, {
             1.0195766967596833`, -4.960361213784825}, {
             1.0301154698543944`, -5.009787428062512}}]}, 
           {Arrowheads[{{0.01351023614308345, 1.}}], 
            ArrowBox[{{1.0350393883923474`, -5.032880310939445}, {
             1.0479414370897147`, -5.093390146174181}, {
             1.075647424004099, -5.223325165681089}, {
             1.1020359040871892`, -5.3470723594231035`}, {
             1.1514021752103636`, -5.578551015645512}, {
             1.1681172314384753`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.2164287319333544`, -0.23696613218782944`}, \
{-1.2915384947674957`, -0.2514930811339641}, {-1.356955600315863, \
-0.26420543108906497`}, {-1.4154093852378904`, -0.27560349056802413`}, \
{-1.541151988525719, -0.30021555411760353`}, {-1.6468095382694472`, \
-0.32097534627684565`}, {-1.7391296703557952`, -0.33915779124290496`}, \
{-1.8217353080335668`, -0.35545359852761427`}, {-2.0208135662422766`, \
-0.39479698275475206`}, {-2.1431944612231395`, -0.4190254683996238}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.1663568967218887`, -0.4236110757860502}, \
{-2.185108063632565, -0.4273233576613458}, {-2.3269991650474715`, \
-0.45544215379666564`}, {-2.4527503530703507`, -0.4803783975219399}, \
{-2.6722731837752343`, -0.5239312893953392}, {-2.8599516875986652`, \
-0.5611851046374673}, {-3.037637274116734, -0.5964676442554061}, \
{-3.0927782258297047`, -0.6074192457961382}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.115937855351361, -0.6120190038067075}, \
{-3.1963899083697815`, -0.6279976693977175}, {-3.3404586657191415`, \
-0.6566157503888774}, {-3.473914071796405, -0.6831281080785097}, \
{-3.5992363838580363`, -0.7080262332751713}, {-3.8254817259344023`, \
-0.7529797861895836}, {-4.026354890598749, -0.7928965419949957}, \
{-4.042311464127291, -0.7960675773586159}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.065470571090975, -0.800669965649582}, \
{-4.209016076501583, -0.8291966335542893}, {-4.376617983887509, \
-0.8625058212369203}, {-4.532313313001131, -0.8934498654123446}, \
{-4.677492205785851, -0.9223047860671735}, {-4.814186041413867, \
-0.9494739465955986}, {-4.832139430983913, -0.9530423948710297}, \
{-4.973120392916205, -0.9810646469448052}, {-4.991831213758673, \
-0.9847837916588357}}]}, 
           {Arrowheads[{{0.013857839319935792`, 1.}}], 
            ArrowBox[{{-5.014990140800627, -0.9893870852190628}, \
{-5.106832939340121, -1.0076426530311726`}, {-5.237445700296634, \
-1.0336046888320976`}, {-5.361858890318341, -1.058334784062138}, \
{-5.594635852710988, -1.1046056158742106`}, {-5.656854249492381, \
-1.1169768830801141`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.2696088503272701, -1.2908229650773322`}, \
{-0.2918294856883363, -1.3952871684066064`}, {-0.31042955670493566`, \
-1.4851925626086686`}, {-0.3265933598787569, -1.564753446892985}, \
{-0.3546882533519939, -1.704899377803056}, {-0.3784059384645604, \
-1.8248828923306257`}, {-0.4165157663386469, -2.02060238145876}, \
{-0.4480100646510894, -2.1838551187751816`}, {-0.4543774629745573, \
-2.2170348792941454`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.4588275455460197, -2.240223733911037}, \
{-0.4752102677425042, -2.32559216407892}, {-0.4993081788884351, \
-2.4515924130788407`}, {-0.5413468055307665, -2.6719902242394338`}, \
{-0.5772512141279574, -2.8607354448207554`}, {-0.6107963901689575, \
-3.0374055460088445`}, {-0.6355678125879765, -3.1680192042965816`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6399674985729484, -3.1912176735687083`}, \
{-0.6407796545211629, -3.19549997345856}, {-0.6679952853186688, \
-3.3391187708546735`}, {-0.693207736860157, -3.4722336875388176`}, \
{-0.7168832690090308, -3.5972736205494296`}, {-0.7596235751289351, \
-3.8231285355500564`}, {-0.797567317470789, -4.023755459883127}, \
{-0.8156161436945701, -4.1192206246037335`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.8200025654313641, -4.142421605567545}, \
{-0.8320656098269994, -4.206226337575212}, {-0.8637147121970717, \
-4.373674492665343}, {-0.8931108845805111, -4.529233249192548}, \
{-0.9205172268287419, -4.674287851593734}, {-0.946318227926841, \
-4.810863270272586}, {-0.9498481356461311, -4.829549782146811}, \
{-0.9764540225820459, -4.9704109451929215`}, {-0.9953535753467379, \
-5.070480850388456}}]}, 
           {Arrowheads[{{0.012136314961221051`, 1.}}], 
            ArrowBox[{{-0.9997355524865925, -5.093682671215322}, \
{-1.001685178997217, -5.104005610732143}, {-1.0263301486130352`, \
-5.2345008361786975`}, {-1.0498027446301472`, -5.358797181439919}, \
{-1.0937133215544133`, -5.591341374230739}, {-1.1060851237376896`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.26988287165310143`, 
             1.2902079374849944`}, {-0.2921367897122873, 
             1.394654785066732}, {-0.3107634616483985, 
             1.4845396433516824`}, {-0.32694974050659703`, 
             1.5640793169023803`}, {-0.35508291279237486`, 
             1.7041840111803277`}, {-0.37883226423806304`, 
             1.8241289291375642`}, {-0.416997762621885, 
             2.0198101393401364`}, {-0.44853680470533586`, 
             2.183024484682294}, {-0.4549449214576767, 
             2.216361205263187}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.4594021126867476, 
             2.2395486945555545`}, {-0.47577504470267035`, 
             2.3247250233896675`}, {-0.49990629287700217`, 
             2.4506909077625765`}, {-0.5420025567355807, 
             2.671025852546379}, {-0.5779557491019954, 
             2.8597148807099924`}, {-0.6115485653655306, 
             3.0363432237499346`}, {-0.6364243882854874, 
             3.167290398803611}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.6408311102445695, 
             3.1904875325686155`}, {-0.6415740332818919, 
             3.1943983046195616`}, {-0.6688277141563715, 
             3.3379800095552854`}, {-0.6940752608623035, 
             3.471059742025683}, {-0.7177836569255805, 
             3.5960661479632092`}, {-0.760582997124169, 
             3.8218589802396488`}, {-0.7985788685394184, 
             4.022429309308027}, {-0.8167603904936116, 
             4.118437322147649}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.821153826029311, 
             4.1416369759711404`}, {-0.8331244049586097, 
             4.204847938091765}, {-0.8648167318471386, 
             4.372247546515523}, {-0.8942529746704001, 
             4.527760814503961}, {-0.921696609062692, 
             4.672772669128382}, {-0.9475326727156859, 
             4.8093076146658005`}, {-0.9510699490374853, 
             4.828002181053413}, {-0.9777121575347985, 
             4.968822500114957}, {-0.996785037691708, 5.069643234601195}}]}, 
           {Arrowheads[{{0.012155087013024896`, 1.}}], 
            ArrowBox[{{-1.0011740187874918`, 
             5.092843731541498}, {-1.0029777209817592`, 
             5.102378242245933}, {-1.0276562837326548`, 
             5.232835376106563}, {-1.0511608450914207`, 
             5.357095293426501}, {-1.0951311495396547`, 
             5.5895709904003645`}, {-1.1078582262688361`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.2114812742049066`, 
             0.2428726686386111}, {-1.286386481864577, 
             0.2577762785044334}, {-1.3515977251526343`, 
             0.27081349542949534`}, {-1.4098508708814659`, 
             0.2825000089160453}, {-1.5353332044192687`, 
             0.3077707597209263}, {-1.6407213479017086`, 
             0.3290770517169226}, {-1.732780666154929, 
             0.34773362116968987`}, {-1.8151381750343194`, 
             0.3644517413312014}, {-2.01388025459077, 
             0.4048690297444338}, {-2.1372368572347287`, 
             0.4300003891749477}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.1603735794168535`, 
             0.434714018350365}, {-2.1778299490962474`, 
             0.43827039305072046`}, {-2.3193917376721065`, 
             0.4671395915919846}, {-2.44483254215365, 
             0.4927377582603139}, {-2.6637878034500417`, 
             0.5374418125334822}, {-2.8509593185593163`, 
             0.5756761336474406}, {-3.0282756277996046`, 
             0.6119101112438008}, {-3.0857607819206563`, 
             0.6236596358363399}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.1088944992635423`, 
             0.6283879902261483}, {-3.186678910861011, 
             0.6442865273520314}, {-3.3304176656842994`, 
             0.6736702551349354}, {-3.4635596939423183`, 
             0.7008903956392539}, {-3.588583165466869, 
             0.7264523040104158}, {-3.814274438315565, 
             0.7726014243532695}, {-4.014641886970406, 
             0.8135770568312646}, {-4.034230698811059, 
             0.817583281372022}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.057363854907373, 
             0.822314380859429}, {-4.196835914171407, 
             0.8508386421121692}, {-4.36400352798523, 
             0.8850289855878866}, {-4.519291736478533, 
             0.91679089265032}, {-4.664087876810165, 
             0.9464078429209282}, {-4.800419192267611, 
             0.9742940937352023}, {-4.818409141518072, 
             0.9779739448730381}, {-4.959023946205265, 
             1.0067374118965216`}, {-4.982686139001873, 
             1.0115777205643952`}}]}, 
           {Arrowheads[{{0.014071637215089599`, 1.}}], 
            ArrowBox[{{-5.005819100720069, 
             1.0163097703824586`}, {-5.092387455685408, 
             1.034018085182529}, {-5.22265858759019, 
             1.0606663685859778`}, {-5.34674496434425, 
             1.0860498722243106`}, {-5.578907180136349, 
             1.1335426087342007`}, {-5.656854249492381, 
             1.149495612569811}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.23608067475319092`, 1.2382214971140086`}, {
             0.25685319284074853`, 1.3529226950470006`}, {0.2754526829067323, 
             1.4512468248419905`}, {0.2922504171781849, 
             1.5378091559660998`}, {0.32196109660925665`, 
             1.688167639504729}, {0.3476056630746791, 1.8157118577715006`}, {
             0.38710579137052104`, 2.009415625833073}, {0.41907887863915405`, 
             2.1647747332286036`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.4238550987727741, 2.187898613003607}, {
             0.44962938757021703`, 2.312497142783837}, {0.47565188179907625`, 
             2.437881502754009}, {0.5212960007201431, 2.6572411793790147`}, {
             0.5604847718683162, 2.8450920685889245`}, {0.5972178467389117, 
             3.0208600539164334`}, {0.6163997178558838, 3.112543438304633}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6212350918140197, 3.135655023538475}, {
             0.6301161596214105, 3.1781037684287603`}, {0.6600169750373942, 
             3.32090835616896}, {0.6877376910247923, 3.4532367624542317`}, {
             0.7137797900190711, 3.5775140494580646`}, {0.7608281370282712, 
             3.8019152656214157`}, {0.8026283704610941, 4.001170624872652}, {
             0.8149840018453783, 4.0600484884601125`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.8198333953962327, 4.083157136095253}, {
             0.8406468447136396, 4.182338747425413}, {0.8755354007733782, 
             4.348545550831203}, {0.9079458796277803, 4.502916952641529}, {
             0.9381668244162216, 4.646834129378177}, {0.9666200962548759, 
             4.782315841258187}, {0.9706377393389306, 4.80144475803874}, {
             1.000001733926409, 4.941237405617291}, {1.0139175771531972`, 
             5.007480276617147}}]}, 
           {Arrowheads[{{0.013551174510533132`, 1.}}], 
            ArrowBox[{{1.018771865778773, 5.030587896470255}, {
             1.0278490973719816`, 5.073797773993682}, {1.0550495551725538`, 
             5.203274254941793}, {1.0809562016831251`, 5.326582961033342}, {
             1.1294202740687396`, 5.557237212239036}, {1.1503555530657954`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.350958479190176, 0.26363071830672336`}, {
             1.4857397810024775`, 0.2901079374634271}, {1.7114471123238284`, 
             0.33390873429734713`}, {1.9428597902134284`, 
             0.378546841152914}, {2.0734833184336967`, 0.403677989426366}, {
             2.1902688506307006`, 0.42612264002625494`}, {2.27824564124159, 
             0.44301516876928504`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.301434044661352, 0.4474676018320662}, {
             2.33206307422116, 0.45334871841539987`}, {2.4589681683918356`, 
             0.47770016788025366`}, {2.6136854363105053`, 
             0.5073719331446089}, {2.752320116208605, 0.5339486698969496}, {
             2.9243532214429044`, 0.5669164847573246}, {3.0784564953392, 
             0.5964406157417202}, {3.2290246393769584`, 
             0.6252810342922098}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.2522150480264886`, 0.6297230113295336}, {
             3.408838185754588, 0.6597184360429307}, {3.543591882135829, 
             0.6855224653615594}, {3.670230400376971, 0.7097710854261889}, {
             3.899161902438954, 0.753602097793451}, {4.10267949791506, 
             0.7925630663575788}, {4.1798443600382384`, 
             0.8073343853040861}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.203035275261734, 0.811773716834036}, {
             4.287829992779808, 0.8280055843314345}, {4.457767793740834, 
             0.8605342328758144}, {4.615647307505774, 0.8907535931515151}, {
             4.762868840628803, 0.9189319559264026}, {4.901480684270303, 
             0.9454617404079935}, {4.92049623954136, 0.9491011976207337}, {
             5.0634332563759425`, 0.9764578230225301}, {5.130675693049523, 
             0.9893270792691989}}]}, 
           {Arrowheads[{{0.010844405814299879`, 1.}}], 
            ArrowBox[{{5.153866777527393, 0.9937655265288167}, {
             5.198988292384285, 1.002401149591527}, {5.3313939583975305`, 
             1.0277415588567076`}, {5.457500884420585, 1.0518761335142557`}, {
             5.656854249492381, 1.090028034621189}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3507575273338546`, -0.2627483409853448}, {
             1.485551104399132, -0.2891438776148566}, {
             1.7112915888946942`, -0.33281147291771873`}, {
             1.9427099956841687`, -0.37730821966141287`}, {
             2.07333128178988, -0.40235870874338225`}, {
             2.1901147830313388`, -0.424731312336089}, {
             2.2781512058414473`, -0.44158131998694955`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.3013422380337265`, -0.4460200404323967}, {
             2.331904563097045, -0.45186961262884756`}, {
             2.458805632786309, -0.4761425417310352}, {
             2.6135164652304677`, -0.505718338788549}, {
             2.7521453045741695`, -0.5322091044025818}, {
             2.924170610984753, -0.565070170429828}, {
             3.0782668095099077`, -0.5944986881450893}, {
             3.2290376634048994`, -0.6232857336667044}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.2522306897786, -0.6277140223832208}, {
             3.4086318463371588`, -0.6575713085314542}, {
             3.5433790344785407`, -0.6832917167438576}, {
             3.67001138661221, -0.707461747937668}, {
             3.898931582856413, -0.7511506792695103}, {
             4.102438959365584, -0.7899853255585264}, {
             4.179964580237998, -0.8047783303807201}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.203158108519757, -0.8092039895609335}, {
             4.287580040435539, -0.8253129098362619}, {
             4.457509105132968, -0.8577360582040223}, {
             4.615380432524562, -0.8878573967631128}, {
             4.762594284245763, -0.9159443509496827}, {
             4.901198860472122, -0.9423880694989123}, {
             4.920224108013734, -0.9460177592975195}, {
             5.063153811059215, -0.9732856732498512}, {
             5.130903021923948, -0.9862105342968438}}]}, 
           {Arrowheads[{{0.010838227805060668`, 1.}}], 
            ArrowBox[{{5.15409671809802, -0.990635313514045}, {
             5.198701876675122, -0.9991448661601882}, {
             5.331100721423702, -1.0244030951119965`}, {
             5.457201124437632, -1.0484593961467472`}, {
             5.656854249492381, -1.0865467164305174`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7680438834427505`, -1.4467615325676055`}, {
             1.8673361696889736`, -1.5266807889300456`}, {
             1.9891682825091321`, -1.6246593361503228`}, {
             2.098005817479953, -1.7121346502269286`}, {
             2.2318325779360833`, -1.819638324710282}, {
             2.3515328412469483`, -1.9157575241930438`}, {
             2.498867970624655, -2.034028400412301}, {
             2.5042781409482577`, -2.038370261729182}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.5226931989502868`, -2.053149025280916}, {
             2.6307970473282234`, -2.1399063525743727`}, {
             2.7928119665465565`, -2.269901472562331}, {
             2.938066893327533, -2.386430193893349}, {
             3.119120025488686, -2.5316569174824473`}, {
             3.259401490998719, -2.6441674890991336`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.277821065615732, -2.658940622966545}, {
             3.281395419039104, -2.661807377639812}, {
             3.464670401917933, -2.8087862385008213`}, {
             3.6303296153320965`, -2.941628595411284}, {
             3.772294709948837, -3.0554644513376705`}, {
             3.905774876593054, -3.1624936124295164`}, {
             4.014658724946025, -3.249797800440901}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.033080348067034, -3.2645683798101897`}, {
             4.147280425963916, -3.356131850109589}, {
             4.25714097477721, -3.4442135639822133`}, {
             4.362186927791275, -3.528433857589094}, {
             4.462418285006114, -3.6087927309302312`}, {
             4.557835046421726, -3.6852901840056247`}, {
             4.737519294067658, -3.829343726634062}, {
             4.769970819863839, -3.855359691226603}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.788393518942887, -3.8701289285792564`}, {
             4.904534182941465, -3.963237382749286}, {
             5.0603449864698815`, -4.08814643284983}, {
             5.207095890274664, -4.205790664257848}, {
             5.215415916728717, -4.212460441495556}, {
             5.366328027935517, -4.333438018216015}, {
             5.509491796024335, -4.448202877178376}, {
             5.525296354520007, -4.460904794371802}}]}, 
           {Arrowheads[{{0.0030747079726972703`, 1.}}], 
            ArrowBox[{{5.543701075963887, -4.475696428558373}, {
             5.646077042585541, -4.5579746555003835`}, {
             5.656854249492381, -4.566687495926102}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.7699183353675367`, 1.4537320643396785`}, {
             1.8692661432927207`, 1.533994236344371}, {1.9911798817273196`, 
             1.632404776005859}, {2.1000913450546865`, 1.7202669970546565`}, {
             2.2340169292152647`, 1.8282529737548987`}, {2.3538067051071634`, 
             1.9248045592588987`}, {2.501256084413525, 2.043611013566745}, {
             2.5050710842581543`, 2.0466841777898828`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.523459086973826, 2.0614965904719753`}, {
             2.633288709588449, 2.1499695866990107`}, {2.7954336707865695`, 
             2.28055728724693}, {2.9408064008277908`, 2.3976182777556825`}, {
             3.1220063818789376`, 2.543508463973987}, {3.2590843521491775`, 
             2.6538625258884148`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.2774768623132755`, 2.668669341319145}, {
             3.284414813006041, 2.6742547102795937`}, {3.4678483614083957`, 
             2.821913131893084}, {3.633651565068483, 2.9553702476623167`}, {
             3.775721969722593, 3.0697183612021735`}, {3.9093022538868394`, 
             3.1772300379278495`}, {4.013231533570917, 
             3.2608745456867463`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.031626061047098, 3.2756788549331843`}, {
             4.034392417561222, 3.2779052778393454`}, {4.150992460745741, 
             3.371744080936661}, {4.260938515470149, 3.4602253909862553`}, {
             4.366066713764197, 3.5448281517545874`}, {4.466377055627888, 
             3.625552363241658}, {4.561869541061219, 3.702398025447466}, {
             4.741697438150382, 3.8471081221088324`}, {4.767433808192024, 
             3.8678181124628415`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.785829449620799, 3.8826210375035255`}, {
             4.908846900545264, 3.9816128618322204`}, {5.064784171346802, 
             4.107092720253236}, {5.211654847887835, 4.225275081206814}, {
             5.219922403086092, 4.231927681344193}, {5.370954709253203, 
             4.353456225425804}, {5.514233050787682, 4.468744189184753}, {
             5.521657155472322, 4.4747354779796416`}}]}, 
           {Arrowheads[{{0.0031793112474515907`, 1.}}], 
            ArrowBox[{{5.540032069837101, 4.489564123751364}, {
             5.6505839440462555`, 4.578780026993343}, {5.656854249492381, 
             4.583874833860163}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.7376722082902738`, 
             1.4046989201865256`}, {-1.8900646884885997`, 
             1.5299776624462023`}, {-2.0204447428591052`, 
             1.637266236175393}, {-2.1297926380573324`, 
             1.727307837179693}, {-2.228692492643169, 
             1.80877838542317}, {-2.4032566794578583`, 
             1.9526365685018279`}, {-2.4668113722443716`, 
             2.005030346821333}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.4850304976008766`, 
             2.0200499901120414`}, {-2.555265487619515, 
             2.0779509307974173`}, {-2.6906781501689325`, 
             2.1896094682578147`}, {-2.814103179849341, 
             2.2913974239979096`}, {-2.927961563661335, 
             2.385305179487294}, {-3.0333938246465713`, 
             2.472271614093371}, {-3.1315404858467035`, 
             2.553235607183543}, {-3.213667749470559, 2.6209906581849545`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.2318814035523196`, 
             2.636016935778761}, {-3.3198863507507292`, 
             2.708621079916747}, {-3.4888003720148317`, 
             2.84798727463676}, {-3.642503510449468, 
             2.974811355487699}, {-3.7851214771572943`, 
             3.0924935358079235`}, {-3.9191832714343415`, 
             3.2031184772960017`}, {-3.9603856553807777`, 3.2371188366943}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.9785974946846014`, 
             3.2521473137464785`}, {-4.044688893280611, 
             3.306686179951934}, {-4.161638342696102, 
             3.40319664377572}, {-4.271890410470015, 
             3.494182587439038}, {-4.377303887391553, 
             3.5811767296135666`}, {-4.477878773460713, 
             3.6641790702993045`}, {-4.573615068677497, 
             3.7431896094962522`}, {-4.707048668294126, 
             3.8533135375850276`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.725259567637267, 
             3.868343153629696}, {-4.753891403074975, 
             3.8919732602583927`}, {-4.921452407105025, 
             4.030265658734603}, {-5.0777712711348295`, 
             4.159282083170586}, {-5.225003060490324, 
             4.280800350424982}, {-5.2325492961285995`, 
             4.28702870752763}, {-5.383947355556287, 
             4.411988189281203}, {-5.453680717481489, 4.46954575645081}}]}, 
           {Arrowheads[{{0.005084578428508063, 1.}}], 
            ArrowBox[{{-5.471890846607276, 
             4.484576305694211}, {-5.527560735670525, 
             4.530525952902092}, {-5.656854249492381, 
             4.637688196929372}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.53225109751741, 1.8816733523739222`}, {
             1.654743795617022, 2.0291042851115555`}, {1.744956770812589, 
             2.1375818895022687`}, {1.8268517358034697`, 
             2.2360101104302883`}, {1.9718863443620775`, 2.410239665879566}, {
             2.0984945900120673`, 2.562268235885461}, {2.136341608293293, 
             2.607701196673078}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1514543896623133`, 2.6258431384828276`}, {
             2.2114280880602286`, 2.697837784596138}, {2.314422020531126, 
             2.8214541802158064`}, {2.40945768766908, 2.935504675400382}, {
             2.4974802207134235`, 3.041126214715307}, {2.5794347509034905`, 
             3.139455742726023}, {2.7363737565356296`, 3.3277315233173885`}, {
             2.756107289588117, 3.351402785835872}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.7712267015580103`, 3.369539202103173}, {
             2.877130913617276, 3.4965760788145133`}, {3.0052053869207653`, 
             3.6501950287603195`}, {3.124030167882348, 3.7927121755451374`}, {
             3.2357127997330384`, 3.9266585798304643`}, {3.340253282472835, 
             4.0520342416163}, {3.3760467412940334`, 4.094959535230856}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.391168350251375, 4.113094119755389}, {
             3.4376516161017387`, 4.168839160902644}, {3.5294591916352314`, 
             4.278935710097455}, {3.617227400088794, 4.384186261608692}, {
             3.700956241462427, 4.484590815436354}, {3.78064571575613, 
             4.5801493715804416`}, {3.9306796595365543`, 4.76005627956014}, {
             3.996061185380422, 4.838453753980433}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.011184079736552, 4.85658726659188}, {
             4.070102327862873, 4.927234774290035}, {4.200144502635874, 
             5.083161559873283}, {4.322606528527434, 5.229996646072724}, {
             4.3292100136341745`, 5.237914319280745}, {4.4551897499980475`, 
             5.388963278101113}, {4.574332232444697, 5.531746027376228}, {
             4.616283171140198, 5.58177457334821}}]}, 
           {Arrowheads[{{0.0015748472089446898`, 1.}}], 
            ArrowBox[{{4.631454725459487, 5.59986739382687}, {
             4.679240485409657, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6529178759611733`, -1.3409488812941068`}, \
{-1.740325893647772, -1.4130551100486688`}, {-1.8932377438861736`, \
-1.539319577458932}, {-2.0240357924161603`, -1.647429630617776}, \
{-2.133489701994385, -1.7379578292364657`}, {-2.2324948501966544`, \
-1.819876079583472}, {-2.380883019117606, -1.9427033279806845`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.3990721647336466`, -1.9577592635243373`}, \
{-2.407261751459186, -1.9645381355214988`}, {-2.559459927683809, \
-2.090562929835441}, {-2.6950489368253843`, -2.2028605654739146`}, \
{-2.8186389005514854`, -2.3052344696159897`}, {-2.9326521385513056`, \
-2.3996849685525223`}, {-3.0382301822460898`, -2.487155934908859}, \
{-3.1264360745302855`, -2.5602405268380046`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.1446175618333583`, -2.575305709629289}, \
{-3.325066627159134, -2.724833010047985}, {-3.4941742923835766`, \
-2.864974356612898}, {-3.648059547112247, -2.9925086752104564`}, \
{-3.7908500385745096`, -3.1108528059796567`}, {-3.871829697152329, \
-3.1779701687809037`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.890009242394416, -3.193037695058534}, \
{-3.9250760945156897`, -3.2221017177706015`}, {-4.050737714935788, \
-3.3262554105832898`}, {-4.167834899834802, -3.4233138844177224`}, \
{-4.278227890048205, -3.5148178240246715`}, {-4.383776926411467, \
-3.6023079141549097`}, {-4.484482008924586, -3.685784154808437}, \
{-4.580343137587564, -3.765246545985253}, {-4.617165113453168, \
-3.7957700404095074`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.635343495756922, -3.8108389697063982`}, \
{-4.7608562671463, -3.914882500440854}, {-4.928639048870879, \
-4.053968498053814}, {-5.08516623846348, -4.183726473840924}, \
{-5.232595215653945, -4.30594400276316}, {-5.240079665871471, \
-4.312148601737567}, {-5.362467726592409, -4.413609485026688}}]}, 
           {Arrowheads[{{0.007604597434024571, 1.}}], 
            ArrowBox[{{-5.380645556135822, -4.4286790811203725`}, \
{-5.391676214289097, -4.437823603166877}, {-5.535221131412738, \
-4.556855084772909}, {-5.656854249492381, -4.658190155384395}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.5224809493104248`, -1.8455108071286752`}, \
{-1.628816867266243, -1.9770417611955386`}, {-1.7155808348132409`, \
-2.0844590245330803`}, {-1.7941271278456863`, -2.1817524797815953`}, \
{-1.932897045015069, -2.3537331797078638`}, {-2.0538375628300702`, \
-2.5036860014592315`}, {-2.1157178401838075`, -2.5804337698157838`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.130538427777359, -2.598815184253145}, \
{-2.1616349532743233`, -2.6373830290915214`}, {-2.2599233259336216`, \
-2.7593084200549134`}, {-2.3506154466946474`, -2.8718252961700825`}, \
{-2.4346153063488267`, -2.9760523938875276`}, {-2.512826895687585, \
-3.073108449657746}, {-2.662200383845507, -3.2584931137073667`}, \
{-2.7231977290376386`, -3.3342041178218342`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.7380113969110496`, -3.352591109350424}, \
{-2.7962555441076384`, -3.4248847944961414`}, {-2.9183017140703504`, \
-3.5763827905907246`}, {-3.031583615547052, -3.717008709319962}, \
{-3.138091920824416, -3.849230441532231}, {-3.2378266299024436`, \
-3.9730479872275315`}, {-3.330506583702661, -4.088112280944992}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.3453177572309385`, -4.106501281789214}, \
{-3.4184430993812076`, -4.197291036461069}, {-3.5022605396233852`, \
-4.30135757478699}, {-3.5822400635076663`, -4.400660961383628}, \
{-3.658381671034051, -4.4952011962509815`}, {-3.8017790724805463`, \
-4.673252764908561}, {-3.9350806794302855`, -4.8387728348704515`}, \
{-3.9377430429542537`, -4.842078756891004}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.952553045940338, -4.860468700471351}, \
{-4.059454215647742, -4.99321050217385}, {-4.176608261276239, \
-5.138686104304191}, {-4.1830332494137155`, -5.146664379091068}, \
{-4.303480626051974, -5.2962331239744715`}, {-4.417756766851197, \
-5.438140481152313}, {-4.528035569614404, -5.5748650552529275`}, \
{-4.54510099686459, -5.5959472165546655`}}]}, 
           {Arrowheads[{{0.0011593424137682261`, 1.}}], 
            ArrowBox[{{-4.5599570508058145`, -5.614299978598336}, \
{-4.5944035576763955`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.521521641549227, 
             1.8454837564046511`}, {-1.627777016987216, 
             1.9769971132652489`}, {-1.71448548451581, 
             2.0844127761273814`}, {-1.7929813564916437`, 
             2.181704624973468}, {-1.93166186075213, 
             2.353682183071144}, {-2.0525242214724044`, 
             2.5036320582169687`}, {-2.1145336179157703`, 
             2.5805882151515696`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.129348572424217, 
             2.598974170015237}, {-2.1602518238563935`, 
             2.6373263489334113`}, {-2.2584764968055757`, 
             2.759249182584836}, {-2.349109799818493, 
             2.871763661645492}, {-2.4330551462782775`, 
             2.9759885068638465`}, {-2.511215949568061, 
             3.0730424389883706`}, {-2.6604936036905733`, 
             3.2584245048151805`}, {-2.721782262662268, 
             3.3345448692988646`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.736590290359448, 
             3.352936403466946}, {-2.794462612802517, 
             3.424813686341061}, {-2.916430255342636, 
             3.576309297150033}, {-3.0296392124024325`, 
             3.7169329350153246`}, {-3.1360789019136086`, 
             3.8491524826779635`}, {-3.235749323876165, 
             3.9729679401379494`}, {-3.328650478290102, 
             4.088379307395283}, {-3.3288597776258846`, 4.088639329034114}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.343665304265887, 
             4.107032876659527}, {-3.4162492731698, 
             4.197207088042763}, {-3.5000126165296406`, 
             4.3012717856731895`}, {-3.5799405083696234`, 
             4.400573400286561}, {-3.656032948689749, 
             4.495111931882877}, {-3.79933772945516, 
             4.673160261233151}, {-3.932553213510605, 
             4.8386772889328125`}, {-3.9358648944807673`, 
             4.842792067149618}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.9506692564397046`, 
             4.861186552201527}, {-4.056846372328212, 
             4.993112087154213}, {-4.17392469025927, 
             5.138584964709264}, {-4.180350799176099, 
             5.146569642973182}, {-4.300720494425035, 
             5.296135800667693}, {-4.414922924469303, 
             5.438040689222027}, {-4.525153342607204, 
             5.574796103686417}, {-4.542990263611879, 5.596847853721483}}]}, 
           {Arrowheads[{{0.0011343212774543431`, 1.}}], 
            ArrowBox[{{-4.557839596371727, 
             5.615206054339285}, {-4.5915274245827185`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.520892333881756, -1.8596032060215242`}, {
             1.6424223132524367`, -2.0052392275030275`}, {
             1.732384761188381, -2.112941162929398}, {
             1.814023627920157, -2.2106293095691214`}, {
             1.9585492757972858`, -2.383479192508107}, {
             2.0846669971243537`, -2.534246168284217}, {
             2.1265617995692985`, -2.5843143622263236`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.141714364214079, -2.602423089349507}, {
             2.1971329206963537`, -2.6686534299172284`}, {
             2.299682563320459, -2.7911879400014783`}, {
             2.3942959964661896`, -2.9042251431801076`}, {
             2.4819165126927287`, -3.0088947945095277`}, {
             2.563487404559262, -3.106326649046153}, {
             2.7199560149733304`, -3.2931985561849917`}, {
             2.7479660076494112`, -3.32664741602853}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.7631254147335036`, -3.344750415509139}, {
             2.8602486390383945`, -3.460732634958308}, {
             2.9878709998114643`, -3.6131237719542812`}, {
             3.1062583091130236`, -3.7544801289013314`}, {
             3.2175187604798334`, -3.887322295453874}, {
             3.3216523539118943`, -4.011650271611909}, {
             3.3695479983498973`, -4.068831619644208}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.384709661417656, -4.0869327297304965`}, {
             3.4186590894092057`, -4.127464057375437}, {
             3.5100887414541107`, -4.23661579237637}, {
             3.5974910845289516`, -4.340957616246626}, {
             3.680866118633728, -4.440489528986201}, {
             3.7602138437684407`, -4.535211530595096}, {
             3.9095946008948266`, -4.713531717491959}, {
             3.991206545724828, -4.810951700662824}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.006369522772585, -4.829051710065732}, {
             4.048400589675263, -4.879224094008324}, {
             4.177859321642836, -5.033754852900008}, {
             4.299766181740088, -5.179268416913705}, {
             4.3064932236923195`, -5.187298043608444}, {
             4.431919759218481, -5.337008859623503}, {
             4.550886442109629, -5.4790069752979536`}, {
             4.613050836891374, -5.552915933537028}}]}, 
           {Arrowheads[{{0.0023805511435918735`, 1.}}], 
            ArrowBox[{{4.628249473185581, -5.570986010131569}, {
             4.664237530961277, -5.613773201555017}, {
             4.700807296870545, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.890854343094219, 0.99579436479542}, {
             2.0160017709643823`, 1.0607552140584413`}, {2.1278368857719894`, 
             1.1187577434277591`}, {2.264578005339253, 1.189627248166053}, {
             2.386913845932861, 1.252998711936959}, {2.536985394518067, 
             1.3307037146168634`}, {2.6713882182820177`, 1.400273609126155}, {
             2.729443918668633, 1.4303163071686742`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.7504144600520406`, 1.4411681552796156`}, {
             2.836114383887203, 1.485516202360282}, {2.9838172381476014`, 
             1.5619341820966768`}, {3.167598418500073, 1.6570016142403754`}, {
             3.33233858803603, 1.742208248387913}, {3.5185481532575342`, 
             1.8385084517201569`}, {3.5893094005157353`, 
             1.8751004238555147`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.610283038198455, 1.8859462864625256`}, {
             3.6868497013878847`, 1.925540348388847}, {3.830476502624398, 
             1.9998079940463025`}, {3.9655373047135956`, 
             2.0696442289794867`}, {4.092032107655477, 2.1350490531884}, {
             4.209960911450043, 2.1960224666730417`}, {4.427516007039256, 
             2.308502329084145}, {4.449250187657103, 2.319738936081148}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.470224828008723, 2.33058285951579}, {
             4.625598076923263, 2.41091108382743}, {4.8075338535706615`, 
             2.504969717448003}, {4.976650069450046, 2.5923992164909686`}, {
             5.134427861860412, 2.6739656634501405`}, {5.283034944440853, 
             2.750790224026168}, {5.295100482183491, 2.7570276403479492`}, {
             5.309217754988472, 2.7643256516376855`}}]}, 
           {Arrowheads[{{0.007786903756707965, 1.}}], 
            ArrowBox[{{5.330192784394181, 2.7751688225192033`}, {
             5.448002834996881, 2.8360714551466266`}, {5.593057174678577, 
             2.911057587769937}, {5.656854249492381, 2.9440375154508422`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.8913278084782432`, -0.9917016624135704}, {
             2.016519390077555, -1.0564032772011955`}, {
             2.128394263709532, -1.1141745407121173`}, {
             2.2651750650221114`, -1.1847569264934177`}, {
             2.3875469887542464`, -1.247872003485069}, {
             2.5376603093533583`, -1.3252614117523729`}, {
             2.6721010662285734`, -1.3945490787740809`}, {
             2.7306871645784607`, -1.4247347640465062`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.751676900926174, -1.4355494384008103`}, {
             2.8368700452777262`, -1.4794440399393203`}, {
             2.9846116129531115`, -1.5555506034760207`}, {
             3.168438408558215, -1.650229379270432}, {
             3.3332198834023092`, -1.7350879485743425`}, {
             3.5194790450063844`, -1.8309963384322197`}, {
             3.5913389720197006`, -1.8679954365546831`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6123317697932107`, -1.8788041670526032`}, {
             3.6878253823902423`, -1.9176741700736082`}, {
             3.83148161440662, -1.9916351931853213`}, {
             3.9665704443659506`, -2.0611833077685064`}, {
             4.093091872268236, -2.1263185138231635`}, {
             4.211045898113475, -2.1870408113492923`}, {
             4.428648162772423, -2.29905781764693}, {
             4.452065016948618, -2.311111944421641}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.473058798743166, -2.321918763532696}, {
             4.626773657482404, -2.4010454634923843`}, {
             4.808749695003385, -2.4947175670356336`}, {
             4.977903588095333, -2.5817879464266573`}, {
             5.135716728211607, -2.6630194919635812`}, {
             5.2843572447745935`, -2.7395287201770726`}, {
             5.296453300588991, -2.7457548468272965`}, {
             5.312817210089707, -2.7541776579668147`}}]}, 
           {Arrowheads[{{0.0076936283619549115`, 1.}}], 
            ArrowBox[{{5.3338113686434205`, -2.764983745138299}, {
             5.449390583512733, -2.8244745348212525`}, {
             5.594478136879708, -2.8991532420304953`}, {
             5.656854249492381, -2.9312590570225585`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.915411092728953, -1.0136346210135811`}, \
{-2.0457247052732055`, -1.0835934070310143`}, {-2.256217644268416, \
-1.1967424568509586`}, {-2.4325106558581506`, -1.2915834549225904`}, \
{-2.585980357410883, -1.3741839739604595`}, {-2.722684806300665, \
-1.447783147508483}, {-2.7472221482035755`, -1.4609959587174648`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.768011685474011, -1.4721906607419644`}, \
{-2.847292260177915, -1.5148814815426475`}, {-2.9622503187654567`, \
-1.5767916445662704`}, {-3.1678206675246323`, -1.6875200014022083`}, \
{-3.35785824770648, -1.7898987197424552`}, {-3.528338546242007, \
-1.8817509480217947`}, {-3.5995238848361075`, -1.9201073913314184`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.6203104073270205`, -1.931307690259167}, \
{-3.683505894378081, -1.9653590014472682`}, {-3.827509372252696, \
-2.0429552814728695`}, {-3.9628920580063847`, -2.115908410689012}, \
{-4.089653951639148, -2.184218389095695}, {-4.207795053150984, \
-2.2478852166929197`}, {-4.319186187240595, -2.3079161625824893`}, \
{-4.42569817860668, -2.3653184958662083`}, {-4.451750114244613, \
-2.3793589758333646`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.472535622291846, -2.390561157252829}, \
{-4.624084733168273, -2.4722373246160947`}, {-4.806298386112964, \
-2.570442617112219}, {-4.975682806717952, -2.6617352875242215`}, \
{-5.133722707487445, -2.746915150036053}, {-5.282590243477481, \
-2.8271523761317785`}, {-5.2934982671511, -2.833031665383879}, \
{-5.303947643991848, -2.8386638144553835`}}]}, 
           {Arrowheads[{{0.007989445174288427, 1.}}], 
            ArrowBox[{{-5.324732701807209, -2.8498668312342827`}, \
{-5.446635675296262, -2.915571775118842}, {-5.591929112153028, \
-2.993884778554459}, {-5.656854249492381, -3.0288797434236874`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.006226461419737, 1.908926507294216}, {
             1.0882135334666312`, 2.060290902336821}, {1.2015579227842457`, 
             2.2690477657385855`}, {1.2972790840260404`, 2.445085421746841}, {
             1.3809475731599434`, 2.598826002050392}, {1.455645608161278, 
             2.736006406557319}, {1.4571682529311736`, 
             2.738801753819602}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.4684629552779085`, 2.7595371320952644`}, {
             1.5238068268532203`, 2.861140173691623}, {1.5867263102531433`, 
             2.9766233306505403`}, {1.6993234565997444`, 3.18321718475581}, {
             1.802933175070831, 3.3732612682186693`}, {1.8959279848841017`, 
             3.543801230745379}, {1.920483196264506, 3.588825755067446}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.931788564871725, 3.6095553197997567`}, {
             1.9805900869726092`, 3.6990379670775817`}, {2.059165876697688, 
             3.843101888947045}, {2.1330357582579316`, 3.9785299796988745`}, {
             2.202199731653341, 4.105322239333068}, {2.2666577968839157`, 
             4.223478667849627}, {2.3274294515790275`, 4.334871418110745}, {
             2.3840753128609644`, 4.438698634693637}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.395384318685143, 4.459426215367159}, {
             2.4937429382278156`, 4.639700516534607}, {2.5931111590439953`, 
             4.821815218435868}, {2.6854659833973633`, 4.991069678600659}, {
             2.7716193988064157`, 5.14895345340523}, {2.847775499834819, 
             5.288512555912986}}]}, 
           {Arrowheads[{{0.008385790841784509, 1.}}], 
            ArrowBox[{{2.8590859909798714`, 5.309239326124213}, {
             2.9425136141163555`, 5.462118182383742}, {3.0217257093282655`, 
             5.6072693927627615`}, {3.048791438007053, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.102504460749452, 
             2.0398543021827136`}, {-1.1591004017495792`, 
             2.1474331435176124`}, {-1.229350243919461, 
             2.2811241876238584`}, {-1.2921324474808749`, 
             2.400708558152617}, {-1.3698826763296859`, 
             2.5489160018289683`}, {-1.4394763292908113`, 
             2.6816501177975125`}, {-1.5252679695969515`, 
             2.8453581442302442`}, {-1.5414043479391228`, 
             2.8761608064581385`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.5523613572781858`, 
             2.8970765937892398`}, {-1.6021782279368753`, 
             2.992171800880412}, {-1.6983208310491582`, 
             3.175755799257118}, {-1.784497800245952, 
             3.340349353249281}, {-1.88192264687714, 
             3.526463433235527}, {-1.9700034727031406`, 
             3.6947516663162676`}, {-1.9904447477788692`, 
             3.733811241596398}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.0013931006423804`, 
             3.7547315614532315`}, {-2.0455276016134336`, 
             3.839064601185021}, {-2.1165508346991944`, 
             3.9747842881390585`}, {-2.183073171960424, 
             4.101910727178381}, {-2.245094613397122, 
             4.220443918302988}, {-2.3035882088381627`, 
             4.332240419280668}, {-2.3595270081124218`, 
             4.4391567878792095`}, {-2.4392689143010786`, 
             4.591574863161555}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.450214688210247, 
             4.612496532475105}, {-2.463740218160593, 
             4.638349127938878}, {-2.559480295024192, 
             4.8213546231107625`}, {-2.6484932901857743`, 
             4.991506958023635}, {-2.7315559513950443`, 
             5.150289642068843}, {-2.8098050462549615`, 
             5.299873897126247}, {-2.815644109057973, 
             5.311036212417734}, {-2.8880116805389218`, 
             5.4493810732433845`}}]}, 
           {Arrowheads[{{0.004458153007636983, 1.}}], 
            ArrowBox[{{-2.89895605272809, 
             5.470303475847224}, {-2.9724668200829854`, 
             5.610835859925686}, {-2.9965389856596834`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2109010243934581`, -2.2589785879452893`}, {
             1.3074811393633101`, -2.4344760525966813`}, {
             1.39188819792648, -2.5877217794690814`}, {
             1.467237637228076, -2.7244456186091184`}, {
             1.5359885242463505`, -2.8491540151632173`}, {
             1.5994490330255668`, -2.9642384056617166`}, {
             1.6667170073762032`, -3.086186921067126}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.678121611040024, -3.106862056583183}, {
             1.7130061758864743`, -3.1701034568877855`}, {
             1.8175622707941785`, -3.3595907315365774`}, {
             1.911395600995194, -3.5296108822153167`}, {
             1.9968135425203188`, -3.684360487101484}, {
             2.0760862188555045`, -3.827963779564959}, {
             2.1344938914468647`, -3.9337636676486465`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.1459056004218584`, -3.9544348822139836`}, {
             2.150608412988611, -3.9629535754124277`}, {
             2.2203801249196373`, -4.089329874643889}, {
             2.285401354648584, -4.207092677259344}, {
             2.346701698372429, -4.318110106602179}, {
             2.40531075228815, -4.424250286015783}, {
             2.51445499069522, -4.621898895055295}, {
             2.602450839256661, -4.78124101720808}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.613865506648064, -4.801910598279785}, {
             2.61467852270507, -4.803382800730077}, {
             2.7078258011529774`, -4.972046299392329}, {
             2.794716343404544, -5.129374800070471}, {
             2.8765491430147265`, -5.277541411473522}, {
             2.882870286442514, -5.288986326868402}, {
             2.9670898989893066`, -5.441468694608647}, {
             3.0469809263122163`, -5.586111098654877}, {
             3.0704970198069397`, -5.6286690880737185`}}]}, 
           {Arrowheads[{{0.0001818956023203551, 1.}}], 
            ArrowBox[{{3.081916772977493, -5.649335859734038}, {
             3.086071178740108, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.278381394113929, 
             1.207536819887091}, {-2.4558629495460544`, 
             1.302934760363569}, {-2.6104390451100783`, 
             1.386057405428205}, {-2.748172227692024, 
             1.4601441938033264`}, {-2.873741435493586, 
             1.527699563310044}, {-2.9896024824453162`, 
             1.590039588953699}, {-3.1101771495812875`, 
             1.6549267349371488`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.130969538381763, 
             1.6661161398054174`}, {-3.1968261815534937`, 
             1.701556831627068}, {-3.388073596912676, 
             1.8044928454348976`}, {-3.5596900104657863`, 
             1.8968720538606585`}, {-3.7159258216236584`, 
             1.9809780825665282`}, {-3.8609416177910094`, 
             2.0590475652687155`}, {-3.96261509947564, 
             2.1137852139570468`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.9834055972105014`, 
             2.124978132132076}, {-3.9972885126206026`, 
             2.132452235840308}, {-4.124966506112439, 
             2.201192094281305}, {-4.243975598266516, 
             2.2652671405917064`}, {-4.35619503385948, 
             2.3256882677855772`}, {-4.463504057667973, 
             2.3834663688769817`}, {-4.663390869931547, 
             2.4910934927523924`}, {-4.815005876814294, 2.572731318592641}}]}, 
           {Arrowheads[{{0.019746966046812107`, 1.}}], 
            ArrowBox[{{-4.835795612874102, 
             2.5839256514401}, {-4.846998362525417, 
             2.5899578255880935`}, {-5.017688862917761, 
             2.6818686807542407`}, {-5.176956159818478, 
             2.7676300237808635`}, {-5.3269858836420765`, 
             2.848418204603338}, {-5.337720802309736, 
             2.85419879293089}, {-5.49203205908128, 
             2.9372939555349085`}, {-5.638444228338557, 
             3.016136263579973}, {-5.656854249492381, 
             3.0260520491310063`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.5773674091322403, -1.9311590865232595`}, {
             0.6503385151368241, -2.164644687797896}, {
             0.6929921144735869, -2.30054512757022}, {
             0.7312138337935509, -2.422093261000903}, {
             0.7784325840545389, -2.5720065313592544`}, {
             0.8207638913111612, -2.706241701304153}, {
             0.8605242093882832, -2.832193586793396}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8676322514971769, -2.8547102906088826`}, {
             0.8728668845595728, -2.871292449302237}, {
             0.9196161612750555, -3.0192709779485805`}, {
             0.9779818803265588, -3.2038976256455873`}, {
             1.0303209965418025`, -3.369378683922769}, {
             1.0894604496794822`, -3.5562814590021614`}, {
             1.1429354914706964`, -3.72523168534897}, {
             1.1524317046538104`, -3.755227462100768}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.159558298750754, -3.7777383010436765`}, {
             1.1888252420807273`, -3.870184066677333}, {
             1.231977078699111, -4.006473326210315}, {
             1.2723910013258477`, -4.134099463947917}, {
             1.3100670099609375`, -4.253062479890139}, {
             1.3795715794409562`, -4.472496681943437}, {
             1.4428570813239465`, -4.6722734679252085`}, {
             1.4447163051187406`, -4.678142015690744}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{1.4518475341650248`, -4.700651386753162}, {
             1.5009864325655662`, -4.855755884241227}, {
             1.555022550121472, -5.026306977297269}, {
             1.605438414006974, -5.185422218117595}, {
             1.652926220195678, -5.335289962107494}, {
             1.657467529348114, -5.349621667044736}, {
             1.7063513490411166`, -5.503886237822778}, {
             1.7371308254269264`, -5.6010154156497185`}}]}, 
           {Arrowheads[{{0.0007404112325558112, 1.}}], 
            ArrowBox[{{1.744263703407438, -5.623524264244245}, {
             1.7527282895334666`, -5.650235514324039}, {
             1.7548313454194424`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.5673724862485785, 1.9238384807232691`}, {
             0.6391476017145543, 2.1565469449092505`}, {0.681110043464762, 
             2.291999735515089}, {0.7187134952424867, 2.413142474446831}, {
             0.765173156217952, 2.562561815072858}, {0.8068242354052121, 
             2.696349595291186}, {0.8472030991645512, 2.82591149214727}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8542286501150278, 2.84845407068608}, {
             0.858093930205288, 2.860856426120322}, {0.9040953715342382, 
             3.0083423765429593`}, {0.9615335009873862, 
             3.1923690413808985`}, {1.013040069669129, 3.3573065868955725`}, {
             1.0712285769076701`, 3.543559405590551}, {1.123843932120793, 
             3.7119204008323377`}, {1.1357478471259848`, 
             3.7500020975615476`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.142792539039111, 3.772538701768599}, {
             1.1690243233939097`, 3.85645654359037}, {1.2115079236434922`, 
             3.992349854207674}, {1.2512947328695403`, 4.119600332684248}, {
             1.2883847510720539`, 4.238207979020094}, {1.3568059335090388`, 
             4.456977631618626}, {1.4191029900570076`, 4.656141668352295}, {
             1.4246805961036368`, 4.673971484023974}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.4317301282007893`, 4.696506574672724}, {
             1.4763228780975761`, 4.839055278239453}, {1.5295125550123596`, 
             5.0090736502984505`}, {1.5791378270249294`, 5.167688488294342}, {
             1.6258803708522107`, 5.317082559286249}, {1.630408053222326, 
             5.331553173567169}, {1.678528213934447, 5.4853406794196}, {
             1.7137487109693417`, 5.597898531431374}}]}, 
           {Arrowheads[{{0.0008082642757297853, 1.}}], 
            ArrowBox[{{1.7207999982675786`, 5.620433072934895}, {
             1.7241801581171712`, 5.6312354057852705`}, {1.732219518238862, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.284883590266289, 
             0.6910727940062379}, {-2.462929543098966, 
             0.7456488376751762}, {-2.617897765228536, 
             0.7931767370054107}, {-2.755935682871889, 
             0.8355272278630588}, {-2.8817667991201583`, 
             0.8741407564200685}, {-2.997864020631711, 
             0.9097725566102033}, {-3.18782619344693, 
             0.9680864721404125}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.2103984961155287`, 
             0.9750159284895494}, {-3.3972715253570986`, 
             1.0323926409588042`}, {-3.5693579801464086`, 
             1.0852357264352797`}, {-3.7260262860302835`, 
             1.1333484218431258`}, {-3.8714492625754353`, 
             1.17801004049221}, {-4.008184500079982, 
             1.2200049172002647`}, {-4.113264588219009, 
             1.2522789086271748`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.135835955155177, 
             1.259211412357356}, {-4.1362319985439235`, 
             1.25933305196729}, {-4.2555917579672595`, 
             1.2959944447932858`}, {-4.475781220376233, 
             1.3636283870692256`}, {-4.676286047991021, 
             1.4252181264751205`}, {-4.860475100272879, 
             1.4817977660486978`}, {-5.031717236683061, 
             1.5344014088276852`}, {-5.038681641289638, 
             1.5365408342451634`}}]}, 
           {Arrowheads[{{0.013193979196890979`, 1.}}], 
            ArrowBox[{{-5.061252645698839, 
             1.5434745182079617`}, {-5.191509156700271, 
             1.583488576289156}, {-5.3420407822554195`, 
             1.6297316468703946`}, {-5.355611595245393, 
             1.6339006061846346`}, {-5.510499992308819, 
             1.6814829245019298`}, {-5.656854249492381, 
             1.7264439327360757`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.7064049457944555, 
             2.312515191267341}, {-0.7417451674096767, 
             2.43339998773394}, {-0.7854503471642221, 
             2.5831478370752174`}, {-0.8245436157221055, 
             2.7172605534892433`}, {-0.8726917700082687, 
             2.8826158462841693`}, {-0.9158353488218077, 
             3.0309039363147985`}, {-0.9697310521908289, 
             3.216279227999956}, {-0.970605782433215, 3.2192894964499863`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.9771944743582889, 
             3.2419636083852446`}, {-1.0180246054513102`, 
             3.38247510494062}, {-1.0726044814184617`, 
             3.570391521120123}, {-1.1219384715621985`, 
             3.7403036033241377`}, {-1.1642248173746075`, 
             3.8859796957926953`}, {-1.2039875706269, 
             4.022979253348982}, {-1.2405536335860483`, 
             4.1489828376911815`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.2471334144107182`, 
             4.171659537132183}, {-1.2759422994511367`, 
             4.270948763724747}, {-1.339986836292883, 
             4.4917104567983595`}, {-1.3983053594101134`, 
             4.6927626549167485`}, {-1.4518769290083786`, 
             4.877471618455283}, {-1.5016806052932288`, 
             5.049203607789335}, {-1.5102485302049464`, 5.078749596305034}}]}, 
           {Arrowheads[{{0.012245996739778242`, 1.}}], 
            ArrowBox[{{-1.5168247560498538`, 
             5.1014273269448696`}, {-1.548151750091797, 
             5.209456635760212}, {-1.5919274669512762`, 
             5.3604231354675225`}, {-1.5959924824495422`, 
             5.374442292545998}, {-1.6410307371026285`, 
             5.529774937307515}, {-1.6778755259986666`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            
            ArrowBox[{{-0.705237761541246, -2.3135221409867923`}, \
{-0.7405154873562565, -2.4344564794573884`}, {-0.7841428616955742, \
-2.5842643682045363`}, {-0.8231666384048862, -2.7184315226226796`}, \
{-0.8712287555771512, -2.8838527343697296`}, {-0.9142953473681801, \
-3.032200557287746}, {-0.9680941548540233, -3.2176483132888767`}, \
{-0.9689068438174716, -3.2204512108118895`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.9754822318533427, -3.243129184387892}, \
{-1.0163010149596379`, -3.3839098165938095`}, {-1.0707842009113246`, \
-3.571905092622325}, {-1.120030793588302, -3.7418886316003688`}, \
{-1.162238737249746, -3.887614043792833}, {-1.2019279155124287`, \
-4.024660550884445}, {-1.238309163339139, -4.150302780311476}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.2448756482038907`, -4.1729833334296}, \
{-1.2737499758415087`, -4.272716849765105}, {-1.3376768773108607`, \
-4.4935575358543405`}, {-1.3958885226558033`, -4.694682616764139}, \
{-1.4493620977811295`, -4.87945926557035}, {-1.4990747885916322`, \
-5.051254655348823}, {-1.5074581270774898`, -5.080227722439894}}]}, 
           {Arrowheads[{{0.012211244372055362`, 1.}}], 
            ArrowBox[{{-1.514021030589373, -5.102909312129109}, \
{-1.5454611364598927`, -5.2115672529093375`}, {-1.589157041072228, \
-5.362590144813878}, {-1.5932118335352659`, -5.376604822791294}, \
{-1.638167674659895, -5.531994525132461}, {-1.6742894059782665`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.2171877379275912, 2.3113190221522935`}, {
             0.23017543987804034`, 2.432914801285012}, {0.24630704649583143`, 
             2.5831261625617223`}, {0.26081080574968746`, 
             2.7176404561812517`}, {0.2787233767298027, 2.883195547316429}, {
             0.29482615213956287`, 3.0316420322665985`}, {0.3149748297177358, 
             3.2169711310759723`}, {0.3186084913596108, 
             3.2503373425452398`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{0.32116478108175234`, 3.273810552726053}, {
             0.33306671175078173`, 3.383100402672148}, {0.35354078063551325`, 
             3.57083085333334}, {0.37206956816312975`, 3.740545746736278}, {
             0.3879688062381184, 3.8860594727108877`}, {0.4029251554021564, 
             4.022889651522181}, {0.4169386156552437, 4.151036283170159}, {
             0.42368634285147294`, 4.2127095094601135`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{0.42625442854780776`, 4.236181432031399}, {
             0.4300091869973803, 4.270499367654821}, {0.4541332332938051, 
             4.4908844940205395`}, {0.4761088646364349, 4.69155462950568}, {
             0.49630206689152667`, 4.875880047778055}, {0.5150788259253374, 
             5.047231022505483}, {0.5290882718160608, 5.1750462462573115`}}]}, 
           {Arrowheads[{{0.009763757111827384, 1.}}], 
            ArrowBox[{{0.5316609047418016, 5.19851767086609}, {
             0.5326023367392203, 5.207106828662607}, {0.5491115085352433, 
             5.357701520784867}, {0.5508523458956565, 5.373579784889207}, {
             0.5678520424545016, 5.528610434759623}, {0.5819162671595743, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.19185926408059575`, -2.035180508346345}, {
             0.2141688378269065, -2.242920225694653}, {
             0.2331672285627602, -2.41782714272346}, {
             0.24985604881892995`, -2.5704783607479373`}, {
             0.26480567039561753`, -2.7066447560750717`}, {
             0.29111330964083076`, -2.9454592815897445`}, {
             0.2942779398221666, -2.974090187835811}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.2968720214371085, -2.9975592515987985`}, {
             0.3137773940015592, -3.1505048121266013`}, {
             0.33468057470246143`, -3.339181618363875}, {
             0.3534678850171333, -3.508512844091462}, {
             0.37058920020697383`, -3.66266776240969}, {
             0.38649024095303014`, -3.805742555764327}, {
             0.4010040617951607, -3.936280944788002}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{0.4036148416187865, -3.9597481568409374`}, {
             0.42851937386724276`, -4.183576782697372}, {
             0.4526260559232876, -4.400065125631006}, {
             0.4745812475297616, -4.597141338318714}, {
             0.4947520465431998, -4.7781298973481805`}, {
             0.5081622133031535, -4.898423704415491}}]}, 
           {Arrowheads[{{0.01565993387125582, 1.}}], 
            ArrowBox[{{0.5107782365561867, -4.92189033254302}, {
             0.5135055508201372, -4.946355279307091}, {
             0.5310052902589392, -5.103294717646911}, {
             0.5474906241919387, -5.251109599784114}, {
             0.5493332157911255, -5.267629534779341}, {
             0.5663149947397788, -5.419856495637594}, {
             0.5824273283133531, -5.564270534580918}, {
             0.5927813958596962, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.24953366213909942`, -2.4156853899262125`}, \
{-0.2633372822629276, -2.568324806425421}, {-0.27558399433392017`, \
-2.704440013069915}, {-0.2969720486590896, -2.9431335625962043`}, \
{-0.31525847843240723`, -3.148063218860173}, {-0.3320467682097797, \
-3.336746098744618}, {-0.3337922194315561, -3.3563990634560246`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-0.33588106426623465`, -3.379918479702879}, \
{-0.34708642956195146`, -3.5060856541203984`}, {-0.3607607867902863, \
-3.6602547624113138`}, {-0.3734424139847349, -3.8033495391534426`}, \
{-0.3853590698608622, -3.9378841636272917`}, {-0.40689746765815327`, \
-4.181272955770148}, {-0.4192247282119379, -4.320713760698399}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-0.4213040362696704, -4.344234021992381}, \
{-0.4260430951572021, -4.397840269949631}, {-0.44346306733305146`, \
-4.595005237275489}, {-0.4594542006541908, -4.776089659561996}, \
{-0.47431331158910955`, -4.944415338623431}, {-0.4881718864880896, \
-5.101458394344981}, {-0.5012222190265002, -5.249378650596392}, \
{-0.5026728046587419, -5.265822519566048}, {-0.5043689259358592, \
-5.285053963792252}}]}, 
           {Arrowheads[{{0.00740372614223719, 1.}}], 
            ArrowBox[{{-0.5064433384629181, -5.308574657362037}, \
{-0.5161066401502188, -5.418141850432185}, {-0.5288493902450555, \
-5.562650896799158}, {-0.5371822403039399, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.2504928053905554, 
             2.4148163789633674`}, {-0.2643588291055386, 
             2.5674146870372017`}, {-0.2766610028633686, 
             2.7034917495495723`}, {-0.2981460570324949, 
             2.9421162752182446`}, {-0.3165155458349022, 
             3.1469848283143596`}, {-0.333381273107193, 
             3.335622602365675}, {-0.3351546868989856, 
             3.3554938398224325`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-0.3372536033389871, 
             3.3790123593998644`}, {-0.34849025557282787`, 
             3.504919908890588}, {-0.362227604961403, 
             3.6590493528986525`}, {-0.3749676286034166, 
             3.8021065873422675`}, {-0.38693914512836736`, 
             3.9366054732311855`}, {-0.40857665682708016`, 
             4.17992819934493}, {-0.42099984877371244`, 4.319771889470303}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.42308922183979564`, 
             4.343291258797028}, {-0.42781034814089175`, 
             4.396435388448201}, {-0.4453104271531521, 
             4.593544897749313}, {-0.46137508207851463`, 
             4.7745778273392325`}, {-0.4763025011316325, 
             4.942855277308928}, {-0.4902247774466871, 
             5.099853027593767}, {-0.5033350922050503, 
             5.247730402016573}, {-0.5047934969190028, 
             5.264182488803118}, {-0.5065565503092541, 
             5.284075582571664}}]}, 
           {Arrowheads[{{0.007424823796384717, 1.}}], 
            ArrowBox[{{-0.508641025979541, 
             5.307595386450867}, {-0.5182891763342724, 
             5.416458544402288}, {-0.5310905831117545, 
             5.56092634995002}, {-0.5396165653059254, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.260124371637426, 0.6668294659528441}, {
             2.3835393941242007`, 0.7027617373937122}, {2.5343575369953877`, 
             0.7466472158507613}, {2.6694327200427526`, 0.7859354510073985}, {
             2.834627571899035, 0.8339671300065029}, {2.9827490259931246`, 
             0.8770232387769309}, {3.1667595860691122`, 0.9304993647099519}, {
             3.167030428148253, 0.9305780617680693}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.189704648033505, 0.937166382186158}, {
             3.331703620230811, 0.978426224095145}, {3.518155056673812, 
             1.0325943421835058`}, {3.6866580410056797`, 
             1.0815428131248035`}, {3.8301828787762107`, 
             1.1232320147608954`}, {3.9651490812693226`, 
             1.1624336640759243`}, {4.091556648485015, 1.19914776106989}, {
             4.096690959795882, 1.2006389051350563`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.11936601241035, 1.2072243589741802`}, {
             4.2094055804232875`, 1.2333743057427928`}, {4.426811979463591, 
             1.2965120417760532`}, {4.624752719386249, 1.3539941758263492`}, {
             4.806552629349123, 1.4067870551543131`}, {4.975536538510074, 
             1.4558570270205773`}, {5.0263748747007035`, 
             1.4706192429267642`}}]}, 
           {Arrowheads[{{0.013402638155402189`, 1.}}], 
            ArrowBox[{{5.049050240730312, 1.47720361751813}, {
             5.133185145128478, 1.501634346708694}, {5.281665609395526, 
             1.544748715205135}, {5.296961114490223, 1.5491900418068203`}, {
             5.449824861228268, 1.5935761236537545`}, {5.594837901301558, 
             1.6356821284195053`}, {5.656854249492381, 
             1.6537526808440088`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.411885639519189, 
             0.2458339021908319}, {-2.5644571834689187`, 
             0.2615857066189227}, {-2.700210258572326, 
             0.2756073511546194}, {-2.9379389475868716`, 
             0.3001705112808084}, {-3.1418131084659837`, 
             0.32124316046623014`}, {-3.331074426047963, 
             0.34081019742535523`}, {-3.3513634380036983`, 
             0.34290812806567134`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.3748502041570583`, 
             0.34533671386682196`}, {-3.500767803216647, 
             0.35835688408499167`}, {-3.655165910943857, 
             0.37432375373434146`}, {-3.7984285745443143`, 
             0.3891400753844919}, {-3.933102091364674, 
             0.40306870441873177`}, {-4.176681684665101, 
             0.42826288463947965`}, {-4.314318769868701, 
             0.4425002628344425}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.337805441973743, 
             0.4449297580014312}, {-4.393374358187883, 
             0.45067788667514286`}, {-4.590649779275762, 
             0.4710853028042791}, {-4.77183802738231, 
             0.48982930406753905`}, {-4.940269181961099, 
             0.5072540615055732}, {-5.097420585301591, 
             0.5235123017546225}, {-5.245453324187551, 
             0.5388274455763487}, {-5.261211389399497, 
             0.5404577559720481}, {-5.277271316637329, 0.5421193235908658}}]}, 
           {Arrowheads[{{0.007580886855685788, 1.}}], 
            ArrowBox[{{-5.300757942992998, 
             0.5445492609903281}, {-5.413624381894984, 
             0.5562264757966959}, {-5.55823416919771, 
             0.5711880687249985}, {-5.656854249492381, 
             0.5814165944058113}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.4127282846895453`, 0.23356298524676067`}, {
             2.565646223311877, 0.24817735524355555`}, {2.7026229118162703`, 
             0.2612622860343847}, {2.8699574126807343`, 0.2772409416315769}, {
             3.020015306877747, 0.29156574235642985`}, {3.206244053264493, 
             0.309339021838682}, {3.352931854597339, 0.3233359554659165}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.376437087792185, 0.32557877194891754`}, {
             3.5620550656907475`, 0.3432875401495584}, {3.7327322539237815`, 
             0.3595689714935812}, {3.8776554979586444`, 0.3733924232686675}, {
             4.013954339374488, 0.38639266807605865`}, {4.141628778171313, 
             0.3985697059157547}, {4.260678814349118, 0.40992353678775567`}, {
             4.316649302330152, 0.4152611717743144}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.340154652363589, 0.4175027634279783}, {
             4.480334159507967, 0.43087100566996017`}, {4.680348855511329, 
             0.44994450276396014`}, {4.8640735173713905`, 
             0.4674638452676366}, {5.034858760100342, 0.4837488503788706}, {
             5.194198032415117, 0.49894203074228366`}, {5.280369418780621, 
             0.5071584064556536}}]}, 
           {Arrowheads[{{0.007508478263077633, 1.}}], 
            ArrowBox[{{5.303874804205894, 0.5093996269592026}, {
             5.3442774670825015`, 0.513251989930442}, {5.360927799793488, 
             0.5148395701390596}, {5.515450838730667, 0.5295728123575674}, {
             5.656854249492381, 0.5430549496033154}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7884813847297907`, -3.094751568379987}, \
{-2.9112827624751727`, -3.232866004089707}, {-3.0244096309697794`, \
-3.360108724454197}, {-3.1295823790291233`, -3.478411359791872}, \
{-3.227912550436039, -3.5890223038605606`}, {-3.320435300810959, \
-3.6931044196572946`}, {-3.4083522506627904`, -3.792007874195452}, \
{-3.416008477210784, -3.8006210237348808`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.431695538680703, -3.818268752080907}, \
{-3.4923793143986948`, -3.8865371649341305`}, {-3.6496846167443935`, \
-4.063508566632335}, {-3.7941928742913986`, -4.226089247990475}, \
{-3.927745753483054, -4.376349832247117}, {-4.0591528799724585`, \
-4.524200211774597}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.074838805147898, -4.54184895010703}, \
{-4.087221695937874, -4.555781338340882}, {-4.234599925015865, \
-4.721605660278218}, {-4.372394963262812, -4.8766506980581275`}, \
{-4.502003767648594, -5.022487507235611}, {-4.624432386562788, \
-5.160247279660433}, {-4.702255377806427, -5.2478166445196806`}}]}, 
           {Arrowheads[{{0.011148972945376716`, 1.}}], 
            ArrowBox[{{-4.717940480593959, -5.265466113743448}, \
{-4.7406868683949694`, -5.291061207182361}, {-4.850695825792413, \
-5.414683104239273}, {-4.9533809950599945`, -5.5293695023739176`}, \
{-4.958518013433246, -5.535075616775366}, {-5.044148170771985, \
-5.628908171080355}, {-5.070083340953858, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.8840769424218102`, 2.597679715891046}, {
             3.038643186789293, 2.7351252266474706`}, {3.17892090685286, 
             2.859852826712984}, {3.307790870849908, 2.974428751693474}, {
             3.4273345140113785`, 3.080706837401536}, {3.5388815048900453`, 
             3.1798709992591867`}, {3.5899172681469564`, 
             3.2252395724186025`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.6075644993285914`, 3.240927193173774}, {
             3.6436663793821187`, 3.273020193883019}, {3.743119092410612, 
             3.361427037184464}, {3.838088495531807, 3.445846908874431}, {
             4.015648364810488, 3.6036783114614708`}, {4.178487972734541, 
             3.7484195497272252`}, {4.313479243593444, 
             3.868403339916961}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.331127638510931, 3.884089651470831}, {
             4.42335800134607, 3.966064646810203}, {4.514708127958646, 
             4.047256473195074}, {4.685864177510563, 4.199376426128609}, {
             4.845400742556903, 4.341166227439568}, {4.995086317031445, 
             4.474198430952495}, {5.0370819697870814`, 
             4.511521259963797}}]}, 
           {Arrowheads[{{0.017120279134351584`, 1.}}], 
            ArrowBox[{{5.0547311789892975`, 4.527206655332502}, {
             5.136170775208802, 4.599584530779195}, {5.269903991363582, 
             4.718436021031468}, {5.396359530077824, 4.830917487132879}, {
             5.513950987796385, 4.936066969506295}, {5.520095895563912, 
             4.941589562422161}, {5.614624701337345, 5.0276503169947055`}, {
             5.656854249492381, 5.066721469325519}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.669567129769473, 2.6925770903832773`}, {
             3.844642178868102, 2.819752299597525}, {3.9933022634369704`, 
             2.9277355883728173`}, {4.133147617879627, 3.0293142643909348`}, {
             4.264178242196069, 3.124488327651877}, {4.386394136386299, 
             3.2132577781556444`}, {4.433731515389558, 
             3.247639909189121}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.45283603159164, 3.2615159199278216`}, {
             4.501690833895756, 3.297000187325031}, {4.611963868169879, 
             3.377093126582833}, {4.71721323920867, 3.4535365959290485`}, {
             4.8174389470121275`, 3.5263305953636785`}, {5.006241333192496, 
             3.663456499135312}, {5.181792986990435, 3.7909571525348613`}, {
             5.217024750169963, 3.8165452377837386`}}]}, 
           {Arrowheads[{{0.011010878403765639`, 1.}}], 
            ArrowBox[{{5.236129648778091, 3.8304207220098587`}, {
             5.345620235461579, 3.909941421888842}, {5.499957740680283, 
             4.022032745296375}, {5.508331567921945, 4.028114419153867}, {
             5.656854249492381, 4.135981650629513}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.745417301755194, 3.6879998010935138`}, {
             2.8770116121342144`, 3.8624101662581727`}, {2.989567169606729, 
             4.011579203811188}, {3.0954144586121046`, 4.1518540240482}, {
             3.194553479150341, 4.283234626969211}, {3.286984231221439, 
             4.40572101257422}, {3.314306901891538, 4.441927227037254}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.328530009446612, 4.460774758037704}, {
             3.3741550269836655`, 4.52123404438536}, {3.4575141785952903`, 
             4.631694585924766}, {3.5370616860563127`, 4.7371026371924385`}, {
             3.6127975493667326`, 4.837458198188375}, {3.755438541707153, 
             5.026464641036581}, {3.8880413537879392`, 5.202166706140919}, {
             3.897472151031755, 5.214662535299181}}]}, 
           {Arrowheads[{{0.011231242193877377`, 1.}}], 
            ArrowBox[{{3.9116961621336652`, 5.23350938441273}, {
             4.011765271054356, 5.366101195769116}, {4.128306989793831, 
             5.5205172729443035`}, {4.134336035224345, 5.528505619840208}, {
             4.231205689693268, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.6672265510618867`, -3.6061531675257616`}, \
{-2.792931918671533, -3.778460285216409}, {-2.90012813049973, \
-3.9254039725282532`}, {-3.0009675372222127`, -4.063637160495643}, \
{-3.095450138838981, -4.1931598491185795`}, {-3.1835759353500337`, \
-4.31397203839706}, {-3.2238482200102476`, -4.369182825192028}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2377630013701166`, -4.388259121295916}, \
{-3.2667141396134194`, -4.427949323491019}, {-3.346233964487185, \
-4.536967299560384}, {-3.4221354099713306`, -4.6410259666051585`}, \
{-3.4944184760658556`, -4.740125324625341}, {-3.6305954099357387`, \
-4.926825139518418}, {-3.757230705946527, -5.100445770166106}, \
{-3.7943385857385565`, -5.1513223952890135`}}]}, 
           {Arrowheads[{{0.012749833811447911`, 1.}}], 
            ArrowBox[{{-3.8082526459026553`, -5.170399217432284}, \
{-3.8754233615957787`, -5.262493385590351}, {-3.986782263095469, \
-5.4151730075677715`}, {-3.992670172645163, -5.423245714518637}, \
{-4.107091963342312, -5.580126623860261}, {-4.1630532537137865`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.1029938473994225`, -2.040352585379182}, \
{-1.159614569116437, -2.1479565394180526`}, {-1.2298948796982596`, \
-2.2816780454270575`}, {-1.2927045572958553`, -2.401290003515137}, \
{-1.370488238203296, -2.5495304135275987`}, {-1.4401120662872193`, \
-2.6822944103441277`}, {-1.5259407084945662`, -2.8460388241049843`}, \
{-1.5419652320144386`, -2.876621563745373}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.552924041386206, -2.8975364080070314`}, \
{-1.6028843476316268`, -2.9928854545083508`}, {-1.6990679397069972`, \
-3.176509212143119}, {-1.7852818757977358`, -3.3411388057902385`}, \
{-1.8827499032206079`, -3.5272962537134527`}, {-1.970869836843047, \
-3.6956238105670867`}, {-1.9910797565451646`, -3.73423318532172}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.002029917318965, -3.7551525589348107`}, \
{-2.046424099773594, -3.8399639610868315`}, {-2.117475841974154, \
-3.9757095646991734`}, {-2.184025063444727, -4.102860621404112}, \
{-2.2460717641853134`, -4.2214171312016475`}, {-2.3045893173275696`, \
-4.3332358802513395`}, {-2.3605510960031517`, -4.440173654712748}, \
{-2.4399781497721023`, -4.591957963729382}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-2.4509257330233387`, -4.612878686333858}, \
{-2.464807329954295, -4.6394062798707125`}, {-2.560587150324517, \
-4.822449199675633}, {-2.649637241399591, -4.992636607127602}, \
{-2.7327346405927777`, -5.151452252856829}, {-2.811016542484975, \
-5.301067717555427}, {-2.8168533550293655`, -5.312223382003977}, \
{-2.888795150973128, -5.449725335303995}}]}, 
           {Arrowheads[{{0.004450151256393435, 1.}}], 
            ArrowBox[{{-2.899741337784589, -5.470646788590544}, \
{-2.9737412910155463`, -5.612084580287432}, {-2.997165334005358, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.294493447877609, -0.6778054292507586}, \
{-2.4730607630839208`, -0.7312649525526018}, {-2.628511028079794, \
-0.7778288748934634}, {-2.7669953561848724`, -0.8193254594167104}, \
{-2.8932430045919513`, -0.857163298092965}, {-3.0097309617359733`, \
-0.8920812366465574}, {-3.199231730334049, -0.9488968595648487}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.2218489941489725`, -0.9556781271928236}, \
{-3.4103819839029055`, -1.0122145500459538`}, {-3.582964183703184, \
-1.0639740078033226`}, {-3.740098193465345, -1.1111044260976535`}, \
{-3.8859621389480212`, -1.1548568612421046`}, {-4.023117269511184, \
-1.195998445453142}, {-4.1265137528804114`, -1.2270148455933891`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            
            ArrowBox[{{-4.149130093620998, -1.2337991911655035`}, \
{-4.151563585154833, -1.2345291787307655`}, {-4.271301085878969, \
-1.2704490610749755`}, {-4.492197749058169, -1.3367182092555678`}, \
{-4.693355365538254, -1.3970678262873324`}, {-4.878150924282538, \
-1.4525103272580266`}, {-5.049961414254335, -1.504058127255408}, \
{-5.053774934989767, -1.5052023086820996`}}]}, 
           {Arrowheads[{{0.012833056904493597`, 1.}}], 
            ArrowBox[{{-5.076390918153031, -1.5119878461622955`}, \
{-5.210287493624618, -1.5521612149154247`}, {-5.361324958139491, \
-1.5974780446884191`}, {-5.374868831209764, -1.6015417363195432`}, \
{-5.530269419578594, -1.648168551068388}, {-5.656854249492381, \
-1.6861497777056969`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.418689735175412, -0.23106731407760875`}, \
{-2.571578198598223, -0.24586196223014078`}, {-2.707627287327386, \
-0.2590329142581998}, {-2.945894090444996, -0.2821077139723217}, \
{-3.150246613500253, -0.3019051228911426}, {-3.3398585346342133`, \
-0.3202789698219492}, {-3.35877101869589, -0.3221119175545362}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.3822728934520967`, -0.32438965684597193`}, \
{-3.509881699841139, -0.33675716349217166`}, {-3.6645903118659326`, \
-0.3517527577229493}, {-3.8081473549013785`, -0.365668404402557}, \
{-3.943101368017841, -0.3787506898673833}, {-4.187200304493819, \
-0.402415177152692}, {-4.3223460517214845`, -0.41551812837844126`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.345847843239084, -0.4177967263683142}, \
{-4.404366405939587, -0.4234703482809147}, {-4.602078957000866, \
-0.4426403319540911}, {-4.783673429069994, -0.4602482346401969}, \
{-4.9524852935393096`, -0.47661716280720773`}, {-5.10999453332234, \
-0.4918905197497499}, {-5.258366136864737, -0.5062780910640259}, \
{-5.274073570881186, -0.5078012532507559}, {-5.285918607166207, \
-0.5089498948713612}}]}, 
           {Arrowheads[{{0.007391718167082016, 1.}}], 
            ArrowBox[{{-5.309420357648339, -0.5112289160673534}, \
{-5.4268287501782035`, -0.5226142899086073}, {-5.571764700617052, \
-0.5366692676009476}, {-5.656854249492381, -0.5449488898056527}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2601554663040035`, -0.6651531964489333}, {
             2.38357688081155, -0.7009965397921587}, {
             2.5344005382668584`, -0.7447727049449899}, {
             2.6694807032453, -0.7839630668008015}, {
             2.834680495034332, -0.8318747310819279}, {
             2.982806440223432, -0.8748232571955306}, {
             3.166821613544672, -0.9281654639158732}, {
             3.16724015877019, -0.9282867706099712}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.1899188398071296`, -0.934859718180195}, {
             3.33176982920638, -0.9759722994007234}, {
             3.518226426035014, -1.0300048737639524`}, {
             3.6867340404547146`, -1.0788308410080898`}, {
             3.830261162279847, -1.1204152183031149`}, {
             3.9652295584880237`, -1.1595183072136828`}, {
             4.091639229079243, -1.1961401077397928`}, {
             4.0970835641812675`, -1.1977172897360377`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.119763076090496, -1.204287369864567}, {
             4.209490174053507, -1.2302806198814458`}, {
             4.426900368829886, -1.2932596665792495`}, {
             4.624844624495878, -1.3505973348749645`}, {
             4.8066478020759416`, -1.4032575378334406`}, {
             4.975634762594535, -1.452204188519529}, {
             5.026950307346917, -1.467067256101107}}]}, 
           {Arrowheads[{{0.013387225129404727`, 1.}}], 
            ArrowBox[{{5.0496301323672235`, -1.4736362552931024`}, {
             5.133286235088483, -1.497866463008082}, {
             5.281769405471644, -1.5408724772067044`}, {
             5.2970726038974005`, -1.5453047892521348`}, {
             5.44993916067536, -1.5895793222540051`}, {
             5.594954865454907, -1.631579505213667}, {
             5.656854249492381, -1.6495718007225706`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.4123776168429227`, -0.23227375876861298`}, {
             2.565279153690401, -0.24680800150202492`}, {
             2.7022410046016203`, -0.25982116950551853`}, {
             2.869556503242965, -0.27571210101917126`}, {
             3.0195971963748818`, -0.28995823688627537`}, {
             3.205804224121274, -0.30763387299101475`}, {
             3.352626744051561, -0.32156831543833503`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.3761331150474967`, -0.3237991753446156}, {
             3.5615722430143655`, -0.3413957285830338}, {
             3.732228235999089, -0.35758757894898574`}, {
             3.877135478177302, -0.3713351609191113}, {
             4.01341913493317, -0.38426404021630894`}, {
             4.141079206266694, -0.39637421684057883`}, {
             4.260115692177872, -0.4076656907919209}, {
             4.316390807422383, -0.41300350895902405`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.339897293987554, -0.41523315079071393`}, {
             4.479745757513352, -0.428498084429784}, {
             4.6797371807197665`, -0.4474667748838606}, {
             4.863440264543685, -0.46488982993588457`}, {
             5.034205311731676, -0.48108531736758947`}, {
             5.193525623277112, -0.49619496941118374`}, {
             5.280157515916868, -0.504410818246797}}]}, 
           {Arrowheads[{{0.007512598484907378, 1.}}], 
            ArrowBox[{{5.30366403758461, -0.506640089970968}, {
             5.343587111245361, -0.5104262468729501}, {
             5.360243947539114, -0.5120059034921525}, {
             5.5147489595354555`, -0.5266581781289699}, {
             5.656854249492381, -0.5401343479017324}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.528038807958366, -4.173616497267858}, {
             2.6068455048949306`, -4.3017808576300665`}, {
             2.681213009275952, -4.422720517074872}, {
             2.7511413211014304`, -4.536435475602275}, {
             2.817513547996715, -4.644363662176509}, {
             2.8812127975871538`, -4.747943005761808}, {
             3.0005923648534965`, -4.942055163965598}, {
             3.0227882176702616`, -4.978144285501628}}]}, 
           {Arrowheads[{{0.016377571823848826`, 1.}}], 
            ArrowBox[{{3.0351580128422238`, -4.998256828372679}, {
             3.1109913804686355`, -5.121557322539267}, {
             3.2141212020007486`, -5.289234853808439}, {
             3.310773554500047, -5.446376044760795}, {
             3.401786906631429, -5.594238543167166}, {
             3.407506977732864, -5.603522256095883}, {
             3.4406430329039144`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.4284569805276233`, -4.079531926337144}, \
{-2.5094057501955485`, -4.2176516740149665`}, {-2.585421320082671, \
-4.347360356819053}, {-2.6565036901889907`, -4.4686579747494015`}, \
{-2.7236909786885692`, -4.58331363445556}, {-2.788021303755467, \
-4.693096442587073}, {-2.905978120181557, -4.894403389558219}}]}, 
           {Arrowheads[{{0.01821551213466354, 1.}}], 
            ArrowBox[{{-2.9179150225212727`, -4.91477583604453}, \
{-3.0186846163013095`, -5.086758430263446}, {-3.1216536084907944`, \
-5.262500491895668}, {-3.217879627945658, -5.426739007878777}, \
{-3.308545885098378, -5.581467727551902}, {-3.3139518830683627`, \
-5.590691065116749}, {-3.352976857377898, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.427788051044377, 
             4.079672944106258}, {-2.5087320016921786`, 
             4.217827844394215}, {-2.5847420711611746`, 
             4.347567876484528}, {-2.6558182594513644`, 
             4.468893040377198}, {-2.7229989696968158`, 
             4.583573483881777}, {-2.7873226050315942`, 
             4.693379354807818}, {-2.9051975734159643`, 4.894609805671203}}]}, 
           {Arrowheads[{{0.018208917232794133`, 1.}}], 
            ArrowBox[{{-2.917131687404486, 
             4.914983885690034}, {-3.0179583246339, 
             5.087117886298978}, {-3.1209135533958143`, 
             5.262891650504263}, {-3.2171259956677654`, 
             5.427158572578094}, {-3.3077795136341175`, 
             5.581914361422631}, {-3.313184380321065, 
             5.591138695725187}, {-3.3519326015523485`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.057225156338248, -2.4267147352962484`}, \
{-4.197306618804885, -2.5112790760296297`}, {-4.328662355818984, \
-2.590578218219092}, {-4.451292367380545, -2.6646121618646346`}, \
{-4.567061436273799, -2.7345058093683687`}, {-4.677834345282978, \
-2.8013840631324043`}, {-4.865778948993886, -2.9148568307532443`}}]}, 
           {Arrowheads[{{0.01907152177361536, 1.}}], 
            ArrowBox[{{-4.885992478340591, -2.9270609056743617`}, \
{-5.074347773095406, -3.0407847023089727`}, {-5.251086004238357, \
-3.1474965632525835`}, {-5.416119990069154, -3.247143430164224}, \
{-5.57160040240258, -3.341029457749108}, {-5.580602229431461, \
-3.346465985457964}, {-5.656854249492381, -3.392798880579345}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.262362103649927, -2.01699467774172}, \
{-4.384776152624521, -2.0754266469094604`}, {-4.5002463690691, \
-2.13054553088557}, {-4.610684663204634, -2.1832631759182846`}, \
{-4.816465484548566, -2.281494749153528}, {-5.0055530884495285`, \
-2.3717599085593855`}, {-5.114709066145885, -2.423868855723271}}]}, 
           {Arrowheads[{{0.012223538651672177`, 1.}}], 
            ArrowBox[{{-5.136017548404312, -2.434041111971442}, \
{-5.181381946700733, -2.45569719608005}, {-5.345480985388717, \
-2.5340361607265978`}, {-5.50008804746276, -2.60784464819722}, \
{-5.51090286990395, -2.613007610430767}, {-5.65223316138747, \
-2.6806777613980577`}, {-5.656854249492381, -2.682918258255715}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.287218794646422, -1.523478655621724}, \
{-4.410268327497663, -1.5675823324262619`}, {-4.637364385872133, \
-1.6489815926995557`}, {-4.844241355059958, -1.723136148765636}, \
{-5.0343479670223665`, -1.7912813828860525`}, {-5.1763073535469255`, \
-1.8421689059131154`}}]}, 
           {Arrowheads[{{0.010309980821190017`, 1.}}], 
            ArrowBox[{{-5.198534430913827, -1.8501365432706975`}, \
{-5.211132953720587, -1.854652677322355}, {-5.3761318571123144`, \
-1.9138001836596388`}, {-5.531592307496805, -1.9695292021456392`}, \
{-5.54369194121702, -1.973866674804576}, {-5.656854249492381, \
-2.0144335623030125`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.007251622487681, -4.260501298310743}, \
{-2.1091795591821465`, -4.480933414472422}, {-2.202006617698925, \
-4.681699671022102}, {-2.287287454417938, -4.866157422813942}, \
{-2.366576725719109, -5.037664024702101}, {-2.4036162829193954`, \
-5.117785963074453}}]}, 
           {Arrowheads[{{0.012077740359133905`, 1.}}], 
            ArrowBox[{{-2.4135243555573695`, -5.139218562308722}, \
{-2.4405661390275575`, -5.197713864964773}, {-2.5102680298637465`, \
-5.348494168428525}, {-2.515719152783866, -5.360286325652086}, \
{-2.587401540191727, -5.51535800373722}, {-2.653029317991407, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0066016639981044`, 
             4.259343801356955}, {-2.1084995868550362`, 
             4.4797237796358935`}, {-2.2012990268794175`, 
             4.6804419513316535`}, {-2.286554268928909, 
             4.864855058412041}, {-2.3658195978611714`, 
             5.0363198428448595`}, {-2.402947351851744, 5.116637237816122}}]}, 
           {Arrowheads[{{0.012104373180711092`, 1.}}], 
            ArrowBox[{{-2.4128549494035747`, 
             5.138070056671492}, {-2.439786544530294, 
             5.1963303964579515`}, {-2.509467183570038, 
             5.347073505009469}, {-2.5149210273307747`, 
             5.358872235302604}, {-2.586581910191369, 
             5.5139064263409265`}, {-2.6528728028614537`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.9082555658243456`, -3.205508462117499}, {
             3.0295510970158515`, -3.3374884832444227`}, {
             3.141858418342431, -3.4596811676127466`}, {
             3.246679626863181, -3.5737234147114743`}, {
             3.3450106190939826`, -3.6807002415644727`}, {
             3.4377890102198356`, -3.7816329561255273`}, {
             3.5261135545466544`, -3.8777181444454083`}, {
             3.5474008541166464`, -3.9008754448136775`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.563380425988548, -3.9182587556642288`}, {
             3.6106441654767516`, -3.969674418240747}, {
             3.769207877141614, -4.14216277178776}, {
             3.9152487252040933`, -4.301023115826492}, {
             4.050535289653858, -4.448180549416869}, {
             4.202586500000482, -4.613569862988701}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.218567234659049, -4.630952104878016}, {
             4.348660428405798, -4.772453926211265}, {
             4.483381916856336, -4.918987562212126}, {
             4.610485781407022, -5.05723404045039}, {
             4.730854356892044, -5.1881492977131165`}, {
             4.845369978145587, -5.3126892707873665`}, {
             4.857833910973559, -5.3262074707900116`}}]}, 
           {Arrowheads[{{0.009086422251906279, 1.}}], 
            ArrowBox[{{4.873839465082723, -5.34356686164899}, {
             4.953436237107566, -5.429896361225711}, {
             5.0539328272704385`, -5.538000571080964}, {
             5.059306653382128, -5.543745381333603}, {
             5.148037110898029, -5.6371940958657625`}, {
             5.1670388843209185`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.4885862569674213`, 
             2.5702833955290445`}, {-3.681470538387324, 
             2.7138793748597014`}, {-3.85588812472763, 
             2.8437338764160325`}, {-4.005203562207894, 
             2.9549038464841084`}, {-4.145642580427692, 
             3.059466949377102}, {-4.2461599986034235`, 
             3.1343081883497472`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.2650989321519726`, 
             3.1484093588465463`}, {-4.277205179387023, 
             3.1574231850950114`}, {-4.3998913590858875`, 
             3.248772553637838}, {-4.51561674871821, 
             3.3349405761501494`}, {-4.626296977477913, 
             3.4173527737765137`}, {-4.7319320453649985`, 
             3.496009146516931}, {-4.832521952379466, 
             3.570909694371401}, {-5.022009594958831, 
             3.7120062414809367`}, {-5.022641137734833, 
             3.7124765073336508`}}]}, 
           {Arrowheads[{{0.016244280377902, 1.}}], 
            ArrowBox[{{-5.041579433122145, 
             3.726578534888547}, {-5.198203216384296, 
             3.843205341163557}, {-5.3626359416248945`, 
             3.9656482548461454`}, {-5.517551791420275, 
             4.081005464725855}, {-5.525176517810469, 
             4.086683196264822}, {-5.656854249492381, 4.18473733597722}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.734856012505513, -3.647314204494975}, {
             2.8659877956602555`, -3.8198455787999275`}, {
             2.9783550287036773`, -3.967679887475489}, {
             3.0840144614889637`, -4.106685210217771}, {
             3.1829660940161144`, -4.236861547026774}, {
             3.2752099262851293`, -4.3582088979024975`}, {
             3.306396557803882, -4.399233977966089}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3206859783715315`, -4.418031282910602}, {
             3.3621958299166312`, -4.472636249851053}, {
             3.445373676531243, -4.582052589878551}, {
             3.5247434661289643`, -4.686457917984992}, {
             3.6003051987097945`, -4.785852234170375}, {
             3.7426086218264354`, -4.973035447876946}, {
             3.874888074886816, -5.147029848097237}, {
             3.892282133193606, -5.169908784199014}}]}, 
           {Arrowheads[{{0.012453121695246736`, 1.}}], 
            ArrowBox[{{3.906572514311869, -5.188705358909076}, {
             3.9983021526777462`, -5.309360153655436}, {
             4.114546361091109, -5.462257604456172}, {
             4.1206994027487935`, -5.470350721658418}, {
             4.240220709400672, -5.627555610510369}, {
             4.262496399454004, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.456232104240556, 4.093849338330807}, {
             2.5394623146497426`, 4.230448954118787}, {2.617640241224456, 
             4.358750309628864}, {2.690765883964697, 4.478753404861039}, {
             2.7598982476467326`, 4.5921985020184914`}, {2.826096337046832, 
             4.700825863304398}, {2.947710388859087, 4.900379583301354}}]}, 
           {Arrowheads[{{0.01826336562277227, 1.}}], 
            ArrowBox[{{2.9599985220408014`, 4.920542122730036}, {
             3.0635044576236514`, 5.0903748403578675`}, {3.1694991367099177`, 
             5.264285140218571}, {3.2685580923894264`, 5.42681050040741}, {
             3.361867227565858, 5.579863648067808}, {3.3676381580062666`, 
             5.589325960596796}, {3.409104761621193, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.002256078208667, -2.3420647254112112`}, {
             4.142310496619096, -2.4232478366879455`}, {
             4.273537766029254, -2.499311722236241}, {
             4.395937886439141, -2.5702563820560975`}, {
             4.511408492111119, -2.637182693059034}, {
             4.621847217307554, -2.7011915321565683`}, {
             4.819399648565819, -2.8156872822217274`}}]}, 
           {Arrowheads[{{0.01999798832016925, 1.}}], 
            ArrowBox[{{4.83982864912998, -2.8275271364971446`}, {
             5.016710540264189, -2.9300397677651415`}, {
             5.192518986205084, -3.0319280498181502`}, {
             5.356583231778057, -3.1270081526683735`}, {
             5.511141676442272, -3.2165779756936974`}, {
             5.521328852409699, -3.222481609590133}, {
             5.6525945752571305`, -3.2986729103808563`}, {
             5.656854249492381, -3.301163651384662}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.198264969611663, -1.9176395833853779`}, {
             4.318773704858778, -1.9721911827896252`}, {
             4.541145770562245, -2.0728499197674037`}, {
             4.743662589656218, -2.164517495311735}, {
             4.929709704698338, -2.2487274527114964`}, {
             5.0587028156101415`, -2.3071118600235407`}}]}, 
           {Arrowheads[{{0.0134063661002169, 1.}}], 
            ArrowBox[{{5.080213986514052, -2.316848170396516}, {
             5.102672658246248, -2.327013335255564}, {
             5.264060560137889, -2.400058589130704}, {
             5.416082596083601, -2.468863680466702}, {
             5.428445311692869, -2.4744589934139958`}, {
             5.580037090751618, -2.5430870788221442`}, {
             5.656854249492381, -2.57819770952007}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9966779123831733`, 4.214855313864861}, {
             2.0550206260006716`, 4.335737868184706}, {2.1100432488975667`, 
             4.449734601588911}, {2.1626599212897153`, 4.558743230852099}, {
             2.2606754145597727`, 4.7617961769554205`}, {2.3507109014826666`, 
             4.948306567985628}, {2.4072513651263834`, 
             5.065426522167784}}]}, 
           {Arrowheads[{{0.01340976999754528, 1.}}], 
            ArrowBox[{{2.4175166270033763`, 5.0866903555929435`}, {
             2.43441017773022, 5.121684265433683}, {2.512505012525099, 
             5.283446671786441}, {2.5860663910999184`, 5.435814461321698}, {
             2.591721406881919, 5.4475275423710645`}, {2.6651265348611166`, 
             5.599511859289508}, {2.6930785727335165`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.078743110101438, -4.317963694062103}, {
             2.1344160125331806`, -4.431554419071672}, {
             2.1876533359509764`, -4.540172549941889}, {
             2.2868212457447274`, -4.742491029264267}, {
             2.3779114854890304`, -4.9283195721129}, {
             2.4625887011902257`, -5.101058618571449}, {
             2.4944442081129874`, -5.166040658642704}}]}, 
           {Arrowheads[{{0.011077314800936846`, 1.}}], 
            ArrowBox[{{2.5048376091080398`, -5.187242154559082}, {
             2.5415937817943526`, -5.262221061413685}, {
             2.6160110120197113`, -5.4140208812169}, {
             2.621753955979994, -5.425735464007147}, {
             2.697889774560244, -5.581035526254058}, {
             2.735301261443004, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.89296473314138, 2.2844229604593136`}, {
             4.043090252537367, 2.371663200458706}, {4.184327010701061, 
             2.4537357102772512`}, {4.316675007632463, 2.53064048991495}, {
             4.4401342433315705`, 2.602377539371801}, {4.556613768349032, 
             2.6700570901251415`}, {4.668022633235492, 2.7347893736523066`}, {
             4.709589063332809, 2.758940235370317}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.730005143924959, 2.770802354345904}, {
             4.875628382615411, 2.85541213902811}, {5.066402458012903, 
             2.9662521621697735`}, {5.243795825969546, 3.0693157697478566`}, {
             5.409348671012012, 3.165498254509648}, {5.546657936508757, 
             3.2452706436583063`}}]}, 
           {Arrowheads[{{0.0022007627280602685`, 1.}}], 
            ArrowBox[{{5.567074461200571, 3.2571319982539784`}, {
             5.575286546625603, 3.261902926826894}, {5.656854249492381, 
             3.3094844559131125`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.198891027005975, 1.924130427183293}, {
             4.319415529397681, 1.9788659454115463`}, {4.541816955282814, 
             2.079864194488519}, {4.744360774618431, 2.171841097133898}, {
             4.9304329071128254`, 2.2563353314334247`}, {5.058854335555936, 
             2.3146493755664315`}}]}, 
           {Arrowheads[{{0.013410510717143694`, 1.}}], 
            ArrowBox[{{5.080353642743271, 2.324411854954415}, {
             5.103419272474286, 2.33488557547284}, {5.264829168238598, 
             2.408177573249084}, {5.416872030484841, 2.4772151436900787`}, {
             5.429211273021638, 2.4828179352373247`}, {5.580808956685457, 
             2.551671697288972}, {5.656854249492381, 2.5865425334330214`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.402289714114355, -3.0330025393713043`}, {
             3.519799579128655, -3.136598954181581}, {
             3.6297768737754095`, -3.2335506113803705`}, {
             3.733342920034639, -3.324847251322565}, {
             3.83180510297079, -3.4116426184387603`}, {
             3.9259444163018604`, -3.4946258617621933`}, {
             4.102272843634975, -3.650054191574276}, {
             4.110788143926479, -3.657559915207602}}]}, 
           {Arrowheads[{{0.019999999999999987`, 1.}}], 
            ArrowBox[{{4.12850133314864, -3.6731730231914757`}, {
             4.264365021006413, -3.792928669845823}, {
             4.414257767388602, -3.925045725663844}, {
             4.589836137976155, -4.079798520948884}, {
             4.752389212497519, -4.223067552336377}, {
             4.837045066784098, -4.297679002844682}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.854759042682739, -4.313291218292803}, {
             4.904577731586908, -4.35719892760466}, {
             5.047879884485553, -4.483496039963922}, {
             5.183370134413649, -4.60290653209319}, {
             5.31212294459139, -4.716378046671495}, {
             5.433735186853927, -4.82371543524332}, {
             5.546328087930853, -4.923723036086113}, {
             5.552388555370041, -4.929135992385293}, {
             5.5627025336135745`, -4.938474341078449}}]}, 
           {Arrowheads[{{0.0021922746270970936`, 1.}}], 
            ArrowBox[{{5.5802060520757335`, -4.954322150226121}, {
             5.644260024718263, -5.012317069121056}, {
             5.656854249492381, -5.0239137113975705`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.3026498542313436`, -2.4142909616637764`}, {
             3.4735222724434527`, -2.537830423085042}, {
             3.6670562792588957`, -2.6777444644633173`}, {
             3.8420162769083985`, -2.8042243995672003`}, {
             3.990593603729489, -2.9116281978704346`}, {
             4.068063990695098, -2.9676291406546222`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.087199866520614, -2.981461872479052}, {
             4.130360189781781, -3.0126611331019353`}, {
             4.261316035065275, -3.107323205261703}, {
             4.383461139579971, -3.1956144143497367`}, {
             4.498690297793544, -3.278905156068461}, {
             4.608898304173671, -3.3585658261202984`}, {
             4.7140851587203505`, -3.4345964245052496`}, {
             4.8142508614335835`, -3.5069969512233143`}, {
             4.852649233715414, -3.534751315231213}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.871785731762852, -3.548583186247693}, {
             5.002939304559772, -3.6433810587623205`}, {
             5.178384126752298, -3.7701914178408535`}, {
             5.342110895141531, -3.8885310016187846`}, {
             5.496353186278735, -4.000014639916023}, {
             5.50478340148976, -4.006107834445485}, {
             5.637250187050599, -4.101851754851589}}]}, 
           {Arrowheads[{{0.000012210791234108218`, 1.}}], 
            ArrowBox[{{5.656386900662731, -4.115683327627791}, {
             5.656854249492381, -4.116021116523011}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.207599827990865, 
             2.504639476863202}, {-4.338932337692007, 
             2.5835197056277206`}, {-4.461564944282769, 
             2.6571771117602485`}, {-4.577353584143219, 
             2.726725548480054}, {-4.6881541936534195`, 
             2.793278869006404}, {-4.894791321623076, 
             2.917400161478738}, {-5.0172505239259415`, 
             2.9909600415401263`}}]}, 
           {Arrowheads[{{0.015302617327942464`, 1.}}], 
            ArrowBox[{{-5.037491486776149, 
             3.003118562676871}, {-5.084849439387352, 
             3.031565957797225}, {-5.261701658141859, 
             3.1378012265818387`}, {-5.426858313908999, 
             3.2370127945456875`}, {-5.5824532648361265`, 
             3.330488988046189}, {-5.591454685547345, 
             3.335897634458063}, {-5.656854249492381, 
             3.3754265996069375`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.5499371215029512`, -4.244977647184311}, {
             1.5954237740532062`, -4.366615352901661}, {
             1.679355359344489, -4.59103505684163}, {
             1.7557925996757306`, -4.795394696806511}, {
             1.8260144096497415`, -4.983120296256018}, {
             1.8808124404636435`, -5.129603818646515}}]}, 
           {Arrowheads[{{0.011420723185431103`, 1.}}], 
            ArrowBox[{{1.8890855196877627`, -5.1517190254845175`}, {
             1.8912997038693322`, -5.157637878649864}, {
             1.95221812867429, -5.320472623111364}, {
             2.0096034762716988`, -5.4738567489946846`}, {
             2.0144381033127012`, -5.486778839287902}, {
             2.073481378483256, -5.644584782145998}, {
             2.078076229363347, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.525317003517521, -4.293065758878993}, \
{-1.568018872557213, -4.416239510052205}, {-1.646838050190452, \
-4.64361686520396}, {-1.7186455901129967`, -4.850786252042648}, \
{-1.7846357840294864`, -5.041187057920847}, {-1.8346353388084766`, \
-5.185458109709238}}]}, 
           {Arrowheads[{{0.010064519839039478`, 1.}}], 
            ArrowBox[{{-1.8423672976094791`, -5.207768264940338}, \
{-1.8460029236445619`, -5.218258670191127}, {-1.9032793681877989`, \
-5.383535002833281}, {-1.9572444857433238`, -5.5392618704775405`}, \
{-1.9615661842832743`, -5.551733200718043}, {-1.9979927049573571`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.830200531826308, -3.5077486636394966`}, \
{-4.931752292659638, -3.5820606559019246`}, {-5.123181977510307, \
-3.72214321493001}, {-5.301310549626445, -3.8524934262143335`}, \
{-5.467658987071922, -3.97422406196697}, {-5.592393139966778, \
-4.065515970589566}}]}, 
           {Arrowheads[{{0.0011919458526083435`, 1.}}], 
            ArrowBox[{{-5.611447058703229, -4.079461378225089}, \
{-5.624381548172226, -4.088928025516781}, {-5.631850837218271, \
-4.094395941576074}, {-5.656854249492381, -4.112726591181938}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.5263106051547597`, 
             4.291597811792024}, {-1.5690430278383358`, 
             4.4147357663373725`}, {-1.6479182734166902`, 
             4.642046137411443}, {-1.7197766100582066`, 
             4.849153716731709}, {-1.7858132665853101`, 
             5.039497120970163}, {-1.8359067017947268`, 5.183893837395018}}]}, 
           {Arrowheads[{{0.010100719822135127`, 1.}}], 
            ArrowBox[{{-1.843645601807271, 
             5.206201585823131}, {-1.847223471820426, 
             5.216514966798796}, {-1.904539990273264, 
             5.381740789155067}, {-1.9585427802685218`, 
             5.53741983898564}, {-1.9628700865306787`, 
             5.549894809376265}, {-1.9999709055116965`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.5651897926874778`, 4.36206177369033}, {
             1.6109374778470227`, 4.486575149897709}, {1.695376046495421, 
             4.716371604719754}, {1.7722969029965954`, 4.925688853313643}, {
             1.8429801396561591`, 5.118016610391246}, {1.8909662683586606`, 
             5.24857834325691}}]}, 
           {Arrowheads[{{0.00871103675200543, 1.}}], 
            ArrowBox[{{1.8991117863868576`, 5.27074085099833}, {
             1.9087058487797262`, 5.296844590664433}, {1.9700449690156208`, 
             5.463728490760975}, {2.0278333917753515`, 5.620945776604338}, {
             2.032367475664256, 5.633280807246708}, {2.0410329605203534`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.071343151408519, 
             2.7737436825155757`}, {-3.2096824763084966`, 
             2.90019118629126}, {-3.3369245120854694`, 
             3.016502906320827}, {-3.455077357609059, 
             3.1245115327810056`}, {-3.5654286896558327`, 
             3.225392580890712}, {-3.669174140763775, 
             3.320237773324053}, {-3.767697989182672, 
             3.410311361991016}, {-3.7684460101452357`, 3.410995237615157}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.785872680706881, 
             3.4269275119811113`}, {-3.861823133261541, 
             3.4963649552402103`}, {-4.037923382192177, 
             3.6573680146342156`}, {-4.199567035141644, 
             3.8051586698039106`}, {-4.348846239695908, 
             3.941648639047139}, {-4.482920614321196, 4.064239146335836}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.500346413284994, 
             4.080172374000356}, {-4.529500223559264, 
             4.106829074066343}, {-4.696186222126236, 
             4.259241349152974}, {-4.851848844638917, 
             4.40157649385547}, {-4.998123985120695, 
             4.535329524589626}, {-5.136179809314774, 
             4.661568458914394}, {-5.197364446404622, 4.717516710102428}}]}, 
           {Arrowheads[{{0.012762481584982855`, 1.}}], 
            ArrowBox[{{-5.214789641232821, 
             4.7334505984707915`}, {-5.26718448296436, 
             4.781361314388723}, {-5.390939171715197, 
             4.894677773816564}, {-5.505814661874156, 
             5.000514676036029}, {-5.511423799929898, 
             5.005710881583314}, {-5.606352263517104, 
             5.094859245818972}, {-5.656854249492381, 
             5.143086101555365}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.1069097986654475`, -2.8098525465531443`}, \
{-3.243821532152966, -2.93515784214023}, {-3.36996708110416, \
-3.0506166949506155`}, {-3.4872579546929603`, -3.1579760201765437`}, \
{-3.5969302244125787`, -3.2583657391125014`}, {-3.700135126138605, \
-3.3528384383193375`}, {-3.7982090793116265`, -3.4426162739518023`}, \
{-3.8036019765856413`, -3.447553063625532}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.821018428252841, -3.4634965081925086`}, \
{-3.891948465006993, -3.528427593509569}, {-4.067448904805216, \
-3.6890888397794006`}, {-4.228687187214179, -3.8366984878856183`}, \
{-4.377714053914787, -3.9731328485850077`}, {-4.517657994248513, \
-4.101254500029491}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.535073605681716, -4.117198862410715}, \
{-4.554361584343405, -4.134857416780904}, {-4.717710421869597, \
-4.2844099684066554`}, {-4.870510108978538, -4.4243064601514135`}, \
{-5.014288169273096, -4.555944645731374}, {-5.150146740814098, \
-4.680333537141438}, {-5.2316843160927595`, -4.754988372675742}}]}, 
           {Arrowheads[{{0.011785167094535818`, 1.}}], 
            ArrowBox[{{-5.249099347490327, -4.770933368591636}, \
{-5.27918796166237, -4.798482146376506}, {-5.400997771595175, \
-4.910198761958396}, {-5.513878623623228, -5.014425194883436}, \
{-5.519434395687326, -5.019584366343999}, {-5.613860151542591, \
-5.108507610183925}, {-5.656854249492381, -5.1496928177797665`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7879065647091683`, 
             3.0964131087322064`}, {-2.910590485064986, 
             3.234498603277594}, {-3.023615657164897, 
             3.3617219820615767`}, {-3.1286985645386336`, 
             3.480011930819153}, {-3.2269485408982286`, 
             3.590615291894078}, {-3.3193987891627685`, 
             3.6946936016546754`}, {-3.4072487683157293`, 
             3.7935956048403634`}, {-3.415171651546147, 
             3.80251540347115}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.4308521629123496`, 
             3.8201689520274758`}, {-3.4912131636259143`, 
             3.8881250174975146`}, {-3.648404848934474, 
             4.065100820639526}, {-3.7928131375214886`, 
             4.22769050990735}, {-3.9262773218199962`, 
             4.377963584127624}, {-4.058047448928528, 4.526333248862716}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.0737268228741925`, 
             4.5439878076509785`}, {-4.085530072012441, 
             4.557277952814034}, {-4.232713352055814, 
             4.723006760254769}, {-4.370334085358301, 
             4.877971466261939}, {-4.49978500714667, 
             5.023739548508938}, {-4.622069516642445, 
             5.161440063049529}, {-4.700881287159645, 5.25018835928473}}]}, 
           {Arrowheads[{{0.011077326047322242`, 1.}}], 
            ArrowBox[{{-4.716559837819158, 
             5.267843649215887}, {-4.738191013067147, 
             5.292202065937475}, {-4.848075446552048, 
             5.4157764584198995`}, {-4.950638257815268, 
             5.5304122354548335`}, {-4.955773618198512, 
             5.536120799507513}, {-5.041245878047681, 
             5.629851282001513}, {-5.066286853386372, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.85610698114697, 3.155442748283648}, {
             2.9800844971283422`, 3.2906303833081125`}, {3.0945392137994516`, 
             3.415425867163996}, {3.2011177331921843`, 3.5316275857773842`}, {
             3.300897086058704, 3.64041154153187}, {3.3948855867988503`, 
             3.7428784606121948`}, {3.4842593710352117`, 3.840311984967487}, {
             3.49451221505858, 3.851489224684458}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.510473375503505, 3.868889442228717}, {
             3.5697214992402326`, 3.933479372620403}, {3.729830728845455, 
             4.108019234203855}, {3.877053158192924, 4.268505038132048}, {
             4.013228669861048, 4.416943777174478}, {4.148943323345241, 
             4.564876558979563}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.164905532236255, 4.582275814729617}, {
             4.171065098562434, 4.588989914924043}, {4.317333870005884, 
             4.748423069889709}, {4.454377558569571, 4.897798294946723}, {
             4.583497594463592, 5.038535063914667}, {4.705643205027638, 
             5.171668022676746}, {4.80341184849549, 5.2782295670273225`}}]}, 
           {Arrowheads[{{0.010456704895009257`, 1.}}], 
            ArrowBox[{{4.819374791117619, 5.295628149618407}, {
             4.821763617601402, 5.298231817116168}, {4.931444656882217, 
             5.4175138063307555`}, {5.0335913152087075`, 5.527773502494344}, {
             5.039016361739808, 5.533594624291018}, {5.127834292232606, 
             5.627529048488073}, {5.1560476155637085`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.665616873242427, 
             3.6058099211175567`}, {-2.7912454773249014`, 
             3.7781003647894744`}, {-2.898378532256854, 
             3.9250329875829015`}, {-2.999158424159059, 
             4.063255621073363}, {-3.0935851530315164`, 
             4.1927682652608596`}, {-3.1816587188742265`, 
             4.3135709201453905`}, {-3.2220517969340934`, 
             4.368975772370386}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.2359619108163535`, 
             4.388055472187697}, {-3.264747567353778, 
             4.42753909471064}, {-3.3442201441367603`, 
             4.536548297940293}, {-3.4200764492231728`, 
             4.640598529834348}, {-3.4923164826130164`, 
             4.739689790392807}, {-3.6284122584187575`, 
             4.926374221969293}, {-3.754971995669745, 
             5.099980417136112}, {-3.7923508304453266`, 5.151254863793155}}]}, 
           {Arrowheads[{{0.012749241543300595`, 1.}}], 
            ArrowBox[{{-3.8062602255048765`, 
             5.170335087649638}, {-3.873094051225506, 
             5.262014441818195}, {-3.984386384769441, 
             5.414681182583653}, {-3.990275718683333, 
             5.422759990315088}, {-4.104629419967249, 
             5.579628076307219}, {-4.160925412673253, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.35926956748898, 
             1.566210267226452}, {-4.484088944610224, 
             1.6114380193182847`}, {-4.714498575564548, 
             1.6949288829507425`}, {-4.924433859461455, 
             1.7710031973136042`}, {-5.11738166435315, 
             1.8409237087049393`}, {-5.2472464244355495`, 
             1.8879850995791367`}}]}, 
           {Arrowheads[{{0.008725724262624189, 1.}}], 
            ArrowBox[{{-5.269445709305158, 
             1.8960298472205557`}, {-5.296828858291836, 
             1.905953163422817}, {-5.464329501430083, 
             1.9666544503802392`}, {-5.622158731265614, 
             2.0238516585860395`}, {-5.63382786106407, 
             2.028080572625665}, {-5.656854249492381, 
             2.0364254840926304`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.3524825741767135`, 
             2.0590948297203804`}, {-4.467213860432389, 
             2.113836356958144}, {-4.576941146653129, 
             2.1661910625163836`}, {-4.781383718989797, 
             2.2637400085942905`}, {-4.969228080932513, 
             2.353371493906734}, {-5.143892022227072, 
             2.436715344406347}, {-5.204897881730751, 2.465825803041525}}]}, 
           {Arrowheads[{{0.010107093228721284`, 1.}}], 
            ArrowBox[{{-5.226208068842087, 
             2.475994487254146}, {-5.306896341958695, 
             2.514496897612995}, {-5.460466846588895, 
             2.5877777683765824`}, {-5.471440767005563, 
             2.593014342524228}, {-5.619414540090901, 
             2.663713136021118}, {-5.656854249492381, 
             2.6818004917052813`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.710010217730994, -1.6207286594596642`}, {
             4.919158134515772, -1.6921218799974147`}, {
             5.111357931308138, -1.7577280189807307`}, {
             5.290080915270579, -1.81873276403973}, {
             5.456877383292336, -1.8756655524015606`}, {
             5.603852416556967, -1.9258320269816962`}}]}, 
           {Arrowheads[{{0.0006859266419506003, 1.}}], 
            ArrowBox[{{5.626198566332533, -1.933459333422609}, {
             5.626979666155908, -1.933725941778586}, {
             5.656854249492381, -1.9439227492922762`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.705901585903304, 1.6231644321299243`}, {
             4.91488738215428, 1.6946711256439686`}, {5.106936783727239, 
             1.7603810398547057`}, {5.28551898462955, 1.8214819502601483`}, {
             5.452183285639284, 1.878504207927798}, {5.599522916973066, 
             1.92891409759318}}]}, 
           {Arrowheads[{{0.0007831169399312522, 1.}}], 
            ArrowBox[{{5.621863546749258, 1.9365575571854559`}, {
             5.622171864900175, 1.936663042603535}, {5.656854249492381, 
             1.948528852059518}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012677478696383197`, 1.}}], 
            ArrowBox[{{0.7835324077204081, -5.065878246812284}, {
             0.8122699775244672, -5.243283265486946}, {
             0.8390916298023492, -5.4088454214022885`}, {
             0.8643620959715291, -5.56482241161141}, {
             0.8667155361203257, -5.579348090994088}, {
             0.8792737021609959, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012511358598748442`, 1.}}], 
            ArrowBox[{{-5.072369275158883, -0.7443936603909751}, \
{-5.250452714597777, -0.770717573840433}, {-5.416675926660034, \
-0.7952887197979501}, {-5.573299028839481, -0.8184410354234732}, \
{-5.587096095820942, -0.8204805546625761}, {-5.656854249492381, \
-0.8307924884507201}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012529033822775463`, 1.}}], 
            ArrowBox[{{-0.7396126735995812, -5.070778875329961}, \
{-0.7642405455234962, -5.248551683913144}, {-0.7872231665226743, \
-5.4144714448997595`}, {-0.8088745478699578, -5.570796355879454}, \
{-0.8108659328748707, -5.585175068177903}, {-0.8207922933052455, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012547950137548933`, 1.}}], 
            ArrowBox[{{-0.7412334133184388, 
             5.069921590541911}, {-0.7659188841481561, 
             5.24766725673504}, {-0.7889552494392749, 
             5.413561522222652}, {-0.81065725759929, 
             5.5698622950537215`}, {-0.8126540363034411, 
             5.5842440934190405`}, {-0.8227343976286859, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.6206913328500154`, -2.6805681917501443`}, \
{-3.8121040026123225`, -2.8237143338520028`}, {-3.9860264944231023`, \
-2.9537860307044785`}, {-4.145501670270318, -3.0730571421666286`}, \
{-4.2935723921419315`, -3.1838015280975105`}, {-4.377042465586233, \
-3.246231435191265}}]}, 
           {Arrowheads[{{0.008211088182562313, 1.}}], 
            ArrowBox[{{-4.395950816052281, -3.2603735883508542`}, \
{-4.431576601790047, -3.2870192399236284`}, {-4.561468336517131, \
-3.3841708863630457`}, {-4.572554977132991, -3.3924631286858404`}, \
{-4.706464504706774, -3.492621967802077}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012998632726904482`, 1.}}], 
            ArrowBox[{{0.7661490543953007, 5.050628912583255}, {
             0.7942883369570929, 5.227547348592408}, {0.8205513170175358, 
             5.392652508846277}, {0.845295237766947, 5.54819694860694}, {
             0.847621830022587, 5.562821784975436}, {0.8625818650782907, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012682483333178004`, 1.}}], 
            ArrowBox[{{-5.064889882485945, 
             0.7729631720555448}, {-5.242733044349076, 
             0.8003005048660543}, {-5.408730430017713, 
             0.825817338554585}, {-5.565139715837623, 
             0.8498605637898876}, {-5.578951511112695, 
             0.8519837233426412}, {-5.656854249492381, 0.863959098153639}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.480673999206945, -0.20656853721358281`}, \
{-4.71103393567264, -0.21727844064858282`}, {-4.920928241667, \
-0.2270372951625474}, {-5.113842796335865, -0.23600703760365208`}, \
{-5.2932634788250725`, -0.24434960482007248`}, {-5.424134482305859, \
-0.2504349043315157}}]}, 
           {Arrowheads[{{0.004433324018699979, 1.}}], 
            ArrowBox[{{-5.4477209908015505`, -0.2515316405435717}, \
{-5.460743585440706, -0.25213717107889005`}, {-5.618557093120508, \
-0.259475400860941}, {-5.6324858347290485`, -0.26012308521796107`}, \
{-5.656854249492381, -0.2612562418762767}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.22562048487671232`, 4.350103957353771}, {
             0.23313905134156848`, 4.474468017970044}, {0.24702724138551546`, 
             4.704019294185343}, {0.25968844279673853`, 
             4.9131435459670145`}, {0.27133043890329517`, 
             5.105318977570559}, {0.28216101303324287`, 5.284023793251481}, {
             0.2826965989015891, 5.292857507502153}}]}, 
           {Arrowheads[{{0.007222039061114653, 1.}}], 
            ArrowBox[{{0.2841255640805746, 5.31642622133752}, {
             0.29227316207765786`, 5.450809065974219}, {0.30180311793610876`, 
             5.6079456787530075`}, {0.3026909802753296, 5.622583185051865}, {
             0.3047708546803234, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-0.21450606530643723`, 
             4.482642787745656}, {-0.22359077041945413`, 
             4.71269814260833}, {-0.23185957773456692`, 
             4.92230314084432}, {-0.23945242678822012`, 
             5.114937717292642}, {-0.24650925711685834`, 
             5.294081806792314}, {-0.2517182045101312, 
             5.426389150106621}}]}, 
           {Arrowheads[{{0.004384032768402084, 1.}}], 
            ArrowBox[{{-0.25264709036654803`, 
             5.44998286504094}, {-0.25309216524077854`, 
             5.461287773641367}, {-0.2592919963635753, 
             5.6188285688962605`}, {-0.259864354753225, 
             5.633375524467805}, {-0.2607879219271164, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.21254141102739618`, -4.483263379354506}, \
{-0.22152535507166643`, -4.713346335052481}, {-0.22970238579190339`, \
-4.922976769368315}, {-0.23721091099344938`, -5.1156349467873445`}, \
{-0.2441893384816466, -5.294801131794906}, {-0.24933654605577277`, \
-5.427026092020666}}]}, 
           {Arrowheads[{{0.004370450468449313, 1.}}], 
            ArrowBox[{{-0.2502550099230407, -5.450620214963905}, \
{-0.2506990822241988, -5.462027845511612}, {-0.25682998825384645`, \
-5.619588272091847}, {-0.2573958180397269, -5.634132810626985}, \
{-0.25827953229180184`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.483540974278579, 
             0.2400682211422489}, {-4.714029139236573, 
             0.25251363946003746`}, {-4.9240418199541125`, 
             0.2638539645246401}, {-5.117066347180356, 
             0.2742773512732699}, {-5.296590051664465, 
             0.2839719546431399}, {-5.426646674252578, 
             0.29099542417431756`}}]}, 
           {Arrowheads[{{0.004381906581639332, 1.}}], 
            ArrowBox[{{-5.450224312051744, 
             0.2922686912898571}, {-5.464166953137262, 
             0.2930216380671882}, {-5.62207209730889, 
             0.30154917965197636`}, {-5.635962829338224, 
             0.30229934491323335`}, {-5.656854249492381, 
             0.3034287557193573}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.2424293003287309, -4.489674363306767}, {
             0.25678975643219126`, -4.71990633805843}, {
             0.26988162575584135`, -4.9296582544212635`}, {
             0.28191972200495363`, -5.122416353877545}, {
             0.2931188588848006, -5.301666877909552}, {
             0.3012847463964502, -5.432318504027004}}]}, 
           {Arrowheads[{{0.004263982383473963, 1.}}], 
            ArrowBox[{{0.3027576509577216, -5.455884512715145}, {
             0.30357518241161596`, -5.468964758273399}, {
             0.31342953927958056`, -5.626586606149342}, {
             0.31433847032931567`, -5.64112298796944}, {
             0.3153242055794199, -5.656854249492381}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sca\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(sca\\)]\\)}\"", 
           TraditionalForm]}}], {583.2, -576.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.5406056949254805`}, \
{-5.511312994300675, -2.534748543569309}, {-5.352203272978967, \
-2.5285261961043166`}, {-5.1921832354948485`, -2.522437348460743}, \
{-5.03125288184832, -2.516482000638588}, {-4.869412212039381, \
-2.5106601526378522`}, {-4.713039502623332, -2.5052112337397463`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689441106362918, -2.5044101435243964`}, \
{-4.543533802943005, -2.499504254188001}, {-4.3796295334077495`, \
-2.494192028260726}, {-4.215081887214449, -2.489056951198552}, \
{-4.049859729701197, -2.484096397367122}, {-3.883931926206086, \
-2.4793077411320796`}, {-3.7454067022247175`, -2.4754697510616888`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7218037666085984`, -2.474815806387043}, \
{-3.717298476729116, -2.4746909824934247`}, {-3.549959381270287, \
-2.470246121451157}, {-3.4151924611755278`, -2.4668039245755446`}, \
{-3.2800135886956188`, -2.463480709110332}, {-3.0854264018880686`, \
-2.4589353232659295`}, {-2.8901503761852725`, -2.454652811298459}, \
{-2.7775933032440627`, -2.452344036719495}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7539862759762292`, -2.4518598085584684`}, \
{-2.69418551158723, -2.45063317320792}, {-2.4975318080939406`, \
-2.4468764089943122`}, {-2.4717381081787684`, -2.4464017313555955`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.336825357213909, \
-2.444053256271173}, {-2.227582362199846, -2.4422634060844444`}, \
{-2.101272705093369, -2.4402539337156144`}, {-1.974837575071162, \
-2.4383624056511684`}, {-1.8482769721332266`, -2.4365888218911067`}, \
{-1.8096403515601125`, -2.4360838862616476`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7860303747026274`, -2.435775331363491}, \
{-1.7215908962795614`, -2.434933182435429}, {-1.594779347510167, \
-2.4333954872841352`}, {-1.4678423258250435`, -2.431975736437225}, \
{-1.3407798312241908`, -2.430673929894699}, {-1.2135918637076086`, \
-2.429490067656557}, {-1.0862784232752971`, -2.428424149722799}, \
{-0.9588395099272564, -2.427476176093425}, {-0.841596067434252, \
-2.4267133025494663`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8179844995799191, -2.4265720292591415`}, \
{-0.7035852644839873, -2.425934061747829}, {-0.5757699323887587, \
-2.4253399210316067`}, {-0.4478291273778013, -2.424863724619769}, \
{-0.3197628494511146, -2.4245054725123145`}, {-0.19157109860869825`, \
-2.424265164709244}, {-0.05426103571853691, -2.4241403547556555`}, {
             0.08300619914120178, -2.4241542636310207`}, {
             0.12649036372911768`, -2.4242026288480303`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15010234212192897`, -2.4242288912465337`}, {
             0.22023060597051713`, -2.42430689133534}, {
             0.35741218476941017`, -2.424598237868613}, {
             0.4945509355378805, -2.42502830323084}, {
             0.6316468582759276, -2.4255970874220214`}, {
             0.7686999529835524, -2.4263045904421565`}, {
             0.9057102196607545, -2.427150812291246}, {
             1.0426112901862568`, -2.4281335802624753`}, {
             1.0945701538662478`, -2.428558119901101}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1181813587337657`, -2.428751039677863}, {
             1.179336796438783, -2.429250721649031}, {
             1.3158867384183321`, -2.4305022364509123`}, {
             1.4522611161249046`, -2.4318881246681197`}, {
             1.5884599295585013`, -2.4334083863006537`}, {
             1.724483178719121, -2.435063021348513}, {
             1.860330863606764, -2.436852029811699}, {
             1.9960029842214313`, -2.438775411690211}, {
             2.062594286809071, -2.439808525509626}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0862034387131785`, -2.440174803689343}, {
             2.1322598409574782`, -2.440889334022617}, {
             2.2671065390497755`, -2.443046424359759}, {
             2.401749072227302, -2.4453357752455727`}, {
             2.536173140169162, -2.44775633024673}, {
             2.6703644425544564`, -2.4503070329299046`}, {
             2.8043086790622898`, -2.452986826861769}, {
             2.937991549371765, -2.455794655608995}, {
             3.03051619704374, -2.457830092886034}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0541224786016903`, -2.4583494042983363`}, {
             3.0713987531619846`, -2.4587294627382565`}, {
             3.2044112021273445`, -2.4617853913885965`}, {
             3.3371105126331653`, -2.4649607259611086`}, {
             3.4694813787823082`, -2.468253826662074}, {
             3.601508494677633, -2.471663053697775}, {
             3.7331765544220006`, -2.4751867672744927`}, {
             3.864470252118272, -2.4788233275985094`}, {
             3.9953742818693074`, -2.482571094876106}, {
             3.998287561424809, -2.482657206560801}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.021889246336786, -2.483354833002304}, {
             4.125873337777969, -2.4864284293135652`}, {
             4.255952113947116, -2.4903936911171685`}, {
             4.385595304479612, -2.494465240493197}, {
             4.514787603478314, -2.4986414376479327`}, {
             4.643513705046083, -2.502920642787658}, {
             4.7717583032857815`, -2.5073012161186536`}, {
             4.899506092300272, -2.511781517847202}, {
             4.965864338313311, -2.5141693226406714`}}]}, 
           {Arrowheads[{{0.01414296259282904, 1.}}], 
            ArrowBox[{{4.989461059554642, -2.515018416272217}, {
             5.026741766192412, -2.516359908179585}, {
             5.1534500190650645`, -2.5210347473220835`}, {
             5.279485365782822, -2.525795864317432}, {
             5.404627933074127, -2.5306282132577653`}, {
             5.528750832837611, -2.535522841923467}, {
             5.651727176971904, -2.540470798094921}, {
             5.656854249492381, -2.5406834968510954`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.541327997760137}, {-5.493135721953781, 
             2.534757143107525}, {-5.335322938556127, 
             2.528601705224157}, {-5.176621937617196, 
             2.5225786611068477`}, {-5.017032719136988, 
             2.516688010755597}, {-4.856555283115502, 
             2.510929754170405}, {-4.713039233869085, 2.505940749434661}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689441252132533, 
             2.505127534319824}, {-4.533446093708006, 
             2.499893593814283}, {-4.370941924136823, 
             2.4946364829223744`}, {-4.207804704654016, 
             2.489553351554567}, {-4.044003887920054, 
             2.484641651932145}, {-3.8795089265954026`, 
             2.479898836276392}, {-3.7454068784253742`, 
             2.4761856761118817`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7218039316976177`, 
             2.4755321326145934`}, {-3.7143198206800623`, 
             2.4753249045873083`}, {-3.548436570174033, 
             2.470919856864893}, {-3.4137112228597464`, 
             2.467478961280519}, {-3.2785758608533784`, 
             2.4641572114648973`}, {-3.0840021505383923`, 
             2.459612944587385}, {-2.888738964100607, 
             2.455331490242708}, {-2.7775936733130235`, 2.453052097317336}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753986644202684, 
             2.45256795899027}, {-2.692786301540022, 
             2.4513128484308653`}, {-2.496144162856638, 
             2.447557019151857}, {-2.4703524670333374`, 
             2.4470824696924187`}, {-2.444546998600464, 
             2.446612201231679}, {-2.3354877643520204`, 
             2.444735490842686}, {-2.226290728434438, 
             2.442946927042012}, {-2.027118072428805, 
             2.4398333223404696`}, {-1.8275784036895666`, 
             2.4370110879166984`}, {-1.8096408308037686`, 
             2.4367839941560074`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7860307298596547`, 
             2.4364850848973343`}, {-1.6276717222167232`, 
             2.4344802237706986`}, {-1.4273980280102743`, 
             2.43224072990247}, {-1.2267573210702198`, 
             2.4302926063120123`}, {-1.0257496013965604`, 
             2.428635852999326}, {-0.8415967391855209, 
             2.427387239576538}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8179852325963006, 
             2.427236453449907}, {-0.6226331238484252, 
             2.4261964572072667`}, {-0.4710990209844548, 
             2.42558456854329}, {-0.31956279892376194`, 
             2.425142213274926}, {-0.16802445766634688`, 
             2.4248693914021744`}, {-0.0164839972122095, 
             2.4247661029250356`}, {0.12648954354708564`, 
             2.424828601996738}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1501015175197435, 2.4248557521453384`}, {
             0.28660328128623214`, 2.4250681261575964`}, {0.4381500993305367, 
             2.4254734378672955`}, {0.5896990365715633, 
             2.4260482829726078`}, {0.7411656956338584, 2.426791364674479}, {
             0.8924656791419686, 2.4277013861738577`}, {1.0435989870958937`, 
             2.4287783474707427`}, {1.0945693132579082`, 
             2.429198321364885}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1181805047802829`, 2.4293928675802157`}, {
             1.194565619495633, 2.4300222485651344`}, {1.3453655763411867`, 
             2.4314330894570326`}, {1.495998857632556, 2.4330108701464375`}, {
             1.6464654633697404`, 2.434755590633349}, {1.7967653935527386`, 
             2.436667250917767}, {1.9481117505654844`, 2.4388330098192514`}, {
             2.0625926590916177`, 2.4405141787840465`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.086202106496355, 2.440860886988618}, {
             2.0973215667109506`, 2.4410241778958857`}, {2.2463190733567546`, 
             2.44337900706835}, {2.3950814535301577`, 2.445895857985807}, {
             2.543585890258421, 2.4485730912974177`}, {2.6918095665688058`, 
             2.451409067652345}, {2.8397296654885738`, 2.45440214769975}, {
             2.9873233700449875`, 2.457550692088795}, {3.0305147707450852`, 
             2.4585185912604994`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.05412083715455, 2.459047592213341}, {
             3.1345709069130394`, 2.460850440804047}, {3.281452989751357, 
             2.464296714523737}, {3.4279475320626593`, 2.467887244937525}, {
             3.574032447349664, 2.4716197637350694`}, {3.7196856491150863`, 
             2.4754920026060296`}, {3.8648850508616435`, 2.479501693240065}, {
             3.9982867478546145`, 2.4833223110305935`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.02188869798754, 2.484010801117518}, {
             4.153834108309032, 2.487924356555996}, {4.297539591015296, 
             2.49233279261721}, {4.440702927713564, 2.4968696072001357`}, {
             4.583302031906552, 2.5015325319944313`}, {4.725314817096977, 
             2.5063192986897564`}, {4.866719196787555, 2.5112276389757704`}, {
             4.965865681474388, 2.5147685895904295`}}]}, 
           {Arrowheads[{{0.014142935937732673`, 1.}}], 
            ArrowBox[{{4.9894626301534934`, 2.5156113388839954`}, {
             5.0074930844810055`, 2.5162552845421318`}, {5.147614393680042, 
             2.5213999670784997`}, {5.2870610378873835`, 
             2.5266594182745337`}, {5.424944477705057, 2.5319942372252005`}, {
             5.5598810577918405`, 2.537343804399929}, {5.656854249492381, 
             2.541282752932847}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.376283275407309}, {-5.460535168844498, 
             4.362059158185276}, {-5.2538710908085156`, 
             4.347617500494767}, {-5.045716135515288, 
             4.333611606926242}, {-4.83611660504006, 
             4.320056619767851}, {-4.71453535272136, 4.312514505572886}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690968660371194, 
             4.311052580469198}, {-4.6251188014580755`, 
             4.306967681307745}, {-4.412769026844581, 
             4.294359933834073}, {-4.199113583274819, 
             4.2822485196349875`}, {-3.984198772824036, 
             4.270648580998637}, {-3.768006922489746, 
             4.259581565053311}, {-3.7479518022437155`, 4.258611845738155}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.724367363171664, 
             4.257471474310575}, {-3.550543622934095, 
             4.249066626258154}, {-3.3318900717292705`, 
             4.239115467897605}, {-3.1121274664474594`, 
             4.2297397932561065`}, {-2.8913370046608504`, 
             4.2209513056180965`}, {-2.7807671860044216`, 
             4.216867540613254}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7571712811858897`, 
             4.215996053877304}, {-2.669599883941631, 
             4.212761708268016}, {-2.446997301861989, 
             4.205182704490307}, {-2.2236104559941112`, 
             4.1982259975694065`}, {-2.069035476140791, 
             4.193799050811214}, {-1.9141717642209264`, 
             4.189687031037946}, {-1.8131367431633876`, 4.187215279602089}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7895318129096074`, 
             4.1866378014203915`}, {-1.7590419555879242`, 
             4.1858918882922005`}, {-1.6034272418255078`, 
             4.182394772162184}, {-1.44764829044029, 
             4.179223308251389}, {-1.2916485130487514`, 
             4.176372621453318}, {-1.135427909650891, 
             4.173842711767969}, {-0.9789864802467092, 
             4.171633579195342}, {-0.8452046020730251, 
             4.170023286169843}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8215943013380711, 
             4.169740737123171}, {-0.6656510538953255, 
             4.168190804335902}, {-0.5088095345671099, 
             4.166960451785998}, {-0.35185214447054447`, 
             4.1660574558226395`}, {-0.3116508958297744, 
             4.165879003153829}, {-0.27144602630106673`, 
             4.165722203963496}, {-0.12317367708081581`, 4.165330909835761}, {
             0.025094561174700714`, 4.165233680665486}, {0.12286895690868357`,
              4.165363486172068}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14648092909828472`, 4.165394833479187}, {
             0.17335868846548275`, 4.1654305164526715`}, {0.3216187047915304, 
             4.165921417197316}, {0.33967017167167923`, 4.165999090128927}, {
             0.3577208959661671, 4.16608112907948}, {0.40065128185795107`, 
             4.1663113769707785`}, {0.4435770178293942, 
             4.1665663569168165`}, {0.611127127931116, 4.167748288014785}, {
             0.7785234709239464, 4.169302664233143}, {0.9457660468078851, 
             4.17122948557189}, {1.0909218573635147`, 4.173226937639482}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1145315597614285`, 4.1735555479342015`}, {
             1.279725114421894, 4.176195554771819}, {1.4463120404975767`, 
             4.179224984955532}, {1.6126156338099804`, 4.182617042582168}, {
             1.778635894359105, 4.186371727651726}, {1.9444466922986006`, 
             4.190497829373902}, {2.058792826888315, 4.193576715093578}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0823962650689656`, 4.194212261620887}, {
             2.1096294300911147`, 4.194945542227084}, {2.2744697389974293`, 
             4.199748851155431}, {2.438938070956084, 4.204904240475064}, {
             2.567157212949006, 4.209172097563038}, {2.695112515248817, 
             4.213645038985868}, {2.8227893694834334`, 4.218320719844363}, {
             2.9501731672807705`, 4.22319679523933}, {3.026326639759404, 
             4.226237588438734}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0499198318828276`, 4.227179659966481}, {
             3.077249300268746, 4.228270920271577}, {3.204003160075273, 
             4.233540750041914}, {3.3304201383282703`, 4.239003939651148}, {
             3.4564856266556525`, 4.244658144200088}, {3.5821850166853357`, 
             4.2505010187895405`}, {3.707503700045235, 4.256530218520314}, {
             3.832427068363268, 4.262743398493218}, {3.9569405132673494`, 
             4.26913821380906}, {3.993373257491014, 4.271068383939655}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.016952183320295, 4.2723175717051385`}, {
             4.081029426385395, 4.275712319568648}, {4.204679199345321, 
             4.28246337087279}, {4.327875223775044, 4.289389022822295}, {
             4.450602891302479, 4.29648693051797}, {4.694631678901405, 
             4.311164777167288}, {4.936722608643939, 4.326427438859652}, {
             4.959786564063328, 4.3279478052614}}]}, 
           {Arrowheads[{{0.014296095679757865`, 1.}}], 
            ArrowBox[{{4.983347421971383, 4.329500927269676}, {
             5.176871006757553, 4.3422579219353565`}, {5.415128957564976, 
             4.358679032844183}, {5.651500771156397, 4.375692424960325}, {
             5.656854249492381, 4.376094410273262}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.3693221130258815`}, \
{-5.603572178397411, -4.3653688740560375`}, {-5.39064358267865, \
-4.35016685679128}, {-5.176231886443473, -4.335466811738689}, \
{-4.960384906437659, -4.321288174013187}, {-4.743102642661206, \
-4.307630943614775}, {-4.714511782249149, -4.3059138226611}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.690942258740125, -4.304498275101418}, \
{-4.524385095114116, -4.294495120543454}, {-4.30423226379639, \
-4.281880704799223}, {-4.082644148708026, -4.269787696382081}, \
{-3.8596207498490234`, -4.258216095292029}, {-3.747888802409233, \
-4.252715485316696}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7243053709147436`, -4.251554463232113}, \
{-3.635162067219384, -4.247165901529068}, {-3.409492749725439, \
-4.236701020812507}, {-3.1828374462735187`, -4.226885358861659}, \
{-2.9551961568636242`, -4.217718915676522}, {-2.7806940911866826`, \
-4.21121805853849}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.757098466014273, -4.210339032907858}, \
{-2.726568881495756, -4.209201691257096}, {-2.4969556201699126`, \
-4.201333685603382}, {-2.2663563728860936`, -4.194114898715379}, \
{-2.0347711396443007`, -4.187545330593089}, {-1.8130526405321368`, \
-4.18190124884438}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7894476703375548`, -4.18132588706855}, \
{-1.7189766191863294`, -4.179673043042404}, {-1.6356706674507846`, \
-4.177811336745257}, {-1.4889395381306476`, -4.174757092085135}, \
{-1.3420038493593605`, -4.171986371313065}, {-1.1948636011369231`, \
-4.169499174429049}, {-1.0475187934633357`, -4.167295501433086}, \
{-1.0285728984095224`, -4.167030560625578}, {-1.0096244893607684`, \
-4.166770392901004}, {-0.9460470836068825, -4.165967523849967}, \
{-0.8824424422568995, -4.165218124010164}, {-0.8451187725133211, \
-4.164820613867847}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8215081185550651, -4.164569152141826}, \
{-0.7134751332458755, -4.1634185630475535`}, {-0.5444657428815807, \
-4.16200098291379}, {-0.37541427116401505`, -4.1609653836088745`}, \
{-0.20632071809317887`, -4.160311765132806}, {-0.03718508366907214, \
-4.160040127485586}, {0.12295484209485533`, -4.160144575928061}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14656677148941388`, -4.160192872318031}, {
             0.3012124292389533, -4.160642794677688}, {
             0.47047430772287213`, -4.1615170995170105`}, {
             0.6396428230625084, -4.162769206924329}, {
             0.8085825307603092, -4.1643949386387895`}, {
             0.9772934308162744, -4.1663942946603925`}, {
             1.0910079981233816`, -4.167995903635241}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.114617649488387, -4.168328432970881}, {
             1.1457755232304039`, -4.168767274989139}, {
             1.3140288080026976`, -4.171513879625027}, {
             1.4820532851331558`, -4.174634108568059}, {
             1.649848954621778, -4.178127961818234}, {
             1.8174158164685652`, -4.181995439375551}, {
             1.9862985022842257`, -4.186408895926322}, {
             2.058877536891689, -4.188377823224368}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0824808462856805`, -4.18901813485763}, {
             2.152444169880159, -4.190916103030288}, {
             2.318302924569904, -4.195790450879531}, {
             2.483845713721284, -4.201028697693114}, {
             2.649043484702123, -4.206627601690106}, {
             2.8138671848802446`, -4.212583921089571}, {
             2.9782877616234726`, -4.218894414110577}, {
             3.0264171741653416`, -4.220849494250143}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.050009710265705, -4.221807854145596}, {
             3.1422761622996305`, -4.2255558389721894`}, {
             3.275998551879442, -4.231252461286431}, {
             3.409371101125008, -4.2371620238828624`}, {
             3.5423750819565853`, -4.2432807879428065`}, {
             3.6749917662944296`, -4.249605014647586}, {
             3.8072024260587964`, -4.2561309651785235`}, {
             3.9389883331699416`, -4.26285490071694}, {
             3.993461916119724, -4.265724180328801}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.017041222200034, -4.266966169904931}, {
             4.070330759548121, -4.269773082444159}, {
             4.20121097711359, -4.276881771541501}, {
             4.331610257786606, -4.28417722919029}, {
             4.461509873487422, -4.2916557165718485`}, {
             4.590891096136296, -4.299313494867498}, {
             4.719735197653483, -4.3071468252585605`}, {
             4.848023449959238, -4.315151968926359}, {
             4.9598924525667165`, -4.322311184724734}}]}, 
           {Arrowheads[{{0.014293805450128646`, 1.}}], 
            ArrowBox[{{4.983455449053074, -4.323831415457377}, {
             5.10285749461748, -4.3316627408174515`}, {
             5.229365830810477, -4.340160891403391}, {
             5.355284370505244, -4.348820648492759}, {
             5.480658759244035, -4.357645735197657}, {
             5.605505381831827, -4.366636482843466}, {
             5.656854249492381, -4.370418099553683}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.0003864859356329797}, {-5.605325356244599, 
             0.0003861692591299577}, {-5.381407981851238, 
             0.00038484452433847153`}, {-5.155968680445485, 
             0.0003835631666651788}, {-4.929045827131806, 
             0.0003823267221612424}, {-4.712374529588443, 
             0.0003811976769879919}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688762536590781, 
             0.00038107710014673114`}, {-4.5321870469250465`, 
             0.0003802935600237211}, {-4.362959243292901, 
             0.0003794768144884722}, {-4.140519160651131, 
             0.0003784501057882934}, {-3.9169452324238954`, 
             0.0003774720913494177}, {-3.744282816681917, 
             0.00037675801428775266`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7206708236841495`, 
             0.0003766603625636792}, {-3.692237458611193, 
             0.000376542771171845}, {-3.4663958392130256`, 
             0.0003756621452555754}, {-3.4365800184983457`, 
             0.0003755493816005175}, {-3.4067463592295093`, 
             0.00037543750597576953`}, {-3.2670141749555466`, 
             0.0003749389650169995}, {-3.126916588528299, 
             0.0003744602491483866}, {-2.930237798822244, 
             0.000373809867199827}, {-2.7761911037712683`, 
             0.00037333427243228627`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752579110773411, 
             0.000373261374144418}, {-2.7330178946265673`, 
             0.00037320098198837014`}, {-2.5352568759412684`, 
             0.00037263359351401607`}, {-2.3369547427663466`, 
             0.00037210770177676473`}, {-2.1381114951018034`, 
             0.0003716233067766161}, {-1.9387271329476377`, 
             0.00037118040851357034`}, {-1.80809939085758, 
             0.00037091813991286133`}}]}, 
           {Arrowheads[{{0.0168774269632949, 1.}}], 
            ArrowBox[{{-1.784487397859658, 
             0.0003708707327980752}, {-1.7388016563038498`, 
             0.0003707790069876273}, {-1.5383350651704397`, 
             0.00037041910219878695`}, {-1.3009837892384037`, 
             0.0003701414952165304}, {-1.0636325133063673`, 
             0.0003698638882342739}, {-1.0584884273312694`, 
             0.0003698578864745869}, {-1.036296359501513, 
             0.0003698323268790148}, {-1.0161191182724092`, 
             0.00036980955674517944`}, {-0.9993240590830063, 
             0.00036979077244645293`}, {-0.9923382312457297, 
             0.0003697829268335679}, {-0.9874680232983247, 
             0.00036977741024229023`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0288490397368746`, 0.0008499518104741905}, {
             1.1700172278656646`, 0.0008503142518874442}, {
             1.3461855680171075`, 0.0008508667537814877}, {
             1.5221164597001033`, 0.0008514955783717411}, {1.697763409254558, 
             0.0008521998011302828}, {1.873100586869308, 
             0.0008529789084304896}, {1.973328759648866, 
             0.0008534675980937301}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.9969407526465548`, 0.0008535827247750462}, {
             2.0480980081377935`, 0.0008538321558607879}, {
             2.2227256886534534`, 0.0008547587990096042}, {2.331775414441622, 
             0.0008553756009872962}, {2.440662008241045, 
             0.0008560205870200982}, {2.670669739463428, 
             0.0008574767506169317}, {2.899790578933497, 
             0.0008590535489605626}, {2.9414204725474278`, 
             0.000859363160916531}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.9650324655447444`, 0.0008595387692282891}, {
             3.128024526651252, 0.0008607509820509908}, {3.355371582616692, 
             0.0008625690498882165}, {3.385255627513307, 
             0.0008628164401696904}, {3.41512216641045, 
             0.0008630658317356592}, {3.554347725760219, 
             0.0008642849087025278}, {3.6931679619021587`, 
             0.0008655465371984417}, {3.895547236484798, 
             0.0008674309465459551}, {3.9095121854291746`, 
             0.0008675672550074419}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.933124178426019, 0.0008677977259136269}, {
             4.096914779324318, 0.0008693964460309272}, {4.297270590420718, 
             0.0008714430356533578}, {4.496614669773998, 
             0.0008735707154132471}, {4.694947017384159, 
             0.000875779485310595}, {4.877603898290592, 
             0.0008778991760982615}}]}, 
           {Arrowheads[{{0.016001155817980024`, 1.}}], 
            ArrowBox[{{4.901215891286921, 0.000878177419282177}, {
             5.088576517375122, 0.0008804402955176667}, {5.283873669755923, 
             0.0008828923358273903}, {5.4780905801492095`, 
             0.0008854195761232389}, {5.656854249492381, 
             0.0008878237469269954}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.2156439935837364`}, {-5.440892529948433, 
             1.2116010958299965`}, {-5.2057531684585365`, 
             1.2073755399354689`}, {-4.968919687186176, 
             1.2032984788803454`}, {-4.837654972623195, 
             1.2011185776114248`}, {-4.712519865637228, 
             1.1990961221228364`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688910834307729, 
             1.198722183142573}, {-4.573700480827438, 
             1.1969118749785999`}, {-4.441043762162898, 
             1.1948876040047531`}, {-4.307956100699407, 
             1.1929177401859883`}, {-4.174454025721084, 
             1.1910035487173343`}, {-4.040554066512045, 
             1.1891462947938196`}, {-3.904862253445042, 
             1.1872392803013565`}, {-3.769684421654475, 
             1.18545899994645}, {-3.74452910941451, 1.185139634998635}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7209190190942274`, 
             1.1848398877646862`}, {-3.6341417642014284`, 
             1.1837381875267403`}, {-3.4982342810859013`, 
             1.1820768430422277`}, {-3.361961972307893, 
             1.1804749664929117`}, {-3.2253248378674035`, 
             1.1789325578787926`}, {-3.0883228777644343`, 
             1.1774496171998703`}, {-2.950956091998984, 
             1.1760261444561448`}, {-2.813224480571053, 
             1.1746621396476165`}, {-2.7764983554498093`, 
             1.1743156442358818`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7528874132478514`, 
             1.1740928850116863`}, {-2.675172046733854, 
             1.1733596734945584`}, {-2.536842793740599, 
             1.1721208167172443`}, {-2.3982367215912888`, 
             1.1709455693156743`}, {-2.259353830285922, 
             1.1698339312898485`}, {-2.1201941198245002`, 
             1.1687859026397667`}, {-1.9807575902070222`, 
             1.167801483365429}, {-1.8410442414334884`, 
             1.1668806734668355`}, {-1.8084371975611817`, 
             1.1666810110514723`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.784825647212962, 
             1.1665364306598411`}, {-1.7010540735038986`, 
             1.166023472943986}, {-1.556593533571855, 
             1.1652086941302704`}, {-1.4119458529880398`, 
             1.1644650799477902`}, {-1.2671110317524525`, 
             1.1637926303965453`}, {-1.1235861950792687`, 
             1.162622028426653}, {-0.978470662866024, 
             1.1620563258222611`}, {-0.8403601936585592, 
             1.1615179309934454`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8167483800704296, 
             1.1614258852679638`}, {-0.6882395984395342, 
             1.1609249206134773`}, {-0.5431240662262891, 
             1.1603592180090856`}, {-0.4972398192485827, 
             1.1602728377281373`}, {-0.4513503823645356, 
             1.1601938804620548`}, {-0.22307227901107948`, 
             1.1598373975648082`}, {0.005205824342376764, 
             1.1594809146675615`}, {0.1277285548224462, 
             1.1594831023105714`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15134054781665196`, 1.1594835239026402`}, {
             0.23364898074991264`, 1.15948499351948}, {0.4620921371574485, 
             1.1594890723713986`}, {0.4878160535368051, 
             1.1595301668509723`}, {0.5135379807380042, 
             1.1595735488117163`}, {0.561394988971947, 1.1596666967736866`}, {
             0.6092443792771737, 1.1597678113996521`}, {0.7553082273793453, 
             1.1603723473243626`}, {0.9013720754815169, 
             1.1609768832490728`}, {1.0474359235836883`, 
             1.1615814191737832`}, {1.095815833310396, 
             1.161781656219733}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.119427624073597, 1.161879381809936}, {
             1.19349977168586, 1.1621859550984937`}, {1.3378305642248078`, 
             1.1633982945687302`}, {1.483588578992293, 1.1641100899426513`}, {
             1.6291427048699867`, 1.1648933916160458`}, {1.7744929418578899`, 
             1.165748199588914}, {1.913865349527117, 1.1666350636467917`}, {
             2.0529574090685663`, 1.167584868323642}, {2.063888903338213, 
             1.1676646225409566`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0875002679399617`, 1.1678368868130764`}, {
             2.1917691204822374`, 1.1685976136194653`}, {2.33030048376813, 
             1.1696732995342611`}, {2.4685514989262445`, 1.17081192606803}, {
             2.6065221659565805`, 1.1720134932207715`}, {2.744212484859138, 
             1.1732780009924861`}, {2.8816224556339174`, 
             1.1746054493831732`}, {3.0187072107567303`, 
             1.1759936457266404`}, {3.031943127996604, 
             1.1761337117822392`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.055553799017609, 1.176383566287977}, {
             3.1554218827033877`, 1.1774403973566945`}, {3.29176647147389, 
             1.1789457042733358`}, {3.427740977068237, 1.180509566476564}, {
             3.563345399486429, 1.1821319839663789`}, {3.6985797387284656`, 
             1.183812956742781}, {3.8334439947943473`, 1.1855524848057704`}, {
             3.9679381676840735`, 1.1873505681553465`}, {3.999963985725414, 
             1.1878068467877434`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.023573582670831, 1.1881432177304556`}, {
             4.102901086633642, 1.1892734135297598`}, {4.2361318109830846`, 
             1.1911473060703415`}, {4.36896089745157, 1.193077263361902}, {
             4.501372568686697, 1.1950620401366374`}, {4.633351047336063, 
             1.1971003911267435`}, {4.7648805560472685`, 
             1.1991910710644162`}, {4.895945317467912, 1.2013328346818515`}, {
             4.967943187768149, 1.202541178679226}}]}, 
           {Arrowheads[{{0.014090513364474895`, 1.}}], 
            ArrowBox[{{4.991551856063591, 1.2029374041856449`}, {
             5.026529554245592, 1.2035244367112452`}, {5.150738997828238, 
             1.2056616216312512`}, {5.274490852542233, 1.2078407270974203`}, {
             5.397774221862363, 1.210060240733625}, {5.520578209263414, 
             1.212318650163737}, {5.656854249492381, 1.214906806013154}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.2137864260074134`}, \
{-5.437511955919041, -1.2096888413720646`}, {-5.201846881598805, \
-1.2054631118546506`}, {-4.96448181014819, -1.2013864101995215`}, \
{-4.833347554609729, -1.199213903572769}, {-4.7125193880800165`, \
-1.197265741768072}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688910372304663, -1.1968908288371043`}, \
{-4.569658377620869, -1.1950215029216353`}, {-4.437136352061697, \
-1.1930041231717672`}, {-4.3041846323868445`, -1.1910409666553734`}, \
{-4.1708196665419255`, -1.1891332905097107`}, {-4.037057902472552, \
-1.1872823518720352`}, {-3.901512230098744, -1.1853821321670508`}, \
{-3.7664771378334336`, -1.183608002042036}, {-3.7445283323777345`, \
-1.1833300123034}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.72091823297066, -1.1830309816624573`}, \
{-3.631078143234893, -1.1818931236995218`}, {-3.495315246303123, \
-1.180237497139508}, {-3.3591884470381244`, -1.1786411223619944`}, \
{-3.2226977454398957`, -1.1771039993669812`}, {-3.085843141508438, \
-1.1756261281544684`}, {-2.9486246352437506`, -1.174207508724456}, \
{-2.811042226645834, -1.1728481410769436`}, {-2.7764973864856644`, \
-1.1725229761536953`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752886439447024, -1.1723007301758288`}, \
{-2.6731398929491137`, -1.1715500889932073`}, {-2.5349616113880145`, \
-1.1703154162545226`}, {-2.396507381962537, -1.1691441228608892`}, \
{-2.257777204672681, -1.1680362088123073`}, {-2.1187710795184467`, \
-1.166991674108777}, {-1.9794890064998332`, -1.166010518750298}, \
{-1.8399309856168413`, -1.1650927427368707`}, {-1.8084361323834461`, \
-1.164900306679204}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.78482458012725, -1.1647560382173734`}, \
{-1.7000970168694716`, -1.1642383460684946`}, {-1.5555449022448444`, \
-1.1634248368291895`}, {-1.4108054033399482`, -1.162682463077167}, \
{-1.2658785201547829`, -1.1620112248124268`}, {-1.1222633269315017`, \
-1.1608420381367097`}, {-0.9770553673259326, -1.1602775031028931`}, \
{-0.8403590787331083, -1.1597460594815312`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8167472641777944, -1.159654262196006}, \
{-0.6866394481147944, -1.1591484330352602`}, {-0.5414314885092253, \
-1.1585838980014436`}, {-0.49559757928012815`, -1.1584980180384377`}, \
{-0.44975848087675596`, -1.1584195308284764`}, {-0.22145830864795707`, \
-1.1580648140408552`}, {0.006841863580841767, -1.157710097253234}, {
             0.12772967626581277`, -1.1577129312055574`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15134166925729411`, -1.157713484737472}, {
             0.23530545769464603`, -1.1577154530862084`}, {
             0.46376905180845024`, -1.1577208089191826`}, {
             0.4895031578887226, -1.157762004411332}, {
             0.5152352955316448, -1.15780548794868}, {
             0.5631460398018776, -1.157898901187185}, {
             0.6110486916269007, -1.1580002497755233`}, {
             0.7577096420217894, -1.1586082818542327`}, {
             0.904370592416678, -1.1592163139329423`}, {
             1.0510315428115669`, -1.1598243460116517`}, {
             1.0958169550312147`, -1.160010018934229}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.119428745110963, -1.1601079095163205`}, {
             1.1976924932064557`, -1.1604323780903614`}, {
             1.342601422323012, -1.1616522275754275`}, {
             1.4889531924923127`, -1.1623682274317293`}, {
             1.6350988425112214`, -1.1631562058064262`}, {
             1.7810383723797378`, -1.1640161626995178`}, {
             1.9208116081114, -1.1649073253720512`}, {
             2.0603022832996065`, -1.1658616841150564`}, {
             2.063890047353401, -1.1658879092140162`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0875014095802955`, -1.1660604986880425`}, {
             2.199510397944358, -1.1668792389285334`}, {
             2.3384359520456535`, -1.1679599898124822`}, {
             2.477078945603494, -1.1691039367669027`}, {
             2.615439378617879, -1.170311079791795}, {
             2.753517251088809, -1.1715814188871592`}, {
             2.891312563016283, -1.1729149540529953`}, {
             3.0287794505766508`, -1.17430943435176}, {
             3.031944401739908, -1.174342982671121}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.055555068340772, -1.1745932545213302`}, {
             3.1658720499462603`, -1.1757626088459097`}, {
             3.3025903611251115`, -1.177274477535445}, {
             3.438934384113205, -1.1788450404203652`}, {
             3.5749041189105406`, -1.180474297500671}, {
             3.710499565517118, -1.182162248776362}, {
             3.8457207239329376`, -1.1839088942474383`}, {
             3.9805675941579994`, -1.1857142339138997`}, {
             3.9999655812724257`, -1.1859909580046588`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023575172027183, -1.1863277631843028`}, {
             4.115870658184757, -1.1876444144604101`}, {
             4.249450877054953, -1.1895258785983693`}, {
             4.3826255670324805`, -1.1914635486551748`}, {
             4.5153791077663845`, -1.193456180492557}, {
             4.64769587890571, -1.1955025299722464`}, {
             4.779560260099499, -1.1976013529559733`}, {
             4.9109566309968, -1.1997514053054683`}, {
             4.967945040737525, -1.200709116851674}}]}, 
           {Arrowheads[{{0.01409046725234969, 1.}}], 
            ArrowBox[{{4.991553700184968, -1.2011058692061636`}, {
             5.041869371246657, -1.2019514428824618`}, {
             5.169402254107746, -1.20414935111441}, {
             5.296452223011514, -1.2063913543825038`}, {
             5.42300769396464, -1.2086758405124696`}, {
             5.549057082973801, -1.2110011973300325`}, {
             5.656854249492381, -1.2130564793686354`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.45584789110883}, \
{-5.588803517854278, -3.452024822683879}, {-5.431767593888155, \
-3.4434108898585127`}, {-5.273240613192466, -3.4349479728027084`}, \
{-5.11322257576721, -3.4266360715164654`}, {-4.951713481612388, \
-3.418475185999785}, {-4.929963484085672, -3.417391352819777}, \
{-4.908196717856004, -3.4163108887935887`}, {-4.720107053476283, \
-3.4073218121864177`}, {-4.713640683821566, -3.4070252368239986`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690053486001559, -3.4059434270736353`}, \
{-4.531056162818036, -3.3986511299633917`}, {-4.322835666249573, \
-3.389324972793536}, {-4.113521315760446, -3.3803960971036346`}, \
{-3.9031131113506543`, -3.371864502893687}, {-3.7464287510527456`, \
-3.3658384642034593`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722834201558403, -3.364931024125451}, \
{-3.6916110530201984`, -3.3637301901636936`}, {-3.4790749159675447`, \
-3.356007012750589}, {-3.265564475391161, -3.348708824491309}, \
{-3.051079731291048, -3.3418356253858534`}, {-2.8356206836672038`, \
-3.3353874154342225`}, {-2.7788712022445887`, -3.3338035949984883`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7552683997039464`, -3.3331448647322843`}, \
{-2.619050952101536, -3.3293431740065214`}, {-2.402143358963242, \
-3.3238220180054863`}, {-2.1843705666356925`, -3.318742667662191}, \
{-1.965787127286125, -3.314113531228594}, {-1.8110482338758254`, \
-3.311168761711244}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7874405154076647`, -3.3107194933457604`}, \
{-1.7493655129643109`, -3.3099949043035544`}, {-1.5323703901545347`, \
-3.306331995266308}, {-1.3148763045887206`, -3.3031330705378443`}, \
{-1.0969578019987927`, -3.300406396539153}, {-0.8786894281166759, \
-3.2981602396912217`}, {-0.8430518934800499, -3.2978736679384824`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8194406638484867, -3.2976838031925384`}, \
{-0.6601457286742942, -3.296402866415041}, {-0.44140124940357206`, \
-3.2951425431316}, {-0.22253053603643388`, -3.2943875362618873`}, \
{-0.003596647994092317, -3.2941299913269804`}, {
             0.12502875234057606`, -3.2942634134773763`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14864073263559255`, -3.2942879060051187`}, {
             0.21534088955168929`, -3.294357093571061}, {
             0.43421283224316154`, -3.2950696689997736`}, {
             0.6529499357225744, -3.296268543618764}, {
             0.8714829556321783, -3.297954543433678}, {
             1.0897426476142233`, -3.30012849445016}, {
             1.0930983906435205`, -3.300169498257883}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1167086211582118`, -3.3004579915494925`}, {
             1.3076597673109596`, -3.302791222673855}, {
             1.5251650703646373`, -3.305943554110409}, {
             1.74220227199844, -3.3095745952858895`}, {
             1.958719074998914, -3.313669846732646}, {
             2.061059381109437, -3.315828606063976}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0846661227354426`, -3.316326565037368}, {
             2.1746522163533557`, -3.318224725465751}, {
             2.389938433049062, -3.3232346485002737`}, {
             2.604514462073328, -3.328695032851286}, {
             2.81831704041345, -3.3346012955338575`}, {
             3.0288230282197497`, -3.3408755356583644`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0524231136633295`, -3.341625157011506}, {
             3.2433487929904476`, -3.3477331239539643`}, {
             3.454476713514242, -3.354939351950922}, {
             3.6646364520238315`, -3.362549653022681}, {
             3.873776409650662, -3.370554749520903}, {
             3.996291741396758, -3.375495326815737}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.019884558842837, -3.376446735398924}, {
             4.081844987526181, -3.37894536379725}, {
             4.288790586781836, -3.387712218203385}, {
             4.494561608549073, -3.39684603509097}, {
             4.69910645395934, -3.4063375368116677`}, {
             4.902373524144083, -3.41617744571714}, {
             4.963390095808481, -3.419253049082951}}]}, 
           {Arrowheads[{{0.014205262862435123`, 1.}}], 
            ArrowBox[{{4.986972149545095, -3.4204417268776326`}, {
             5.117441832357081, -3.4270181861025124`}, {
             5.330893915029666, -3.4381878926196965`}, {
             5.539516779035461, -3.449484637098834}, {
             5.656854249492381, -3.456053248461777}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.297392094794825}, \
{-5.567203837355306, -5.289067484996478}, {-5.366987586813732, \
-5.271120235902769}, {-5.156967010580467, -5.252966399664791}, \
{-4.944388766948028, -5.2353168429465144`}, {-4.729876499466871, \
-5.218246963568993}, {-4.715796339771828, -5.217175600420326}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.692252404909404, -5.215384136066757}, \
{-4.513774499161362, -5.201803704082234}, {-4.296147704529765, \
-5.186005551765198}, {-4.077061054070346, -5.170870993896844}, \
{-3.8565794862813707`, -5.1564185177561335`}, {-3.750061088094536, \
-5.14981457336163}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            
            ArrowBox[{{-3.726494344245542, -5.148353478672004}, \
{-3.634767939661107, -5.142666610622028}, {-3.4116913527078183`, \
-5.129633759773485}, {-3.187414663919773, -5.117338452489467}, \
{-2.9619456130741892`, -5.105811542008274}, {-2.7834024400983255`, \
-5.097356663593982}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7598168773468745`, -5.096239773700785}, \
{-2.735312739483212, -5.095079384855716}, {-2.507612180947498, \
-5.0851537232420245`}, {-2.2789400752677014`, -5.07604629937743}, \
{-2.0493925602444767`, -5.067768855472162}, {-1.8190657736784797`, \
-5.060333133736449}, {-1.8160325571437752`, -5.060246707093728}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7924301432911027`, -5.059574194147132}, \
{-1.5880558533703653`, -5.053750876380524}, {-1.356458937120789, \
-5.048033825614614}, {-1.1637018262674481`, -5.043956500855859}, \
{-0.9706042610222689, -5.040494729640791}, {-0.8481912702605153, \
-5.038696897038161}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8245818233650646, -5.038350154154954}, \
{-0.7772440581549553, -5.037654922569639}, {-0.5836644492042311, \
-5.035440641086971}, {-0.38992017440488924`, -5.033854667857256}, \
{-0.19606597399172307`, -5.032899785544962}, {-0.1604948504136728, \
-5.032793135177254}, {-0.12492230568923945`, -5.0327077457575955`}, {
             0.11320224408691992`, -5.032684310189443}, {
             0.11987097048042077`, -5.032710347864426}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14348278350168842`, -5.032802538888158}, {
             0.3512800771676501, -5.033613871978698}, {
             0.3663080609567632, -5.033702612943319}, {
             0.3813354478046465, -5.033795145968252}, {
             0.425011141953485, -5.034107194320791}, {
             0.46868021453037445`, -5.034451281713676}, {
             0.7069408002665168, -5.036804691937699}, {
             0.944898302970317, -5.040107819357617}, {
             1.0879005279434761`, -5.042663053508376}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1115087523896807`, -5.043084896884275}, {
             1.1824557169325232`, -5.044352612171408}, {
             1.4195160364438846`, -5.049531018577053}, {
             1.65599836502082, -5.055632709395101}, {
             1.8917570889928845`, -5.062639092102543}, {
             2.055648189398992, -5.068059610750196}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0792455199245126`, -5.068891184869845}, {
             2.2290239034063752`, -5.0742551655842565`}, {
             2.3970492571835393`, -5.080730000689486}, {
             2.5646228361299594`, -5.087641026009445}, {
             2.731709835837366, -5.094981985022993}, {
             2.89827545189749, -5.10274662120899}, {
             3.022868760354066, -5.108887414196432}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0464521266199722`, -5.110049760489182}, {
             3.064284879902064, -5.110928678046297}, {
             3.2297033154428196`, -5.119521899013773}, {
             3.3944959541114885`, -5.12852002759028}, {
             3.5586279914998022`, -5.137916807254677}, {
             3.722064623199492, -5.147705981485824}, {
             3.884771044802291, -5.157881293762583}, {
             3.989340251540212, -5.164697019663334}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.012902248202065, -5.16623276920119}, {
             4.046712451899929, -5.168436487563812}, {
             4.207854040084139, -5.179365306368372}, {
             4.368161004946652, -5.190661493655124}, {
             4.5275985420791995`, -5.202318792902927}, {
             4.686169561187604, -5.214331383506468}, {
             4.8438985229000275`, -5.226693693955187}, {
             4.954815688617944, -5.235676930161398}}]}, 
           {Arrowheads[{{0.014422476014529048`, 1.}}], 
            ArrowBox[{{4.978350619557516, -5.237583035878747}, {
             5.0007829491917075`, -5.239399841370081}, {
             5.156820362037881, -5.252443942872146}, {
             5.309875267123657, -5.265607050956634}, {
             5.456593303682646, -5.278548466904086}, {
             5.595143694012828, -5.291079681013432}, {
             5.656854249492381, -5.296807803130046}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.829494327345963}, \
{-5.523126271042988, -4.818641269060372}, {-5.315013818664949, \
-4.802240523224843}, {-5.100331830944196, -4.785914529322418}, \
{-4.884050195093433, -4.770119206009801}, {-4.715069546640322, \
-4.758280507116606}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.6915152889512886`, -4.756630307718119}, \
{-4.6661689111126625`, -4.754854553286996}, {-4.446687979001883, \
-4.740120571154}, {-4.282090616131864, -4.729505343445263}, \
{-4.116676998802059, -4.719231999487915}, {-3.9504749891273505`, \
-4.709307674307029}, {-3.783512449222619, -4.699739502927672}, \
{-3.7488744748678218`, -4.697838205391707}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7252979728352402`, -4.696544078178549}, \
{-3.6158172412027456`, -4.690534620374916}, {-3.447417227182612, \
-4.681700161673832}, {-3.2783402692770993`, -4.673243261849489}, \
{-3.1086142296010886`, -4.665171055926957}, {-2.938244258861101, \
-4.65749464206877}, {-2.78193194118942, -4.650848220533497}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7583403335247048`, -4.649867700217701}, \
{-2.5956530025464133`, -4.643363134924065}, {-2.4235122172833217`, \
-4.636917988265003}, {-2.250861660824138, -4.630893210633104}, \
{-2.0777415833246673`, -4.625293775342096}, {-1.9041922349407137`, \
-4.620124655705709}, {-1.814417032590361, -4.617681373017227}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7908137792843404`, -4.617038997186434}, \
{-1.7302538658280824`, -4.615390825037668}, {-1.487680347350771, \
-4.609543607061378}, {-1.2444378577816384`, -4.604559202721619}, \
{-1.0006692126948924`, -4.6004507279458045`}, {-0.8465260714111564, \
-4.5984150194258016`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8229161372817494, -4.59810321220776}, \
{-0.7564537540762034, -4.5972254693602705`}, {-0.5119123539563537, \
-4.59489209425467}, {-0.26716588436612587`, -4.593459269918652}, \
{-0.22948220620855808`, -4.593318718638351}, {-0.19179568130531022`, \
-4.593199493033719}, {-0.058002610912213676`, -4.5929484827718134`}, {
             0.07577945262163438, -4.592966284909483}, {
             0.12154166833522256`, -4.593064333894115}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.1451536071364391, -4.593114924246627}, {
             0.20955050929623392`, -4.593252899446729}, {
             0.3433105591115851, -4.5938083263835505`}, {
             0.3599204616512474, -4.5938939912187085`}, {
             0.37652966316856595`, -4.593983801710933}, {
             0.4200539255752498, -4.594258538941387}, {
             0.463572388168439, -4.594561769369248}, {
             0.604960430738848, -4.595696207643514}, {
             0.7462398185862522, -4.597128422027716}, {
             0.8874105517106514, -4.598858412521856}, {
             1.0284726301120457`, -4.600886179125932}, {
             1.0895843482200132`, -4.601893817953138}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1131931321796302`, -4.602283090716486}, {
             1.1693888214944277`, -4.603209671742651}, {
             1.3101218935617895`, -4.605826840274722}, {
             1.4506718463141317`, -4.608737684722144}, {
             1.5910386797514537`, -4.611942205084918}, {
             1.7312729947222973`, -4.615447102818589}, {
             1.8710880530849279`, -4.619214403008396}, {
             2.0106795114537053`, -4.623270017949116}, {
             2.057398060299918, -4.624725492118184}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0809986029951606`, -4.625460745697699}, {
             2.1500271294892137`, -4.6276112670585325`}, {
             2.3954918483415826`, -4.635958319538725}, {
             2.6400145786439535`, -4.645149471923578}, {
             2.883482470194947, -4.655165181295143}, {
             3.024783516518874, -4.661475450653998}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.04837199918948, -4.662528872997927}, {
             3.125782672793184, -4.66598590473547}, {
             3.3668023362372863`, -4.677592099326609}, {
             3.606428610325875, -4.689964222150612}, {
             3.844548644857571, -4.703082730289529}, {
             3.991563302722338, -4.711689332153215}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.015134937664768, -4.713069273991478}, {
             4.081049589630996, -4.716928080825411}, {
             4.315908132687321, -4.73148926875806}, {
             4.549190500310269, -4.746763827005032}, {
             4.7808382243545715`, -4.762717060407251}, {
             4.957544183433176, -4.775453938951496}}]}, 
           {Arrowheads[{{0.014352611006110703`, 1.}}], 
            ArrowBox[{{4.981095076879652, -4.777151475757839}, {
             5.010712911367245, -4.779286314687885}, {
             5.237858736725843, -4.796349020264046}, {
             5.460462481984602, -4.813708712687911}, {
             5.656854249492381, -4.8295227119279724`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.9090864191999692`}, \
{-5.515667597112305, -3.899989723470262}, {-5.352364029768171, \
-3.889773307498018}, {-5.183757763701663, -3.879534544656983}, \
{-5.014364475139571, -3.8695731397926965`}, {-4.8441333755663045`, \
-3.859905676565488}, {-4.714058930663372, -3.8527830176249394`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.69048225823187, -3.8514919984950255`}, \
{-4.67309403304463, -3.8505398483806617`}, {-4.501276015637315, \
-3.841483348643523}, {-4.328708891407125, -3.832743870759376}, \
{-4.155422228416825, -3.8243291081335253`}, {-3.981445594729183, \
-3.816246754171276}, {-3.804285417050909, -3.8078479983586018`}, \
{-3.7471327788322237`, -3.805369512032172}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7235429571318015`, -3.8043465137533574`}, \
{-3.6280664401378986`, -3.8002060707355025`}, {-3.4512166286530785`, \
-3.7929119385866135`}, {-3.273735982596448, -3.785965601911935}, \
{-3.095624501968008, -3.779367060711467}, {-2.9168821867677575`, \
-3.77311631498521}, {-2.779744902762078, -3.768603295248337}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7561456851330512`, -3.7678266739545236`}, \
{-2.7375090369956974`, -3.767213364733163}, {-2.557505052651827, \
-3.7616582099553266`}, {-2.3768702337361463`, -3.7564508506517007`}, \
{-2.1957329923477813`, -3.751608001531263}, {-2.014221740585857, \
-3.7471463773029923`}, {-1.8323364784503733`, -3.7430659779668876`}, \
{-1.8120063009377998`, -3.7426533521944925`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7883991697596338`, -3.742174216646837}, \
{-1.6500772059413307`, -3.739366803522949}, {-1.4674439230587284`, \
-3.736048853971177}, {-1.2844366298025671`, -3.7331121293115714`}, \
{-1.101055326172846, -3.730556629544132}, {-0.9173000121695659, \
-3.728382354668859}, {-0.8603046014182875, -3.72778683922276}, \
{-0.8440361917367714, -3.727627759992447}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8204253275161039, -3.7273968832084967`}, \
{-0.803289499617689, -3.72722932200453}, {-0.640027142347181, \
-3.7258446159340632`}, {-0.4766749121207895, -3.7247733526030835`}, \
{-0.3132328089385145, -3.7240155320115913`}, {-0.149700832800356, \
-3.7235711541595866`}, {-0.13113010335752714`, -3.7235384967960314`}, \
{-0.11255863841683561`, -3.7235098947656198`}, {-0.0773738243015328, \
-3.7234779385924317`}, {-0.04218634045212898, -3.7234605223642503`}, {
             0.12168557386552864`, -3.7235375095284584`}, {
             0.12404173341678588`, -3.7235431647682695`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14765365840152023`, -3.723599837966873}, {
             0.28550762355002407`, -3.723930714214793}, {
             0.4492798086013575, -3.7246401364232535`}, {
             0.6130021290195287, -3.72566577615384}, {
             0.7766131203696487, -3.7270054621631035`}, {
             0.9400513182168289, -3.7286570232075937`}, {
             1.0921034081388097`, -3.730485607533516}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1157133839685212`, -3.730793405574351}, {
             1.2664093334023696`, -3.7328957704022554`}, {
             1.4293938231872594`, -3.7354869765627066`}, {
             1.5919037147187396`, -3.7383712977104127`}, {
             1.7541890747900566`, -3.7415642778851224`}, {
             1.9162240344225983`, -3.7450643090827236`}, {
             2.0600224104835094`, -3.748483022224138}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0836277333260558`, -3.7490442234672936`}, {
             2.1261863505727674`, -3.750056026994199}, {
             2.335560371684627, -3.7555390368136368`}, {
             2.544276293431798, -3.76150577417238}, {
             2.7522643114879015`, -3.767948674701774}, {
             2.9594546215265596`, -3.774860174033162}, {
             3.027679819498638, -3.777298065440578}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0512767524574333`, -3.7781412547872057`}, {
             3.165777419221393, -3.7822327077978883`}, {
             3.371162900246024, -3.790058711627297}, {
             3.5755412602740746`, -3.798330621152732}, {
             3.778907829900213, -3.8070365656018827`}, {
             3.981277981233275, -3.8161633491551603`}, {
             3.9949597126492544`, -3.8168115125435165`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.018545253602594, -3.8179288626562857`}, {
             4.182611972218136, -3.825701419872991}, {
             4.382870060799671, -3.835641225815802}, {
             4.582012504922752, -3.845973215044019}, {
             4.779999562532254, -3.856687835618069}, {
             4.961748631527456, -3.8669279870233715`}}]}, 
           {Arrowheads[{{0.014246943906299676`, 1.}}], 
            ArrowBox[{{4.985322154092471, -3.868275065288455}, {
             5.1723485499900175`, -3.879226763045373}, {
             5.366159496558525, -3.8909982514359345`}, {
             5.557241590884437, -3.9030130196633963`}, {
             5.656854249492381, -3.909492304765543}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQzXavpq+s5pG9p0StjOmy5/tvuOTdVl34yD7yRchD
JyCfR91/3b7jj+yLX2QnBQL5RrsjSphfP7K/mJu0PA7Iv33jgOlC2cf2yW8N
dhYC+a//VDu7FD62V5vekTIRyP/q3qDYyPTEPv/NeY6TQL6C4I4FcUVP7C9y
/Iv6AuRfiSnf9ZftqX3f9jsT9ZY/338q84JNzcWn9u8tJzPWA/nWswRMz0c+
s7/+1vfQViD/Tt8N+Q0sz+2fclfz/Aby645O+zPnxHP7Z45OIj4rnu9fVXTy
xE6JF/ZMl54/ywXyXRieul/NeGE/33uR8gQg/wSzBM+nAy/sPzR8d98G5G9g
3Z7498kL+ymfpdiPgeRnKu2YfPSl/V/+hzkaK5/vj9h7u0Rh2Sv7CO07yn1A
vo+/q/WRhjf2s7RWrahe9Xx/TZXSGdfod/ZlkvxPK1Y/3/9gRXLYa4bP9pY7
jxbzb3i+/0DpvlOyl77Z29dLpSzb+nx/isc9rfNRP+xF1e4+893xfD8AXZLZ
kA==
             "]]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.5457820846799366`, -0.7413278840974238}, {
             1.6643622038193306`, -0.7417286449157112}, {
             1.9019172174914316`, -0.7426554739831226}, {
             2.1388080431958447`, -0.7437015194994087}, {
             2.3748797400267363`, -0.7448637457736762}, {
             2.4902524454428723`, -0.7454907029168616}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.513864089812582, -0.745619013066533}, {
             2.6101323079841077`, -0.7461421528059251}, {
             2.844565747067958, -0.7475367405961555}, {
             3.0783347662663116`, -0.7490533186869359}, {
             3.310562681313698, -0.7506589663370435}, {
             3.4583236977337735`, -0.7517560212940118}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.481935039970434, -0.7519313242302595}, {
             3.541847700297143, -0.7523761471110776}, {
             3.7721279396214387`, -0.7542025371920105}, {
             3.8991953206551218`, -0.7552596933099989}, {
             4.025918062969367, -0.7563483611975744}, {
             4.152284878055947, -0.7574680492058626}, {
             4.278284477406628, -0.7586182656859887}, {
             4.403905572513182, -0.7597985189890778}, {
             4.42637998888562, -0.7600156333541902}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.4499908801603105`, -0.7602437266485339}, {
             4.529136874867378, -0.7610083174662553}, {
             4.653967095960985, -0.7622471694686466}, {
             4.778384947285772, -0.7635145833473768}, {
             4.90237914033351, -0.7648100674535712}, {
             5.025938386595968, -0.766133130138355}, {
             5.149051397564916, -0.7674832797528537}, {
             5.271706884732123, -0.7688600246481924}, {
             5.394417055985851, -0.7702845430326106}}]}, 
           {Arrowheads[{{0.00505767847572692, 1.}}], 
            ArrowBox[{{5.4180274581172725`, -0.7705586315743842}, {
             5.515600133628394, -0.7716913336858912}, {
             5.656854249492381, -0.7734031156424529}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.878124125284057}, {-5.532693172760044, 
             1.8744201183819513`}, {-5.31444900379624, 
             1.868166838598606}, {-5.094916892457493, 
             1.8621329851378259`}, {-4.874065750043239, 
             1.8563190566486187`}, {-4.712729863517557, 
             1.8522576949903398`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689125348385461, 
             1.8516634907200797`}, {-4.651762137611758, 
             1.8507229342516194`}, {-4.427978587295646, 
             1.845346822721244}, {-4.202793602301818, 
             1.8401972504856912`}, {-3.9762856858371856`, 
             1.8352807459731593`}, {-3.7485333411086628`, 
             1.830603837611847}, {-3.7448829564715562`, 
             1.8305331832902723`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7212753850878464`, 
             1.8300762514581608`}, {-3.5196150713231624`, 
             1.8261730538299523`}, {-3.2896093796875983`, 
             1.8219949230556742`}, {-3.058594769408884, 
             1.818075973717211}, {-2.846225455995137, 
             1.8147234436128228`}, {-2.77693850180098, 
             1.8137092529722196`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7533290379211968`, 
             1.8133636684740262`}, {-2.6331530149050564`, 
             1.8116045869963453`}, {-2.4194327243894325`, 
             1.808722691348063}, {-2.2045302280239625`, 
             1.8060459776918953`}, {-1.9892286343615038`, 
             1.8036210186652015`}, {-1.808921154738173, 
             1.8017987015331935`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7853103675805508`, 
             1.8015600739286848`}, {-1.7733897477750808`, 
             1.801439595567271}, {-1.557013568264694, 
             1.799501708398104}, {-1.3401000958303437`, 
             1.7978073571577005`}, {-1.1227873896768896`, 
             1.7963622635991132`}, {-0.9052135090091924, 
             1.7951721494753958`}, {-0.8408552042697621, 
             1.7948958684919378`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8172434288369986, 
             1.7947945065221942`}, {-0.6873784538272517, 
             1.7942370147865478`}, {-0.46928222413106785`, 
             1.7935568595325697`}, {-0.42559076197470636`, 
             1.7934513986021139`}, {-0.38189418413695936`, 
             1.793356263856264}, {-0.16480004091215267`, 
             1.7930363050778424`}, {0.0522791941948999, 
             1.7929705941754632`}, {0.12723352906568036`, 
             1.7930356977493922`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15084551315691438`, 1.7930562065639197`}, {
             0.2693435211841984, 1.7931591311491266`}, {0.4863929400557429, 
             1.793601915998832}, {0.5113132342923331, 1.793667351707039}, {
             0.5362322535211833, 1.7937361877548303`}, {0.5848083945466602, 
             1.7938900820245505`}, {0.6333701253741411, 
             1.7940562235908466`}, {0.7828757620569601, 
             1.7950507123670403`}, {0.9323813987397793, 
             1.7960452011432337`}, {1.0818870354225987`, 
             1.7970396899194274`}, {1.0953138080487579`, 
             1.7971290027705913`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.118925278683163, 1.7972860626852296`}, {
             1.231392672105418, 1.7980341786956209`}, {1.3791453632667687`, 
             1.8000358921978419`}, {1.52834165662227, 1.8012081265139226`}, {
             1.6773317210928926`, 1.8024988578565946`}, {1.8261155566786367`, 
             1.8039080862258583`}, {1.9775054893533666`, 1.805462196802917}, {
             2.063358867755864, 1.806410547176666}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.086969420345025, 1.8066713531785845`}, {
             2.1285396548554036`, 1.807130544746445}, {2.2792180531847475`, 
             1.8089131300564427`}, {2.429540684341399, 1.81080995273291}, {
             2.579507548325357, 1.8128210127758468`}, {2.729118645136622, 
             1.8149463101852534`}, {2.8783739747751946`, 
             1.8171858449611296`}, {3.027273537241074, 1.8195396171034752`}, {
             3.031359549520043, 1.8196073815643186`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.054968296000775, 1.81999892076372}, {
             3.175753689051314, 1.8220020858251518`}, {3.323750786722968, 
             1.8245677103390205`}, {3.471264830256036, 1.8272364906450813`}, {
             3.618295819650518, 1.8300084267433343`}, {3.7648437549064138`, 
             1.8328835186337795`}, {3.9109086360237244`, 
             1.8358617663164167`}, {3.9992805498145216`, 
             1.8377322574888628`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.022887255444215, 1.8382319200241273`}, {
             4.056490463002449, 1.8389431697912462`}, {4.2015892358425875`, 
             1.8421277290582678`}, {4.346169531326489, 1.8454094341791558`}, {
             4.4901959262365025`, 1.8487822752155847`}, {4.633668420572629, 
             1.8522462521675547`}, {4.776587014334868, 1.8558013650350653`}, {
             4.918951707523218, 1.8594476138181169`}, {4.96709835474091, 
             1.860716505552536}}]}, 
           {Arrowheads[{{0.014111808690369394`, 1.}}], 
            ArrowBox[{{4.990702151897904, 1.8613385771783753`}, {
             5.060762500137681, 1.8631849985167095`}, {5.202019392178255, 
             1.8670135191308428`}, {5.342722383644942, 1.870933175660517}, {
             5.4826235230947145`, 1.874934812571174}, {5.621866375249313, 
             1.8790203296102443`}, {5.656854249492381, 
             1.8800729601388555`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.6060677551802771}, \
{-5.567265395035259, -0.6052175233576628}, {-5.367643838897561, \
-0.6033902834018109}, {-5.166762105093317, -0.601618327352878}, \
{-4.964620193622525, -0.5999016552108639}, {-4.761218104485185, \
-0.5982402669757687}, {-4.712410318707831, -0.597857243777551}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688799052743551, -0.5976719523848035}, \
{-4.556555837681298, -0.5966341626475924}, {-4.350633393210862, \
-0.595083342226335}, {-4.14345077107388, -0.5935878057119963}, \
{-3.9352084684618798`, -0.5921553604189184}, {-3.744343614894317, \
-0.5909125599606719}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.720732110044127, -0.5907607738083563}, \
{-3.516146313387416, -0.58950316543957}, {-3.3053264609249537`, \
-0.5882834157532996}, {-3.093647425179004, -0.5871345646026316}, \
{-2.8811092061495662`, -0.5860566119875661}, {-2.776266802528595, \
-0.585561845091986}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752655072450082, -0.5854504178260446}, \
{-2.6677118038366414`, -0.5850495579081031}, {-2.45345521824023, \
-0.5841134023642426}, {-2.350966637357977, -0.583692253284919}, \
{-2.24832260590278, -0.5832881466340486}, {-2.018255777085553, \
-0.5824479081705826}, {-1.8081826522913924`, -0.5817638839103692}}]}, 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAOFRQF5qN/L/r/vqNMJ3ivyuI8PnA
5vi/vCpHndaX4r9c9yLwFTH1v8d/foolk+K/UPBD6/+79L8hhpEpnZLivylV
cWDiRvS/9TVMoheS4r8bkrNJBSHzv7mf5MThkOK/5YHXVvv68b/EH7TXvY/i
v7Sve7NE6vG/pJkATK2P4r+B+QT6jdnxv4k+edCcj+K/G8Xxv3vA8b8d2lsx
hI/ivxJuptTEr/G/B2wP2nOP4r+MZ/7SDZ/xv+Ff2ZJjj+K/ZQ7e2eL38L/g
d2U4xI7iv/BIRr+uUPC/hUrUDSuO4r+EoRlD4lLvvyKE2/2XjeK/zJ2a3jq5
7L9upi/LkIziv7N3f42hGOy/NXg2XVKM4r8/M8N6i4LrvwJWjNQYjOK/Jkzg
1Qvi6r/pK8ft24viv2hjuzg=
             "]]}, 
           {Arrowheads[{{0.0004326515547452361, 1.}}], 
            ArrowBox[{{-0.8164815667257624, -0.5795379334599718}, \
{-0.8057812517543896, -0.5795223633348375}, {-0.800102082611497, \
-0.5795141792483087}, {-0.7960500572170837, -0.5795083252223603}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.7882695929853896, 0.563578026677293}, {
             0.7923724210718712, 0.5635839087216221}, {0.796440920054088, 
             0.5635897266347856}, {0.8044724372505476, 0.5636011997244008}, {
             0.8109949877789396, 0.5636105161422685}, {0.8200691605890275, 
             0.5636235262066202}, {0.8353564821134785, 0.5636456935055526}, {
             0.854041901063634, 0.5636730648819722}, {0.8960545518491406, 
             0.56373554388318}, {0.9435091004120842, 0.5638086868601786}, {
             0.9917573776622203, 0.5638867156227614}, {1.1904154256054174`, 
             0.5642826395160612}, {1.3887360928089516`, 0.5647423959039946}, {
             1.634473845701958, 0.5653613692342709}, {1.7327469518598368`, 
             0.5656484979633308}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7563588440756144`, 0.5657174858366939}, {
             1.879508450860195, 0.5660772972994911}, {2.1238399082836628`, 
             0.566890180099655}, {2.3674682179723603`, 0.5678000176347626}, {
             2.61026954789525, 0.5688044275864854}, {2.700831978817746, 
             0.5692150562965171}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.724443729099701, 0.5693221168343263}, {
             2.852120066021293, 0.5699010276364951}, {3.0930197723504893`, 
             0.5710898177847914}, {3.3329686668828393`, 0.5723707980313746}, {
             3.572180033189385, 0.5737494893900837}, {3.6689100169331375`, 
             0.5743386448963292}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6925215719773874`, 0.5744824563302502}, {
             3.809445264367557, 0.5751946061158297}, {4.04558905689205, 
             0.576727496128791}, {4.280526097334446, 0.5783459510234319}, {
             4.521339724618215, 0.5800993232676235}, {4.636978798226823, 
             0.5809850504182246}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.660590098637931, 0.5811658990637776}, {
             4.760537632921757, 0.581931438271143}, {4.99803364505352, 
             0.5838383306819701}, {5.2338233227377495`, 0.5858182096561233}, {
             5.467866458078036, 0.5878681813526823}, {5.605036243133953, 
             0.5891185379227465}}]}, 
           {Arrowheads[{{0.0005973270894070676, 1.}}], 
            ArrowBox[{{5.628647255228089, 0.5893337615894289}, {
             5.656854249492381, 0.5895908794422107}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.7246855702395545}, {-5.472939556986484, 
             0.7226224351508159}, {-5.254905902307756, 
             0.7202747841296598}, {-5.035471613889758, 
             0.7180096478385984}, {-4.814636691732492, 
             0.7158270262776318}, {-4.712425780001672, 0.7148611419795518}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688814841218849, 
             0.7146380206449792}, {-4.592401135835956, 
             0.7137269194467598}, {-4.368764946200152, 
             0.7117093273459825}, {-4.143728122825079, 
             0.7097742499752998}, {-3.9172906657107363`, 
             0.7079216873347118}, {-3.744369597577155, 0.7065841553409205}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207583108897504`, 
             0.7064015237408509}, {-3.6896719229594823`, 
             0.706161072771649}, {-3.4610912426736737`, 
             0.7045018396335417}, {-3.2315486248533105`, 
             0.7029439879203901}, {-3.001044069498393, 
             0.7014875176321941}, {-2.776299281965511, 0.7001717800718441}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752687649856861, 
             0.7000413253408466}, {-2.537149146184894, 
             0.6988787213306686}, {-2.303758778226312, 
             0.6977263953173393}, {-2.0694064727331765`, 
             0.6966754507289655}, {-1.978279434922164, 
             0.6962873022731878}, {-1.887067631249006, 
             0.6959164644643493}, {-1.808218438759488, 0.6956109973277003}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7846066229486794`, 
             0.6955195235466877}, {-1.6566280417800359`, 
             0.6950237258155038}, {-1.426188452311066, 
             0.6941309871666583}, {-1.1946369061466977`, 
             0.6934508322038034}, {-0.9630853599823294, 
             0.6927706772409487}, {-0.9354156472350736, 
             0.6927156929304714}, {-0.9077416287528304, 
             0.692662294119784}, {-0.8473976994642005, 
             0.6925571893507516}, {-0.8401317981291817, 
             0.6925451862802571}}]}, 
           {Arrowheads[{{0.002574961461968259, 1.}}], 
            ArrowBox[{{-0.8165198373498728, 
             0.6925061799661496}, {-0.7990930541245238, 
             0.6924773913963767}, {-0.7743352279916733, 
             0.6924373529335491}, {-0.7524323821524276, 
             0.6924025636063628}, {-0.7161774038559184, 
             0.6923456935973649}, {-0.7096681474169824, 
             0.6923357102850936}, {-0.7044318566982204, 
             0.6923277287903689}, {-0.7004698926142111, 
             0.6923217099120137}, {-0.6949200464305961, 
             0.6923132789217343}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.36388838082965497`}, {-5.6122035931680045`, 
             0.36363653900279086`}, {-5.606129137207883, 
             0.36360246564593346`}, {-5.600053479636039, 
             0.36356841988986566`}, {-5.590937891563244, 
             0.36351739961668605`}, {-5.584859532535689, 
             0.36348341607459966`}, {-5.578779973921548, 
             0.36344946023508945`}, {-5.384827164002918, 
             0.3623846448681059}, {-5.189682716986377, 
             0.36134889814327215`}, {-4.973756189793615, 
             0.36024565189174873`}, {-4.756483689980273, 
             0.35918144769509575`}, {-4.712387344400631, 
             0.3589746678032782}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688775611003981, 
             0.3588639458916729}, {-4.537865217546351, 
             0.35815628555331325`}, {-4.317900772491848, 
             0.3571701654664012}, {-4.288606094540762, 
             0.357041827278361}, {-4.259289075286739, 
             0.35691422539560724`}, {-4.092270058576441, 
             0.3562191954828349}, {-3.9245643531352106`, 
             0.3555488145569893}, {-3.744304463104944, 
             0.35484921710796474`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720692647933267, 
             0.3547575784985205}, {-3.703079594035048, 
             0.3546892213749549}, {-3.480635614173648, 
             0.353877318344179}, {-3.2572324135510105`, 
             0.3531131054646618}, {-3.032869992167136, 
             0.3523965827364031}, {-2.807548350022024, 
             0.35172775015940305`}, {-2.776218104283798, 
             0.35164174843311047`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752606200244222, 
             0.3515769336044805}, {-2.581267487115674, 
             0.35110660773366154`}, {-2.3540274034480873`, 
             0.3505331554591786}, {-2.125828099019263, 
             0.3500073933359543}, {-1.896871741034159, 
             0.34953238400724257`}, {-1.8081290972627542`, 
             0.34936952549662403`}}]}, 
           {Arrowheads[{{0.019478189481090962`, 1.}}], 
            ArrowBox[{{-1.7845171440258256`, 
             0.3493261933693227}, {-1.667360496697732, 
             0.34911119011629743`}, {-1.4373331397853146`, 
             0.3487435882339171}, {-1.2068284440722388`, 
             0.3484293549308999}, {-1.0914032292629727`, 
             0.3482922300672707}, {-0.978645634641036, 
             0.3481709845864367}, {-0.954346321108592, 
             0.3481462982316332}, {-0.9360364805499988, 
             0.3481277421734077}, {-0.9224506473273392, 
             0.3481139618837429}, {-0.9043537515703863, 
             0.3480955686093989}, {-0.8933152685268033, 
             0.34808431453377275`}, {-0.8858825865100826, 
             0.34807671984808397`}, {-0.8796725077892825, 
             0.3480703589037134}, {-0.8753952194450884, 
             0.34806596281462615`}, {-0.8688468105843139, 
             0.34805920285943653`}, {-0.8646803077244664, 
             0.34805488254387923`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.472643962373634, -5.656854249492381}, \
{-4.466055500618909, -5.656305336174792}, {-4.292167297301829, \
-5.642324952660251}, {-4.11747433468051, -5.628811448453273}, \
{-3.9417878337587453`, -5.615771610716078}, {-3.7651563411054756`, \
-5.603217649117057}, {-3.587628403289638, -5.591161773324604}, \
{-3.53072684225003, -5.587478754613115}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.507164155295376, -5.585953632712039}, \
{-3.409252566880172, -5.579616193007111}, {-3.2300773784460155`, \
-5.568593117832973}, {-3.0501513845561075`, -5.55810475747058}, \
{-2.869523131779387, -5.5481633215883255`}, {-2.7200629035907475`, \
-5.540393376731205}, {-2.570170289140209, -5.533024599064732}, \
{-2.564196144027672, -5.532747765162596}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.540609460959479, -5.5316547897846595`}, \
{-2.4198764214918347`, -5.526060182053674}, {-2.2688803476930204`, \
-5.519469255538595}, {-2.1176231194846507`, -5.513297060270393}, \
{-1.9660269042065688`, -5.507535612587146}, {-1.8140917018587752`, \
-5.502184912488854}, {-1.6618175124412704`, -5.497244959975515}, \
{-1.5968411916381047`, -5.495320222433542}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.573239551247811, -5.494621091384726}, \
{-1.5092481549727121`, -5.4927255294130495`}, {-1.3564274484717584`, \
-5.488636395167373}, {-1.2033553929384102`, -5.484977557238485}, \
{-1.050031988372667, -5.481749015626388}, {-0.9890945180024906, \
-5.480586740448429}, {-0.9281329819888178, -5.4794928157144325`}, \
{-0.7192940741025469, -5.476273106448308}, {-0.6289719948862484, \
-5.475234516063859}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6053615627352554, -5.474963025770261}, \
{-0.5101831381148271, -5.473868593517643}, {-0.4966914433005065, \
-5.473739837688481}, {-0.48319896880439556`, -5.473614479780554}, \
{-0.4362881715630319, -5.473231613726023}, {-0.38937064853564946`, \
-5.472889828344099}, {-0.1786016029924485, -5.471770193496544}, {
             0.032197082766479534`, -5.471481899198603}, {
             0.2429846473493368, -5.472024532695618}, {
             0.3391019512683169, -5.4726508306914035`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.3627134430239981, -5.47280468259279}, {
             0.4537203293643256, -5.473397681232928}, {
             0.6642956800179411, -5.475600234438869}, {
             0.8746022505166788, -5.478631081941777}, {
             1.112436139182856, -5.483050449823368}, {
             1.3070654389861094`, -5.487522830394226}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3306712004960632`, -5.4880652664469896`}, {
             1.3496801872016202`, -5.488502073355813}, {
             1.5863343945729704`, -5.49498595253911}, {
             1.8223987612969075`, -5.5025020873732595`}, {
             2.0576856548901814`, -5.511019031655655}, {
             2.2746056845458176`, -5.519800844597801}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.298197212988518, -5.520782675139415}, {
             2.525364125234988, -5.530961009957363}, {
             2.7577557019865213`, -5.542386043976676}, {
             2.9882964930748894`, -5.5546723347496}, {
             3.2161008184508404`, -5.5677117757841055`}, {
             3.241420812429522, -5.569263433711139}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.264988592803873, -5.5707077126186}, {
             3.4411686781143738`, -5.5815043670801945`}, {
             3.6635000720654904`, -5.596050108637865}, {
             3.8840234425248563`, -5.611360046137347}, {
             4.103667231713137, -5.627445225258871}, {
             4.207236343045039, -5.635427421294129}}]}, 
           {Arrowheads[{{0.005240279862497903, 1.}}], 
            ArrowBox[{{4.230778519650491, -5.637241845173457}, {
             4.322431439630334, -5.644305646002437}, {
             4.477466602452956, -5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.002740649690485, -0.3658952783503807}, {
             1.1182692404639658`, -0.36602089104550534`}, {
             1.233725940952841, -0.36616138040592455`}, {
             1.464422464670051, -0.36647042421653375`}, {
             1.6951189883872613`, -0.366779468027143}, {
             1.9049600082592826`, -0.3671866679308977}, {
             1.9472193083021556`, -0.3672778898186214}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9708312462884785`, -0.36732885908582985`}, {
             2.1141334883459852`, -0.36763819456990704`}, {
             2.3226394286473693`, -0.3681340479441709}, {
             2.5304778291634347`, -0.3686742280536892}, {
             2.737648689894181, -0.36925873489846217`}, {
             2.9153076925012407`, -0.369799733203584}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9389195760236944`, -0.3698716349298063}, {
             2.944152010839609, -0.36988756847848964`}, {
             3.1499877919997186`, -0.37056072879377167`}, {
             3.3551560333745094`, -0.3712782158443083}, {
             3.5029251298199386`, -0.371823183875448}, {
             3.650219140638841, -0.3723890449295692}, {
             3.873769819162298, -0.37328997113053497`}, {
             3.883392922039652, -0.3733309191135067}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.90700470127512, -0.3734313913568557}, {
             4.096091454193449, -0.3742359885057546}, {
             4.317184045732295, -0.3752270970552283}, {
             4.537047593778835, -0.3762632967789559}, {
             4.566222284532133, -0.3764041802645152}, {
             4.59537365228546, -0.37654581312625085`}, {
             4.771441933387671, -0.3774377808813722}, {
             4.851474002939369, -0.37785732095009955`}}]}, 
           {Arrowheads[{{0.016554738384213608`, 1.}}], 
            ArrowBox[{{4.875085671513697, -0.37798109684533665`}, {
             4.946618481666796, -0.3783560825261518}, {
             5.187453492544823, -0.3796469570747298}, {
             5.426525510824878, -0.3809853526141153}, {
             5.656854249492381, -0.3823371709451032}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.5839366105438075`}, \
{-5.59397635249701, -1.582350669607639}, {-5.567143058556228, \
-1.5816873324322371`}, {-5.540284335469112, -1.5810262666689303`}, \
{-5.331954447382631, -1.5760961102992355`}, {-5.1221198800159, \
-1.5713086415672541`}, {-4.982637716290315, -1.568172399756908}, \
{-4.842669489495194, -1.5651172794539194`}, {-4.712621537181027, \
-1.5623636259063545`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.68901465711994, -1.5618723323540826`}, \
{-4.561274846696349, -1.5592504033700165`}, {-4.419848430692624, \
-1.556438647589102}, {-4.277935951619364, -1.5537080133155454`}, \
{-4.135537409476569, -1.5510585005493467`}, {-3.99265280426424, \
-1.548490109290506}, {-3.849282135982376, -1.546002839539023}, \
{-3.744699989371541, -1.5442535981509382`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7210912985169307`, -1.5438587190965327`}, \
{-3.705425404630977, -1.5435966912948982`}, {-3.561082610210043, \
-1.5412716645581312`}, {-3.416253752719574, -1.5390277593287223`}, \
{-3.2709388321595703`, -1.536864975606671}, {-3.1251378485300316`, \
-1.534783313391978}, {-2.978850801830958, -1.5327827726846426`}, \
{-2.8320776920623496`, -1.5308633534846652`}, {-2.7767112323012655`, \
-1.5301834607242502`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753101019388787, -1.5298935304505732`}, \
{-2.6157850647681347`, -1.5282073087950996`}, {-2.398914973118634, \
-1.5257602112489934`}, {-2.1814674171138493`, -1.5235220608463467`}, \
{-1.9634423967537786`, -1.5214928575871594`}, {-1.8086717845782077`, \
-1.5202041158159283`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785060610110757, -1.520007510618234}, \
{-1.7448399120384228`, -1.5196726014714312`}, {-1.5256599629677823`, \
-1.5180612924991626`}, {-1.3059025495418557`, -1.5166589306703533`}, \
{-1.0855676717606446`, -1.5154655159850035`}, {-0.9184152173364011, \
-1.5147043097879493`}, {-0.8405982060729987, -1.5144093137261614`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8169863827357517, -1.5143198038004648`}, \
{-0.7511917392055216, -1.514070383263579}, {-0.5838972373680046, \
-1.5135637364118915`}, {-0.41653171182385107`, -1.5131843692328877`}, \
{-0.24909516257306163`, -1.5129322817265671`}, {-0.08158758961563473, \
-1.5128074738929298`}, {0.08599100704842877, -1.512809945731976}, {
             0.12749141857357296`, -1.5128420647497278`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15110340449986967`, -1.5128603391177944`}, {
             0.2536406274191281, -1.5129396972437055`}, {
             0.42124535674348684`, -1.5131959690769263`}, {
             0.5886892802685295, -1.513578001880447}, {
             0.7559723979942549, -1.5140857956542675`}, {
             0.9230947099206623, -1.5147193503983876`}, {
             1.0900562160477532`, -1.5154786661128072`}, {
             1.0955786860120096`, -1.5155079694034879`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1191903466111075`, -1.5156332574283145`}, {
             1.256856916375527, -1.5163637427975265`}, {
             1.4234968109039827`, -1.5173745804525456`}, {
             1.5899758996331221`, -1.5185111790778643`}, {
             1.7576871406162258`, -1.5198214982242517`}, {
             1.922975656453303, -1.5211797004497212`}, {
             2.06364481389194, -1.5224427243857441`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0872558551861555`, -1.5226547204682686`}, {
             2.0880509668150777`, -1.5226618595244585`}, {
             2.2528868718635584`, -1.5242670733879473`}, {
             2.417457171760749, -1.5259944399796714`}, {
             2.581735666668659, -1.5278430572391153`}, {
             2.7456961567492963`, -1.5298120231057626`}, {
             2.9093124421646657`, -1.5319004355190973`}, {
             3.0316720102996015`, -1.5335487005184287`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0552818612862978`, -1.5338667409595155`}, {
             3.059205133766433, -1.5339195900567328`}, {
             3.2087371435471015`, -1.5360318832311814`}, {
             3.3578850655049086`, -1.538235938384659}, {
             3.5066254936380954`, -1.5405303788593812`}, {
             3.654935021944903, -1.5429138279975625`}, {
             3.80279024442357, -1.5453849091414191`}, {
             3.95016775507234, -1.5479422456331664`}, {
             3.9996423370493424`, -1.5488322626679545`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.023250510344029, -1.5492569590585632`}, {
             4.097044147889449, -1.5505844608150194`}, {
             4.243396016873138, -1.553310178029194}, {
             4.389199956021649, -1.5561180206179053`}, {
             4.53443255933322, -1.5590066119233688`}, {
             4.679070420806092, -1.5619745752877998`}, {
             4.823090134438505, -1.565020534053414}, {
             4.966468294228699, -1.5681431115624267`}, {
             4.967540230858074, -1.5681671307839067`}}]}, 
           {Arrowheads[{{0.01410077067284759, 1.}}], 
            ArrowBox[{{4.991146298440973, -1.568696079370983}, {
             5.109181494174916, -1.5713409311570534`}, {
             5.2512063282753925`, -1.5746126161795093`}, {
             5.392230660535344, -1.5779490607761284`}, {
             5.531777366392544, -1.5813367424098834`}, {
             5.656854249492381, -1.5844509226554162`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.056298224000441}, \
{-5.646204171661844, -2.0559477524687635`}, {-5.459878896226755, \
-2.050008940650466}, {-5.26831181112072, -2.0440903907988384`}, \
{-5.242336432377579, -2.043300056556627}, {-5.2163410436987885`, \
-2.0425128974118407`}, {-5.018612459020053, -2.036771555335781}, \
{-4.819721999828933, -2.031214315199445}, {-4.712791429503978, \
-2.028281488359286}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689188312699995, -2.02763411638452}, \
{-4.654409587385885, -2.026680226596429}, {-4.48847104402759, \
-2.0222985236767808`}, {-4.321906369754046, -2.0180692064405004`}, \
{-4.1547155645652545`, -2.0139922748875874`}, {-3.9868986284612147`, \
-2.010067729018042}, {-3.818455561441927, -2.006295568831865}, \
{-3.7449878500328686`, -2.00472262383782}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721381266912299, -2.004217206477815}, \
{-3.649386363507391, -2.0026757943290554`}, {-3.4796910346576064`, \
-1.9992084055096133`}, {-3.3093695748925747`, -1.995893402373539}, \
{-3.138421984212294, -1.9927307849208324`}, {-2.9668482626167654`, \
-1.9897205531514937`}, {-2.7946484101059883`, -1.9868627070655225`}, \
{-2.777067248560896, -1.9865874872435425`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753458148154586, -1.986217904585749}, \
{-2.6218224266799637`, -1.9841572466629191`}, {-2.4483703123386906`, \
-1.9816041719436834`}, {-2.27429206708217, -1.9792034829078153`}, \
{-2.0995876909104005`, -1.976955179555315}, {-1.9051218574991748`, \
-1.9746553622423435`}, {-1.8090634207800655`, -1.9736313592699402`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785452769301759, -1.973379664800199}, \
{-1.7103381177120696`, -1.9725789269459717`}, {-1.5152364715490854`, \
-1.9707258736662}, {-1.3198169190102225`, -1.9690962024030279`}, \
{-1.1240794600954804`, -1.9676899131564558`}, {-0.9280240948048597, \
-1.9665070059264835`}, {-0.8410025712771849, -1.9660817986402666`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.817390860145353, -1.9659664263598662`}, \
{-0.7316508231383607, -1.9655474807131113`}, {-0.5349596450959822, \
-1.9648113375163387`}, {-0.3849494707412655, -1.9644022301765243`}, \
{-0.23494633230434814`, -1.9641266614313164`}, {-0.08495022978523237, \
-1.963984631280715}, {0.06503883681608302, -1.9639761397247202`}, {
             0.12708555866608998`, -1.9640278709807084`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15069754345731737`, -1.964047557397544}, {
             0.21502086749959792`, -1.964101186763332}, {
             0.3649958622653124, -1.9643597723965505`}, {
             0.5149638211132271, -1.9647518966243755`}, {
             0.6649247440433406, -1.965277559446807}, {
             0.8147929968849759, -1.9659351072024265`}, {
             0.9644829454674533, -1.9667228862298158`}, {
             1.0951696052841247`, -1.967525310015718}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1187811255093527`, -1.9676744954943417`}, {
             1.2633279298549338`, -1.968689138099903}, {
             1.4124829656599371`, -1.969867610942601}, {
             1.5614596972057833`, -1.9711763150570687`}, {
             1.7102581244924715`, -1.9726152504433059`}, {
             1.858878247520002, -1.9741844171013125`}, {
             2.008386610751072, -1.975943626854292}, {
             2.0632172477173993`, -1.97660944733308}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.086827500021745, -1.9768961518173491`}, {
             2.1559847887459402`, -1.9777359439780404`}, {
             2.3033645416868156`, -1.9796562423990178`}, {
             2.450505809176281, -1.981703397129954}, {
             2.597388530816918, -1.9838762831835786`}, {
             2.743992646211309, -1.9861737755726214`}, {
             2.8902980949620365`, -1.9885947493098122`}, {
             3.031199888376362, -1.9910494915484604`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.054808016884816, -1.9914765900210933`}, {
             3.1819284716120153`, -1.9937997103559424`}, {
             3.3272040353618557`, -1.9965751177593347`}, {
             3.4720904204843936`, -1.99946247330512}, {
             3.6165665395428164`, -2.002459948680361}, {
             3.7606113051003076`, -2.005565715572119}, {
             3.904203629720052, -2.0087779456674575`}, {
             3.9990852630657434`, -2.0109768851199514`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.022690917512791, -2.0115239604920254`}, {
             4.047322425965237, -2.0120948106534384`}, {
             4.189946606399044, -2.0155144822171236`}, {
             4.332055083584662, -2.019035132045576}, {
             4.4736267700852785`, -2.022654931825858}, {
             4.614640578464075, -2.026372053245032}, {
             4.755075421284239, -2.0301846679901594`}, {
             4.894910211108956, -2.034090947748304}, {
             4.966848220961197, -2.0361569559480546`}}]}, 
           {Arrowheads[{{0.014118234857750853`, 1.}}], 
            ArrowBox[{{4.990450482424331, -2.0368347960191886`}, {
             5.03412386050141, -2.0380890642065266`}, {
             5.172695282024786, -2.0421771890518903`}, {
             5.310603388242273, -2.046353493971458}, {
             5.318704011786524, -2.0466023437678906`}, {
             5.326802679463407, -2.046851501532199}, {
             5.3348993918993735`, -2.047100967168491}, {
             5.342994149708065, -2.0473507405797253`}, {
             5.3510869534784335`, -2.047600821671038}, {
             5.3672686546370345`, -2.0481015989690134`}, {
             5.383442545369109, -2.04860360611971}, {
             5.399608630400804, -2.0491068423702172`}, {
             5.560841512766215, -2.054206584595767}, {
             5.656854249492381, -2.0573311968422736`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.602521307923698, -5.55872914284084}, {
             4.793841121589273, -5.574633616785719}, {
             4.806523789709248, -5.57570759176419}, {
             4.819169414416937, -5.576780867872912}, {
             4.997015626507674, -5.592426739675412}, {
             5.171469116634273, -5.608330021159341}, {
             5.357369919888257, -5.62563129598991}, {
             5.543168426362307, -5.643613811200308}}]}, 
           {Arrowheads[{{0.0019191418444276208`, 1.}}], 
            ArrowBox[{{5.566666135375148, -5.645934058301909}, {
             5.656854249492381, -5.6548680015714075`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.635317045918636}, \
{-5.5993956719697175`, -5.629595074143353}, {-5.39694201588566, \
-5.609884859230327}, {-5.200217795480562, -5.59151286487335}, \
{-5.017249624101876, -5.575087280804594}, {-4.829988291212114, \
-5.558882056446429}, {-4.817233638384321, -5.5577982226142995`}, \
{-4.804445999365569, -5.556714132527285}, {-4.716293453828789, \
-5.549508740884263}}]}, 
           {Arrowheads[{{0.001686465548790482, 1.}}], 
            ArrowBox[{{-4.692759944372346, -5.547585164527665}, \
{-4.613383038491493, -5.5410970740159255`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.0057449239544036`}, \
{-5.557681820584556, -3.0008973827458663`}, {-5.329593426945185, \
-2.9902058392769484`}, {-5.0999918215493665`, -2.979894553415918}, \
{-4.86882602511689, -2.969963103642048}, {-4.713318798264368, \
-2.963584584625267}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689726643071703, -2.9626168931964565`}, \
{-4.635918021969901, -2.9604097976169688`}, {-4.401234390040308, \
-2.9512406290983475`}, {-4.164886300869782, -2.942469277939894}, \
{-3.9269849259999963`, -2.9341094239953183`}, {-3.7458802580834116`, \
-2.928105471154687}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7222812297147807`, -2.927323119959436}, \
{-3.68764143697262, -2.9261747471183286`}, {-3.4469670053293235`, \
-2.9186789271626346`}, {-3.2050728026117787`, -2.911635643981945}, \
{-2.9620700003616562`, -2.90505857742997}, {-2.8139741961526203`, \
-2.9013020500322835`}, {-2.7781867182444477`, -2.9004419920629094`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754581540905281, -2.899874703668317}, \
{-2.6655696448676034`, -2.897735536701795}, {-2.5168751061244814`, \
-2.8943603411530603`}, {-2.367909339541132, -2.8911777671006353`}, \
{-2.218691104735431, -2.8881891182590773`}, {-2.0692391613252563`, \
-2.885395698342942}, {-1.9195722689284853`, -2.8827988110667855`}, \
{-1.8102933820678824`, -2.880987667159667}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7866846313205507`, -2.880596385309173}, \
{-1.7681083664375103`, -2.880288509836367}, {-1.6174644205461377`, \
-2.8780466628322787`}, {-1.4666430449039225`, -2.876003955897281}, \
{-1.3156442395108616`, -2.8741603890313754`}, {-1.1644680043669566`, \
-2.8725159622345604`}, {-1.0131143394722075`, -2.871070675506837}, \
{-0.8615832448266145, -2.8698245288482047`}, {-0.8422706567683738, \
-2.869691244268195}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186592260677041, -2.8695282915031446`}, \
{-0.7098747204301774, -2.868777522258664}, {-0.5579887662828962, \
-2.867929655738214}, {-0.406018820744377, -2.8672831359988393`}, \
{-0.2540583221742262, -2.866840169752522}, {-0.10210727057244373`, \
-2.866600756999263}, {0.04983433406096971, -2.866564897739062}, {
             0.12581327673308967`, -2.8666487590538785`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1494252553484031, -2.866674820637555}, {
             0.2017664917260148, -2.866732591971919}, {
             0.3536892024226924, -2.867103839697834}, {
             0.5056024661510015, -2.867678640916807}, {
             0.6575062829109423, -2.8684569956288377`}, {
             0.8940428446184656, -2.870065879850836}, {
             1.0938881555268345`, -2.8718294203512778`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1174992292185029`, -2.872037776927296}, {
             1.1300038852573135`, -2.872148124612054}, {
             1.3653894048274853`, -2.874703729912492}, {
             1.60019940332898, -2.8777326957521496`}, {
             1.8344338807617984`, -2.8812350221310274`}, {
             2.0618859495009683`, -2.8851050993934253`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0854938744039773`, -2.8855428563789354`}, {
             2.3011762724214067`, -2.889659756506442}, {
             2.5336841866481974`, -2.894582164502979}, {
             2.76533940736528, -2.8999465695573656`}, {
             2.9958647621316237`, -2.9057216081882316`}, {
             3.0297354659809304`, -2.906634935091588}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.053338879321423, -2.9072714034835894`}, {
             3.2252602509472275`, -2.911907280395577}, {
             3.453525873812093, -2.9185035861794013`}, {
             3.680661630726219, -2.9255105255397047`}, {
             3.906667521689606, -2.932928098476488}, {
             3.9973761301846054`, -2.936085774888589}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.020973829425715, -2.9369072393505604`}, {
             4.131543546702254, -2.9407563049897503`}, {
             4.355289705764163, -2.948995145079492}, {
             4.537647033078994, -2.956026815803893}, {
             4.718995483530221, -2.963284284153439}, {
             4.893936453848888, -2.9705392490131697`}, {
             4.964738720408334, -2.9735776970583094`}}]}, 
           {Arrowheads[{{0.01417150111169713, 1.}}], 
            ArrowBox[{{4.988329000768051, -2.97459006353648}, {
             5.0679841157407175`, -2.9780084276671097`}, {
             5.24113846920571, -2.9856918201152602`}, {
             5.4133995142438645`, -2.99358942635762}, {
             5.436442231354233, -2.994662970544093}, {
             5.459469344039452, -2.9957403946593653`}, {
             5.656854249492381, -3.0053686862396405`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.4606679849072783`}, {-5.515664308623704, 
             3.4528132809756684`}, {-5.360557674453249, 
             3.444410988818125}, {-5.202852835008463, 
             3.4360907805760355`}, {-5.042549790289345, 
             3.427852656249399}, {-5.020881302017439, 
             3.4267535471962067`}, {-4.999196240146687, 
             3.4256577995693753`}, {-4.808196434099449, 
             3.4163664080556573`}, {-4.713636164065978, 
             3.4119377994646816`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.690050023780782, 
             3.410833172929055}, {-4.61602285692923, 
             3.4073662058088434`}, {-4.470456603398349, 
             3.4006587640084835`}, {-4.32434186500497, 
             3.394145567437689}, {-4.177678641749093, 
             3.3878266160964587`}, {-4.03046693363072, 
             3.3817019099847934`}, {-3.8827067406498474`, 
             3.375771449102693}, {-3.7464352593786527`, 3.370500802669667}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7228402738014634`, 
             3.369604935548086}, {-3.58554090010061, 
             3.3644932630271875`}, {-3.4361352525322446`, 
             3.359145537833782}, {-3.286247447837501, 
             3.354005040865589}, {-3.1359438137524975`, 
             3.3490847551182568`}, {-2.985224350277235, 
             3.3443846805917854`}, {-2.8340890574117132`, 
             3.3399048172861745`}, {-2.7788814353785996`, 
             3.3383530949446496`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755278763656599, 
             3.337689693919901}, {-2.6825379351559318`, 
             3.335645165201424}, {-2.5305709835098913`, 
             3.3316057243375345`}, {-2.3781882024735914`, 
             3.327786494694506}, {-2.2253895920470326`, 
             3.324187476272338}, {-2.071110085631612, 
             3.320690757570347}, {-1.9181442310111236`, 
             3.3176057176671288`}, {-1.8110610379714143`, 
             3.3156082167071204`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7874531519355716`, 
             3.31516784157745}, {-1.7648026122015765`, 
             3.314745324527117}, {-1.611105261803572, 
             3.312111795921484}, {-1.457072212417711, 
             3.309707349621403}, {-1.3027234966445937`, 
             3.3075342033980464`}, {-1.1480791470848215`, 
             3.3055945750225866`}, {-0.9931591963389943, 
             3.3038906822661964`}, {-0.8506142359512388, 
             3.3025332270048953`}, {-0.8430622414497113, 
             3.3024719257849404`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.819451026302168, 
             3.3022802682972574`}, {-0.7079326711925604, 
             3.301375048992056}, {-0.5651371128082121, 
             3.30041749705495}, {-0.42225017154344635`, 
             3.2996619200208497`}, {-0.2792944581435137, 
             3.299109666717027}, {-0.13629258335366634`, 3.298762085970753}, {
             0.006732842080843016, 3.2986205266093003`}, {
             0.12501823982470733`, 3.298674953376181}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14863023032310638`, 3.2986858179826917`}, {
             0.149759207414764, 3.2986863374599404`}, {0.2927639019028444, 
             3.298960867349945}, {0.4357243147998314, 3.299445465106586}, {
             0.578617835360475, 3.3001414795571353`}, {0.7214218528395222, 
             3.3010502595288647`}, {0.8641137564917223, 
             3.3021731538490458`}, {1.0066709355718215`, 
             3.3035115113449507`}, {1.0930884247369121`, 
             3.304455289370052}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1166990097427192`, 3.304713144018498}, {
             1.1490707793345691`, 3.305066680843851}, {1.2912906770347137`, 
             3.3068400111730187`}, {1.4333278531283846`, 
             3.3088225477554056`}, {1.575182705703934, 3.3110036874692717`}, {
             1.7168373844644413`, 3.3133823063248524`}, {1.8582740391129875`, 
             3.3159572803323827`}, {1.9994748193526515`, 3.318727485502097}, {
             2.0610509459216315`, 3.320022516968188}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0846577186309707`, 3.3205190001861964`}, {
             2.1404218748865116`, 3.321691797844231}, {2.281097355417649, 
             3.324849093369019}, {2.4214834106491434`, 3.328198248086697}, {
             2.561562190284075, 3.331738138007499}, {2.701315844025525, 
             3.3354676391416604`}, {2.8407265215765722`, 3.339385627499416}, {
             2.979776372640294, 3.3434909790910012`}, {3.0288161472712516`, 
             3.3450086603862093`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.052416840877855, 3.3457390538578395`}, {
             3.1184475469197728`, 3.3477825699266504`}, {3.256722194118088, 
             3.352259276016599}, {3.3945824639383195`, 3.356919973371082}, {
             3.532010506083548, 3.361763538000334}, {3.668922204970344, 
             3.3667764451729245`}, {3.805222842569436, 3.3719431860387563`}, {
             3.940878664915142, 3.3772596604300644`}, {3.996289287043477, 
             3.3795019551982146`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.019881970630979, 3.3804566773966473`}, {
             4.075855918041781, 3.382721768179084}, {4.210120847983671, 
             3.3883254091180506`}, {4.343639700775129, 3.394066483079199}, {
             4.476378722450473, 3.3999408898947645`}, {4.608304159044019, 
             3.4059445293969826`}, {4.739382256590088, 3.4120733014180877`}, {
             4.869579261122995, 3.418323105790316}, {4.963402340892877, 
             3.4229435951372613`}}]}, 
           {Arrowheads[{{0.014204870785645987`, 1.}}], 
            ArrowBox[{{4.9869857533693205`, 3.424105003464288}, {
             4.998861418677059, 3.4246898423459027`}, {5.127194975286598, 
             3.431169410917082}, {5.254546176985931, 3.43775771133609}, {
             5.380881269809372, 3.4444506434351614`}, {5.506166499791242, 
             3.4512441070465316`}, {5.630368112965856, 3.458134002002436}, {
             5.635862014462614, 3.458442194826589}, {5.641341170144288, 
             3.458749835139294}, {5.646805270713927, 3.4590569037613905`}, {
             5.652254009048892, 3.4593633816282865`}, {5.656854249492381, 
             3.4596223635264622`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.303012623453794}, {-5.5135157539111495`, 
             5.28970011607248}, {-5.3904603559681386`, 
             5.278690973015417}, {-5.264047320667872, 
             5.267638337335853}, {-5.134820269894497, 
             5.256599144899344}, {-5.003322825532157, 
             5.245630331571438}, {-4.87053539063835, 
             5.234832445488842}, {-4.737088943331895, 
             5.224271144971338}, {-4.715810990329644, 5.222633457686915}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.692268624802357, 
             5.22082148673909}, {-4.603002968088913, 
             5.213951031159093}, {-4.468296949385532, 
             5.203876705192271}, {-4.332990371697876, 
             5.194052768211041}, {-4.1971027195020705`, 
             5.184483821355567}, {-4.060653477274242, 
             5.175174465766015}, {-3.923662129490514, 
             5.1661293025825525`}, {-3.786148160627013, 
             5.1573529329453445`}, {-3.7500854049131167`, 
             5.155131174218745}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7265180951361216`, 
             5.153679236475138}, {-3.6481310551598636`, 
             5.148849957994559}, {-3.5096302975651916`, 
             5.140624978870359}, {-3.370665372319122, 
             5.132682596712912}, {-3.2312557638977797`, 
             5.125027412662385}, {-3.0914209567772906`, 
             5.117664027858944}, {-2.9511804354337796`, 
             5.110597043442754}, {-2.8105536843433727`, 
             5.103831060553982}, {-2.7834303241954164`, 5.102594743897718}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.759842821774544, 
             5.101519596056024}, {-2.645995496086544, 
             5.096330292656615}, {-2.480965907259013, 
             5.0892666424602595`}, {-2.315496386950018, 
             5.082645081274276}, {-2.1492827339635987`, 
             5.076417553108167}, {-1.9827707603972824`, 
             5.070654484844558}, {-1.8160655612570438`, 5.065349296392578}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7924635402793219`, 
             5.064663157912865}, {-1.6486158333556804`, 
             5.060484443204625}, {-1.480972879880394, 
             5.056077469828302}, {-1.313020323883818, 
             5.052131683362294}, {-1.144825556147652, 
             5.048656239087824}, {-0.9763885766718962, 
             5.04565113700489}, {-0.8482259388919158, 5.0437252236098855`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8246166114004001, 
             5.043370443770374}, {-0.8077093854565501, 
             5.043116377113494}, {-0.7539688169746931, 
             5.042408680384601}, {-0.70021151448578, 
             5.041749709394647}, {-0.4624321430769932, 
             5.039421353923672}, {-0.22445460193816907`, 
             5.038045631633221}, {-0.2097312429285723, 
             5.037989994513623}, {-0.1950075378909846, 
             5.0379380028412815`}, {-0.1572164381429179, 
             5.037837945778961}, {-0.11942412260854285`, 5.037761921720894}, {
             0.07959747414737989, 5.037694935226894}, {0.1198365256111718, 
             5.037816219202276}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.14344841135574127`, 5.037887387464578}, {
             0.278596555249374, 5.038294735639068}, {0.47751284131295235`, 
             5.039560723396103}, {0.6762860529536278, 5.041492298936684}, {
             0.8748682200521576, 5.044085508152438}, {1.073172996393906, 
             5.04733323364829}, {1.0878676494044661`, 5.047626718898389}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.11147493450888, 5.048098209444511}, {
             1.3051307143583473`, 5.051965950652236}, {1.5366089114414643`, 
             5.057477634277905}, {1.7675085184718056`, 5.0638579030662765`}, {
             1.9977304662779192`, 5.071096375558324}, {2.0556125907621605`, 
             5.073136304390874}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.079209933699447, 5.0739679411121985`}, {
             2.227175685688353, 5.079182670295027}, {2.4557451075316563`, 
             5.088106405817362}, {2.6833396626363757`, 5.097857200666305}, {
             2.9098602818310604`, 5.108424673382834}, {3.022825247612291, 
             5.114115892953824}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0464073317403915`, 5.115303967661645}, {
             3.13527436993708, 5.11978112412784}, {3.3595697853120576`, 
             5.131893524329878}, {3.5826781390889213`, 5.1447434994314225`}, {
             3.804531042400598, 5.15831267487495}, {3.98927684047492, 
             5.170267211468966}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.012839554939063, 5.1717919082969965`}, {
             4.025060106380016, 5.1725826761029365`}, {4.244196942160102, 
             5.187535128557856}, {4.461873160873783, 5.203151657682185}, {
             4.678020373653989, 5.2194138889184}, {4.892599152139004, 
             5.236312554430605}, {4.954739231771441, 5.241428155924394}}]}, 
           {Arrowheads[{{0.014424279110359541`, 1.}}], 
            ArrowBox[{{4.978271617669147, 5.243365429084693}, {
             5.105599028472472, 5.2538474931045425`}, {5.314780838333657, 
             5.271783225320638}, {5.515691201190123, 5.2896535063148225`}, {
             5.656854249492381, 5.302659545242439}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.843459525238695}, {-5.614116877029507, 
             4.839957415580064}, {-5.605566636516047, 
             4.839261371634704}, {-5.5969713517116375`, 
             4.838562522709586}, {-5.588331757696855, 
             4.837860941678531}, {-5.584000975977044, 
             4.837509477305397}, {-5.579659363147421, 
             4.837157353757611}, {-5.575307013184114, 
             4.83680458031731}, {-5.570944020650482, 
             4.836451166315331}, {-5.566570480711864, 
             4.8360971211328225`}, {-5.407533347777653, 
             4.823407848607831}, {-5.245402441951357, 
             4.810843363208974}, {-5.080386649849985, 
             4.798431585188906}, {-4.912694858090548, 
             4.78620043480028}, {-4.742535953290055, 
             4.774177832295749}, {-4.715065672131017, 4.772300011788229}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.691508654204374, 
             4.770689695129926}, {-4.570118822065517, 
             4.762391697927966}, {-4.3956523510339425`, 
             4.750869951949586}, {-4.219345426812342, 
             4.73964051461326}, {-4.041723262911969, 
             4.7287675602325265`}, {-3.863196044882537, 
             4.718302079826057}, {-3.748867730796607, 4.711897343135682}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7252927016204156`, 
             4.710576656693758}, {-3.6838001173987402`, 
             4.708252218704203}, {-3.5035718251352703`, 
             4.698626122177318}, {-3.322547512766824, 
             4.689431935555754}, {-3.140763524968094, 
             4.6806778041498625`}, {-2.9582562064137736`, 
             4.672371873269999}, {-2.7819296183967914`, 4.664816558977762}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.758337390884726, 
             4.663851069770627}, {-2.591186305811694, 
             4.657142658748345}, {-2.40664625868986, 
             4.650244607503126}, {-2.221494823228906, 
             4.643833299209255}, {-2.0357850622446785`, 
             4.637913898585128}, {-1.8495700385530252`, 
             4.632491570349144}, {-1.814417534624456, 4.631565036384387}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.790813739224062, 
             4.630942898109968}, {-1.6629028149697949`, 
             4.627571479219698}, {-1.4758364543108342`, 
             4.623158789915189}, {-1.2884240193919914`, 
             4.619258667154014}, {-1.0825436651944527`, 
             4.615581441331887}, {-0.8763080779802983, 
             4.612536544951981}, {-0.8465283938790438, 
             4.612189447690103}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8229180045717562, 
             4.611914256675565}, {-0.6698145169431571, 
             4.6101297581846055`}, {-0.4631170149683785, 
             4.608364292235491}, {-0.2562721287744766, 
             4.6072422031360905`}, {-0.04933641507996567, 
             4.606765546917858}, {-0.01724499079331291, 
             4.6067494431464615`}, {0.01484714767859907, 4.606748868061211}, {
             0.12154009958749154`, 4.606879858501845}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14515207478997302`, 4.606908847699169}, {
             0.14804334674988281`, 4.606912397408697}, {0.2811995506576357, 
             4.607343291475777}, {0.4143157594018577, 4.608041550262449}, {
             0.5473919729825488, 4.609007173768715}, {0.5642414734635186, 
             4.609146383760371}, {0.5810899821919939, 4.6092898887246285`}, {
             0.6310787973173827, 4.609766370954421}, {0.681057383308944, 
             4.610280737866097}, {0.842385603863347, 4.612135565844796}, {
             1.0035222854957957`, 4.614377380378908}, {1.0895819217730875`, 
             4.615783037373583}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1131907657507072`, 4.616168652954927}, {
             1.1644674282062901`, 4.617006181468433}, {1.3252210319948303`, 
             4.6200219691133695`}, {1.4857250454397832`, 4.623418477859977}, {
             1.645921417119515, 4.627189442254515}, {1.8058101470340262`, 
             4.631334862296982}, {1.9653912351833167`, 4.63585473798738}, {
             2.0573937745030566`, 4.638685821077189}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0809945962975926`, 4.639412060678641}, {
             2.124728959942827, 4.64075784546105}, {2.2834590771850602`, 
             4.645994453284384}, {2.4418301299617196`, 4.651598495847374}, {
             2.5998164069226295`, 4.657566462695883}, {2.840485490250365, 
             4.667369722399125}, {3.024775599213238, 4.675523309038132}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0483645162945257`, 4.676566958533078}, {
             3.0800745389981925`, 4.677969911838029}, {3.318485899351852, 
             4.689347977724054}, {3.5556219174970844`, 4.701484866768658}, {
             3.791384939619631, 4.714361525683302}, {3.9915432968480533`, 
             4.7259779019032155`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.015115625423162, 4.727345943892066}, {
             4.0256773119052305`, 4.727958901179443}, {4.258401380539626, 
             4.742257939968541}, {4.489459491708556, 4.757239588762055}, {
             4.718809753651235, 4.77288096637407}, {4.946466036660349, 
             4.789155363721298}, {4.957509115536468, 4.789979349796546}}]}, 
           {Arrowheads[{{0.01435382770749607, 1.}}], 
            ArrowBox[{{4.98105565196949, 4.791736288994281}, {
             5.17203310051059, 4.805986187962638}, {5.394734475485394, 
             4.8232450485505}, {5.607485492804434, 4.840274537881672}, {
             5.656854249492381, 4.844341557847591}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.002853998224591}, {-5.49083499469964, 
             2.9948857772675184`}, {-5.318866570425514, 
             2.986890129515746}, {-5.146026172243998, 
             2.979110738849354}, {-4.972313800155091, 
             2.9715476052683423`}, {-4.948993921355434, 
             2.970549319583078}, {-4.925657960458283, 
             2.9695548822203275`}, {-4.737223434256107, 
             2.961853724371776}, {-4.713309299712142, 2.960913068510246}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689715552023918, 
             2.959985014976986}, {-4.54771548049967, 
             2.954399481477065}, {-4.3087828517144375`, 
             2.945259016077458}, {-4.068490183203429, 
             2.936580820699519}, {-3.826837474966644, 
             2.928364895343249}, {-3.7458579051130982`, 2.925781130997333}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7222579216472016`, 
             2.9250281411265093`}, {-3.5838247270040835`, 
             2.9206112400086477`}, {-3.3394519393157465`, 
             2.913319854695714}, {-3.093719111901634, 
             2.9064907394044495`}, {-2.970342683297411, 
             2.9032495330169428`}, {-2.8466262447617448`, 
             2.900123894134853}, {-2.7781544729189718`, 
             2.8984625139883096`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.754549427377578, 
             2.8978897676876767`}, {-2.7225697962946342`, 
             2.8971138227581807`}, {-2.5981733378960796`, 
             2.8942193188869254`}, {-2.3929711843266848`, 
             2.8897349273977095`}, {-2.187265865007513, 
             2.8856163264821197`}, {-1.9810573799385647`, 
             2.8818635161401556`}, {-1.8102600833204512`, 
             2.8790649616429467`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7866512593117232`, 
             2.8786781254229847`}, {-1.7743457291198392`, 
             2.8784764963718175`}, {-1.567130912551338, 
             2.8754552671771054`}, {-1.359412930233059, 
             2.872799828556019}, {-1.1511917821650037`, 
             2.8705101805085587`}, {-0.9424674683471723, 
             2.8685863230347244`}, {-0.8422365576250337, 
             2.8678218353999143`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186252514128204, 
             2.8676417457298626`}, {-0.7837332227248108, 
             2.8673756150093768`}, {-0.6249530806361624, 
             2.8663879142546898`}, {-0.4661270420812266, 
             2.865623220770664}, {-0.3072551070600036, 
             2.865081534557298}, {-0.14833727557249315`, 2.864762855614593}, {
             0.010626452381304607`, 2.864667183942549}, {0.12584723202602333`,
              2.8647594532438734`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1494592174529573, 2.8647783618244693`}, {
             0.16963607680138895`, 2.8647945195411655`}, {
             0.32869159768776135`, 2.865144862410443}, {0.4876909592071266, 
             2.8657164670760853`}, {0.646532105526188, 2.8665075880637967`}, {
             0.8052150366449478, 2.867518225373577}, {0.9637397525634048, 
             2.8687483790054267`}, {1.0939221021469356`, 
             2.869940054264184}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1175331059383353`, 2.870156186859291}, {
             1.1221062532815593`, 2.8701980489593453`}, {1.2803145387994115`, 
             2.8718672352353334`}, {1.4383646091169617`, 2.87375593783339}, {
             1.5962564642342079`, 2.8758641567535164`}, {1.755198746771942, 
             2.878267909670121}, {1.9120201906687182`, 2.8807677395503495`}, {
             2.061917825922361, 2.883367667626734}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0855258411109463`, 2.883800806642808}, {
             2.225029301231038, 2.886415939680383}, {2.381171501716489, 
             2.88956145033115}, {2.537041821551408, 2.892919328306393}, {
             2.692617527645747, 2.8964881438065935`}, {2.8478758869094585`, 
             2.9002664670322322`}, {2.9901777626423685`, 2.903914716361648}, {
             3.029765297761306, 2.9049772044318467`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.053368791143328, 2.905610697526531}, {
             3.132139336614267, 2.907724816644947}, {3.273739019181324, 
             2.9116942579298297`}, {3.4149552206997096`, 
             2.9158205302639963`}, {3.5557663515255946`, 
             2.9201011236951473`}, {3.69615082201515, 2.924533528270983}, {
             3.8360870425245457`, 2.9291152340392026`}, {3.9755534234099534`, 
             2.933843731047508}, {3.9974006983351784`, 
             2.9346097462599277`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.020998190842837, 2.935437128086617}, {
             4.114528375027543, 2.9387165093435983`}, {4.252990307733485, 
             2.943731058975174}, {4.390917631883951, 2.9488848699899357`}, {
             4.528288757835112, 2.9541754324355836`}, {4.665082095943136, 
             2.9596002363598175`}, {4.8012760565641965`, 
             2.9651567718103378`}, {4.936849050054463, 2.970842528834845}, {
             4.964765677862233, 2.972045107939974}}]}, 
           {Arrowheads[{{0.014170772109336672`, 1.}}], 
            ArrowBox[{{4.988355793237582, 2.973061311617342}, {
             5.071779486770107, 2.9766549974810395`}, {5.2060989606557735`, 
             2.982594697423236}, {5.3398694562780955`, 2.988663879550957}, {
             5.473114969926223, 2.994862630734715}, {5.6058594978893055`, 
             3.0011910378450235`}, {5.656854249492381, 
             3.00368141630713}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.9185141795636915`}, {-5.606130300315846, 
             3.915166112205929}, {-5.563614720256003, 
             3.912427284681209}, {-5.520478374647779, 
             3.9096703268967827`}, {-5.476960149217833, 
             3.906909395025333}, {-5.472596085736951, 
             3.9066335929229865`}, {-5.468231261666951, 
             3.906357927622764}, {-5.461682693682928, 
             3.905944669131622}, {-5.457316156688618, 
             3.9056693117236354`}, {-5.452948857652304, 
             3.905394091187669}, {-5.433232718159144, 
             3.9041522362338847`}, {-5.413501018835564, 
             3.90291317101933}, {-5.209337813000087, 
             3.8906077200305775`}, {-5.003955976272913, 
             3.8787324630624838`}, {-4.852008109129706, 
             3.87008123672717}, {-4.714043717805879, 
             3.8624686766138607`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.6904667475900315`, 
             3.861183260907326}, {-4.546039611971727, 
             3.853465683593795}, {-4.392018981956954, 
             3.845501356795732}, {-4.237307430984993, 
             3.8377659965100865`}, {-4.081904959055844, 
             3.8302596027368576`}, {-3.925811566169506, 
             3.822982175476046}, {-3.7690272523259796`, 
             3.815933714727651}, {-3.7471216204698607`, 
             3.8149878367172314`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7235316088317454`, 
             3.8139692277393853`}, {-3.6116412127136814`, 
             3.809137837074173}, {-3.453742642521028, 
             3.8026181590981114`}, {-3.29533154174802, 
             3.7963746807994663`}, {-3.1364079103946567`, 
             3.790407402178238}, {-2.976971748460939, 
             3.784716323234426}, {-2.8170230559468656`, 
             3.7793014439680306`}, {-2.779737956468923, 
             3.7781074098209295`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7561380619740783`, 
             3.7773516365954487`}, {-2.6565618328524376`, 
             3.774162764379052}, {-2.4955880791776544`, 
             3.76930028446749}, {-2.332935842264628, 
             3.764549039512256}, {-2.171664377206313, 
             3.760341867982162}, {-2.009924241855714, 
             3.7564171016989305`}, {-1.847737366356866, 
             3.752777843447283}, {-1.8120030824295308`, 
             3.7520415311310775`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7883961003616835`, 
             3.75155510437966}, {-1.6851256808538049`, 
             3.749427196011943}, {-1.522111115490567, 
             3.746368262177633}, {-1.358715600411187, 
             3.7436041447290753`}, {-1.1949610657597003`, 
             3.741137946450993}, {-1.050910379650072, 
             3.739219499012222}, {-0.9066912159382936, 
             3.737533558827123}, {-0.8440347421672167, 
             3.7369035727855127`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8204239426067405, 
             3.7366661755421138`}, {-0.7623269427092665, 
             3.7360820332054643`}, {-0.617840928047894, 
             3.7348668294570158`}, {-0.4732565400390787, 
             3.7338898548915473`}, {-0.328597146767722, 
             3.7331530168188274`}, {-0.18388611631872753`, 
             3.7326582225486264`}, {-0.039146816776998605`, 
             3.732407379390713}, {0.10559738377256345`, 
             3.7324023946548572`}, {0.12404146396653262`, 
             3.7324333350553776`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14765342374144505`, 3.732472944701661}, {
             0.25032311724505574`, 3.732645175650828}, {0.3950070155555767, 
             3.7331376296883954`}, {0.5396257106192218, 3.733881664077328}, {
             0.6841558343510894, 3.734879186127396}, {0.8285740186662782, 
             3.736132103148369}, {0.9728568954798834, 3.7376423224500153`}, {
             1.0921044798786674`, 3.7391063383429093`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1157146935898223`, 3.7393962035697985`}, {
             1.1169810967070035`, 3.7394117513421055`}, {1.260939323904568, 
             3.7414289277930717`}, {1.4047268497721985`, 
             3.7436802506767326`}, {1.5483241629390334`, 3.746164418660937}, {
             1.6917117520342075`, 3.748880130413533}, {1.8348701056868593`, 
             3.75182608460237}, {1.9777797125261265`, 3.755000979895296}, {
             2.0600263948998383`, 3.7569628739981207`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0836316731190383`, 3.75752594906446}, {
             2.120421061181144, 3.75840351496016}, {2.2627746402810502`, 
             3.7620323884648097`}, {2.404820938454982, 3.765886299077095}, {
             2.5465404443320767`, 3.7699639454648635`}, {2.687913646541471, 
             3.7742640262959646`}, {2.828921033712302, 3.7787852402382462`}, {
             2.9695430944737073`, 3.783526285959557}, {3.0276896531756807`, 
             3.785582968303347}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.051286889727233, 3.786417618209742}, {
             3.109760317454823, 3.788485862127746}, {3.249553191284788, 
             3.7936626674106617`}, {3.3889022045927373`, 
             3.7990554004761523`}, {3.527792348439165, 3.804654852917189}, {
             3.6662093342735815`, 3.810450551194763}, {3.8041347313086487`, 
             3.8164392962787517`}, {3.9415501087570295`, 
             3.8226178891390328`}, {3.994969292990542, 
             3.825101881009792}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.0185557997998, 3.8261986534898376`}, {
             4.078437035831386, 3.828983130745485}, {4.214777081744381, 
             3.835531822067986}, {4.350551815708678, 3.842260764076414}, {
             4.485742806936938, 3.8491667577406465`}, {4.620331624641825, 
             3.856246604030562}, {4.754299838036, 3.8634971039160377`}, {
             4.887629016332128, 3.8709150583669527`}, {4.96176141567142, 
             3.875151737070801}}]}, 
           {Arrowheads[{{0.014246654802101086`, 1.}}], 
            ArrowBox[{{4.985334942819235, 3.876498967989156}, {
             5.0203007287428685`, 3.8784972683531844`}, {5.152296544480886, 
             3.8862405348446103`}, {5.283598032758843, 3.8941416588111095`}, {
             5.414186762789402, 3.902197441222559}, {5.544044303785223, 
             3.9104046830488373`}, {5.656854249492381, 3.917700722117545}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.473589118107576, 
             5.656854249492381}, {-4.438236290556041, 
             5.653954189217845}, {-4.313222076426436, 
             5.643981267029249}, {-4.187758144946064, 
             5.63425368732125}, {-4.061844496114922, 
             5.624771450093847}, {-3.935481129933014, 
             5.615534555347041}, {-3.808668046400336, 
             5.60654300308083}, {-3.68140524551689, 
             5.597796793295217}, {-3.5536927272826775`, 
             5.589295925990199}, {-3.5316421636642272`, 5.587879189815935}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.5080787553289654`, 
             5.586365254228837}, {-3.4253490862263902`, 
             5.581049920030102}, {-3.296192916876722, 
             5.57306829427925}, {-3.1662242192336745`, 
             5.565351048737644}, {-3.0354429932972478`, 
             5.557898183405282}, {-2.9038492390674406`, 
             5.550709698282165}, {-2.771442956544253, 
             5.543785593368293}, {-2.638224145727687, 
             5.537125868663667}, {-2.56508379413744, 5.53363595542368}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.5414986346202255`, 
             5.532510582648232}, {-2.50419280661774, 
             5.530730524168285}, {-2.327304637347456, 
             5.5227875437569685`}, {-2.149977437293007, 
             5.515419816178167}, {-1.972211206454392, 
             5.508627341431882}, {-1.7940059448316112`, 
             5.50241011951811}, {-1.6153616524246648`, 
             5.496768150436855}, {-1.597726869168057, 5.49626921820086}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5741243207988938`, 
             5.495601442926184}, {-1.436278329233553, 
             5.491701434188115}, {-1.2567559752582755`, 
             5.4872099707718895`}, {-1.0767945904988323`, 
             5.483293760188179}, {-0.9206814303996215, 
             5.480377433350605}, {-0.7644032886743224, 
             5.477912919346074}, {-0.629856315848355, 5.476184338712634}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6062462134984549, 
             5.475886086545127}, {-0.4514142218950843, 
             5.474351374979071}, {-0.2947635895680052, 
             5.473257762556902}, {-0.1380685610685586, 
             5.472622798848378}, {-0.10421960896095939`, 
             5.4725459124760825`}, {-0.07037114355234923, 
             5.4724904874145235`}, {0.13906552297513472`, 
             5.4726252417595465`}, {0.3382185459162075, 5.473534289591616}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.36183014802171437`, 5.473668208316746}, {
             0.36188301400377565`, 5.473668553135194}, {0.37528724516860823`, 
             5.473759339812964}, {0.41877179562943057`, 5.474100093680554}, {
             0.46224953784708755`, 5.474476135307343}, {0.6638538542911339, 
             5.476600638965905}, {0.8652109584711715, 5.479484635891178}, {
             1.066295299466184, 5.483119824923374}, {1.267081326355156, 
             5.487497904902707}, {1.306181420939443, 5.488496500818356}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3297857170663343`, 5.489099342165793}, {
             1.4674776867967507`, 5.492615922881323}, {1.6673930284496319`, 
             5.498470925911371}, {1.806126931772463, 5.502968724093627}, {
             1.9445342149685771`, 5.507803779675597}, {2.0826148780379734`, 
             5.512976092657279}, {2.220368920980652, 5.518485663038676}, {
             2.2737222598759117`, 5.520755572330983}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.2973129122376745`, 5.521759232872504}, {
             2.3577963437966134`, 5.524332490819786}, {2.494897146485857, 
             5.5305165760006085`}, {2.6316713290483835`, 5.537037918581145}, {
             2.7681188914841925`, 5.543896518561395}, {2.903958292787414, 
             5.551055588052925}, {3.038907991952175, 5.558478339167304}, {
             3.1729679889784768`, 5.566164771904531}, {3.240537893319031, 
             5.57019861794549}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.26410792242922, 5.571605721737324}, {
             3.3061382838663196`, 5.5741148862646055`}, {3.438418876615703, 
             5.582328682247528}, {3.5698097672266274`, 5.590806159853299}, {
             3.7003109556990923`, 5.5995473190819185`}, {3.829922442033098, 
             5.608552159933385}, {3.9633517614687195`, 5.618798346656116}, {
             4.088247167937171, 5.627720659889848}, {4.206346942957294, 
             5.6364465953380805`}}]}, 
           {Arrowheads[{{0.005056649003532767, 1.}}], 
            ArrowBox[{{4.229891560933006, 5.638228895889099}, {
             4.334749073580691, 5.64622761054111}, {4.467958856192093, 
             5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.594627245432151, 5.560807715543952}, {
             4.78593103036367, 5.576696111107809}, {4.798614650223308, 
             5.577769179463855}, {4.811260536319223, 5.578841480602533}, {
             4.988728547813864, 5.594436130337809}, {5.162658395943445, 
             5.610270397442773}, {5.348141037189027, 5.627508295856498}, {
             5.535283269887309, 5.645594492164017}}]}, 
           {Arrowheads[{{0.0019218179362676681`, 1.}}], 
            ArrowBox[{{5.55878075826214, 5.647917015586335}, {
             5.649095540194834, 5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.648261183292325}, {-5.4990139189136364`, 
             5.632626076589236}, {-5.297376458607603, 
             5.613347869033959}, {-5.117119340695163, 
             5.596790896919815}, {-4.934260585688904, 
             5.580608178175722}, {-4.921856461976379, 
             5.579530790240207}, {-4.909425860627728, 
             5.578453671410176}, {-4.716304236847748, 
             5.5623411819793676`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.5535451550372117`}, {-5.639973971633887, 
             1.5531230922676285`}, {-5.438600233225042, 
             1.5482926914339536`}, {-5.235818184962862, 
             1.5435950906243538`}, {-5.031627826847347, 
             1.5390302898388293`}, {-4.826029158878497, 
             1.53459828907738}, {-4.798512791507864, 
             1.5340160116643597`}, {-4.7709715429039905`, 
             1.5334362554899863`}, {-4.712615018708969, 
             1.5322606642076646`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689007815367527, 
             1.5317850974594558`}, {-4.587576096416484, 
             1.5297417570413174`}, {-4.4034215968458925`, 
             1.5261851164090974`}, {-4.275273119556577, 
             1.5237468788032777`}, {-4.146750430515565, 
             1.5213748919467374`}, {-4.017853529722856, 
             1.519069155839476}, {-3.8885824171784504`, 
             1.5168296704814936`}, {-3.7589370928823467`, 
             1.5146564358727905`}, {-3.744688199665752, 
             1.5144255306647378`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721079306386726, 
             1.5140429454118611`}, {-3.6289175568345464`, 
             1.5125494520133667`}, {-3.498523809035049, 
             1.5105087189032218`}, {-3.367755849483854, 
             1.508534236542356}, {-3.236646456481565, 
             1.506628990395811}, {-3.1052284083287827`, 
             1.5047959659286279`}, {-2.9735017050255075`, 
             1.5030351631408068`}, {-2.84146634657174, 
             1.5013465820323477`}, {-2.7766965816717852`, 
             1.5005555283430627`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7530863495197, 
             1.500267169086585}, {-2.7091223329674787`, 
             1.4997302226032507`}, {-2.5764696642127256`, 
             1.498186084853516}, {-2.4435083403074795`, 
             1.4967141687831431`}, {-2.3102383612517405`, 
             1.4953144743921323`}, {-2.175946454468308, 
             1.4939495535106866`}, {-2.042504121985762, 
             1.49271766356238}, {-1.908779965923026, 
             1.491559404002017}, {-1.8086553067743276`, 
             1.4907494515700814`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7850440863115318`, 
             1.490558450016644}, {-1.7747874020652494`, 
             1.490475479183889}, {-1.6405398461975853`, 
             1.4894665934622862`}, {-1.506050714105184, 
             1.4885334511914998`}, {-1.371333421573196, 
             1.4876767567258207`}, {-1.2364013843867734`, 
             1.4868972144195396`}, {-1.0109835426971179`, 
             1.485769778017057}, {-0.8405809083574739, 
             1.4850832166026569`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8169691070071716, 
             1.4849880833801312`}, {-0.7851946840309086, 
             1.4848600625143455`}, {-0.5591223825839678, 
             1.4841709165156798`}, {-0.332854212552118, 
             1.4837051886253332`}, {-0.10647774813118105`, 
             1.4834657274475804`}, {0.1199194364830215, 
             1.4834553815866953`}, {0.1275086948076048, 1.483462812834218}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15112067648607752`, 1.4834859332068355`}, {
             0.3462497670946658, 1.483676999646952}, {0.5724256695079305, 
             1.4841334302326248`}, {0.7983929449039937, 
             1.4848194303340352`}, {1.0241076638108004`, 
             1.4857272672141346`}, {1.0955960788311225`, 
             1.4860852921679655`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1192077757213663`, 1.486203543169706}, {
             1.2494976560526831`, 1.4868560548861427`}, {1.4744907514539731`, 
             1.4882049073632782`}, {1.6990147798390016`, 
             1.4897729386587606`}, {1.9229975710321006`, 
             1.4915592627858087`}, {2.0636635605134517`, 
             1.4928211044714514`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0872746035456213`, 1.4930329069010888`}, {
             2.146366954857601, 1.4935629937576418`}, {2.369050761139835, 
             1.495783245587479}, {2.591004209386843, 1.4982140938529651`}, {
             2.8121909467016546`, 1.5008480638438755`}, {3.031693733765193, 
             1.5036709138117101`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0553034868780564`, 1.5039961118225942`}, {
             3.2520261734019416`, 1.5067125233276306`}, {3.470555605221043, 
             1.5099365899833066`}, {3.6880802109752002`, 
             1.5133509326900687`}, {3.904540461881226, 1.5169523400293325`}, {
             3.9996692228912063`, 1.5186245477993499`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.023277568695632, 1.519039543841265}, {
             4.119876829155932, 1.5207376005825137`}, {4.333901513378416, 
             1.5246966865235791`}, {4.546387247239247, 1.528817472670358}, {
             4.757215300122445, 1.5330936015700591`}, {4.9662669414120275`, 
             1.5375187157698904`}, {4.967575288182161, 
             1.5375475644450745`}}]}, 
           {Arrowheads[{{0.014099856358366074`, 1.}}], 
            ArrowBox[{{4.991181543314976, 1.538068075675112}, {
             5.173423440492018, 1.5420864578170608`}, {5.378566066746437, 
             1.546790470258779}, {5.581576089559306, 1.5516243956422533`}, {
             5.656854249492381, 1.553483294204972}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.610481433967546, 0.8541634566298831}, {
             0.6218465701350152, 0.8541813175873837}, {0.6264958193463008, 
             0.8541887184625565}, {0.7737826978446863, 0.8544514895839685}, {
             0.9209471503447273, 0.8547689459127279}, {1.0679891768464236`, 
             0.8551410874488347}, {1.2149087773497753`, 0.8555679141922888}, {
             1.3616665221856563`, 0.8560487927014221}, {1.5082229816849402`, 
             0.8565830895345663}, {1.5549573276576727`, 
             0.8567707595889053}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.5785691302784057`, 0.8568655769697553}, {
             1.6545781558476271`, 0.8571708046917214}, {1.8007320446737165`, 
             0.8578119381728875}, {1.9465993439104103`, 0.8585037002874288}, {
             2.0920947493049105`, 0.8592433013447099}, {2.237218260857217, 
             0.8600307413447307}, {2.38196987856733, 0.860866020287491}, {
             2.5230361259293774`, 0.8617288708509105}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.5466476328069603`, 0.8618803573571908}, {
             2.670357432460973, 0.8626800950012307}, {2.813993368644504, 
             0.86365889077221}, {2.957257410985841, 0.864685525485929}, {
             3.1001495594849837`, 0.8657599991423875}, {3.2426698141419332`, 
             0.8668823117415858}, {3.3848181749566884`, 0.8680524632835238}, {
             3.4911005576796144`, 0.8689655268801109}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.5147116793968656`, 0.8691683681710407}, {
             3.52659464192925, 0.8692704537682013}, {3.6679992150596172`, 
             0.8705362831956186}, {3.8090318943477914`, 0.8718499515657754}, {
             3.9496926797937713`, 0.8732114588786719}, {4.089981571397557, 
             0.8746208051343081}, {4.2629427219456275`, 0.8764267307225126}, {
             4.43518190721807, 0.8782979396843382}, {4.459144377608878, 
             0.8785695735331345}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.482754853677362, 0.8788372172435616}, {
             4.6510986375915415`, 0.8807455292497843}, {4.865815026994992, 
             0.8832921505523635}, {5.079331075428419, 0.8859378035920759}, {
             5.291646782891824, 0.8886824883689212}, {5.319931704411096, 
             0.8890557899560061}, {5.348194541240777, 0.8894308018890983}, {
             5.427162009719386, 0.8905238947562366}}]}, 
           {Arrowheads[{{0.0043643709249240005`, 1.}}], 
            ArrowBox[{{5.45077174089791, 0.890850708180087}, {
             5.547819424574829, 0.8921940731485141}, {5.656854249492381, 
             0.8937559231285419}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.2299205742510666`}, {-5.637936106688844, 
             2.229243188776849}, {-5.612708252439426, 
             2.228353632165053}, {-5.587459951611667, 
             2.2274671629734075`}, {-5.377745306218484, 
             2.2203965535479173`}, {-5.166614130289887, 
             2.2135403845966914`}, {-5.006337161676349, 
             2.2084224636699727`}, {-4.845407959057491, 
             2.203457029924725}, {-4.712865403327463, 2.1995090501847088`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.689263878069465, 
             2.1988060431916803`}, {-4.683826522433312, 
             2.1986440833609486`}, {-4.521592851803812, 
             2.193983623978643}, {-4.358706947168992, 
             2.189475651777809}, {-4.195168808528852, 
             2.1851201667584452`}, {-4.030978435883391, 
             2.1809171689205527`}, {-3.8661358292326096`, 
             2.176866658264131}, {-3.745110963242634, 2.1740160692861825`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721505517239152, 
             2.173460072601975}, {-3.7006409885765077`, 
             2.172968634789181}, {-3.534493913915085, 
             2.1692230984957015`}, {-3.367694605248342, 
             2.165630049383693}, {-3.2002430625762783`, 
             2.1621894874531558`}, {-3.0321392858988943`, 
             2.1589014127040893`}, {-2.8633832752161896`, 
             2.155765825136494}, {-2.777222473537866, 2.1542486243578143`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753614140432302, 
             2.1538329065293658`}, {-2.6939750305281644`, 
             2.1527827247503692`}, {-2.523914551834819, 
             2.149952111545716}, {-2.3179401448154433`, 
             2.1467613546971203`}, {-2.111497169781336, 
             2.143840832088113}, {-1.9045856267324974`, 
             2.1411905437186944`}, {-1.8092358437200244`, 
             2.1400962360549878`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785625405610418, 
             2.139825264453894}, {-1.6972055156689272`, 
             2.1388104895888644`}, {-1.4893568365906247`, 
             2.1367006696986235`}, {-1.281039589497592, 
             2.134861084047971}, {-1.0722537743898275`, 
             2.1332917326369074`}, {-0.8629993912673316, 
             2.1319926154654323`}, {-0.8411805467401559, 
             2.1318825989662336`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8175688538978317, 
             2.1317635424422536`}, {-0.7038003605258373, 
             2.1311898910124403`}, {-0.5445628584029307, 
             2.130550646657636}, {-0.3852868848986105, 
             2.1300748824010185`}, {-0.22597244001287853`, 
             2.1297625982425887`}, {-0.06661952374573371, 
             2.129613794182346}, {0.09277186390282438, 2.129628470220291}, {
             0.12690702859573297`, 2.129666614825605}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15051900685142813`, 2.1296930002143775`}, {
             0.25220172293279447`, 2.1298066263564235`}, {
             0.41167005334417717`, 2.130148262590743}, {0.5710730394640868, 
             2.1306521753484766`}, {0.7303068656196382, 2.131317161054851}, {
             0.8893715318108316, 2.1321432197098655`}, {1.048267038037666, 
             2.133130351313521}, {1.0949896786809736`, 
             2.133468336468129}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.118601053909965, 2.133639137908232}, {
             1.2069933843001415`, 2.1342785558658166`}, {1.3655505705982596`, 
             2.135587833366753}, {1.5239385969320174`, 2.13705818381633}, {
             1.6821574633014182`, 2.1386896072145474`}, {1.8413533088798633`, 
             2.1405375351133937`}, {1.9985188656794575`, 2.142456524851382}, {
             2.063029726712987, 2.143310614140239}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.086639650587353, 2.143623196901789}, {
             2.1554721475614613`, 2.1445345023385634`}, {2.3121915970492615`, 
             2.1467704249752133`}, {2.46865565666624, 2.149163250161608}, {
             2.624842768935782, 2.1517119352980236`}, {2.7807313763812704`, 
             2.1544154377847367`}, {2.9362999215260888`, 2.1572727150220223`},
              {3.0309910273561824`, 2.159098180163559}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0545986339329736`, 2.1595532900970977`}, {
             3.0645093758630075`, 2.159744350427014}, {3.1924383270286483`, 
             2.16231230839967}, {3.3200707040265343`, 2.164975194081193}, {
             3.4473904358601937`, 2.1677316126127857`}, {3.574381451533153, 
             2.170580169135652}, {3.701027680048937, 2.173519468790994}, {
             3.8273130504110733`, 2.176548116720015}, {3.9532214916230872`, 
             2.179664718063918}, {3.998837352440542, 
             2.1808288369558535`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.022441660268046, 2.181431219990628}, {
             4.078736932688505, 2.182867877963906}, {4.203843302610854, 
             2.1861562015611824`}, {4.32852453039366, 2.1895282939969496`}, {
             4.452764545040448, 2.192982760412411}, {4.576547275554744, 
             2.1965182059487693`}, {4.699856650940076, 2.2001332357472276`}, {
             4.822676600199968, 2.203826454948989}, {4.944991052337947, 
             2.2075964686952565`}, {4.966538199301528, 2.20828431469309}}]}, 
           {Arrowheads[{{0.014126041703465835`, 1.}}], 
            ArrowBox[{{4.990138170381663, 2.209037692654632}, {
             5.1881498139307505`, 2.2153587855013956`}, {5.429425633083651, 
             2.223403997525817}, {5.656854249492381, 2.2312978789968443`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9182522715369822, 0.28729609675268697`}, {
             0.9227508968674226, 0.2872999679359213}, {0.9283928325346531, 
             0.2873047998554224}, {0.9341015786365265, 
             0.28730966315215994`}, {0.9458663596645205, 
             0.2873196590305137}, {0.9670519027780486, 0.2873376731692203}, {
             0.9987733904445472, 0.28736482045027034`}, {1.0114380904314764`, 
             0.2873757040941901}, {1.0281837786467243`, 0.2873902233668884}, {
             1.0484335106300138`, 0.2874081336353916}, {1.0686872519069555`, 
             0.28742638956360217`}, {1.090963022690584, 0.287446864629667}, {
             1.0961264480599573`, 0.28745166998574906`}, {1.3260304240010412`,
              0.287666129763845}, {1.555934399942125, 0.2878805895419409}, {
             1.7597569366141197`, 0.28816713139646316`}, {1.8627313946567101`,
              0.2883290090869422}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.88634335847928, 0.28836612751654045`}, {
             1.9629790028845766`, 0.2884866001207232}, {2.165600598753496, 
             0.288838995714721}, {2.367621724220879, 0.28922431817845656`}, {
             2.5690423792867243`, 0.2896425675119299}, {2.769862563951032, 
             0.290093743715141}, {2.8308211905461467`, 
             0.29024113308968935`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.854433114526056, 0.2902982233967003}, {
             2.970082278213802, 0.2905778467880899}, {3.1697015220750355`, 
             0.2910948767307765}, {3.3111040963525142`, 
             0.29148154942160887`}, {3.4520989757990743`, 
             0.2918834289563826}, {3.6769286177116363`, 0.2925571567441455}, {
             3.7989091011204503`, 0.2929444485015123}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.8225209751052085`, 0.29301941692199013`}, {
             3.900581909031903, 0.29326726276943477`}, {4.1230588497598735`, 
             0.29401374703225036`}, {4.344359439895549, 0.2947966095325923}, {
             4.373692077656558, 0.2949030691397157}, {4.403002271919937, 
             0.295010133702649}, {4.573084108818675, 0.2956584245412458}, {
             4.742371840364574, 0.2963263960249047}, {4.766994521897121, 
             0.2964257709648547}}]}, 
           {Arrowheads[{{0.01834355988406457, 1.}}], 
            ArrowBox[{{4.790606322594593, 0.29652106608018647`}, {
             4.975645206258068, 0.2972678664612971}, {5.20733752739667, 
             0.29824515038219207`}, {5.437410655425881, 
             0.29925687511363486`}, {5.656854249492381, 
             0.30026062842449147`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.903462672227936}, \
{-5.567143280377249, -0.9021871680984431}, {-5.417916673890868, \
-0.90012214128386}, {-5.268049189556687, -0.8981046688956681}, \
{-5.117540827374705, -0.896134750933867}, {-4.936840680309042, \
-0.893844318094174}, {-4.7552736721469575`, -0.8916253876892553}, \
{-4.712455368178562, -0.8911235484468771}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688844996722685, -0.8908468300852057}, \
{-4.539904076718352, -0.8891012121712116}, {-4.323382520922611, \
-0.8866812872946517}, {-4.105709004759735, -0.8843656130595755}, \
{-3.886883528229723, -0.8821541894659831}, {-3.8578358220496485`, \
-0.8818683086759262}, {-3.828768700381698, -0.8815843169615344}, \
{-3.7444189783717143`, -0.8807980150470207}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.720808011228088, -0.8805779153451349}, \
{-3.675539764808622, -0.8801559280762012}, {-3.52178893236243, \
-0.8787807168393493}, {-3.390077584252112, -0.8776255857465327}, \
{-3.2580935272676275`, -0.8765139151362377}, {-3.1258367614089773`, \
-0.8754457050084643}, {-2.993307286676161, -0.8744209553632126}, \
{-2.860505103069179, -0.8734396662004825}, {-2.7763601455075895`, \
-0.8728466651239845}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752748738838445, -0.8726802666851691}, \
{-2.7274302105880306`, -0.8725018375202741}, {-2.5940826092327165`, \
-0.8716074693225874}, {-2.460462299003236, -0.8707565616074222}, \
{-2.3265692798995907`, -0.8699491143747788}, {-2.1924035519217786`, \
-0.8691851276246569}, {-2.0579651150698, -0.8684646013570568}, \
{-1.9232539693436563`, -0.8677875355719783}, {-1.8082848648834713`, \
-0.8672478781853088}}]}, 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAZMaNaAWO/L8SlKCvmL/rv8G2aFa+
cvq//OXM+eO6678fgWKYnUf4v8Wr4X5ptuu/Mimh5V4b9r/CraEoSrLrv890
QaWJ/vW/bLgYIRay67/t7sDts+H1v2Ut71viseu/PtGnvt3E9b+9VQfZrrHr
vz7gYxcHqPW/LRpKmHux678sz233L4v1v5uOnZlIseu/bhyNxIBR9b87sxUg
47Drv6AxfKnPF/W/YVfSrX6w67+rHNOhHN70v7Q2DUIbsOu/sfJPn7ic8r8j
1tSycazrv3IeM1S/WvC/rEA5iDKp678Av9QjizDsvzIXvTBepuu/5bBEUuUA
7L9MtKagQqbrvzXO58hcweu/FCytHx6m67/HRGRk04Hrv+UMDOj5peu/ZMMu
4uji6r+tWdz/o6Xrv5NGuXU=
             "]]}, 
           {Arrowheads[{{0.0062932985557515, 1.}}], 
            ArrowBox[{{-0.8165869968921856, -0.8639203779160208}, \
{-0.7820210572650002, -0.8638509483014722}, {-0.6850215168361569, \
-0.8636681768123503}, {-0.5894448660042232, -0.8635111114989721}, \
{-0.5853192521821082, -0.8635048470246955}, {-0.5780477341031285, \
-0.863493876975851}, {-0.5710754664568007, -0.8634834447485009}, \
{-0.5643837336245171, -0.8634735113799119}, {-0.5193928000274693, \
-0.8634086083031473}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.0023655801903823413`, 1.}}], 
            ArrowBox[{{-0.5624723704361158, 
             0.8627005419373066}, {-0.524828422380134, 
             0.8626461832826842}, {-0.49548328299277344`, 
             0.8626057193952555}, {-0.4733974738937274, 
             0.8625764801388941}, {-0.46415278723140957`, 
             0.8625645128864771}, {-0.45696541087190373`, 
             0.8625553650705441}, {-0.45076034961298705`, 
             0.8625475730577624}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.30281304779688295`}, \
{-5.537386326406652, -0.3022537423353476}, {-5.378970171134497, \
-0.30153432171032907`}, {-5.219766518012572, -0.30083102664301076`}, \
{-5.059787774668274, -0.3001443145953068}, {-4.8990463487289935`, \
-0.2994746430291314}, {-4.7375820174339855`, -0.2988231115860189}, \
{-4.712383400692092, -0.29872484994359894`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688771587213913, -0.29863277601761146`}, \
{-4.5754345580225015`, -0.29819081990750357`}, {-4.412603970494543, \
-0.2975777679935854}, {-4.249090254850108, -0.29698395584426446`}, \
{-4.084893411089198, -0.29640938345954065`}, {-3.9200134392118127`, \
-0.2958540508394141}, {-3.754450339217952, -0.29531795798388466`}, \
{-3.7442978187787, -0.295286394190652}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7206859398924204`, -0.29521298577276606`}, \
{-3.588204111107615, -0.29480110489295247`}, {-3.421357271910911, \
-0.2943050779727416}, {-3.253992338657948, -0.2938314636293762}, \
{-3.0861093113487263`, -0.2933802618628562}, {-2.917708189983245, \
-0.29295147267318167`}, {-2.776209829374766, -0.29261106365363126`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525979047050098`, -0.2925542593762392}, \
{-2.748788974561504, -0.2925450960603526}, {-2.5793516650835047`, \
-0.29216113202436905`}, {-2.4093962615492455`, -0.2917995805652309}, \
{-2.2389227639587275`, -0.2914604416829383}, {-2.142775090872801, \
-0.29127967121456955`}, {-2.0464992262020747`, -0.29110648409295925`}, \
{-1.813965673829792, -0.29072117044478274`}, {-1.808120003903793, \
-0.29071266292249875`}}]}, 
           {Arrowheads[{{0.01833918921319906, 1.}}], 
            ArrowBox[{{-1.7845080359115555`, -0.29067829913761095`}, \
{-1.5809178767764636`, -0.290382003274594}, {-1.347355835042089, \
-0.290088982582393}, {-1.1132795486266684`, -0.28984210836817975`}, \
{-1.084982332504597, -0.28981508300889475`}, {-1.0566793739790201`, \
-0.28978872922428994`}, {-1.0117042116242134`, -0.28974949926498716`}, \
{-1.0009226254413106`, -0.2897401531337038}, {-0.9907959361342339, \
-0.2897314145322127}, {-0.9722699026155739, -0.2897154702848129}, \
{-0.9574285649844985, -0.28970275297276127`}, {-0.9463524382647927, \
-0.28969327829840313`}, {-0.9345147244084289, -0.28968315149866714`}, \
{-0.9283166020898832, -0.2896778357976881}, {-0.922765707327023, \
-0.2896730480846203}, {-0.9184590276918367, -0.28966931659192824`}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(inc\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(inc\\)]\\)}\"", 
           TraditionalForm]}}], {972., -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.019417813629044198`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAA736MOcAH8L/3oZ9d8BE3P9VfPDn3
/++/MdCxWToMNz+kphEpm4PvvxURBMpv3jY/oPvd8kdK7796IALMO8k2P8I5
MLzqaO6/pZ6/hI51Nj99SqNY4h3rv8zoUNK3NzU/MyRu/Q0l6L8fCQOIphE0
P/r3wxfocuW/Tr2dTPv/Mj+N667ZZ4bZv8ZDo0rWqy4/S4PCZDEL0L/0YTJZ
7UoqPxZbVhXoEcG/wdvel0mJJj9yKEbfz5ikv8JzWdWlTCM/91LW//wIlL9l
+KFYO4wiP2z0ADC1hRq/MH1HLvrSIT9j1IEqYPmUP4XWblKUBSE/5Mrt6UxV
pD9apgHHCUEgPy5RkoUmXLM/Fm8wZreRHT/fdp2E4VS7P6ulLTxR4ho/8zda
3GMewT8TwvKBtW4YPwuhefiWxcg/+F25niFkEj/n1uYFQsPNPyaqobEwmgs/
IiTIKHt+0D/qxADQbqwEP886J/i2hNE/MyaC+3fu/j6CDxJi1UbSPy+ft9mt
sPU+dlDBoCi40j+0JpclqGPuPh6ix5M=
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.011365953428347514`, 1.}}], 
            ArrowBox[{{-0.3192045321194213, 
             0.947809196843688}, {-0.319111299988626, 
             0.9477162013969593}, {-0.30793502192769695`, 
             0.936553575926131}, {-0.3024601437086921, 
             0.9310432223630749}, {-0.2735762321946322, 
             0.9015856188640264}, {-0.17226527656674606`, 
             0.7942716246784165}, {-0.14464510115342522`, 
             0.7639649028538235}, {-0.11877132525280286`, 
             0.7350038181521802}, {-0.09442667940818221, 
             0.7066590113098972}, {-0.07156946693023164, 
             0.6795071415510743}, {-0.028604624176834886`, 
             0.6274581103570598}, {0.009239738868697368, 
             0.5796837908636416}, {0.04263932793742684, 0.5357342541944062}, {
             0.1096891442394811, 0.44077551566221373`}, {0.15946707159995338`,
              0.36276776945770844`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.008532681411602952, 1.}}], 
            ArrowBox[{{0.16047286774934438`, -0.9927487048285157}, {
             0.1617491111822586, -0.9868352084870815}, {
             0.16376523716119387`, -0.9774257371083475}, {
             0.16519942866209794`, -0.9706411514724442}, {
             0.17209863569747572`, -0.9372004416075758}, {
             0.1795467896599861, -0.9000901930234481}, {
             0.18742241556607522`, -0.860368123474845}, {
             0.19472222767638203`, -0.8227530121586808}, {
             0.2024441127716344, -0.7812840544071543}, {
             0.20957173435382373`, -0.7422147748377675}, {
             0.22275404440514293`, -0.6684719361135381}, {
             0.23394050389910745`, -0.6028557186600391}, {
             0.24345520248899966`, -0.5442236393549201}, {
             0.2601414307806889, -0.43286665029153354`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.009725913900272049, 1.}}], 
            ArrowBox[{{-0.6545019978854386, -0.7785836657173775}, \
{-0.6381694278573793, -0.7698825135247951}, {-0.6129165391981036, \
-0.7562952674182433}, {-0.5838955661447747, -0.7404368724127749}, \
{-0.5511747497942147, -0.7223297900616111}, {-0.5099245088053521, \
-0.6993604486806984}, {-0.4709853103728953, -0.6773389861973221}, \
{-0.4273695479892784, -0.6518071363079506}, {-0.3864324381263566, \
-0.6273983220798041}, {-0.2728974793146872, -0.557838394576574}, \
{-0.17889783649919266`, -0.4967016641311969}, {-0.10053748783616831`, \
-0.4425630312242535}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.008236601185456226, 1.}}], 
            ArrowBox[{{-0.8348361296376693, 
             0.5504819183074323}, {-0.8146694361906197, 
             0.5440360509088812}, {-0.8011348275086364, 
             0.5396922341028384}, {-0.7848054442451298, 
             0.5344198372504239}, {-0.7734065125133994, 
             0.5307149361468012}, {-0.7616805508122969, 
             0.5268888710148434}, {-0.7092569003560524, 
             0.5094739429824329}, {-0.6598175977853217, 
             0.4927997554049255}, {-0.5267193981064922, 
             0.4469181622054658}, {-0.4136019596076452, 
             0.40604545612330767`}, {-0.31662328444868093`, 
             0.36930127224806664`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.008306168668184361, 1.}}], 
            ArrowBox[{{0.9830602548382065, -0.23293317473185607`}, {
             0.973026482097445, -0.23068855644026515`}, {
             0.9435402737280351, -0.2240646538624634}, {
             0.9299153554966368, -0.22099247089289387`}, {
             0.9143761109039132, -0.21747381704477278`}, {
             0.8794233473149123, -0.20951425469854207`}, {
             0.8451579876469388, -0.2015583494765628}, {
             0.8115603215073952, -0.19340960410453983`}, {
             0.7804334440458046, -0.18569252210206588`}, {
             0.7226046183605257, -0.17104104679673848`}, {
             0.6728207613121926, -0.15783491391237803`}, {
             0.6296721817649389, -0.1458626645469977}, {
             0.5518601018443244, -0.12262553355402762`}, {
             0.4934338184469624, -0.10346323245203135`}, {
             0.44923632169658717`, -0.0875322517536226}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.004745593449001598, 1.}}], 
            ArrowBox[{{0.7728612114228901, 0.4379762790371465}, {
             0.7453192068956382, 0.4214744265135605}, {0.6521386019253469, 
             0.3628372561044683}, {0.6240572015261231, 
             0.34430207139841407`}, {0.5985407437635454, 
             0.32692918579783276`}, {0.573951085904836, 0.3091473802322322}, {
             0.5515916015354607, 0.2924784434040834}, {0.510846384395275, 
             0.26116779936789536`}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sp\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(sp\\)]\\)}\"", 
           TraditionalForm]}}], {1360.8000000000002`, -576.}, 
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}}, {}},
  ContentSelectable->True,
  ImageSize->1050,
  PlotRangePadding->{6, 5}]], "Output",
 Editable->False,
 CellChangeTimes->{3.532429053284424*^9, 
  3.532521962832561*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "AuNP, R = 30 nm, ",
 StyleBox["\[Lambda]=635",
  FontColor->RGBColor[1, 0, 0]],
 ", nParticle = 0.1748 - 3.4618 I; w0=281nm"
}], "Subsubtitle",
 CellChangeTimes->{{3.532328089689765*^9, 3.532328135651807*^9}, {
  3.5324302957095003`*^9, 3.532430296312084*^9}, {3.5324306500869617`*^9, 
  3.532430655164406*^9}, {3.532521851145369*^9, 3.532521854801162*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"VP1x", ",", "VP1Sx", ",", "VP1Ix", ",", "VP2x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"VP1y", ",", "VP1Sy", ",", "VP1Iy", ",", "VP2y"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1050"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.532327174821657*^9, 3.532327208396069*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.5303852964827294`}, \
{-5.584110798707111, -2.526493741411751}, {-5.446503091155861, \
-2.519203687059504}, {-5.3068777623795285`, -2.511877238750839}, \
{-5.1652348123781096`, -2.5045143964857544`}, {-4.975960960143214, \
-2.4949072692661893`}, {-4.785629266680309, -2.4856178406835827`}, \
{-4.713604149688761, -2.4822415333008645`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.69001805692144, -2.4811358926234726`}, \
{-4.5942397319893935`, -2.4766461107379336`}, {-4.401792356070467, \
-2.467992079429243}, {-4.208207472195527, -2.459973516707757}, \
{-4.01340541363657, -2.4529081925237235`}, {-3.8173861803935973`, \
-2.4467961068771413`}, {-3.7462516722466237`, -2.4449355373424884`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.722647751804039, -2.4443181613822427`}, \
{-3.620149772466608, -2.4416372597680116`}, {-3.483836710811847, \
-2.4387518570280076`}, {-3.3467721150827034`, -2.4365687813729866`}, \
{-3.1392056453859984`, -2.434894940241049}, {-2.9294945160770376`, \
-2.435319657831284}, {-2.7782723771805173`, -2.437391549194699}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7546626000548007`, -2.437715026257488}, \
{-2.717304370856676, -2.4382268705746815`}, {-2.5023008534257682`, \
-2.4440005149022324`}, {-2.474144533249781, -2.444938172451073}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.3360295089700265`, \
-2.4508527349646627`}, {-2.225098760636686, -2.4567078452009232`}, \
{-2.0770474688034506`, -2.4652414458785}, {-1.9264879019500634`, \
-2.4753458497737424`}, {-1.8114800066052597`, -2.4841180450391565`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7879364006720342`, -2.485913827040723}, \
{-1.7734200600765242`, -2.4870210568866504`}, {-1.6178439431828333`, \
-2.5002670672172242`}, {-1.4590988982171154`, -2.5145541862869085`}, \
{-1.2965242721274952`, -2.5293527196171492`}, {-1.1301200649139727`, \
-2.5446626672079455`}, {-0.959886276576548, -2.5604840290592983`}, \
{-0.847241914520494, -2.5703357765563113`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.82371971142738, -2.5723930016248104`}, \
{-0.8223057344117046, -2.572516666442745}, {-0.6823882166527098, \
-2.5831353556797367`}, {-0.5401337232995633, -2.5923400967702745`}, \
{-0.3955422543522657, -2.6001308897143582`}, {-0.18001242316363256`, \
-2.607695327545827}, {0.038063281157457635`, -2.609563209045916}, {
             0.11969425484289774`, -2.60828131427817}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14330333700892264`, -2.607910568254528}, {
             0.2162757222844211, -2.606764643923954}, {
             0.39405230209340825`, -2.599963966797825}, {
             0.5705767892931514, -2.589654551894134}, {
             0.745032952592384, -2.5763297734394817`}, {
             0.917061375790833, -2.560670304397971}, {
             1.0852460858565807`, -2.5434649041534634`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1087207154997127`, -2.540921866150874}, {
             1.2209243013791868`, -2.5287348105848735`}, {
             1.3536666954044732`, -2.514170938066978}, {
             1.484529824764085, -2.499665200180015}, {
             1.6135136894580229`, -2.4852175969239854`}, {
             1.7408694719634905`, -2.4711961625880363`}, {
             1.8668483547576917`, -2.457968931461315}, {
             1.991450337840627, -2.445535903543822}, {
             2.047804249800239, -2.4402131779673693`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.07131161943451, -2.437992865778978}, {
             2.114675421212297, -2.433897078835557}, {
             2.3580016012239295`, -2.4133721350003334`}, {
             2.597833607194682, -2.3967641959092663`}, {
             2.7628006193632406`, -2.387306366752164}, {
             2.926761504246704, -2.3792957264126153`}, {
             3.0136229787603703`, -2.3757971413728054`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0372158421930466`, -2.3748468738403465`}, {
             3.089716261845073, -2.3727322748906197`}, {
             3.251664892158347, -2.367616012186178}, {
             3.412782880370016, -2.3636916401513153`}, {
             3.573245711663569, -2.3607038606380577`}, {
             3.733053386039006, -2.358652673646405}, {
             3.892205903496327, -2.357538079176358}, {
             3.9814792963176866`, -2.357332986763726}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.005091227005902, -2.35727874184619}, {
             4.050694285355782, -2.357173975566285}, {
             4.2085095529376195`, -2.3573742611545545`}, {
             4.365651706241842, -2.3581389359411675`}, {
             4.522120745268447, -2.359467999926123}, {
             4.76737598356396, -2.3623979979423355`}, {
             4.949524559313515, -2.3651727864453798`}}]}, 
           {Arrowheads[{{0.01448151385248792, 1.}}], 
            ArrowBox[{{4.973133813038697, -2.3655324416638326`}, {
             5.010979206412816, -2.366108965317644}, {
             5.252930413815012, -2.3706009020520487`}, {
             5.49322960577055, -2.375873808145549}, {
             5.656854249492381, -2.3799369782299107`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.531052764465196}, {-5.583373715606627, 
             2.527121045925359}, {-5.4454189745542045`, 
             2.5198115750405177`}, {-5.305441408603548, 
             2.512465934193362}, {-5.163441017754659, 
             2.5050841233838916`}, {-4.974208293775205, 
             2.4954791174377675`}, {-4.7839174412168814`, 
             2.486192381668623}, {-4.713604767240245, 2.482896849110754}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690018666613268, 
             2.4817913761123127`}, {-4.59256846007969, 
             2.477223916076457}, {-4.400161350363628, 
             2.46857372066127}, {-4.20661694360326, 
             2.460559962561084}, {-4.011856071333148, 
             2.4535008089139216`}, {-3.8158787335532938`, 
             2.447396259719783}, {-3.7462527908096073`, 2.445577897521294}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7226488460192666`, 
             2.4449614531436574`}, {-3.6186849302636963`, 
             2.442246314978667}, {-3.4824156270459925`, 
             2.439367926896421}, {-3.3453946570409445`, 
             2.4371920406326035`}, {-3.1378292082372217`, 
             2.435529163935255}, {-2.928117337870062, 
             2.4359665893915237`}, {-2.7782735644877365`, 
             2.4380296209366366`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7546638090526487`, 
             2.4383546772878986`}, {-2.715924681393157, 
             2.4388880330663048`}, {-2.5009168742601964`, 
             2.4446772110244925`}, {-2.472760743044137, 
             2.445616945544744}, {-2.444546998600464, 
             2.446612201231679}, {-2.334689583124953, 
             2.4515396440284545`}, {-2.2238025919445747`, 
             2.4574002248761073`}, {-2.075797025720434, 
             2.4659403614118665`}, {-1.9252836700448452`, 
             2.4760485810644974`}, {-1.8114801803335892`, 
             2.484732374412086}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7879366287523037`, 
             2.4865288688528002`}, {-1.7722625249178088`, 
             2.4877248838339994`}, {-1.6167335903393243`, 
             2.5009692697203727`}, {-1.4580378183425788`, 
             2.515251463609159}, {-1.2955161609607595`, 
             2.5300411903858993`}, {-1.129168618193866, 
             2.5453384500505933`}, {-0.9589951900418985, 
             2.5611432426032414`}, {-0.8472383696078497, 
             2.5709082340047535`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8237159997515653, 
             2.572963551420708}, {-0.8214049192718418, 
             2.573165487024504}, {-0.6814817853054533, 
             2.5837709329226892`}, {-0.5392257881427331, 
             2.5929595802977965`}, {-0.39463692778368126`, 
             2.600731429149826}, {-0.17910700015981065`, 2.608267616671043}, {
             0.03896053531983015, 2.610109555586165}, {0.11969881044061731`, 
             2.6088327375876608`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14330785141204802`, 2.608459377512843}, {
             0.2172751251611518, 2.6072896380518267`}, {0.39515313570339133`, 
             2.6004662640098215`}, {0.5717755804220557, 
             2.5901346290153406`}, {0.7463234727926528, 
             2.5767899286235747`}, {0.9184383278451848, 
             2.5611145419277617`}, {1.0852530542444623`, 
             2.544047506853052}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1087286860127414`, 2.5415139573321306`}, {
             1.2225965455669707`, 2.5291486043928306`}, {1.355548004456545, 
             2.5145684896980693`}, {1.486616037278376, 2.500050503936856}, {
             1.6158006440324633`, 2.485594647109191}, {1.7433544876296025`, 
             2.471569165798012}, {1.8695302309805868`, 2.458342306586257}, {
             1.9943278740854185`, 2.445914069473926}, {2.047819560100359, 
             2.440873638272059}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0713274208859738`, 2.4386585322654946`}, {
             2.1177474169440953`, 2.4342844544610194`}, {2.361462204821785, 
             2.4137851086891255`}, {2.6016845975124516`, 
             2.3972082872262237`}, {2.766798251943097, 2.387781385106799}, {
             2.930906732678426, 2.3798010193829606`}, {3.013640474130219, 
             2.376486750922413}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.037233544111655, 2.375541625434857}, {
             3.094010039718438, 2.373267190054709}, {3.2561081730631334`, 
             2.3681798971220447`}, {3.417376306641715, 2.364283484428566}, {
             3.577989614383384, 2.361322295817873}, {3.7379480962881413`, 
             2.359296331289964}, {3.8972517523559866`, 2.3582055908448405`}, {
             3.981496797938855, 2.3580241851420114`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.00510873619563, 2.3579733413182}, {4.055890232766561,
              2.3578639930115735`}, {4.213853187699508, 
             2.3580854563192344`}, {4.371140617154825, 2.3588699807678233`}, {
             4.527752521132514, 2.3602175663573406`}, {4.773254768794739, 
             2.3631753940759617`}, {4.94954190424367, 2.365877486380654}}]}, 
           {Arrowheads[{{0.01448114548035517, 1.}}], 
            ArrowBox[{{4.973151124015707, 2.3662393635584946`}, {
             5.017102019367519, 2.3669130336808895`}, {5.2592942728508545`, 
             2.371430485172124}, {5.499831529244748, 2.376727748549665}, {
             5.656854249492381, 2.3806377490359805`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.0003582012731743271}, {-5.547897565877549, 
             0.00035727337869925844`}, {-5.3645484686823055`, 
             0.00035571691621336945`}, {-5.180025539511674, 
             0.0003542038053664646}, {-4.994152249473771, 
             0.00035278092000787334`}, {-4.806928598568595, 
             0.0003514482601375957}, {-4.712374529602602, 
             0.0003508252833809697}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688762536605145, 
             0.00035066971394883534`}, {-4.618354586796147, 
             0.0003502058257556316}, {-4.428430214156426, 
             0.00034905361686198114`}, {-4.237155480649433, 
             0.00034799163345664426`}, {-4.0445303862751665`, 
             0.000347019875539621}, {-3.8505549310336287`, 
             0.00034613834311091133`}, {-3.7442828166997706`, 
             0.0003456816886127661}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.720670823702019, 
             0.00034558022716278756`}, {-3.7080163939078594`, 
             0.0003455258506941985}, {-3.564582631786184, 
             0.0003450683480175904}, {-3.423736331035134, 
             0.0003448136445981345}, {-3.2828900302840838`, 
             0.00034455894117867863`}, {-3.1403170594564136`, 
             0.0003448440133824978}, {-2.997744088628744, 
             0.00034512908558631707`}, {-2.8017878815888655`, 
             0.000346739557058193}, {-2.776191103792598, 
             0.00034694992487983823`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525791107954256`, 
             0.00034714398069307585`}, {-2.605831674548987, 
             0.000348350028530069}, {-2.574260137809172, 
             0.0003491305829038239}, {-2.5426841506461373`, 
             0.00034997642862381266`}, {-2.430775478491416, 
             0.0003542754576779158}, {-2.31924575647908, 
             0.0003599561106712505}, {-2.1060880531343047`, 
             0.0003767147947133717}, {-1.8986459114752077`, 
             0.00040498578873116573`}, {-1.8080993962450684`, 
             0.00042639064790894233`}}]}, 
           {Arrowheads[{{0.013295420891894264`, 1.}}], 
            ArrowBox[{{-1.7844874039068557`, 
             0.00043197243501164414`}, {-1.7560488649118497`, 
             0.0004386951997791522}, {-1.6222346602343682`, 
             0.0004909282146768054}, {-1.395992557565234, 
             0.0007289147946955404}, {-1.2467449935733512`, 
             0.001513985746217258}, {-1.1878837718794646`, 
             0.003071638135774773}, {-1.156904160745676, 
             0.0070681408506104975`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.218461620798159, 0.007956893075058816}, {
             1.2452887358437144`, 0.003706386804732376}, {1.2961034049936198`,
              0.0018908637548925079`}, {1.3430506888988363`, 
             0.001359516806532905}, {1.405205285088644, 
             0.0010293619822025586`}, {1.483250311797903, 
             0.0008215533695215008}, {1.5281029949437743`, 
             0.0007487045616292568}, {1.5766037785107117`, 
             0.0006900598274671535}, {1.821688797777138, 
             0.0005298790429421617}, {1.9607677622139434`, 
             0.0004891070868088509}, {2.107207372047629, 
             0.0004610205525580741}, {2.162569962499665, 
             0.000454225779400924}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1861819553197983`, 0.00045132782730563574`}, {
             2.292134436115254, 0.00043832404503019943`}, {2.482060542217597, 
             0.00042308123235332463`}, {2.5148235844419293`, 
             0.0004211204849132239}, {2.5476696666738947`, 
             0.0004192869966235791}, {2.6605590395575236`, 
             0.00041460067571536874`}, {2.7739238842469573`, 
             0.0004108290492949323}, {3.008440974818676, 
             0.0004041877270919349}, {3.1306616734442265`, 
             0.00040193290670499535`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.154273666438178, 0.00040149729470328235`}, {
             3.24344786540247, 0.00039985214127121344`}, {3.4782909381231706`,
              0.00039717991776156884`}, {3.712316575105609, 
             0.0003955286824918018}, {3.9452581756553866`, 
             0.0003946404839162836}, {4.098753386318851, 
             0.0003943865617627563}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.122365379316788, 0.00039434750120780353`}, {
             4.176849139078105, 0.0003942573704893853}, {4.3199868932598005`, 
             0.00039421407699986063`}, {4.46250119942688, 
             0.0003942464230506889}, {4.604392057579345, 
             0.00039435440864186993`}, {4.745659467717193, 
             0.0003945380337734038}, {4.886303429840426, 
             0.00039479729844529046`}, {5.026323943949043, 
             0.00039513220265752994`}, {5.066845099234508, 
             0.0003952515430971562}}]}, 
           {Arrowheads[{{0.01199384476593946, 1.}}], 
            ArrowBox[{{5.090457092232375, 0.00039532108370143973`}, {
             5.165721010043044, 0.0003955427464101222}, {5.3044946281224306`, 
             0.00039602892970306734`}, {5.4426349140778, 
             0.0003965698073392959}, {5.58013198379975, 
             0.0003971444341217384}, {5.656854249492381, 
             0.00039748341974932933`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.340168777909787}, \
{-5.562655007416532, -4.332358470437481}, {-5.405332661839688, \
-4.31947945357214}, {-5.240942647666926, -4.306170362347856}, \
{-5.072764511387339, -4.292778950671749}, {-4.904077799490019, \
-4.279652972450936}, {-4.734889282376463, -4.2668901745239385`}, \
{-4.715336164783077, -4.265472595014709}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.691785981618364, -4.263765232649939}, \
{-4.565205730448162, -4.254588303729272}, {-4.334548968350292, \
-4.238868964789406}, {-4.10267634449658, -4.224394943132703}, \
{-3.869587858887025, -4.211166238759163}, {-3.7491573099032456`, \
-4.205006874230905}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.725576138147892, -4.203800826147006}, \
{-3.6352835115216258`, -4.199182851668787}, {-3.3994576134457013`, \
-4.188794704505226}, {-3.1618044757045705`, -4.180351719912136}, \
{-2.9223240982982324`, -4.173853897889516}, {-2.7817062098609915`, \
-4.171200913426346}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            
            ArrowBox[{{-2.7580984180788963`, -4.17075551415671}, \
{-2.6810164812266866`, -4.169301238437364}, {-2.559564530254991, \
-4.167737859602245}, {-2.4374299142440505`, -4.166627801263805}, \
{-2.3146126331938675`, -4.165971063422043}, {-2.1911126871044413`, \
-4.16576764607696}, {-2.0669300759757716`, -4.166017549228555}, \
{-1.9420647998078584`, -4.166720772876829}, {-1.816516858600702, \
-4.167877317021782}, {-1.8136572363459207`, -4.16791378682014}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.79004716333838, -4.16821489463267}, \
{-1.6902862523543014`, -4.169487181663413}, {-1.5238701084520436`, \
-4.1719985618536795`}, {-1.3561035537036743`, -4.174722989279974}, \
{-1.186986588109193, -4.177660463942298}, {-1.0165192116685997`, \
-4.180810985840651}, {-0.8456981541679891, -4.183843158371532}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8220889309541091, -4.184204630655409}, \
{-0.6719494911137736, -4.186488966109282}, {-0.4979512132157149, \
-4.1887008731705215`}, {-0.3228106569038918, -4.190494724849709}, \
{-0.1468180634411051, -4.191662925250981}, {
             0.02973632590984454, -4.191997878478472}, {
             0.12234560587643152`, -4.191737334003018}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14595750542967512`, -4.191670904915287}, {
             0.2068525111489577, -4.191499584532182}, {
             0.3845304922762346, -4.19016804341211}, {
             0.5309027107716917, -4.188537013760382}, {
             0.6771032229169128, -4.186521362933382}, {
             0.8231320287118988, -4.184121090931106}, {
             0.9689891281566497, -4.1813361977535575`}, {
             1.0903339906795773`, -4.178696233133644}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1139403976645847`, -4.178182654907521}, {
             1.1146745212511655`, -4.178166683400735}, {
             1.2601882079954456`, -4.1746125478726395`}, {
             1.4055301883894908`, -4.1706737911692695`}, {
             1.550700462433301, -4.166350413290625}, {
             1.7289310546981342`, -4.1609902587073275`}, {
             1.9064792654343257`, -4.156025730578911}, {
             2.0580582765691573`, -4.152110052797909}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.081662395101163, -4.151500297385309}, {
             2.083345094641876, -4.151456828905377}, {
             2.259528542320785, -4.147283553686725}, {
             2.435029608471053, -4.143505904922955}, {
             2.60984829309268, -4.140123882614066}, {
             2.783984596185665, -4.13713748676006}, {
             2.957438517750009, -4.134546717360936}, {
             3.025968559128643, -4.133697738003181}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0495787404322297`, -4.133405245015341}, {
             3.0915599424858202`, -4.13288516399335}, {
             3.2253424041564993`, -4.131611163448211}, {
             3.402143410386673, -4.130535256170751}, {
             3.5783394305338536`, -4.130173953523184}, {
             3.753930464598041, -4.13052725550551}, {
             3.9289165125792356`, -4.13159516211773}, {
             3.952227078467962, -4.131785348461335}, {
             3.9755270486157683`, -4.131987902935196}, {
             3.9940387557279986`, -4.132223796888236}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.017648831865777, -4.132524659156528}, {
             4.132386660137862, -4.133986758773291}, {
             4.288778948146568, -4.136511169421328}, {
             4.485800156592038, -4.140088291313046}, {
             4.6821110478002606`, -4.144447744293121}, {
             4.877671957955798, -4.1495422852341335`}, {
             4.961914530124139, -4.152043285831924}}]}, 
           {Arrowheads[{{0.014224813360355608`, 1.}}], 
            ArrowBox[{{4.985516124398498, -4.152743971956168}, {
             5.072443223243212, -4.155324671008667}, {
             5.264785273958503, -4.161659273364227}, {
             5.453058540397669, -4.168410464048321}, {
             5.637605249763412, -4.175470903275821}, {
             5.656854249492381, -4.176247587180157}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.340249105543188}, {-5.562195722176659, 
             4.33240085841689}, {-5.4048423249676985`, 
             4.3195195415205125`}, {-5.240439701626964, 
             4.306209606559545}, {-5.072258301785201, 
             4.29281835349187}, {-4.903568575073152, 
             4.279693082275372}, {-4.7343771094104765`, 
             4.266931346735903}, {-4.715336308765625, 4.2655510720062315`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.691786111118869, 
             4.263843909408562}, {-4.564690492716835, 
             4.254630700699314}, {-4.334029339278559, 
             4.238913306675362}, {-4.10215200165943, 
             4.224441584201768}, {-3.8690584798594485`, 
             4.211215533278534}, {-3.7491574825704004`, 4.205084931779567}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7255762939692927`, 
             4.203879213116219}, {-3.634748773878616, 
             4.19923515390566}, {-3.3989171522035657`, 
             4.1888503722581065`}, {-3.1612578833209315`, 
             4.1804111145108385`}, {-2.921770967230714, 
             4.1739173806638545`}, {-2.781706448203284, 4.171277495072557}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.758098647974015, 
             4.170832543759404}, {-2.680456403932915, 
             4.169369170717156}, {-2.5590008145429826`, 
             4.167808061951738}, {-2.4368624332747784`, 
             4.166700183652041}, {-2.3140412601283, 
             4.166045535818065}, {-2.190537295103548, 
             4.165844118449811}, {-2.066350538200523, 
             4.166095931547277}, {-1.9414809894192255`, 
             4.166800975110465}, {-1.8159286487596544`, 
             4.167959249139373}, {-1.8136574565385366`, 4.167988242941644}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7900473873060738`, 
             4.168289646615262}, {-1.6896935162218114`, 
             4.1695707536340025`}, {-1.5231912787768178`, 
             4.172085117183}, {-1.3553373564301583`, 
             4.174812010520037}, {-1.1861317491818344`, 
             4.177751433645111}, {-1.0155744570318452`, 
             4.1809033865582235`}, {-0.8456983685569948, 
             4.183917641569997}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8220891838759687, 
             4.184281429670396}, {-0.6708228757826058, 
             4.186580838079574}, {-0.4967331011222893, 
             4.188790325770565}, {-0.3215006704381745, 
             4.1905803214151}, {-0.1454165085444745, 4.191743381098077}, {
             0.031228459744596315`, 4.192072060904395}, {0.12234537987131235`,
              4.191812036461064}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14595727672348907`, 4.191744654131565}, {
             0.2084342344290388, 4.191566360834054}, {0.3862008155088533, 
             4.190226280887053}, {0.53265446082169, 4.188588064422214}, {
             0.6789350611382452, 4.186566029299493}, {0.825042616458519, 
             4.184160175518888}, {0.9709771267825111, 4.181370503080399}, {
             1.0903338020086577`, 4.17877189208763}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1139402008141444`, 4.178257938030855}, {
             1.116738592110222, 4.178197011984027}, {1.2623270124416512`, 
             4.174639702229771}, {1.407742387776799, 4.170698573817632}, {
             1.552984718115666, 4.1663736267476095`}, {1.7315158939518074`, 
             4.161006736383543}, {1.9093627388339927`, 4.156038175102629}, {
             2.0580585192364125`, 4.152202294541903}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0816626595377627`, 4.1515933824215345`}, {
             2.086525252762222, 4.1514679429048655`}, {2.263003435736495, 
             4.147296039790253}, {2.4387972877568127`, 4.143522465758792}, {
             2.613906808823174, 4.140147220810483}, {2.788331998935579, 
             4.137170304945325}, {2.962072858094028, 4.134591718163318}, {
             3.0259690763048357`, 4.133806688405585}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0495792874352614`, 4.133516613048346}, {
             3.096351139873324, 4.132941973468472}, {3.230290196600115, 
             4.13168059766406}, {3.407071546167742, 4.130623814670757}, {
             3.583247769022373, 4.130281745362459}, {3.758818865164009, 
             4.130654389739168}, {3.9337848345926494`, 4.131741747800884}, {
             3.957093304894692, 4.131934542016897}, {3.9803911904551894`, 
             4.132139688799534}, {3.9940394450827323`, 
             4.132315127999072}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.017649487572074, 4.132618619329532}, {
             4.137404036366859, 4.134157984087506}, {4.293948916683325, 
             4.136702269262291}, {4.49107382757175, 4.140303010017132}, {
             4.687487862999917, 4.144686033873048}, {4.883149155192884, 
             4.149803537044235}, {4.961915014307105, 4.152149608312217}}]}, 
           {Arrowheads[{{0.014224800833119522`, 1.}}], 
            ArrowBox[{{4.985516540354557, 4.152852588801012}, {
             5.078015836375705, 4.155607715744895}, {5.270360893852237, 
             4.1619590259337595`}, {5.458457314926332, 4.168717923569562}, {
             5.642152871277951, 4.1757576807715315`}, {5.656854249492381, 
             4.176351637660667}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.5315534202872606}, \
{-5.507069277959012, -0.5297227735574866}, {-5.321108436483125, \
-0.52747979288051}, {-5.134021861545786, -0.5252528551293262}, \
{-4.945809553146998, -0.5230419603039353}, {-4.756319923366937, \
-0.5209012728099276}, {-4.7124400194716785`, -0.5204378513838736}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688829343174829, -0.5201884959316441}, \
{-4.565401384285784, -0.5188849570528935}, {-4.373053935903539, \
-0.5169930130328327}, {-4.179277578220204, -0.5152254407497456}, \
{-3.999037976488288, -0.5137281513004295}, {-3.817340224545189, \
-0.5125204411037197}, {-3.7443849871751036`, -0.5121616868700096}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7207732796572692`, -0.5120455773165011}, \
{-3.6341403637241063`, -0.5116195636882812}, {-3.4493853774014753`, \
-0.511177532233375}, {-3.263011646861367, -0.511315053153685}, \
{-3.075055616949407, -0.5123156989863156}, {-2.885593079814969, \
-0.5144233727962549}, {-2.7763319793385772`, -0.5166362231891468}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7527248274181235`, -0.5171143356662724}, \
{-2.6948212601230375`, -0.5182870488375666}, {-2.490728696126852, \
-0.5252996430064172}, {-2.2858932591428913`, -0.5366864317409049}, \
{-2.080908951615845, -0.5550075320037419}, {-1.8765296523855954`, \
-0.5845146643763308}, {-1.813036651862206, -0.597954286756887}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7899364852928548`, -0.6028439204654982}, \
{-1.7828762011701815`, -0.6043383773619432}, {-1.689198892877887, \
-0.6294809288983654}, {-1.5948404605376, -0.6612122579739881}, \
{-1.547065495203425, -0.6801389649679667}, {-1.4986747009226806`, \
-0.7013964931757681}, {-1.4013430312033526`, -0.750679333762589}, \
{-1.2982306400938244`, -0.8120551724143468}, {-1.1383988135885486`, \
-0.9198434661929151}, {-0.9933252670105013, -1.0178315714245645`}, \
{-0.9595335116556957, -1.038357294060808}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.9393527390379404, -1.050615459905934}, \
{-0.8184474301954247, -1.1240555286000244`}, {-0.6061876463465382, \
-1.226757487253102}, {-0.4849203861842604, -1.2711752628927855`}, \
{-0.3547467063246664, -1.3075681080114683`}, {-0.1462680025094812, \
-1.341677516367757}, {-0.05463601111311148, -1.3437410717512872`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.031030003271592776`, -1.344272679804574}, {
             0.07047414516397416, -1.3465585564810814`}, {
             0.2853551309274001, -1.320315435127823}, {
             0.40920896035958904`, -1.2908608998094635`}, {
             0.5266909641412818, -1.2526209342075398`}, {
             0.5725742353573517, -1.2355063781727493`}, {
             0.6170722956933158, -1.2173797667759438`}, {
             0.6665483667252655, -1.1933478125002166`}, {
             0.7140974315128827, -1.168419298724737}, {
             0.8336178467156296, -1.100250847678674}, {
             0.8605462870546331, -1.0823949381990865`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8802251010610329, -1.0693461645924336`}, {
             0.9394617014047784, -1.030067121309544}, {
             1.0328981740897445`, -0.9608622855143567}, {
             1.1533525941799567`, -0.8616551890851792}, {
             1.2558369184789189`, -0.7735952004499386}, {
             1.3933432617299548`, -0.6652043850984206}, {
             1.5185926442221096`, -0.5853438093177307}, {
             1.6402533128896883`, -0.527190332124324}, {
             1.6473398464496762`, -0.5247923353607725}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.6697060038230769`, -0.5172238997440523}, {
             1.76327759432644, -0.48556041162422653`}, {
             1.966303630978687, -0.44169438340756406`}, {
             2.1761861626213013`, -0.41470642233928323`}, {
             2.39120443261813, -0.3976281153870497}, {
             2.601617268371017, -0.387038074033606}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6252105559527203`, -0.38611804079813344`}, {
             2.792005106005322, -0.3805813077005311}, {
             2.974984913144084, -0.37635195261148374`}, {
             3.1580179057764832`, -0.3732941517049083}, {
             3.34082054707587, -0.3711645217271539}, {
             3.523121440921697, -0.3696737745532781}, {
             3.5695048162224277`, -0.3694230892742181}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.5931164643736757`, -0.3692954769008734}, {
             3.704782435740386, -0.3686919629260477}, {
             3.8856662729490488`, -0.36807861997328845`}, {
             4.0657032092289755`, -0.36776242964173966`}, {
             4.252909249972535, -0.367691482661749}, {
             4.4391147556881805`, -0.36785465396301875`}, {
             4.537592999137151, -0.368027579527366}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.561204955731928, -0.36806904158818765`}, {
             4.6242534864554505`, -0.36817975337969394`}, {
             4.8082592023538835`, -0.3685945907459193}, {
             4.99112835057858, -0.36908458085719187`}, {
             5.172893199533537, -0.36966805562978095`}, {
             5.353541241111632, -0.3703222005789903}, {
             5.505680170298432, -0.3709171336433798}}]}, 
           {Arrowheads[{{0.002701240866238561, 1.}}], 
            ArrowBox[{{5.529291982764827, -0.37100946667097184`}, {
             5.533059967205742, -0.37102420122012364`}, {
             5.656854249492381, -0.371537774717606}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.5279215370129465}, {-5.480888700078141, 
             0.5257867064092783}, {-5.296261385822538, 
             0.5235782506384673}, {-5.110518835457522, 
             0.52138772489721}, {-4.923661048983094, 
             0.5192151291855064}, {-4.735538351758682, 
             0.5171143662549199}, {-4.712439216632379, 
             0.516873667305811}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688828505446118, 
             0.516627637602137}, {-4.5460010691437125`, 
             0.5151393388570137}, {-4.355049201138186, 
             0.5132900469917877}, {-4.162682747742102, 
             0.5115664906592421}, {-3.982812763976052, 
             0.5101034914327431}, {-3.8014874088145936`, 
             0.5089340994793997}, {-3.7443835652239246`, 
             0.508665970430073}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720771832512982, 
             0.5085551023860562}, {-3.618663008241829, 
             0.5080756540642242}, {-3.434289073952673, 
             0.5076823637590956}, {-3.2483046721529476`, 
             0.5078765854910249}, {-3.0607502937692606`, 
             0.5089465702535998}, {-2.871705517063396, 
             0.5111407366626726}, {-2.776330375433986, 0.5131342291020264}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7527235385103848`, 
             0.5136276496109795}, {-2.681374595068358, 
             0.5151189562227194}, {-2.482977979201503, 
             0.5220750271087577}, {-2.283911452644699, 
             0.5332118817348862}, {-2.0847325545548525`, 
             0.5508988158124465}, {-1.8861157843312983`, 
             0.5789773721279224}, {-1.8129894104721584`, 
             0.5940546279746901}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7898877376354785`, 
             0.5989247417335787}, {-1.6975154371475503`, 
             0.6231647720292786}, {-1.6026650815625554`, 
             0.6544771119647038}, {-1.5546821118931715`, 
             0.6731797081891111}, {-1.5061114986716593`, 
             0.6942039496407163}, {-1.4072733580070313`, 
             0.7436679373577265}, {-1.3026923505908081`, 
             0.8057417939126904}, {-1.1450232198062689`, 
             0.9121320973460477}, {-1.0011696176048854`, 
             1.0098789572020983`}, {-0.9599394569452743, 
             1.0352352077411677`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.9398265897500486, 
             1.0476044755660383`}, {-0.8277287586912482, 
             1.1165438307308027`}, {-0.6167950558752662, 
             1.2204929373213833`}, {-0.496051781437641, 
             1.2658204819512968`}, {-0.3662404780580009, 
             1.3032587909952276`}, {-0.16114553814126653`, 
             1.3387454206662348`}, {-0.055696824424781535`, 
             1.3422807100703427`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.032098090223086836`, 1.3430718847754028`}, {
             0.05278151375482486, 1.3459175711189535`}, {0.2658402651146073, 
             1.3224998869110691`}, {0.3917382032816843, 
             1.2941003801526725`}, {0.5113135627769333, 1.256484529591395}, {
             0.5570054290823707, 1.2399118387937647`}, {0.6013341361558374, 
             1.2223368573670188`}, {0.6503528340842989, 
             1.1991541728315762`}, {0.6976565361069136, 
             1.1748453623167319`}, {0.8493450675085171, 
             1.0880850055458287`}, {0.8595307667359643, 
             1.0811000772266697`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8790038583720727, 1.0677462419922554`}, {
             0.9791112505459494, 0.9990967616828207}, {1.0898594524275302`, 
             0.9127970961501575}, {1.235733820018669, 0.791645537539411}, {
             1.358307890573496, 0.6937665445913191}, {1.4688614774922173`, 
             0.6176150312221335}, {1.6071952096962328`, 0.5442538060483858}, {
             1.6498146266664542`, 0.5286527164965312}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.6719877415003626`, 0.520536116722089}, {
             1.746356612210565, 0.49331295192302993`}, {1.8889661505595432`, 
             0.45831405441488066`}, {2.035073789296927, 
             0.43372089478630305`}, {2.156977252613985, 
             0.41903868103399605`}, {2.280616689521725, 
             0.40784034798772467`}, {2.4056886569005522`, 
             0.39911193629627373`}, {2.5318517802806313`, 
             0.3923785334088917}, {2.6034218426825055`, 
             0.38940953077809787`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.627013544798335, 0.38843085585039555`}, {
             2.6587999268317075`, 0.38711223394741917`}, {2.786243239687986, 
             0.3830016631065205}, {2.9139549810385432`, 
             0.37975490326708866`}, {3.041779670109555, 
             0.37720775928265743`}, {3.2714977199449216`, 
             0.37400388652706795`}, {3.5006135947657913`, 
             0.3720243221930871}, {3.5713010819189814`, 
             0.37164135901997564`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.594912728401959, 0.37151343834513384`}, {
             3.728679363005324, 0.370788731655064}, {3.9555290819357456`, 
             0.3701487085307092}, {4.180974268515702, 0.3699066999811948}, {
             4.404944893809792, 0.36998197083283507`}, {4.539389325539801, 
             0.3701572585128928}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.563001298469071, 0.37018804363283486`}, {
             4.627354923583373, 0.3702719474249402}, {4.848204494260723, 
             0.3707668187676583}, {4.979709689146985, 0.37111357116495325`}, {
             5.109883186721295, 0.37149023714959206`}, {5.2387249869836525`, 
             0.37189681672157476`}, {5.366235089934057, 
             0.37233330988090135`}, {5.492413495572509, 0.3727997166275719}, {
             5.507477037482966, 0.3728596008027548}}]}, 
           {Arrowheads[{{0.002663189970452271, 1.}}], 
            ArrowBox[{{5.531088843899922, 0.3729534680725021}, {
             5.61726020389901, 0.3732960369615863}, {5.656854249492381, 
             0.37346472682125514`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.4914062887125388`}, \
{-5.634194826181425, -1.4906446924383596`}, {-5.49846521762977, \
-1.486114449292371}, {-5.360948908441277, -1.4815603125148087`}, \
{-5.2228836538124535`, -1.4770283349705349`}, {-5.083405711829755, \
-1.4725230336323476`}, {-4.943286316649422, -1.4681023559667097`}, \
{-4.802525468271454, -1.4637663019736211`}, {-4.712862404811044, \
-1.4610704740954292`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689261076927078, -1.460360871777413}, \
{-4.66112316669585, -1.459514871653082}, {-4.519005186868331, \
-1.4554159729096772`}, {-4.376097303734622, -1.4515375136479924`}, \
{-4.232399517294719, -1.4478794938680273`}, {-4.0879118275486235`, \
-1.444441913569782}, {-3.9426015868890545`, -1.4413867035965888`}, \
{-3.796436147708732, -1.4388757947917807`}, {-3.7450515056161064`, \
-1.4381884529932798`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721441624760622, -1.4378726376580215`}, \
{-3.6494155100076546`, -1.4369091871553576`}, {-3.501539673785822, \
-1.4354868806873193`}, {-3.3098420163350024`, -1.434838081508888}, \
{-3.116422866574862, -1.43585172593983}, {-2.9210407024673763`, \
-1.439090983905144}, {-2.777072776418499, -1.4434832057494469`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753471764288003, -1.444203233354707}, \
{-2.723454001974522, -1.4451190253298278`}, {-2.523199879293511, \
-1.4549558020627964`}, {-2.319815448621555, -1.469621265952965}, \
{-2.1885216527331517`, -1.4819680257538488`}, {-2.0552459553141147`, \
-1.49729030547432}, {-1.9194070731508006`, -1.5161452070416452`}, \
{-1.8139622445542265`, -1.5335529906663095`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.79066558550087, -1.537399013324566}, \
{-1.7804237230295668`, -1.5390898323830913`}, {-1.6372007758754563`, \
-1.566380196130202}, {-1.4886431026135127`, -1.5982723129145215`}, \
{-1.3675762055952643`, -1.6263855133377492`}, {-1.24149589799858, \
-1.6571106081666231`}, {-1.1094645550758442`, -1.6898339181612172`}, \
{-0.9705445520794416, -1.7239417640816048`}, {-0.8699679944520672, \
-1.747182908616591}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8469622394869571, -1.7524990587105478`}, \
{-0.8242155552387054, -1.7577553429658108`}, {-0.6699572307829691, \
-1.7895958518518593`}, {-0.4406242775476083, -1.827201349813674}, \
{-0.19932247005768416`, -1.850868996425248}, {-0.0755457171310281, \
-1.856152507736184}, {0.04936746064563355, -1.8564945760847458`}, {
             0.08929369701865547, -1.8547371566302326`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.11288284948285282`, -1.8536988409956523`}, {
             0.22320907655266456`, -1.8488426492929317`}, {
             0.3945757686332772, -1.8318269151165363`}, {
             0.561631826785946, -1.806956051902948}, {
             0.7225415409091449, -1.7757387379995553`}, {
             0.8767215352394291, -1.7401651035235959`}, {
             1.023588434013355, -1.7022252785923073`}, {
             1.0420129726443828`, -1.697148527957924}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0647766211726086`, -1.6908761664393601`}, {
             1.0946752689000014`, -1.6826378066162477`}, {
             1.1639670388000953`, -1.6632569041145144`}, {
             1.3655281046625904`, -1.6075273687797578`}, {
             1.5550013260343187`, -1.5572800144552004`}, {
             1.7352030916219383`, -1.513263054103356}, {
             1.908949790132107, -1.4762247006867384`}, {
             1.9810174701206498`, -1.4632912416385844`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0042581739663716`, -1.4591204026232767`}, {
             2.104896154028001, -1.441059640933391}, {
             2.2969082861421217`, -1.4134420330309128`}, {
             2.330017756897114, -1.4092879734891615`}, {
             2.3630544355259513`, -1.4053098998490186`}, {
             2.4687873783454948`, -1.3946960662178527`}, {
             2.573999455175647, -1.3856043145859804`}, {
             2.789329957108393, -1.3691765352998189`}, {
             2.9428676200402695`, -1.360605139889159}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9664429049148455`, -1.3592890257532508`}, {
             3.003112837628592, -1.3572418896501615`}, {
             3.2155804983829466`, -1.348835313177887}, {
             3.42696534101816, -1.3429917414238737`}, {
             3.637260599449783, -1.339191660423916}, {
             3.8464595075933676`, -1.3369155562138082`}, {
             3.910570754918256, -1.3365467856033972`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.93418235731282, -1.3364109706662193`}, {
             4.010476397887598, -1.3359721241129632`}, {
             4.173680906605185, -1.335528165820069}, {
             4.336073033746127, -1.3355836813351258`}, {
             4.497652779310425, -1.3361386706581337`}, {
             4.658426754844786, -1.337070879046706}, {
             4.818401571895916, -1.3382580517584555`}, {
             4.878649668485013, -1.3388039016211586`}}]}, 
           {Arrowheads[{{0.01598026024024664, 1.}}], 
            ArrowBox[{{4.902260692456461, -1.3390178183243036`}, {
             4.977577230463817, -1.3397001887933822`}, {
             5.135953730548487, -1.3413972901514863`}, {
             5.2932852337641, -1.3432911982792493`}, {
             5.449325901724826, -1.345323755623152}, {
             5.604075734430666, -1.347494962183195}, {
             5.656854249492381, -1.348289381278189}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.497491350409132}, {-5.594548975874543, 
             1.4953959742666465`}, {-5.458301584077136, 
             1.4908408146919243`}, {-5.315606549140486, 
             1.486089415779063}, {-5.172354324501146, 
             1.4813304900781488`}, {-5.02854491015912, 
             1.4765640375891818`}, {-4.883791648390681, 
             1.472104290802768}, {-4.738493035439935, 
             1.4675926782341404`}, {-4.712873331815436, 
             1.4668195197305531`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.6892720835349655`, 
             1.4661072747307369`}, {-4.592448443706, 
             1.4631853041420348`}, {-4.445629167299783, 
             1.4589471590378427`}, {-4.29800650033219, 
             1.4549432334329544`}, {-4.149563982365755, 
             1.4511788475054792`}, {-4.000275356601709, 
             1.4477070577001516`}, {-3.8500972226090036`, 
             1.444664458928301}, {-3.7450848998674795`, 
             1.4429432354928826`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721476077963587, 
             1.4425562708349955`}, {-3.6989861799565853`, 
             1.4421876461012573`}, {-3.5469782102057845`, 
             1.440260305286353}, {-3.3940457893240272`, 
             1.4389884496261187`}, {-3.2400502584894046`, 
             1.43869216464468}, {-3.0848529588800075`, 
             1.4396915358661628`}, {-2.9247285018888363`, 
             1.442235048796421}, {-2.7770952176600834`, 
             1.4462516681393167`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.753496509295477, 
             1.447027157419221}, {-2.599913752315826, 
             1.4533335136291743`}, {-2.4347670293279964`, 
             1.4629543849301232`}, {-2.2674075784142316`, 
             1.4761671370419225`}, {-2.097119351209652, 
             1.4938498315417543`}, {-1.9231918724273427`, 
             1.5173036653959986`}, {-1.8139666193725374`, 
             1.5356483224739328`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7906807666807616`, 
             1.5395592402374612`}, {-1.74403226758671, 
             1.547393973462124}, {-1.5036319990244555`, 
             1.5966788547196684`}, {-1.3770988200884582`, 
             1.6261142152103547`}, {-1.2451285604289335`, 
             1.6584431298497895`}, {-1.10651597052246, 
             1.6932980749490962`}, {-0.9603630709128472, 
             1.7295449828811411`}, {-0.8702979813589936, 
             1.7505635276763276`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8473038392163186, 
             1.755929684630668}, {-0.8053714626930152, 
             1.7657154688750358`}, {-0.6416581259921232, 
             1.7994766945708869`}, {-0.4045528405654204, 
             1.836258077090813}, {-0.28132047688187894`, 
             1.8491708398815607`}, {-0.15573294828424028`, 
             1.85759012330051}, {-0.028607511961165843`, 
             1.8611567387946792`}, {0.08875201698421364, 
             1.8596464484793584`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.11233966939347957`, 1.8587269110871054`}, {
             0.27639592350292214`, 1.8489020556896092`}, {
             0.45028966361523004`, 1.8289305925084143`}, {0.6191596571948228, 
             1.8013680971810797`}, {0.7812457662009162, 
             1.7679855586211843`}, {0.9361632555560205, 
             1.7308869002317284`}, {1.041782357156593, 
             1.7031419830697807`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0646195507459302`, 1.6971429162840803`}, {
             1.0835273901826454`, 1.6921760454157124`}, {1.1566912185240754`, 
             1.6719040706814516`}, {1.2280229828343137`, 1.651916554959469}, {
             1.4226797400723723`, 1.598517560496707}, {1.6065629658892309`, 
             1.5509691503881307`}, {1.7822206963892422`, 
             1.5096842745282295`}, {1.9522009676767587`, 
             1.4750758828114927`}, {1.9810260138615394`, 
             1.4701696969722757`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0043032438036965`, 1.4662077808252443`}, {
             2.151540584442564, 1.4411471529596147`}, {2.3471551324263578`, 
             1.4146459142583685`}, {2.3802046137307915`, 
             1.4107589103812208`}, {2.41318830444692, 1.4070372131506832`}, {
             2.5205322852215613`, 1.3970266609142772`}, {2.6273747407025403`, 
             1.3884766729258715`}, {2.8235207054916716`, 
             1.3745085066286988`}, {2.9429669989942346`, 
             1.3681274638356327`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.966545370866586, 1.3668678634286509`}, {
             3.0184206354778538`, 1.3640965904683977`}, {3.2122427517866523`, 
             1.3565318644660966`}, {3.4051552755436325`, 1.351105268642925}, {
             3.5971794038265585`, 1.3474163063010398`}, {3.7883363337131946`, 
             1.3450644807425982`}, {3.910674154397713, 
             1.3441807207781993`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9342855313217684`, 1.3440101538225917`}, {
             3.9520334781929276`, 1.3438819438805865`}, {4.114921459883773, 
             1.3432309417498636`}, {4.277000278785729, 1.3431114743504293`}, {
             4.438269934898797, 1.343523541682284}, {4.598736973811613, 
             1.3443358680212847`}, {4.758407941112817, 1.3454171776432893`}, {
             4.878752852901359, 1.3464400005369666`}}]}, 
           {Arrowheads[{{0.01597809331928342, 1.}}], 
            ArrowBox[{{4.902363993143813, 1.346640673871858}, {
             4.917282836802407, 1.3467674705482975`}, {5.075361660880383, 
             1.3483867467363095`}, {5.232620978932021, 1.3502169767918866`}, {
             5.3890373565425955`, 1.3522001312995906`}, {5.544610793712105, 
             1.3543362102594212`}, {5.656854249492381, 1.355996682232841}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.424971008192695}, \
{-5.493872708419977, -3.4137512453934393`}, {-5.268757209621757, \
-3.3985327283640605`}, {-5.042636820866661, -3.3837511424255378`}, \
{-4.815383353211907, -3.369569633797837}, {-4.714377206687654, \
-3.3635631151902503`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690806852921795, -3.3621614602083127`}, \
{-4.586996806657495, -3.3559882024809595`}, {-4.357477181203423, \
-3.343006848474904}, {-4.126591058237922, -3.3310634250060867`}, \
{-3.894105019149224, -3.3205957853009234`}, {-3.747529667749818, \
-3.314965441339593}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7239350755965046`, -3.3140591111266193`}, \
{-3.660019063937326, -3.3116039293594137`}, {-3.4243331926022287`, \
-3.3040878571815577`}, {-3.256174975107021, -3.299876573075966}, \
{-3.08681964469136, -3.296847944004356}, {-2.9162672013552475`, \
-3.2950019699667275`}, {-2.7797131187705464`, -3.2944745804352586`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7561013018693603`, -3.2943833885439804`}, \
{-2.7445176450986795`, -3.2943386509630797`}, {-2.57128192506749, \
-3.29494093133467}, {-2.396270990407512, -3.296891755422754}, \
{-2.219484841118744, -3.300191123227332}, {-2.040923477201185, \
-3.304839034748404}, {-1.86021512465034, -3.3105826672096494`}, \
{-1.8118473503593884`, -3.3123213608866595`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7882505984484038`, -3.313169601764952}, \
{-1.6769880094617122`, -3.317169197834749}, {-1.4912421316353013`, \
-3.3245986266237013`}, {-1.3029774911711085`, -3.3328709535765078`}, \
{-1.182661480201864, -3.3382753973808663`}, {-1.061272081216229, \
-3.343499783482889}, {-0.9388092942142041, -3.3485441118825747`}, \
{-0.844583472014508, -3.352254279416832}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8209897619204681, -3.353183288208266}, \
{-0.815273119195789, -3.3534083825799246`}, {-0.690763000424969, \
-3.3578695830784215`}, {-0.5653783821657279, -3.361704700881549}, \
{-0.439119264418066, -3.3649137359893073`}, {-0.3119856471819835, \
-3.3674966884016957`}, {-0.18420502691517052`, -3.369302437325024}, \
{-0.056004900075318276`, -3.3701798619656005`}, {
             0.07261473333757323, -3.370128962323425}, {
             0.12326275330487574`, -3.369744615737517}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14687406646551965`, -3.369565439382588}, {
             0.20165387332350349`, -3.369149738398498}, {
             0.39019126185957353`, -3.3661885831766862`}, {
             0.5781747120943457, -3.361522283416547}, {
             0.7656042240278202, -3.355150839118081}, {
             0.9524797976599965, -3.347074250281288}, {
             1.0908295915007777`, -3.340444779790929}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1144145227297622`, -3.3393146327826893`}, {
             1.115980072618663, -3.339239614479434}, {
             1.2783885123877305`, -3.331435662453482}, {
             1.4397051169671986`, -3.323662394203432}, {
             1.5999298863570672`, -3.3159198097292832`}, {
             1.7590628205573369`, -3.308207909031036}, {
             1.9171039195680073`, -3.300526692108691}, {
             2.0577905654568687`, -3.293668884550818}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.081374504550073, -3.2925182205249848`}, {
             2.22991061202055, -3.2852563095917056`}, {
             2.3848721843404634`, -3.2780203813983855`}, {
             2.5391338792268585`, -3.2715216117836063`}, {
             2.692695696679736, -3.265760000747369}, {
             2.8455576366990956`, -3.2607355482896727`}, {
             2.9977196992849375`, -3.256448254410518}, {
             3.025112621954097, -3.2558061893191095`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.04871813151767, -3.2552528977321282`}, {
             3.1491818844372617`, -3.2528981191099047`}, {
             3.2999441921560675`, -3.2500851423878325`}, {
             3.450006622441356, -3.248009324244302}, {
             3.6009638601213285`, -3.2466188940042175`}, {
             3.7514461060063997`, -3.2458774126930607`}, {
             3.952755966361673, -3.245765808135701}, {
             3.993121069204998, -3.2459292396657013`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.016732868669144, -3.246024839880755}, {
             4.153105403817542, -3.246576989398517}, {
             4.352494418374006, -3.2483109564815087`}, {
             4.550923010031066, -3.2509677093846756`}, {
             4.577334538522601, -3.251383752177758}, {
             4.603729827803148, -3.2518132131280426`}, {
             4.780213199178416, -3.255358661287451}, {
             4.955995221959467, -3.259434372316651}, {
             4.961094987633735, -3.2595595338020553`}}]}, 
           {Arrowheads[{{0.014239349465902731`, 1.}}], 
            ArrowBox[{{4.984699872630638, -3.2601388589431917`}, {
             5.124375668427454, -3.2635668654818346`}, {
             5.292135828265911, -3.2681417691937837`}, {
             5.45928470355429, -3.273134052764386}, {
             5.625831296372042, -3.27851868550553}, {
             5.656854249492381, -3.279589516383659}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.4253957378378317`}, {-5.491286170654985, 
             3.413999015031042}, {-5.26623468076005, 
             3.3987874184044697`}, {-5.040177800786796, 
             3.384013784980241}, {-4.812987251437013, 
             3.369841281101491}, {-4.714377713131849, 3.363980023961815}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.690807320527134, 
             3.3625790222502783`}, {-4.584663032710701, 
             3.3562699067682185`}, {-4.3552051446078615`, 
             3.343299661980424}, {-4.124380499802312, 
             3.3313686946863017`}, {-3.891956010967867, 
             3.3209151528340457`}, {-3.7475305203203595`, 
             3.315375643327414}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7239358764927544`, 
             3.314470659358153}, {-3.6579316781045295`, 
             3.3119390364236563`}, {-3.422307501212298, 
             3.3044403454551334`}, {-3.2542904021692176`, 
             3.3002439180654353`}, {-3.085077272915455, 
             3.297228527651743}, {-2.9146681134510115`, 
             3.295394174214056}, {-2.779714094399293, 3.2948803920703837`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7561022725148323`, 
             3.2947904997311332`}, {-2.7430629237758835`, 
             3.2947408577523745`}, {-2.5699732661354004`, 
             3.2953511438744174`}, {-2.3951107027748884`, 
             3.2973075981879036`}, {-2.2184752336943476`, 
             3.3006102206928323`}, {-2.0400668588937787`, 
             3.3052590113892037`}, {-1.8595150154290763`, 
             3.3110010653194717`}, {-1.8118481838133325`, 
             3.3127149988100975`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7882514396671456`, 
             3.3135634556655456`}, {-1.6764491403561381`, 
             3.3175834775260884`}, {-1.4908692336749638`, 
             3.3250062480090548`}, {-1.302775295385552, 
             3.3332693767683703`}, {-1.1823432987380422`, 
             3.338677146290487}, {-1.0608362145821244`, 
             3.343904149560593}, {-0.9382540429177983, 
             3.3489503865786894`}, {-0.8445838026795462, 
             3.352635975427904}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8209900658337932, 
             3.353564304566474}, {-0.8145967837450648, 
             3.353815857344775}, {-0.6899644048270795, 
             3.3582769862719988`}, {-0.5644568739269982, 
             3.362110197773508}, {-0.43807419104482165`, 
             3.365315491849303}, {-0.3108163561805501, 
             3.367892868499384}, {-0.18291171816779667`, 
             3.369691246564692}, {-0.054588625840175264`, 
             3.3705595448861705`}, {0.07415292080231423, 
             3.3704977634638182`}, {0.12326258887978409`, 
             3.3701206345362156`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.14687388568557982`, 3.3699393157981286`}, {
             0.2033129217596707, 3.369505902297635}, {0.39223094220844834`, 
             3.366521040974538}, {0.5805893554430269, 3.3618277873121465`}, {
             0.7683881614634074, 3.3554261413104607`}, {0.9556273602695896, 
             3.3473161029694802`}, {1.0908296025668056`, 
             3.3408263371189517`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.114414440975762, 3.3396942547193107`}, {
             1.119265429996761, 3.339461405157389}, {1.2818099143555595`, 
             3.3316418171864144`}, {1.443260813345985, 3.323857339056557}, {
             1.6036181269680374`, 3.316107970767816}, {1.7628818552217171`, 
             3.3083937123201927`}, {1.9210519981070238`, 
             3.3007145637136857`}, {2.0577910603920397`, 
             3.294060237254201}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0813751253726664`, 3.2929121556203795`}, {
             2.234111527772518, 3.285461596024023}, {2.389198009163801, 
             3.2782393799381255`}, {2.5435850944089022`, 3.271755479687862}, {
             2.697272783507821, 3.266009895273232}, {2.8502610764605576`, 
             3.261002626694236}, {3.0025499732671124`, 3.2567336739508734`}, {
             3.0251138397337125`, 3.2562081440204955`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0487194310529944`, 3.255658351511268}, {
             3.1541394739274846`, 3.2532030370431446`}, {3.3050295784416748`, 
             3.2504107159710496`}, {3.4552202868096824`, 
             3.2483567107345883`}, {3.6063534243435638`, 
             3.2469885200955586`}, {3.757011650707118, 3.24626954502898}, {
             3.958287025529947, 3.2461878015572063`}, {3.993122452227507, 
             3.2463336237506155`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.016734238353375, 3.2464324634310673`}, {
             4.15860136032477, 3.2470263236721992`}, {4.3579546550915875`, 
             3.2487851113739588`}, {4.556346909830399, 3.2514641646624844`}, {
             4.582754264845574, 3.25188302613848}, {4.609145397622271, 
             3.25231527249627}, {4.785799085721801, 3.25588244641297}, {
             4.9610964720822945`, 3.259964571370087}}]}, 
           {Arrowheads[{{0.014239319688728604`, 1.}}], 
            ArrowBox[{{4.984701320274352, 3.2605453704694547`}, {
             5.130355787686187, 3.2641346806512828`}, {5.298339399658441, 
             3.2687322668200887`}, {5.465710208798747, 3.273747532423435}, {
             5.6324771694837965`, 3.279155451652202}, {5.656854249492381, 
             3.2799991581683066`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.255445068613539}, {-5.501000570000735, 
             5.240923426467994}, {-5.342726942179516, 
             5.226329669494498}, {-5.184507932717036, 
             5.211943840993175}, {-5.02610860285873, 
             5.197786444951331}, {-4.8673428334260835`, 
             5.183885109228282}, {-4.716162964445489, 5.170972202100173}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.692633429054362, 
             5.169000799545678}, {-4.5486021536125, 
             5.157053740511968}, {-4.388572332118928, 
             5.144225268405405}, {-4.228066248825744, 
             5.131855978391038}, {-4.067056448176633, 
             5.119996650912218}, {-3.905515474615276, 
             5.108698066412294}, {-3.7761941382473787`, 
             5.100174003014019}, {-3.7507974583823596`, 5.098605212404292}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.727230385207066, 
             5.097149439315343}, {-3.6465366507020818`, 
             5.092164867567066}, {-3.5165206425511215`, 
             5.084671681372253}, {-3.3861237443662326`, 
             5.077695465730399}, {-3.2553235867191503`, 
             5.071237241942326}, {-3.1240978001816093`, 
             5.06529803130885}, {-2.9924240153253443`, 
             5.059878855130791}, {-2.8602798627220927`, 
             5.054980734708971}, {-2.7838425831991476`, 5.052507703084297}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7602429386031195`, 
             5.0517441663940685`}, {-2.7276139393214724`, 
             5.050688496338716}, {-2.594385399753872, 
             5.047056491771898}, {-2.4605877111121823`, 
             5.044040030494149}, {-2.326214340489292, 
             5.041594421991102}, {-2.1912587549780893`, 
             5.0396749757483885`}, {-2.055714421671464, 
             5.03823700125164}, {-1.9195748076623034`, 
             5.03723580798649}, {-1.815912027843464, 5.036774051338108}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7923002690939844`, 
             5.036668874855271}, {-1.7828333800434997`, 
             5.03662670543857}, {-1.6454122197544323`, 
             5.03636871420838}, {-1.5072593663357579`, 
             5.036419505400107}, {-1.3684072247822805`, 
             5.036732364254908}, {-1.2288882000888015`, 
             5.037260576013941}, {-1.088734697250123, 
             5.037957425918365}, {-0.9479791212610472, 
             5.038776199209337}, {-0.8478283644302074, 5.03940972343419}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8242168438297459, 
             5.039559082967352}, {-0.8066538771163765, 
             5.039670181128018}, {-0.6647913698109119, 
             5.040592656915562}, {-0.5223687315163903, 
             5.041379876181793}, {-0.379383193612935, 
             5.041910646947924}, {-0.2358973099079298, 
             5.042202092072209}, {-0.09197363420875804, 5.042271334412899}, {
             0.05232527967719558, 5.042135496828245}, {0.120255817904399, 
             5.041983395992406}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14386775171430827`, 5.041930527356856}, {
             0.19693687794254666`, 5.041811702176499}, {0.34179860677991136`, 
             5.041317073315913}, {0.4868479123819062, 5.040668733104737}, {
             0.6785590893348237, 5.039549982149404}, {0.8702255480768728, 
             5.038148485569038}, {1.061761617406282, 5.036545068153975}, {
             1.0883275408727433`, 5.03618760454011}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1119373966098645`, 5.035869916944373}, {
             1.253995452273514, 5.033958423597634}, {1.4457133773201318`, 
             5.031533569763107}, {1.6371295705505653`, 5.029068444674558}, {
             1.828244031964815, 5.026563048331983}, {2.019056761562881, 
             5.024017380735385}, {2.056336714541115, 5.023549684883424}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.079946849616076, 5.02325348380599}, {
             2.2094801652674856`, 5.0216284228930546`}, {2.399426649001352, 
             5.019593155813284}, {2.588896212764479, 5.017911579496073}, {
             2.7778888565568676`, 5.016583693941422}, {2.905797023875756, 
             5.015899683451326}, {3.024390855012836, 5.01550344677942}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.048002794389385, 5.015463863301065}, {
             3.1829816058452414`, 5.015377979118629}, {3.3321542331681453`, 
             5.015716437226846}, {3.4809886284591967`, 5.016488484062543}, {
             3.6294847917183968`, 5.017694119625718}, {3.6493201227652636`, 
             5.017884336912556}, {3.669149382898547, 5.0180821368510795`}, {
             3.816454789841489, 5.020028557964643}, {3.9634099157304554`, 
             5.022386101673687}, {3.992437217100822, 5.02288705733771}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.016045694567978, 5.023294494472675}, {
             4.109972570243023, 5.024915492572808}, {4.256131059103437, 
             5.027794686510441}, {4.401885382311693, 5.031023683486584}, {
             4.547235539867794, 5.03460248350124}, {4.692181531771739, 
             5.038531086554408}, {4.836723358023528, 5.042809492646088}, {
             4.960223071248788, 5.0467750246100955`}}]}, 
           {Arrowheads[{{0.014263074818991266`, 1.}}], 
            ArrowBox[{{4.983822652133624, 5.047540273884887}, {
             5.124594513570639, 5.052415713944982}, {5.267923842865962, 
             5.057743529152198}, {5.410849006509127, 5.063421147397925}, {
             5.553370004500137, 5.069448568682164}, {5.656854249492381, 
             5.074092228643656}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.252506843545668}, \
{-5.631092321245107, -5.250155214307775}, {-5.475282104767904, \
-5.235990202534083}, {-5.319807059122203, -5.221913617418511}, \
{-5.164667184308005, -5.207925458961058}, {-5.009483192098877, \
-5.19417850348203}, {-4.853875794268385, -5.180825527301733}, \
{-4.716043615604407, -5.169378000698199}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6925114543252935`, -5.167438187966563}, \
{-4.541390781743312, -5.15530151283733}, {-4.38451316704873, \
-5.143130474553224}, {-4.227212146732786, -5.131353415567848}, \
{-4.069487720795477, -5.119970335881203}, {-3.911339889236806, \
-5.108981235493288}, {-3.781135549011416, -5.100379474427541}, \
{-3.7505638998960094`, -5.098486874424833}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.726997023507919, -5.0970279190983625`}, \
{-3.6506137220117427`, -5.092299255751717}, {-3.5197744082377858`, \
-5.084740579465816}, {-3.388617607689544, -5.077703445569837}, \
{-3.2571433203670184`, -5.071187854063782}, {-3.1253515462702097`, \
-5.065193804947649}, {-2.993242285399117, -5.059721298221438}, \
{-2.8588701223681134`, -5.0548411832540525`}, {-2.7836090383785903`, \
-5.052410944648018}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7600093458045083`, -5.05164889232371}, \
{-2.7252712013148512`, -5.050527170773001}, {-2.5911002522483013`, \
-5.046881888274649}, {-2.4563509309019302`, -5.043859594292238}, \
{-2.3210168930092037`, -5.041414547359011}, {-2.185091794303589, \
-5.039501006008208}, {-2.0485692905185555`, -5.038073228773071}, \
{-1.911443037387568, -5.037085474186843}, {-1.8156785972560276`, \
-5.036672847820467}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7920668234386048`, -5.036571110260883}, \
{-1.773706690644092, -5.036492000782764}, {-1.6352809007699454`, \
-5.036249495014307}, {-1.4961128656111813`, -5.036313760454858}, \
{-1.3562360619476204`, -5.036637731317535}, {-1.215683966559085, \
-5.037174341815454}, {-1.0744900562253978`, -5.037876526161731}, \
{-0.9326878077263806, -5.038697218569482}, {-0.8475946921477083, \
-5.039230411859455}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8239831626717499, -5.039378361655357}, \
{-0.7903106978418551, -5.039589353251823}, {-0.6473922033516452, \
-5.0405058644218705`}, {-0.5039109291647444, -5.041279369012521}, \
{-0.3598654335977215, -5.041786235694937}, {-0.2153191235417597, \
-5.042045026289622}, {-0.07033540588804099, -5.0420743026170864`}, {
             0.07502231247225222, -5.041892626497838}, {
             0.1204894827324654, -5.041775869763651}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14410139787865828`, -5.041715235902238}, {
             0.22069062464793754`, -5.041518559752384}, {
             0.36660612374783275`, -5.040970664201232}, {
             0.5127054028807552, -5.040267501664892}, {
             0.7019041871461524, -5.039104410790668}, {
             0.8910485546228604, -5.037672705398166}, {
             1.0800577322890055`, -5.036050830033827}, {
             1.0885614116386317`, -5.035935581855726}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1121712364472187`, -5.035615603975257}, {
             1.2697125260226942`, -5.033480487415381}, {
             1.458868651347391, -5.031072975284086}, {
             1.6477280408177783`, -5.028632182273839}, {
             1.8362906944338564`, -5.026158108384637}, {
             2.024556612195625, -5.023650753616483}, {
             2.0565699629662233`, -5.023250041866879}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.080180106467715, -5.022954513230133}, {
             2.2124419870365033`, -5.021298988635147}, {
             2.399863011889912, -5.0192916841064}, {
             2.5868196867558497`, -5.017628840030243}, {
             2.7733120116343173`, -5.016310456406675}, {
             2.9010642577974277`, -5.015617589421235}, {
             3.024624052494236, -5.015192682773285}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.048236016772358, -5.015164621090307}, {
             3.1781149123990984`, -5.015069147508457}, {
             3.3273083381992223`, -5.015393016849868}, {
             3.476163457048414, -5.016150675855442}, {
             3.624680268946673, -5.01734212452518}, {
             3.644517910850109, -5.0175304538480905`}, {
             3.664349482729908, -5.017726369522475}, {
             3.8115039802988346`, -5.019656312279706}, {
             3.9583091345228842`, -5.021996670221609}, {
             3.992670413487855, -5.022586318343616}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.016278930692496, -5.022991446390429}, {
             4.104758329166988, -5.02450977494857}, {
             4.250802397117932, -5.027373264110621}, {
             4.396441338375715, -5.03058713770776}, {
             4.541675152940337, -5.034151395739987}, {
             4.6865038408118, -5.038066038207302}, {
             4.8309274019901025`, -5.042331065109706}, {
             4.960456012317831, -5.046482115763557}}]}, 
           {Arrowheads[{{0.01425817856712588, 1.}}], 
            ArrowBox[{{4.98405512252216, -5.0472614532055395`}, {
             5.118559144267225, -5.051912272219779}, {
             5.261767325366046, -5.057228452427448}, {
             5.404570379771707, -5.062895017070205}, {
             5.546968307484207, -5.06891196614805}, {
             5.656854249492381, -5.0738395430119905`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            
            ArrowBox[{{-5.656854249492381, -4.790362697447631}, \
{-5.51695415378713, -4.7781452357275}, {-5.348090433422636, \
-4.763561580123899}, {-5.1778892202821805`, -4.749024318041132}, \
{-5.046311107464034, -4.737992787148069}, {-4.914423646650297, \
-4.727224978898287}, {-4.782226837840964, -4.716720893291788}, \
{-4.715670854158579, -4.711577302633695}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.692129058582307, -4.709757941652138}, \
{-4.649720681036039, -4.70648053032857}, {-4.516905176235522, \
-4.696503890008635}, {-4.38378032343941, -4.686790972331981}, \
{-4.250346122647706, -4.67734177729861}, {-4.116602573860408, \
-4.66815630490852}, {-3.9824744184319743`, -4.659374478015397}, \
{-3.8478863977168607`, -4.651136219472922}, {-3.74985112961272, \
-4.645550415516509}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.726277370944868, -4.644207241809935}, \
{-3.712838511715068, -4.643441529281096}, {-3.577330760426595, \
-4.63629040743992}, {-3.441363143851442, -4.629682853949393}, \
{-3.30493566198961, -4.623618868809515}, {-3.168048314841098, \
-4.618098452020286}, {-3.030701102405904, -4.613121603581707}, \
{-2.8927708806881127`, -4.608718726237936}, {-2.782616169096356, \
-4.605700592951757}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7590130339599352`, -4.605053889721509}, \
{-2.754134505691803, -4.604920222733135}, {-2.614791977416976, \
-4.601726093067302}, {-2.4747432958636306`, -4.599136337240438}, \
{-2.333988461031767, -4.597150955252543}, {-2.1925274729213853`, \
-4.595769947103617}, {-2.050360331532487, -4.594993312793659}, \
{-1.9074870368650696`, -4.59482105232267}, {-1.8146188781490125`, \
-4.59502260643797}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.791006940760773, -4.5950738520232886`}, \
{-1.7422210157851405`, -4.5951797333510065`}, {-1.5758318118947192`, \
-4.595956956303886}, {-1.4083194251938058`, -4.597152721181309}, \
{-1.2396838556824004`, -4.598767027983274}, {-1.0699617075412071`, \
-4.600568918134833}, {-0.8991895849509304, -4.602327433061037}, \
{-0.846562385854713, -4.6028527612933745`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8229515691379693, -4.603088446049981}, \
{-0.7273674879115701, -4.604042572761884}, {-0.5544954164231262, \
-4.605714337237375}, {-0.38074193335875894`, -4.607127037296522}, \
{-0.2062756015916284, -4.608064983748334}, {-0.031096421121734497`, \
-4.608528176592812}, {0.12150642879469548`, -4.608518146545588}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14511842075860812`, -4.608515818875341}, {
             0.2697123464281608, -4.608208223474555}, {
             0.39466119651248543`, -4.607635871881057}, {
             0.5196421583038965, -4.606799561049466}, {
             0.6446552318023933, -4.605699290979779}, {
             0.7697004170079771, -4.604335061671998}, {
             0.8947777139206472, -4.602706873126122}, {
             1.0198871225404036`, -4.600814725342151}, {
             1.089546125771758, -4.599614546012182}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1131546149339155`, -4.599207787095318}, {
             1.145028642867247, -4.598658618320086}, {
             1.3428570616002338`, -4.5951025932994725`}, {
             1.5401252893017434`, -4.591678018132355}, {
             1.7368333259717754`, -4.588384892818733}, {
             1.9329811716103302`, -4.585223217358608}, {
             2.0574999371404767`, -4.583294056990212}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0811090968452053`, -4.582928281959922}, {
             2.1285688262174074`, -4.5821929917519775`}, {
             2.3235962897930076`, -4.579294215998844}, {
             2.5180635623371304`, -4.576526890099206}, {
             2.7119706438497753`, -4.573891014053065}, {
             2.8377230736422785`, -4.572380995362908}, {
             2.963190439149736, -4.571192401833376}, {
             3.0255079308545736`, -4.570782266612936}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0491194124972627`, -4.5706268704318065`}, {
             3.126950932443033, -4.570114631464594}, {
             3.2902663458477974`, -4.569572238103036}, {
             3.4531366793640292`, -4.569565221748704}, {
             3.6155619329917283`, -4.570093582401595}, {
             3.6372110869481213`, -4.570199830875216}, {
             3.658852692953678, -4.570315350433743}, {
             3.80582488597372, -4.571590147210205}, {
             3.9523874937698618`, -4.573330206268913}, {
             3.993575678164653, -4.573873414601514}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.0171856179517755`, -4.574184793124578}, {
             4.084434208950925, -4.575071697840655}, {
             4.216156589537597, -4.577156882568382}, {
             4.347554635529878, -4.579585760452097}, {
             4.478628346927768, -4.582358331491797}, {
             4.609377723731267, -4.585474595687484}, {
             4.739802765940374, -4.588934553039157}, {
             4.86990347355509, -4.592738203546816}, {
             4.96140589900199, -4.595662403041326}}]}, 
           {Arrowheads[{{0.014237901771289791`, 1.}}], 
            ArrowBox[{{4.985005843889687, -4.596416601048363}, {
             4.999679846575415, -4.596885547210461}, {
             5.129130950293652, -4.601354425579152}, {
             5.258255850002103, -4.606122680201947}, {
             5.3869510084905645`, -4.611177542452942}, {
             5.515112888548832, -4.61650624370623}, {
             5.656854249492381, -4.622796102052734}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAANevp5efR5z9fcDRuxB3sv/88q65Q
AOw/1S4XE7eK57+yz3RY2tXuPw5aGFLiC+O/HZNwj3BG8D+nd1ZefvDdv3ON
DgIsefA/PXZig6h227/x5X0AtJ/wP0p1N5leG9m/yJnITbSy8D+swAfqWHXW
vwqmn7ByufA/dkBohidu1L8qgo77VrfwP9WQejI4hNK/qinI1hWg8D+bxvwx
8NPNv9nz9IrHXvA/tgDJXAttx7/vWjoUpgfwP2TuvpsgZMK/nDgNnwOD7z8f
viVuE8u+vzsixx80Ee8/SVXm1KfSur+0kFSJlbTuP22k9cSYD7i/w+eVSuhH
7j9/9G28QTm1v7G0dHwC/e0/lwQxI+9+s7/zU5qDLMntP4WFFhISY7K/OV3u
vseN7T+5FM+nYTCxv8SictWtiu0/4rsYkUkhsb/I3a7o
             "]]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.016847798198595332`, 1.}}], 
            ArrowBox[{{0.7018235200001439, 0.8741947614466165}, {
             0.8326576659585025, 0.73338745432645}, {0.9380561046190315, 
             0.5526117332404895}, {0.958953496481921, 0.49526242904665696`}, {
             0.9737974363932096, 0.44087055234357686`}, {0.982620177484312, 
             0.38906795962254076`}, {0.986073900886108, 0.3586861877236438}, {
             0.9872316265169848, 0.3291459357721577}, {0.9863540364981623, 
             0.3106385747058135}, {0.98501015446795, 0.29394881023995334`}, {
             0.981514191853817, 0.26343166945244256`}, {0.9765871681443243, 
             0.2378926467649244}, {0.9706633299286652, 0.2164091990340617}, {
             0.9591146120212762, 0.18599424946280152`}, {0.9514538423974652, 
             0.17056292351978672`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0879007420589546`, 
             0.20798971878099923`}, {-1.0764271419519076`, 
             0.2818195188315519}, {-1.0507457392953337`, 
             0.37776028627004044`}, {-1.0409117003648907`, 
             0.4095181274244408}, {-1.0289310285097544`, 
             0.4430708437810698}, {-1.0133853946281008`, 
             0.47768239882354185`}, {-0.9953778082971424, 
             0.5143949902126987}, {-0.9536197097690343, 
             0.5913584915100143}, {-0.8989277589404898, 
             0.6743033615575447}, {-0.8287870271006471, 
             0.761172778561092}, {-0.6771170645683832, 
             0.9012964476508369}, {-0.576703306392225, 
             0.962663631950217}}]}, 
           {Arrowheads[{{0.002002826886862202, 1.}}], 
            ArrowBox[{{-0.5565559092689799, 
             0.9749765764597329}, {-0.475852411951529, 
             1.0242979690999343`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAAITbqrTjO7b8PyT2QMTjGv5V+1nhM
2e2/92EhTyvKxr+UkUuYZOvtv4Gp/wED08e/P4B1wW4M7r8+s2ZMByzKv6wJ
W2CaMO6/pwV/QLGDzr/5IB/EiznuvyeijYgEWtC/6QWwFds87r+DbTgOCKLR
v+NNRSHXOO6/bPf9cbkl07+Bbg0/9DTuvzKY1GSI0NO/We5HxWwv7r/iV5Nd
NI7UvwQsdNqeJ+6/VCHA2Qhv1b+G9Emu9SLuv+aGS7Q/7dW/Fr32vV0d7r/r
he6Jg3rWv+Z5Td0A9e2/FoC1WPs22L/+agF7y73tvx7N6knL/dm/0yrRTHRt
7b94XRoeYEXcvw7mi260/ey/JmTUBjXi3r9I5Y3dGWDsv3sG5Kpy/+C/rQln
RSIk7L8UhADO6obhv7NBaANq8Ou/IxErYo/y4b+6Bx0whrrrv0auHY95XOK/
lI9MMYVG6799lV4CYzDjvwf/19OlxOq/i0Fw1nYK5L8fEliHyS/qv9jwBf+/
8uS/F9IbNOlQ6L/14ExednXnv1Wa/omWAua/INF8yJfk6b+WCearizXjv86o
pb2WQuy/ARQWHn4H4L/FmRhhhVPuv6yV+8E=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.47932733546145606`, -0.957189427757431}, \
{-0.288327318960961, -1.0377333488742673`}, {-0.0974232095815803, \
-1.074593854823093}, {0.10032171428011309`, -1.0737879210057184`}, {
             0.29294756770363994`, -1.0344319889267415`}, {
             0.41071673026082667`, -0.9894526334616197}, {
             0.4303732008201785, -0.9788294018097181}}]}, 
           {Arrowheads[{{0.0016291624441678858`, 1.}}], 
            ArrowBox[{{0.4511456592302155, -0.9676030406477277}, {
             0.5188290774595588, -0.9310239086681685}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.010051741335641736`, 1.}}], 
            ArrowBox[{{-0.31832043307671004`, 
             0.9273757050378935}, {-0.2943663933717846, 
             0.9365818076670298}, {-0.2680513533416015, 
             0.9457630639001269}, {-0.24054420673927782`, 
             0.9543438679160393}, {-0.21203949956153598`, 
             0.9622251482878164}, {-0.18254821821922046`, 
             0.9693760646287196}, {-0.1510090281890317, 
             0.9759265172611512}, {-0.11877706575401661`, 
             0.9814123645363549}, {-0.0866178877906669, 
             0.9856364827734022}, {-0.05215264402924891, 
             0.9875417737783136}, {-0.01642433898112855, 0.988088052166517}, {
             0.018550174048301525`, 0.987263000918577}, {0.05189579122670649, 
             0.9852160492754025}, {0.08454447930797243, 0.9819909679704981}, {
             0.1164806115259948, 0.9776426566473424}, {0.14740959612296678`, 
             0.9722746334205523}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.0100269369329244`}, \
{-5.503760676080085, -2.0032785300719342`}, {-5.261538584981536, \
-1.9928902915220565`}, {-5.0177522651949165`, -1.9827220792478175`}, \
{-4.772401716720226, -1.9727738932492167`}, {-4.713204246568456, \
-1.970469628320362}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689610121243601, -1.969551225635692}, \
{-4.628364434242151, -1.9671672337482138`}, {-4.483685116893586, \
-1.9618362258044566`}, {-4.338363764674529, -1.9567808694179452`}, \
{-4.192400377584981, -1.9520011645886792`}, {-4.0456906479839265`, \
-1.9476246410325062`}, {-3.8981302682303536`, -1.9437788284652735`}, \
{-3.7497192383242615`, -1.9404637268869807`}, {-3.745594216392215, \
-1.9403867769809904`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.7219863306617067`, -1.9399463854830739`}, \
{-3.6004575582656493`, -1.9376793362976281`}, {-3.4502263254165704`, \
-1.9356957698841826`}, {-3.2989066371390767`, -1.934783140833611}, \
{-3.1464984934331666`, -1.9349414491459134`}, {-2.993001894298842, \
-1.93617069482109}, {-2.8044734629706447`, -1.9396375149306353`}, \
{-2.777594244463894, -1.9404979097067858`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75399433882215, -1.9412533347771501`}, \
{-2.6137016405757287`, -1.9457440570305873`}, {-2.420154914100676, \
-1.9550658909750793`}, {-2.223301770532067, -1.9681785866182444`}, \
{-2.022137286354514, -1.985643913160985}, {-1.815656538052634, \
-2.008023639804204}, {-1.8122399828631868`, -2.008452925354913}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7888121996969117`, -2.0113965947062766`}, \
{-1.6573537412790242`, -2.0279141726723946`}, {-1.4944828025511174`, \
-2.050528810384106}, {-1.326144738239204, -2.075454238258488}, \
{-1.1514405647135741`, -2.102277141614692}, {-0.969689195472916, \
-2.1296080713894416`}, {-0.8539764584438321, -2.1457604383562954`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8305912021560031, -2.149024791537052}, \
{-0.780209544015918, -2.1560575785194627`}, {-0.6405361517393898, \
-2.173361472219496}, {-0.49736720577068705`, -2.1881653763304114`}, \
{-0.3511745710802195, -2.199835361891779}, {-0.2024301126383981, \
-2.207737499943169}, {-0.05191553856448053, -2.211463528849536}, {
             0.09958744302227449, -2.210605186975835}, {
             0.1108370061062168, -2.2101665130101633`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.1344310674598052, -2.209246468348602}, {
             0.28972812646531737`, -2.203190697451301}, {
             0.47790167423820407`, -2.1888702988089355`}, {
             0.7084800968743862, -2.1634892260724867`}, {
             0.9312473961827754, -2.1318736762179697`}, {
             1.0728205193589284`, -2.1092065381044134`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0961316884381587`, -2.1054496037897756`}, {
             1.2400459869147444`, -2.0819843454949214`}, {
             1.3880876290161162`, -2.0573857749017597`}, {
             1.5318908356077476`, -2.0330179341541728`}, {
             1.6723147664362594`, -2.0097320663413654`}, {
             1.8102185812482747`, -1.988379414552543}, {
             1.9456022800437935`, -1.9689599787877057`}, {
             2.0289657736296447`, -1.9579884820335363`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0523758904858633`, -1.9549074688699237`}, {
             2.0784658628228154`, -1.951473759046853}, {
             2.2742645527660645`, -1.9285455878488516`}, {
             2.4677283002491026`, -1.9092096663343585`}, {
             2.65885710527193, -1.8934659945033736`}, {
             2.8476509678345474`, -1.881314572355897}, {
             2.993106495093621, -1.8739879989531159`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0166885917141273`, -1.8728001722328986`}, {
             3.0347381535179374`, -1.871891018473426}, {
             3.2207469279030834`, -1.8643309514374578`}, {
             3.4056772909899857`, -1.8586343712479925`}, {
             3.5895292427786445`, -1.8548012779050298`}, {
             3.7455240989179965`, -1.8527515558975312`}, {
             3.9008354570336703`, -1.8514909691881103`}, {
             3.960845230165343, -1.851278625703939}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.984457075343557, -1.851195075621824}, {
             4.135714633400588, -1.8506598535203407`}, {
             4.369218413598224, -1.8508924983639294`}, {
             4.601346797626578, -1.8521889037188763`}, {
             4.832099785485648, -1.8545490695851814`}, {
             4.862716936978491, -1.8549339438716412`}, {
             4.893311231830079, -1.855331359425218}, {
             4.928910633606786, -1.8558916592973993`}}]}, 
           {Arrowheads[{{0.0149172300253024, 1.}}], 
            ArrowBox[{{4.952519702603064, -1.8562632430229884`}, {
             5.078833611000621, -1.858251300776705}, {
             5.263221810698351, -1.8614861408602192`}, {
             5.46944745457143, -1.8652811739661521`}, {
             5.656854249492381, -1.8690345176780574`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.0200193754806963`}, {-5.494412614356962, 
             2.012651281752228}, {-5.282530573638237, 
             2.0031911264754507`}, {-5.067948932252902, 
             1.9938712164668178`}, {-4.8516188275605785`, 
             1.9847322867999304`}, {-4.713262179066524, 1.979107317678533}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68966967575716, 
             1.9781481508870844`}, {-4.634081721996051, 
             1.975888190655095}, {-4.415162146875638, 
             1.9675807378993517`}, {-4.194684633515664, 
             1.9600517383997416`}, {-4.072572439229322, 
             1.9562820498046174`}, {-3.94991884037061, 
             1.952791187058874}, {-3.826689476324557, 
             1.9496464129441082`}, {-3.7456896182717, 1.9478598677037275`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722083366487947, 
             1.9473392046089852`}, {-3.7028499864762003`, 
             1.946914990241918}, {-3.57838358963656, 
             1.9446233695527158`}, {-3.4532594410758675`, 
             1.9428306512218618`}, {-3.327422084867972, 
             1.9416530726483747`}, {-3.200816065086722, 
             1.9412068712312733`}, {-3.0734696161808674`, 
             1.9415649206940468`}, {-2.945344020299239, 
             1.9428347857006076`}, {-2.8162833930658047`, 
             1.9451847400606106`}, {-2.777691491359486, 
             1.9462516956494575`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75408851727235, 
             1.9469042503047664`}, {-2.6861318501045344`, 
             1.9487830575837102`}, {-2.5549066635869195`, 
             1.953820921816611}, {-2.4224865804464337`, 
             1.960471188516378}, {-2.2885079284500223`, 
             1.968874639808205}, {-2.152607035364627, 
             1.9791720578172873`}, {-1.9965728303885202`, 
             1.9934118796299392`}, {-1.8372887870455523`, 
             2.010620222260113}, {-1.8123188787847346`, 
             2.0137261521741308`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7888874567280422`, 
             2.016640714531897}, {-1.674055717963797, 
             2.030924280525858}, {-1.506039090203555, 
             2.054156308529895}, {-1.3321799341561764`, 
             2.0802175582866793`}, {-1.1515974624153629`, 
             2.108281404556541}, {-0.9629486101780415, 
             2.1373036493533277`}, {-0.8543084732534366, 
             2.1527158898558785`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8309305568238069, 
             2.1560323995792787`}, {-0.7661712318393905, 
             2.165219485675602}, {-0.6238511933431489, 
             2.1822780161435875`}, {-0.4777369594003713, 
             2.1969631743660276`}, {-0.328675777491414, 
             2.2082446481275855`}, {-0.17713834066092213`, 
             2.2155500417530734`}, {-0.02396898267565875, 
             2.2185052148845785`}, {0.11050628797698345`, 
             2.216959899751454}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1341127990501772, 2.216549934701136}, {
             0.32717885681972836`, 2.207839737459107}, {0.5218885854020512, 
             2.1917733439836544`}, {0.7551562524052857, 2.164771812867216}, {
             0.9801915289313874, 2.1319913017482017`}, {1.0725959088896442`, 
             2.1170139641598777`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0959037216746232`, 2.113236123967846}, {
             1.1422884696988085`, 2.105717865304984}, {1.2999607602784653`, 
             2.0799569084150655`}, {1.4532084006703578`, 
             2.0547084310784456`}, {1.602031390874486, 2.029972433295125}, {
             1.747399439492955, 2.006567201892585}, {1.8902822551278704`, 
             1.9853110236983065`}, {2.02885781203156, 1.966451863620454}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.052290249449976, 1.9635466246310207`}, {
             2.168592187447037, 1.949245826934537}, {2.3834426908250346`, 
             1.9261380986726169`}, {2.5958671372117657`, 
             1.9070360534052468`}, {2.805865526607231, 1.8919396911324267`}, {
             2.9929889892655677`, 1.8819416037874246`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0165693587113136`, 1.880724975632548}, {
             3.2191797225428354`, 1.8726997396763234`}, {3.4236867053199194`, 
             1.8664275987048142`}, {3.6269588073426817`, 
             1.8620325889396292`}, {3.8289960286111224`, 1.859514710380768}, {
             3.960726799406269, 1.8584818221904404`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.984338066607883, 1.8582966885356078`}, {
             3.9935153233339276`, 1.8582247305562025`}, {4.157305486648408, 
             1.857688267434468}, {4.391114944493221, 1.8578463096617484`}, {
             4.624924402338036, 1.8580043518890288`}, {4.856023319920509, 
             1.8602050194620579`}, {4.928802741476154, 
             1.8608980703628444`}}]}, 
           {Arrowheads[{{0.01491932737064544, 1.}}], 
            ArrowBox[{{4.952413663975334, 1.8611229082463654`}, {
             5.0871222375029825`, 1.8624056870350867`}, {5.117576467923691, 
             1.8628886079607543`}, {5.14800830346654, 1.8633820902719582`}, {
             5.341110751027994, 1.8669090044260934`}, {5.532914329583875, 
             1.8707075674375373`}, {5.656854249492381, 1.873235009815162}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.9915502328068658}, \
{-5.592378935738664, -0.9900537716346011}, {-5.454615748085831, \
-0.9868652516851446}, {-5.316300844699856, -0.9836885291892921}, \
{-5.1774415745723035`, -0.9805322034669345}, {-5.038030282320426, \
-0.9774103123890509}, {-4.898033054906431, -0.9743464112910246}, \
{-4.757415979292526, -0.9713640555082391}, {-4.712610656964089, \
-0.9704447869616604}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689003632075573, -0.9699604428183634}, \
{-4.616150669748186, -0.9684657222514241}, {-4.474204318697071, \
-0.9656707512310325}, {-4.331536380332667, -0.9630279915320319}, \
{-4.188106308848464, -0.96058629223939}, {-4.04387533890541, \
-0.9583304775510783}, {-3.8988032807904873`, -0.9562965915746651}, \
{-3.7528474521362214`, -0.954610313259514}, {-3.744653931644729, \
-0.9545426490573964}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721042743760574, -0.9543476617877742}, \
{-3.6059651705751388`, -0.9533973215549884}, {-3.4397326441104568`, \
-0.9526692729954283}, {-3.2722149160392546`, -0.9527835773329278}, \
{-3.1033509126473087`, -0.9539434598757912}, {-2.9330819872493707`, \
-0.9565399327318274}, {-2.7766445168933016`, -0.9605798748261118}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7530444748467957`, -0.9613123812094518}, \
{-2.58817279179411, -0.9680020929791269}, {-2.413501575100345, \
-0.9783386890590106}, {-2.2369956578244543`, -0.9934943271819665}, \
{-2.0278083213815092`, -1.0199163155590134`}, {-1.8150198692555368`, \
-1.059782873990561}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.792171320300953, -1.065727050406942}, \
{-1.5908673462362644`, -1.118858742339541}, {-1.4734585306213395`, \
-1.1576482735265938`}, {-1.349887780090774, -1.2034754659230547`}, \
{-1.1718527931839509`, -1.2749562427531147`}, {-0.9718169210105527, \
-1.3561298365012908`}, {-0.9031656599170198, -1.381269528744989}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8809935348564164, -1.389388831894467}, \
{-0.7426376163845921, -1.4400539639702927`}, {-0.6153432185770413, \
-1.4792551897129707`}, {-0.47992300139180016`, -1.5137804356161908`}, \
{-0.2661639407611114, -1.5512103068082381`}, {-0.04166221637051326, \
-1.5675142063314773`}, {0.0403711583181999, -1.5645004626588785`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.06396723308638695, -1.5636335896172582`}, {
             0.18521852618654755`, -1.5591790573154765`}, {
             0.32201772626090897`, -1.5422310771893462`}, {
             0.4548771513095192, -1.517089482526236}, {
             0.582564016429335, -1.4852216490204735`}, {
             0.703845536717314, -1.4480949523663857`}, {
             0.7641496909928787, -1.426987321361936}, {
             0.8226745413734935, -1.4049655300156882`}, {
             0.9447955848228715, -1.3555192235863769`}, {
             0.975442680113649, -1.3420662935682293`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.997063351889013, -1.3325756262935777`}, {
             1.0581063758791625`, -1.305780019008645}, {
             1.2622585796606987`, -1.2115880758272741`}, {
             1.41286616202524, -1.1440950069744893`}, {
             1.5529511711850372`, -1.0866283397745151`}, {
             1.6855883144100798`, -1.0384260242219538`}, {
             1.8138522989703578`, -0.9987260103114073}, {
             1.8730523995258204`, -0.9834648199450653}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.895916875135261, -0.977570588151061}, {
             1.939224611761389, -0.9664062893274882}, {
             2.0631867396786903`, -0.940344852554809}, {
             2.096195082927982, -0.9342035637357677}, {
             2.1291516580933627`, -0.9284032019132165}, {
             2.2278224300269005`, -0.9144879413856849}, {
             2.3263223501765653`, -0.9027139064753635}, {
             2.459939724311678, -0.8882096616468813}, {
             2.593415658226039, -0.876657324415545}, {
             2.7267415781138458`, -0.8675144987168811}, {
             2.831766568684749, -0.8617763692030076}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.855343398589935, -0.8604882290871445}, {
             2.8599089101692976`, -0.8602387884864163}, {
             2.9928771747969787`, -0.8544906192820534}, {
             3.125605892401475, -0.8499304166616953}, {
             3.3481364703486, -0.8442407496736108}, {
             3.56973421063725, -0.8405110450114234}, {
             3.7902973970034624`, -0.838288829469628}, {
             3.7994983722605706`, -0.8382398866367511}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.823110031214356, -0.838114288920658}, {
             4.009724313183274, -0.83712162984272}, {
             4.227964836707184, -0.8367883820996911}, {
             4.444968845105688, -0.8370680222095334}, {
             4.6533380958881665`, -0.8377752356815179}, {
             4.767584171838321, -0.838321177272175}}]}, 
           {Arrowheads[{{0.018331469141415636`, 1.}}], 
            ArrowBox[{{4.791195895245538, -0.8384340093473941}, {
             4.860342703642703, -0.8387644374890284}, {
             5.065982668369297, -0.8400356276320647}, {
             5.270257990067947, -0.8415888061106269}, {
             5.47311580429072, -0.8433614744833949}, {
             5.656854249492381, -0.8451100006110486}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.0082179645643565`}, {-5.538803239768369, 
             1.005438087338327}, {-5.401225682767493, 
             1.0022161088737294`}, {-5.2631368236133325`, 
             0.9990136239358484}, {-5.140841701917686, 
             0.9962100125993983}, {-5.0181123189351196`, 
             0.9934375660504758}, {-4.894925685980479, 
             0.9907120884953032}, {-4.77125881436861, 
             0.988049384140103}, {-4.712617170766187, 
             0.9868235852738103}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689010334642203, 
             0.9863301265100396}, {-4.647092241373672, 
             0.9854539036068399}, {-4.522403683502373, 
             0.982939180384885}, {-4.397165920918384, 
             0.9805346429815694}, {-4.271351733785379, 
             0.9782697199042247}, {-4.14493593222352, 
             0.9761454201945813}, {-4.017891702387776, 
             0.9741854884668503}, {-3.890189388494032, 
             0.9724534565870838}, {-3.7617993347581695`, 
             0.9710128564213342}, {-3.7446620871497456`, 
             0.9708577606943457}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721051061078347, 
             0.9706440758986795}, {-3.632692074187713, 
             0.9698444083195621}, {-3.5028379887568732`, 
             0.9689950818446015}, {-3.372207196131565, 
             0.9686277826818139}, {-3.240769813977704, 
             0.968905416516561}, {-3.09931233590521, 
             0.970006466376906}, {-2.9568630083492202`, 
             0.9721241532789899}, {-2.8133879747449235`, 
             0.9755016537298601}, {-2.7766606044073807`, 
             0.9767812372980708}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753062928841799, 
             0.9776033815905746}, {-2.668845947737934, 
             0.9805375057653908}, {-2.5232633801309787`, 
             0.9876477337552366}, {-2.3765163828334095`, 
             0.997524112459146}, {-2.2287299707643773`, 
             1.010691840368183}, {-2.079230667036686, 
             1.0285607692909668`}, {-1.8854215156359169`, 
             1.0612255304762632`}, {-1.8153919882183895`, 
             1.0775133897535054`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7923938568185975`, 
             1.082862423820892}, {-1.6851933804745978`, 
             1.1077957103577847`}, {-1.4732910815816673`, 
             1.1728740428464584`}, {-1.3315102870429814`, 
             1.2245297230090026`}, {-1.1782335703200142`, 
             1.2847750237551323`}, {-1.0093238090394543`, 
             1.3520399254511344`}, {-0.901793697402434, 
             1.3937820858541874`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8796684121364733, 
             1.402018996509156}, {-0.7590474357498371, 
             1.4442616512055793`}, {-0.6190430606639068, 
             1.4872329782265157`}, {-0.469334204448023, 
             1.5245891655765282`}, {-0.3109696162918646, 
             1.5531030800158645`}, {-0.14600338374131744`, 
             1.5705140667751958`}, {0.022831857206772, 1.5744978654922233`}, {
             0.04304885935811163, 1.5733387676011288`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.06662214082800877, 1.571987244727787}, {
             0.1921498907450631, 1.5647903839314365`}, {0.4012608328537808, 
             1.534673761608387}, {0.5994292219433952, 1.4870228193028727`}, {
             0.7828822581972233, 1.4270740507260116`}, {0.8467405165903588, 
             1.4027882826992797`}, {0.9082767198630162, 
             1.3780761331507396`}, {0.9780014348695465, 
             1.3477669978600275`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9996559631941023, 1.3383538359907527`}, {
             1.111573916848822, 1.2897034198726969`}, {1.2914379679834769`, 
             1.2069813137009706`}, {1.445389861682858, 1.139438903031855}, {
             1.5890215676500103`, 1.0825912045810249`}, {1.72545820718269, 
             1.0354493429428147`}, {1.857824901578653, 0.9970244427115595}, {
             1.876984140212601, 0.9924458569553183}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8999494715586993`, 0.9869577088614637}, {
             1.987518150009488, 0.9660309532889729}, {2.115934451646785, 
             0.9411833240767684}, {2.148952014389738, 0.9355567806938162}, {
             2.1819269407842707`, 0.9302400851889269}, {2.282307245355572, 
             0.9172939912063816}, {2.382540031870551, 0.9063592950214208}, {
             2.52142165132593, 0.892643061562501}, {2.6601472308161105`, 
             0.8818134113101019}, {2.798691917494885, 0.8733224103570016}, {
             2.835852409060793, 0.8715225852084089}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.8594367557525735`, 0.8703803048321196}, {
             2.9370308585160476`, 0.8666221247959782}, {3.0751210313124187`, 
             0.8613831814027605}, {3.212919413316819, 0.8572762069530772}, {
             3.4464782825211118`, 0.8522003497937191}, {3.6789329969055466`, 
             0.8490173775249518}, {3.8035845462881515`, 
             0.8480834705118719}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.8271958766176946`, 0.8479065710903074}, {
             3.910185172114038, 0.8472848035674931}, {4.140136423790502, 
             0.8465601413420614}, {4.36874212542877, 0.8466305931673174}, {
             4.5959576505226725`, 0.847283361361922}, {4.771669162875183, 
             0.8481246828148632}}]}, 
           {Arrowheads[{{0.018244968245139877`, 1.}}], 
            ArrowBox[{{4.795280885216519, 0.8482377377210597}, {
             4.817178493478705, 0.8483425853053325}, {5.0368020751499545`, 
             0.8496699160291841}, {5.2548283955364194`, 0.8512653535334769}, {
             5.4712574546381, 0.8531288978182109}, {5.656854249492381, 
             0.8549196099788926}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.799037889814912}, {-5.623469963398864, 
             4.796067131366908}, {-5.485082018900673, 
             4.78388583510681}, {-5.343213619131692, 
             4.7715282188859}, {-5.323919216616578, 
             4.769856078291135}, {-5.304619386091764, 
             4.768186870792772}, {-5.104659370773657, 
             4.751344251256408}, {-4.9040760171202304`, 
             4.734948692955421}, {-4.735002944118785, 
             4.721459561793159}, {-4.715692907957368, 4.719994120249689}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.692148617112242, 
             4.718207340482548}, {-4.565341312903737, 
             4.708583915127509}, {-4.395091123475088, 
             4.696321752958469}, {-4.224252375832836, 
             4.6846730752860415`}, {-4.052825069976981, 
             4.673637882110226}, {-3.8808092059075254`, 
             4.663216173431021}, {-3.749752876339201, 4.6557689142939065`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.726178913606947, 
             4.654429326881883}, {-3.708204783624467, 
             4.653407949248428}, {-3.535011803127807, 
             4.644213209562447}, {-3.361017774466794, 
             4.63582498905766}, {-3.1860102076906776`, 
             4.628436322418651}, {-3.0099891027994583`, 
             4.622047209645418}, {-2.8329544597931355`, 
             4.616657650737963}, {-2.7825433293065935`, 
             4.61541470000632}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7589385102800787`, 
             4.614832693080545}, {-2.6549062786717093`, 
             4.612267645696285}, {-2.47584455943518, 
             4.608877194520384}, {-2.2957693020835475`, 
             4.606486297210261}, {-2.1146805066168115`, 
             4.6050949537659145`}, {-1.9323997328507405`, 
             4.604383752774274}, {-1.8145453217263836`, 4.604158845822655}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.790933371723175, 
             4.6041137860608154`}, {-1.748748540601104, 
             4.604033282822272}, {-1.5637269298679017`, 
             4.6040435439099054`}, {-1.3773349006511335`, 
             4.604414536037176}, {-1.1895724529507992`, 
             4.605146259204083}, {-1.0004395867668991`, 
             4.606238713410626}, {-0.8464631587029289, 
             4.607413266772856}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8228518526479885, 
             4.607593377061568}, {-0.809936302099433, 
             4.607691898656806}, {-0.618062598948401, 
             4.609505814942622}, {-0.3882573123831131, 
             4.611446136355136}, {-0.15731623232877084`, 4.612518798371713}, {
             0.07476064121462578, 4.612723800992353}, {0.1216079555859071, 
             4.612590687767126}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1452198532662907, 4.612523596282883}, {
             0.3079733082470767, 4.612061144217056}, {0.4929675027556467, 
             4.610905296924377}, {0.678036190904258, 4.609172739238361}, {
             0.8631793726929112, 4.606863471159006}, {1.048397048121606, 
             4.603977492686313}, {1.089643836823533, 4.60324660266442}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.113252123661439, 4.602828265581054}, {
             1.2334770764486764`, 4.600697888377396}, {1.418207316932456, 
             4.597207742789372}, {1.602587769572945, 4.59350705592224}, {
             1.7866184343701432`, 4.589595827776001}, {1.9702015592624744`, 
             4.5857188846745505`}, {2.057543506488861, 
             4.5840020722303185`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.081150939361386, 4.583538039359299}, {
             2.153239392188362, 4.582121052941788}, {2.3357319331478053`, 
             4.578802332577711}, {2.517679182140805, 4.575762723582321}, {
             2.6723378050057383`, 4.573515969833781}, {2.82659793670992, 
             4.5717196695676945`}, {2.980459577253352, 4.570373822784062}, {
             3.025527742402415, 4.570110868887096}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0491393335068397`, 4.569973105126936}, {
             3.1339227266360314`, 4.569478429482883}, {3.286987384857959, 
             4.569033489664158}, {3.439653551919137, 4.569039003327887}, {
             3.5919212278195625`, 4.569494970474071}, {3.7437904125592363`, 
             4.570401391102708}, {3.895249649266259, 4.571761271979734}, {
             3.9936003597126306`, 4.572944016086956}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.017210645519529, 4.573227948213946}, {
             4.046287481068731, 4.573577619871084}, {4.196903907966653, 
             4.575850434776756}, {4.347098929960023, 4.578579716696752}, {
             4.4968725470488415`, 4.581765465631071}, {4.646224759233111, 
             4.585407681579714}, {4.795155566512828, 4.589506364542681}, {
             4.943664968887994, 4.59406151451997}, {4.961431762412675, 
             4.594659030376076}}]}, 
           {Arrowheads[{{0.014237263776852142`, 1.}}], 
            ArrowBox[{{4.985030413587061, 4.595452677706971}, {
             5.091751256821065, 4.599041811329806}, {5.239412720774498, 
             4.6044159347904134`}, {5.3862892094685835`, 4.610153734446612}, {
             5.532020571623613, 4.616225059843222}, {5.656854249492381, 
             4.621699131374525}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.978216634721124}, \
{-5.6278706650580546`, -2.9764084909944057`}, {-5.489170650256728, \
-2.9678523831504173`}, {-5.346839290058683, -2.959150558269165}, \
{-5.203939697546897, -2.9504782277199997`}, {-5.060523189962445, \
-2.9418987724335155`}, {-4.916641084546405, -2.933475573340305}, \
{-4.744759614121419, -2.923780693439762}, {-4.7140429324713615`, \
-2.9221398025396645`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.690464558502594, -2.920880241375955}, \
{-4.5721811664834116`, -2.914561520369302}, {-4.398905741632382, \
-2.9058180541289245`}, {-4.22493333956833, -2.8975502947186302`}, \
{-4.050099395044409, -2.8899365222354527`}, {-3.874239342813769, \
-2.8831550167764255`}, {-3.746938685939396, -2.878873494915528}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7233400364313383`, -2.8780797980388804`}, \
{-3.6973531828764097`, -2.8772057783415494`}, {-3.519440915232334, \
-2.8720888069308237`}, {-3.3403000753121495`, -2.8681095645599957`}, \
{-3.1597281985464676`, -2.865573513244811}, {-2.9777252849352887`, \
-2.8644806529852698`}, {-2.7942913344786113`, -2.8648309837813724`}, \
{-2.7790148807089152`, -2.864975859346186}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755403949451829, -2.865199775645951}, \
{-2.6620681724561233`, -2.866084933524436}, {-2.528722709508451, \
-2.8683139846748618`}, {-2.394254945635593, -2.871518137232651}, \
{-2.25866488083755, -2.8756973911978023`}, {-2.121694054073233, \
-2.8808582523089834`}, {-1.983084004301557, -2.8870072263048603`}, \
{-1.8428347315225202`, -2.894144313185433}, {-1.81151592280113, \
-2.8959377748460216`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.78794254958884, -2.897287696595699}, \
{-1.7009462357361227`, -2.902269512950701}, {-1.5571447829475504`, \
-2.9110688725255427`}, {-1.4111566391619879`, -2.920228438834835}, \
{-1.2629818043794356`, -2.929748211878578}, {-1.1126202785998949`, \
-2.9396281916567712`}, {-0.9044513756913659, -2.9526145343468277`}, \
{-0.8452837305459292, -2.9558414386176306`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8217067755012119, -2.9571272862585047`}, \
{-0.692197290460509, -2.9641905166669495`}, {-0.4763208905162999, \
-2.9735275635481075`}, {-0.2572850434677151, -2.9797970999212717`}, \
{-0.03601371834217851, -2.9824782473765072`}, {
             0.12226944100475984`, -2.981462682424234}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.14588094800389187`, -2.9813111879817575`}, {
             0.186569115832885, -2.9810501275038788`}, {
             0.350931840128876, -2.977523949941481}, {
             0.5145514140800569, -2.972085469136965}, {
             0.6774278376864278, -2.9647346850903302`}, {
             0.839561110947989, -2.9554715978015773`}, {
             1.0352281544078734`, -2.94267961723814}, {
             1.0892520937311416`, -2.9389054757040873`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1128066776760575`, -2.9372599397676593`}, {
             1.2285233274559815`, -2.929175912212716}, {
             1.4194466300923128`, -2.9149604827253044`}, {
             1.607998062316868, -2.9000333287759053`}, {
             1.7423184374100815`, -2.889352215161551}, {
             1.8756993547920953`, -2.8792979744717706`}, {
             2.008140814462909, -2.869870606706564}, {
             2.054644390969366, -2.866758452678356}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0782036857050246`, -2.865181796439816}, {
             2.139642816422523, -2.8610701118659314`}, {
             2.2702053606709365`, -2.8528964899498725`}, {
             2.399828447208151, -2.8453497409583877`}, {
             2.528512076034165, -2.838429864891477}, {
             2.656256247148978, -2.83213686174914}, {
             2.7832948583649038`, -2.8264631768199155`}, {
             2.9098618074942526`, -2.8214012553923427`}, {
             3.0214327675251034`, -2.8174636903672874`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0450314832226444`, -2.8166738320798617`}, {
             3.1615807194932204`, -2.813112703042152}, {
             3.2867326823628398`, -2.809886072119533}, {
             3.411412983145882, -2.807271204698566}, {
             3.5356216218423477`, -2.805268100779251}, {
             3.6593585984522368`, -2.803876760361587}, {
             3.817970207254011, -2.8024827138153365`}, {
             3.975931694306248, -2.8018418440159065`}, {
             3.9893564072267087`, -2.801845489479789}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.012968399354119, -2.8018519012865064`}, {
             4.18864131198494, -2.8018996050446314`}, {
             4.40135092966363, -2.8019573660733568`}, {
             4.612077990703093, -2.8041402155892796`}, {
             4.822805051742556, -2.806323065105202}, {
             4.85067955658614, -2.8068410469161273`}, {
             4.878538541117929, -2.807372529054574}, {
             4.957396239942384, -2.8091205976602143`}}]}, 
           {Arrowheads[{{0.014316388418423616`, 1.}}], 
            ArrowBox[{{4.9810024336964265`, -2.809643885136456}, {
             5.063354107430784, -2.811469406012958}, {
             5.2471144114543256`, -2.8159844370922764`}, {
             5.407925713357206, -2.8200826619830233`}, {
             5.566744883546808, -2.824426051439678}, {
             5.656854249492381, -2.8270372942263506`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.9551421532276825`, 
             5.656854249492381}, {-4.8294568976495125`, 
             5.645088139674284}, {-4.697457345464431, 
             5.6329274239585105`}, {-4.566724914426599, 
             5.621081841872278}, {-4.436747239568273, 
             5.609607950879302}, {-4.307011955921712, 
             5.598562308443298}, {-4.1775190634869155`, 
             5.5879449145642655`}, {-4.048268562263884, 
             5.577755769242205}, {-4.014211059224763, 5.57522116124503}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.9906641839468215`, 
             5.5734687691709714`}, {-3.866172492100106, 
             5.564203919737525}, {-3.6804492682355847`, 
             5.551401408239285}, {-3.4910988906703193`, 
             5.539348234747484}, {-3.298121359404309, 
             5.528044399262122}, {-3.1747871053568204`, 
             5.521376215846182}, {-3.051043915874897, 
             5.51518857897523}, {-3.0480214232750455`, 
             5.5150496394420685`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.024434338125343, 
             5.513965375877782}, {-2.926891790958541, 
             5.509481488649266}, {-2.8023307306077494`, 
             5.504254944868291}, {-2.6773607348225235`, 
             5.499508947632304}, {-2.5519818036028643`, 
             5.495243496941305}, {-2.42619393694877, 
             5.491458592795295}, {-2.2999971348602424`, 
             5.488154235194274}, {-2.1074996523780913`, 
             5.4839384157133155`}, {-2.0804802164542235`, 
             5.4834720402689126`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0568717400679466`, 
             5.483064540508468}, {-1.913880934794428, 
             5.480596413470475}, {-1.719140982109253, 
             5.478128228465752}, {-1.5232797943225664`, 
             5.4765338606991465`}, {-1.326305179741199, 
             5.475594266722003}, {-1.1282249466719816`, 
             5.475090403085665}, {-1.1124383319473807`, 5.475085003133419}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0888263403307634`, 
             5.475076926441273}, {-0.9290390951149139, 
             5.4750222697901325`}, {-0.7287476250699951, 
             5.475389866835406}, {-0.5274817820912464, 
             5.475933361165447}, {-0.32537281173268795`, 
             5.476392919724217}, {-0.14434853342532672`, 
             5.476727958606696}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.1207365797085895, 5.476770952971061}, {
             0.0813745111238594, 5.477060229527947}, {0.264786119244512, 
             5.477181048985897}, {0.4483008550136049, 5.477095076933292}, {
             0.6319187184311378, 5.476802313370131}, {0.8156397094971113, 
             5.476302758296414}, {0.8237419008860218, 5.476271625519862}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.8473537195714822, 5.4761808967972465`}, {
             0.999463828211525, 5.47559641171214}, {1.183391074574379, 
             5.474683273617311}, {1.3674214485856733`, 5.473563344011926}, {
             1.5515549502454076`, 5.472236622895985}, {1.6377509768501353`, 
             5.471562187014809}, {1.7239084020609587`, 5.470879365415181}, {
             1.7918145361239939`, 5.470360506884185}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.81542583989296, 5.47018009716778}, {
             1.861380575126331, 5.469828965318728}, {1.9986968040443345`, 
             5.4688692981283475`}, {2.135857088814969, 5.468000363844041}, {
             2.272861429438234, 5.467222162465806}, {2.2910508625918578`, 
             5.467124811955267}, {2.3092367748269433`, 5.467030761764594}, {
             2.413763437898085, 5.466620444096871}, {2.518166241429816, 
             5.466325211535932}, {2.673516805802974, 5.466066580317494}, {
             2.759893941330386, 5.466124407935468}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.7835059290368958`, 5.466140215648891}, {
             2.8284985280829114`, 5.466170337217677}, {2.983111408269628, 
             5.466636482236482}, {3.1373554463631232`, 5.467465015373908}, {
             3.2912306423633977`, 5.468655936629956}, {3.444736996270451, 
             5.470209246004624}, {3.597874508084283, 5.472124943497915}, {
             3.727943801076376, 5.474064536121578}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.7515531302272853`, 5.474419002278245}, {
             3.903059560037458, 5.477078523435902}, {4.055140209387146, 
             5.48018644707168}, {4.206885125853957, 5.483726800017162}, {
             4.358294309437894, 5.487699582272348}, {4.5093677601389555`, 
             5.492104793837236}, {4.660105477957141, 5.496942434711829}, {
             4.695720672526672, 5.498190387490441}}]}, 
           {Arrowheads[{{0.019872281904950027`, 1.}}], 
            ArrowBox[{{4.719318183522117, 5.499017241864565}, {
             4.810507462892451, 5.502212504896125}, {4.960573714944886, 
             5.507915004390125}, {5.167263222515431, 5.516424374651125}, {
             5.340498914244497, 5.52424932655648}, {5.513105247910882, 
             5.532620909379625}, {5.656854249492381, 5.540080180306851}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.958182757239445, -5.656854249492381}, \
{-4.830590333763012, -5.644908549605547}, {-4.698463660400145, \
-5.632734776567112}, {-4.56759594852281, -5.620875313400653}, \
{-4.437482077471199, -5.609387712037328}, {-4.307616926585502, \
-5.598329524408297}, {-4.178000495865717, -5.58770075051356}, \
{-4.048632785311846, -5.577501390353118}, {-4.0172562902790965`, \
-5.575166160514192}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.993709423126492, -5.573413659263475}, \
{-3.8664161628322375`, -5.563939719633729}, {-3.6805732926702315`, \
-5.551128735504686}, {-3.4911041748258294`, -5.539068437965988}, \
{-3.2980088092990285`, -5.527758827017636}, {-3.174676171806056, \
-5.521091666120583}, {-3.0510716381560234`, -5.514911890816111}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.027484571439353, -5.513827250404362}, \
{-2.926784017103247, -5.509198943043523}, {-2.8022244998934105`, \
-5.503973380863514}, {-2.6772560227779523`, -5.499228351589188}, \
{-2.551878585756873, -5.494963855220544}, {-2.4260921888301725`, \
-5.491179891757581}, {-2.29989683199785, -5.487876461200301}, \
{-2.1073580265613763`, -5.48366112080607}, {-2.0835330924974005`, \
-5.4832500644457784`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.059924613040507, -5.482842742620186}, \
{-1.9136973952963374`, -5.480319855138522}, {-1.7189149382027331`, \
-5.477852664197659}, {-1.5230106552805633`, -5.47625954798348}, \
{-1.325992407401227, -5.475321230186243}, {-1.1278680554361225`, \
-5.474818434496207}, {-1.1154916307131384`, -5.474814255383985}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            
            ArrowBox[{{-1.091879639061278, -5.474806282389757}, \
{-0.9286375993852504, -5.474751160913372}, {-0.7283010392486091, \
-5.4751194094377365`}, {-0.5269898293706873, -5.475663232378539}, \
{-0.3248354240959717, -5.476122682045013}, {-0.14740182642283048`, \
-5.476450524115267}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.12378987372988534`, -5.476494151655682}, \
{-0.12183782342446248`, -5.476497758437159}, {
             0.08200297264384038, -5.476788461554977}, {
             0.2655323927925267, -5.476908231310272}, {
             0.449164633839865, -5.476821082386695}, {
             0.6328996957858551, -5.476527014784247}, {
             0.8167375786304971, -5.476026028502926}, {
             0.8206886285888565, -5.476010822690365}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8443004467261919, -5.475919951432191}, {
             1.0006782823737912`, -5.475318123542735}, {
             1.1847218070157375`, -5.474403299903672}, {
             1.3688681525563355`, -5.473281557585738}, {
             1.5531173189955854`, -5.471952896588931}, {
             1.6393662390761534`, -5.471277550957389}, {
             1.7255764614458107`, -5.470593861430924}, {
             1.7887613271537595`, -5.470110909767662}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.8123726304444336`, -5.469930437465186}, {
             1.8630559161449651`, -5.469543041261136}, {
             2.000379084128291, -5.468583589533824}, {
             2.1375459653957893`, -5.4677155062489895`}, {
             2.274556559947459, -5.466938791406632}, {
             2.292747074874287, -5.466841679120176}, {
             2.3109340664809146`, -5.466747869122798}, {
             2.4155142050490417`, -5.466338878142005}, {
             2.519970282095075, -5.466045144068311}, {
             2.6754699418355257`, -5.465789034429017}, {
             2.7568406254326416`, -5.465845297789046}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.7804526127862097`, -5.465861624181879}, {
             2.830596362719987, -5.4658962958318025`}, {
             2.985349544748459, -5.466366928276668}, {
             3.1397294879209428`, -5.467200931763613}, {
             3.293736192237437, -5.468398306292639}, {
             3.4473696576979425`, -5.469959051863745}, {
             3.6006298843024593`, -5.471883168476931}, {
             3.724890784706201, -5.473742354009276}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.7485001352576193`, -5.474095595960932}, {
             3.753516872050987, -5.474170656132197}, {
             3.9060507261640063`, -5.476856457859764}, {
             4.058251551862001, -5.4799755166898505`}, {
             4.2101193491449695`, -5.483527832622458}, {
             4.361654118012913, -5.487513405657585}, {
             4.512855858465831, -5.491932235795232}, {
             4.663724570503723, -5.496784323035399}, {
             4.692669354943834, -5.497800581433468}}]}, 
           {Arrowheads[{{0.019936936784483113`, 1.}}], 
            ArrowBox[{{4.716266807787781, -5.498629093722974}, {
             4.814260254126589, -5.502069667378087}, {
             4.964462909334429, -5.507788268823295}, {
             5.171381656931107, -5.516322752798733}, {
             5.344854162521742, -5.5241721730321425`}, {
             5.517694752223928, -5.532569523843216}, {
             5.656854249492381, -5.539799367360184}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.012328239334775254`, 1.}}], 
            ArrowBox[{{-1.5921342865355423`, -0.23817153971830932`}, \
{-1.5110048043987363`, -0.26093905244432236`}, {-1.4338529943926979`, \
-0.29204525436063633`}, {-1.3595810716609529`, -0.3347013245485386}, \
{-1.3373118270203652`, -0.3497371773586318}, {-1.3151443400005918`, \
-0.3663088111394535}, {-1.2942622073410204`, -0.3851627126359716}, \
{-1.273156204462313, -0.405920825181714}, {-1.230140351365889, \
-0.45177001828455876`}, {-1.1839237881037645`, -0.506275710577303}, \
{-1.1318614368640207`, -0.5702391396346}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.878168931446309}, \
{-5.5569492267003495`, -3.870639898788054}, {-5.395189882117096, \
-3.858561896290314}, {-5.373094357741461, -3.8569297154097084`}, \
{-5.350950695050698, -3.8552965540477913`}, {-5.149316682691137, \
-3.84071001284448}, {-4.946828779367509, -3.826412496838927}, \
{-4.788686695400094, -3.8155288644568617`}, {-4.714790816108017, \
-3.810705884207193}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.691228954340736, -3.809168066469077}, \
{-4.629948621682561, -3.8051684681567637`}, {-4.470614558214908, \
-3.795331307938633}, {-4.310684504997137, -3.7860173838024695`}, \
{-4.150158462029247, -3.777226695748274}, {-3.989036429311238, \
-3.7689592437760453`}, {-3.8273184068431103`, -3.7612150278857843`}, \
{-3.7481700663878197`, -3.757693898930392}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7245814046833146`, -3.756644493228783}, \
{-3.665004394624864, -3.753994048077491}, {-3.5018533615077745`, \
-3.747544769120292}, {-3.3376242763431145`, -3.7421156557833144`}, \
{-3.1723171391308864`, -3.7377067080665585`}, {-3.0059319498710897`, \
-3.7343179259700237`}, {-2.838468708563723, -3.731949309493711}, \
{-2.7804896417802145`, -3.731485435503644}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.756878404464811, -3.731296528722774}, \
{-2.669927415208788, -3.7306008586376196`}, {-2.5003080698062843`, \
-3.7302725734017494`}, {-2.329610672356211, -3.7309644537861013`}, \
{-2.195839823270442, -3.7321132474700383`}, {-2.060980972627709, \
-3.733689304849689}, {-1.9250341204280104`, -3.735692625925054}, \
{-1.8124497970290245`, -3.737689532072753}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7888415173277974`, -3.738108271711174}, \
{-1.787999266671347, -3.738123210696132}, {-1.649876411357718, \
-3.740981059162924}, {-1.510665554487124, -3.74426617132543}, \
{-1.3703666960595644`, -3.7479785471836498`}, {-1.22897983607504, \
-3.7521181867375835`}, {-0.9923400356851864, -3.758766969988697}, \
{-0.8446725090220066, -3.762168820986266}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8210667791392493, -3.762712631650429}, \
{-0.7528838972013091, -3.764283376486339}, {-0.5106114206234074, \
-3.768667406230509}, {-0.26552260595148025`, -3.771919059221208}, \
{-0.10852627114004981`, -3.773138688297751}, {
             0.0489104244934207, -3.7733815757970497`}, {
             0.12332789025102592`, -3.7730356638454166`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14693962816865075`, -3.772925910278006}, {
             0.20678748094893062`, -3.7726477217191037`}, {
             0.36510489822648, -3.770937126063914}, {
             0.5235257797694918, -3.768334332415272}, {
             0.6817132290213885, -3.76492388435697}, {
             0.8396672459821702, -3.760705781889008}, {
             0.9973878306518362, -3.7556800250113858`}, {
             1.0911434704282248`, -3.7520181038112637`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1147374735040763`, -3.7510965658614905`}, {
             1.155124063070708, -3.7495191406645914`}, {
             1.3114644896769718`, -3.7440788095191957`}, {
             1.4673722199598649`, -3.7380928024117503`}, {
             1.622747621903261, -3.7316921085660604`}, {
             1.8234716825600503`, -3.72309803647379}, {
             2.0231651784343723`, -3.7146045921065434`}, {
             2.0584519751234382`, -3.7131809917904}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0820447759294747`, -3.7122291706607538`}, {
             2.2216941144889084`, -3.706595198150462}, {
             2.4189244956863423`, -3.699453277291686}, {
             2.6149478088075475`, -3.693250059104191}, {
             2.8099843873866446`, -3.6878783770978565`}, {
             3.004093506516195, -3.6834540598626813`}, {
             3.02605580552463, -3.6830720600156384`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0496642276455184`, -3.682661428431229}, {
             3.197334441288758, -3.680092935988664}, {
             3.3897384023126302`, -3.677781580046536}, {
             3.5813205633479592`, -3.6764327071674465`}, {
             3.7721161442150803`, -3.676051356782022}, {
             3.9621603647343306`, -3.6766425683208888`}, {
             3.9941006808815085`, -3.6768951972549457`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.017711935346263, -3.677081948257024}, {
             4.151456804166623, -3.6781397907495648`}, {
             4.3399909614532, -3.680435564196363}, {
             4.527770935934896, -3.6834735648361026`}, {
             4.714804826952543, -3.6871974688436024`}, {
             4.894257004713249, -3.6913834760785176`}, {
             4.9620393170286565`, -3.693176827473354}}]}, 
           {Arrowheads[{{0.01422058727034602, 1.}}], 
            ArrowBox[{{4.985643050165453, -3.6938013235446485`}, {
             5.072922561204843, -3.696110522324041}, {
             5.25079671166971, -3.701341568270945}, {
             5.427917107414878, -3.7070493591357505`}, {
             5.601694854558032, -3.713083768271052}, {
             5.656854249492381, -3.7151176587314674`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.878261285035258}, {-5.554717426428447, 
             3.870564823146144}, {-5.3926736578900645`, 
             3.8584670662813974`}, {-5.370572056564709, 
             3.856834697153886}, {-5.348424740826674, 
             3.8552015336232364`}, {-5.1468757786509585`, 
             3.8406245389416536`}, {-4.944472912741665, 
             3.8263373602482926`}, {-4.786162483185791, 
             3.815446518991645}, {-4.714791312535989, 3.810791175909697}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.691229389502203, 
             3.8092542971616807`}, {-4.627254308860896, 
             3.8050813804732053`}, {-4.467748389766981, 
             3.7952419446929735`}, {-4.307644725904044, 
             3.7859282116509503`}, {-4.146943317272088, 
             3.777140181347135}, {-3.985644163871111, 
             3.7688778537815275`}, {-3.8237472657011136`, 
             3.7611412289541284`}, {-3.7481702029059916`, 
             3.7577873933956845`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.724581424727413, 
             3.7567406090922244`}, {-3.6612526227620954`, 
             3.7539303068649374`}, {-3.4979177572795974`, 
             3.7474939476689895`}, {-3.3335001914791595`, 
             3.7420810115213192`}, {-3.1679999253607822`, 
             3.7376914984219267`}, {-3.001416958924466, 
             3.734325408370812}, {-2.8337512921702106`, 
             3.731982741367975}, {-2.7804900725308572`, 3.731566354867526}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75687880106192, 
             3.731381766253809}, {-2.6650029250980154`, 
             3.7306634974134156`}, {-2.4951718577078803`, 
             3.730367676507134}, {-2.324258089999806, 
             3.7310952786491303`}, {-2.19045030094152, 
             3.7322701574847397`}, {-2.0555533318594286`, 
             3.7338682851089446`}, {-1.919567182753532, 
             3.7358896615217456`}, {-1.8124503750783079`, 
             3.7378000012539094`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7888421361734628`, 
             3.7382210346824176`}, {-1.782491853623831, 
             3.7383342867231413`}, {-1.644327344470325, 
             3.741202160713133}, {-1.505073655293013, 
             3.74449328349172}, {-1.3647307860918971`, 
             3.748207655058903}, {-1.223298736866976, 
             3.752345275414681}, {-0.9865428569663761, 
             3.758982762187886}, {-0.8446720423659277, 
             3.7622358429724634`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8210662542710913, 
             3.7627771208658225`}, {-0.7469756597659603, 
             3.7644760093227707`}, {-0.5045971452657297, 
             3.768825016819334}, {-0.25940731346568263`, 
             3.772029784677576}, {-0.1030094437184157, 3.773212095503018}, {
             0.05381939070928393, 3.7734242285051436`}, {0.12332861346123174`,
              3.773089170806794}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14694033214428798`, 3.772975354426711}, {
             0.21107918981741822`, 3.772666183683953}, {0.3687699536059863, 
             3.7709379610394467`}, {0.5265592106250496, 3.768324828814318}, {
             0.684114489424671, 3.7649120552512594`}, {0.8414357900048501, 
             3.7606996403502726`}, {0.9985231123655868, 3.755687584111356}, {
             1.0911567483638216`, 3.752404182236519}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1147539228589516`, 3.751567779712282}, {
             1.1551800809336856`, 3.7501348733842006`}, {1.3112103201359449`, 
             3.7443004950184964`}, {1.4666138299723674`, 3.738184449014243}, {
             1.621390610442953, 3.731786735371441}, {1.8219540631339828`, 
             3.723513923815223}, {2.021337011772304, 3.7157254510797575`}, {
             2.058498906525301, 3.7143559651666656`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0820948825660044`, 3.713486408944945}, {
             2.2195394563579143`, 3.708421317165045}, {2.4165613968908124`, 
             3.701601522071085}, {2.6125274000678362`, 3.695496793985838}, {
             2.8075620325858237`, 3.6903378610972637`}, {3.0016652944447713`, 
             3.6861247234053627`}, {3.02615080492253, 3.6857105712820677`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0497594210769794`, 3.685311251099738}, {
             3.194837185644682, 3.682857380910135}, {3.3871502731557848`, 
             3.680546032605382}, {3.578677123948307, 3.6792008774849077`}, {
             3.769417738022251, 3.678821915548711}, {3.959372115377618, 
             3.679409146796793}, {3.994197652590113, 3.679651074616268}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.017809075866195, 3.679815099656658}, {
             4.092107618498631, 3.6803312405649686`}, {4.224461805839951, 
             3.6815964285387466`}, {4.356434677401572, 3.6832047107181274`}, {
             4.488026233183497, 3.6851560871031106`}, {4.619236473185726, 
             3.6874505576936967`}, {4.7500653974082585`, 
             3.6900881224898856`}, {4.880513005851096, 3.693068781491677}, {
             4.962149344878091, 3.6951549410809537`}}]}, 
           {Arrowheads[{{0.014218302458871183`, 1.}}], 
            ArrowBox[{{4.985753632070851, 3.6957581321434403`}, {
             5.010579298514236, 3.696392534699071}, {5.140253031580597, 
             3.700018934283922}, {5.269522961233095, 3.703907532418082}, {
             5.3982107050135735`, 3.708038938538484}, {5.526137880463879, 
             3.712393762082059}, {5.656854249492381, 3.7171533159581442`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.9788073220938998`}, {-5.627844286202091, 
             2.9769972109546443`}, {-5.489132572308218, 
             2.968438820258621}, {-5.346791979760689, 
             2.9597348066704403`}, {-5.203883767459407, 
             2.9510602948241265`}, {-5.060459312741586, 
             2.942478900635561}, {-4.916569992944442, 
             2.9340542400206275`}, {-4.744668501844749, 
             2.924357277588009}, {-4.714043492790448, 2.9227211253322416`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.690465125323254, 
             2.9214614424681367`}, {-4.57206979343168, 
             2.9151361287677133`}, {-4.398773867705237, 
             2.90639079355974}, {-4.224780724665419, 
             2.8981212719640888`}, {-4.049925736663174, 
             2.890505906837237}, {-3.874044276049451, 
             2.883723041035661}, {-3.746939558126393, 2.8794478248894966`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7233409103918613`, 
             2.878654075283102}, {-3.6971363428242476`, 
             2.877772674559361}, {-3.519201936987564, 
             2.872654807408337}, {-3.3400386361171583`, 
             2.8686750261562546`}, {-3.1594440177907863`, 
             2.8661389173767793`}, {-2.9774180820084473`, 
             2.865046481069911}, {-2.793960828770142, 
             2.8653977172356497`}, {-2.7790158856510088`, 
             2.865539500840368}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7554049551723443`, 
             2.865763499206058}, {-2.661763198211711, 
             2.86665188437743}, {-2.5284437272691727`, 
             2.8688804390406575`}, {-2.394002415942527, 
             2.872083381225332}, {-2.258439264231776, 
             2.8762607109314544`}, {-2.1214960765767725`, 
             2.881418951552951}, {-1.982914657417371, 
             2.8875646264837496`}, {-1.8426950067535723`, 
             2.8946977357238497`}, {-1.811516245987805, 
             2.8964825395059517`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7879428452443915`, 
             2.897831980400025}, {-1.7008371245853777`, 
             2.9028182792732515`}, {-1.5570677201004, 
             2.9116123624495756`}, {-1.411113502486253, 
             2.9207660905704413`}, {-1.2629744717429372`, 
             2.93027946363585}, {-1.112650627870454, 
             2.9401524816458}, {-0.9043396015708217, 
             2.9531408776678716`}, {-0.8452824020338828, 
             2.9563596218278536`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8217054006225203, 
             2.957644619020368}, {-0.6919396923571501, 
             2.9647171287045406`}, {-0.4759149977938691, 
             2.9740514690621813`}, {-0.25672961544540834`, 
             2.9803141330471674`}, {-0.03530944334344255, 
             2.9829843799708753`}, {0.12227129743074724`, 
             2.981963521027013}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1458827949623479, 2.9818105581185086`}, {
             0.18741962048035382`, 2.981541469144682}, {0.35201882072708723`, 
             2.9779995501073344`}, {0.5158709468931268, 
             2.9725426650926146`}, {0.6789759989784716, 
             2.9651708141005226`}, {0.8413339769831217, 
             2.9558839971310586`}, {1.0371400904926882`, 
             2.9430720256906104`}, {1.0892549663731144`, 
             2.939429642526763}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.112809499723188, 2.9377833825240827`}, {
             1.230571605898182, 2.929552820604389}, {1.4216285231996026`, 
             2.9153263818723936`}, {1.6103108423969497`, 
             2.9003927094946245`}, {1.7448397386550747`, 
             2.8897007753742034`}, {1.8784279203068914`, 2.879639132423302}, {
             2.0110753873524, 2.87020778064192}, {2.054648329226726, 
             2.8672960992332537`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0782077804052967`, 2.8657217823970647`}, {
             2.1427821397916, 2.8614067200300584`}, {2.273548177624492, 
             2.853235950587716}, {2.4033735008510764`, 2.8456954723148926`}, {
             2.532258109471352, 2.8387852852115896`}, {2.6602020034853204`, 
             2.832505389277806}, {2.7874394484753906`, 2.8268468443332324`}, {
             2.9142047100239736`, 2.821800710197559}, {3.0214383103712157`, 
             2.8180361007478614`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0450364690634313`, 2.8172291423712097`}, {
             3.166318682796678, 2.813545674352914}, {3.2916673940207994`, 
             2.810336772643942}, {3.4165439218034335`, 2.8077402817438704`}, {
             3.5409482661445804`, 2.8057562016526996`}, {3.664880427044239, 
             2.804384532370429}, {3.823678956567273, 2.8030167112409385`}, {
             3.9818271808534913`, 2.802401389129171}, {3.9893617090470284`, 
             2.802404625802643}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.012973699866344, 2.8024147690129877`}, {
             4.194491500361244, 2.802492745209311}, {4.407155819868997, 
             2.8025841012894515`}, {4.617841104158038, 2.804793181144294}, {
             4.82852638844708, 2.8070022609991363`}, {4.856396396997208, 
             2.8075230704923886`}, {4.884250898041165, 2.8080573393087915`}, {
             4.957402122866427, 2.8096851520017228`}}]}, 
           {Arrowheads[{{0.014316270733318802`, 1.}}], 
            ArrowBox[{{4.981008271906855, 2.8102104526939673`}, {
             5.069245295357403, 2.8121739652271116`}, {5.25318261255097, 
             2.816708296931948}, {5.414206964765772, 2.8208245326721744`}, {
             5.573099870032914, 2.8251817112520285`}, {5.656854249492381, 
             2.827614798490605}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.012065204289892039`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.599014041264198}, \
{-5.576163892354409, -5.591439452336284}, {-5.447942059264503, \
-5.5793184329369385`}, {-5.322482775729196, -5.567372198614759}, \
{-5.305791521553528, -5.565776920415017}, {-5.289095950120364, \
-5.564182999122048}, {-5.089611110750235, -5.545445485142774}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.012128856159671346`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.600110842094292}, {-5.573035446197524, 
             5.592242725613584}, {-5.444826670199972, 
             5.580123314388638}, {-5.3193856748749315`, 
             5.568179332280204}, {-5.3026972732908515`, 
             5.566584404249411}, {-5.28600455590955, 
             5.5649908376768655`}, {-5.08661810982341, 
             5.54626413881046}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.43341967618822, 
             0.22918288901607514`}, {-2.3280974809909663`, 
             0.2321461219794317}, {-2.2355572663239704`, 
             0.23537901174208098`}, {-2.1434335273513274`, 
             0.2394482222979795}, {-1.9851343052460348`, 
             0.2491876606976387}, {-1.830392526713185, 
             0.2640656306261351}, {-1.6815703802189146`, 
             0.28712932016499076`}, {-1.5900285074418488`, 
             0.30928287932344567`}, {-1.5015016114960302`, 
             0.3394340638764202}, {-1.4997466739353629`, 
             0.3402796380901454}}]}, 
           {Arrowheads[{{0.004050958905754937, 1.}}], 
            ArrowBox[{{-1.478475092541209, 
             0.3505288350503}, {-1.4154349549745264`, 
             0.3809032004697765}, {-1.390441165973434, 
             0.39504862088603276`}, {-1.3655465403883318`, 
             0.4106185129040397}, {-1.3409029997673065`, 
             0.4293237473389508}, {-1.316072382750946, 
             0.44999080470007496`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.004475566169560289, 1.}}], 
            ArrowBox[{{1.2624419505957, 0.4041504472997973}, {
             1.2805996475254051`, 0.37902728984746226`}, {1.2982736095930612`,
              0.3561289379615704}, {1.3167951874695871`, 
             0.33559928873037753`}, {1.335262950896428, 
             0.31690889075074036`}, {1.3723333952193881`, 
             0.2827626408696498}, {1.4099991193165684`, 
             0.25447546734888354`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.2586411765401959}, \
{-5.569671291160823, -0.2581252486592902}, {-5.42698886590155, \
-0.2572940125995683}, {-5.283329619931076, -0.2564701203318072}, \
{-5.138693553249403, -0.25565357185600696`}, {-4.993080665856527, \
-0.2548443671721675}, {-4.846490957752452, -0.25404250628028896`}, \
{-4.712389530101203, -0.25332048701042004`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688777869495138, -0.25319521861810235`}, \
{-4.574160212079435, -0.2525991113107617}, {-4.448770626797409, \
-0.25198200981030566`}, {-4.322755673091098, -0.25139668467900317`}, \
{-4.196115350960504, -0.25084313591685414`}, {-4.068803080149942, \
-0.2503415160141174}, {-3.9407722804037295`, -0.24991197746105173`}, \
{-3.8120229517218673`, -0.249554520257657}, {-3.744306156837689, \
-0.2494052574328361}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.720694221200043, -0.24935321149329046`}, \
{-3.6825550941043543`, -0.24926914440393333`}, {-3.552347974565728, \
-0.24910522907473867`}, {-3.4213808601205247`, -0.24911215344493112`}, \
{-3.289653750768744, -0.24928991751451066`}, {-3.1571666465103863`, \
-0.2496385212834773}, {-3.0343504051775008`, -0.2501643986933004}, \
{-2.9109534364848066`, -0.25097510904301856`}, {-2.7762268794010883`, \
-0.2524262182173254}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752616255892338, -0.25268052288543447`}, \
{-2.7068770152701873`, -0.253173169867064}, {-2.501904897449756, \
-0.2569101922297031}, {-2.3129197408360644`, -0.2624765576089954}, \
{-2.125021992149366, -0.2713376321264158}, {-1.939976667650535, \
-0.28567246180917794`}, {-1.9098903024227618`, -0.288593093431604}, \
{-1.8799553687284591`, -0.2917662519163617}, {-1.8128285259517252`, \
-0.3013817813581107}, {-1.810056541301193, -0.3018763652609123}}]}, 
           {Arrowheads[{{0.0008594735009478894, 1.}}], 
            ArrowBox[{{-1.7868116446765874`, -0.30602377339703224`}, \
{-1.746854899314344, -0.3131529481782538}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0042102147869976115`, 1.}}], 
            ArrowBox[{{0.34302344978445587`, 1.0166340097911681`}, {
             0.38955815539865385`, 0.9991905826322882}, {0.43459478307844424`,
              0.979638389379806}, {0.4782291735848099, 0.9551010955930029}, {
             0.5203400333203937, 0.9282027348097379}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(tot\\)]\\)}\"", 
           TraditionalForm]}}], {194.4, -192.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAANhrmd6+867+I0W+LoFXQv8NWnHmg
1eu/2vL7WnWG0L/gaDcSi/Drv8KtD9DSu9C/7gyVIrcK7L9RSOWsYfDQv9U0
dHiFNey/h2UsetZH0b9f+eVi5VHsv4bP42bVgtG/M+Jv+ah87L/eRoyrd93R
v/JUQiHSnuy/FsjTPDMn0r8TuLDAXc3sv1PNUUPQjdK/TwLYSggS7b9fCU5t
OSrTv1ACfCrDPu2/BuMrxP6S079NsWa18Hftv9Id6nq0HNS//UTKGUvH7b8k
Y2im4uPUv6NGDnXcBO6/+DQ15OaE1b+Kny3jZlTuv/+RaU+eXda/KC3rcHCp
7r/lnrTtGE3Xv2+BCQBZQ++/RZLlZd4P2b+B2Nd/ksrvvwiNAAvyrtq/3Fcs
D7Ig8L9SKoQM/incv3csmPMD3vC//KkqnVWU4L9na5SyrZ3xvzQ09WrOUeO/
6xgzFcpq8r+rMLuTJ2bmv0c1YWqzL/O/VIelMWVj6b/Dbz2m8Ab0vxLmT9iZ
luy/XDuGbqEA9b8JnFmawxLwv7Ji1nLWj/W/bgYJPIAJ8b+9lvAm
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3594693633937804`, -1.085241086706145}, \
{-1.381575511148055, -1.123328592145586}, {-1.4645831198171815`, \
-1.2569073264912305`}, {-1.5585088640628288`, -1.396310530211136}, \
{-1.6700435312285005`, -1.5488760377184838`}, {-1.803078580707085, \
-1.7182726599300675`}, {-1.9124164088665074`, -1.8493603070916733`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.927540447041856, -1.8674928657254337`}, \
{-1.960162461888512, -1.9066041526780508`}, {-2.057682878479855, \
-2.0190877361103947`}, {-2.146308753868348, -2.1191700184370834`}, \
{-2.3032692397346914`, -2.292188873767551}, {-2.3738818298561206`, \
-2.368625498617369}, {-2.440463412164672, -2.4400882606264997`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.516709488909639, \
-2.5210020776812168`}, {-2.5610860505357795`, -2.567777523068338}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.5773372234792036`, -2.584907192980484}, \
{-2.58385935342803, -2.591781892642869}, {-2.7119639591961513`, \
-2.726166150690334}, {-2.8289727899136685`, -2.847812303111574}, \
{-2.9370782384607153`, -2.9594223874618786`}, {-3.053068310575967, \
-3.078518574327468}, {-3.1609679423797257`, -3.188739789704611}, \
{-3.2343677638322745`, -3.263381854025672}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2509232809021564`, -3.280217562145172}, \
{-3.261936921107091, -3.2914176008416858`}, {-3.357135033993161, \
-3.387883574987071}, {-3.447260709667671, -3.4789202732577156`}, \
{-3.5330123767603547`, -3.5653102567705686`}, {-3.669980700367522, \
-3.7028998048602095`}, {-3.7976509045294513`, -3.8307323237552824`}, \
{-3.9169695493574572`, -3.9498580410182527`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.9336983446069675`, -3.966521582271487}, \
{-4.030291869717813, -4.062733581265599}, {-4.137355386507321, \
-4.169149154738376}, {-4.239306295377739, -4.2703013687316504`}, \
{-4.405824613966009, -4.435182685455514}, {-4.560964226465749, \
-4.5884400618385985`}, {-4.604521697874504, -4.63137933099143}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.621336798461991, -4.647955778305883}, \
{-4.706319608037208, -4.731732444298955}, {-4.843485233840635, \
-4.866718779254635}, {-4.973435039864566, -4.994403480122457}, \
{-5.097142962097537, -5.11579096031924}, {-5.198995157168599, \
-5.215619872762662}, {-5.295149465352229, -5.309784616294929}}]}, 
           {Arrowheads[{{0.010077908186216698`, 1.}}], 
            ArrowBox[{{-5.312025769056038, -5.326298748832465}, \
{-5.392327397523664, -5.4048676245029705`}, {-5.483807442807667, \
-5.494286463799857}, {-5.6176130564023525`, -5.619943865614034}, \
{-5.656854249492381, -5.654203652081553}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.885471864971056, -0.7055004633194174}, \
{-0.8765521801184906, -0.7919077586003404}, {-0.8552537481018284, \
-0.8942978838646549}, {-0.8231132363664748, -0.990450982819371}, \
{-0.7735247514222369, -1.0942553187339523`}, {-0.6898032340288637, \
-1.2160978366210429`}, {-0.6065626179250004, -1.3006518286465567`}, \
{-0.5245862288337364, -1.3619876476868409`}, {-0.4573031512560166, \
-1.4001166959463263`}, {-0.39037104005432766`, -1.4300637936599572`}, \
{-0.3742313766747761, -1.435643795489534}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3519154653303945, -1.4433591253078801`}, \
{-0.3237175508340304, -1.4531080531993574`}, {-0.1275783506398066, \
-1.4918686784604374`}, {0.06841115724024303, -1.4988104089799565`}, {
             0.2602302598551996, -1.4872459629291215`}, {
             0.4171969235159682, -1.4732374457973247`}, {
             0.5628391366948136, -1.4617520137035722`}, {
             0.5855630245294612, -1.4607270902310374`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.6091510370263256, -1.4596631918411846`}, {
             0.6954918344219894, -1.455768932613534}, {
             0.8134899517277513, -1.4582674684928798`}, {
             1.0127702221399506`, -1.4851619083773315`}, {
             1.2056074766636433`, -1.5450917285531847`}, {
             1.3947636742199359`, -1.6375794806148747`}, {
             1.5017945358430018`, -1.7049107766213936`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.521780704088453, -1.7174837353901433`}, {
             1.5951233255114776`, -1.763622332034529}, {
             1.7441799311486164`, -1.8692171662383212`}, {
             1.8745498938983314`, -1.9676900441629737`}, {
             1.990219665323656, -2.0595285690288394`}, {
             2.0951756969876234`, -2.1452203440562716`}, {
             2.2701019361020993`, -2.292376442378979}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.288101498273966, -2.3076580377873293`}, {
             2.3631596495744254`, -2.3721451809012795`}, {
             2.441002563487892, -2.4396458013472646`}, {
             2.446513457451672, -2.4444459204077544`}, {
             2.52670258207977, -2.514819865921259}, {
             2.6025984391122403`, -2.581822315175941}, {
             2.747116450876967, -2.709960613235145}, {
             2.878608999738186, -2.827472225609708}, {
             2.9959407920375125`, -2.932926795931571}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0134765840853257`, -2.948738874149451}, {
             3.1304047721950945`, -3.054265739432404}, {
             3.2515540092669397`, -3.1640030720547094`}, {
             3.364517015922183, -3.266637329971558}, {
             3.470699666198815, -3.363321244697131}, {
             3.5709439338238003`, -3.4547661569706793`}, {
             3.666091792524104, -3.541683407531453}, {
             3.7123728344946723`, -3.5840197358308212`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.729794997100843, -3.5999569395836857`}, {
             3.8150078324311805`, -3.6779067526877074`}, {
             3.953546004081849, -3.8048151951376075`}, {
             4.083170620273118, -3.9236948111505408`}, {
             4.205345993801998, -4.035831676995898}, {
             4.320966023741561, -4.1420210885969535`}, {
             4.4258286315513455`, -4.238375819099287}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.443212783233522, -4.254354476055779}, {
             4.608616010128726, -4.406404490498679}, {
             4.773983897734819, -4.558484216153545}, {
             4.928763817720134, -4.700869022474879}, {
             5.074691315821651, -4.835130413095983}, {
             5.138372089541632, -4.893725616056069}}]}, 
           {Arrowheads[{{0.014419887957305831`, 1.}}], 
            ArrowBox[{{5.155747678599449, -4.909713583976666}, {
             5.212825923060759, -4.962233538170729}, {
             5.344227170458849, -5.0831435478529885`}, {
             5.45166316542611, -5.182001878016279}, {
             5.55537339316101, -5.277429968293118}, {
             5.655357853663548, -5.369427818683506}, {
             5.656854249492381, -5.3708046522808175`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAmJuSD3hw6r9ZiEPkEVjXP07tVU1G
f+q/SvnBk1WU1z/TsNGer47qvw1/EadX1Nc/dNIM/uWg6r9wVo3jwiHYP2vR
9Fxhruq/JQ6nXF5c2D917N1gccPqv3cDXld9utg/oQWBWDPY6r+K4AtOHhrZ
PxHjoz5f9uq/tSecrz+r2T/sK1Oo+yTrv6p4XV6Kndo/Pz/owglB678wz+4o
oTnbP6GerCAjY+u/eC+feCkF3D/ag91vFIzrv8EaeimCEt0/SxMuIWCn67/l
Tv0bU9jdP/oieWIcxuu/7M7NDe7S3j/9pt8ooerrvyz7m1oNHOA/XhKnM24e
7L+9mb1PPFjhP4NbTeUQQOy/annarT174j9/ApwfG1Psv9r3mP/Ci+M/sz1t
kRZM7L+CeYh32B/nP8eAbGaj9uu/6qcNTkzY6T93j6ClReDqv6//lwkjTO4/
4pPoQrc86r+EWiAWFv3vP2SLxQ7ck+m/wSHjTMO68D9+nQhdKunovzFB6ty3
X/E/9KwR2dAz5r+xSk/wR2PzP+Da5marMuW/U7U5g5nn8z9sSuSp
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6459804419352002, 
             1.2609770408765173`}, {-0.6096117778988599, 
             1.298405173847058}, {-0.5267835961813374, 
             1.3610098784672333`}, {-0.4603315253978888, 
             1.3990173436120805`}, {-0.39421482760209403`, 
             1.4289595202700969`}, {-0.3283969099994727, 
             1.4521287057500654`}, {-0.13086164404729222`, 
             1.4920896475761938`}, {0.06649795450292943, 
             1.4994104478716181`}, {0.23671666743570074`, 
             1.4892294240704014`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.2602852598800611, 1.4878024924156623`}, {
             0.41647729336067174`, 1.4738947800763935`}, {0.561966979933451, 
             1.4624366763334697`}, {0.694513378705137, 1.4564577980003008`}, {
             0.8124660373754178, 1.4589351833732787`}, {1.0117231652440655`, 
             1.4857637564947332`}, {1.1931916645423215`, 
             1.5421082912149293`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2150916075103224`, 1.550747452904461}, {
             1.3938204304874602`, 1.6381335894392386`}, {1.5940696263980345`, 
             1.7641614201638367`}, {1.7430654164099515`, 
             1.8697651643842002`}, {1.8733821373489319`, 
             1.9682513921745128`}, {1.9890045731992183`, 
             2.0601059665735613`}, {2.000842248481348, 
             2.0697767736749686`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0191279433130496`, 2.084715300304394}, {
             2.0939175079450534`, 2.1458147506201324`}, {2.278979190147401, 
             2.3015962168762347`}, {2.3617909196475195`, 
             2.3727914578269873`}, {2.439601604646695, 2.4403087535933468`}, {
             2.4451078456962634`, 2.4451080079266476`}, {2.5252633441561017`, 
             2.5154995981760697`}, {2.6011273547952913`, 
             2.5825191132868386`}, {2.7346991060263974`, 
             2.701032013902594}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.7523376065981773`, 2.7167293859353494`}, {
             2.8770222428607166`, 2.8282328913400687`}, {2.9980261116540006`, 
             2.937062213621256}, {3.128713960361641, 3.055087877035272}, {
             3.2498137227267208`, 3.164855590405377}, {3.362730688986557, 
             3.2675183435479838`}, {3.453143449222679, 
             3.3498994747414788`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.4705954197181725`, 3.365804030612662}, {
             3.5690737360873688`, 3.455699465317904}, {3.6641830812981744`, 
             3.542640887381139}, {3.8130388666019814`, 3.678901942902032}, {
             3.9515212239423474`, 3.805845489102255}, {4.081093843964398, 
             3.924757956125004}, {4.167079090603618, 4.003731575299362}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.18446926577911, 4.019703676623291}, {
             4.203220417313259, 4.036925774113479}, {4.318794452052087, 
             4.143144455381267}, {4.428709456244039, 4.2442095122419605`}, {
             4.606332438503963, 4.407602064253456}, {4.771636951728365, 
             4.559724805239533}, {4.87959901218761, 4.659106914832054}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.896971238201299, 4.675098536909425}, {
             4.926357828824258, 4.702149719124903}, {5.072229902698653, 
             4.836448789834277}, {5.210312271540595, 4.963587465077631}, {
             5.341664033539133, 5.084531192564942}, {5.449059880591806, 
             5.183417172865521}, {5.552731560496561, 5.27887198736428}, {
             5.591792936576235, 5.314836567680753}}]}, 
           {Arrowheads[{{0.0013727443986735993`, 1.}}], 
            ArrowBox[{{5.609163503611563, 5.3308299917734026`}, {
             5.652679073253396, 5.370895636061218}, {5.656854249492381, 
             5.374739705576735}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAA6olqZURB7b9yNrXjT8iiP9hgOtmC
Ye2/JI9M0vD/oj+lxD3tsoftv800t3xcQqM/5/jVKjur7b+iJOtUroCjP9AY
+ZvN5O2/44xVfr7moz9zEXJAkwvuv4WyYLw3LKQ/927xD+JE7r8YJbqhDpSk
PwNa0tRkjO6/XXeeG4gXpT8JlRz30/zuvyZI0h906qU/Unr9jbCq779P/CDm
TTmnP3Ye+6m8DvC/XBncQBMbqD+L16CvzlHwv56HZdSoJ6k/9MUM3g2c8L88
J1dUVlaqPzeUdtMauPG/Zm+269L1rj+fpI45SzTyv3irPeUqgrA/PvYZV1yl
8r842LvNhnKxPxGr95YaKfS/fOFA7h+otD/3Cwe821z1v5Ug5ZG9K7c/5RCl
4qtv9b+VbUuXtFK3P7J2iuxIgvW/2kLSizV5tz+tGbjkACT2v8q5Zr9Qw7g/
q1ToIJu59r/W9y6pDfG5P0G00pK70fe/jzudMvofvD+XuZ1qHsn4v0AngTOf
Ar4/yaVc23Go+b9fs7WCpa2/P+NXB026Xvu/TwNkryBvwT+qBs8Zqdf8v6Ou
S3wqw8I/BxQSvTCg/b8Qa71+h3PDP58f9hQ=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8750795682340193`, 
             0.1545434323905545}, {-1.8842968213310667`, 
             0.15555673880494317`}, {-2.0143886314060215`, 
             0.16949041339602683`}, {-2.127227135342532, 
             0.18124809588880272`}, {-2.2278244322412655`, 
             0.19151861707567314`}, {-2.3885939326526473`, 
             0.20761095230267032`}, {-2.528425532793269, 
             0.2213303947586151}, {-2.6532389490797983`, 
             0.2334036352565234}, {-2.814833831277174, 0.2488299267662786}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.8383389644395485`, 
             0.2510737913689677}, {-2.8491533123776738`, 
             0.2521061587404645}, {-3.0199307406662586`, 
             0.26819992238838786`}, {-3.172522211272508, 
             0.2824508946621548}, {-3.409144335692811, 
             0.30436857863999617`}, {-3.6157506378763697`, 
             0.32335410042092105`}, {-3.7787861418402153`, 
             0.3382525428918608}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-3.802300216049267, 
             0.34040068696566633`}, {-3.947660818743192, 
             0.3536345157504649}, {-4.084402733139297, 
             0.3660480809557879}, {-4.212230425143551, 
             0.37762323109093177`}, {-4.332639177710237, 
             0.3885048531072676}, {-4.5548044824302645`, 
             0.40853215609338345`}, {-4.730621083718382, 
             0.4243432686136072}, {-4.742942838958781, 0.4254492964812626}}]}, 
           {Arrowheads[{{0.018930184109908176`, 1.}}], 
            ArrowBox[{{-4.7664602790551065`, 
             0.42756027366064775`}, {-4.8941236001657185`, 
             0.439019614320396}, {-5.047062899610809, 
             0.45272512214536237`}, {-5.191189849892188, 
             0.46562372102011895`}, {-5.327566529529763, 
             0.47781404943381134`}, {-5.457255017043441, 
             0.4893947458755852}, {-5.656854249492381, 
             0.5073148804102359}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1405963113038806`, 
             0.7308894437331538}, {-1.1848136829004006`, 
             0.8272749995203161}, {-1.2331355454088277`, 
             0.9311997086036721}, {-1.287648129487048, 
             1.044346230986652}, {-1.3520851539329384`, 
             1.170479293322431}, {-1.4241080815301115`, 
             1.300257035242501}, {-1.5100497475387862`, 
             1.4416472712789103`}, {-1.588807056137668, 
             1.5606564323406624`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.601837876921815, 
             1.5803471388548433`}, {-1.6132539724353798`, 
             1.5975978546784346`}, {-1.7367765943201299`, 
             1.7707499161740654`}, {-1.8835974844677976`, 
             1.9639655674508427`}, {-1.973841394077956, 
             2.078004847530656}, {-2.0560065601865483`, 
             2.179568211364218}, {-2.161985886834797, 
             2.30793387699395}, {-2.178644507653301, 
             2.3277686424277495`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.1938301745886113`, 
             2.345849619532596}, {-2.2581444660365997`, 
             2.4224261200010453`}, {-2.374336905047809, 
             2.558646830616162}, {-2.4800087745137707`, 
             2.680992925582581}, {-2.577013075356848, 
             2.7921107658854614`}, {-2.6672028084994053`, 
             2.894646712509961}, {-2.751381585161552, 
             2.98968799372211}, {-2.813055344945597, 
             3.0589632926608705`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.8287559064539662`, 
             3.0765990115761306`}, {-2.8307201690355273`, 
             3.0788053774278046`}, {-2.834052429510258, 
             3.0825390172157547`}, {-2.9171751658739518`, 
             3.1752530986692626`}, {-2.9960390587617654`, 
             3.2628825360694544`}, {-3.1464952734821363`, 
             3.4295667552930458`}, {-3.2839163977193078`, 
             3.580960597198893}, {-3.4108621147111537`, 
             3.72019889883728}, {-3.462624428856356, 3.776772916659671}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.478563362679726, 
             3.794193496498195}, {-3.5477631365892366`, 
             3.869825919567227}, {-3.675040659113909, 
             4.008466289803488}, {-3.7940780657265645`, 
             4.137743945796037}, {-3.906258739868597, 
             4.25928282379485}, {-4.012415794358945, 
             4.374046744531909}, {-4.113382342016548, 
             4.482999528739196}, {-4.118659540760271, 4.488682602872317}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.134726442958366, 
             4.505985228889573}, {-4.2731718623020845`, 
             4.655078643735321}, {-4.422127696567685, 
             4.815121124793275}, {-4.561758976952739, 
             4.964834114383114}, {-4.693574835596636, 
             5.105924754974895}, {-4.778692779794684, 5.196888839867355}}]}, 
           {Arrowheads[{{0.012854665243419638`, 1.}}], 
            ArrowBox[{{-4.794825756283475, 
             5.214129874724587}, {-4.8185001243015675`, 
             5.239430265170606}, {-4.937459694869723, 
             5.366387863572235}, {-5.0356765456391726`, 
             5.4710888087964245`}, {-5.130565141296856, 
             5.5721550260574855`}, {-5.210160452808105, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAu0qGJb8/47/uYbgaBnnnPxzU3zFS
EeO/Y2ZpLcCz5z/v38NqsLPiv6HYmtLCIug/1BwkbYIU4r8gjTliJNToPwUg
tcIOkOC/13p3tf8/6j8iAtM3l+Tdv/iP7kE4cus/Gev2QooF2r+6ZGAWwJbs
P3ZHcCgSg9W/HPrpDbee7T8Cn6oBMUHQv0SCyiRQee4//UmLrm2Mzb+eDuMF
SKnuP7Z2ywKTi8q/JT2qOvPT7j/nmcOKHHfHvzugiqCE+e4/4/pNgQXbtb8T
E0pvXV/vPyVrif8GO4Q/Oqcu24947z/qNWkA0+e6P6ZDxhT6Uu8/4QuAFSsy
yj+u5rtkSOvuP581UOYC1M0/ghSH+tfB7j8aG4gvt7vQP0PvhwsIk+4/F4mB
zI8m0T8pQolkCIfuP1pEngk=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.291014405506614, 0.9487994765098089}, {
             0.31278403298131413`, 0.9434363625325781}, {0.3381699858300468, 
             0.9366292351471365}, {0.364477550338097, 0.929012376857643}, {
             0.376593552336233, 0.9252880655633156}, {0.388331722920734, 
             0.9215518350470326}, {0.40110779521211964`, 
             0.9173317543778773}, {0.4750899504767576, 0.8894793227765142}, {
             0.5460391139613201, 0.8573119565201502}, {0.6152820906069744, 
             0.8198798849800106}, {0.6848713410244929, 0.7748202672267389}, {
             0.7648622703084009, 0.712874182343065}, {0.838917530599924, 
             0.6425592765836354}, {0.8995532873291419, 0.572639269932696}, {
             0.9471285321373968, 0.5070982613520167}, {1.0022627192382285`, 
             0.41575307797847216`}, {1.0146548909893154`, 
             0.39081608257574363`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0251626877855284`, 0.36967104959337027`}, {
             1.039856895779794, 0.34010162426906443`}, {1.0668563478768496`, 
             0.27900874292421984`}, {1.0839936190471076`, 
             0.23866827714411948`}, {1.0984032895644527`, 
             0.20507222040022421`}, {1.1114406173424727`, 
             0.17725665879023322`}, {1.148826063444095, 
             0.12368937301165424`}, {1.1934008991165068`, 
             0.09361186847268517}, {1.2619085983198237`, 
             0.07365540869841207}, {1.3747138987024048`, 
             0.06145854233075389}, {1.487165967662689, 0.05771954307010708}, {
             1.5972809853712553`, 0.05694926742119071}, {1.701488624173177, 
             0.05747872081811574}, {1.8042889381314136`, 
             0.05865812840125613}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.82789937731646, 0.05892900628035903}, {
             1.8912099439471832`, 0.059655355836134946`}, {
             2.0571804790332293`, 0.06243425408033323}, {2.2037932752135174`, 
             0.0654532053373014}, {2.335441378270252, 0.06834999939363029}, {
             2.52847476791803, 0.07282371759538626}, {2.6980195135990725`, 
             0.0768913863715362}, {2.7721656084657793`, 
             0.07871782807033775}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.7957704410169057`, 0.07929928621108151}, {
             2.8489783472793095`, 0.08060995724343031}, {2.986254000924672, 
             0.08403638173241884}, {3.2290298822496637`, 
             0.09017999755141248}, {3.337895760021533, 0.09296051982873348}, {
             3.440296777550931, 0.0955861271848637}, {3.4550895817952503`, 
             0.09596616958680215}, {3.5608258602482916`, 
             0.09869117217204543}, {3.6609994578375566`, 
             0.10127883803084063`}, {3.7399445579347614`, 
             0.10332149037532377`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.7635486510033855`, 0.10393223069976008`}, {
             3.8518651851453325`, 0.1062173627130142}, {4.025734908519833, 
             0.11072933779292442`}, {4.185954357256688, 
             0.11489543201292873`}, {4.359189122233156, 
             0.11940605963287729`}, {4.519813556408731, 
             0.12359305837508956`}, {4.669664916529293, 
             0.12750268287277589`}, {4.707708896249234, 
             0.12849579521868693`}}]}, 
           {Arrowheads[{{0.01960565506789405, 1.}}], 
            ArrowBox[{{4.731312848329073, 0.12911196041474013`}, {
             4.810580459340724, 0.13118118775914656`}, {4.943662852593, 
             0.13465668014898277`}, {5.070014764036096, 
             0.13795726715706583`}, {5.267335767504585, 
             0.14311272990242918`}, {5.45098443952244, 
             0.14791154898540582`}, {5.622878230536669, 
             0.15240336884209738`}, {5.656854249492381, 
             0.1532911480379322}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{0.2971141521283195, -3.695668854500807}, {
             0.33716125984298034`, -3.71731228100789}, {
             0.3761354897568271, -3.7409637049562114`}, {
             0.5021885440499739, -3.831148354846328}, {
             0.6144201817989912, -3.937249482928637}, {
             0.7129345943206022, -4.0532528787000786`}, {
             0.8202406274108297, -4.210168848836859}, {
             0.9202120844084807, -4.385284789257599}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.931310024830983, -4.406117271430753}, {
             1.025437314438805, -4.592889922141951}, {
             1.1003749678221793`, -4.755074789443828}, {
             1.1713200808872266`, -4.9171695146329}, {
             1.2382255007643095`, -5.07628627874831}, {
             1.3016053112622132`, -5.232264423268003}, {
             1.315860362989028, -5.268301619165986}}]}, 
           {Arrowheads[{{0.00832342480322389, 1.}}], 
            ArrowBox[{{1.3245456257218597`, -5.2902582223777275`}, {
             1.3617339639781072`, -5.384271450568259}, {
             1.4189268966367563`, -5.532166604143096}, {
             1.466332955597497, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.0516608947230397`, -1.1507397433555933`}, \
{-1.055594924115164, -1.2753179448874468`}, {-1.0581131005965119`, \
-1.4051183304464423`}, {-1.061103830759856, -1.536781470697333}, \
{-1.064863499601735, -1.6771877454127868`}, {-1.0691037503664869`, \
-1.8273991334902508`}, {-1.07550413192081, -1.991986467435505}, \
{-1.0825552550374367`, -2.0946224896661914`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0841735909305343`, -2.1181789580405734`}, \
{-1.0872481283792605`, -2.1629318702670606`}, {-1.1063661023420703`, \
-2.348167678541859}, {-1.1341542067863397`, -2.5504216183360127`}, \
{-1.1718542327676587`, -2.772587888556142}, {-1.1970135440491054`, \
-2.9032098179267827`}, {-1.2208836553393083`, -3.0190409053170386`}, \
{-1.2278601138483936`, -3.0509035000476086`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.23291042447131, -3.073969071272883}, \
{-1.2522435799687504`, -3.162266664912381}, {-1.2816079324067735`, \
-3.289799471513548}, {-1.3217354160271892`, -3.456327641556051}, \
{-1.3588042396427291`, -3.604389088498296}, {-1.3932729172751677`, \
-3.7377551403891323`}, {-1.4255999629462792`, -3.860197125277406}, \
{-1.456007897392055, -3.973187047735581}, {-1.460718359013843, \
-3.990454917938427}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.4669323653653754`, -4.01323456539837}, \
{-1.485161593090503, -4.080060274538984}, {-1.5165483727927156`, \
-4.192341239658092}, {-1.5468600067157372`, -4.298380018667011}, \
{-1.6055011969027673`, -4.49999778270944}, {-1.6604828650696841`, \
-4.683071541532668}, {-1.7123433390479825`, -4.851566882919115}, \
{-1.733572844718619, -4.9192356069034915`}}]}, 
           {Arrowheads[{{0.01591840914475616, 1.}}], 
            ArrowBox[{{-1.7406408913995812`, -4.9417648973817085`}, \
{-1.7691396062381166`, -5.0326041141886115`}, {-1.8228015501248351`, \
-5.200644167170756}, {-1.8737059576132997`, -5.3576353611992555`}, \
{-1.9222296156086727`, -5.505526015607818}, {-1.9686153143151908`, \
-5.645424066965514}, {-1.9724385000402194`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.29481993946367335`, 3.6959473894629755`}, {
             0.33480727195150517`, 3.7174248284584643`}, {0.373733650411458, 
             3.740911337654391}, {0.4981441287667285, 3.829296898325692}, {
             0.609177766837082, 3.9333223797784833`}, {0.7068690836412068, 
             4.047195411367982}, {0.8168415232361668, 4.206727975146402}, {
             0.9187227315817925, 4.3846948735304645`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9298506993898349, 4.405510804720089}, {
             1.0261758007874746`, 4.5966950165367955`}, {1.12008432610264, 
             4.802011845592011}, {1.2076964892415358`, 5.006313493108806}, {
             1.2889794794210518`, 5.204469241515686}, {1.3140390592670919`, 
             5.267847566878296}}]}, 
           {Arrowheads[{{0.008333146499264059, 1.}}], 
            ArrowBox[{{1.3227211270279484`, 5.289805433640167}, {
             1.3650242748479713`, 5.396794564458482}, {1.436306443798612, 
             5.581864829473579}, {1.4646077942993894`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.0475961857558815`, 
             1.1827784589617705`}, {-1.0498418166188261`, 
             1.3111434677661404`}, {-1.0508903541208359`, 
             1.4373947446787785`}, {-1.052139585020446, 
             1.5706607243311481`}, {-1.053523146112208, 
             1.713036382904871}, {-1.0549478907750651`, 
             1.8649254850580383`}, {-1.0587725215057997`, 
             2.029626326687487}, {-1.0640729645978109`, 
             2.1270264065603213`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.0653560140232157`, 
             2.1506035140484787`}, {-1.0681456540333538`, 
             2.2018654849983093`}, {-1.0841047678434264`, 
             2.3880741799352267`}, {-1.1076537027406943`, 
             2.5914367005413563`}, {-1.1392142867990427`, 
             2.812066182927908}, {-1.1607921125927274`, 
             2.9457435307680218`}, {-1.1810406056324336`, 
             3.06366913128525}, {-1.1852434551910633`, 
             3.0868865026356516`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.189449383552899, 
             3.1101208819032644`}, {-1.2061269165298691`, 
             3.2022508691734073`}, {-1.2293513156534972`, 
             3.3255922383327055`}, {-1.263514087877694, 
             3.498117883486745}, {-1.2956867723890766`, 
             3.6506992381006365`}, {-1.3263678057295238`, 
             3.7876799226341182`}, {-1.356055624440914, 
             3.9134035575469275`}, {-1.3847837991758816`, 
             4.029436341733191}, {-1.3858862963142682`, 4.033736835054003}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.3917499679074596`, 
             4.056609167002962}, {-1.4129028632779794`, 
             4.139119934686114}, {-1.4436839153738825`, 
             4.253814331337323}, {-1.4734890035624109`, 
             4.362124664427622}, {-1.5312697956884884`, 
             4.56806388275961}, {-1.5856551563139347`, 
             4.755090642197521}, {-1.6371148969159077`, 
             4.927285781620607}, {-1.6487426194199728`, 4.965376628376669}}]}, 
           {Arrowheads[{{0.014850216045493364`, 1.}}], 
            ArrowBox[{{-1.6556364365355452`, 
             4.987959841144413}, {-1.6933907974406572`, 
             5.11163802275796}, {-1.7467067128732847`, 
             5.2828972229839835`}, {-1.7974057449846026`, 
             5.4430244969417485`}, {-1.8458309955454235`, 
             5.593980959274327}, {-1.8662714005230234`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5537111393403311, -0.95509841104397}, \
{-0.4953445881205276, -0.997343683519628}, {-0.3546154857695583, \
-1.0683298195920765`}, {-0.20825900091830946`, -1.1083280560712827`}, \
{-0.05794308378753177, -1.125193406142495}, {
             0.07134390659459472, -1.1248444147166206`}, {
             0.19915164663240026`, -1.113036321082877}, {
             0.3228740076784562, -1.0918643951885636`}, {
             0.3507144095873683, -1.085030312824587}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.3736456220015385, -1.0794013066465509`}, {
             0.4498740824932529, -1.0606892356360837`}, {
             0.5656739890091022, -1.0240736965620272`}, {
             0.6689229143108404, -0.9850213029755209}, {
             0.8544563093481147, -0.9042122419901313}, {
             0.9948738036344412, -0.8401505012534372}, {
             1.1303030191092636`, -0.787987959852756}, {
             1.2589272354856174`, -0.7569595923715898}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.2823739275792914`, -0.7545626883969729}, {
             1.3973204896357987`, -0.7459469609837991}, {
             1.5524837212123879`, -0.7565328493765459}, {
             1.7438098882531363`, -0.7908360349533173}, {
             1.8757649780637968`, -0.8230494708510685}, {
             1.99400608062525, -0.8557002262967234}, {
             2.135129733845415, -0.898390032275126}, {
             2.2050156199695357`, -0.9207444645333979}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.227505097605357, -0.9279381846422192}, {
             2.2616004897896502`, -0.9388442942613965}, {
             2.4150572052303083`, -0.9901644969017409}, {
             2.552539751984053, -1.0375210620821755`}, {
             2.70823268518227, -1.0924611572983562`}, {
             2.848664928490644, -1.1428256589793315`}, {
             3.0752928639498114`, -1.225284275374294}, {
             3.1184641191247944`, -1.241183730071671}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.140621226487053, -1.2493439265566528`}, {
             3.273949479089587, -1.2984471204189159`}, {
             3.450642172283815, -1.3641568452623751`}, {
             3.6113783419063377`, -1.4242561010538504`}, {
             3.7588866230389932`, -1.4796556284607747`}, {
             3.895895650763619, -1.5312661681505817`}, {
             4.023622602223469, -1.579509232078279}, {
             4.025275391033416, -1.5801346788725485`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.047359066191449, -1.5884915625531217`}, {
             4.143849183761501, -1.6250052625187013`}, {
             4.151103552986978, -1.6277529613686437`}, {
             4.274849231103496, -1.674696362252509}, {
             4.392170621799904, -1.7192582673258772`}, {
             4.615855720676172, -1.8042989039729227`}, {
             4.819881961134938, -1.881997485845006}, {
             4.930212794518585, -1.9240668126177258`}}]}, 
           {Arrowheads[{{0.0159711646410683, 1.}}], 
            ArrowBox[{{4.952275347979592, -1.9324793002472198`}, {
             5.008090274085272, -1.9537616226327508`}, {
             5.212278530123862, -2.031690773981522}, {
             5.401739366724814, -2.1040590728045645`}, {
             5.578607384145095, -2.1716641844718088`}, {
             5.656854249492381, -2.201587893683602}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9654128896405695, 0.8878634113240957}, {
             1.1013114711650345`, 0.8394750195951183}, {1.2746550080160715`, 
             0.8034474341987133}, {1.4150574698779297`, 0.8002980703038645}, {
             1.5764464542401568`, 0.8190010821901546}, {1.7920450525434342`, 
             0.866942379186482}, {1.8876200007699466`, 0.8942667796477922}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.910322413413173, 0.9007572860619967}, {
             1.923847139874961, 0.9046239378240852}, {2.0419395809926084`, 
             0.9417018590587891}, {2.1838268503753384`, 0.9895634490562132}, {
             2.3109991306168824`, 1.0344650426221365`}, {2.466156035949925, 
             1.091307179507553}, {2.6051802006045586`, 1.143527406360507}, {
             2.7627126930351973`, 1.203926594490198}, {2.7995884889753984`, 
             1.2182620874080488`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.8215960036267633`, 1.226817524989267}, {
             2.904855222359413, 1.2591846077885966`}, {3.0236233725355386`, 
             1.3058248697656512`}, {3.135287445284422, 1.3498757645319763`}, {
             3.337303358500463, 1.4302094524324378`}, {3.5170118660095198`, 
             1.5022652199362683`}, {3.6805218718135766`, 1.568122615489755}, {
             3.699268355608915, 1.5757011399808}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.721159207594587, 1.5845508186573158`}, {
             3.8306030602319536`, 1.628795004749048}, {3.970025115583972, 
             1.6852957533702975`}, {4.1000230343694986`, 
             1.7380913501998259`}, {4.2224043547782655`, 
             1.7878678412923983`}, {4.2290002760337595`, 
             1.7905525230615298`}, {4.35492032682281, 1.8418656944888179`}, {
             4.4743198284129155`, 1.890567392075228}, {4.596090545713808, 
             1.9402697830373234`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.617951650190409, 1.9491926931231238`}, {
             4.701994708667883, 1.983496021892848}, {4.9097090733964155`, 
             2.06838014675157}, {5.101357493483287, 2.14676475176765}, {
             5.309398542314142, 2.2319030581147983`}, {5.492143866064165, 
             2.306725648301692}}]}, 
           {Arrowheads[{{0.0032702206681399205`, 1.}}], 
            ArrowBox[{{5.5139908571729, 2.3156830516130853`}, {
             5.656854249492381, 2.3743307953846946`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8341510276828813, -1.5116235370500781`}, \
{-0.7752296045575331, -1.6360079837423933`}, {-0.706034846146985, \
-1.7503881173431126`}, {-0.6095824261527877, -1.8691348766209146`}, \
{-0.5209705064141167, -1.9496519251078475`}, {-0.4411186183682713, \
-2.003994213662835}, {-0.3628265549898326, -2.041578287864266}, \
{-0.2855664146424059, -2.067935437429305}, {-0.21402811929204074`, \
-2.0864492346807086`}, {-0.1535544464533718, -2.097579316235876}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.13019286490865462`, -2.1009043181482845`}, \
{-0.07346528591001034, -2.10717843369265}, {
             0.028352161483239158`, -2.1109079486038698`}, {
             0.13027659194645094`, -2.1112665829825126`}, {
             0.23134901674919922`, -2.112547894349613}, {
             0.4028421995305853, -2.119667792113312}, {
             0.5644300231929195, -2.1438121406023933`}, {
             0.7124833193594289, -2.1912881458190214`}, {
             0.795531063566571, -2.2309050751620365`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.8162715069524547, -2.2421326291341113`}, {
             0.8909565623103021, -2.2870993356016758`}, {
             0.9708147177601032, -2.344107137926172}, {
             1.1162435540550357`, -2.4651910929759593`}, {
             1.2439349901024868`, -2.591327389138616}, {
             1.3566713166201565`, -2.717815693852612}, {
             1.4572348243257442`, -2.839955674556415}, {
             1.495567696880415, -2.8897129040798175`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.509977896390958, -2.908417779471076}, {
             1.5696385555836796`, -2.985859121982936}, {
             1.6701569365198048`, -3.123019938681775}, {
             1.7487183631456313`, -3.2342247072398607`}, {
             1.8223479621176104`, -3.3403053129004086`}, {
             1.9548116771000263`, -3.5370940355288902`}, {
             2.0499112985949677`, -3.6830076274394727`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.062803927418313, -3.70278909187868}, {
             2.071807145674082, -3.716602941963499}, {
             2.1775934320468076`, -3.882048867600514}, {
             2.2741315576269945`, -4.035465137520312}, {
             2.363382543823433, -4.178885076803269}, {
             2.4462152668115626`, -4.313335346941299}, {
             2.52473132040061, -4.4417117101027}, {
             2.5625763517222158`, -4.504169246632533}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.574812591421475, -4.524363321292157}, {
             2.6042979711442635`, -4.573024509216202}, {
             2.679500359620869, -4.697756515734807}, {
             2.752859698898322, -4.819658688385841}, {
             2.82253293977747, -4.935901193301736}, {
             2.8889110306955956`, -5.047042063073243}, {
             2.9523849200899814`, -5.153639330291118}, {
             3.059836664338167, -5.334786628856747}}]}, 
           {Arrowheads[{{0.007421119610163645, 1.}}], 
            ArrowBox[{{3.0718824489593746`, -5.3550948851051965`}, {
             3.1371470679108437`, -5.465460165000483}, {
             3.2001490590566477`, -5.572147810242823}, {
             3.2500953985362764`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8045963975795629, 
             1.5899137592787866`}, {-0.7395379321086363, 
             1.7119258244783897`}, {-0.6785973000444163, 
             1.800103263606394}, {-0.6206511894210323, 
             1.8676622987246945`}, {-0.5663033894774144, 
             1.9215348708662163`}, {-0.36131095576119915`, 
             2.0497468145849247`}, {-0.2869867296545655, 
             2.0750923210847865`}, {-0.21415122764307815`, 
             2.0941020461699345`}, {-0.14233384679847746`, 
             2.1073401352149297`}, {-0.0777456391239852, 
             2.1134312257541703`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.054237950174293614`, 
             2.115648154616518}, {-0.04197989061508684, 2.116804169828874}, {
             0.05823707998908641, 2.1190141254822956`}, {0.15841434334020232`,
              2.119680927926148}, {0.39268613550865833`, 2.127662791935428}, {
             0.6088050337295396, 2.164342301568191}, {0.7981401144074775, 
             2.2405791999704796`}, {0.8615663069367752, 2.278741486336888}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.8817984108165177, 2.2909147433347283`}, {
             0.9097268901752661, 2.307718757332172}, {1.012131153442478, 
             2.383869947236661}, {1.1918311846660676`, 2.549300179731028}, {
             1.3055688737850966`, 2.6718580191845747`}, {1.4070279079755716`, 
             2.791327098425459}, {1.5194211852693784`, 2.9337995754334254`}, {
             1.5401261983203058`, 2.9615324704313175`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.5542520291318738`, 2.980453017918616}, {
             1.6198874637951834`, 3.068367022762823}, {1.6966318883199, 
             3.1753773000820202`}, {1.7686024599669399`, 3.277668828120364}, {
             1.898222044627988, 3.4680956363544935`}, {2.0128256264851045`, 
             3.6424178607442435`}, {2.0880988596840786`, 3.75931227023391}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.100882460947618, 3.7791643671526485`}, {
             2.1164926142450664`, 3.803405914568646}, {2.211125739037419, 
             3.952929276257324}, {2.298627731991708, 4.0928574242399}, {
             2.3798455889138, 4.224155091783696}, {2.456882442176776, 
             4.349679480197444}, {2.5349116696285106`, 4.478108066436252}, {
             2.597864098676159, 4.582281816837649}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.610074150631048, 4.602491735179968}, {
             2.6805971480468505`, 4.719427929301439}, {2.7489197135809027`, 
             4.833206295504786}, {2.814009314410355, 4.942017996781064}, {
             2.8762491247707014`, 5.046401620386606}, {2.993248888292877, 
             5.243435281402738}, {3.057411197296115, 5.351861591140108}, {
             3.093898263858049, 5.413631860522632}}]}, 
           {Arrowheads[{{0.005477984528825574, 1.}}], 
            ArrowBox[{{3.1059070718829354`, 5.433962004229886}, {
             3.1192121802800283`, 5.456486701534808}, {3.178651837244616, 
             5.557310612586838}, {3.235730168189879, 5.654333324296198}, {
             3.2372109585561324`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.292084137678858, -1.6614415924013788`}, \
{-1.3497105658897663`, -1.8268926718474103`}, {-1.419910734762962, \
-2.0046927192620663`}, {-1.5085079563774522`, -2.2064092721847945`}, \
{-1.564766868358636, -2.3257676670792584`}, {-1.616799671433178, \
-2.4319006959691762`}, {-1.6655877776878028`, -2.5278640900216915`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6762886429988992`, -2.5489120755530896`}, \
{-1.6847512886600728`, -2.5655576119891967`}, {-1.74726110024634, \
-2.68474193947983}, {-1.8281729968956963`, -2.8346649422205408`}, \
{-1.9022625341428812`, -2.9686629237478948`}, {-1.996929274217747, \
-3.136127327499154}, {-2.0833191329053626`, -3.2861366430338825`}, \
{-2.1350112845957323`, -3.374378291856274}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.1469461928638345`, -3.3947519066059484`}, \
{-2.194596707674881, -3.4760942353089312`}, {-2.2957584471324823`, \
-3.6463122742463483`}, {-2.411359012898307, -3.838327577012456}, \
{-2.5171437795063385`, -4.0122391550743615`}, {-2.614765500489076, \
-4.171312036063125}, {-2.6346692160928065`, -4.20353392517372}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.647078035070921, -4.223622415034946}, \
{-2.7058769293790186`, -4.318811247609807}, {-2.7912163754110826`, \
-4.456132587541678}, {-2.8728668505052823`, -4.5869072017864125`}, \
{-2.9566155108815186`, -4.720199336960965}, {-3.0362783393701402`, \
-4.84653543308604}, {-3.1141854823018815`, -4.969914635785423}, \
{-3.148457744809987, -5.024028000956443}}]}, 
           {Arrowheads[{{0.015396075922188274`, 1.}}], 
            ArrowBox[{{-3.1610915130307315`, -5.043975785642485}, \
{-3.1885812541198635`, -5.087380051633421}, {-3.259818149786981, \
-5.199549518602892}, {-3.3282486642661313`, -5.307040874666696}, \
{-3.457685480479832, -5.50971016200335}, {-3.5283961242267727`, \
-5.619906366559006}, {-3.5522432476266705`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.895410520239323, -2.2992677795339964`}, \
{-0.8677161329778121, -2.468092220596892}, {-0.8372444715877444, \
-2.6469298333404376`}, {-0.8077065180470792, -2.837187859111057}, \
{-0.778854133016307, -3.036823115078369}, {-0.7510787114671112, \
-3.2325997159517557`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.7475982030447278, -3.2559533627585746`}, \
{-0.7156912558006608, -3.4629735233804975`}, {-0.6767685530670131, \
-3.665639491712379}, {-0.6300978472146561, -3.862811851495851}, \
{-0.5753717714612837, -4.088550457549893}, {-0.554814513020626, \
-4.1800160533986475`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            
            ArrowBox[{{-0.5496367868702032, -4.203053357174206}, \
{-0.5434264272885209, -4.230685166212038}, {-0.5172827043182935, \
-4.353810471623849}, {-0.47706036547776526`, -4.559085651188932}, \
{-0.46115444631559194`, -4.646822609994823}, {-0.4471621612250364, \
-4.72756762968271}, {-0.432452907516401, -4.8193190802442025`}, \
{-0.41960374138194617`, -4.903939718587855}, {-0.3968138963437979, \
-5.061517654181501}, {-0.3875197027777046, -5.133180473558822}}]}, 
           {Arrowheads[{{0.0106473792674176, 1.}}], 
            ArrowBox[{{-0.38448281776146864`, -5.156596355834199}, \
{-0.3789870082041849, -5.198971759879214}, {-0.3647525620865166, \
-5.321520902637055}, {-0.3428322716292737, -5.5452132970879315`}, \
{-0.33459427849284956`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.8676093879013361, 
             2.404081259290133}, {-0.8348356017878655, 
             2.57554147567872}, {-0.8018191551297915, 
             2.7601788117122843`}, {-0.768871650916981, 
             2.9523167714270597`}, {-0.7342426107860719, 
             3.1515344189414107`}, {-0.6989229892797197, 
             3.333337267834641}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.6942547858611336, 
             3.356479243942026}, {-0.6445699681283408, 
             3.5553123536440245`}, {-0.6184725021098771, 
             3.6380680818184037`}, {-0.5943482555844775, 
             3.7110976307707704`}, {-0.572629534531737, 
             3.7774842951220062`}, {-0.5012771135226008, 
             3.9980855956468346`}, {-0.43334074479736123`, 
             4.209252121518445}, {-0.4168757204929972, 
             4.258914218426108}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.4094451145096363, 
             4.2813265433402306`}, {-0.3566944551067251, 
             4.44043401325852}, {-0.2964878281199029, 
             4.608351888212131}, {-0.27006217127447707`, 
             4.675936067500619}, {-0.24516280369535975`, 
             4.735371399065896}, {-0.2186321791879699, 
             4.790667796899941}, {-0.19294372340315458`, 
             4.838452332644888}, {-0.1426521071316633, 
             4.920625166631286}, {-0.09361435100097822, 
             4.977868290509988}, {-0.0441579770386921, 5.012835056116331}, {
             0.061107038777442536`, 5.048858897151157}, {0.0631916970399431, 
             5.049912931092482}}]}, 
           {Arrowheads[{{0.016224281457610682`, 1.}}], 
            ArrowBox[{{0.08426336874870544, 5.0605670788638575`}, {
             0.17252692692626673`, 5.105194434711477}, {0.28302699360756245`, 
             5.214025747093704}, {0.3868302270473023, 5.3606383697683855`}, {
             0.4561660415630361, 5.483735292853919}, {0.520114762599398, 
             5.6161600949620025`}, {0.5373620635175208, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.273012364013431, 
             1.7127208463324337`}, {-1.326041525049277, 
             1.876780691024262}, {-1.3942325557322655`, 
             2.062832480143348}, {-1.4765091689302023`, 
             2.264506050669103}, {-1.5296788215141945`, 
             2.3861916741870552`}, {-1.5788182069390853`, 
             2.4943976257698184`}, {-1.6232921375725764`, 
             2.5889183034387995`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.6333448720135912`, 
             2.6102834325887625`}, {-1.6429126362610638`, 
             2.630617852046779}, {-1.701814418860494, 
             2.752086634678224}, {-1.7779447042407284`, 
             2.904825093180189}, {-1.8475717288708082`, 
             3.041333626616911}, {-1.936390221524288, 
             3.21186139178522}, {-2.017336253234796, 
             3.3646035759444923`}, {-2.0637790385153867`, 
             3.4508692843901665`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.0749719891004563`, 
             3.4716597646764984`}, {-2.1214245733541244`, 
             3.5579436743422206`}, {-2.2159163168212856`, 
             3.7311774995020763`}, {-2.323690381201516, 
             3.926483050164726}, {-2.422182217413171, 
             4.103362360566549}, {-2.5129611260137357`, 
             4.265137982040581}, {-2.5316997783110726`, 4.298347471375979}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.543303243649304, 
             4.318911658826025}, {-2.5975964075606974`, 
             4.415132465919857}, {-2.676788145835771, 
             4.554766762826136}, {-2.7524086871245936`, 
             4.687593553172926}, {-2.8299666464640936`, 
             4.823128511474318}, {-2.9036820447101346`, 
             4.951581469377681}, {-2.9757482640645394`, 
             5.0770242106221035`}, {-3.011526531639531, 5.139156770655241}}]}, 
           {Arrowheads[{{0.012163951306648033`, 1.}}], 
            ArrowBox[{{-3.0233093072031636`, 
             5.159618745470816}, {-3.044516125635672, 
             5.196446518548647}, {-3.1103185044876542`, 
             5.310477674726683}, {-3.173488275684609, 
             5.419746960725586}, {-3.292868518676026, 
             5.625752479293064}, {-3.310931726171257, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.233411536156652, -0.30645465554360135`}, \
{-1.334028594753537, -0.36104890871896694`}, {-1.4483630826701288`, \
-0.42106640053944583`}, {-1.577942198274686, -0.4859890932400253}, \
{-1.7263200831518943`, -0.5565124325572186}, {-1.8973760872714387`, \
-0.6336466497728311}, {-2.0848086286702285`, -0.7142135886167004}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.1065600728112064`, -0.7233995858521032}, \
{-2.215476487860883, -0.7687354138521739}, {-2.3233806312933996`, \
-0.8128586745620471}, {-2.4593944220603845`, -0.8675705283359854}, \
{-2.580948927489399, -0.9158114606085572}, {-2.7325803442565695`, \
-0.9752548291833554}, {-2.8683409540320315`, -1.027953819998654}, \
{-2.984116740606248, -1.0724951222993435`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.0061541153296045`, -1.0809733490383808`}, \
{-3.0396755730321976`, -1.0938697363165089`}, {-3.193086276217481, \
-1.1524672535180465`}, {-3.364653450606028, -1.2175865496749936`}, \
{-3.519982858603518, -1.2762641272348245`}, {-3.6619897731076536`, \
-1.329694082599878}, {-3.79358946701614, -1.3790705121724922`}, \
{-3.8895922845198925`, -1.414999413926008}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            
            ArrowBox[{{-3.9117063420476446`, -1.4232755647822593`}, \
{-3.916034683147287, -1.4248954395543583`}, {-4.031148545852726, \
-1.467896953468849}, {-4.039597062298843, -1.4710500573542271`}, \
{-4.158635752208542, -1.5154059788314993`}, {-4.271393598428856, \
-1.5573667802687432`}, {-4.4862360783197595`, -1.637237024623697}, \
{-4.6819713902885365`, -1.7098689921464345`}, {-4.796956705706179, \
-1.7524763184184629`}}]}, 
           {Arrowheads[{{0.01891300959918312, 1.}}], 
            ArrowBox[{{-4.8190975575317125`, -1.7606805181829694`}, \
{-4.86239809176686, -1.776725349500856}, {-5.057546755178527, \
-1.8489569443536604`}, {-5.238583763383259, -1.9158959540485878`}, \
{-5.407562626534956, -1.9783188693007787`}, {-5.566536854787521, \
-2.037002180825374}, {-5.656854249492381, -2.070319669729636}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.1471500586696521`, 
             0.3522151520720197}, {-1.2302839539043207`, 
             0.41735009167761167`}, {-1.3227565241292778`, 
             0.48890693351646203`}, {-1.424499324413355, 
             0.5648868673096281}, {-1.5344019182813073`, 
             0.6428492797491343}, {-1.6637673746713746`, 
             0.7295429971870032}, {-1.8134980890825243`, 
             0.8241955466624153}, {-1.9227558138296736`, 
             0.8896151018008611}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.9430139721064654`, 
             0.9017449507928567}, {-1.987424401034823, 
             0.9283363017543046}, {-2.1892120197826874`, 
             1.043595227904635}, {-2.312051558269035, 
             1.1116287438326213`}, {-2.4221985725181807`, 
             1.1716179514416631`}, {-2.563661272520779, 
             1.2474766487665896`}, {-2.6903539303484436`, 
             1.3145419893044732`}, {-2.770650128754025, 
             1.3565477319939814`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.7915721754566754`, 
             1.3674927845342062`}, {-2.849426201117935, 
             1.3977582437182634`}, {-2.991985854492073, 
             1.471621809964094}, {-3.171770151192821, 
             1.5639573691839448`}, {-3.3328785484951275`, 
             1.6461089907919233`}, {-3.5114110619015446`, 
             1.7365651853679323`}, {-3.632433111049902, 1.797582972029142}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.6535168874321187`, 
             1.8082131454426305`}, {-3.6732723521774426`, 
             1.8181736009274447`}, {-3.8214261911329803`, 
             1.8925563177571403`}, {-3.958836350578318, 
             1.9613354161436984`}, {-4.086785496374716, 
             2.0251987048814906`}, {-4.2071417691530035`, 
             2.085144706108541}, {-4.213208968470869, 
             2.08816344178036}, {-4.33744815965617, 
             2.1498621284583623`}, {-4.455190904524075, 
             2.2082411889667632`}, {-4.498684983653026, 2.229793038054984}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.519842034634332, 
             2.240276616027725}, {-4.570169857968451, 
             2.265214669095127}, {-4.679621228565768, 
             2.3193769884634166`}, {-4.884246342944465, 
             2.4204612576066142`}, {-5.072979342894589, 
             2.513514352028641}, {-5.27748835136401, 
             2.6141854951767574`}, {-5.366867398729529, 2.658115342650499}}]}, 
           {Arrowheads[{{0.006348649737839266, 1.}}], 
            ArrowBox[{{-5.388058160018729, 
             2.6685306126575745`}, {-5.467275413038509, 
             2.707465933015333}, {-5.639921793144445, 
             2.7928176720142024`}, {-5.656854249492381, 
             2.801321679565516}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.4318725598738158`, -0.7362082082968757}, \
{-1.5382370944031467`, -0.8345875462107354}, {-1.6620915027180572`, \
-0.9428167851302534}, {-1.8061968033783724`, -1.061745739285908}, \
{-1.9685299203473594`, -1.1884716898197396`}, {-2.156961478720604, \
-1.3284847318419066`}, {-2.1631100433869612`, -1.3329094371185861`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.182275328292205, -1.3467013937541397`}, \
{-2.2718392016514177`, -1.411154443296048}, {-2.3753551484152675`, \
-1.4843600339579721`}, {-2.507579384242757, -1.576375863253291}, \
{-2.6265554373515565`, -1.6580669463447888`}, {-2.777620051787546, \
-1.76052273673532}, {-2.9133901234783663`, -1.8516764220608108`}, \
{-2.959911974386812, -1.882623197591629}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.979571552244022, -1.8957009348505152`}, \
{-3.0840400288620335`, -1.9651943542397512`}, {-3.2373535349572404`, \
-2.066412606295042}, {-3.432452286211739, -2.1943313321084834`}, \
{-3.6074575475050628`, -2.3084229482408207`}, {-3.7694534989700474`, \
-2.4134998364849745`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7892631344762813`, -2.4263491381954303`}, \
{-3.798851959958941, -2.432568824147594}, {-3.972683825403105, \
-2.544887211972036}, {-4.132032606490964, -2.6475044665051897`}, \
{-4.279977765875929, -2.7425469425380986`}, {-4.41786462661893, \
-2.830928597865758}, {-4.547655861867005, -2.913979322360374}, \
{-4.551493177983104, -2.916432711687025}, {-4.5837678112708735`, \
-2.937036513093326}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.603670053470842, -2.94974190441945}, \
{-4.685186736742024, -3.0017813354625367`}, {-4.811962451890183, \
-3.0826093316998735`}, {-4.935789880646419, -3.1615179600382124`}, \
{-5.053720736618804, -3.236587852578555}, {-5.166364751622866, \
-3.308221714527143}, {-5.274331657474127, -3.3768222510902177`}, \
{-5.4004542702072325`, -3.4568673611260627`}}]}, 
           {Arrowheads[{{0.005932924889629447, 1.}}], 
            ArrowBox[{{-5.420390158671845, -3.4695198930648763`}, \
{-5.47794070046494, -3.5060449804431335`}, {-5.588511113966308, \
-3.576263932216696}, {-5.656854249492381, -3.6197979404521927`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.565023001985335, 
             0.37492786926418936`}, {-1.7152392204920566`, 
             0.43062976164966127`}, {-1.8878753684849467`, 
             0.49128334036399524`}, {-2.0834811420201413`, 
             0.5566555825209547}, {-2.3097360425185305`, 
             0.6290927689487743}, {-2.444288433617764, 
             0.6709811281447972}, {-2.4601179575171064`, 
             0.6758360447134835}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.482692091219288, 
             0.6827595337856353}, {-2.564517648168627, 
             0.7078554403145639}, {-2.715100841881351, 
             0.753407687308085}, {-2.8498738803873644`, 
             0.7937183326222734}, {-3.017824323353338, 
             0.8434345417008912}, {-3.168340515115249, 
             0.8876146152428939}, {-3.3544787709646444`, 
             0.9418306260697027}, {-3.3881023835719613`, 
             0.9515626779573201}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.4107834182764707`, 
             0.9581274992091894}, {-3.5215404200454286`, 
             0.99018511600132}, {-3.7314350609896794`, 
             1.0505877409395747`}, {-3.91974773200193, 
             1.1045209679484893`}, {-4.1242546903559125`, 
             1.162842876257708}, {-4.31010406350774, 
             1.2156696326107566`}, {-4.318770473743396, 1.218125990766341}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.341487601425768, 
             1.2245648045700621`}, {-4.480546468833438, 
             1.2639788611142402`}, {-4.638832523709032, 
             1.3087481858747643`}, {-4.786388975461743, 
             1.3504010215244906`}, {-4.92529891061014, 
             1.3895542373641239`}, {-4.931587655751481, 
             1.3913254732861544`}, {-5.074621688895734, 
             1.431557023892541}, {-5.210264176843086, 
             1.4696655262683822`}, {-5.250498454548365, 
             1.4809641586525826`}}]}, 
           {Arrowheads[{{0.008437748644195654, 1.}}], 
            ArrowBox[{{-5.273231101451532, 
             1.4873479645794632`}, {-5.342755931825323, 
             1.5068720009178682`}, {-5.468946220877328, 
             1.5422744201146437`}, {-5.656854249492381, 
             1.5950834361525261`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.878378511972527, -1.1332807951416206`}, {
             1.044530776731646, -1.1122589961587261`}, {
             1.2143795501108336`, -1.1136549278917185`}, {
             1.3873359342287594`, -1.1429443576084028`}, {
             1.5890147741452598`, -1.2062353082427435`}, {
             1.792010717626525, -1.291955862942071}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8137365352254176`, -1.3011994206413453`}, {
             1.941654007221122, -1.3629689590707095`}, {
             2.0572642779587285`, -1.4220210136318578`}, {
             2.197796833437558, -1.4971697213845838`}, {
             2.323744550387393, -1.566713706171034}, {
             2.476796015948697, -1.6535140282846748`}, {
             2.6140797192458987`, -1.7328681051107264`}, {
             2.6441327552816443`, -1.7505223919407193`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.664491832642876, -1.7624820818336704`}, {
             2.7833057061081976`, -1.8322778322212314`}, {
             2.9350626059593776`, -1.9224800704967697`}, {
             3.1076940498752434`, -2.026112708190496}, {
             3.2636208555612307`, -2.120374034880059}, {
             3.394083030672766, -2.199650004476097}, {
             3.4743015742870487`, -2.24851259318515}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.494467117641713, -2.260795796128492}, {
             3.5168213794569816`, -2.2744121876978283`}, {
             3.6318359019138784`, -2.3446605845452533`}, {
             3.7391265980434563`, -2.410395195018371}, {
             3.9371540877894495`, -2.5320602891913557`}, {
             4.1175214251637575`, -2.643144702566449}, {
             4.283232869123039, -2.7454057130550185`}, {
             4.29917198309449, -2.755254629100111}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.319258670063241, -2.7676663662853547`}, {
             4.437292678623954, -2.8406005985684315`}, {
             4.581043047203033, -2.9295275755681747`}, {
             4.716449359309043, -3.0133585062288777`}, {
             4.719852230385055, -3.0154660079896507`}, {
             4.858918535432222, -3.101646022270952}, {
             4.990854635983893, -3.183446219976019}, {
             5.119746432014758, -3.2633718107458383`}, {
             5.12224128911992, -3.2649194023011727`}}]}, 
           {Arrowheads[{{0.01282408463003486, 1.}}], 
            ArrowBox[{{5.142306375031176, -3.2773660299854113`}, {
             5.242549619004014, -3.3395481876451605`}, {
             5.359886215817587, -3.4123547524631612`}, {
             5.472378241321405, -3.4821709069890154`}, {
             5.580178781560006, -3.5491018409418973`}, {
             5.656854249492381, -3.5967359541310944`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.4822734532666615`, 
             0.9325472420283627}, {-1.5875921793591763`, 
             1.0448928115373781`}, {-1.7111339693673273`, 
             1.1680587884936562`}, {-1.8562397523561267`, 
             1.3039770667799104`}, {-2.0262209966695823`, 
             1.4548188206843486`}, {-2.130133848418839, 
             1.543826168850236}, {-2.170819702847984, 1.5780056408618761`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.188898786665564, 
             1.593193561774664}, {-2.224080147898331, 
             1.622748805690726}, {-2.3441857787067666`, 
             1.721853802807738}, {-2.4525677250593976`, 
             1.8099467606150066`}, {-2.5901597994895567`, 
             1.9202468634192904`}, {-2.714132391620052, 
             2.018496143739361}, {-2.870564555255189, 
             2.141178298860349}, {-2.9256832141494606`, 
             2.1840333778836003`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.9443238494981174`, 
             2.198526580674377}, {-3.011357566261533, 
             2.250645686740236}, {-3.187279458052371, 
             2.3863509407697827`}, {-3.345571620852108, 
             2.5076649021830515`}, {-3.448568203741061, 
             2.5862153989847796`}, {-3.546455941030482, 
             2.660701239976949}, {-3.6942220557112124`, 2.772705841962547}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.713039276316809, 
             2.7869690261097304`}, {-3.726904878810726, 
             2.797478954532611}, {-3.827819702524191, 
             2.873685850471675}, {-3.924251452880757, 
             2.94639037972584}, {-4.103665733523192, 
             3.0812923381794755`}, {-4.268268617725675, 
             3.204676443828586}, {-4.421181002475851, 
             3.319034310608241}, {-4.468245804065161, 3.3541568279932035`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.487169327487333, 
             3.3682786718751707`}, {-4.563773355670885, 
             3.4254450939311405`}, {-4.700839925641792, 
             3.5275603521670136`}, {-4.8390072561636925`, 
             3.630260660380981}, {-4.970071069626777, 
             3.7275536944991603`}, {-5.0981046687392775`, 
             3.822548180443632}, {-5.2200778391506075`, 
             3.912945570040688}, {-5.245254620441605, 3.9316148311352923`}}]}, 
           {Arrowheads[{{0.010387615820760374`, 1.}}], 
            ArrowBox[{{-5.264221072881287, 
             3.9456789662025273`}, {-5.335815076619503, 
             3.9987678473088177`}, {-5.445140876904697, 
             4.080036996266509}, {-5.639763548432493, 
             4.2265508068938855`}, {-5.656854249492381, 
             4.239734222790453}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.2859116642462315, 1.2624926275880908`}, {
             0.40911082992775905`, 1.2425802162518114`}, {0.5568617169296726, 
             1.2147669277583826`}, {0.6876123994637028, 
             1.1881812933530949`}, {0.9030401885761075, 
             1.1488379044067403`}, {1.0701265223562482`, 
             1.1341136807004994`}, {1.2190901059734922`, 
             1.1422356011583505`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.2426670808436582`, 1.1435210852336013`}, {
             1.2435708802120502`, 1.1435703629590808`}, {1.4216480765120687`, 
             1.1822220922737803`}, {1.6273688227872758`, 
             1.2556351878572727`}, {1.7468979520759835`, 1.308040426560797}, {
             1.853952369149668, 1.3592220142365374`}, {1.9846179517543452`, 
             1.4261745807314248`}, {2.101674901007079, 1.4891226834789184`}, {
             2.113911520705045, 1.4959696751426532`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.1345170847671167`, 1.5074995035464083`}, {
             2.244104991508413, 1.5688193371625934`}, {2.371774934533752, 
             1.6422840299198096`}, {2.5271113282279174`, 1.733788160579838}, {
             2.6664725018076902`, 1.8172681170160672`}, {2.838435452919601, 
             1.9217524353743998`}, {2.9472223870163523`, 
             1.9885392618704714`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.9673448515978915`, 2.0008929104206308`}, {
             2.9926800939590255`, 2.0164468043680794`}, {3.1682365033788784`, 
             2.125169353124499}, {3.3268402190733832`, 2.223996148502243}, {
             3.4594341201937793`, 2.306989445063671}, {3.584200596439004, 
             2.3852451389763862`}, {3.701139647809058, 2.4587632302403883`}, {
             3.768433886297205, 2.5011833714562797`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.788408476575208, 2.513774715965984}, {
             3.8102512743039405`, 2.527543718855677}, {4.011689592108037, 
             2.6548246580698365`}, {4.1952128892911364`, 
             2.7710207265485853`}, {4.363864584515366, 2.877975633247679}, {
             4.5206880964428535`, 2.9775330871228727`}, {4.58626941081283, 
             3.019204322234481}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.606198514392166, 3.031867538408117}, {
             4.667043961288625, 3.070529540648408}, {4.808066453116755, 
             3.1601908340518015`}, {4.949632919246055, 3.2502603730577104`}, {
             5.083959769756044, 3.3357514610814736`}, {5.215194631265856, 
             3.419283061338122}, {5.340245514775313, 3.498895686060542}, {
             5.403049358412635, 3.5388888439730515`}}]}, 
           {Arrowheads[{{0.005875820968035289, 1.}}], 
            ArrowBox[{{5.422965997510969, 3.5515716551899246`}, {
             5.459662528105572, 3.574939813218378}, {5.57399577907779, 
             3.647765920781278}, {5.656854249492381, 3.700873759411911}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.5090128507086555`, -0.1626980444322418}, \
{-1.6541163082489403`, -0.18801994109340728`}, {-1.8198358075602377`, \
-0.21553518289511286`}, {-2.0070073073351518`, -0.24514123868849427`}, \
{-2.2231832634713258`, -0.27788234715509286`}, {-2.4419190518864475`, \
-0.3098215635896069}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.465283283444307, -0.31323314636698196`}, \
{-2.4666953092604555`, -0.3134393266106442}, {-2.610803000296496, \
-0.3340012047651293}, {-2.7396786144892395`, -0.35216696632677474`}, \
{-2.900565789332546, -0.37459293201724403`}, {-3.0446544853302613`, \
-0.39449474970134535`}, {-3.22311035533796, -0.41893931990328653`}, \
{-3.3831818267525455`, -0.44071837029689076`}, {-3.400789628608866, \
-0.44309939001760107`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.424188654954197, -0.4462635296205042}, \
{-3.5844625849610807`, -0.46793661472085457`}, {-3.7649576817663166`, \
-0.4922217752602714}, {-3.962221784428291, -0.5186453682160991}, \
{-4.141333689748308, -0.5425565276813674}, {-4.305477630880793, \
-0.5644060210848068}, {-4.360302949633057, -0.5716886797832825}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.383709344620642, -0.5747978415708599}, \
{-4.457837840980174, -0.5846446158551475}, {-4.599805395968344, \
-0.6034663650758649}, {-4.733409611653867, -0.621153687254043}, \
{-4.741320472488508, -0.6222002230097128}, {-4.879044420051977, \
-0.6403965608150676}, {-5.009613863788884, -0.6576291090742682}, \
{-5.137136416900275, -0.6744525802750545}, {-5.258565188760634, \
-0.6904578973590123}, {-5.3200461831847035`, -0.6985523053128291}}]}, 
           {Arrowheads[{{0.006693607603416995, 1.}}], 
            ArrowBox[{{-5.343456158438998, -0.7016343942034217}, \
{-5.485664330530342, -0.7203571063205061}, {-5.656854249492381, \
-0.7428667512690215}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0190124894517838`, -0.5799320138110984}, {
             1.0978860927338174`, -0.5079492985210422}, {
             1.193595649082068, -0.43543805930761065`}, {
             1.2768188365932533`, -0.3933912674872844}, {
             1.3711901610595338`, -0.36684066038227925`}, {
             1.4863475500951893`, -0.3536018396267592}, {
             1.6342974493859308`, -0.3533434393043167}, {
             1.8244633425337307`, -0.36677152524591333`}, {
             1.8958921765779295`, -0.37443599225693197`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.9193694009423834`, -0.3769551487580768}, {
             1.9717576127039225`, -0.3825765161818278}, {
             2.103593350984883, -0.39900475009402725`}, {
             2.2540480375183303`, -0.4198056322903714}, {
             2.3888693551220155`, -0.4395120388743607}, {
             2.5488047448537268`, -0.46393211026794245`}, {
             2.6922527317564913`, -0.4864513158329275}, {
             2.853981669975158, -0.5124286846492992}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.8772906763685064`, -0.5161990390987754}, {
             3.023743138859005, -0.5400989753063016}, {
             3.20138771940763, -0.5694766481112415}, {
             3.3618106743265805`, -0.5962524352638205}, {
             3.4948183807117514`, -0.6186048605671892}, {
             3.6199711894294193`, -0.6397053149258161}, {
             3.808873595765343, -0.6717346111459181}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.832153327623232, -0.6756817997607361}, {
             3.846712113862247, -0.6781503108088448}, {
             4.048726192434595, -0.7126055421981687}, {
             4.2327061699559945`, -0.74408912837905}, {
             4.401714998946693, -0.7730910254568196}, {
             4.5588156319269375`, -0.8001011895368092}, {
             4.705380127595553, -0.8253436785783854}, {
             4.7630492838390115`, -0.8352884478951735}}]}, 
           {Arrowheads[{{0.01870795254043335, 1.}}], 
            ArrowBox[{{4.786317838810399, -0.8393009985652157}, {
             4.843418139459189, -0.8491476714638825}, {
             4.850511979588202, -0.8503717187417565}, {
             4.992415492747572, -0.8748834402156211}, {
             5.127022911327494, -0.8981553377203274}, {
             5.258514865336024, -0.9208960774484994}, {
             5.383775890201774, -0.9425745016236035}, {
             5.618154448692849, -0.9831735763481062}, {
             5.656854249492381, -0.9898835773503102}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.2880206746459952`, 0.4710924239531011}, {
             1.3919151866520652`, 0.44725809774807734`}, {1.5160286300085741`,
              0.4381465983349706}, {1.6717059540776524`, 
             0.44369010099630746`}, {1.8832753029632228`, 
             0.4665811521849864}, {2.0271515094356976`, 
             0.48765290087775487`}, {2.156001060698535, 0.5086546032047301}, {
             2.223852831544585, 0.5206148611228605}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.2471063303268486`, 0.5247137643565849}, {
             2.3065675132448784`, 0.5351950100919447}, {2.4415183007807553`, 
             0.5600826529440767}, {2.6029171036173415`, 0.5909371590179454}, {
             2.7477043791243987`, 0.6192689494426633}, {2.924825045855232, 
             0.6546024504794008}, {3.0836832625102333`, 0.6867186711733838}, {
             3.174150116333488, 0.7052125607771185}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1972836751987397`, 0.7099416904606964}, {
             3.2638699370595745`, 0.7235537364635949}, {3.4266255059495054`, 
             0.7570794932841985}, {3.5618253766148085`, 0.785085099429048}, {
             3.6890519015651715`, 0.8115061226847277}, {3.919584914321079, 
             0.8595944205285775}, {4.122025126907638, 
             0.9020180048445879}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.145132973782952, 0.9068712109757011}, {
             4.312177482516815, 0.9419661401005679}, {4.484141441962972, 
             0.9781695593507534}, {4.644020826562028, 1.0118746420883495`}, {
             4.793204980976127, 1.0433628179607177`}, {4.933728994254244, 
             1.0730474434517925`}, {4.940242493728942, 1.0744239009541112`}, {
             5.069296509890949, 1.1017135332701136`}}]}, 
           {Arrowheads[{{0.012217567195157042`, 1.}}], 
            ArrowBox[{{5.092397502133772, 1.1065992644809304`}, {
             5.221630548060525, 1.1339403924658968`}, {5.355457188337479, 
             1.1622581846388074`}, {5.48295626496658, 1.1892469339754548`}, {
             5.656854249492381, 1.2260730444745562`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.36416663073095523`, 
             1.692517830068053}, {-0.29558410903272675`, 
             1.7136779319131752`}, {-0.2270873740257832, 
             1.728873025336524}, {-0.0868155629501055, 1.747289839120583}, {
             0.052803985776571916`, 1.7513487234312484`}, {
             0.19146236686233314`, 1.7479343797318958`}, {0.3270839889654229, 
             1.744400709385459}, {0.45663966000500955`, 1.7439012047892122`}, 
             {0.5739471079450538, 1.750007837446512}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5975271728122376, 1.751235336609675}, {
             0.6109544239271697, 1.7519343143096937`}, {0.7493611062748542, 
             1.7734234991282456`}, {0.9828277165259879, 
             1.8500717516266898`}, {1.168702605373492, 1.9546047024900024`}, {
             1.280969197502476, 2.0346214476809235`}, {1.3815490726032649`, 
             2.114736334045321}, {1.43092807038593, 2.1578299211609897`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4487180728623623`, 2.1733554493395957`}, {
             1.4977067512312976`, 2.2161084004680265`}, {1.6016294515548346`, 
             2.3132914837784417`}, {1.724020855814896, 2.4345609029484785`}, {
             1.8335918283793378`, 2.5479210600955824`}, {1.9648144335643227`, 
             2.688754888213165}, {2.082388318856944, 2.8184492755204857`}, {
             2.1086883034235764`, 2.848152004449977}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.1243411696817067`, 2.865830069707274}, {
             2.2259057099885298`, 2.980535232439931}, {2.354490291034154, 
             3.12835709908588}, {2.501408068289437, 3.299831685236014}, {
             2.6338972586760145`, 3.4561784938866578`}, {2.739809641981088, 
             3.582191502742427}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.7549781883326263`, 3.6002868325348976`}, {
             2.84887260289827, 3.7124401547704795`}, {2.946380711292633, 
             3.8294281436844857`}, {3.0372357772091525`, 
             3.9389875715798897`}, {3.122873668409905, 4.042637142563658}, {
             3.2047302526569657`, 4.141895560742756}, {3.3570995002900132`, 
             4.327238938686946}, {3.3574429737523883`, 4.32765816176185}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3724073145775133`, 4.3459227372292855`}, {
             3.4969371886884404`, 4.497916420761971}, {3.6268369864323926`, 
             4.656826722317342}, {3.747952554975385, 4.805293379271006}, {
             3.863027401238314, 4.946557495976118}, {3.9696080357675467`, 
             5.077627449457526}}]}, 
           {Arrowheads[{{0.015335512433847289`, 1.}}], 
            ArrowBox[{{3.9845024213059337`, 5.0959491161201225`}, {
             4.091160030715287, 5.227234462050303}, {4.199173077844892, 
             5.3599982908815855`}, {4.301136678412842, 5.484935964546181}, {
             4.397226726656626, 5.60202780988823}, {4.442599415554922, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.36241322315825886`, -1.6907333020387236`}, \
{-0.2941526783949049, -1.7116351931948433`}, {-0.22597317350806173`, \
-1.7266667732997911`}, {-0.08442508080879302, -1.745016463626798}, {
             0.05646144956365724, -1.7489115515578335`}, {
             0.19629217743791466`, -1.7453403481240606`}, {
             0.32951126685706983`, -1.7417324165530277`}, {
             0.45686628695075815`, -1.7411272905436375`}, {
             0.5758084623552884, -1.7472614110690485`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5993891174280731, -1.7484775194830124`}, {
             0.612899208711013, -1.7491742658470082`}, {
             0.7526640832694184, -1.7709500496693549`}, {
             0.877274270745309, -1.8046956236640057`}, {
             0.9878431312580206, -1.8486519694842902`}, {
             1.1747486732937695`, -1.9543176687349844`}, {
             1.2883411236335465`, -2.035508615497394}, {
             1.3899718447814602`, -2.1166884708781133`}, {
             1.432879760672728, -2.1542277530943243`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4506506521179825`, -2.169775152573888}, {
             1.506220204905827, -2.2183918490831696`}, {
             1.6102232318712344`, -2.3157989305666815`}, {
             1.7328396876600756`, -2.437385578654378}, {
             1.8426098437953966`, -2.5509781771280764`}, {
             1.9741238245713433`, -2.6920951115807075`}, {
             2.091957101172739, -2.8220068880906175`}, {
             2.1113346197979115`, -2.8438742067786573`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.12699442461332, -2.861546125929657}, {
             2.235840251044251, -2.9843774553928775`}, {
             2.3647493666515462`, -3.13242783291582}, {
             2.511999581136711, -3.304096680323192}, {
             2.6447904210771536`, -3.460606420182306}, {
             2.743070188270835, -3.577385635999057}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.758268683179418, -3.5954558241105157`}, {
             2.860395522847401, -3.717279832924863}, {
             2.9581852740083106`, -3.8344456327730154`}, {
             3.0492998253530765`, -3.94416416160575}, {
             3.1351802180524224`, -4.047959268823722}, {
             3.21726749327707, -4.147354803827585}, {
             3.361326388232855, -4.32233562576188}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.3763214138405035`, -4.340575007562451}, {
             3.5102876793762996`, -4.503847084543157}, {
             3.6405447174467773`, -4.662960448719305}, {
             3.7619912254340973`, -4.811613611563649}, {
             3.877375418747934, -4.953048906972873}, {
             3.974092383112185, -5.071813929559518}}]}, 
           {Arrowheads[{{0.015503247466972753`, 1.}}], 
            ArrowBox[{{3.989002387169578, -5.090122888905824}, {
             3.9947869767272888`, -5.097226160953204}, {
             4.106123642565609, -5.234069932313972}, {
             4.214407749417635, -5.366960513013465}, {
             4.316586738297073, -5.491944712390412}, {
             4.412876964235322, -5.609070401724815}, {
             4.452487868672072, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6203653980101053, 
             2.512343570670601}, {-0.5583528064661529, 
             2.6076027705974707`}, {-0.4987229773467943, 
             2.6771531511622593`}, {-0.4407868602666469, 
             2.729545761581234}, {-0.3327497118744269, 
             2.8085460822760133`}, {-0.23320683701818654`, 
             2.862779398515848}, {-0.16698852425511432`, 
             2.888333869706297}, {-0.1019694217991572, 
             2.9053192140729824`}, {-0.03731149260929624, 
             2.9142369511507478`}, {-0.005104130260379366, 
             2.9157374314635134`}, {0.02824468800392458, 
             2.9163764166037787`}, {0.06088148308141808, 2.917926104356119}, {
             0.09355679565816616, 2.9202923603751496`}, {0.1725522866628535, 
             2.9283921737521714`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.19585839139141942`, 2.932177245680948}, {
             0.2511645760075522, 2.941202489095263}, {0.32749544308915474`, 
             2.958394454779197}, {0.5133295392077775, 3.0218483343511067`}, {
             0.6818320671203418, 3.124418353935603}, {0.841635553729639, 
             3.28103235253644}, {0.9593918882524153, 
             3.4337085550493414`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.9738124514983779, 3.4524054416619663`}, {
             0.9824810514688009, 3.4636446580485094`}, {1.0764092819308893`, 
             3.605919911337535}, {1.1612181461993238`, 3.747682690957638}, {
             1.2382470961047747`, 3.8864786313941977`}, {1.3181244284294613`, 
             4.038818426543297}, {1.3910085073888538`, 4.1851099534135034`}, {
             1.4342503778936544`, 4.275738754257085}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.444418313378085, 4.297049298626495}, {
             1.4579186358709955`, 4.325344051472543}, {1.5198741167639291`, 
             4.45951156018814}, {1.577426066641379, 4.587901745767026}, {
             1.6315664953360483`, 4.711035287381315}, {1.7076692126328883`, 
             4.889601540825926}, {1.7776712360622948`, 5.057760594900118}, {
             1.8209200096128884`, 5.163112258102769}}]}, 
           {Arrowheads[{{0.010763915569100946`, 1.}}], 
            ArrowBox[{{1.8298869856277753`, 5.184955324611037}, {
             1.8429725072703333`, 5.216830944559082}, {1.9039783121515446`, 
             5.367732009695884}, {1.9613558023789746`, 5.511382403189018}, {
             2.015536667528412, 5.6485003933713465`}, {2.0188087663169294`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01487500379404532, 1.}}], 
            ArrowBox[{{0.37690651615536047`, -5.031054303037838}, {
             0.418566100886133, -5.093765065828955}, {
             0.4583159898988872, -5.15965992243284}, {
             0.5211674486903068, -5.27062023232261}, {
             0.5792205930453327, -5.387164458063552}, {
             0.6327475390391502, -5.507354645908315}, {
             0.6820204027469445, -5.6292528421095485`}, {
             0.6922508601500452, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019172946240007538`, 1.}}], 
            ArrowBox[{{-0.18040777857429974`, -5.0201897095022305`}, \
{-0.13368291966827583`, -5.10278587960435}, {-0.0879017959515917, \
-5.160784892016836}, {-0.0415170215268497, -5.196530383647752}, \
{-0.010735145230828858`, -5.208175526156287}, {
             0.02108324954693071, -5.214603671723954}, {
             0.05400209565691985, -5.225677550694449}, {
             0.0873158315256652, -5.2421074898471725`}, {
             0.17650233647211883`, -5.303889536987287}, {
             0.26463876319409935`, -5.399099240226674}, {
             0.3487786909514681, -5.521782990743095}, {
             0.41378659484332897`, -5.638923831419601}, {
             0.42231551328882533`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6873876848458134, -2.2057081969677963`}, \
{-0.5905541947161551, -2.3585202298466386`}, {-0.5153343098563022, \
-2.4472409101309123`}, {-0.44275218875165634`, -2.5086550854381877`}, \
{-0.37241899492997943`, -2.553354689182977}, {-0.291705634498227, \
-2.595210966815998}, {-0.2143397665116478, -2.6259268912573392`}, \
{-0.13903907054777778`, -2.6468819442017706`}, {-0.025293381130683433`, \
-2.6617433578933234`}, {0.07641352021300582, -2.6662107652100357`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.09998085936824108, -2.667611783492502}, {
             0.20234569111142292`, -2.6754115950810466`}, {
             0.32096359472567115`, -2.6920679143694675`}, {
             0.4334674579224126, -2.7158654613276894`}, {
             0.5401836190193414, -2.7507787386812614`}, {
             0.6852098920536696, -2.830627669395285}, {
             0.8192082130252513, -2.9403636830226088`}, {
             0.926601339454336, -3.0535239985123375`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9424658284760752, -3.070988377998514}, {
             1.0441451908861992`, -3.199752772285047}, {
             1.1372991912908343`, -3.334045984106566}, {
             1.2201812855444016`, -3.4658649231403804`}, {
             1.2947284334724019`, -3.593653882567729}, {
             1.3636295110481373`, -3.7171259054461174`}, {
             1.428674569059862, -3.836422558261305}, {
             1.4455916186717703`, -3.8682503578330545`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.4566736668209257`, -3.8891001641188683`}, {
             1.4898636075075755`, -3.951543841013292}, {
             1.5471966263912782`, -4.062489753702078}, {
             1.6534555571155702`, -4.2731375959443865`}, {
             1.7506123128816575`, -4.469648212042568}, {
             1.8401064514005991`, -4.653605969368516}, {
             1.8787778211838062`, -4.733942767604457}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.8890190707688632`, -4.7552181764201}, {
             1.923377530383454, -4.826595235294123}, {
             2.0011149346472963`, -4.98958721670519}, {
             2.0746670447840834`, -5.144762810557309}, {
             2.1607015595433023`, -5.327729163105129}, {
             2.241735768990444, -5.500737690957877}, {
             2.2926256842419446`, -5.609111561980115}}]}, 
           {Arrowheads[{{0.0006168982920869416, 1.}}], 
            ArrowBox[{{2.3026619090626506`, -5.630484451459182}, {
             2.315044568964439, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8497197392092553, 
             3.692816646213257}, {-0.8517580532015991, 
             3.840545329821718}, {-0.8546698443355474, 
             3.970193459430511}, {-0.8595146360066253, 
             4.12861110487405}, {-0.864723751975278, 
             4.267985441473659}, {-0.8724347002159953, 
             4.445418008959335}, {-0.8799331705662166, 
             4.601150933613976}, {-0.8817733738026104, 
             4.636682720022507}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.8829946101792993, 
             4.660263110075439}, {-0.8871058690563486, 
             4.739645848568908}, {-0.8938395017167982, 
             4.865364386955454}, {-0.9001241368661798, 
             4.9800432430502415`}, {-0.9059668052906562, 
             5.086430897058009}, {-0.912275077856263, 
             5.203519387437734}, {-0.9192552553702873, 
             5.314265517240564}, {-0.9330421945395293, 
             5.510504362912572}, {-0.9408257384983368, 
             5.602923382466922}}]}, 
           {Arrowheads[{{0.0006460658107774037, 1.}}], 
            ArrowBox[{{-0.9428073288332139, 
             5.626452077991342}, {-0.9453678043658761, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.758442867729037, -1.2995668604098436`}, \
{-1.8534444001378443`, -1.393390273235455}, {-1.9383370042236319`, \
-1.4747006202599848`}, {-2.0155530420932717`, -1.54697952358171}, \
{-2.1191965024772887`, -1.642131381421321}, {-2.21283514948873, \
-1.7264755674742538`}, {-2.3781094932742173`, -1.872384031627601}, \
{-2.454018381592734, -1.9381771732190558`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.4718610742412763`, -1.9536421184949309`}, \
{-2.52219701853753, -1.997270209797318}, {-2.650740110141751, \
-2.1072790676473536`}, {-2.76806055616493, -2.2068871145568787`}, \
{-2.87642609986756, -2.298353286660704}, {-2.9769021087137157`, \
-2.3826779982065753`}, {-3.070553950167469, -2.460861663442237}, \
{-3.1935029911803263`, -2.562937714521124}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2116699180541, -2.5780204523793215`}, \
{-3.2579417961553117`, -2.616436779612662}, {-3.4256410112805074`, \
-2.7548698790742763`}, {-3.578019908875398, -2.8801219326278376`}, \
{-3.719291134539146, -2.9959216331848744`}, {-3.852031838653605, \
-3.104526713181195}, {-3.941468430892322, -3.1775465391083038`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.959758687502436, -3.1924794800936667`}, \
{-3.9762420212187743`, -3.2059371726167996`}, {-4.091921682234654, \
-3.3001530114916884`}, {-4.200938884044725, -3.388778269380874}, \
{-4.305161688992471, -3.4734169858593686`}, {-4.4045900970778895`, \
-3.554069160927173}, {-4.499224108300982, -3.6307347945842863`}, \
{-4.677413822385629, -3.7748953190183356`}, {-4.693150264518016, \
-3.787607479010401}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.711517889772773, -3.802445152542224}, \
{-4.843035713471854, -3.908687440513411}, {-4.99755103968686, \
-4.033332841119717}, {-5.1451373237915226`, -4.152258924006099}, \
{-5.292902176246813, -4.271156589018755}, {-5.4301006850520634`, \
-4.382202451997622}, {-5.446525170973042, -4.395576672468355}}]}, 
           {Arrowheads[{{0.0052581029285020345`, 1.}}], 
            ArrowBox[{{-5.464834759134466, -4.410485904329695}, \
{-5.561432362660837, -4.48914393068874}, {-5.656854249492381, \
-4.567918327355966}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5039307633936787`, 
             1.8240600026413658`}, {-1.603843711618793, 
             2.0133711966800933`}, {-1.7244033154525282`, 
             2.22325481411823}, {-1.7997564439691796`, 
             2.3474876043876245`}, {-1.868931378332857, 
             2.4581703371452956`}, {-1.958283209795794, 
             2.5972527207625964`}, {-1.9842416658726514`, 
             2.6367263435640784`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.997215358303722, 
             2.656454737265547}, {-2.0399644146227933`, 
             2.7214609194229964`}, {-2.1445150807883753`, 
             2.8770854955700003`}, {-2.2397592963208623`, 
             3.016341183789517}, {-2.3606882505045683`, 
             3.190284127835947}, {-2.470554016343167, 
             3.3461749923514814`}, {-2.533238731024439, 
             3.4340207358040167`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.546953903720346, 
             3.4532410441068926`}, {-2.60849506706017, 
             3.539484225941713}, {-2.7336085773352203`, 
             3.713013042428442}, {-2.8150550638387752`, 
             3.8251060070385026`}, {-2.892708615586483, 
             3.931592907252837}, {-3.0366369148143555`, 
             4.127748514494328}, {-3.1025279782795865`, 4.217020012994281}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.1165500414894622`, 
             4.236017590647087}, {-3.1173565185160634`, 
             4.237110233698879}, {-3.1946775870806374`, 
             4.341599071745962}, {-3.339124118798382, 
             4.53595810436772}, {-3.472261566955214, 
             4.71422866852103}, {-3.5963749885387584`, 
             4.8798138203673185`}, {-3.6814509062358227`, 
             4.992934545567337}}]}, 
           {Arrowheads[{{0.017165956530729422`, 1.}}], 
            ArrowBox[{{-3.695643219042731, 
             5.0118052760918035`}, {-3.712488446471456, 
             5.034203439925684}, {-3.823098139031457, 
             5.180891100796873}, {-3.935000926774018, 
             5.328770119921836}, {-4.0399688908879785`, 
             5.466513156454546}, {-4.141110611260618, 
             5.598389568875323}, {-4.186604819596012, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.8599548250666131`, 
             1.5797649779427723`}, {-1.9721480686556383`, 
             1.7016189997880373`}, {-2.071680020846906, 
             1.806461413511243}, {-2.174486507237401, 
             1.9116979803648877`}, {-2.2677984520224115`, 
             2.00542490049715}, {-2.4332950375858666`, 
             2.1683529501523977`}, {-2.5215026279335024`, 
             2.2535948752236177`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.538481820661034, 
             2.270003203220629}, {-2.5782213791267194`, 
             2.308406660924722}, {-2.707920503863806, 
             2.4321383721449643`}, {-2.826541515446828, 
             2.544376928707352}, {-2.9362828872611964`, 
             2.647578737640567}, {-3.03819158091709, 
             2.7428464629893488`}, {-3.1333145580246873`, 
             2.831282768798437}, {-3.2262270707985334`, 2.917318057124427}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.243573226846198, 
             2.933337941579533}, {-3.3232391602259206`, 
             3.006835097677051}, {-3.4935552301904065`, 
             3.163311462366244}, {-3.6485534171240483`, 
             3.305070571974534}, {-3.7924039878038274`, 
             3.4362421116242317`}, {-3.9276660313081377`, 
             3.5593322250506327`}, {-3.9403970624983673`, 
             3.570890909346797}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.9578787573908487`, 
             3.5867627887888274`}, {-4.054339547636981, 
             3.6743409122537374`}, {-4.172424536790356, 
             3.7812681732335456`}, {-4.283788484016235, 
             3.881906145685061}, {-4.390298874562591, 
             3.9780469673032877`}, {-4.4919557084294235`, 
             4.069690638088226}, {-4.5887589856167335`, 
             4.156837158039876}, {-4.658806675081919, 4.219803042763544}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.676366930718872, 
             4.2355879607329525`}, {-4.771130541952017, 
             4.3207709934134275`}, {-4.940739215567672, 
             4.472980721394059}, {-5.099060620814609, 
             4.614842208618591}, {-5.2498058379866155`, 
             4.749753440267145}, {-5.379769844701913, 4.865877943142117}}]}, 
           {Arrowheads[{{0.007364966066156833, 1.}}], 
            ArrowBox[{{-5.39737718309985, 
             4.881610325284587}, {-5.4030002999549005`, 
             4.886634652141724}, {-5.5484059970166415`, 
             5.016436474201699}, {-5.656854249492381, 
             5.113210443781438}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.0064744248321156`, -0.9413805706330672}, \
{-2.219571895497066, -1.0624920636246205`}, {-2.39504957368983, \
-1.1588164999348922`}, {-2.5465678326556414`, -1.2402353029228905`}, \
{-2.6808879351589647`, -1.3113556320774788`}, {-2.8030175448991144`, \
-1.3754239871340463`}, {-2.8360830379268265`, -1.3926512988665862`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.8570233677549632`, -1.4035613309483452`}, \
{-2.9155230423759915`, -1.4340399973364126`}, {-3.116314485851215, \
-1.5376437784358064`}, {-3.305950073906314, -1.6345454326921425`}, \
{-3.475571221042637, -1.7206422156612198`}, {-3.629643160044412, \
-1.7984561550591902`}, {-3.698228319620396, -1.8329812818045284`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.719318846631477, -1.8435980555014215`}, \
{-3.7724558339445613`, -1.8703467170659862`}, {-3.9066284091229457`, \
-1.9377378148465798`}, {-4.0321608855795645`, -2.0006294484009706`}, \
{-4.149053263314418, -2.0590216177291585`}, {-4.364496715550586, \
-2.1663375085517838`}, {-4.560537758763208, -2.2637154321593127`}, \
{-4.564289353091272, -2.2655743780382966`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.585446437892638, -2.276057887758042}, \
{-4.7405233051634825`, -2.3528997523440687`}, {-4.907800266962608, \
-2.435634832898374}, {-5.063847281016406, -2.5126830175484622`}, \
{-5.210825761143342, -2.585156727500875}, {-5.214777465399466, \
-2.587104006853714}, {-5.365884431543183, -2.661475300642743}, \
{-5.4323357848761145`, -2.6941721484311896`}}]}, 
           {Arrowheads[{{0.004803440590993928, 1.}}], 
            ArrowBox[{{-5.453522003836987, -2.7045966551091154`}, \
{-5.508851778300476, -2.731821220495133}, {-5.645351237843552, \
-2.79938036934273}, {-5.656854249492381, -2.8051508443561275`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.850086727966021, 1.6099921460095847`}, {
             1.9790757248337079`, 1.692629729782023}, {2.094486104108504, 
             1.7699981930289692`}, {2.234240030669188, 1.8671818934817648`}, {
             2.359398721985172, 1.95638301268191}, {2.5120920870338304`, 
             2.067438926797939}, {2.624459398867907, 
             2.1503106515540993`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.643462332278992, 2.1643254556950797`}, {
             2.648987124255807, 2.1684000306988294`}, {2.816334661740425, 
             2.293301558817665}, {2.9665208708633197`, 2.4063865407637786`}, {
             3.152589391225522, 2.547558544633271}, {3.319543688965463, 
             2.6749489860186237`}, {3.3967031019195746`, 
             2.7341082825522536`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.4154412904244875`, 2.748475136936235}, {
             3.5096457399880348`, 2.8207031225202064`}, {3.6814790351766855`, 
             2.9529038912155916`}, {3.8252939990326458`, 
             3.0638298152470766`}, {3.9606583159222497`, 
             3.1683600013924216`}, {4.087571985845496, 3.266494449651626}, {
             4.163386412720483, 3.32520574686135}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.182055037434641, 3.3396628788251266`}, {
             4.2060350088023855`, 3.3582331600246906`}, {4.317852117633091, 
             3.4449188919842144`}, {4.424828045177787, 3.527894405002797}, {
             4.52696279143647, 3.6071596990804387`}, {4.624256356409144, 
             3.6827147742171387`}, {4.807602120924939, 3.8251787888344806`}, {
             4.928095027328296, 3.9188571737741102`}}]}, 
           {Arrowheads[{{0.019116358576135455`, 1.}}], 
            ArrowBox[{{4.946736078968486, 3.933349841129843}, {
             4.9781475171536504`, 3.9577709700215866`}, {5.137361121354233, 
             4.081612460746424}, {5.289263842190579, 4.19980295310927}, {
             5.413770513281705, 4.297243687133163}, {5.528174644332658, 
             4.387870966925687}, {5.637930304616672, 4.47540300561363}, {
             5.656854249492381, 4.490725748627478}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.3670180740144093`, 
             2.8131186161994357`}, {-1.412825219130751, 
             2.954532226359789}, {-1.4559496056898782`, 
             3.080862897316031}, {-1.5144927167818723`, 
             3.2442481407211754`}, {-1.5690667161457066`, 
             3.3902432331312786`}, {-1.6386978452144076`, 
             3.569479170652254}, {-1.6910726536950806`, 
             3.7000016665123687`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.6998659208143465`, 
             3.7219152391719192`}, {-1.7033037601192182`, 
             3.7304826283319854`}, {-1.7895931995627745`, 
             3.9391862133425346`}, {-1.8690657400728212`, 
             4.126474709965334}, {-1.96298053746715, 
             4.342695812142203}, {-2.049692647885153, 
             4.5385963814063395`}, {-2.072661968928057, 4.589655405216718}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.082348957679826, 
             4.611188831842763}, {-2.130350784479693, 
             4.717893179478377}, {-2.2061036604036333`, 
             4.884302968078952}, {-2.2774786937023728`, 
             5.0393928666032055`}, {-2.345704963129913, 
             5.186410173261596}, {-2.4164192535066307`, 
             5.337095537641832}, {-2.4784998951440813`, 5.468553192371436}}]}, 
           {Arrowheads[{{0.003915635373601831, 1.}}], 
            ArrowBox[{{-2.488602881473546, 
             5.489894591138013}, {-2.5496074980539873`, 
             5.618392448080173}, {-2.5680809463685095`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.046394588808516, -0.47182259844933594`}, \
{-2.2628561452390548`, -0.5322957114338713}, {-2.440837287487219, \
-0.5804281698504647}, {-2.594347253158488, -0.6211015224992731}, \
{-2.730329106082014, -0.6566157571773632}, {-2.9588544054109502`, \
-0.715561415635068}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.981729497086022, -0.7214141970713241}, \
{-3.170711663728399, -0.7695183512482746}, {-3.3628798608036496`, \
-0.8179588202667397}, {-3.5346575336778754`, -0.8609676166908324}, \
{-3.6906175903138663`, -0.8998189526096969}, {-3.835138579203577, \
-0.9357011908019421}, {-3.8978205163704334`, -0.9512291880830788}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.920739720482234, -0.9569068897499321}, \
{-3.9708887098018533`, -0.969330139652594}, {-4.097867982108695, \
-1.0007057991616521`}, {-4.216076396124102, -1.029828169329117}, \
{-4.433888485202516, -1.0833355749788707`}, {-4.632032812959, \
-1.1318748899414597`}, {-4.813907137731376, -1.1763197079778214`}, \
{-4.837958452185427, -1.1821864365935368`}}]}, 
           {Arrowheads[{{0.0173461341452782, 1.}}], 
            ArrowBox[{{-4.860897861898909, -1.1877819433027776`}, \
{-4.9829092178574665`, -1.217543622848892}, {-5.140538630763528, \
-1.2559279545581794`}, {-5.288987205575471, -1.2920290540041157`}, \
{-5.294699118201264, -1.2934172299291018`}, {-5.4473804892486575`, \
-1.3304796444182405`}, {-5.592217717098964, -1.365601914657736}, \
{-5.656854249492381, -1.3813430443614854`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6231517536152099, -2.7591436627338184`}, \
{-0.5490975690000136, -2.8888608523364923`}, {-0.4308419676699102, \
-3.0370623306351883`}, {-0.3272275778380454, -3.1338075983131883`}, \
{-0.23331098676749007`, -3.200348300205245}, {-0.19580505979705645`, \
-3.2208788378052944`}, {-0.15841106169544544`, -3.2378723041839264`}, \
{-0.12196200199509025`, -3.2493999386717696`}, {-0.08551003360685852, \
-3.2575918316742642`}, {0.0019556141469294352`, -3.2677560317354057`}, {
             0.09067494666773812, -3.2730086053344327`}, {
             0.10282814661214917`, -3.2749272139104746`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12615129276093964`, -3.278609206178028}, {
             0.17981319126342188`, -3.287080734593958}, {
             0.25669119105394844`, -3.3063760105293953`}, {
             0.33149310270392063`, -3.331759494201846}, {
             0.40340124858745285`, -3.3626406741038375`}, {
             0.5614860879237791, -3.455220822070846}, {
             0.7025905653976859, -3.5774605423464263`}, {
             0.8370585426262122, -3.7408319674890604`}, {
             0.8766408001156457, -3.8011649204647027`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.889593100557252, -3.820907365262815}, {
             0.9628775657645262, -3.932610650361596}, {
             1.027249704171872, -4.0433718822714075`}, {
             1.0881238569974812`, -4.155178019197806}, {
             1.1456084871889738`, -4.266543476640484}, {
             1.2000062074065534`, -4.376722377219725}, {
             1.3005250020364145`, -4.5912240038943155`}, {
             1.3290866043129412`, -4.655549551430081}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.338668629844169, -4.6771298897048865`}, {
             1.3916400696715667`, -4.7964305100855436`}, {
             1.4850029875667232`, -5.016383567611507}, {
             1.570190555523042, -5.224193102834816}, {
             1.6487338371679896`, -5.420353228955205}, {
             1.6995259705230918`, -5.549856146628483}}]}, 
           {Arrowheads[{{0.001931745910237541, 1.}}], 
            ArrowBox[{{1.7081473967466838`, -5.571837894129701}, {
             1.7216411799412767`, -5.60624251899421}, {
             1.7412250467333346`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.4046880136071963, -3.9774689495847446`}, \
{-0.3029231224694909, -4.18703033635476}, {-0.21847079407059994`, \
-4.324716812209495}, {-0.1322931115520148, -4.422235593202368}, \
{-0.04793764866402771, -4.472393406830025}, {
             0.03867849230992301, -4.49322994062225}, {
             0.07327625227936531, -4.500217293686259}, {
             0.1082840672384049, -4.510878323501457}, {
             0.14330924971006279`, -4.526873238943454}, {
             0.17814113111562752`, -4.54624778223009}, {
             0.24619551374111476`, -4.592653998251163}}]}, 
           {Arrowheads[{{0.005204417166919621, 1.}}], 
            ArrowBox[{{0.2657036540441391, -4.6059565797770805`}, {
             0.26787061071939683`, -4.607434225384913}, {
             0.35395741008804465`, -4.687860706008658}, {
             0.4348041094569699, -4.783641107561626}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.2535755243927493`, -0.04538131956643478}, \
{-2.4310709005944866`, -0.04946478650406879}, {-2.5840121672827996`, \
-0.05291025112941023}, {-2.719396458115568, -0.05591496223020553}, \
{-2.955597210187672, -0.061089017048144886`}, {-3.157464096714357, \
-0.06544920940146787}, {-3.1978231700286543`, -0.06631186258066482}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.221429771100257, -0.06681644080291152}, \
{-3.3492022510472506`, -0.06954750787131982}, {-3.5204795644393734`, \
-0.07318156285346392}, {-3.67590916341978, -0.07646103546241324}, \
{-3.819893331078424, -0.07948778658008057}, {-3.955111355808202, \
-0.08232306970403327}, {-4.165699758223533, -0.08671892097533015}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.189306608679677, -0.08721169361807185}, \
{-4.199248976481162, -0.08741923197079492}, {-4.416042690599364, \
-0.09192200525039748}, {-4.613213163323518, -0.09600387253054028}, \
{-4.794156069836839, -0.09973908341147872}, {-4.9622670853225435`, \
-0.10320188749346818`}, {-5.119043377050917, -0.10642463749707198`}, \
{-5.133584767627397, -0.1067230787487533}}]}, 
           {Arrowheads[{{0.010582909601919419`, 1.}}], 
            ArrowBox[{{-5.157191789310122, -0.10720757911771084`}, \
{-5.266672682431643, -0.10945451792363374`}, {-5.273358966812391, \
-0.10959163544943859`}, {-5.425249769376437, -0.11270195265935244`}, \
{-5.56932295270461, -0.11564844243283103`}, {-5.656854249492381, \
-0.1174376673857335}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.4140032537648417`, 
             1.447320040717217}, {-2.5646033222900213`, 
             1.547733681485839}, {-2.6983115186197972`, 
             1.635611081466184}, {-2.8200006572724843`, 
             1.7148728746428936`}, {-2.93218120025942, 
             1.7874586829073222`}, {-3.1325961737192682`, 
             1.9159312745713184`}, {-3.2056760347631488`, 
             1.9623445797793655`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2256079287011765`, 
             1.9750034034758777`}, {-3.3229213481112487`, 
             2.036807536261603}, {-3.493201735363367, 
             2.144269876657441}, {-3.6479007763570914`, 
             2.241441845287158}, {-3.7913115230012284`, 
             2.3312487347549764`}, {-3.926058039620039, 
             2.4154578802571827`}, {-4.025386301150192, 
             2.4773883390238005`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.04542279171463, 
             2.4898809472061356`}, {-4.0521403262135225`, 
             2.4940692817937764`}, {-4.169558382781679, 
             2.567082939364757}, {-4.280210615619001, 
             2.635750390004235}, {-4.385995431019985, 
             2.7013231707463192`}, {-4.582962809512933, 
             2.823184722538306}, {-4.763816355436392, 
             2.9348368772255835`}, {-4.848475435905738, 2.9870196983057}}]}, 
           {Arrowheads[{{0.01959101049285558, 1.}}], 
            ArrowBox[{{-4.868575780746261, 
             2.999409304862335}, {-4.931911905966227, 
             3.0384489172930182`}, {-5.088732739952246, 
             3.1349696852977593`}, {-5.239510420516798, 
             3.227666132052587}, {-5.391339507520878, 
             3.320867906155058}, {-5.53539294437444, 
             3.4092213181379956`}, {-5.656854249492381, 
             3.4837108486409676`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7805938223108844`, -0.5806041282038821}, {
             1.9178035381541096`, -0.6042299662763179}, {
             2.0406784364518633`, -0.6285008369822702}, {
             2.1850305553088796`, -0.6599539001327464}, {
             2.314369280616314, -0.6897585367030327}, {
             2.4692808542404583`, -0.7270625041352861}, {
             2.6081790247265277`, -0.7614670279201299}, {
             2.7023010179033795`, -0.7853257626020261}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.7251891117436267`, -0.7911276048694623}, {
             2.776115482993169, -0.8040367957922636}, {
             2.9268250804973777`, -0.8428454756355568}, {
             3.1122682661703003`, -0.8912325335885767}, {
             3.2786494967146327`, -0.9350534316481808}, {
             3.4677275058617374`, -0.9852427832514468}, {
             3.638587002125261, -1.0308410795314766`}, {
             3.6387262230221724`, -1.0308783812133266`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.6615337570045146`, -1.0369892409712054`}, {
             3.780608685058572, -1.0688931805457866`}, {
             3.9142903202327575`, -1.1047744138141617`}, {
             4.039631907647816, -1.1384847793366017`}, {
             4.15663344730375, -1.1700242771131069`}, {
             4.372719838529807, -1.228391099883942}, {
             4.569652949102498, -1.2816753125822962`}, {
             4.573487934325095, -1.282714367385616}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.5962782332933445`, -1.2888891942069898`}, {
             4.7506749658818395`, -1.3307216022349884`}, {
             4.919028075727847, -1.3763746558688372`}, {
             5.0761651888027535`, -1.4190179130458405`}, {
             5.22421512075179, -1.4592143116912397`}, {
             5.229603451120344, -1.4606775898418045`}, {
             5.381629396429719, -1.501976368169058}, {
             5.507788632252126, -1.536256690190526}}]}, 
           {Arrowheads[{{0.002771888731693073, 1.}}], 
            ArrowBox[{{5.530573014255503, -1.5424533052319667`}, {
             5.656854249492381, -1.5769172570943015`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.2008669794766975`, -0.17617126875448919`}, {
             2.335169281329269, -0.18418507022596772`}, {
             2.4932543619358842`, -0.19412336263114105`}, {
             2.6349985744307642`, -0.2033181844841622}, {
             2.8053348426591183`, -0.21465120640077154`}, {
             2.9582044689378373`, -0.2249937355563467}, {
             3.1433366039614272`, -0.23769454350371336`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.166892260174431, -0.23932465114050677`}, {
             3.3140690805833017`, -0.24951979475623676`}, {
             3.5052219023081403`, -0.26286821279230965`}, {
             3.6779500655347106`, -0.27499623818017566`}, {
             3.8210774420594285`, -0.2850860836141623}, {
             3.955811685272668, -0.2946010305497356}, {
             4.1090537524689, -0.30545654771771646`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.132606723060836, -0.30712501696572203`}, {
             4.20010077176471, -0.3119062289256417}, {
             4.417954315129484, -0.3273875645757901}, {
             4.616509305485639, -0.34152076876807685`}, {
             4.799029211836466, -0.3545296314053739}, {
             4.968777503185252, -0.36663794239055325`}, {
             5.0747017445174505`, -0.37419880378340953`}}]}, 
           {Arrowheads[{{0.01185894739843966, 1.}}], 
            ArrowBox[{{5.098253813795562, -0.37587994805300384`}, {
             5.127217863174615, -0.3779473989025602}, {
             5.276495119079393, -0.38860732508180074`}, {
             5.2827809338293035`, -0.38905628186410657`}, {
             5.436082996749845, -0.40000881830400864`}, {
             5.581550993161082, -0.41040368193512694`}, {
             5.656854249492381, -0.41582391912457967`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.578409372970545, 
             0.9658668674025532}, {-2.7137059057759876`, 
             1.0217013653373528`}, {-2.8366398763804135`, 
             1.0719794645704144`}, {-2.9498334118795144`, 
             1.1179674541819622`}, {-3.151722745691003, 
             1.1992253035267324`}, {-3.343136832094531, 
             1.2755512993277203`}, {-3.4541586728365212`, 
             1.3195409131437539`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.4761103175717936`, 
             1.3282387006068128`}, {-3.514205761370112, 
             1.343333062667814}, {-3.6694991122430167`, 
             1.404576763702528}, {-3.8133885891094375`, 
             1.4611516762801713`}, {-3.9485386300293923`, 
             1.5141839045937493`}, {-4.074949235002881, 
             1.563673448643262}, {-4.1926204040299035`, 
             1.6096203084287093`}, {-4.355407107360184, 1.673023754408069}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.377409140357367, 
             1.6815932793264685`}, {-4.409430422268718, 
             1.694065180140978}, {-4.606654672770005, 
             1.7706977246641262`}, {-4.78767822670073, 
             1.840890620716927}, {-4.955886155227861, 
             1.9060165470181543`}, {-5.112772101321447, 
             1.9666748407105374`}, {-5.25809957401419, 
             2.022805455885258}}]}, 
           {Arrowheads[{{0.008549559747891112, 1.}}], 
            ArrowBox[{{-5.280128793120671, 
             2.0313048500660855`}, {-5.417242846442688, 
             2.084187954284809}, {-5.561384113128178, 
             2.1397380156122554`}, {-5.656854249492381, 
             2.1765197885951117`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.029980531645983, -2.3795457857423696`}, {
             2.1464526666658554`, -2.49320285172138}, {
             2.2897869529426584`, -2.635866718030099}, {
             2.4182761690486063`, -2.7656549564355895`}, {
             2.575159862722739, -2.926136956788203}, {
             2.6951379098188792`, -3.050011637958833}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.711565216811553, -3.0669724692564024`}, {
             2.7159511397953913`, -3.071500837773908}, {
             2.805366555562363, -3.1644378350040805`}, {
             2.8903063238296625`, -3.2529553806143086`}, {
             3.046758917865244, -3.4167321169749307`}, {
             3.138003486128915, -3.5126452903904184`}, {
             3.2249702945267607`, -3.604201736895049}, {
             3.363468854604648, -3.75038809014324}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.379708261100891, -3.7675289153855074`}, {
             3.386070631724976, -3.7742444491717455`}, {
             3.5213978777445267`, -3.9174325632608102`}, {
             3.6487663985685996`, -4.052339476460878}, {
             3.768176194197195, -4.178965188771948}, {
             3.879627264630313, -4.297309700194021}, {
             3.9848236243359207`, -4.4091146729516755`}, {
             4.0276790894139545`, -4.4546788703779}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.043856213100977, -4.47187848905248}, {
             4.085469287781986, -4.516121769269489}, {
             4.181564254968508, -4.618330989147461}, {
             4.273108525895488, -4.7157423325855925`}, {
             4.360874881926917, -4.809160492802213}, {
             4.445636104426791, -4.89939016301565}, {
             4.606143148831866, -5.07028403343298}, {
             4.690581794235145, -5.160201027014412}}]}, 
           {Arrowheads[{{0.013927877977835242`, 1.}}], 
            ArrowBox[{{4.706745414183457, -5.177413336664854}, {
             4.756010733539759, -5.229874971775069}, {
             4.898282313250533, -5.3813780637015345`}, {
             5.043128600318902, -5.535604737472902}, {
             5.157017610341948, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.585022287798042, 
             0.4630549616023613}, {-2.720650207519607, 
             0.4900047774309914}, {-2.957216751649213, 
             0.53645453390301}, {-3.1593508264859897`, 
             0.5756463341018357}, {-3.3512108906533995`, 
             0.6125062981811656}, {-3.5121532362502244`, 
             0.6432338285051186}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.5353483547172617`, 
             0.6476511347085796}, {-3.6781248122464834`, 
             0.6747853611516785}, {-3.822200950051447, 
             0.7020857579377723}, {-3.957506627503983, 
             0.7276743903102263}, {-4.084041844604092, 
             0.7515512582690405}, {-4.201806601351772, 
             0.7737163618142148}, {-4.418749076381369, 
             0.8144492523830106}, {-4.463441402859424, 0.8228214277719945}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.486649691965764, 
             0.8271690167696703}, {-4.616058395184291, 
             0.8514110387359799}, {-4.797131962142889, 
             0.885264970419162}, {-4.965367181639514, 
             0.9166742969785959}, {-5.1222618106359, 
             0.9459283694516987}, {-5.270004427399439, 
             0.9734492815112358}, {-5.2761777762771835`, 
             0.9745986859166326}, {-5.415099010734339, 
             1.000442389910903}}]}, 
           {Arrowheads[{{0.004707028623806983, 1.}}], 
            ArrowBox[{{-5.438312974618172, 
             1.004759575556715}, {-5.572349969470081, 
             1.029676952037401}, {-5.656854249492381, 
             1.0453819643249027`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5390291749315403, 
             4.581848733444243}, {-0.5140521048874164, 
             4.7738374308469975`}, {-0.4960142139515214, 
             4.939203675073285}, {-0.4831744806347213, 
             5.084223528348201}, {-0.4737918834478821, 
             5.2151730528968425`}, {-0.4672857845112714, 
             5.334311833172375}, {-0.4628405484193032, 
             5.4449350787845034`}, {-0.4614755713677019, 
             5.522547903296087}}]}, 
           {Arrowheads[{{0.0023441827942496645`, 1.}}], 
            ArrowBox[{{-0.46106037135975314`, 
             5.546156245514243}, {-0.46069545353604463`, 
             5.566905534287568}, {-0.4604132108705907, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.29306047420269, -2.3217912035727792`}, {
             1.3943286703238478`, -2.423319964145755}, {
             1.4852145561378824`, -2.5214095166313633`}, {
             1.6036446842255128`, -2.657032163923243}, {
             1.7099066159885579`, -2.783849524590252}, {
             1.8380935641534981`, -2.9422653220537573`}, {
             1.9111971167803776`, -3.03498183606346}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9258166074832552`, -3.0535235917765697`}, {
             1.9530430282490556`, -3.088054592414126}, {
             2.0928900259761947`, -3.2693642322074794`}, {
             2.218328323672465, -3.4346353823267983`}, {
             2.3621457805610193`, -3.626698833117923}, {
             2.491953323568442, -3.8016996388489472`}, {
             2.495640469084476, -3.8067047546289317`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.5096450261861722`, -3.825715241043579}, {
             2.5997269937704757`, -3.9479970103655577`}, {
             2.7011303515552734`, -4.086060631301883}, {
             2.796163396922834, -4.2158905016579205`}, {
             2.884826129873158, -4.337486621433672}, {
             2.968485357859059, -4.452530878429991}, {
             3.048507888333351, -4.5627051604477336`}, {
             3.067003667858228, -4.58820315098438}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.080867925422012, -4.607316198243811}, {
             3.1248937212960346`, -4.668009467486898}, {
             3.197642856747109, -4.7684437995474855`}, {
             3.334711962801304, -4.957916475254558}, {
             3.4621961341828107`, -5.134337124090582}, {
             3.5812017234632365`, -5.29917363802884}, {
             3.6342556877283276`, -5.372694191056094}}]}, 
           {Arrowheads[{{0.006935638172915419, 1.}}], 
            ArrowBox[{{3.6480727181496047`, -5.391841407137647}, {
             3.694079821646163, -5.4555966371021425`}, {
             3.78424177200291, -5.580030445474148}, {
             3.840536311833756, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.0042515699653604055`, 1.}}], 
            ArrowBox[{{0.9319593301156539, 5.4656110675354155`}, {
             0.9672050847096331, 5.57360256950821}, {0.9930746667399062, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.007473499535091163, 1.}}], 
            ArrowBox[{{0.7293748209094864, 5.049714436564876}, {
             0.7653151070929721, 5.132024268201353}, {0.7990405729298303, 
             5.213941171614677}, {0.8626474349768638, 
             5.376463864379475}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.008020309341591408, 1.}}], 
            ArrowBox[{{0.4029879379965829, 4.5960546384274625`}, {
             0.4454377630669031, 4.648909305659784}, {0.4859557114046146, 
             4.704443055029007}, {0.6162380851585724, 
             4.908637244672516}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019202170353855606`, 1.}}], 
            ArrowBox[{{-0.31913195188710275`, 
             3.9042641711892387`}, {-0.23285204446838775`, 
             4.021544540349013}, {-0.1460606647912394, 
             4.104906551623704}, {-0.061695814425336365`, 
             4.150150154818639}, {0.024059962947525427`, 4.167445598985498}, {
             0.05816772963155671, 4.171578121003989}, {0.09272342057449695, 
             4.178596685641375}, {0.127302698306686, 4.189825029158768}, {
             0.1617579121221654, 4.203760763626763}, {0.25053038242137843`, 
             4.248638154549303}, {0.3363163121128547, 4.309412340753447}, {
             0.4175608025793113, 4.383428984171924}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.5949181801969603, 
             2.9469220803889384`}, {-0.5299461024315637, 
             3.0546596123585226`}, {-0.40920386735113623`, 
             3.207386662517722}, {-0.3070852497991853, 
             3.3109868481706948`}, {-0.21468685352391267`, 
             3.3812487605433397`}, {-0.17784229167986013`, 
             3.4025395488547407`}, {-0.14117030418775944`, 
             3.41987442499647}, {-0.10516718152386167`, 
             3.431260604937013}, {-0.06905110468495473, 
             3.4389360459801472`}, {0.01761025579168781, 
             3.4494020841070054`}, {0.10560225812474477`, 
             3.457398317823206}, {0.13397880171075982`, 3.463303555950687}}]}, 
           {Arrowheads[{{0.00254630628139483, 1.}}], 
            ArrowBox[{{0.15709554403263903`, 3.4681142147163864`}, {
             0.1937983883685393, 3.475752179329743}, {0.2726388177075081, 
             3.500911711962686}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.0716485115611234`, 
             4.125653634219305}, {-1.0987645267742847`, 
             4.2857146508411255`}, {-1.141379315662725, 
             4.515063513535794}, {-1.1827275960233894`, 
             4.719570518437088}, {-1.2228314076539324`, 
             4.904560626638211}, {-1.256333102455277, 5.051726901441496}}]}, 
           {Arrowheads[{{0.012706140222651527`, 1.}}], 
            ArrowBox[{{-1.2615741721262954`, 
             5.074749876966821}, {-1.2617127903520085`, 
             5.075358799232365}, {-1.2994344304594196`, 
             5.233949078758802}, {-1.3362030978573638`, 
             5.383576195936597}, {-1.376400432757212, 
             5.540260233454531}, {-1.407063269922685, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.19298205549781972`, -3.96761770903045}, \
{-0.10681870015202397`, -4.028567236746826}, {-0.02100821487543999, \
-4.055618119714468}, {0.06683562622267326, -4.06864136774475}, {
             0.10270879218983581`, -4.0760814032197175`}, {
             0.13884746503762208`, -4.086393761041037}, {
             0.17466899388064136`, -4.10077817664158}, {
             0.21015261501415958`, -4.1177400015486665`}, {
             0.3002180779558307, -4.16945493143791}, {
             0.3861551941603346, -4.235564084554358}, {
             0.46670926293808046`, -4.313285601546149}, {
             0.5487720312564679, -4.408400833557402}, {
             0.5830519102357935, -4.455401242410036}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{0.5969657570453359, -4.474478220165874}, {
             0.6235398228983026, -4.510913353461402}, {
             0.6914711828830731, -4.618378420854651}, {
             0.7530246562302683, -4.728351295333647}, {
             0.8596608777643945, -4.950185417664576}, {
             0.9082762201226093, -5.064852360598181}, {
             0.9553489212467663, -5.182528920843748}, {
             1.0012555904461133`, -5.302837743990769}, {
             1.0081742997295529`, -5.3216328366017915`}}]}, 
           {Arrowheads[{{0.0070389981944546706`, 1.}}], 
            ArrowBox[{{1.0163310728085766`, -5.343791204463019}, {
             1.0463728370298988`, -5.425401475628734}, {
             1.0905851305362968`, -5.549218510009677}, {
             1.1280561544909697`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.014394985895832248`, 1.}}], 
            ArrowBox[{{-0.4369284053982524, -3.3807111711470705`}, \
{-0.3355946178135553, -3.5132381394214827`}, {-0.2932816950022065, \
-3.5597368274223062`}, {-0.25260845961446216`, -3.5991013785202455`}, \
{-0.21396700683346764`, -3.628839474500523}, {-0.17596506642704637`, \
-3.653032764618466}, {-0.08089689817135472, -3.6977996527140764`}, {
             0.014421282815764686`, -3.713749474816887}, {
             0.11169394635665093`, -3.7252817620233176`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.22265446058130325`, -2.352683761505023}, \
{-0.14817005456081767`, -2.3701020066786773`}, {-0.0745668268220556, \
-2.380391883267389}, {0.03762709250157406, -2.3860915031913965`}, {
             0.1499239978812936, -2.388946405676407}, {
             0.2608212176700187, -2.3955340408333488`}, {
             0.4709251518677321, -2.425162048727461}, {
             0.6637929969822658, -2.4930709482476736`}, {
             0.6986122325072587, -2.515180202043948}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.7185453126001136, -2.527837157892334}, {
             0.834923331319359, -2.6017339885773296`}, {
             0.9100009017563031, -2.6655707008199014`}, {
             0.9784887184557014, -2.732402827442549}, {
             1.0417195664250891`, -2.801049170254061}, {
             1.1587404057274582`, -2.940107561632746}, {
             1.2653793102514708`, -3.0796889867980117`}, {
             1.358629176489503, -3.2117332764036863`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.372249923316505, -3.2310206160131525`}, {
             1.3914828195309972`, -3.258254908352185}, {
             1.504469975235774, -3.428212353359179}, {
             1.6304261201624257`, -3.6272741609380437`}, {
             1.7435208076388782`, -3.8123479506795968`}, {
             1.8265001309909654`, -3.9515825756337803`}, {
             1.8734796556699476`, -4.03127355580041}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.8854708384618848`, -4.051614100251985}, {
             1.9046976337555215`, -4.084228354501742}, {
             1.9781133159325466`, -4.210285287283482}, {
             2.046747177522041, -4.329753373979}, {
             2.1115805947026267`, -4.443727871292499}, {
             2.1735949436529274`, -4.553304035928182}, {
             2.289166436862672, -4.7592613671661}, {
             2.3522288476926505`, -4.872670747189186}}]}, 
           {Arrowheads[{{0.018454422620982697`, 1.}}], 
            ArrowBox[{{2.363703797738442, -4.893306922580541}, {
             2.395350694118898, -4.950219667445921}, {
             2.4940367523892277`, -5.1287732365208125`}, {
             2.5860823941535442`, -5.296208469923683}, {
             2.6731786782860736`, -5.455229325064975}, {
             2.7515112448542522`, -5.598322414626367}, {
             2.7838104478620984`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.9810538201273826`, -2.6692986092648945`}, \
{-3.0968183009820303`, -2.776639024887992}, {-3.2043437805231267`, \
-2.8758376024986414`}, {-3.3047275191455063`, -2.9680157235483944`}, \
{-3.406146002242913, -3.060827682456627}, {-3.501666527960613, \
-3.147971004135149}, {-3.6772193116445417`, -3.307565473349771}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.6947187782311506`, -3.323417751851447}, \
{-3.8398221181872523`, -3.4548229463937465`}, {-3.9895825553205913`, \
-3.5900991354624923`}, {-4.13047545843016, -3.7171424598454923`}, \
{-4.262500827515959, -3.8359529195427466`}, {-4.385658662577988, \
-3.946530514554255}, {-4.396133315345843, -3.955918821261546}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.413716387421464, -3.971678319658375}, \
{-4.501864386872682, -4.0506843232771175`}, {-4.613033423656473, \
-4.150223424108433}, {-4.7191657729293635`, -4.2451478170482035`}, \
{-4.820261434691351, -4.335457502096428}, {-4.917178986041906, \
-4.421950450712178}, {-5.010777004080494, -4.505424634354521}, \
{-5.118019749187292, -4.600961895779751}}]}, 
           {Arrowheads[{{0.014766616536066994`, 1.}}], 
            ArrowBox[{{-5.13565038855904, -4.616668161048093}, \
{-5.1880144402217745`, -4.663316706718992}, {-5.353502458255122, \
-4.810542215272054}, {-5.510910105993246, -4.950431336406821}, \
{-5.656854249492381, -5.079947052062183}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.004409200642662733, 1.}}], 
            ArrowBox[{{-0.16746116690891508`, 
             5.320490732491538}, {-0.11450197470797448`, 
             5.42978329787144}, {-0.08854239842438383, 
             5.468937721730801}, {-0.06234932838391209, 
             5.498895728761647}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-0.8940135803718225, -3.5146513283459937`}, \
{-0.8985222182267809, -3.6365871379851877`}, {-0.9064009329815526, \
-3.790117502935954}, {-0.9152169652687785, -3.925660667175855}, \
{-0.9278446685411802, -4.086101630440874}, {-0.9409033777303607, \
-4.229070012252444}, {-0.9630824549640845, -4.4410187650183905`}, \
{-0.9648821873360549, -4.456204405101274}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.9676611241013945, -4.4796522989041385`}, \
{-0.9851750346025219, -4.6274297937450894`}, {-1.0070442112134121`, \
-4.794023348234137}, {-1.028553079364495, -4.946519678287129}, \
{-1.0496962814851558`, -5.08700816319197}, {-1.0705267886718621`, \
-5.218776826739326}, {-1.0943504637257055`, -5.359570847791972}, \
{-1.1039451952185035`, -5.414101677525713}}]}, 
           {Arrowheads[{{0.0047217937163683546`, 1.}}], 
            ArrowBox[{{-1.1080368854818992`, -5.437356446587662}, \
{-1.1177763631346789`, -5.492709928649976}, {-1.140992472824788, \
-5.622671899046393}, {-1.1472966001093647`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1302517355209813`, 1.2040258161900301`}, {
             2.2730548229475884`, 1.268187698585351}, {2.401012526631291, 
             1.3274245695235034`}, {2.556952811401827, 1.4014337316371288`}, {
             2.6967865950139225`, 1.468972846044083}, {2.8673052885108388`, 
             1.5525622258158873`}, {2.9829978331226643`, 
             1.609883318848607}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0041553191749104`, 1.6203660187529818`}, {
             3.0203576264875887`, 1.6283936230202305`}, {3.20964295837472, 
             1.7230355086291549`}, {3.379500722476948, 1.808533387260445}, {
             3.5728579247124186`, 1.9064117145663697`}, {3.747631577604994, 
             1.9952366776318962`}, {3.8472731290187605`, 
             2.046026578204919}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.8683098610190885`, 2.0567495498118262`}, {
             3.8933348372752627`, 2.0695054336560608`}, {4.0304936862048795`, 
             2.139513413205334}, {4.159108124393843, 2.2052606162797157`}, {
             4.279178151842154, 2.2667470428792056`}, {4.392524194338866, 
             2.324862739450062}, {4.500966677673032, 2.380497752438542}, {
             4.703140966853727, 2.484325727668373}, {4.708941110299176, 
             2.4873075950945194`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.729940533435819, 2.498103448060561}, {
             4.889020052348123, 2.5798866039554063`}, {5.0619229671201005`, 
             2.66883601668635}, {5.223336794830796, 2.7519229949183655`}, {
             5.378781331357071, 2.831967329091225}, {5.523440100578798, 
             2.906598174874866}, {5.5695463664889955`, 
             2.9306567796521907`}}]}, 
           {Arrowheads[{{0.0015853807624011376`, 1.}}], 
            ArrowBox[{{5.590479812937582, 2.9415800132906464`}, {
             5.656568772045625, 2.976065741335118}, {5.656854249492381, 
             2.976215993619171}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.026502002087414, 2.3789804763740716`}, {
             2.142682211483054, 2.4924836391263}, {2.285785978312065, 
             2.635094217574629}, {2.414064262600197, 2.76484037064617}, {
             2.5706871632290413`, 2.9252788615682737`}, {2.6912071859159794`, 
             3.04989395995446}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.70762217958217, 3.0668667085908794`}, {
             2.7112396705906523`, 3.0706071161006268`}, {2.80050419529252, 
             3.1635262322063893`}, {2.8852994032893173`, 
             3.2520272381263036`}, {3.0414818691676997`, 3.415774919408588}, {
             3.1325590927171296`, 3.511663924356099}, {3.2193655761828923`, 
             3.6031977795757753`}, {3.3589805702878404`, 
             3.7508019741646135`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.375206078559981, 3.767955956053576}, {
             3.380166322863421, 3.7732000408316244`}, {3.515293489313976, 
             3.916412446641566}, {3.6424699469264477`, 4.051340264818333}, {
             3.761695695700836, 4.177983495361925}, {3.872970735637141, 
             4.296342138272341}, {3.9779978726857643`, 4.408158869693678}, {
             4.022593766111429, 4.455655326218786}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.0387560842509025`, 4.472868858270478}, {
             4.078479912797107, 4.5151763657700315`}, {4.174416855971169, 
             4.6173946265014}, {4.265808702207951, 4.714813651887786}, {
             4.353427462772069, 4.808238465268195}, {4.438045148928136, 
             4.898474089981634}, {4.598277298016127, 5.069377773407605}, {
             4.684876122424858, 5.161759841453125}}]}, 
           {Arrowheads[{{0.013870455101109591`, 1.}}], 
            ArrowBox[{{4.701024406177894, 5.178986540067996}, {
             4.747884703467417, 5.228976262242533}, {4.889907575045685, 
             5.380486318000293}, {5.034517634322587, 5.534740465657927}, {
             5.149010191977431, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.231983368397278, 0.7535480458216306}, {
             2.361574279996017, 0.788123350656444}, {2.5176885173819783`, 
             0.831341775319313}, {2.6576694465781125`, 0.8710509951562435}, {
             2.8273883186491786`, 0.920179105329575}, {2.979705946975658, 
             0.9648930671059172}, {3.1402078341130353`, 
             1.0125719270894409`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1628422479228373`, 1.01929572994369}, {
             3.1674507401990515`, 1.0206647335229733`}, {3.3359045763343316`, 
             1.0711349899663838`}, {3.5274008622382245`, 1.128923197700704}, {
             3.7004608485568062`, 1.1814116348961654`}, {3.844441683709479, 
             1.2252431327072455`}, {3.9799708141196914`, 
             1.2665725395110219`}, {4.066764117456404, 
             1.2930914194770389`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.089345578288962, 1.2999909730860628`}, {
             4.107048239787444, 1.3053998553074946`}, {4.225673960712736, 
             1.3417250800966636`}, {4.4447693555059, 1.4089487836206065`}, {
             4.6444560656691465`, 1.4703231770503666`}, {4.828019027692577, 
             1.5268212404828083`}, {4.992169460290637, 
             1.5773907993867369`}}]}, 
           {Arrowheads[{{0.01423066135144238, 1.}}], 
            ArrowBox[{{5.0147338010614275`, 1.5843461378381352`}, {
             5.158100476958061, 1.6285485473706838`}, {5.308247587257923, 
             1.6748666938791656`}, {5.313229826145533, 1.6764040267037603`}, {
             5.467386364647696, 1.7239906782663184`}, {5.613652778932516, 
             1.7691593231069658`}, {5.656854249492381, 
             1.7825973617290287`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.260512701836693, 0.29389855400832837`}, {
             2.395066838660286, 0.3075110338920177}, {2.554947635444232, 
             0.3243989273947839}, {2.6983228246201043`, 
             0.33995910192138024`}, {2.871252935094037, 
             0.35914765737899634`}, {3.0264706743825727`, 
             0.3766319422924982}, {3.199409639540964, 
             0.3963604936905665}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.2228688199029665`, 0.3990424639952981}, {
             3.38846883974137, 0.41810480050619975`}, {3.583072288384662, 
             0.4406761106405989}, {3.758940968853241, 0.4611826398982408}, {
             3.9046469596030926`, 0.47823861971199216`}, {4.041821613725113, 
             0.494324923501881}, {4.161004013608147, 0.5083298171130466}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.184454213097373, 0.511089227829472}, {
             4.2905769120856645`, 0.5235885030100715}, {4.512456329019338, 
             0.5497764583002629}, {4.714709329610578, 0.5736918692499057}, {
             4.900652285603971, 0.5957118586610013}, {5.073601568744105, 
             0.6162135493355512}, {5.122398764948327, 
             0.6220031648801843}}]}, 
           {Arrowheads[{{0.010896985288755125`, 1.}}], 
            ArrowBox[{{5.145846299373868, 0.6247851322953876}, {
             5.235045041787603, 0.6353682490687156}, {5.3871630198611795`, 
             0.6534274763209912}, {5.3930683127139885`, 0.6541287434320662}, {
             5.549252215836348, 0.6726847494931831}, {5.656854249492381, 
             0.6854735774942292}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.147955416764115, -4.001970489416977}, \
{-1.1856865760444293`, -4.194424021525563}, {-1.2223230163396308`, \
-4.367419153926634}, {-1.2750663242128866`, -4.599533285587768}, \
{-1.3254364201580666`, -4.8079210151147596`}, {-1.3548046472590702`, \
-4.923354096854548}}]}, 
           {Arrowheads[{{0.015603634274112682`, 1.}}], 
            ArrowBox[{{-1.360626492625001, -4.946237110857764}, \
{-1.3736452740682836`, -4.997407992141352}, {-1.4199048558366503`, \
-5.172819866301287}, {-1.464357646888081, -5.336025271382836}, \
{-1.5073555060429669`, -5.490171021579702}, {-1.5523395539109661`, \
-5.646448310132971}, {-1.555417237663411, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.7369041551228437, -4.491068409653917}, \
{-0.724905161859263, -4.709395835036193}, {-0.7191133669487288, \
-4.899371033489669}, {-0.717833133647801, -5.067637808656367}, \
{-0.7193688252130395, -5.2208399641783085`}, {-0.7231780407301106, \
-5.361326842521453}, {-0.726174854141991, -5.435005265588308}}]}, 
           {Arrowheads[{{0.004205471051620002, 1.}}], 
            ArrowBox[{{-0.727134460412554, -5.4585977510262955`}, \
{-0.7285162569132376, -5.492570031971803}, {-0.7371127389206168, \
-5.635257649399021}, {-0.7386661673655863, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.868683788918502, 
             3.4496151227266583`}, {-2.9939277343411264`, 
             3.607000491241659}, {-3.1097577346496257`, 
             3.751897681215314}, {-3.2173387697474514`, 
             3.8858894628217326`}, {-3.3178358195380557`, 
             4.010558606235025}, {-3.423332784998177, 
             4.141081155092245}, {-3.4598550945924744`, 4.186195690562845}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.474711969168956, 
             4.204547788294572}, {-3.5239903120525047`, 
             4.265419337017749}, {-3.6203254860932312`, 
             4.384252638513143}, {-3.7073398149958385`, 
             4.491012690062928}, {-3.7923586751497056`, 
             4.5953255504398145`}, {-3.874089353074354, 
             4.695492503389795}, {-4.0276861622359945`, 
             4.88338868700904}, {-4.071359200864339, 4.936703033561713}}]}, 
           {Arrowheads[{{0.019252430039871753`, 1.}}], 
            ArrowBox[{{-4.086321919305891, 
             4.954968938143064}, {-4.170179500399803, 
             5.0573390108452685`}, {-4.303618625484821, 
             5.21998124482309}, {-4.4289533929516525`, 
             5.372518301951912}, {-4.548121941514379, 
             5.517125197789994}, {-4.6642095517160955`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2483294900790067`, -2.3451662339434636`}, \
{-3.424299256704142, -2.4745052830537286`}, {-3.5844093445331087`, \
-2.5916335362744793`}, {-3.731942228510702, -2.6991770155262067`}, \
{-3.8684735078156964`, -2.7983559221595398`}, {-3.9955787816268646`, \
-2.8903904575251076`}, {-4.011354776613439, -2.901788592004858}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.030494017742586, -2.9156166671542243`}, \
{-4.118879234536904, -2.97947486360401}, {-4.236680986460836, \
-3.064473862070838}, {-4.349556131517763, -3.145821007198319}, \
{-4.451974426556354, -3.219325274350084}, {-4.648324231342655, \
-3.3601473456355806`}, {-4.797426406489855, -3.4668464804639187`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.816628233284427, -3.480587516126757}, \
{-4.829544361613762, -3.489830437745515}, {-4.997948901827473, \
-3.610104925451661}, {-5.155851936441582, -3.7227011835257944`}, \
{-5.304349743458827, -3.8284324901611155`}, {-5.446154092117744, \
-3.929427422881375}, {-5.550569284868806, -4.004501551149647}, \
{-5.585112189765846, -4.029649496762673}}]}, 
           {Arrowheads[{{0.0013807751681576446`, 1.}}], 
            ArrowBox[{{-5.604201267594889, -4.043546738250569}, \
{-5.645141489055018, -4.073352061969963}, {-5.656854249492381, \
-4.082009824076184}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.3390175936835025`, 
             3.322126531029611}, {-3.506862807213544, 
             3.4894320407463764`}, {-3.605289375646521, 
             3.5871088791106653`}, {-3.6992571859372485`, 
             3.6801752234669594`}, {-3.873816532091956, 
             3.8524764301555643`}, {-4.01019498291386, 
             3.9866245871305566`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.027034466504577, 
             4.003176260093411}, {-4.1590677398115865`, 
             4.1327942619540545`}, {-4.289134553492476, 
             4.260197080581893}, {-4.410828840387413, 
             4.379095834362128}, {-4.525913849604992, 
             4.4913140435402825`}, {-4.636152830253802, 
             4.598675228361879}, {-4.702556775344737, 4.663259059716593}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.719483340327859, 
             4.679721672243416}, {-4.7415457823338425`, 
             4.701179388826917}, {-4.842092705845114, 
             4.798826524935398}, {-4.938602932824214, 
             4.892440625142278}, {-5.03188579530774, 
             4.982845677902513}, {-5.121941293295691, 
             5.070041683216104}, {-5.208769426788068, 
             5.154028641083051}, {-5.374171550396787, 
             5.313816759454545}, {-5.397961945099179, 5.336766376596107}}]}, 
           {Arrowheads[{{0.007070508950554698, 1.}}], 
            ArrowBox[{{-5.4149557340075845`, 
             5.353159587138058}, {-5.531252071321698, 
             5.4653458896232605`}, {-5.6308207072438154`, 
             5.561244206871284}, {-5.6467880819522, 
             5.574723488956074}, {-5.656854249492381, 
             5.583221110779631}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.331830022546828, 
             3.532853433662911}, {-2.4612017732621134`, 
             3.7359391923188046`}, {-2.5787401670532395`, 
             3.918344179852638}, {-2.655362304801865, 
             4.036231075636404}, {-2.7284696364415044`, 
             4.1482480209731}, {-2.7980621619721586`, 
             4.254395015862727}, {-2.845054008599702, 4.325708062589379}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.8580460890190946`, 
             4.345424351786694}, {-2.864139881393827, 
             4.354672060305284}, {-2.940070048539346, 
             4.469422881002428}, {-3.012858249866293, 
             4.579095579209534}, {-3.1490087550644716`, 
             4.7832066081536295`}, {-3.2746874142082296`, 
             4.970537373729639}, {-3.382672081377316, 5.130791525141012}}]}, 
           {Arrowheads[{{0.01297445306625661, 1.}}], 
            ArrowBox[{{-3.39587759994355, 
             5.150365489322211}, {-3.5018604587273945`, 
             5.307004759558584}, {-3.6064615840389846`, 
             5.461102950839949}, {-3.6974645851558763`, 
             5.594366293769022}, {-3.7406577088519146`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.007404460725027612, 1.}}], 
            ArrowBox[{{-0.11684225511431033`, 
             4.4789491378763335`}, {-0.06654602804681387, 
             4.5106701977532015`}, {-0.015384208516919538`, 
             4.526590420702726}, {0.01696591406401239, 4.530515463320782}, {
             0.04998995101547598, 4.535089826025497}, {0.0834659423610106, 
             4.544881093803331}, {0.11704626270863573`, 4.558073290094695}, {
             0.2054922161139661, 4.604172806087383}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.712950229919211, 3.246166872651147}, {
             3.89433866613715, 3.398955285916052}, {4.044582851561131, 
             3.525839997341976}, {4.1860599062860935`, 3.645473001037237}, {
             4.3187698303120365`, 3.7578542970018343`}, {4.434293485318425, 
             3.8558426830636674`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.452295433756779, 3.871121950600644}, {
             4.559749160608808, 3.9623755017062186`}, {4.671740315563516, 
             4.0575428823803605`}, {4.778686088503087, 4.148486027258197}, {
             4.88058647942752, 4.235204936339725}, {4.978292749495014, 
             4.318403455638748}, {5.0726561598637705`, 4.398785431169068}, {
             5.171640324956817, 4.4831550681287915`}}]}, 
           {Arrowheads[{{0.013006130619124118`, 1.}}], 
            ArrowBox[{{5.189610331724589, 4.498471891236159}, {
             5.251354401505067, 4.551099750923594}, {5.418209264015852, 
             4.693421730619833}, {5.576869876007568, 4.8288240244842955`}, {
             5.656854249492381, 4.8971275905794895`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.6295054147489716`, -2.0398672064612047`}, \
{-3.7885106283840333`, -2.1315850847422206`}, {-3.9360013762126282`, \
-2.2164635070399337`}, {-4.074625833294662, -2.2961164794407485`}, \
{-4.204383999630133, -2.370544001944665}, {-4.325275875219043, \
-2.439746074551683}, {-4.439234312272821, -2.5048801084080297`}, \
{-4.448546893401362, -2.510198316457586}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.469050942148486, -2.521907722860634}, \
{-4.548192163002894, -2.567103514659932}, {-4.751106105491929, \
-2.6828184443504015`}, {-4.937454111808702, -2.788917014985139}, \
{-5.110672591075764, -2.887425377926191}, {-5.272284156879117, \
-2.979233925466126}, {-5.28983345278055, -2.9891951289865277`}}]}, 
           {Arrowheads[{{0.008439602691590256, 1.}}], 
            ArrowBox[{{-5.310368072514937, -3.000850840277576}, \
{-5.427703169427681, -3.067451733384542}, {-5.579058398939143, \
-3.1533175403651033`}, {-5.656854249492381, -3.197803790619169}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6358386956492951, 
             2.1500940520846026`}, {-0.5384544886591298, 
             2.267932381060384}, {-0.4522471040337878, 
             2.3416558050200056`}, {-0.3688889796880606, 
             2.3915485886295}, {-0.2885578568147539, 
             2.4275503182174467`}, {-0.17036180171393311`, 
             2.464601345074462}, {-0.05513866430967473, 
             2.4822849000355713`}, {0.059645787995113025`, 
             2.487762582973471}, {0.1971367812555246, 2.494244693036683}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.22063352869747416`, 2.4965490408500965`}, {
             0.3343426175163905, 2.5081847785124007`}, {0.46207153493573233`, 
             2.53028589917953}, {0.6881051165455022, 2.620872004545437}, {
             0.7919050443955413, 2.690895218051297}, {0.8862844738535829, 
             2.7707704087474334`}, {1.0280161059556239`, 
             2.9232627848646806`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0440909238167253`, 2.9405580571686536`}, {
             1.048627735863159, 2.9454393193025714`}, {1.1332736315539251`, 
             3.055228645908717}, {1.211235371176225, 3.164700510865317}, {
             1.2842769002624315`, 3.2728057087316356`}, {1.353205818724484, 
             3.378442834775289}, {1.4185513465105521`, 3.481109946618601}, {
             1.5384922300547361`, 3.6775341277041997`}, {1.5670533803601665`, 
             3.7260956532458374`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{1.5790237494836226`, 3.746448453455744}, {
             1.6148150954580849`, 3.8073032279701295`}, {1.686936138413319, 
             3.9316829194882468`}, {1.7548553589204388`, 4.050673202258551}, {
             1.818572756979444, 4.1642740762810435`}, {1.9366790860329441`, 
             4.378206798018665}, {2.041115542147358, 4.570102517162799}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.052332508005517, 4.590879983922666}, {
             2.143806036304418, 4.760915070293242}, {2.23617497724809, 
             4.933931689143462}, {2.322414883939561, 5.0965546483150375`}, {
             2.40408372897191, 5.251261826136455}, {2.49527270467647, 
             5.425046722156096}}]}, 
           {Arrowheads[{{0.005043926047373443, 1.}}], 
            ArrowBox[{{2.5062415530500655`, 5.445956302972249}, {
             2.5927945469924585`, 5.611007868701047}, {2.6169598189526893`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.075057934749652, -1.7545299234894787`}, \
{-4.205009337903582, -1.8109135863071022`}, {-4.3260784447213005`, \
-1.8633032165134098`}, {-4.54932437513267, -1.959655540275486}, \
{-4.75255033176833, -2.047142055959115}, {-4.9391973924468875`, \
-2.1273115074548072`}, {-4.942286374731025, -2.128636069609692}}]}, 
           {Arrowheads[{{0.015958670914080354`, 1.}}], 
            ArrowBox[{{-4.9639874077197135`, -2.1379415185811292`}, \
{-5.112706634986951, -2.201712638653073}, {-5.274601971329797, \
-2.271024498768428}, {-5.427111742021617, -2.33623841039108}, \
{-5.4312356128061205`, -2.3380007476613116`}, {-5.58799152934199, \
-2.4049169580407437`}, {-5.656854249492381, -2.4344151613702727`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.0038846038592472206`, 1.}}], 
            ArrowBox[{{-0.1321605100043336, -5.440003442523905}, \
{-0.07754037199931968, -5.528462317124479}, {-0.04708920259206278, \
-5.558941879277727}, {-0.015595603313052299`, -5.577190899283901}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.6008037426452157, 3.5039709441502414`}, {
             0.6500972376264034, 3.548560353617487}, {0.6992119561086892, 
             3.6001136039095853`}, {0.7887553528732183, 3.704483210896496}, {
             0.8752200801276075, 3.824116666628499}, {0.957226777993594, 
             3.9530364986103845`}, {1.0282698669581132`, 
             4.0751828080143975`}, {1.0951979637505802`, 4.198694858393858}, {
             1.1348261647931785`, 4.276263710070657}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{1.1455683533745409`, 4.297290635614316}, {
             1.1582558791051507`, 4.32212539408557}, {1.2176884237559804`, 
             4.444027159426341}, {1.2738082731670481`, 4.563819405651169}, {
             1.326928102802333, 4.680921383995056}, {1.409979762174734, 
             4.870161562876358}, {1.4866487687519918`, 5.051084317834289}, {
             1.5311483848428604`, 5.159227414718295}}]}, 
           {Arrowheads[{{0.01084351300013217, 1.}}], 
            ArrowBox[{{1.5401334852838038`, 5.181063032030437}, {
             1.55779243580399, 5.223977865117418}, {1.6242680766006137`, 
             5.389130420974316}, {1.686623363925895, 5.546954387079681}, {
             1.7294322931021737`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.002842005714738337, 1.}}], 
            ArrowBox[{{0.9452111914432134, -0.3019585422721742}, {
             0.9521091201628651, -0.259747948302876}, {
             0.9539271146876216, -0.24186517177499123`}, {
             0.9548077058662878, -0.22561548790422714`}, {
             0.9548756993664594, -0.21260485283361083`}, {
             0.954375474287537, -0.20088235931844872`}, {
             0.9528923338721789, -0.18530258137236674`}, {
             0.9511039023665822, -0.17349840620120355`}, {
             0.9501994824269748, -0.16872453631640214`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.814899487877618, 
             3.1388425519972265`}, {-3.954051191083685, 
             3.255278967259463}, {-4.085286456321055, 
             3.3649428184157486`}, {-4.208605283589725, 
             3.467834105466084}, {-4.3240076728896994`, 
             3.563952828410469}, {-4.433151988699891, 
             3.654738580572496}, {-4.537696595499219, 
             3.7416309552757565`}, {-4.540246970576726, 
             3.7437489080548816`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.558411959952804, 
             3.75883397929446}, {-4.637641493287681, 
             3.824629952520251}, {-4.732986682065279, 
             3.9037355723059792`}, {-4.912941143046791, 
             4.052890755753127}, {-5.080623188902664, 
             4.191720581869191}, {-5.23741668733028, 
             4.321401982899893}, {-5.285738180483468, 4.361360415719691}}]}, 
           {Arrowheads[{{0.009736523646530649, 1.}}], 
            ArrowBox[{{-5.303934600396174, 
             4.376407558827161}, {-5.386838617277352, 
             4.444963275401069}, {-5.510603218975453, 
             4.548112929091961}, {-5.625835173599757, 
             4.645013124509278}, {-5.656854249492381, 
             4.671126230551093}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.190087091085528, -1.275257421669653}, \
{-4.322897424411758, -1.3161012501222957`}, {-4.446655619974258, \
-1.3540703996271328`}, {-4.674898222849261, -1.4239322440256683`}, \
{-4.882697524751728, -1.4873905370975382`}, {-5.073561359935435, \
-1.5455602391034011`}, {-5.093249736877695, -1.5515516601714123`}}]}, 
           {Arrowheads[{{0.011974387269164447`, 1.}}], 
            ArrowBox[{{-5.115838935514553, -1.5584258378153732`}, \
{-5.25099756265416, -1.5995563103039163`}, {-5.416561423492015, \
-1.64986864477002}, {-5.572527934704357, -1.6972127822188345`}, \
{-5.577298303373661, -1.6986600705823767`}, {-5.656854249492381, \
-1.7229495292531785`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.007976378455455397, 1.}}], 
            ArrowBox[{{-0.23996488467195526`, 
             3.6652041781380027`}, {-0.16129185399207746`, 
             3.7249542173815096`}, {-0.08491049451686308, 
             3.7611760829460783`}, {-0.05300176029700367, 
             3.7699322170324234`}, {-0.020654319638123676`, 
             3.775059523571375}, {0.012093739067440636`, 
             3.7761495033607186`}, {0.045126467377514586`, 
             3.7792441718733185`}, {0.10547839794441513`, 
             3.7914212628978756`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.8051309886742883`, 
             3.4201929028691715`}, {-1.8790443308869837`, 
             3.580059094100557}, {-1.9736898592361736`, 
             3.7797631216427603`}, {-2.06043550668665, 
             3.9590586108038313`}, {-2.1178167160829147`, 
             4.0758566802843434`}, {-2.1727297440333033`, 
             4.186834306270481}, {-2.2149268986047694`, 4.271084787271074}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.225500916960558, 
             4.292196782656343}, {-2.275151255596453, 
             4.3913282277596375`}, {-2.333336459339717, 
             4.506168994051724}, {-2.389216281446516, 
             4.615917213326925}, {-2.4940597807507174`, 
             4.820136010826664}, {-2.5911736276081587`, 
             5.007564429704413}, {-2.656412520670697, 5.1326334368988205`}}]}, 
           {Arrowheads[{{0.012054065241689041`, 1.}}], 
            ArrowBox[{{-2.6673327178754485`, 
             5.1535684675017475`}, {-2.682049696117941, 
             5.181782279405727}, {-2.7673702464046146`, 
             5.344345030620857}, {-2.8486342740389863`, 
             5.498435340218295}, {-2.9214131189537986`, 
             5.63486700754565}, {-2.933292830929624, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.111106079866065, 
             2.7997774169127445`}, {-4.265624949894151, 
             2.9047603763715633`}, {-4.373369121548604, 
             2.9778060914649376`}, {-4.476983547495174, 
             3.047979730249694}, {-4.669333155027505, 
             3.1779470013950397`}, {-4.847155785518027, 
             3.297836989304566}, {-4.893409712200406, 3.328966644333302}}]}, 
           {Arrowheads[{{0.018978007820782516`, 1.}}], 
            ArrowBox[{{-4.9129984807081, 
             3.342150208407108}, {-5.012941446203901, 
             3.4094134714765865`}, {-5.168348812671191, 
             3.513839093219249}, {-5.315036560505965, 
             3.612276499840701}, {-5.4543191775025175`, 
             3.705628191731138}, {-5.586955512180223, 
             3.7946400550148556`}, {-5.656854249492381, 
             3.842032326845257}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.3891508236405374`, 2.423618753215343}, {
             1.4793746278703135`, 2.521045832669534}, {1.5961843137564573`, 
             2.655019200786349}, {1.701108438312222, 2.78043138825733}, {
             1.8289045081672184`, 2.938621002177597}, {1.9434972630843377`, 
             3.0842427772706467`}, {1.9933667347638961`, 
             3.149042689302156}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0077674631974345`, 3.1677548573732173`}, {
             2.082854272243945, 3.2653219351278238`}, {2.207847802644064, 
             3.4304098115953963`}, {2.351173858895273, 3.6223180120271445`}, {
             2.4805302339716158`, 3.7971884264726445`}, {2.5736312251937137`, 
             3.923925895797697}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.587610135096189, 3.9429552492095876`}, {
             2.5878845443937815`, 3.9433287999041573`}, {2.688892319915955, 
             4.0812481602383945`}, {2.7835535605381367`, 4.210946507475357}, {
             2.8718682662603254`, 4.332423841615043}, {2.9551982785565127`, 
             4.447358552311595}, {3.0349054389006884`, 4.557429029219153}, {
             3.1109897472928534`, 4.6626352723377185`}, {3.142960755728461, 
             4.706907570802643}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.1567843800840807`, 4.726050026836571}, {
             3.1834512037330067`, 4.762977281667291}, {3.3199772996710446`, 
             4.952277733555267}, {3.446955465628567, 5.1285395194788945`}, {
             3.565487938484216, 5.293228742560421}, {3.677917965163016, 
             5.449514119918528}, {3.708858024407599, 5.49237655659227}}]}, 
           {Arrowheads[{{0.003803550302128455, 1.}}], 
            ArrowBox[{{3.7226778834876417`, 5.511521731136889}, {
             3.7696633339872796`, 5.57661245642309}, {3.828229549928183, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.053038297111805, 2.3977216979178535`}, {
             4.1945621320423605`, 2.4790400308306566`}, {4.327305201413059, 
             2.5554455305271855`}, {4.4512675052239, 2.6269381970074397`}, {
             4.56831302872578, 2.694540597327823}, {4.680305757169596, 
             2.7592752985447384`}, {4.871122056243745, 
             2.8697172103006414`}}]}, 
           {Arrowheads[{{0.01873835255542937, 1.}}], 
            ArrowBox[{{4.891557041209245, 2.8815467318440757`}, {
             5.081159896596378, 2.9914448259413273`}, {5.259798136541802, 
             3.095092678927837}, {5.426578528267177, 3.1919496267349285`}, {
             5.586472945564553, 3.2848704634182995`}, {5.656854249492381, 
             3.3258073218228903`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.7010721195387823`, 
             4.301472891367316}, {-1.7810945420227577`, 
             4.524289334005461}, {-1.8549421741262435`, 
             4.725817043574166}, {-1.9236181809374937`, 
             4.910008268235199}, {-1.988125727544763, 
             5.080815256150325}, {-2.028801248239127, 5.187244759257772}}]}, 
           {Arrowheads[{{0.010169344919316155`, 1.}}], 
            ArrowBox[{{-2.037230700622601, 
             5.209300836557484}, {-2.0489208120038773`, 
             5.239888588707695}, {-2.106967461208543, 
             5.390381196672114}, {-2.1674264385804602`, 
             5.545174309405173}, {-2.211360956918849, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.8212280748651146`, 2.8016391679499795`}, {
             3.9592074186105553`, 2.8979980038128677`}, {4.089610859754081, 
             2.9891408743399825`}, {4.212438398295692, 3.075067779531324}, {
             4.327690034235388, 3.155778719386892}, {4.436906157461227, 
             3.2323178169554123`}, {4.5416271578612655`, 
             3.3057291952856103`}, {4.595030205887372, 
             3.3431848987041377`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.61436138466637, 3.356743355118885}, {
             4.737583790183942, 3.4431687942310387`}, {4.91849042614246, 
             3.5701144487991416`}, {5.087277560675861, 3.6885830915658824`}, {
             5.245287393439336, 3.799505462367908}, {5.3874300134054804`, 
             3.899336022147508}}]}, 
           {Arrowheads[{{0.006510897218240941, 1.}}], 
            ArrowBox[{{5.40672634772124, 3.9129439590067716`}, {
             5.507258370795, 3.9840854043347957`}, {5.608091999076845, 
             4.056293880913992}, {5.656854249492381, 4.091751248221683}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.216274054615231, -0.3286344565669785}, \
{-4.349671092171697, -0.33910535768733324`}, {-4.473958222612723, \
-0.34883596392629773`}, {-4.703144835899899, -0.36673370000869104`}, \
{-4.911775968228199, -0.3829850730627934}, {-5.103381831723992, \
-0.39787726171786425`}, {-5.157891642986201, -0.40210685100705634`}}]}, 
           {Arrowheads[{{0.010097545598159719`, 1.}}], 
            
            ArrowBox[{{-5.18143287497602, -0.4039334899253157}, \
{-5.281492638513639, -0.41169744460316293`}, {-5.44767261998964, \
-0.4245716638880661}, {-5.60420967812029, -0.43668398740818176`}, \
{-5.609980484621881, -0.4371302440480948}, {-5.656854249492381, \
-0.44077039839815574`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.2152261064311976`, -0.790840209238658}, \
{-4.336223646800375, -0.8139662228475026}, {-4.55923619712156, \
-0.8564943056712835}, {-4.762159920610679, -0.8951085367388666}, \
{-4.948457800733926, -0.9304938213180773}, {-5.121592820957495, \
-0.9633350646767409}, {-5.143055796331965, -0.9674012693200579}}]}, 
           {Arrowheads[{{0.010573069622013164`, 1.}}], 
            ArrowBox[{{-5.1662551235093455`, -0.9717964293686827}, \
{-5.2830953515663355`, -0.993932049876203}, {-5.4352030835844785`, \
-1.022722435102854}, {-5.44098214113818, -1.0238157799330276`}, \
{-5.597389914245695, -1.05338271566342}, {-5.656854249492381, \
-1.0646159723982176`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.6717639504367225`, 4.8287785416007525`}, {
             4.77083510639283, 4.927101777984407}, {4.865969286641266, 
             5.021516704008796}, {4.9579440541876325`, 5.112788403106067}, {
             5.132415351174158, 5.285902120519251}, {5.29561957415559, 
             5.4478005412147095`}, {5.342215658469536, 
             5.494012664750019}}]}, 
           {Arrowheads[{{0.004380174852263801, 1.}}], 
            ArrowBox[{{5.358980789920476, 5.510639648263839}, {
             5.450474461500613, 5.60137939423204}, {5.45343685593291, 
             5.604317021565792}, {5.463569485818551, 5.614364846579861}, {
             5.471984246667907, 5.622709071333137}, {5.480372714772745, 
             5.6310271262372416`}, {5.488735038258737, 5.6393191598960435`}, {
             5.505278641605991, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.6778991066100755`, -4.829371066225841}, {
             4.777034689642997, -4.92764068191975}, {
             4.87223329620453, -5.022006551729853}, {
             4.964271963489166, -5.113232383161241}, {
             5.138869480227748, -5.286263930887875}, {
             5.302195236235006, -5.448088891501232}, {
             5.348748922535461, -5.494203718721881}}]}, 
           {Arrowheads[{{0.00437742061111814, 1.}}], 
            ArrowBox[{{5.365524004570642, -5.510820662967111}, {
             5.457163895754487, -5.601596669859194}, {
             5.4601270015565655`, -5.604531488537254}, {
             5.470262066025201, -5.614569708904423}, {
             5.47867884971725, -5.6229059592928055`}, {
             5.487069334728743, -5.631216065979482}, {
             5.495433669336915, -5.639500177526173}, {
             5.511818746355035, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.011928553406164622`, 1.}}], 
            ArrowBox[{{-0.1650811516355755, -4.697126446489075}, \
{-0.11416618866260018`, -4.756599403060136}, {-0.06346006217442382, \
-4.795081549022455}, {-0.011537800264777041`, -4.813829159832123}, {
             0.020804462085870074`, -4.818615107648671}, {
             0.05389132670949228, -4.824846268745313}, {
             0.08753285839511887, -4.837435568337022}, {
             0.12129373781566552`, -4.854149508082131}, {
             0.21035077181858675`, -4.91195283455471}, {
             0.29724671736515584`, -4.994768816943862}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.330239879497444, -1.4567975629738277`}, {
             4.454311939993471, -1.497355436460273}, {
             4.6835521148021995`, -1.572418436648594}, {
             4.89256487842243, -1.6409614753451094`}, {
             5.084764711872246, -1.7040694262313052`}, {
             5.2277140494795535`, -1.7510454582221684`}}]}, 
           {Arrowheads[{{0.009066959557659918, 1.}}], 
            ArrowBox[{{5.25014586839159, -1.7584170057960355`}, {
             5.263566096169733, -1.7628271629886667`}, {
             5.430501293591325, -1.8177262791555568`}, {
             5.587816059689605, -1.8694883734321812`}, {
             5.592203089425733, -1.870932208858075}, {
             5.656854249492381, -1.8922998544325407`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.354108067319722, 
             2.4134198880627715`}, {-4.468788913683838, 
             2.4776529843504522`}, {-4.5784446493095095`, 
             2.5390166129098333`}, {-4.782680788345517, 
             2.653135466843695}, {-4.970266403364799, 
             2.7577725951771677`}, {-5.14465141330441, 
             2.854924143223061}, {-5.178734430506687, 2.8738899444338584`}}]}, 
           {Arrowheads[{{0.011091031454995024`, 1.}}], 
            ArrowBox[{{-5.199367107782298, 
             2.8853711831203688`}, {-5.307365462354422, 
             2.9454678380541717`}, {-5.463854970241373, 
             3.0324691290336174`}, {-5.602993488926135, 
             3.110023456733748}, {-5.656854249492381, 
             3.1403849156434127`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-3.993430281123025, 
             0.13450820189848256`}, {-4.133626023254966, 
             0.13925207183106933`}, {-4.264819966780318, 
             0.14367994580924964`}, {-4.3870121116990815`, 
             0.1477918238330235}, {-4.6122640548457365`, 
             0.15534960605667036`}, {-4.817254901823827, 
             0.16220743254132847`}, {-4.93737760747863, 
             0.16621569716726722`}}]}, 
           {Arrowheads[{{0.014743817413065867`, 1.}}], 
            ArrowBox[{{-4.96097646630372, 
             0.16700314588918458`}, {-5.00547260360604, 
             0.16848789677093992`}, {-5.18040511116506, 
             0.17431359222944673`}, {-5.343595617131534, 
             0.1797381940066639}, {-5.4973003753167635`, 
             0.18484004462756762`}, {-5.503405765207649, 
             0.1850425517789278}, {-5.656854249492381, 
             0.19012543086472564`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.613919065550106, 
             2.0313796309953416`}, {-4.819781822070553, 
             2.12179973614009}, {-5.008887476527674, 
             2.204676407105077}, {-5.184706220163132, 
             2.2816017228375562`}, {-5.348776636273703, 
             2.353274803790504}, {-5.479122571463709, 2.4101462804704283`}}]}, 
           {Arrowheads[{{0.003606403032626357, 1.}}], 
            ArrowBox[{{-5.500764303620055, 
             2.4195888247572803`}, {-5.503349216243745, 
             2.420716652777261}, {-5.507289976151946, 
             2.4224350329379805`}, {-5.645265102757295, 
             2.48262188882349}, {-5.656854249492381, 2.487713542980861}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.003346549276718471, 1.}}], 
            ArrowBox[{{0.12423895732232654`, 5.54053976903899}, {
             0.16243066375020856`, 5.574474724501041}, {0.20054876550236145`, 
             5.61582433005725}, {0.23034689780412734`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012095902209395312`, 1.}}], 
            ArrowBox[{{5.089843718536034, -0.6347701069881092}, {
             5.268789382429, -0.656585999301484}, {
             5.435861670238357, -0.6769698237600891}, {
             5.593305910161469, -0.6961889661440842}, {
             5.598779112257165, -0.696857239219742}, {
             5.656854249492381, -0.7039625215634999}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.8514145423676223`, 4.690350643103743}, {
             1.9561901711718481`, 4.909315460903498}, {2.052609582824108, 
             5.112923329525018}, {2.1423171064168014`, 5.303605354177733}, {
             2.22607322423012, 5.482644504742152}, {2.2548281350842765`, 
             5.544334656676129}}]}, 
           {Arrowheads[{{0.0021287907832460277`, 1.}}], 
            ArrowBox[{{2.264803666296501, 5.565735941459293}, {
             2.30527009415681, 5.652551723834322}, {2.307274032601037, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.2578109778340623`, 4.50490475682659}, {
             2.3180182213324887`, 4.609686233535184}, {2.4333393811712134`, 
             4.81068268677905}, {2.5397216389494237`, 4.997441231165027}, {
             2.6385157235896455`, 5.171927745094792}, {2.72517148440121, 
             5.3256409103882305`}}]}, 
           {Arrowheads[{{0.007545438188809144, 1.}}], 
            ArrowBox[{{2.736750783722579, 5.346218706176751}, {
             2.818015989481381, 5.4909138796766035`}, {2.9002948849285595`, 
             5.637407046224136}, {2.9113171811044447`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.009415558677587189, 1.}}], 
            ArrowBox[{{-0.9500062548352818, 
             3.0757943958276655`}, {-0.9568831118540789, 
             3.270812817718554}, {-0.9616894499742962, 
             3.35505565804778}, {-0.9671235304028011, 
             3.4343459089197856`}, {-0.9744335626568025, 
             3.5196778700192137`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.49381670641734, 1.650243173078191}, {
             4.724700128440849, 1.7333892227942496`}, {4.935232092884719, 
             1.8093505268186822`}, {5.12884317394649, 1.879318924005472}, {
             5.308963945823705, 1.9444862532086007`}, {5.382162721286632, 
             1.9709969168091082`}}]}, 
           {Arrowheads[{{0.005686929436341522, 1.}}], 
            ArrowBox[{{5.404363528303674, 1.9790374628806289`}, {
             5.477135179203871, 2.0053934332430807`}, {5.635616288190462, 
             2.062834997624451}, {5.639746169928254, 2.064332420753453}, {
             5.656854249492381, 2.0705395190304103`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.3935194744693139, -3.026068010093043}, {
             0.4362265698851927, -3.042159497604376}, {
             0.4775113842502156, -3.0595213434326807`}, {
             0.632314713628914, -3.147057017107375}, {
             0.7776095488897931, -3.275029826985658}, {
             0.9110886940845138, -3.433041692149252}, {
             1.0152891485843814`, -3.581542829534195}, {
             1.065088930797415, -3.661671267613065}}]}, 
           {Arrowheads[{{0.0012688032499397306`, 1.}}], 
            ArrowBox[{{1.0775527406768362`, -3.681725684997417}, {
             1.1091809856401171`, -3.732615904903245}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.013757025544207628`, 1.}}], 
            ArrowBox[{{-0.3001008847076841, -2.873537901437038}, \
{-0.21912935744656498`, -2.9154417507694026`}, {-0.13674066901656254`, \
-2.9449134127212697`}, {-0.0556280167724051, -2.9607671560626367`}, {
             0.02566976499895684, -2.9663206306183336`}, {
             0.06012449318426085, -2.967566640719414}, {
             0.09558557400897626, -2.969858464681287}, {
             0.1301748713429602, -2.9735612445453987`}, {
             0.1646117970080731, -2.9782124350764967`}, {
             0.2476323590564758, -2.992252849048192}, {
             0.32846759415829624`, -3.0115444655151244`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.5883699530077378`, -1.7924622480830938`}, \
{-1.7068424653660803`, -1.9854443918968838`}, {-1.7809527984983868`, \
-2.1010690998214776`}, {-1.8484237817267195`, -2.203905915460207}, \
{-1.9339264659064495`, -2.3311010483193986`}, {-2.0119242457644875`, \
-2.444320245264956}, {-2.108095344855159, -2.5807930373020502`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.1218386493734407`, -2.599993060304231}, \
{-2.200488751575918, -2.709481912981746}, {-2.314828358938513, \
-2.865897484071788}, {-2.418652447699601, -3.0058847497655106`}, \
{-2.54978189884397, -3.180377460197249}, {-2.6685903748621573`, \
-3.3367703463483345`}, {-2.684999025117115, -3.3581586151183505`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.699371361486972, -3.3768925992276593`}, \
{-2.8171141419843897`, -3.530367394282596}, {-2.9515169896924998`, \
-3.7041518439653043`}, {-3.0387375480227856`, -3.8162537505570078`}, \
{-3.1218216034637165`, -3.9227462048351613`}, {-3.2007691560152933`, \
-4.023629206799765}, {-3.2755802056775156`, -4.1189027564508205`}, \
{-3.2786778150086953`, -4.122836877883936}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.2932847976379116`, -4.141388488913869}, \
{-3.3614446519822585`, -4.227954971379866}, {-3.4436412016915097`, \
-4.332151609955051}, {-3.522169854805269, -4.431492672176377}, \
{-3.5970306113235373`, -4.525978158043843}, {-3.738230363413994, \
-4.703766614624248}, {-3.8697223868032764`, -4.868901193603318}, \
{-3.8798772278080254`, -4.8816235368281635`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-3.8946071413810603`, -4.900077692443284}, \
{-3.99261551544712, -5.022866042668977}, {-4.109607603611911, \
-5.169169997012459}, {-4.227346214567811, -5.316031371141833}, \
{-4.338109083247376, -5.453363039046068}, {-4.445504996382742, \
-5.58593317646981}, {-4.486515779850769, -5.63606388027633}}]}, 
           {Arrowheads[{{0.00006880091040427717, 1.}}], 
            ArrowBox[{{-4.501466640297119, -5.654339492037635}, \
{-4.503523905917191, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.298369514949711, -2.358916944356206}, \
{-1.3621840650553594`, -2.577862006377324}, {-1.4052348583514795`, \
-2.71082679629594}, {-1.4458503862491925`, -2.829020118035338}, \
{-1.4985318576808593`, -2.974227472549838}, {-1.547855438051124, \
-3.1040694106888433`}, {-1.606187444373024, -3.251255387247858}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.6149160229165709`, -3.2731946142673833`}, \
{-1.6753482233668846`, -3.420186128029066}, {-1.7550124058290173`, \
-3.6075746527696952`}, {-1.8285223479968458`, -3.7756621021313195`}, \
{-1.9245642055656162`, -3.989655649292655}, {-1.9929154597720038`, \
-4.138639235606456}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.002761496244716, -4.160100404705882}, \
{-2.012684956544992, -4.181730332661755}, {-2.1147933933191307`, \
-4.399972079779777}, {-2.2088675203964914`, -4.597926454543241}, \
{-2.2961978676598256`, -4.779253525627142}, {-2.3780749649918866`, \
-4.947613361706472}, {-2.40983133513565, -5.0123310213022005`}}]}, 
           {Arrowheads[{{0.01474813838938072, 1.}}], 
            ArrowBox[{{-2.4202327812444127`, -5.033528571447976}, \
{-2.455089991197735, -5.104565564593082}, {-2.5286119598722507`, \
-5.2533853022714405`}, {-2.6045501406241027`, -5.4057126492536245`}, \
{-2.6768032439296974`, -5.549746196424665}, {-2.7309143966650744`, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3757829641631312`, -1.3505855002059697`}, {
             1.5816279924878387`, -1.4401606020363968`}, {
             1.6994414216288207`, -1.502539071229926}, {
             1.8047884201819713`, -1.563370001343997}, {
             1.9314503619580115`, -1.6418632354189453`}, {
             2.044766443134091, -1.7157566565211226`}, {
             2.182153913092785, -1.8089998491037214`}, {
             2.1942192775670213`, -1.8173968612366203`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.213599687513874, -1.8308848530674333`}, {
             2.3051946629800635`, -1.8946313003417388`}, {
             2.4554408558747736`, -2.0014411841289754`}, {
             2.5901334322336265`, -2.098679067221192}, {
             2.7547258806755215`, -2.2190748544922956`}, {
             2.9024305149863783`, -2.328165300523133}, {
             2.97851838362281, -2.384829724981988}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.997455832950198, -2.398932888680562}, {
             3.085391460524794, -2.464420617739604}, {
             3.2495479747307003`, -2.587425926606679}, {
             3.436408467256857, -2.728174975496466}, {
             3.6053058068082975`, -2.8558628126221453`}, {
             3.746837988250556, -2.9631525722160124`}, {
             3.7519654775468627`, -2.9670443076577926`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.7707735616951745`, -2.981319537393463}, {
             3.880043819559722, -3.064255046507101}, {
             4.004923300735797, -3.159170235495411}, {
             4.121476431778779, -3.247898139180943}, {
             4.231483018498517, -3.331737164802576}, {
             4.336722866704857, -3.411985719599189}, {
             4.437195976397799, -3.488643803570784}, {
             4.522184207722645, -3.553528587435442}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.540950143454776, -3.567859179132527}, {
             4.713249039377357, -3.6994794007012706`}, {
             4.880997107086019, -3.827693841716743}, {
             5.037592982803749, -3.9474398546685587`}, {
             5.187154096870564, -4.061838151524645}, {
             5.291238432570115, -4.141539672846746}}]}, 
           {Arrowheads[{{0.009309052605280858, 1.}}], 
            ArrowBox[{{5.309985447049377, -4.155895008490697}, {
             5.329665457955034, -4.170964776657773}, {
             5.460760098804395, -4.272295288304575}, {
             5.5856672608157885`, -4.369565175823374}, {
             5.656854249492381, -4.425959904880812}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.5788486817916183`, -0.9698353956114762}, {
             1.8102090249399736`, -1.0400350788527977`}, {
             1.9399687313016698`, -1.08833068313092}, {
             2.0560558503168314`, -1.1346233392356115`}, {
             2.1959345629901863`, -1.1935437048705246`}, {
             2.321262307312491, -1.2482958834291615`}, {
             2.4587009130594217`, -1.3101687046918813`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.4802085348413567`, -1.3199124805020777`}, {
             2.6104506740636078`, -1.3797808731021772`}, {
             2.7769726089841233`, -1.457676669995571}, {
             2.9264165134509232`, -1.5284583764052}, {
             3.1110877650922815`, -1.6168541118401212`}, {
             3.2767821168545934`, -1.6967770562500504`}, {
             3.3336701213055493`, -1.724394850624579}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3549112854844676`, -1.7347069385635172`}, {
             3.465294600297452, -1.7882954537576488`}, {
             3.6356691559128604`, -1.871382107613512}, {
             3.777865441163036, -1.9409571098654261`}, {
             3.911706287063576, -2.006542227724482}, {
             4.037191693614481, -2.0681374611906804`}, {
             4.154321660815753, -2.1257428102640215`}, {
             4.203259281825007, -2.149851577624277}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.224440455965917, -2.16028633087237}, {
             4.370644445092503, -2.2323126756006437`}, {
             4.567803807816939, -2.329580644102863}, {
             4.749046330838498, -2.419097980365573}, {
             4.917618596006615, -2.502415948983668}, {
             5.071316657696491, -2.578427929130215}}]}, 
           {Arrowheads[{{0.013340901935298051`, 1.}}], 
            ArrowBox[{{5.092480482547281, -2.588897825464719}, {
             5.223242236316824, -2.653590792261062}, {
             5.226912279283798, -2.655406806124881}, {
             5.37910313178718, -2.730732896519523}, {
             5.5227982256749115`, -2.8019738175614464`}, {
             5.656854249492381, -2.868888517501706}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.766613348221323, -3.0993151629694053`}, \
{-2.8606375470772742`, -3.2086587326920086`}, {-2.9485709636122768`, \
-3.3103641190605497`}, {-3.036892066948899, -3.4121106759103683`}, \
{-3.1202151029502834`, -3.5077478626463336`}, {-3.2748450733826338`, \
-3.6844869195707064`}, {-3.386690315893606, -3.8117298520643015`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-3.402278958086674, -3.82946457641831}, \
{-3.416060372950928, -3.8451432731770607`}, {-3.5474255651530173`, \
-3.9941250706801963`}, {-3.6711392907716234`, -4.134123071297018}, \
{-3.7872015498067455`, -4.265137275027525}, {-3.8956123422583846`, \
-4.387167681871721}, {-3.9980089739395734`, -4.502175929554509}, \
{-4.028556446448103, -4.5364406999625135`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.044269215382119, -4.5540655433877015`}, \
{-4.096028750663345, -4.612123655800799}, {-4.189671672429701, \
-4.71701086061059}, {-4.27893773923864, -4.816837543983883}, \
{-4.36456708784165, -4.912474239343675}, {-4.4472998549902165`, \
-5.004791480112962}, {-4.604075644924023, -5.179467597880026}, \
{-4.6743672879402745`, -5.25763993545914}}]}, 
           {Arrowheads[{{0.010878767588976912`, 1.}}], 
            ArrowBox[{{-4.690155002054305, -5.2751976772384745`}, \
{-4.750589183358402, -5.342407391217262}, {-4.88982727202542, \
-5.497027326224549}, {-5.031956210718125, -5.654533722006576}, \
{-5.034052754287274, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.175059325869714, -3.055279640150113}, \
{-2.3033133763832847`, -3.247320897497884}, {-2.4188359637350714`, \
-3.417523304447328}, {-2.5248985407509577`, -3.572154143509027}, \
{-2.62331981684928, -3.7145051083977494`}, {-2.7075102895536203`, \
-3.8353403136030737`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7210368715436055`, -3.8546937700496473`}, \
{-2.80097578211832, -3.9686184863015597`}, {-2.893059729081611, \
-4.099214733696692}, {-2.9810070344771096`, -4.223562966002535}, \
{-3.065256559352692, -4.3423582815426425`}, {-3.1415659802455567`, \
-4.448881396522656}, {-3.2161524953339473`, -4.552979537192929}, \
{-3.267757593723472, -4.624840089460336}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.2815305412051825`, -4.644019039666284}, \
{-3.2879189519981735`, -4.652914957744575}, {-3.422991690054132, \
-4.84029763849199}, {-3.548527583439586, -5.013698299248668}, \
{-3.6662700211806865`, -5.175785800498378}, {-3.7770388949044054`, \
-5.3277908011466355`}, {-3.836102722599711, -5.40853643846039}}]}, 
           {Arrowheads[{{0.006046630792977724, 1.}}], 
            ArrowBox[{{-3.850043020161753, -5.4275940961658335`}, \
{-3.882454964784821, -5.4719041794653585`}, {-3.966884160676148, \
-5.5858312198905296`}, {-4.020262329628735, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.312479291107179, -2.8950607984417487`}, {
             3.487007732964457, -3.040168343500841}, {
             3.588991199861704, -3.125308765020843}, {
             3.6861867543872227`, -3.2065855716725533`}, {
             3.8662141263230745`, -3.357548340371102}, {
             4.0155133020735185`, -3.4830861560932154`}, {
             4.036890828822285, -3.501085574173895}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.0549530346658464`, -3.5162935633046444`}, {
             4.156086193601886, -3.6014455095939693`}, {
             4.287932800908175, -3.7126264008733627`}, {
             4.411053123992388, -3.8166288299313957`}, {
             4.527301182908659, -3.9149516925776546`}, {
             4.638530997711126, -4.009093884621724}, {
             4.744742568399789, -4.099055406063606}, {
             4.7763781955708895`, -4.1258726983440095`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.794389592075373, -4.141140828854797}, {
             4.845935894974646, -4.184836256903298}, {
             4.942958378963104, -4.2671332300395415`}, {
             5.036657421892568, -4.346643118371074}, {
             5.214085184574511, -4.497301640620011}, {
             5.3797396489493075`, -4.638072758701592}, {
             5.514311812291994, -4.752494856145292}}]}, 
           {Arrowheads[{{0.0034630276763716605`, 1.}}], 
            ArrowBox[{{5.53230035916832, -4.767789900918498}, {
             5.537293234985138, -4.772035172072989}, {
             5.656854249492381, -4.873766294849545}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.9564546359990853`, -3.4512584032877327`}, \
{-2.037540649132087, -3.614331568389101}, {-2.1404605689180944`, \
-3.817268291094642}, {-2.234374702569508, -3.999452550754558}, \
{-2.2960854393802452`, -4.1177267502467725`}, {-2.355041644708059, \
-4.230096045385013}, {-2.3875938167753876`, -4.291556598323591}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.3986453522707563`, -4.312422594023072}, \
{-2.4646904609149147`, -4.437119922599569}, {-2.5264683981743277`, \
-4.552721324206782}, {-2.585728232832357, -4.663194894083597}, \
{-2.696693594344265, -4.868758538646029}, {-2.7992396844445406`, \
-5.0573998968420355`}, {-2.8465244549406297`, -5.143946227209923}}]}, 
           {Arrowheads[{{0.011898002334780517`, 1.}}], 
            ArrowBox[{{-2.8578454393008172`, -5.164667267880037}, \
{-2.8950196421270835`, -5.232708009226789}, {-2.984784404236025, \
-5.396249193762693}, {-3.0701781434359634`, -5.551269520074476}, \
{-3.1288609028386105`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.8120425758392338`, -4.363218329210998}, \
{-1.9019048152520952`, -4.59051174084402}, {-1.9849196107239586`, \
-4.79651938689634}, {-2.0621862866088763`, -4.9851331685226965`}, \
{-2.134804167260902, -5.160244986877828}, {-2.167511747879641, \
-5.238227188031972}}]}, 
           {Arrowheads[{{0.00913136570953021, 1.}}], 
            ArrowBox[{{-2.1766444099486737`, -5.260001500808017}, \
{-2.203275718101214, -5.323496506860515}, {-2.268675122739252, \
-5.47806094435125}, {-2.3366071461050644`, -5.636706563394409}, \
{-2.345334356486034, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.522161907866983, -2.5388252163555807`}, {
             3.6711073533042407`, -2.6400787816027687`}, {
             3.8089903030427656`, -2.7340226637181817`}, {
             3.93739296150945, -2.821683082788217}, {
             4.06774850876062, -2.9107831502519663`}, {
             4.192073045013011, -2.995806751475959}, {
             4.302290651465737, -3.0712160887304787`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.321770680775452, -3.0845597964106544`}, {
             4.41833152392053, -3.150766675250223}, {
             4.523166319981282, -3.222632066769749}, {
             4.623904007313669, -3.291707038029021}, {
             4.813088055793351, -3.421485719766806}, {
             4.988446632156176, -3.541830167343133}, {
             5.100617271355813, -3.618825543167099}}]}, 
           {Arrowheads[{{0.013814368149239606`, 1.}}], 
            ArrowBox[{{5.120084417710476, -3.6321880439114316`}, {
             5.1525426991987455`, -3.6544678276375593`}, {
             5.306577641729396, -3.7602140007860574`}, {
             5.45373046393606, -3.861326986616755}, {
             5.559867761111776, -3.9348963566896815`}, {
             5.655909545187918, -4.002268381111944}, {
             5.656854249492381, -4.002941108407707}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.054763534741963, -2.3215471238939767`}, {
             4.196368946524346, -2.400585615595399}, {
             4.329157397060056, -2.4748179121609084`}, {
             4.453128886349095, -2.544244013590504}, {
             4.570160870133669, -2.609869707915352}, {
             4.682130804155984, -2.67270078316662}, {
             4.878749621568752, -2.7831616624767586`}}]}, 
           {Arrowheads[{{0.018413043252087567`, 1.}}], 
            ArrowBox[{{4.899332775708753, -2.794731448042681}, {
             5.0828147706088505`, -2.8979450522979526`}, {
             5.261346275227205, -2.998464869577303}, {
             5.428013661829407, -3.0923819483403827`}, {
             5.587904115749885, -3.1825347289119406`}, {
             5.656854249492381, -3.2216455433365776`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.320468718925529, -1.9510828869258987`}, {
             4.544288990839757, -2.0482418101731743`}, {
             4.748372985738395, -2.1369401120848197`}, {
             4.936052383941581, -2.2185860432905176`}, {
             5.11065886576945, -2.294587854419951}, {
             5.186623772831842, -2.327669153659507}}]}, 
           {Arrowheads[{{0.010363251815738942`, 1.}}], 
            ArrowBox[{{5.208272089770903, -2.3370965916488093`}, {
             5.273687346197162, -2.365583714931827}, {
             5.427328798440322, -2.432510381208503}, {
             5.431146994310302, -2.4341737969054016`}, {
             5.5817349426346485`, -2.499803747689212}, {
             5.656854249492381, -2.532750335453489}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sca\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(sca\\)]\\)}\"", 
           TraditionalForm]}}], {583.2, -192.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.509618658038815}, \
{-5.650950386179752, -2.5094539641924456`}, {-5.451559709214463, \
-2.5040691351555204`}, {-5.249788874322055, -2.4988093438511108`}, \
{-5.046424422790572, -2.493704727753227}, {-4.8422528959080555`, \
-2.4887854243358816`}, {-4.712675931860511, -2.485792838081411}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689070233441884, -2.4852476633342326`}, \
{-4.637274293674505, -2.484051433599074}, {-4.43148861608992, \
-2.479502755542804}, {-4.224895863154301, -2.4751393901670724`}, \
{-4.017496034867649, -2.4709613374718784`}, {-3.8092891312299626`, \
-2.466968597457222}, {-3.7447917238361503`, -2.465793703830111}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721183647419646, -2.4653636558692567`}, \
{-3.6002751522412426`, -2.463161170123104}, {-3.463861482047055, \
-2.460786651920513}, {-3.327167312805484, -2.4584972740584092`}, \
{-3.1212336361436566`, -2.4552206749234586`}, {-2.914758123363276, \
-2.452145434184163}, {-2.7768260767582356`, -2.450230616534971}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.753216358671033, -2.4499028587295983`}, \
{-2.7077407744643414`, -2.4492715518405213`}, {-2.500181589446853, \
-2.4465990278925345`}, {-2.4730598433122144`, -2.446263403171289}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.336833924873502, \
-2.444668637588712}, {-2.2276018237721136`, -2.443461480337032}, \
{-2.0643346749686455`, -2.4417238814233584`}, {-1.9008804043157297`, \
-2.44011764681754}, {-1.8087971893552544`, -2.4392877174420353`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785186155310719, -2.4390749154590896`}, \
{-1.7372390118133656`, -2.438642776519577}, {-1.5734104974615537`, \
-2.4372992705294694`}, {-1.4093948612602938`, -2.436087128847217}, \
{-1.2451921032095858`, -2.43500635147282}, {-1.0808022233094299`, \
-2.4340569384062785`}, {-0.9162252215598261, -2.4332388896475923`}, \
{-0.8407273544070037, -2.4329250233340107`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.817115565449858, -2.4328268623469986`}, \
{-0.7515396925611215, -2.432554244612754}, {-0.5868242309136629, \
-2.432005042717756}, {-0.42207883661745005`, -2.431591283962599}, \
{-0.2573035096724835, -2.4313129683472825`}, {-0.09249825007876311, \
-2.431170095871806}, {0.07233694216371156, -2.4311626665361703`}, {
             0.12736183890379477`, -2.4312053920450514`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15097382478375632`, -2.4312237261841805`}, {
             0.2372020670549403, -2.4312906803403753`}, {
             0.40209712459492253`, -2.4315541372844205`}, {
             0.5680853160333115, -2.431968852522881}, {
             0.7323769879344981, -2.432493329866481}, {
             0.8966585974531037, -2.433152655422476}, {
             1.0609101470734603`, -2.4339465317271443`}, {
             1.0954481597140775`, -2.434141753774567}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1190597755262928`, -2.4342752156511893`}, {
             1.2251116392799013`, -2.4348746613167638`}, {
             1.3892430765567587`, -2.4359367467276116`}, {
             1.5532844613883663`, -2.4371324904959653`}, {
             1.7172157962590546`, -2.4384615951581026`}, {
             1.933899863217916, -2.44041926396066}, {
             2.0635092079489814`, -2.441724086977687}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0871200044813207`, -2.4419617851994446`}, {
             2.150273658732457, -2.4425975753258995`}, {
             2.3662868296418726`, -2.4449945488336264`}, {
             2.58188902278536, -2.4476082040636475`}, {
             2.7970298850021167`, -2.4504365605957688`}, {
             3.0116590631313387`, -2.453477638009795}, {
             3.0315249579720622`, -2.4537794137596594`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.055134227140607, -2.454138053778858}, {
             3.225726204012223, -2.456729455885533}, {
             3.4391809544839678`, -2.4601900338027884`}, {
             3.651972961385768, -2.4638573913413673`}, {
             3.864051871556822, -2.467729548081075}, {
             3.999474092188693, -2.4703410097947427`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.023081696152007, -2.4707962552752405`}, {
             4.075367331836327, -2.471804523601718}, {
             4.285868989063478, -2.476080337483102}, {
             4.495506490077474, -2.4805550093050326`}, {
             4.704229481717511, -2.4852265586473163`}, {
             4.911987610822786, -2.4900930050897583`}, {
             4.967334694385892, -2.4914474456792504`}}]}, 
           {Arrowheads[{{0.014105943173714912`, 1.}}], 
            ArrowBox[{{4.990939620335265, -2.4920250997805966`}, {
             5.118730524232496, -2.4951523682121652`}, {
             5.12772280239059, -2.4953775463974734`}, {
             5.13671326212576, -2.4956030515993004`}, {
             5.145701904905681, -2.4958288837687133`}, {
             5.154688732119001, -2.4960550428599313`}, {
             5.1636737449435115`, -2.496281528833944}, {
             5.181640145387477, -2.4967351544709215`}, {
             5.19959930045363, -2.4971900873375206`}, {
             5.217551220097529, -2.4976463271288196`}, {
             5.39667535730195, -2.502280522105985}, {
             5.574973469611246, -2.507041981176256}, {
             5.656854249492381, -2.5092955403457307`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.5103366035457677`}, {-5.648459766701725, 
             2.5101024177172357`}, {-5.449087764826464, 
             2.5047187667274358`}, {-5.247393375330116, 
             2.499461636303281}, {-5.044134884710521, 
             2.4943603669693695`}, {-4.840070579465519, 
             2.4894442992503003`}, {-4.712676144447289, 
             2.4865025036635346`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689070444381837, 
             2.4859574002273828`}, {-4.635200459595108, 
             2.484713433146073}, {-4.42952452509929, 
             2.480167768656688}, {-4.2230427759780635`, 
             2.4758073057821446`}, {-4.015755212231429, 
             2.4716320445224436`}, {-3.807661833859388, 
             2.467641984877585}, {-3.744792071119371, 2.466496884610924}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721183993718512, 
             2.4660668906909713`}, {-3.598762640861938, 
             2.463837126847568}, {-3.462394051455578, 
             2.4614636819889544`}, {-3.3257448968849186`, 
             2.459175317452859}, {-3.119819165119707, 
             2.4558992516384412`}, {-2.9133521259322412`, 
             2.452824621563813}, {-2.7768264901249675`, 2.450929699500109}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753216771146565, 
             2.450602005897765}, {-2.7063437793225207`, 
             2.449951427228975}, {-2.4987941252905452`, 
             2.447279668633927}, {-2.4716742916008054`, 
             2.446944156683084}, {-2.444546998600464, 
             2.446612201231679}, {-2.335493945630991, 
             2.4453503357202337`}, {-2.226305429791719, 
             2.4441439618066116`}, {-2.0631293493666445`, 
             2.4424077666043305`}, {-1.8997665022795176`, 
             2.4408028330853484`}, {-1.8087976451914123`, 
             2.4399831537260286`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7851866106638912`, 
             2.4397704053385705`}, {-1.7362168885303388`, 
             2.4393291612496664`}, {-1.5724805081191078`, 
             2.437986751097283}, {-1.4085573610458246`, 
             2.4367756026281997`}, {-1.2444474473104892`, 
             2.4356957158424155`}, {-1.0801507669131019`, 
             2.434747090739931}, {-0.9156673198536622, 
             2.433929727320746}, {-0.8407278253086613, 
             2.4336182681629177`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8171160362390931, 
             2.4335201342218884`}, {-0.7510755759907635, 
             2.4332456607115396`}, {-0.5864540051829974, 
             2.432696926038991}, {-0.421802607430365, 
             2.4322835233030995`}, {-0.25712138273286556`, 
             2.432005452503866}, {-0.09241033109049929, 
             2.4318627136412907`}, {0.07233054749673334, 
             2.4318553067153728`}, {0.12736136641060095`, 
             2.4318980316529024`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15097335229228478`, 2.431916363573845}, {
             0.23710125302883264`, 2.4319832317261123`}, {
             0.40190178550579914`, 2.43224648867351}, {0.5677932367493892, 
             2.432660896945141}, {0.7319914880924849, 2.4331849492450774`}, {
             0.8961796507006322, 2.433843738394992}, {1.0603377667339238`, 
             2.434636966851544}, {1.0954476833877553`, 
             2.4348353719809737`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.119059299388248, 2.4349688005440435`}, {
             1.2244458783524506`, 2.4355643370713937`}, {1.3884840277163066`, 
             2.4366255515112014`}, {1.5524322569855837`, 
             2.4378203126276268`}, {1.7162706083203738`, 2.43914832287733}, {
             1.9341616313305514`, 2.441117042049121}, {2.0635087119017923`, 
             2.442420046768179}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.087119506923223, 2.442657895022641}, {
             2.1517390112538735`, 2.443308853039739}, {2.3689516100485917`, 
             2.4457217390598625`}, {2.5857482896729547`, 
             2.4483536833201702`}, {2.8020779120852133`, 
             2.4512026690313413`}, {3.0178893392436166`, 2.454266679404054}, {
             3.0315244821975766`, 2.454474271754744}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.055133739105034, 2.4548337180147506`}, {
             3.233131433106415, 2.4575436976489864`}, {3.4477530556318587`, 
             2.4610317069768177`}, {3.661703068778197, 2.4647286905982266`}, {
             3.8749303345036785`, 2.4686326317238914`}, {3.999473525028572, 
             2.4710413166470726`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.023081103330045, 2.471497890930162}, {
             4.087383714766554, 2.472741513564491}, {4.299012071525074, 
             2.4770533193307034`}, {4.509764266737488, 2.481566032233208}, {
             4.719589162362045, 2.4862776354826828`}, {4.928435620356995, 
             2.4911861122898067`}, {4.967334276059514, 
             2.4921413417854428`}}]}, 
           {Arrowheads[{{0.014105955826735374`, 1.}}], 
            ArrowBox[{{4.990939152785404, 2.4927210038349967`}, {
             5.1362525026805885`, 2.496289445865258}, {5.145253379332883, 
             2.4965156335039347`}, {5.15425243485867, 2.496742148989984}, {
             5.16324967044186, 2.4969689922840335`}, {5.172245087292702, 
             2.497196163347467}, {5.181238686652568, 2.497423662142338}, {
             5.199222254128518, 2.4978793151210334`}, {5.217198564071106, 
             2.498336278719367}, {5.235167626470322, 2.4987945526229525`}, {
             5.414462505096029, 2.5034492766747563`}, {5.592756403716549, 
             2.5082267495146637`}, {5.656854249492381, 
             2.5099966435166885`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.304273632984294}, \
{-5.494438968809937, -4.296412786866923}, {-5.316180648981428, \
-4.288050613157377}, {-5.131149546874441, -4.279636426561433}, \
{-4.9451879176231, -4.27146330756364}, {-4.758433115004895, \
-4.263552237381084}, {-4.713336238897657, -4.261716691575069}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689743780340378, -4.260756424654242}, \
{-4.5710224927973115`, -4.255924197230855}, {-4.382956051000352, \
-4.248579187112951}, {-4.194233789614016, -4.241517207027375}, \
{-4.004855708638302, -4.234738256974124}, {-3.8148218080732104`, \
-4.228242336953199}, {-3.7459066717118636`, -4.225997002698078}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7223072011787015`, -4.225228104856637}, \
{-3.624132087918743, -4.2220294469646005`}, {-3.4327865481748976`, \
-4.216099587008329}, {-3.240897550452847, -4.210470639388915}, \
{-3.0485774563637626`, -4.205160486410893}, {-2.8558262659076443`, \
-4.200169128074261}, {-2.7782145907986973`, -4.198291908887117}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7546095015975345`, -4.197720964808143}, \
{-2.662643979084492, -4.19549656437902}, {-2.4690305958943055`, \
-4.191142795325171}, {-2.274986116337085, -4.187107820912712}, \
{-2.0805105404128303`, -4.183391641141644}, {-1.885603868121542, \
-4.179994256011967}, {-1.81032258489484, -4.178773101512832}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7867135426710326`, -4.178399922451994}, \
{-1.7140851274107547`, -4.177275803800049}, {-1.5440838153255747`, \
-4.1748354908254575`}, {-1.3739035815484855`, -4.172648458420589}, \
{-1.2035444260794872`, -4.170714706585442}, {-1.0330063489185797`, \
-4.169034235320018}, {-1.011449243693456, -4.16883792411292}, \
{-0.9898897181714179, -4.168645675033699}, {-0.9269428912541505, \
-4.168130939399584}, {-0.8639744505845147, -4.1676505587588295`}, \
{-0.8422995312339951, -4.167503171781825}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186880841080428, -4.167342616637037}, \
{-0.6766171650338204, -4.166376550607264}, {-0.48923990236399395`, \
-4.165413037928153}, {-0.3018426625750348, -4.164760020721496}, \
{-0.11442544566694324`, -4.164417498987293}, {
             0.07301174836028079, -4.164385472725544}, {
             0.12578436232767704`, -4.164463866889227}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14939632927298, -4.164498942665514}, {
             0.26046891950663714`, -4.164663941936249}, {
             0.447946067772126, -4.165252906619409}, {
             0.6354431931567472, -4.166152366775022}, {
             0.8228381215208673, -4.16735869315762}, {
             1.0100086787248528`, -4.168868256521731}, {
             1.0938589318770549`, -4.1696813448821395`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1174698148346998`, -4.169910297489795}, {
             1.196954864768703, -4.170681056867355}, {
             1.3836766796524187`, -4.172797094194493}, {
             1.5701741233759994`, -4.175216368503144}, {
             1.7564471959394452`, -4.1779388797933095`}, {
             1.9424958973427566`, -4.180964628064988}, {
             2.061854468324176, -4.183102899851676}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.085462673263272, -4.183525833522384}, {
             2.1283202275859328`, -4.18429361331818}, {
             2.3152256781797034`, -4.18803538746751}, {
             2.4997868685771087`, -4.191902505520686}, {
             2.684074578415856, -4.196068739480219}, {
             2.8680642529966844`, -4.200532028808526}, {
             3.0297021058832634`, -4.2047195991428765`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.053306109654114, -4.205333704415562}, {
             3.23505127758754, -4.210341531421152}, {
             3.4179995181990437`, -4.215683623630313}, {
             3.600551504755584, -4.221314529057933}, {
             3.745247848011824, -4.225985987335669}, {
             3.8895789054717067`, -4.230820596335845}, {
             3.997330937969373, -4.234557309549483}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.020928745627622, -4.235375653646067}, {
             4.033503239042318, -4.235811722225084}, {
             4.176979410630743, -4.240952731170006}, {
             4.320024761392236, -4.246246607505307}, {
             4.462690220623863, -4.251701831661725}, {
             4.604984732445423, -4.257320013949944}, {
             4.746917240976719, -4.263102764680651}, {
             4.8884674822153205`, -4.269046394678168}, {
             4.964682186927808, -4.272339373100699}}]}, 
           {Arrowheads[{{0.014172838044234552`, 1.}}], 
            ArrowBox[{{4.98827217117777, -4.273358616164305}, {
             5.0295985018032345`, -4.2751441864888955`}, {
             5.170294208326922, -4.281393208006637}, {
             5.31053851037284, -4.287790527125197}, {
             5.448149380078791, -4.2942223204513015`}, {
             5.579707111611912, -4.300511398141919}, {
             5.656854249492381, -4.30428562555572}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.208706421699353}, \
{-5.495298410129127, -5.1990257460592595`}, {-5.3224115951105535`, \
-5.188987604248594}, {-5.148815248155279, -5.1792316509509275`}, \
{-4.9744695311869185`, -5.169759286773467}, {-4.799360047284173, \
-5.1605729676689025`}, {-4.713836702436469, -5.1562463088268835`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.690254867674088, -5.155053294754908}, \
{-4.623516921547147, -5.151676996444517}, {-4.4469702790759476`, \
-5.143075675907592}, {-4.269750244970678, -5.13477330886541}, \
{-4.091886944331443, -5.126774198125252}, {-3.913410502258347, \
-5.119082646494402}, {-3.746751190085609, -5.112214011780716}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7231583756330573`, -5.111262788318292}, \
{-3.554738694210995, -5.104639431789749}, {-3.374603578436947, \
-5.097896374330512}, {-3.1939758216294587`, -5.091478087209709}, \
{-3.012885548888634, -5.085388873234624}, {-2.8313628853145776`, \
-5.079633035212539}, {-2.779265679367151, -5.078081455888072}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755664151218022, -5.0773785459635175`}, \
{-2.649437956007395, -5.0742148759507355`}, {-2.46714088606719, \
-5.069138698256496}, {-2.284501800594068, -5.064408804937101}, \
{-2.1248515899071605`, -5.060569282009102}, {-1.9649737850037876`, \
-5.057003167073164}, {-1.8114817754826678`, -5.053848377567284}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7878742225866098`, -5.053390815076772}, \
{-1.644393679847676, -5.050674985149195}, {-1.483787035667417, \
-5.047923836980249}, {-1.3230165679856796`, -5.045453376016083}, \
{-1.1620822768024635`, -5.043263602256701}, {-1.0009841621177689`, \
-5.041354515702101}, {-0.8434969649322261, -5.039765932620326}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8198858489926485, -5.039562992946404}, \
{-0.6784694119252033, -5.038387109651381}, {-0.5170960138376473, \
-5.0373309665162935`}, {-0.3556452670892422, -5.036559863308056}, \
{-0.3153304847892946, -5.036411850231281}, {-0.27501258629375824`, \
-5.03628163980075}, {-0.12737468302136254`, -5.035956670522608}, {
             0.020260526422096248`, -5.035870175538975}, {
             0.12458276455661207`, -5.035977569372879}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14819474504314423`, -5.036001876569081}, {
             0.16789304203661803`, -5.036022154849851}, {
             0.31552286382220285`, -5.036412608455236}, {
             0.3334964429179675, -5.036474662656263}, {
             0.35146939504239816`, -5.036540254750798}, {
             0.394202849768592, -5.036724654917348}, {
             0.4369324545057098, -5.036929074189196}, {
             0.6080520958107866, -5.037907465211809}, {
             0.7790657364739778, -5.039204851692262}, {
             0.9499733764952836, -5.040821233630553}, {
             1.0926483038859978`, -5.042437903297601}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.116258781201974, -5.042705436936477}, {
             1.1207750158747036`, -5.042756611026685}, {
             1.2914293847688025`, -5.045009793603692}, {
             1.4618952133341447`, -5.04757959108461}, {
             1.6321725015707307`, -5.050466003469441}, {
             1.8022612494785595`, -5.053669030758182}, {
             1.972236830439846, -5.057198599009905}, {
             2.060590491529454, -5.059180073253356}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0841965489000587`, -5.059709477401327}, {
             2.1416721286220426`, -5.060998460556546}, {
             2.310858587769711, -5.065106996159842}, {
             2.479766058529966, -5.0695202353961655`}, {
             2.6749483334153834`, -5.075006416113151}, {
             2.869694844425833, -5.080892286076615}, {
             3.0283054308829596`, -5.0860195328662625`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0519050966212102`, -5.086782415805517}, {
             3.0639638840033214`, -5.087172228240317}, {
             3.257713744589859, -5.093840625558017}, {
             3.4509027186274515`, -5.1008918609834755`}, {
             3.643489098558108, -5.108320317470452}, {
             3.835431176823837, -5.116120377972707}, {
             3.9956875133489413`, -5.122962831956985}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.0192780130668675`, -5.1239700739312255`}, {
             4.026687245866646, -5.124286425444}, {
             4.217246533915951, -5.132809490992416}, {
             4.407107787904988, -5.141679574388908}, {
             4.596243578331491, -5.15088951158154}, {
             4.784626475693195, -5.1604321385183765`}, {
             4.9626416380175025`, -5.169795980107618}}]}, 
           {Arrowheads[{{0.0142243360418258, 1.}}], 
            ArrowBox[{{4.986219588895527, -5.17106323959031}, {
             5.159023873213149, -5.180486805416914}, {
             5.344983514366867, -5.190984517274742}, {
             5.5300805444467285`, -5.20178626266903}, {
             5.656854249492381, -5.209383624856843}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.477418763193844, -5.656854249492381}, \
{-5.428143575086973, -5.6536898811129035`}, {-5.246826610948429, \
-5.642225411635835}, {-5.062173623870148, -5.630926339822216}, \
{-4.828587318768502, -5.617180984242045}, {-4.593677671188081, \
-5.603994797235783}, {-4.534606070055975, -5.600839747850665}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.511027684040484, -5.599580412216035}, \
{-4.357514838160103, -5.591381199722716}, {-4.120168976715789, \
-5.5793536126221275`}, {-3.8817102438863564`, -5.5679254568533025`}, \
{-3.642208796703026, -5.557110153335528}, {-3.5676559801846444`, \
-5.553951304995336}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.5440651536264234`, -5.552951747275088}, \
{-3.401734792197016, -5.546921122988087}, {-3.160358387399545, \
-5.537371786730264}, {-2.973030806318242, -5.530441273621718}, \
{-2.785272932499105, -5.523927172539818}, {-2.600240164711564, \
-5.517932559418329}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.5766391206290176`, -5.5172138034651415`}, \
{-2.4083063841099994`, -5.512137367600588}, {-2.219205657252729, \
-5.506868979970632}, {-2.029746602799423, -5.502021881852236}, \
{-1.8399292207500821`, -5.4975960732454014`}, {-1.6497535111047061`, \
-5.493591554150128}, {-1.6324680907774085`, -5.4932669699002}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6088602595948256`, -5.49282366392142}, \
{-1.459282359412593, -5.490014901992746}, {-1.2685786512230401`, \
-5.486872694199587}, {-1.077642386536048, -5.48416493077065}, \
{-0.8864735653516166, -5.481891611705937}, {-0.830381561254948, \
-5.4813079066170864`}, {-0.7742790532101987, -5.480762508130044}, \
{-0.6644752173638845, -5.479822903998173}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6408640888034421, -5.479620860838363}, \
{-0.639026039740755, -5.479605132439801}, {-0.5037222043980841, \
-5.478669704223025}, {-0.3683746234998623, -5.477956031910341}, \
{-0.23299037336376546`, -5.4774639239323735`}, {-0.2166065914953231, \
-5.477417783314651}, {-0.20022237623896555`, -5.477374886401207}, \
{-0.1622659581458828, -5.477300440349056}, {-0.12430763947431873`, \
-5.477243405735533}, {0.0009859783411950707, -5.47714998429281}, {
             0.12626645575192202`, -5.477246261816241}, {
             0.2515337927578623, -5.477532238305825}, {
             0.3036085436218193, -5.4777300015865915`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3272203663510705, -5.477819671752082}, {
             0.3767879893590158, -5.478007913761563}, {
             0.5020139660149296, -5.478673429407457}, {
             0.6271966431851508, -5.479528926467506}, {
             0.7523360208696794, -5.480574404941711}, {
             0.8774320990685156, -5.481809864830072}, {
             1.0024607711812608`, -5.483233244850949}, {
             1.1273979306075161`, -5.4848424837227014`}, {
             1.252243577347282, -5.486637581445331}, {
             1.2716507528662302`, -5.486945745757554}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2952597696749015`, -5.487320630625266}, {
             1.3769977114005583`, -5.488618538018837}, {
             1.536875928760565, -5.491427524487894}, {
             1.696474046534301, -5.494532313084762}, {
             1.8557920647217665`, -5.497932903809442}, {
             2.0148299833229615`, -5.501629296661934}, {
             2.1735878023378863`, -5.505621491642237}, {
             2.2395207583172883`, -5.507405466863412}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.2631241128456328`, -5.508044112575404}, {
             2.3320655217665403`, -5.509909488750352}, {
             2.4902631416089234`, -5.514493287986278}, {
             2.6481806618650365`, -5.5193728893500165`}, {
             2.772381861447144, -5.523420028384986}, {
             2.8963708008426687`, -5.527639460178768}, {
             3.0201474800516106`, -5.5320311847313635`}, {
             3.1437118990739696`, -5.536595202042773}, {
             3.207090290857081, -5.539028720175492}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.2306848974614715`, -5.539934674103806}, {
             3.267064057909746, -5.541331512112996}, {
             3.3902039565589397`, -5.546240114942033}, {
             3.5131315950215507`, -5.551321010529883}, {
             3.635846973297579, -5.556574198876547}, {
             3.8793511665280067`, -5.567513358688704}, {
             4.119426753488342, -5.578973499220892}, {
             4.174233509661526, -5.581748292244815}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.19781529885068, -5.582942206803942}, {
             4.356073734178586, -5.590954620473112}, {
             4.589292108598737, -5.603456722445363}, {
             4.7793822220456645`, -5.614137762066101}, {
             4.970493129080115, -5.625278193345502}, {
             5.140823038791584, -5.635561747737168}}]}, 
           {Arrowheads[{{0.006704908418980852, 1.}}], 
            ArrowBox[{{5.164391892894224, -5.636988340482729}, {
             5.355777323911586, -5.648937230880293}, {
             5.480400529001575, -5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9626094564588596, 0.0005252366926755919}, {
             0.9671553429467746, 0.0005252417086207639}, {0.9714914653611848, 
             0.0005252464716955861}, {0.9991086656254479, 
             0.0005252758337020564}, {1.0452490394996974`, 
             0.0005253254568599443}, {1.0948451775476242`, 
             0.0005253808337095827}, {1.194003977329075, 
             0.0005254992202841897}, {1.2931154549207375`, 
             0.0005256277670245545}, {1.39217575402739, 
             0.0005257664478344846}, {1.590118019187854, 
             0.0005260740132858679}, {1.7878098224940495`, 
             0.0005264217454372492}, {1.907089176376536, 
             0.0005266559401243426}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.93070116937446, 0.000526702300228852}, {
             1.9852212817208201`, 0.0005268093457504419}, {
             2.1823225146430083`, 0.0005272365156872597}, {2.289918277693839, 
             0.0005274866594496033}, {2.397407945084965, 
             0.0005277484605058513}, {2.6289750439521806`, 
             0.0005283523299160882}, {2.859935221113327, 
             0.000529008797299738}, {2.8751808892902706`, 
             0.0005290557259838072}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.898792882288128, 0.0005291284075971532}, {
             3.090288476568405, 0.0005297178626568009}, {3.3200348103174138`, 
             0.0005304795259872768}, {3.3502243042332718`, 
             0.0005305832040108312}, {3.380401719564123, 
             0.0005306877651669452}, {3.5186603619500008`, 
             0.000531190420991285}, {3.6566479483796135`, 
             0.0005317113382460309}, {3.843272602201078, 
             0.0005324355065943133}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.86688459519887, 0.0005325271293119914}, {
             3.87849832503934, 0.0005325721946095487}, {4.099498499142147, 
             0.0005334765383646077}, {4.319648470688033, 
             0.0005344243695112082}, {4.538948239677, 
             0.0005354156880493502}, {4.757397806109045, 
             0.0005364504939790335}, {4.811364315108318, 
             0.0005367179199732433}}]}, 
           {Arrowheads[{{0.017403824011583705`, 1.}}], 
            ArrowBox[{{4.834976308105998, 0.0005368349269988926}, {
             4.974997169984171, 0.0005375287873002584}, {5.191746331302376, 
             0.0005386505680130246}, {5.407645290063662, 
             0.0005398158361173324}, {5.566287336744341, 
             0.0005407867282721841}, {5.656854249492381, 
             0.0005413409993933403}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.00037788544585843405`}, {-5.613018147787441, 
             0.00037770428184359564`}, {-5.490022489216744, 
             0.00037720675209254183`}, {-5.366704953085265, 
             0.00037671867368179026`}, {-5.243065539393005, 
             0.0003762400466113409}, {-5.11911466011089, 
             0.00037577111733174025`}, {-4.994862727209849, 
             0.00037531213229353495`}, {-4.870309740689881, 
             0.00037486309149672493`}, {-4.745455700550987, 
             0.0003744239949413102}, {-4.712374529580382, 
             0.0003743111291898817}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.68876253658255, 
             0.00037423057021164025`}, {-4.575322055740379, 
             0.00037384353599438}, {-4.404667946626321, 
             0.0003732821766877326}, {-4.1785966596361925`, 
             0.00037257118407852964`}, {-3.95171994650173, 
             0.0003718952178700616}, {-3.7442828166682993`, 
             0.0003713112690608432}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.720670823670422, 
             0.0003712453493467906}, {-3.495550241799801, 
             0.00037064836465533035`}, {-3.465413632714931, 
             0.00037057089353192025`}, {-3.435264460578042, 
             0.0003704940522069211}, {-3.294745301526161, 
             0.0003701533502683364}, {-3.153972071400098, 
             0.0003698264768031073}, {-2.9345119126562285`, 
             0.00036933499045416934`}, {-2.776191103754314, 
             0.0003690064588886543}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752579110756395, 
             0.0003689574616337872}, {-2.7146077276375427`, 
             0.0003688786672034951}, {-2.4942595163440417`, 
             0.0003684575070510846}, {-2.2734672787757253`, 
             0.00036807150999693784`}, {-2.0522310149325937`, 
             0.0003677206760410548}, {-1.8305507248146462`, 
             0.00036740500518343556`}, {-1.8080993908389567`, 
             0.00036737665271176413`}}]}, 
           {Arrowheads[{{0.017393466616273345`, 1.}}], 
            ArrowBox[{{-1.7844873978410059`, 
             0.00036734683451195}, {-1.6084264084218833`, 
             0.0003671244974240801}, {-1.385858065754305, 
             0.0003668791527629883}, {-1.3814662656569938`, 
             0.00036687467193955564`}, {-1.375610376191446, 
             0.0003668687123294643}, {-1.369754306820445, 
             0.00036686277104979766`}, {-1.3404711499468183`, 
             0.0003668334741495877}, {-1.3111833511979016`, 
             0.0003668048079448916}, {-1.2818910234247558`, 
             0.0003667768005921833}, {-1.2086411350919495`, 
             0.0003667095355591373}, {-1.1353651234252384`, 
             0.00036664630213410136`}, {-1.0620645252798928`, 
             0.0003665870125252962}, {-1.0254054412621263`, 
             0.0003665588416403438}, {-0.9947123491969682, 
             0.00036653577188233244`}, {-0.9762900298616436, 
             0.00036652184906848747`}, {-0.969118705628988, 
             0.00036651634076416374`}, {-0.9630985739337169, 
             0.00036651165010937424`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.307771563002431}, {-5.526866215865615, 
             4.3014488606862145`}, {-5.388563186028041, 
             4.294882655628357}, {-5.2450189401951635`, 
             4.288230697543684}, {-5.097422055450617, 
             4.281559038643208}, {-4.947937626656267, 
             4.27498726073469}, {-4.7979495344513925`, 
             4.268592121948494}, {-4.713341584885475, 4.265096652271976}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689749716886796, 
             4.264121984293081}, {-4.647474534585746, 
             4.262375438979541}, {-4.49652938280908, 
             4.256339028522758}, {-4.345130834871148, 
             4.250484707273065}, {-4.193295646521703, 
             4.244814291925387}, {-4.041040573510496, 
             4.2393295991746465`}, {-3.8883823715872805`, 
             4.2340324457157665`}, {-3.7459156583652193`, 
             4.229277679875508}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7223162402229475`, 
             4.228507332835184}, {-3.581923604003835, 
             4.224008023453283}, {-3.4281565498431106`, 
             4.219284388039526}, {-3.274053389769388, 
             4.214755558697323}, {-3.1196308795324206`, 
             4.210423352121597}, {-2.9649057748819603`, 
             4.206289585007271}, {-2.8098948315677608`, 
             4.202356074049269}, {-2.7782226786618156`, 4.201594980165226}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7546175001937656`, 
             4.201027738746018}, {-2.654614805339573, 
             4.198624635942514}, {-2.4478651934399283`, 
             4.1939854693913}, {-2.2407186923717077`, 
             4.189717864214503}, {-2.033212750806195, 
             4.185824654728325}, {-1.824985364920976, 
             4.182278442542834}, {-1.8103310438549294`, 4.182056322372795}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7867217627491176`, 
             4.181698469046799}, {-1.6165670575592441`, 
             4.17911938047086}, {-1.4078642070427896`, 
             4.176340382721905}, {-1.1988768133716121`, 
             4.1739414492959686`}, {-0.9896048765457109, 
             4.1719225801930495`}, {-0.8423080822226356, 
             4.1707728067061405`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186968085424431, 
             4.170588501157643}, {-0.7801300146801752, 
             4.170287455386337}, {-0.5705338458900925, 
             4.169039754849015}, {-0.36081637017546286`, 
             4.168179478581086}, {-0.15097758753628654`, 
             4.16770662658255}, {-0.11674895852819192`, 
             4.167666274672624}, {-0.08251794490556053, 4.167636252495248}, {
             0.08874722990402012, 4.1676415168306855`}, {0.12577564432436253`,
              4.1676987277762985`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1493876091391586, 4.167735209566188}, {
             0.25997500270280266`, 4.167906073197745}, {0.4311653734907869, 
             4.168429921596427}, {0.602318342267973, 4.169213062026732}, {
             0.6233345095092957, 4.169325156891524}, {0.6443501207438941, 
             4.169441190448955}, {0.6963457245030927, 4.169762199262265}, {
             0.7483357413140238, 4.170107199172116}, {0.9034445090803271, 
             4.171985704623976}, {1.0585532768466306`, 4.173864210075838}, {
             1.0938365120177447`, 4.174291521507568}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1174467735770839`, 4.1745774628228}, {
             1.213662044612934, 4.175742715527698}, {1.3687708123792373`, 
             4.1776212209795585`}, {1.5221463135763205`, 4.181248896949065}, {
             1.6769492107715849`, 4.1834360795510985`}, {1.8315481942528233`, 
             4.185829046919913}, {1.985943264020036, 4.1884277990555105`}, {
             2.061796807279133, 4.1898061317232935`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.08540490308806, 4.190235113788988}, {
             2.140099659834731, 4.191228970723567}, {2.293982621458417, 
             4.1942291966897605`}, {2.4475921488910934`, 4.197428476954092}, {
             2.60092824213276, 4.200826811516561}, {2.753990901183418, 
             4.204424200377166}, {2.9067801260430666`, 4.208220643535909}, {
             3.02964380278185, 4.211439336536815}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0532476975280383`, 4.212057694157474}, {
             3.0592959167117053`, 4.21221614099279}, {3.211538273189335, 
             4.216410692747807}, {3.363447002311225, 4.220794933126889}, {
             3.514961910912641, 4.225359496455964}, {3.666082998993584, 
             4.230104382735031}, {3.816810266554055, 4.23502959196409}, {
             3.967143713594053, 4.2401351241431415`}, {3.997275268127409, 
             4.241197358562243}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.020872602415795, 4.242029240656225}, {
             4.117083340113578, 4.245420979272184}, {4.26662914611263, 
             4.250887157351221}, {4.415781131591211, 4.256533658380248}, {
             4.639910117582285, 4.265379306971856}, {4.863036009845088, 
             4.274613994959214}, {4.964625036206622, 4.2790154571291}}]}, 
           {Arrowheads[{{0.014174107534909252`, 1.}}], 
            ArrowBox[{{4.9882148986601855`, 4.280037515228296}, {
             5.08515880837962, 4.284237722342323}, {5.30627851318588, 
             4.294250489121183}, {5.520118213818732, 4.304328422849004}, {
             5.656854249492381, 4.311019787936259}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.408159397219442}, \
{-5.623935099948645, -3.4068901023130067`}, {-5.4560313606245, \
-3.4006113502951076`}, {-5.287554294979911, -3.3945057638775085`}, \
{-5.1185039030148785`, -3.3885733430602083`}, {-4.948880184729403, \
-3.382814087843207}, {-4.778683140123484, -3.377227998226506}, \
{-4.71295340569499, -3.3751445568417404`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689353265317135, -3.3743965010405566`}, \
{-4.607912769197123, -3.3718150742101036`}, {-4.436569071950318, \
-3.366575315794001}, {-4.2646907256328195`, -3.3615162143827364`}, \
{-4.092316407494377, -3.356645261380849}, {-3.9194461175349904`, \
-3.3519624567883386`}, {-3.746079855754659, -3.347467800605206}, \
{-3.745259711408409, -3.347447485911615}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7216549584814618`, -3.3468628042940383`}, \
{-3.572217622153384, -3.3431612928314505`}, {-3.3978594167311647`, \
-3.339042933467072}, {-3.223005239488001, -3.335112722512071}, \
{-3.0476550904238944`, -3.3313706599664474`}, {-2.9276131467173405`, \
-3.328923133469759}, {-2.807335271353688, -3.3265628289598}, \
{-2.777407068408965, -3.3260065627833324`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753799152912873, -3.325567769818996}, \
{-2.617977147991103, -3.3230432885630545`}, {-2.428263319352065, \
-3.3197659769004852`}, {-2.2381937854365743`, -3.3167308939720916`}, \
{-2.04776854624463, -3.3139380397778733`}, {-2.022985324551589, \
-3.3135906460404154`}, {-1.998194935502307, -3.3132471561632735`}, \
{-1.903276810683504, -3.3120054585888243`}, {-1.8094360623928756`, \
-3.310841466243327}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785824604753227, -3.3106854360895204`}, \
{-1.5868381891332108`, -3.3094281383864805`}, {-1.3653644680408903`, \
-3.3080287544137335`}, {-1.1438907469485697`, -3.3066293704409864`}, \
{-0.9224170258562494, -3.3052299864682393`}, {-0.8413638767487339, \
-3.305763664622846}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8177523955593836, -3.3059191296707486`}, \
{-0.7000832282211124, -3.3066938986312477`}, {-0.47845772891535365`, \
-3.3057998022118693`}, {-0.2567310441339694, -3.305242564161403}, \
{-0.03490317387695985, -3.3050221844798497`}, {
             0.1267221517940648, -3.3050753539492184`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15033412292027246`, -3.3051061971636297`}, {
             0.2945448750666947, -3.3053161617364633`}, {
             0.4591555333678894, -3.3057415124347864`}, {
             0.6236906142219958, -3.306352437846454}, {
             0.788150117629014, -3.307148937971466}, {
             0.9525340435889436, -3.3081310128098225`}, {
             1.0948035515358268`, -3.309142044377472}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1184149346608683`, -3.3093116195973717`}, {
             1.281075163167538, -3.310651886626568}, {
             1.445155591063396, -3.3121872934989547`}, {
             1.6090069100665554`, -3.31390149087268}, {
             1.7726291201770148`, -3.3157944787477436`}, {
             1.9360222213947735`, -3.317866257124146}, {
             2.062836835506518, -3.3196154483500755`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0864465826756353`, -3.3199411045284575`}, {
             2.0991862137198325`, -3.320116826001887}, {
             2.262121097152192, -3.3225461853809666`}, {
             2.424826871691852, -3.325154335261385}, {
             2.587303537338811, -3.3279412756431417`}, {
             2.75037243287274, -3.3309771161968404`}, {
             2.9118785095206503`, -3.334077901454472}, {
             3.0307796067626644`, -3.3364942801574524`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0543867253016064`, -3.336974038038577}, {
             3.0731245805192584`, -3.3373548398590622`}, {
             3.234095197490263, -3.3408066127334206`}, {
             3.394774912055364, -3.344431901400358}, {
             3.5551482758362605`, -3.3482293871826836`}, {
             3.7151998404546513`, -3.3521977514032075`}, {
             3.8749141575322343`, -3.35633567538474}, {
             3.9985920214126804`, -3.359669355683821}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.0221954414659375`, -3.3603055750843964`}, {
             4.02224440719987, -3.3603068949333768`}, {
             4.169181723096061, -3.3644093360690968`}, {
             4.315687494774893, -3.3686381004074066`}, {
             4.461723111790448, -3.372988289563811}, {
             4.6072937018218845`, -3.3774595581550404`}, {
             4.752429385762688, -3.3820541625128095`}, {
             4.8971290429884355`, -3.386771106825102}, {
             4.966235013284515, -3.3890887887960095`}}]}, 
           {Arrowheads[{{0.014133737611032197`, 1.}}], 
            ArrowBox[{{4.989833738051804, -3.3898802448553806`}, {
             5.041391552874703, -3.3916093952799016`}, {
             5.185226284981217, -3.3965702546599386`}, {
             5.328648603258652, -3.4016561818020867`}, {
             5.471666378669002, -3.406868085975542}, {
             5.614287482174256, -3.4122068764495}, {
             5.656854249492381, -3.4138429418372986`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.2063359125072706`}, {-5.51031590606774, 
             1.2044463930640197`}, {-5.352184096200734, 
             1.202461001544217}, {-5.200793999074204, 
             1.200611899448041}, {-5.048956721036972, 
             1.1988106759247947`}, {-4.896672262089042, 
             1.197057330974478}, {-4.74394062223041, 
             1.1953518645970909`}, {-4.712442609053775, 
             1.1950110164155734`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688831998412602, 
             1.1947555198654756`}, {-4.5907618014610785`, 
             1.1936942767926333`}, {-4.437135799781046, 
             1.1920845675611051`}, {-4.283062617190314, 
             1.1905227369025067`}, {-4.128542253688881, 
             1.1890087848168378`}, {-3.9736127625753017`, 
             1.187545260497745}, {-3.8183121971481286`, 
             1.186134713138875}, {-3.7443979143995176`, 
             1.1854901266074822`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207868192098132`, 
             1.185284220612257}, {-3.662640557407363, 
             1.1847771427402278`}, {-3.5065978433530036`, 
             1.1834725493018032`}, {-3.350184054985051, 
             1.1822209328236015`}, {-3.1933991923035054`, 
             1.1810222933056225`}, {-3.036243255308367, 
             1.179876630747866}, {-2.8787162439996354`, 
             1.1787839451503326`}, {-2.7763345299865185`, 
             1.1781110388094922`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7527230469684136`, 
             1.1779558517549222`}, {-2.7208859773536793`, 
             1.1777466018295422`}, {-2.5628202743468678`, 
             1.1767669661020157`}, {-2.4045191349792012`, 
             1.175845037967753}, {-2.2459825592506792`, 
             1.1749808174267538`}, {-2.0872105471613023`, 
             1.1741743044790185`}, {-1.9282030987110703`, 
             1.173425499124547}, {-1.8082570316007465`, 
             1.1729049455152352`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7846452609621364`, 
             1.1728024728562787`}, {-1.7689602138999825`, 
             1.1727344013633392`}, {-1.6094818927280399`, 
             1.1721010111953951`}, {-1.5319393479453767`, 
             1.1718141710572862`}, {-1.4543500047682307`, 
             1.1715408193254948`}, {-1.2242795703028033`, 
             1.1708132653645968`}, {-0.9939910996464627, 
             1.1702107902602998`}, {-0.8401702269482001, 
             1.1698922157070353`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8165582845901349, 
             1.1698433136051523`}, {-0.7634845927992091, 
             1.1697333940126042`}, {-0.5327600497610425, 
             1.1693810766215096`}, {-0.5070102823589565, 
             1.169348751533669}, {-0.4812588839442166, 
             1.1693179779812717`}, {-0.4344107725621175, 
             1.1692697834623085`}, {-0.38756006967482426`, 
             1.1692268405313324`}, {-0.24741884940833925`, 
             1.1694698744412872`}, {-0.10727762914185424`, 
             1.1697129083512419`}, {0.032863591124630886`, 
             1.1699559422611965`}, {0.1279201942140314, 
             1.1701207901044786`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15153215170584722`, 1.1701617381306197`}, {
             0.1730048113911158, 1.1701989761711513`}, {0.31314603165760074`, 
             1.170442010081106}, {0.4532872519240858, 1.1706850439910605`}, {
             0.5934284721905709, 1.1709280779010154`}, {0.7335696924570558, 
             1.17117111181097}, {0.8985647672348814, 1.171716584073909}, {
             1.0635598420127066`, 1.172262056336848}, {1.0960090157447813`, 
             1.1723693330191973`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1196208797092522`, 1.1724473936333475`}, {
             1.2285549167905319`, 1.1728075285997872`}, {1.3935499915683573`, 
             1.1733530008627262`}, {1.5569252979299906`, 
             1.1744358704584659`}, {1.7216345312226058`, 
             1.1750761775448402`}, {1.8861532035250808`, 
             1.1757797078468382`}, {2.0504813148374152`, 
             1.1765464613644598`}, {2.0640908028388045`, 
             1.176615185702969}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0877024947914355`, 1.1767344185433495`}, {
             2.214566459486135, 1.1773750482315062`}, {2.3783562317977647`, 
             1.1782640785817786`}, {2.5418506317723044`, 
             1.1792135524152771`}, {2.7050496594097546`, 
             1.1802234697320018`}, {2.867953314710115, 1.1812938305319525`}, {
             3.030561597673385, 1.182424634815129}, {3.0321648113228394`, 
             1.182436401129168}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0557761684290843`, 1.1826096897252878`}, {
             3.1928745082995658`, 1.1836158825815317`}, {3.354892046588656, 
             1.1848675738311605`}, {3.5165332737741455`, 1.186176072590681}, {
             3.6777172510895255`, 1.1875377428867593`}, {3.838443978534793, 
             1.1889525847193951`}, {3.9987134561099498`, 
             1.1904205980885885`}, {4.000223294764842, 1.19043496960324}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.023834218173279, 1.1906597119825655`}, {
             4.158525683814995, 1.1919417829943397`}, {4.31788066164993, 
             1.1935161394366485`}, {4.476778389614754, 1.195143667415515}, {
             4.635218867709466, 1.1968243669309389`}, {4.79303676921584, 
             1.198554164739185}, {4.9500667674156515`, 1.2003289875965184`}, {
             4.9682620674323505`, 1.2005409194620293`}}]}, 
           {Arrowheads[{{0.014082511638767283`, 1.}}], 
            ArrowBox[{{4.991872458909668, 1.200815924232857}, {
             5.106308862308897, 1.2021488355029386`}, {5.261763053895576, 
             1.204013708458446}, {5.416429342175692, 1.20592360646304}, {
             5.570307727149243, 1.2078785295167214`}, {5.656854249492381, 
             1.209009158614472}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.2057445850391748`}, \
{-5.513101452910997, -1.2038910889688168`}, {-5.354846879027562, \
-1.2019041957196102`}, {-5.203381620901341, -1.2000541668996105`}, \
{-5.051468744076286, -1.198252044776942}, {-4.8991082485523965`, \
-1.196497829351605}, {-4.746300134329672, -1.1947915206235995`}, \
{-4.712442544091266, -1.1944251428357366`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688831933419988, -1.194169649067665}, \
{-4.593044401408112, -1.1931331185929253`}, {-4.439341049787719, \
-1.1915226232595826`}, {-4.28519007946849, -1.189960034623571}, \
{-4.130591490450426, -1.1884453526848908`}, {-3.975583201875725, \
-1.186981120494161}, {-3.8202031328865833`, -1.185569881102}, \
{-3.7443978046977153`, -1.1849088146094804`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7207867094772213`, -1.184702912144906}, \
{-3.6644512834830008`, -1.1842116345084077`}, {-3.5083276536649777`, \
-1.1829063807133844`}, {-3.3518322434325136`, -1.18165411971693}, \
{-3.1949650527856086`, -1.1804548515190445`}, {-3.0377260817242635`, \
-1.179308576119728}, {-2.880115330248477, -1.1782152935189802`}, \
{-2.7763343936425526`, -1.1775331797807884`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7527229106408546`, -1.1773779902299781`}, \
{-2.7222008476030846`, -1.1771773799907868`}, {-2.5640506830329204`, \
-1.1761972118091333`}, {-2.405664836537984, -1.1752747889740194`}, \
{-2.2470433081182755`, -1.1744101114854453`}, {-2.0881860977737956`, \
-1.173603179343411}, {-1.9290932055045436`, -1.1728539925479164`}, \
{-1.808256881412935, -1.1723295966984029`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7846451107561916`, -1.1722271282177936`}, \
{-1.7697646313105193`, -1.1721625510989617`}, {-1.6102003751917233`, \
-1.1715288549965466`}, {-1.5326364004427702`, -1.1712419553144822`}, \
{-1.4550256694695287`, -1.1709685494275048`}, {-1.2249527072408182`, \
-1.1702410171698028`}, {-0.9946613915171261, -1.169638494085764}, \
{-0.8401700714496324, -1.1693184565159103`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8165581291151423, -1.1692695430323503`}, \
{-0.7641517222984524, -1.1691609801753882`}, {-0.5334236995847973, \
-1.1688084754386754`}, {-0.5076700726996276, -1.1687761212268148`}, \
{-0.48191482076159436`, -1.1687453188638866`}, {-0.43504598123262206`, \
-1.1686970609865106`}, {-0.388174449306551, -1.168654049923935}, \
{-0.24792584634436754`, -1.1688972235856951`}, {-0.10767724338218398`, \
-1.1691403972474552`}, {0.03257135957999968, -1.1693835709092153`}, {
             0.12792034998498042`, -1.1695488942183405`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15153230749036323`, -1.1695898344205715`}, {
             0.17281996254218324`, -1.1696267445709752`}, {
             0.3130685655043667, -1.1698699182327352`}, {
             0.45331716846655035`, -1.1701130918944953`}, {
             0.5935657714287339, -1.1703562655562554`}, {
             0.7338143743909175, -1.1705994392180155`}, {
             0.8988288019812867, -1.1711448607313286`}, {
             1.063843229571656, -1.171690282244642}, {
             1.0960091736648667`, -1.1717966002082325`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1196210376836047`, -1.1718746444059025`}, {
             1.2288576571620253`, -1.1722357037579552`}, {
             1.3938720847523944`, -1.1727811252712683`}, {
             1.5572637192311727`, -1.1738636618613116`}, {
             1.7219917715665556`, -1.1745038683881655`}, {
             1.8865289070652802`, -1.1752072649240461`}, {
             2.050875125727347, -1.1759738514689542`}, {
             2.064090969633069, -1.1760405652165817`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.087702661791285, -1.1761597573380187`}, {
             2.2149781208912493`, -1.1768022454695484`}, {
             2.3787855858954763`, -1.1776910643724878`}, {
             2.5422975207400293`, -1.1786403081777725`}, {
             2.7055139254249094`, -1.1796499768854027`}, {
             2.8684347999501147`, -1.1807200704953782`}, {
             3.031060144315646, -1.181850589007699}, {
             3.0321649970634574`, -1.1818586948329326`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0557763546269276`, -1.1820319211188068`}, {
             3.193389958521504, -1.183041532422365}, {
             3.355424242567688, -1.1842929007393765`}, {
             3.5170821385262494`, -1.1856010614011478`}, {
             3.678282788469242, -1.1869623818500934`}, {
             3.839026192396665, -1.1883768620862132`}, {
             3.9993123503085193`, -1.1898445021095074`}, {
             4.000223514672842, -1.1898531719964267`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.023834438845882, -1.190077834033985}, {
             4.159141262204804, -1.191365301919976}, {
             4.31851292808552, -1.1929392615176186`}, {
             4.477427347950665, -1.1945663809024356`}, {
             4.635884521800241, -1.196246660074427}, {
             4.793718704961855, -1.1979760213480137`}, {
             4.950764152763117, -1.199750387037617}, {
             4.968262339845172, -1.1999541266273108`}}]}, 
           {Arrowheads[{{0.014082504814185444`, 1.}}], 
            ArrowBox[{{4.991872732462689, -1.2002290334894816`}, {
             5.107020865204025, -1.2015697571432362`}, {
             5.26248884228458, -1.203434131664872}, {
             5.417168084004781, -1.2053435106025243`}, {
             5.571058590364628, -1.207297893956193}, {
             5.656854249492381, -1.208418317256539}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.4128634368910125`}, {-5.454607476619563, 
             3.405253420198616}, {-5.222450049616829, 
             3.396891968822082}, {-4.989224102431195, 
             3.38886088035293}, {-4.754875992293604, 
             3.381151276929252}, {-4.712953813223917, 3.3798362009750527`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689353429264345, 
             3.3790958697674713`}, {-4.519389863670305, 
             3.373764205165038}, {-4.282774835995214, 
             3.366712413947358}, {-4.045065653237538, 
             3.3600050965689086`}, {-3.8063226839017785`, 
             3.353647890728012}, {-3.745260739981948, 3.352119165009201}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7216561433167796`, 
             3.351528208487221}, {-3.5666062964924423`, 
             3.3476464341229906`}, {-3.3259768595140318`, 
             3.342006364452166}, {-3.084494741471049, 
             3.33673331941386}, {-2.842220310868, 
             3.331832936706395}, {-2.777409435744259, 3.3306268772514755`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753801529999444, 
             3.330187559962826}, {-2.599213936209387, 
             3.327310854028093}, {-2.3555253753321863`, 
             3.3231805514489245`}, {-2.111208244497929, 
             3.3194526572673526`}, {-1.86632869984795, 
             3.316128531524436}, {-1.80943859908789, 3.315451765328059}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7858282766437292`, 
             3.3151708962857778`}, {-1.6209528975235896`, 
             3.313209534261233}, {-1.4980995735276847`, 
             3.311902383822355}, {-1.3751469936661838`, 
             3.310697025518803}, {-1.2521034274567555`, 
             3.3095936293557084`}, {-1.128977144417068, 
             3.3085923653382046`}, {-1.0057764140647876`, 
             3.307693403471423}, {-0.8825095059175805, 
             3.306896913760496}, {-0.8413886065892859, 
             3.3066655602010306`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8177769872882229, 
             3.3065327169933365`}, {-0.7591846894931153, 
             3.3062030662105575`}, {-0.6358102343090587, 
             3.3056120308267376`}, {-0.512389850468779, 
             3.3051264144945116`}, {-0.3889280410172622, 
             3.304748400294076}, {-0.26543426488460015`, 
             3.304477522522648}, {-0.1419179810008872, 
             3.304313315477445}, {-0.01838864829621556, 
             3.3042553134556845`}, {0.10514427429932283`, 
             3.3043030507545827`}, {0.12669840994006165`, 
             3.304329749505664}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15031038482367845`, 3.304358997268156}, {
             0.2286713278556336, 3.3044560616713574`}, {0.3521830534426247, 
             3.3047138805032263`}, {0.4756699921302031, 
             3.3050760415474056`}, {0.5991226849882764, 3.305542079101113}, {
             0.722531673086752, 3.3061115274615664`}, {0.8458874974955358, 
             3.306783920925982}, {0.9691806992845361, 3.307558793791577}, {
             1.0924018195236602`, 3.3084356803555695`}, {1.0947795884001674`, 
             3.3084545734787074`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1183908360651882`, 3.308642182213089}, {
             1.215541399282814, 3.3094141149151763`}, {1.3385899796319058`, 
             3.3104936317676144`}, {1.5545063543456221`, 3.31263394933656}, {
             1.770010504009703, 3.3150826889257137`}, {1.9850654221393098`, 
             3.3178372284563244`}, {2.0628125845813226`, 
             3.3189532478858124`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0864221453195158`, 3.319292150653166}, {
             2.200028838087885, 3.320922914689653}, {2.4143764933202103`, 
             3.3243026015100576`}, {2.6282009040483842`, 3.327982844114417}, {
             2.8415020702724054`, 3.3319636425027306`}, {3.030756399433413, 
             3.335771672984577}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.054363611537366, 3.336246800227058}, {
             3.2664839124386336`, 3.3408219268339976`}, {3.4780630748421215`, 
             3.3456894531825045`}, {3.6890174792027395`, 
             3.3508475757205205`}, {3.8993471255204866`, 
             3.3562962944480446`}, {3.998567688870878, 
             3.358995553553093}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.022170949190956, 3.359637671609839}, {
             4.065620971547709, 3.360819713562643}, {4.231361106689843, 
             3.3655075230057667`}, {4.415584992741058, 3.370918880937377}, {
             4.5990987751190415`, 3.376522945125012}, {4.781902453823793, 
             3.3823197155686717`}, {4.963996028855313, 3.388309192268356}, {
             4.966211700448255, 3.3883833878765937`}}]}, 
           {Arrowheads[{{0.014134416152255047`, 1.}}], 
            ArrowBox[{{4.989810457736799, 3.389173873119218}, {
             5.012635332112538, 3.3899418816280895`}, {5.202049501620034, 
             3.3965867152592923`}, {5.390756862514018, 3.4034501440330387`}, {
             5.533304499024523, 3.4087060516301113`}, {5.656854249492381, 
             3.4133860949491024`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.2079980286349326`}, {-5.490891341505952, 
             5.198373420530422}, {-5.282999265750664, 
             5.186674998730889}, {-5.07477106049803, 
             5.175314848551636}, {-4.8662067257480475`, 
             5.1642929699926645`}, {-4.713782145194261, 5.156497657941546}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.690200970500304, 
             5.155291667315864}, {-4.657306261500718, 
             5.153609363053973}, {-4.447831322409838, 
             5.14331602249043}, {-4.237543563129206, 
             5.133464943056904}, {-4.02644298365882, 
             5.124056124753393}, {-3.814529583998681, 
             5.115089567579897}, {-3.7467012250041694`, 5.112371571591341}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7231081665573535`, 
             5.111426158210171}, {-3.601803364148789, 
             5.106565271536417}, {-3.3882643241091444`, 
             5.098483236622954}, {-3.1739124638797467`, 
             5.090843462839506}, {-2.9587477834605957`, 
             5.083645950186074}, {-2.7792222455377207`, 5.078052862081603}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7556217033834316`, 
             5.077317591138486}, {-2.742950228277657, 
             5.076922813451143}, {-2.5266997437568954`, 
             5.070706167423199}, {-2.309996329898311, 
             5.064996012102243}, {-2.092839986701903, 
             5.059792347488274}, {-1.8752307141676727`, 
             5.055095173581291}, {-1.8114374943940834`, 5.053869206072554}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7878298604400813`, 
             5.053415518481796}, {-1.6571685122956195`, 
             5.0509044903812965`}, {-1.4386533810857434`, 
             5.047220297888289}, {-1.2196853205380442`, 
             5.044042596102269}, {-1.1537067761883355`, 
             5.043185976903933}, {-1.0877012937067638`, 
             5.042376265609827}, {-0.9405250388587483, 
             5.0407422798666}, {-0.8434523453698457, 5.039821230899661}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8198414151548956, 
             5.039597204738428}, {-0.793269401253716, 
             5.039345083105932}, {-0.6459343808916672, 
             5.038184675327823}, {-0.4985199777726016, 
             5.037261056532274}, {-0.48031666208582113`, 
             5.037161651003664}, {-0.4621126375556891, 
             5.03706588316789}, {-0.4158722727410282, 
             5.0368553442017125`}, {-0.36962771955113627`, 
             5.036668248312998}, {-0.1902852555185438, 
             5.036118688660846}, {-0.010940763046878355`, 
             5.0359211664621695`}, {0.12462726347947609`, 
             5.036037964535838}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1482392477143163, 5.036058307343392}, {
             0.16840575786386017`, 5.03607568171697}, {0.34775430721367173`, 
             5.036582234425247}, {0.5270520808256984, 5.0374402490322945`}, {
             0.7062462745230826, 5.038649149983405}, {0.8853368883058241, 
             5.040208937278578}, {1.0643239221739231`, 5.042119610917815}, {
             1.0926928535521299`, 5.042478522129095}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.116302957086133, 5.0427772267487665`}, {
             1.243271303633653, 5.044383574286008}, {1.4218167768161307`, 
             5.046987208202094}, {1.6002075280789474`, 5.049939805754329}, {
             1.7784179864195935`, 5.053240405588754}, {1.9540109474217098`, 
             5.0568297047522135`}, {2.060635332526029, 
             5.059208172856135}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0842414530352666`, 5.059734754131456}, {
             2.129354429640358, 5.060741088431279}, {2.304421151803343, 
             5.06497199680754}, {2.479183832638464, 5.069519870062586}, {
             2.6536151908735235`, 5.074382148378004}, {2.827687945236323, 
             5.079556271935383}, {3.001374814454664, 5.08503968091631}, {
             3.0283534378341996`, 5.085941201792176}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0519522588501586`, 5.086729782791748}, {
             3.1746485172563483`, 5.090829815502375}, {3.3474817723691785`, 
             5.096924115875166}, {3.519847298520955, 5.103320022216272}, {
             3.691717814439479, 5.11001497470728}, {3.863066038852554, 
             5.117006413529778}, {3.995743892176619, 5.122665747629613}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.019334434334079, 5.123671995140561}, {
             4.03386469048798, 5.124291778865357}, {4.2040864880735604`, 
             5.131868510895602}, {4.373704150337095, 5.1397340498021045`}, {
             4.542690396006386, 5.147885835766451}, {4.671618540373013, 
             5.154302020222704}, {4.800358270385314, 5.160858046579919}, {
             4.928920626290903, 5.1675499873684885`}, {4.962705518194768, 
             5.169345569955314}}]}, 
           {Arrowheads[{{0.014221852385844492`, 1.}}], 
            ArrowBox[{{4.986284233784688, 5.170598719773092}, {
             5.057316648337391, 5.174373915118809}, {5.185557376772385, 
             5.181325902361276}, {5.313653851843497, 5.18840202162628}, {
             5.441617113798337, 5.195598345444219}, {5.569458202884514, 
             5.202910946345487}, {5.656854249492381, 5.207991284108276}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.9610768363280244`}, {-5.5632191052759685`, 
             2.957997112946055}, {-5.427782965349718, 
             2.9536562246309495`}, {-5.288725892018538, 
             2.949310841663963}, {-5.1480032899432855`, 
             2.945025812113752}, {-5.006864766097661, 
             2.940843064813117}, {-4.865324781502821, 
             2.936764419932111}, {-4.723397797179925, 
             2.9327916976407855`}, {-4.712808030299099, 
             2.93250396718041}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689204748163501, 
             2.9318626515299644`}, {-4.5852266775322885`, 
             2.9290375035858847`}, {-4.446721086156771, 
             2.925387064943104}, {-4.307890900338707, 
             2.921841580897318}, {-4.168745997363432, 
             2.918402250633402}, {-4.02929625451628, 
             2.9150702733362306`}, {-3.889551549082584, 
             2.9118468481906783`}, {-3.74952175834768, 
             2.90873317438162}, {-3.7450119405723195`, 
             2.908633964755179}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7214056588707187`, 
             2.908114659872822}, {-3.6083738979150217`, 
             2.9056281206512846`}, {-3.4674858490887774`, 
             2.902698973289701}, {-3.3263324695319936`, 
             2.89988197563436}, {-3.1849137592446715`, 
             2.8971771276852634`}, {-3.0432297182268098`, 
             2.89458442944241}, {-2.9012803464784085`, 
             2.8921038809058004`}, {-2.7771003145848607`, 
             2.8900358257950067`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7534915211806332`, 
             2.889647212796964}, {-2.6165856107899903`, 
             2.887479232951311}, {-2.473840246849972, 
             2.8853351335334323`}, {-2.330881560107064, 
             2.883307184410003}, {-2.1877615584889143`, 
             2.88139938616923}, {-2.0444802419955233`, 
             2.879611738811113}, {-1.9010376106268905`, 
             2.8779442423356523`}, {-1.8090983457985315`, 
             2.8769535883880493`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7854877233879483`, 
             2.8766991817823397`}, {-1.7574336643830168`, 
             2.8763968967428477`}, {-1.613668403263901, 
             2.8749697020326996`}, {-1.4697418272695444`, 
             2.873662658205207}, {-1.3256539363999458`, 
             2.8724757652603716`}, {-1.256528211576083, 
             2.871949506190655}, {-1.18737278977158, 
             2.871450922979805}, {-0.9841977944856523, 
             2.8701489727580554`}, {-0.8410374517442346, 
             2.869403495351872}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8174257788695981, 
             2.869280542526298}, {-0.7808789205821415, 
             2.869090232440428}, {-0.5774161680610478, 
             2.868274702026923}, {-0.3738095369223709, 
             2.8677023815175398`}, {-0.35097476385933035`, 
             2.867651850980897}, {-0.32813971054646573`, 
             2.867604429888156}, {-0.2861388833759561, 
             2.867533424054092}, {-0.2441363475351681, 
             2.867472899495779}, {-0.11126142746083922`, 
             2.8673334463334554`}, {0.02159118071554411, 2.867298057583668}, {
             0.12705070600004975`, 2.8673525820633614`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1506626958421864, 2.867364789888659}, {
             0.15442147699398145`, 2.867366733246417}, {0.28722946137447325`, 
             2.867539473321702}, {0.4200151338570192, 2.8678162778095233`}, {
             0.5527784944416194, 2.868197146709881}, {0.6855195431282739, 
             2.8686820800227752`}, {0.8182382799169825, 
             2.8692710777482056`}, {0.9508937605782696, 2.869963187580431}, {
             1.0834450408826588`, 2.8707574572137107`}, {1.0951348224510045`, 
             2.870836576091099}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1187462746508576`, 2.8709963833193726`}, {
             1.2158921208301505`, 2.871653886648045}, {1.3482350004207446`, 
             2.872652475883433}, {1.4804736796544409`, 2.8737532249198754`}, {
             1.61260815853124, 2.8749561337573724`}, {1.7446384370511414`, 
             2.876261202395923}, {1.8765645152141448`, 2.877668430835528}, {
             2.0089129853301726`, 2.879208006356271}, {2.063183048966431, 
             2.87986587504128}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.08679330731162, 2.880152081626818}, {
             2.140302161620527, 2.8808007228345467`}, {2.271567328438877, 
             2.8824944635422125`}, {2.4026985812276687`, 
             2.8842886606934353`}, {2.5336860154293497`, 
             2.8861827465023837`}, {2.664519726486366, 2.8881761531832244`}, {
             2.7951898098411645`, 2.8902683129501257`}, {2.9256863609361914`, 
             2.8924586580172553`}, {3.0311652106450975`, 
             2.894334416449584}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.054773470946369, 2.8947542484202105`}, {
             3.1345839442535635`, 2.8961735392894914`}, {3.3429261441373286`, 
             2.900132612234383}, {3.5506578829779536`, 2.904332007095342}, {
             3.757724083165906, 2.908767854115779}, {3.9640935078145776`, 
             2.9134354049048508`}, {3.9990503350702236`, 
             2.9142672778281535`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.022655645118356, 2.914829016973746}, {
             4.1697485433076045`, 2.918329408994993}, {4.3746545469408185`, 
             2.923445243514541}, {4.57877687601005, 2.9287782855918287`}, {
             4.782100603480204, 2.93432651314041}, {4.966809761364424, 
             2.9395825297104197`}}]}, 
           {Arrowheads[{{0.014119173983185908`, 1.}}], 
            ArrowBox[{{4.990412004349826, 2.940260909260945}, {
             5.186323527248588, 2.9460645232538694`}, {5.387187236428321, 
             2.9522495185643627`}, {5.585754901309635, 2.958590448204724}, {
             5.656854249492381, 2.9609477257335493`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7265414222521266, 0.5882881029913737}, {
             0.7310214182233881, 0.5882925899043098}, {0.7356698553255345, 
             0.588297235990896}, {0.7424213237405087, 0.5883039602982459}, {
             0.7559351889621894, 0.5883173557426427}, {0.783976049277569, 
             0.5883452048225912}, {0.8380619350765156, 0.5883997764496935}, {
             0.9119499167062575, 0.5884774021242979}, {0.9923490801263064, 
             0.5885680822501351}, {1.0003880211977039`, 0.5885775477742956}, {
             1.0120441297445544`, 0.5885914332615494}, {1.0800065104527297`, 
             0.5886757832298959}, {1.1479434498193364`, 0.5887653788516148}, {
             1.3805405682635135`, 0.5891126654895819}, {1.612762581135616, 
             0.5895224853130674}, {1.671020127282168, 
             0.5896411762524463}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.6946320712760783`, 0.5896892820172539}, {
             1.844609488435644, 0.5899948383220716}, {2.0760812901635974`, 
             0.5905297245165942}, {2.1057869487950636`, 0.5906024399803977}, {
             2.1354844703358067`, 0.5906761566757983}, {2.2345449056208775`, 
             0.5909368535835415}, {2.3335113786356176`, 0.5912087192868352}, {
             2.4594218122456044`, 0.5915635214063832}, {2.5851201004733317`, 
             0.5919355808505921}, {2.639108654624744, 0.592103078623506}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.66272053398717, 0.5921763337285867}, {
             2.7106062433187996`, 0.5923248976194617}, {2.835880240782008, 
             0.5927314717129921}, {2.960942092862957, 0.5931553031311833}, {
             3.0857917995616466`, 0.5935963918740352}, {3.2104293608780767`, 
             0.594054737941548}, {3.3348547768122474`, 0.5945303413337214}, {
             3.459068047364158, 0.5950232020505557}, {3.58306917253381, 
             0.5955333200920507}, {3.607193868617107, 0.595636097984333}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.630805647339609, 0.5957366907064862}, {
             3.7068581523212023`, 0.5960606954582065}, {3.8304349867263348`, 
             0.5966053281490231}, {3.953799675749208, 0.5971672181645005}, {
             4.076952219389822, 0.5977463655046386}, {4.199892617648176, 
             0.5983427701694374}, {4.322620870524271, 0.598956432158897}, {
             4.567277478859986, 0.6002314484553612}, {4.575274412043783, 
             0.6002753245227559}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.598886049654947, 0.6004048724105918}, {
             4.81075858312727, 0.6015673347375936}, {5.053024830302707, 
             0.6029624970284531}, {5.294036867362883, 0.6044153413507988}, {
             5.53327072546622, 0.6059241190807549}, {5.543349207560053, 
             0.6059906035951633}}]}, 
           {Arrowheads[{{0.0019035987044386565`, 1.}}], 
            ArrowBox[{{5.566960686822943, 0.6061463609521385}, {
             5.656854249492381, 0.6067393599580277}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.575578209049944, 
             5.656854249492381}, {-5.486186618508002, 
             5.651075781029539}, {-5.303845665964938, 
             5.639438390285692}, {-5.120649063140495, 
             5.628122329081915}, {-5.083907270034934, 
             5.625897553310817}, {-5.047131694480484, 
             5.623685359872158}, {-5.01032239581123, 
             5.621485700194321}, {-4.991909322387379, 
             5.620388997827421}, {-4.973487826889075, 
             5.6192954140021385`}, {-4.9550579110246575`, 
             5.618204943912444}, {-4.936619573243127, 
             5.617117583618172}, {-4.918172807275154, 
             5.616033330482833}, {-4.770408003858257, 
             5.6075085812581555`}, {-4.632826406308743, 
             5.5998158897834776`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6092499569490135`, 
             5.598520969033319}, {-4.474185017554608, 
             5.591208345559865}, {-4.325726834667858, 
             5.583432859086252}, {-4.177037525291157, 
             5.575907126862994}, {-4.028117089424504, 
             5.56863114889009}, {-3.8789655270679013`, 
             5.561604925167542}, {-3.729582838221347, 
             5.554828455695347}, {-3.6659189459632047`, 
             5.55205418728778}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.6423293399314227`, 
             5.551026227852068}, {-3.5798024478032873`, 
             5.548301506266541}, {-3.4294577807321653`, 
             5.5420238426741575`}, {-3.2785488370079814`, 
             5.535995464918196}, {-3.127075616630736, 
             5.530216372998657}, {-2.9750381196004287`, 
             5.524686566915539}, {-2.8224363459170596`, 
             5.519406046668844}, {-2.6985292226894257`, 5.515335916371095}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.6749299581392614`, 
             5.514560722184125}, {-2.6692702955806293`, 
             5.514374812258571}, {-2.5155399685911366`, 
             5.50959286368472}, {-2.361416393815723, 
             5.505076675786665}, {-2.20707060012153, 
             5.500842723403781}, {-2.0525025875085574`, 
             5.4968910065360665`}, {-1.8977123559768043`, 
             5.4932215251835235`}, {-1.742699905526272, 
             5.489834279346152}, {-1.7307852434838105`, 5.489595961779736}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7071779724318124`, 
             5.489123768160918}, {-1.5874652361569597`, 
             5.486729269023949}, {-1.4320083478688674`, 
             5.483906494216918}, {-1.2763292406619962`, 
             5.4813659549250575`}, {-1.0685156561802127`, 
             5.478424643302936}, {-0.8604605168841255, 
             5.475998319332467}, {-0.7628076031396703, 
             5.475104530040701}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7391965990937776, 
             5.474888425248997}, {-0.6522236125788698, 
             5.474092386287749}, {-0.44386473306958163`, 
             5.4727122474428835`}, {-0.235409453319596, 
             5.471857400054956}, {-0.026883348292248338`, 
             5.471527341381051}, {0.005967616347849036, 5.471523200077208}, {
             0.03881851320467761, 5.471532090568081}, {0.17403313846367022`, 
             5.471705821464676}, {0.20527264706085002`, 5.471796954370427}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.22888453958754157`, 5.471865835747659}, {
             0.3092138442765748, 5.47210017499568}, {0.44436063064339126`, 
             5.472715151161095}, {0.5794734975641196, 5.4735507499609195`}, {
             0.5965918700963324, 5.473670608823421}, {0.6137094743878958, 
             5.473794013501836}, {0.664732020130775, 5.474204017780731}, {
             0.7157467552618714, 5.47464556810571}, {0.8901245908533234, 
             5.4763369040405925`}, {1.064341374258363, 5.4783909159127235`}, {
             1.1733246974967315`, 5.479904101757579}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.196934414850769, 5.480231912371529}, {
             1.23839710547699, 5.480807603722104}, {1.4122917845092045`, 
             5.4835869674687325`}, {1.5859814442534415`, 5.486726748436731}, {
             1.759422117608135, 5.490224687910222}, {1.9326138045732857`, 
             5.494080785889206}, {2.1055565051488934`, 5.49829504237368}, {
             2.1412175677696883`, 5.499237568347412}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1648213179957088`, 5.499861418172137}, {
             2.278104940895206, 5.502855517313731}, {2.450113833372473, 
             5.50775027065944}, {2.6215831825806926`, 5.512979302410808}, {
             2.7925129885198663`, 5.518542612567835}, {2.934345243666335, 
             5.523412581916186}, {3.075217108384079, 5.528465310468189}, {
             3.10882393490811, 5.529722878009858}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1324194138224186`, 5.530605820896226}, {
             3.2151285826730978`, 5.533700798223844}, {3.3540796665333916`, 
             5.539119045183151}, {3.49207035996496, 5.5447200513461095`}, {
             3.6291006629678035`, 5.5505038167127205`}, {3.7651705755419216`, 
             5.556470341282983}, {3.9002800976873147`, 5.562619625056898}, {
             4.076030070775892, 5.570992473978945}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.0996153139993075`, 5.572116091097225}, {
             4.101341592015579, 5.572198332162607}, {4.303738027311532, 
             5.582356158930821}, {4.507469403575172, 5.593093105361542}, {
             4.7125357208065, 5.604409171454769}, {4.917740728131066, 
             5.616209636203525}, {5.042682056874427, 5.623670187949232}}]}, 
           {Arrowheads[{{0.010722306413067841`, 1.}}], 
            ArrowBox[{{5.06625206693565, 5.625077610789034}, {
             5.121888174674422, 5.628399778600834}, {5.324978060436568, 
             5.640979598646696}, {5.527010385417504, 5.653949096341111}, {
             5.57160338426206, 5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.7541553213746535}, {-5.566730436420229, 
             0.7534122300443351}, {-5.328032293575825, 
             0.7515265954144852}, {-5.088022793589572, 
             0.7497099875360637}, {-4.846737736848686, 
             0.7479644293325355}, {-4.712401423818845, 0.7470380270114101}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688789992256001, 
             0.7468751992211309}, {-4.604212923740381, 
             0.7462919437273654}, {-4.394714426898278, 
             0.7449149357960554}, {-4.184470244771319, 
             0.7435980303530949}, {-3.973480377359504, 
             0.742341227398484}, {-3.7617448246628333`, 
             0.7411445269322224}, {-3.744328306605779, 0.7410514805816233}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720716650560845, 
             0.7409253372032863}, {-3.5493457707404525`, 
             0.740009802024899}, {-3.3363653996515072`, 
             0.7389389257471018}, {-3.1228037113959974`, 
             0.7379318980988312}, {-2.908660705973925, 
             0.7369887190800869}, {-2.7762476295916345`, 
             0.7364465745256688}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7526358345027075`, 
             0.7363498997373681}, {-2.6939676158451418`, 
             0.7361096919260883}, {-2.478755673469503, 
             0.7352951198720546}, {-2.2630248788470086`, 
             0.7345450029179859}, {-2.0467752319776586`, 
             0.7338593410638821}, {-1.9562393757095697`, 
             0.7335922149724385}, {-1.8656451928403346`, 
             0.7333373356409437}, {-1.808161481783686, 0.7331894788038623}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7845495668933937`, 
             0.7331287453719224}, {-1.6334492988670304`, 
             0.7327400925291978}, {-1.4009397995632002`, 
             0.7322217339907586}, {-1.1681166949288446`, 
             0.7317822600256264}, {-0.9349799849639635, 
             0.7314216706338008}, {-0.9073150680690314, 
             0.7313835876718038}, {-0.8796462725367314, 
             0.7313465743303933}, {-0.8400716981166224, 
             0.7312987560883567}}]}, 
           {Arrowheads[{{0.004223099000248346, 1.}}], 
            ArrowBox[{{-0.8164597219920525, 
             0.7312705370724493}, {-0.7620684672314032, 
             0.731209349405018}, {-0.6965784027693727, 
             0.731137382585284}, {-0.6506832413338797, 
             0.7310892551743878}, {-0.6265247993546007, 
             0.7310645968809225}, {-0.6212438028368829, 
             0.7310592350495837}, {-0.6170282706166202, 
             0.7310549550071244}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.38094704706404575`}, {-5.521173498577246, 
             0.38039518376232223`}, {-5.3263978076137795`, 
             0.37962921918931636`}, {-5.13078719890355, 
             0.3788861665211512}, {-4.934371856210927, 
             0.3781668294115601}, {-4.737168548293893, 
             0.37747165433483953`}, {-4.712381253945723, 
             0.37738770332927857`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688769396370766, 
             0.3773077333592312}, {-4.53919922492473, 
             0.3768011606724972}, {-4.340485835875724, 
             0.37615586780604093`}, {-4.141092622765418, 
             0.3755369378714464}, {-3.941083827212358, 
             0.37494553300468936`}, {-3.7442941942744907`, 
             0.3743924312343114}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7206822866669493`, 
             0.3743289421305055}, {-3.539219488777971, 
             0.3738452984746877}, {-3.3373639458966453`, 
             0.3733364688114431}, {-3.134892820572565, 
             0.372855164216036}, {-2.931806112805729, 
             0.3724013846884664}, {-2.776205272276609, 0.3720757842637222}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525933309734882`, 
             0.37202637541675715`}, {-2.728103822596138, 
             0.37197513022873424`}, {-2.6174280459252426`, 
             0.37175580977867334`}, {-2.5066094810029655`, 
             0.3715451387555593}, {-2.2747370587045688`, 
             0.37113393119251037`}, {-2.042409709705244, 
             0.3707623559381679}, {-1.809627434004991, 
             0.37043041299253193`}, {-1.8081149818488425`, 
             0.3704285174722267}}]}, 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQvfFHK1tw75/9a7rrNs7dct3evm/5tycWP/en7lbf
Gb7hur3f66JjwQd/7J/RmXrxxPrr9m1Bz/7v8fyx39L4SZcNkP9HqyUgj/n7
fuk2j/U31l63Zwvaz/Njz9f9lTKtth1rrttzPixXc1r2dT+7z8+nBUC++Yc/
TL/av+7ff9HyZSCQv+u8av/GzK/7p6wpFjEG8i/rS/o7Xfqyvz22NHv26uv2
rL3/zpyy+rL/39Hlr9iB/Ke/ExW8F3/ev/8Gz8SKVdftZY9++5qh8Wl/2IQF
fiorr9tXzam8H7r2w/7JFY/vvFx+3d7RdWpIee27/XY6J+0uLrtuHztp+cMP
du/263LwhewC8rWDHviKS77bryygWboGyG8+5rnA9evb/W12TiHzgfwSE6vV
vG/e7H+j+OG9LZA/+77LpseBb/YLHpnJxArkc51dOMPj/ev9zzSKwx4svW4v
eIP9WuuC1/u/17ZePgTkx3sH3piX+Xr/ikU+CuuAfK04rQPyjq/3Hwk3PjUP
yJfM2/m8Uej1/j8XfAV7gfwrIVcVbD692s/+3u5AA5D/SMy0ofLhq/02MyND
qoB8APGC8yI=
             "]]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQLZG0S3li3FX7tDRPBdeXr+33XbnpKbT0qn1f4Mlw
byB/qmuHORPTNfs1Ifqzg4H874w/ZO0rrtkvsRe1jwPyN4U79taXXrf/drB4
bimQ/036XJdk2k37jQHuS5cC+bsbL9+3y79l7yOVZ38AyLedJdV/bfVte4nA
SP6HQL7UzAlPP6rftXde8uM256vX9odF1xzyf33Xfu6+NxHyQH5fwcakIyfv
2UedNzK1APLfLupn6L5z3/6RtHJcOJD/7fTDKc0+D+xzw/Pv5gD5qz6vSmfY
/MC+RP7j9BYgv1K4V39//UP7OTO6Y7YC+ada3p2c4/fI/sukhR9eAPlu0523
Hb/+2P76im2c/q+B9rEl+ExNfmV/Z6rdbcW3r+3fWNkVbiz/YP+w6diaL+9e
208o8rGZsfez/bN8v7rjH17b86/Vb7cq+WJfOCffTvfja3sAMyu4YA==
             "]]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.3019881082374063`, 0.8732162124383449}, {
             1.438353565909563, 0.8733645972560259}, {1.4672535989337339`, 
             0.8734376502513974}, {1.4961500347943846`, 0.8735122376459552}, {
             1.575038374705704, 0.8737307860787996}, {1.6538743958531417`, 
             0.8739596308601262}, {1.7792119779439914`, 0.8743370284609016}, {
             1.9044098072049531`, 0.874741157061083}, {2.029467883636027, 
             0.8751720166606705}, {2.1543862072372124`, 0.875629607259664}, {
             2.246463429621093, 0.8759870002578807}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.2700752447561485`, 0.8760786483027063}, {
             2.2791647780085103`, 0.8761139288580635}, {2.4038035959499195`, 
             0.8766249814558691}, {2.5283026610614407`, 0.8771627650530808}, {
             2.652661973343074, 0.8777272796496984}, {2.77684704519368, 
             0.8783175375798273}, {2.9008233890121202`, 0.8789325511775722}, {
             3.0245910047983946`, 0.8795723204429332}, {3.148149892552503, 
             0.8802368453759103}, {3.2145440004501444`, 
             0.8806078556013588}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.238155624805821, 0.8807397973406605}, {
             3.271500052274446, 0.8809261259765035}, {3.394641483964223, 
             0.881640162244713}, {3.517574187621834, 0.8823789541805385}, {
             3.640298163247279, 0.8831425017839801}, {3.8850766346644594`, 
             0.8847426088688025}, {4.1289336024785515`, 0.8864392283742706}, {
             4.182615564629574, 0.8868354605197174}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.206226914454915, 0.8870097383483084}, {
             4.371869066689556, 0.8882323603003844}, {4.613883027297472, 
             0.8901220046471442}, {4.785983424301676, 0.8915281325632242}, {
             4.957529472267734, 0.8929806611730935}, {5.128521171195646, 
             0.8944795904767521}, {5.150675371285331, 
             0.8946804593003415}}]}, 
           {Arrowheads[{{0.010219155693196232`, 1.}}], 
            ArrowBox[{{5.174286393798364, 0.8948945369152739}, {
             5.298958521085411, 0.8960249204742001}, {5.468031850331608, 
             0.8976079901831181}, {5.634931487328814, 0.8992201386211864}, {
             5.656854249492381, 0.8994385634291201}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.6053586477125096}, \
{-5.454640035895746, -0.6040537821165008}, {-5.215002245358075, \
-0.6025699621110936}, {-4.974099198003488, -0.6011425917785813}, \
{-4.731960882829503, -0.5997730193601029}, {-4.712391718918747, \
-0.5996676511423992}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688780068190067, -0.5995405165562886}, \
{-4.488626992765052, -0.598462812218912}, {-4.24413722073907, \
-0.597213537718262}, {-4.121499960686731, -0.5966127487577354}, \
{-3.9986558935364656`, -0.5960291900565351}, {-3.875605019288272, \
-0.5954628616146609}, {-3.7523473379421506`, -0.5949137634321131}, \
{-3.744311899868002, -0.594879147877353}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720700125958784, -0.5947774316242753}, \
{-3.628882849498101, -0.5943818955088914}, {-3.505211553956124, \
-0.593867257844996}, {-3.3813334513162197`, -0.5933698504404269}, \
{-3.2572485415783867`, -0.5928896732951839}, {-3.1329568247426263`, \
-0.5924267264092673}, {-3.0084583008089383`, -0.5919810097826769}, \
{-2.883752969777322, -0.5915525234154128}, {-2.7762272353901545`, \
-0.5911985096607095}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7526153674937537`, -0.5911216620127543}, \
{-2.6337218864203074`, -0.590747241458863}, {-2.508396134094908, \
-0.5903704458695777}, {-2.382863574671581, -0.5900108805396184}, \
{-2.2571242081503264`, -0.5896685454689854}, {-2.1603768769135443`, \
-0.5894174170145622}, {-2.063542367403525, -0.5891769210489496}, \
{-1.8312327262012895`, -0.588644841022648}, {-1.8081390653967353`, \
-0.5885982695964731}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7845271204113227`, -0.5885506529815916}, \
{-1.5985481740054288`, -0.5881756017999734}, {-1.3654887108159426`, \
-0.5877692033809259}, {-1.1320543366328317`, -0.587425645765505}, \
{-1.1037750807130469`, -0.5873878624463786}, {-1.0754913560219328`, \
-0.5873509859243886}, {-1.0098347140804687`, -0.5872723809046717}, \
{-0.9441657829127628, -0.5871991369047606}, {-0.9382615668688037, \
-0.5871925731328532}, {-0.9127911759681743, -0.5871647446483521}, \
{-0.8896749514702995, -0.5871401605054711}, {-0.8671485530223348, \
-0.5871167134783378}, {-0.840048581237221, -0.5870890462917921}}]}, 
           {Arrowheads[{{0.0019181059876386326`, 1.}}], 
            ArrowBox[{{-0.8164366004477467, -0.5870650358749995}, \
{-0.7878259725944118, -0.5870363667991376}, {-0.7652020856685215, \
-0.5870139368298062}, {-0.7488234725931306, -0.5869977476402356}, \
{-0.7401948077748451, -0.5869891799356376}, {-0.735143610925027, \
-0.5869841473366142}, {-0.7298618412424202, -0.5869788730662768}, \
{-0.7258560350322862, -0.5869748643101383}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7bFl99db7s/tTWPYD7YefrT/k8eMfIfc5/aebAuC
+4F8qSi1jxMWPLffFrI9dw6Qf0Ni1f1pZ5/bd98LebocyJ9+4uoiO60X9rt2
BafsB/JNved/2Xf3hX3Cedlbb4D8mxMzPieKv7K/n72fyfbIo/1/S+1aN79/
Za+5te9HCZD/dPNSs9R3r+3jH4bc2w7k3ypQZitkfmufFddTwXT00X6ti+ev
eZa8tVcvN56iCOTXe3lmKj59a/8p+ouWI5B/u57jcUfOO/s4hpPb0oH8NU0m
+9mmvLP/s+SvaDGQz+K306i+6r09tyT30q1Avl3G9MxKgw/2ESIJjr+A/HSJ
Yv8fJh/tl+9evHXxsUf7fQr0E+MtP9mL78jfE3b80X7msiQ23c6v9ln/cg0u
nny0/37e566+6z/sX93acX3jmUf7zd/s0W8+8MtebC+zy/Rzj/YDAFWawME=

             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.6956120577834812`, -0.5877643973719333}, {
             1.7589148837484385`, -0.5878871424378531}, {
             1.9648563347178662`, -0.5883358720772794}, {
             2.1704505266686915`, -0.5888333346589864}, {
             2.375697459600914, -0.5893795301829737}, {
             2.580597133514534, -0.5899744586492416}, {
             2.640088683014948, -0.5901616596391093}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.663700559115439, -0.590235958705376}, {
             2.7851495484095516`, -0.59061812005779}, {
             2.989222404402752, -0.5913085553859023}, {
             3.192683401610921, -0.592043805610862}, {
             3.3955325400340577`, -0.5928238707326692}, {
             3.5977698196721626`, -0.5936487507513236}, {
             3.608173902402653, -0.5936936279191574}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.631785675746237, -0.5937954753902551}, {
             3.799395240525235, -0.5945184456668254}, {
             4.0004088025932765`, -0.5954329554791747}, {
             4.2008105058762855`, -0.5963922801883713}, {
             4.400600350374263, -0.5973964197944153}, {
             4.576254509560871, -0.59831981837084}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.599866176097278, -0.5984439815982069}, {
             4.798000956679723, -0.5995297650160033}, {
             4.995504535679315, -0.6006557669723934}, {
             5.192181890278094, -0.6018201765073231}, {
             5.388016788613774, -0.6030222603111199}, {
             5.544329421496737, -0.6040151835802928}}]}, 
           {Arrowheads[{{0.0018828402310336586`, 1.}}], 
            ArrowBox[{{5.567940938137514, -0.6041651677745367}, {
             5.582980013334237, -0.6042606984263736}, {
             5.656854249492381, -0.6047478097739163}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.960925988215735}, \
{-5.6340016405495525`, -2.960158342876653}, {-5.507122308985041, \
-2.9560379203714495`}, {-5.3793714990805075`, -2.951986777571447}, \
{-5.250780500429264, -2.948006794530858}, {-5.121380602624623, \
-2.944099851303894}, {-4.991203095259899, -2.9402678279447683`}, \
{-4.860279267928402, -2.9365126045076932`}, {-4.728640410223447, \
-2.9328360610468804`}, {-4.712806478257422, -2.9324057599672555`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68920319949911, -2.9317643200296466`}, \
{-4.596317811738344, -2.929240077616543}, {-4.463342762066407, \
-2.9257265342708934`}, {-4.32974655080095, -2.9222973110641433`}, \
{-4.195560467535282, -2.9189542880505055`}, {-4.060815801862719, \
-2.9156993452841924`}, {-3.9255438433765715`, -2.9125343628194162`}, \
{-3.789775881670153, -2.90946122071039}, {-3.745011632864175, \
-2.908482222287959}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721405284662495, -2.90796594918464}, \
{-3.6535432063367757`, -2.9064817990113245`}, {-3.5168771069697518`, \
-2.9035979777764336`}, {-3.3637821945428885`, -2.9004968232197603`}, \
{-3.2104133873465193`, -2.8975309687496895`}, {-3.0567843741042346`, \
-2.894701260953985}, {-2.9029088435396266`, -2.892008546420411}, \
{-2.7770991993902654`, -2.889922820009818}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.753490450535015, -2.8895314240135783`}, \
{-2.7488004843762877`, -2.8894536717367303`}, {-2.5944729853378083`, \
-2.887037483490708}, {-2.4399400351477807`, -2.8847608282701085`}, \
{-2.284047218116646, -2.88255231050684}, {-2.128704111185433, \
-2.8805300291939693`}, {-1.973182930549854, -2.878648974082049}, \
{-1.8174836762099105`, -2.876909145171078}, {-1.8090974001949014`, \
-2.8768231395682573`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7854866488022898`, -2.8765809990874356`}, \
{-1.6616063481656016`, -2.875310542461057}, {-1.5055509464169279`, \
-2.873853165951986}, {-1.3493174709638884`, -2.8725370156438648`}, \
{-1.1929059218064841`, -2.8713620915366933`}, {-1.036316298944715, \
-2.8703283936304715`}, {-0.8796189796622853, -2.8694381284417356`}, \
{-0.8410365809923603, -2.869254828465837}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8174248544603068, -2.869142652213104}, \
{-0.7228843412429009, -2.8686935024870217`}, {-0.5661123836865614, \
-2.8680945157663293`}, {-0.4093031069932671, -2.867641168279659}, \
{-0.25245651116301804`, -2.8673334600270106`}, {-0.09557259619581404, \
-2.867171391008384}, {0.06134863790834477, -2.8671549612237786`}, {
             0.1270515902507497, -2.867209048383235}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15066357524814777`, -2.8672284859450508`}, {
             0.2183071911494583, -2.8672841706731953`}, {
             0.447015248840019, -2.8677305081952524`}, {
             0.6754627668084672, -2.868480492674472}, {
             0.9036497450548038, -2.8695341241108534`}, {
             1.0951357780368565`, -2.8706744036541774`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1187473523959437`, -2.8708150081400925`}, {
             1.1315761835790288`, -2.870891402504397}, {
             1.359242082381142, -2.872552327855103}, {
             1.5866474414611442`, -2.8745169001629707`}, {
             1.8137922608190342`, -2.8767851194280007`}, {
             2.040676540454813, -2.8793569856501935`}, {
             2.063184598688983, -2.87964170519748}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0867947027866216`, -2.879940365263139}, {
             2.267109888309582, -2.882221293162688}, {
             2.492901912324443, -2.885366836298623}, {
             2.7180526124993967`, -2.888793615058}, {
             2.9425619888344428`, -2.892501629440818}, {
             3.031167325580613, -2.8940805453970238`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0547755705965334`, -2.8945012360249534`}, {
             3.1664300413295807`, -2.8964908794470774`}, {
             3.3896567699848115`, -2.9007613650767783`}, {
             3.6122421748001345`, -2.9053130863299206`}, {
             3.83418625577555, -2.910146043206504}, {
             3.998140108685934, -2.9138999688439333`}, {
             3.9990543417669357`, -2.9139217395084667`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.022659642894801, -2.91448385337499}, {
             4.161604680391238, -2.9177925564429255`}, {
             4.355416202188149, -2.922606821794991}, {
             4.548602774067428, -2.927624839939787}, {
             4.741164396029075, -2.9328466108773115`}, {
             4.933101068073089, -2.9382721346075655`}, {
             4.958722558342851, -2.9390111865160167`}, {
             4.966813515503528, -2.9392458497993905`}}]}, 
           {Arrowheads[{{0.014119255290070073`, 1.}}], 
            ArrowBox[{{4.990415357015892, -2.9399380360133196`}, {
             5.172852382342611, -2.945459013411788}, {
             5.3604123316919425`, -2.9513177095053966`}, {
             5.585344295516415, -2.958482662500688}, {
             5.656854249492381, -2.960860867831883}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.757583999163666}, \
{-5.5581677981115325`, -4.752109265093802}, {-5.3541944199917015`, \
-4.741230843776668}, {-5.14719271644956, -4.730627294812394}, \
{-4.937394361061459, -4.720317127312642}, {-4.72503102740375, \
-4.710318850389073}, {-4.713587569879337, -4.709803546827042}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68999947999917, -4.708741365514199}, \
{-4.510334389052783, -4.700650973153349}, {-4.293536119584909, \
-4.691332004717131}, {-4.074867892576476, -4.68238045419208}, \
{-3.8548753426959275`, -4.673836461532833}, {-3.7463240530014486`, \
-4.669853776112736}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722727936201087, -4.668988047933769}, \
{-3.6339899369418527`, -4.6657323009329446`}, {-3.412272097385825, \
-4.658074682862454}, {-3.1897822460994187`, -4.650870317791398}, \
{-2.9665808051542077`, -4.644125916189817}, {-2.7787324582873256`, \
-4.638857892863524}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755129744845363, -4.638195977829136}, \
{-2.7427281966217647`, -4.637848188527747}, {-2.518284842573664, \
-4.632043845275229}, {-2.293311165081479, -4.6267195969023}, \
{-2.1221692149448006`, -4.623001793031343}, {-1.9507725623317447`, \
-4.619567639153289}, {-1.8108912354727627`, -4.61700219561491}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.787283212548252, -4.616569221098399}, \
{-1.7791500571345498`, -4.616420057865027}, {-1.6070228170615797`, \
-4.613530797396646}, {-1.4347995489195422`, -4.610941261204048}, \
{-1.2624081279778419`, -4.608644142795014}, {-1.0898485542364784`, \
-4.606639442169545}, {-0.9171208276954527, -4.604927159327642}, \
{-0.8428865089073387, -4.604318012872621}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8192753108134121, -4.604124265858403}, \
{-0.7442720754652352, -4.60350880988503}, {-0.5713494246562973, \
-4.602385909457438}, {-0.3983528752686393, -4.601558458044865}, \
{-0.22528242730226053`, -4.601026455647312}, {-0.18884404152606976`, \
-4.60095211846286}, {-0.15240312454438537`, -4.600890876748506}, {
             0.007194527870163753, -4.600776925895765}, {
             0.1251952300502437, -4.600878423409325}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1488072143135929, -4.6008987330994255`}, {
             0.16676728457662499`, -4.600914181333558}, {
             0.32631514557499847`, -4.601302643061885}, {
             0.485838110865284, -4.601942311080746}, {
             0.5054099304041242, -4.60203620927231}, {
             0.524981050333136, -4.602133904479879}, {
             0.5732008358550315, -4.602407074560304}, {
             0.6214162996459799, -4.6027033425442925`}, {
             0.8499513279747936, -4.604363993966522}, {
             1.0782302973841908`, -4.6065358314027485`}, {
             1.093265613699836, -4.606712743916363}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1168759723310318`, -4.606990554359794}, {
             1.3062532078741724`, -4.609218854852974}, {
             1.534020059444738, -4.612413064317196}, {
             1.7614199776627393`, -4.616109881683996}, {
             1.9883420880950278`, -4.620300728841951}, {
             2.0612358448342833`, -4.621808818366352}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.084842786140536, -4.622297219327966}, {
             2.214786390741603, -4.6249856057910606`}, {
             2.4407528856024663`, -4.6301645125313255`}, {
             2.666374017213905, -4.635855230229714}, {
             2.8908992665369504`, -4.641956998940075}, {
             3.0290210687313848`, -4.6460163575658}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.052622870847007, -4.646710007499977}, {
             3.1148407524452515`, -4.648538572508017}, {
             3.338145497124293, -4.655592838466753}, {
             3.5284387010666975`, -4.661990539463264}, {
             3.7181868168162917`, -4.668723156439504}, {
             3.9073540210380266`, -4.675786018635526}, {
             3.996537159747214, -4.679280700846415}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.020131045485493, -4.680205238084829}, {
             4.095904490396855, -4.683174455291381}, {
             4.283797938260081, -4.690877435132629}, {
             4.470991527539212, -4.698880292305119}, {
             4.657445609215502, -4.707172904179336}, {
             4.843120534270206, -4.715745148125767}, {
             4.96370346106926, -4.721520698863874}}]}, 
           {Arrowheads[{{0.014197571861369374`, 1.}}], 
            ArrowBox[{{4.987288416266761, -4.722650345564407}, {
             5.028032799565335, -4.724601876011382}, {
             5.212230985323338, -4.733756496558287}, {
             5.395723567566119, -4.743211722419666}, {
             5.5785190223155805`, -4.752970266248708}, {
             5.656854249492381, -4.757349233054968}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.8596062989157227`}, {-5.635581901871712, 
             1.8591625340771032`}, {-5.434323248502308, 
             1.8551226263164518`}, {-5.229591760196643, 
             1.8511688430208033`}, {-5.021387436954715, 
             1.8473011841901577`}, {-4.993374754354958, 
             1.8467908629908822`}, {-4.965349645765006, 
             1.846283321861361}, {-4.776142718577518, 
             1.8430124252191729`}, {-4.712540050997036, 
             1.8419578713610578`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688931302889119, 
             1.841566430288701}, {-4.586363897211615, 
             1.8398658278220326`}, {-4.393374265983725, 
             1.836736864288409}, {-4.199896872364964, 
             1.833741553854354}, {-4.005931716355329, 
             1.830879896519868}, {-3.811478797954822, 
             1.8281518922849505`}, {-3.744560397395175, 
             1.8272613145575984`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.72095049512513, 
             1.826947104221864}, {-3.6165381171634423`, 
             1.8255575411496017`}, {-3.421109673981189, 
             1.8230968431138217`}, {-3.225193468408063, 
             1.8207697981776103`}, {-3.0287895004440646`, 
             1.8185764063409677`}, {-2.831897770089193, 
             1.8165166676038937`}, {-2.7765349884437094`, 
             1.8159764217197023`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7529241195815, 
             1.815746020097062}, {-2.6345182773434486`, 
             1.8145905819663886`}, {-2.4366510222068323`, 
             1.812798149428452}, {-2.2382960046793423`, 
             1.8111393699900842`}, {-2.0394532247609796`, 
             1.809614243651285}, {-1.8401226824517443`, 
             1.8082227704120546`}, {-1.808476423775457, 1.808023562929198}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7848648985732591`, 
             1.8078749326424381`}, {-1.6403043777516362`, 
             1.8069649502723928`}, {-1.439998310660655, 
             1.8058407832322998`}, {-1.2380726375255184`, 
             1.8048512587866337`}, {-1.0360398271865376`, 
             1.8040113077884652`}, {-0.8403965088622225, 
             1.8033431184644262`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8167846149426435, 
             1.8032751644093825`}, {-0.6316527948970467, 
             1.8027801261346204`}, {-0.4292985729465364, 
             1.8023888954789442`}, {-0.2268372137921817, 
             1.8021472382707657`}, {-0.024268717433983455`, 
             1.8020551545100845`}, {0.12769389365168374`, 
             1.8020982592620745`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1513058856997499, 1.802104956890221}, {
             0.17840691612805737`, 1.8021126441969009`}, {0.3339253845887402, 
             1.802258111442914}, {0.48936306204628466`, 
             1.8024915156064862`}, {0.6447199485006911, 
             1.8028128566876176`}, {0.7999960439519604, 1.803222134686308}, {
             0.955191348400092, 1.8037193496025572`}, {1.0957826926830272`, 
             1.8042497144349487`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1193944966862786`, 1.8043439603217006`}, {
             1.2653395842869395`, 1.804977590187733}, {1.4202925157256563`, 
             1.8057386158566593`}, {1.5750985742988086`, 
             1.8065856803308278`}, {1.729691678143968, 1.8075168854979216`}, {
             1.8840718272611352`, 1.8085322313579406`}, {2.038239021650311, 
             1.8096317179108852`}, {2.0638578336806934`, 
             1.8098286798392653`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.087469128880216, 1.8100102076255085`}, {
             2.1921932613114943`, 1.810815345156755}, {2.345934546244685, 
             1.8120831130955501`}, {2.4994628764498827`, 
             1.8134350217272706`}, {2.6527782519270886`, 
             1.8148710710519163`}, {2.8066205591153093`, 
             1.8164274940193015`}, {2.959048465884611, 1.818009221729757}, {
             3.031907412316799, 1.8188060967276332`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0555179931729417`, 1.8190643310624806`}, {
             3.1112355852072113`, 1.8196737271381607`}, {3.2631680007237565`, 
             1.8214203287470234`}, {3.414831796074892, 1.823248345058857}, {
             3.5662130549012634`, 1.8251570945761726`}, {3.717297860843516, 
             1.8271458958014815`}, {3.8680722975422976`, 1.829214067237295}, {
             3.9999206040390476`, 1.8310949452494296`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.023530155412802, 1.831434459553645}, {
             4.168613774393105, 1.8335826750054498`}, {4.318342025656374, 
             1.8358800909782653`}, {4.467684907821018, 1.8382512264106636`}, {
             4.616649674164675, 1.8406967192160864`}, {4.765257884548145, 
             1.8432182955154741`}, {4.913513215603276, 1.845816321170394}, {
             4.967884409243835, 1.846799608966675}}]}, 
           {Arrowheads[{{0.014092097845678402`, 1.}}], 
            ArrowBox[{{4.991492541953863, 1.8472265554291751`}, {
             5.061419343961913, 1.8484911620424127`}, {5.2089161116549425`, 
             1.8512382542267665`}, {5.355906883798411, 1.8540502168093596`}, {
             5.502340621651913, 1.8569231901377612`}, {5.6481662864750435`, 
             1.8598533145595404`}, {5.656399214071849, 1.8600209023507253`}, {
             5.656854249492381, 1.8600301794259282`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.763197973190364}, {-5.599587891452205, 
             4.759974958247492}, {-5.451719622065682, 
             4.751897112760139}, {-5.431793483662753, 
             4.750838931495854}, {-5.411858987659376, 
             4.749784361753324}, {-5.208241694913875, 
             4.739471283345655}, {-5.0037667165994, 
             4.729527050897892}, {-4.817652296192434, 
             4.7206545245980225`}, {-4.713564548176867, 4.715891455995363}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6899772380511955`, 
             4.714812097680646}, {-4.630964444420238, 
             4.71211166473001}, {-4.443703161282812, 
             4.703898471293856}, {-4.2558684467801555`, 
             4.69601494428956}, {-4.067460300912268, 
             4.688461083717123}, {-3.8784787236791507`, 
             4.681236889576545}, {-3.7462814763446293`, 4.676428588326665}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7226850864332204`, 
             4.675570336332835}, {-3.6889237150808034`, 
             4.674342361867825}, {-3.4987952751172244`, 
             4.6677775005909625`}, {-3.308093403788416, 
             4.661542305745959}, {-3.1168181010943767`, 
             4.655636777332814}, {-2.9249693670351076`, 
             4.650060915351527}, {-2.77866941925624, 4.646072195376227}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7550661970615447`, 
             4.645428677416866}, {-2.732547201610608, 
             4.644814719802099}, {-2.5395516048208773`, 
             4.639898190684528}, {-2.345982576665917, 
             4.635311327998817}, {-2.151840117145726, 
             4.631054131744964}, {-1.9571242262603046`, 
             4.627126601922969}, {-1.8108224132986595`, 4.624457818250332}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7872143478496618`, 
             4.624027168634053}, {-1.7458807057362342`, 
             4.6232731755907}, {-1.534403007544928, 
             4.619860528278965}, {-1.3226911316863867`, 
             4.6168886599877625`}, {-1.110745078160611, 
             4.614357570717092}, {-0.8985648469675993, 
             4.612267260466956}, {-0.8428169851716806, 
             4.611834343323955}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8192057041018291, 
             4.611650986904282}, {-0.6861504381073523, 
             4.610617729237352}, {-0.4735018515798708, 
             4.609408977028281}, {-0.2606190873851535, 
             4.608641003839742}, {-0.10594128158854466`, 4.608361295136896}, {
             0.04869863142058273, 4.608317563160105}, {0.12526486501417416`, 
             4.608412771853745}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14887683975718768`, 4.608442132907097}, {
             0.2033006516422291, 4.60850980790937}, {0.35786477907639413`, 
             4.608938029384691}, {0.512391013723078, 4.609602227586069}, {
             0.6668793555822807, 4.610502402513502}, {0.8213298046540023, 
             4.611638554166991}, {0.9757423609382426, 4.613010682546536}, {
             1.0933352403925833`, 4.614233616507799}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1169459566243287`, 4.614479161534535}, {
             1.1300464735076394`, 4.614615403346804}, {1.284171591434831, 
             4.6164493322624605`}, {1.4381177147198176`, 4.618512469293506}, {
             1.5918848433625987`, 4.620804814439941}, {1.7454729773631745`, 
             4.623326367701765}, {1.8988821167215448`, 4.626077129078977}, {
             2.05211226143771, 4.62905709857158}, {2.0613067950000796`, 
             4.629249889616992}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0849135991161614`, 4.629744877254321}, {
             2.20516341151167, 4.63226627617957}, {2.358833557008129, 
             4.635793366519191}, {2.511028912083333, 4.639405624249396}, {
             2.663015254081295, 4.6432437532442234`}, {2.8147775737844976`, 
             4.647306085078289}, {2.966300861975423, 4.651590951326207}, {
             3.029092318044659, 4.653461268608334}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0526938435359083`, 4.654164267770548}, {
             3.1175701094365538`, 4.656096683562596}, {3.2685703069503713`, 
             4.66082161336207}, {3.4192864452993574`, 4.665764072299247}, {
             3.566993081560928, 4.670827243074352}, {3.7143829400632975`, 
             4.676095975133295}, {3.8614370855143934`, 4.681568349196379}, {
             3.996606115880778, 4.6867964663753465`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.020199791800465, 4.687726191547805}, {
             4.15444934825529, 4.693109719797247}, {4.300335786231623, 
             4.699157838412674}, {4.44576569168263, 4.705379202762834}, {
             4.590708859739794, 4.711766213780375}, {4.7351778416807075`, 
             4.718321746415115}, {4.879209620866448, 4.725054660769541}, {
             4.963768800254047, 4.729124586910198}}]}, 
           {Arrowheads[{{0.014196193234552842`, 1.}}], 
            ArrowBox[{{4.987353490877435, 4.730259743963313}, {
             5.022810640553733, 4.731966335505306}, {5.165987343999283, 
             4.73905814928406}, {5.3084999267889454`, 4.746318102255318}, {
             5.4499678715537945`, 4.753726549704518}, {5.590186552118374, 
             4.761273402997196}, {5.656854249492381, 4.764960836557281}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.856441289406867}, \
{-5.606948558678145, -3.854288219289714}, {-5.410279369177292, \
-3.8460107873928053`}, {-5.240372008732655, -3.8390728498440367`}, \
{-5.069613145730752, -3.8323094528469217`}, {-4.898002780171583, \
-3.8257205964014602`}, {-4.725540912055148, -3.8193062805076528`}, \
{-4.713124541290018, -3.8188518873908084`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689528269020013, -3.817990409141079}, \
{-4.679253148409687, -3.8176160200386606`}, {-4.49889904794002, \
-3.8113043060487586`}, {-4.318058505767593, -3.8052435389369035`}, \
{-4.116793452116884, -3.7986577828574393`}, {-3.914869885971983, \
-3.7923690107634247`}, {-3.745546982041453, -3.787360932215242}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721945310207267, -3.7866628634739774`}, \
{-3.7122878073328915`, -3.7863772226548593`}, {-3.509047216199609, \
-3.7806824185317436`}, {-3.305188272440836, -3.7752903522966386`}, \
{-3.100751135925274, -3.770206777852104}, {-2.895735806652922, \
-3.765431695198141}, {-2.7777675127524972`, -3.7628687929310605`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7541610901039584`, -3.762355935178157}, \
{-2.690142284623781, -3.760965104334749}, {-2.4840376752609403`, \
-3.7568140446518177`}, {-2.2774890839874913`, -3.7529855555392357`}, \
{-2.0704965108034337`, -3.749479636997003}, {-1.8630599557087668`, \
-3.7462962890251204`}, {-1.8098327996239711`, -3.7455715746685496`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7862229949391861`, -3.745250115367143}, \
{-1.6256693980414378`, -3.7430640978296763`}, {-1.3880378703246383`, \
-3.740273524953117}, {-1.1501653725583698`, -3.737924570395442}, \
{-0.9120519047426306, -3.7360172341566513`}, {-0.8417951056499305, \
-3.7355852025555296`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8181835590729897, -3.735440007579323}, \
{-0.6736974668774218, -3.734551516236745}, {-0.43510205896274384`, \
-3.7335274166357233`}, {-0.19626568099859612`, -3.732944935353586}, {
             0.04281166701502215, -3.732804072390333}, {
             0.1262904454923584, -3.732879388832417}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1499024288801859, -3.732900692097891}, {
             0.18848075437158895`, -3.7329354983357224`}, {
             0.3340877756610414, -3.733232382560405}, {
             0.47963273088337954`, -3.7336947250643813`}, {
             0.6251156200386031, -3.734322525847651}, {
             0.7705364431267123, -3.735115784910214}, {
             0.9158952001477072, -3.736074502252071}, {
             1.061191891101587, -3.7371986778732214`}, {
             1.0943687595586276`, -3.7374932771418607`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1179798217284325`, -3.7377029353154776`}, {
             1.206426515988353, -3.738488311773665}, {
             1.3515456967909407`, -3.739940718764506}, {
             1.4964960554922846`, -3.7415532136568475`}, {
             1.6412775920923859`, -3.74332579645069}, {
             1.785890306591246, -3.745258467146033}, {
             1.930334198988863, -3.7473512257428774`}, {
             2.0623847962081157`, -3.7494131878333383`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0859937031801974`, -3.74979469473339}, {
             2.2187155174803666`, -3.7520170066410676`}, {
             2.3626529435742554`, -3.754590028942414}, {
             2.50709432851935, -3.757387290208162}, {
             2.650274413202171, -3.760240469310889}, {
             2.793260367409363, -3.7632513231089884`}, {
             2.9360395369537335`, -3.7664186449993973`}, {
             3.0302838986539102`, -3.7686151611423915`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0538894812713995`, -3.7691653271401098`}, {
             3.0785992676480873`, -3.769741228379051}, {
             3.2209269053052303`, -3.7732178666448855`}, {
             3.3630097957379705`, -3.7768473531938374`}, {3.5048352847591153`,
              -3.780628481422842}, {
             3.6463809307287836`, -3.784558275589285}, {
             3.7876186991769836`, -3.788632749013663}, {
             3.928527546671363, -3.792849178687583}, {
             3.9980135660520473`, -3.7950024234419475`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.021614230301445, -3.7957337648966383`}, {
             4.069086429779568, -3.7972048416026505`}, {
             4.209299544547513, -3.8017006296772378`}, {
             4.349185509580128, -3.8063395005021543`}, {
             4.488744915283571, -3.8111218295776625`}, {
             4.627978352064007, -3.816047992404024}, {
             4.766843911821716, -3.8211098561639805`}, {
             4.905275401596475, -3.826294426144546}, {
             4.965519453318756, -3.8286089479588803`}}]}, 
           {Arrowheads[{{0.014151594784280136`, 1.}}], 
            ArrowBox[{{4.989114039617959, -3.8295154305597094`}, {
             5.04323698450369, -3.831594785002394}, {
             5.180692823658767, -3.837004015394197}, {
             5.316631154324682, -3.8424751126221524`}, {
             5.449482538705883, -3.84793816492876}, {
             5.578374630329978, -3.8533518943811425`}, {
             5.656854249492381, -3.8567192616794252`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.8620552241128758`}, \
{-5.53291635671387, -1.859546502130368}, {-5.375850952412119, \
-1.8564516062791103`}, {-5.21802458896918, -1.8534301272472622`}, \
{-5.059732219554577, -1.8504924698755}, {-4.900973844168309, \
-1.8476386341638245`}, {-4.741749462810379, -1.8448686201122348`}, \
{-4.7125404557452955`, -1.8443772880173377`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688931802598991, -1.8439801608920565`}, \
{-4.582059075480784, -1.8421824277207317`}, {-4.421902682179525, \
-1.8395800569893146`}, {-4.2612802829066005`, -1.837061507917984}, \
{-4.100191877662013, -1.8346267805067393`}, {-3.9386729541316488`, \
-1.832278763657458}, {-3.7767590000013938`, -1.8300203462720164`}, \
{-3.7445621755057177`, -1.829590123323478}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7209522901920526`, -1.829274641451169}, \
{-3.614450015271249, -1.827851528350415}, {-3.451745999941214, \
-1.8257723098926535`}, {-3.2886469540112895`, -1.823782690898732}, \
{-3.125152877481474, -1.8218826713686505`}, {-2.961263770351769, \
-1.8200722513024088`}, {-2.7969796326221745`, -1.8183514307000073`}, \
{-2.77653855483, -1.8181486647377694`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7529277234227285`, -1.8179144562973824`}, \
{-2.6461382673637557`, -1.8168551546776333`}, {-2.4950352272115017`, \
-1.8154377207187402`}, {-2.343670512165412, -1.8140991288233286`}, \
{-2.194137521376171, -1.8122086424835486`}, {-2.0423802939893276`, \
-1.8109883136833587`}, {-1.8906230666024837`, -1.8097679848831685`}, \
{-1.8084902422723577`, -1.8091075283586466`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7848790126469463`, -1.808917662847686}, \
{-1.73886583921564, -1.8085476560829785`}, {-1.5871086118287967`, \
-1.8073273272827886`}, {-1.5102379996163169`, -1.8068806759432923`}, \
{-1.4333119992772247`, -1.806454040863304}, {-1.2570099895527502`, \
-1.8055286626249938`}, {-1.0788652627777797`, -1.8047110331052993`}, \
{-0.9007205360028092, -1.803893403585605}, {-0.8404149838709319, \
-1.8036166196441594`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8168032395656247, -1.803508248997972}, \
{-0.7225758092278388, -1.8030757740659105`}, {-0.5444310824528683, \
-1.802258144546216}, {-0.5192335294287737, -1.8022079674744411`}, \
{-0.4940349236051495, -1.802160144322307}, {-0.44678479262359444`, \
-1.802083052891593}, {-0.39952926655300147`, -1.802014061101952}, \
{-0.16384685550366396`, -1.8017714687317372`}, {
             0.07181787535756573, -1.8017318973219392`}, {
             0.1276732613666407, -1.8017706397450535`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15128524868464158`, -1.8017870174960386`}, {
             0.3074649260306872, -1.8018953468725576`}, {
             0.5430942965157004, -1.8022618173835923`}, {
             0.778601324041909, -1.8028308802986917`}, {
             1.0138813458386153`, -1.8036021070615038`}, {
             1.0957619924384971`, -1.8039411873843927`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1193737829762425`, -1.8040389674324502`}, {
             1.2489343619058197`, -1.804575497672029}, {
             1.4837603722435224`, -1.8057510521302669`}, {
             1.7185161676278797`, -1.807134102149503}, {
             1.952313266994003, -1.8086944346877867`}, {
             2.0638370057058384`, -1.8095343960537902`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0874483290225334`, -1.809712229039084}, {
             2.185757928009699, -1.8104526657031548`}, {
             2.4187874343645044`, -1.812406662510293}, {
             2.546645353352152, -1.813562631862269}, {
             2.674347676259539, -1.8147758639711495`}, {
             2.8018838977164204`, -1.8160459095509975`}, {
             2.929243512352552, -1.8173723193158757`}, {
             3.031886786002737, -1.8184880190625143`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.055497384245961, -1.8187446587578513`}, {
             3.0564160147976898`, -1.8187546439798474`}, {
             3.183390899681589, -1.8201924342569755`}, {
             3.3101576616340047`, -1.8216852408613233`}, {
             3.4367057952846918`, -1.823232614506954}, {
             3.5630247952634067`, -1.82483410590793}, {
             3.689104156199905, -1.826489265778315}, {
             3.814933372723942, -1.828197644832172}, {
             3.940501939465272, -1.8299587937835635`}, {
             3.9998994775637065`, -1.8308184733738484`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.023508997865435, -1.8311601815218557`}, {
             4.065799351053651, -1.8317722633465534`}, {
             4.190815102118836, -1.833637604235204}, {
             4.315538687290581, -1.835554367163579}, {
             4.439959601198641, -1.8375221028457411`}, {
             4.564093151546197, -1.8395413053400795`}, {
             4.687969396364098, -1.8416130077588841`}, {
             4.811599955773606, -1.8437375693970686`}, {
             4.934996449895983, -1.8459153495495473`}, {
             4.967863359257754, -1.8465174064008874`}}]}, 
           {Arrowheads[{{0.014092543901262852`, 1.}}], 
            ArrowBox[{{4.991471391750021, -1.8469498589187732`}, {
             5.180946623276187, -1.8504206708543867`}, {
             5.425538678498399, -1.8551091825874029`}, {
             5.656854249492381, -1.8597485210841365`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.864397020012038}, {-5.6046725864068225`, 
             3.8621473011102343`}, {-5.476395919675825, 
             3.8567133806241056`}, {-5.345230396013963, 
             3.85127934623416}, {-5.21166114644106, 
             3.84586814276632}, {-5.0761733019769375`, 
             3.8405027150465085`}, {-4.939621266075517, 
             3.8352187096883377`}, {-4.8025640242434395`, 
             3.8300416118752683`}, {-4.713126840942381, 
             3.8267491949935364`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689530830820425, 
             3.825880564081877}, {-4.665043580579615, 
             3.8249791242879976`}, {-4.527101939182954, 
             3.820038949607224}, {-4.3888232477342175`, 
             3.8152366161970472`}, {-4.250257939048685, 
             3.8105813918748463`}, {-4.111397444927047, 
             3.8060715885012355`}, {-3.972233197169989, 
             3.801705517936827}, {-3.8327292145950604`, 
             3.79747742776831}, {-3.745560731113485, 3.794926645794293}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721958841143159, 
             3.7942359916371426`}, {-3.6928714464063224`, 
             3.7933848170015128`}, {-3.5526842199842283`, 
             3.7894308746257592`}, {-3.4121918627092334`, 
             3.785618789630374}, {-3.271428047744799, 
             3.7819533926556694`}, {-3.130418971627978, 
             3.778438201021168}, {-2.989177746799619, 
             3.775074433735007}, {-2.847717485700568, 
             3.7718633098053234`}, {-2.7777833261975595`, 
             3.7703540786642344`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7541768296685665`, 
             3.769844632923458}, {-2.706051300771671, 
             3.768806048240254}, {-2.5641923044537758`, 
             3.7659038680479364`}, {-2.4221536091877276`, 
             3.7631579882365074`}, {-2.2788293991288042`, 
             3.7604656057864028`}, {-2.136048859775095, 
             3.757996772332752}, {-1.9931148463549264`, 
             3.7556866772762634`}, {-1.8500273588682983`, 
             3.753535320616938}, {-1.8098498930641682`, 3.752976413784558}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.786240184367468, 
             3.752647980240108}, {-1.7067863973152109`, 
             3.7515427023547763`}, {-1.563391961695664, 
             3.749708822489777}, {-1.4198440520096576`, 
             3.748033681021941}, {-1.2761426682571917`, 
             3.7465172779512677`}, {-1.1322878104382665`, 
             3.745159613277757}, {-0.9883276518407373, 
             3.743962682501514}, {-0.84431036575246, 
             3.742928481122643}, {-0.8418127937870008, 
             3.742913373901759}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8182012327294743, 
             3.742770553164961}, {-0.7002359521734343, 
             3.742057009141144}, {-0.5561044111036602, 
             3.7413482665570164`}, {-0.4119157425431378, 
             3.7408022533702603`}, {-0.26766994649186704`, 
             3.740418969580876}, {-0.12336702294984803`, 3.740198415188864}, {
             0.02099302808291903, 3.7401405901942235`}, {0.12627280083472497`,
              3.7402554223572606`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14988477978712103`, 3.7402811767310196`}, {
             0.260707370600484, 3.74040205463077}, {0.5001634771499257, 
             3.741108244488066}, {0.7393613477312452, 3.742259159766111}, {
             0.9783009823444428, 3.7438548004649053`}, {1.094351055631812, 
             3.744846853633063}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.117962185933538, 3.745048693200726}, {
             1.216982380989518, 3.745895166584449}, {1.4554055436664708`, 
             3.7483802581247416`}, {1.6935704703753012`, 
             3.7513100750857835`}, {1.9314771611160078`, 
             3.7546846174675745`}, {2.062366821110235, 
             3.756767040538136}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0859758263361075`, 3.757142654143959}, {
             2.136055054256323, 3.757939402638695}, {2.34018731478759, 
             3.7615076421252924`}, {2.5438739427098094`, 
             3.7653893359273667`}, {2.747114938022981, 3.769584484044918}, {
             2.949845351703174, 3.7740859917474974`}, {3.030265104521572, 
             3.775995799398988}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.053870442140544, 3.7765563787693637`}, {
             3.152000234726458, 3.778886764304656}, {3.3535795870928333`, 
             3.7839868017163942`}, {3.554583408802299, 3.7893861039827126`}, {
             3.7549784727162487`, 3.7950798773778094`}, {3.954731551696075, 
             3.801063328175885}, {3.9979935526386248`, 
             3.8024263264530402`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.021593835636647, 3.8031698691548534`}, {
             4.153842645741777, 3.8073364563769396`}, {4.352311754853356, 
             3.813899261980972}, {4.534083752143327, 3.8201882609399553`}, {
             4.71521048832065, 3.826705899546227}, {4.931849467775661, 
             3.834802873632194}, {4.965496771696726, 
             3.8361114890062322`}}]}, 
           {Arrowheads[{{0.014152256404041772`, 1.}}], 
            ArrowBox[{{4.989090927202292, 3.8370291160085164`}, {
             5.147340001626864, 3.8431837598458083`}, {5.273980926776081, 
             3.848263074608426}, {5.400077890973749, 3.853435074518663}, {
             5.422809479313694, 3.8543778222119696`}, {5.445466537095915, 
             3.8553210664051205`}, {5.600762030572584, 3.861971034458775}, {
             5.656854249492381, 3.864425451949297}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.184628285054146}, \
{-5.443981030343043, -2.179603597837657}, {-5.205866857878852, \
-2.1742274005460387`}, {-4.96666737531425, -2.169069866130829}, \
{-4.726382582649236, -2.1641309945920284`}, {-4.7126034903539225`, \
-2.163861531711661}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688996011077693, -2.1633998656434152`}, \
{-4.484970726554517, -2.1594099627051775`}, {-4.242390053700801, \
-2.1549059472458167`}, {-3.998640564088088, -2.150618948213946}, \
{-3.753722257716378, -2.146548965609566}, {-3.7446697551260377`, \
-2.146405672564271}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721060719690739, -2.146031962581838}, \
{-3.612688301498202, -2.1443165238206943`}, {-3.4714016305551203`, \
-2.1421683914417615`}, {-3.260255771596648, -2.139120870157792}, \
{-3.04852747315003, -2.136255869498456}, {-2.8362167352152667`, \
-2.133573389463753}, {-2.776673330392331, -2.132874183895042}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.753062965191068, -2.132596932386212}, \
{-2.623323557792358, -2.131073430053683}, {-2.595486743269647, \
-2.130758911210296}, {-2.5676384227183133`, -2.130447363666523}, \
{-2.4546991431867933`, -2.1292523807317134`}, {-2.341666352296625, \
-2.1281139665390763`}, {-2.108983662482056, -2.1258879360699123`}, \
{-1.8758719528707704`, -2.1238924694701242`}, {-1.808628872271521, \
-2.1233843033063384`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7850175534915373`, -2.1232058689874553`}, \
{-1.6423312234627667`, -2.122127566739712}, {-1.4083614742580453`, \
-2.120593227878676}, {-1.1740629766761188`, -2.119292073522832}, \
{-0.9395360021365007, -2.118226724307996}, {-0.8405535894463265, \
-2.1178769549061074`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8169417438648722, -2.1177935188604295`}, \
{-0.7047805506391904, -2.1173971802341685`}, {-0.469796622184188, \
-2.1168034413013492`}, {-0.2344414672220132, -2.116444053658608}, {
             0.0004760001336110431, -2.116327255794549}, {
             0.12753620565357637`, -2.1163922209351824`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15114819556520265`, -2.1164042936076526`}, {
             0.23550774480734285`, -2.116447426152243}, {
             0.47059666697938995`, -2.1168051462720605`}, {
             0.5958063707106096, -2.1170923201722833`}, {
             0.7209929713769889, -2.1174460319160286`}, {
             0.8461462306521947, -2.117866246732421}, {
             0.9712559102098959, -2.1183529298505843`}, {
             1.0956239347394487`, -2.118903004226508}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1192356394330498`, -2.1190196674627555`}, {
             1.2213035768674532`, -2.119525561908722}, {
             1.3462210873146447`, -2.1202114413069455`}, {
             1.4710540647390031`, -2.120963649923437}, {
             1.5957922708141958`, -2.121782152987321}, {
             1.7204254672138888`, -2.1226669157277227`}, {
             1.8449434156117512`, -2.1236179033737654`}, {
             1.9693358776814516`, -2.1246350811545742`}, {
             2.0636927543459724`, -2.1254577321757364`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0873038499935417`, -2.125663585661268}, {
             2.0935926150966573`, -2.1257184142992727`}, {
             2.2177033895310343`, -2.1268678680369857`}, {
             2.3416579626582523`, -2.1280834075968373`}, {
             2.4654460961519797`, -2.129364998207952}, {
             2.589066173327423, -2.1307108263347305`}, {
             2.7125179569624356`, -2.1321187938392163`}, {
             2.8357932779246546`, -2.1335884390470006`}, {
             2.9588839670817197`, -2.1351193002836735`}, {
             3.0317254285587896`, -2.136081303601105}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0553353626262916`, -2.1363931155065323`}, {
             3.204478773450931, -2.1383628241460486`}, {
             3.4492370230111695`, -2.141845672031066}, {
             3.6930933627035336`, -2.1455641505434504`}, {
             3.9359824394691207`, -2.149514566287926}, {
             3.9997073145834467`, -2.1506155687548616`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023315784164536, -2.151023462582864}, {
             4.177838900249031, -2.1536932258692167`}, {
             4.418597391984363, -2.1580964358920482`}, {
             4.65823158504253, -2.1627190677575188`}, {
             4.896754173217255, -2.1675545576631023`}, {
             4.967622581052831, -2.1690609715828497`}}]}, 
           {Arrowheads[{{0.014098653137929245`, 1.}}], 
            ArrowBox[{{4.99122924145341, -2.169562766429274}, {
             5.134174873294087, -2.1726012894629996`}, {
             5.370519936763545, -2.1778618770663267`}, {
             5.605803613161231, -2.1833370750526173`}, {
             5.656854249492381, -2.184577379176868}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5854034726616073, -0.8737530760562366}, {
             0.7225754598811849, -0.8739119512219075}, {
             0.8620912272666966, -0.8741066449224368}, {
             1.0015357334391155`, -0.8743353689372376}, {
             1.140897808066582, -0.8745985481058136}, {
             1.2801583737095386`, -0.8748957074428538}, {
             1.4193174303679865`, -0.8752268469483583}, {
             1.5298814364920956`, -0.8755171518943607}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.553493348098061, -0.875579149057489}, {
             1.5583749780419252`, -0.8755919666223271}, {
             1.6973038655065906`, -0.8759904476350452}, {
             1.8360769415372182`, -0.876421671156798}, {
             1.9746942061338082`, -0.8768856371875855}, {
             2.1131556592963605`, -0.8773823457274076}, {
             2.218380108984825, -0.8777824533697947}, {
             2.323520640653644, -0.8782023087290396}, {
             2.4979669441289793`, -0.8789492756081634}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.52157872066786, -0.8790503795850344}, {
             2.5519880850745262`, -0.8791805903580601}, {
             2.7798064997409746`, -0.8802442021662374}, {
             3.0069758846529893`, -0.8813931441535715}, {
             3.2334962398105707`, -0.8826274163200623}, {
             3.263249631430649, -0.8827953823366212}, {
             3.2929907215095082`, -0.882964787712366}, {
             3.4284876473777555`, -0.8837748444419677}, {
             3.4660453086647407`, -0.8840080894446543}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.489656846341689, -0.8841547245912575}, {
             3.5637215532883375`, -0.8846146899399715}, {
             3.7108090325758756`, -0.8855456890033415}, {
             3.8574911504298597`, -0.886509248864892}, {
             4.00376790685029, -0.8875053695246228}, {
             4.1496393018371664`, -0.888534050982534}, {
             4.295105335390489, -0.8895952932386255}, {
             4.434114185306658, -0.8906434636516483}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.457725473956369, -0.8908258237187999}, {
             4.584821318196474, -0.8918154601453498}, {
             4.729071267449136, -0.8929743847959825}, {
             4.872915855268245, -0.8941658702447955}, {
             5.016355081653799, -0.895389916491789}, {
             5.1593889466058, -0.8966465235369628}, {
             5.302017450124247, -0.897935691380317}, {
             5.402170857763831, -0.89886645149069}}]}, 
           {Arrowheads[{{0.004893341408082612, 1.}}], 
            ArrowBox[{{5.425781831188195, -0.8990858763984231}, {
             5.444240592209141, -0.8992574200218516}, {
             5.586058372860481, -0.9006117094615665}, {
             5.656854249492381, -0.9013060139568299}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.5436654853656882`}, \
{-5.5580601648721935`, -1.5420181455753386`}, {-5.430609310014495, \
-1.539940092096916}, {-5.302416861193531, -1.5378969744265374`}, \
{-5.173574692602599, -1.5358905030219352`}, {-5.044248118034135, \
-1.5339233171898854`}, {-4.914543699601263, -1.5319973131579292`}, \
{-4.78446518397831, -1.5301130867649442`}, {-4.712487185727637, \
-1.5290968043714837`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688877545973863, -1.528763451655642}, \
{-4.654016317839603, -1.5282712338498081`}, {-4.5231759583778635`, \
-1.5264713011539903`}, {-4.3919428743710975`, -1.5247136746968866`}, \
{-4.260350679871558, -1.5230002092342656`}, {-4.1284329889314995`, \
-1.5213327595218962`}, {-3.9729175230182983`, -1.519434506169013}, \
{-3.8170834174437673`, -1.5176072987534748`}, {-3.744474030059436, \
-1.5167908589566215`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7208635295955492`, -1.5165253760363442`}, \
{-3.6609417996950078`, -1.515851599727943}, {-3.5045037972591206`, \
-1.5141678715450797`}, {-3.3477805376232035`, -1.5125565766575462`}, \
{-3.190783148274357, -1.5110181775180045`}, {-3.033522756699682, \
-1.5095531365791164`}, {-2.8750609448204316`, -1.5081224536664084`}, \
{-2.776429259522943, -1.5072916513914796`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75281810413523, -1.5070927680250377`}, \
{-2.7169499970870206`, -1.5067906409261933`}, {-2.558598302101981, \
-1.505533111291955}, {-2.40000585986531, -1.504349864763694}, \
{-2.2411726703770096`, -1.5032409013414096`}, {-2.0820987336370784`, \
-1.5022062210251024`}, {-1.922784049645517, -1.5012458238147721`}, \
{-1.8083609593939882`, -1.5006103586767598`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.784749330519527, -1.5004792280896693`}, \
{-1.763228618402326, -1.5003597097104189`}, {-1.6034324399075048`, \
-1.4995478787120426`}, {-1.4434626553930776`, -1.498811857719631}, \
{-1.2833864060910685`, -1.498153173633172}, {-1.1232036920014763`, \
-1.4975718264526652`}, {-0.9629145131243029, -1.4970678161781108`}, \
{-0.8402773343056136, -1.4967415852593224`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8166654248499159, -1.496678774495162}, \
{-0.8025188694595475, -1.4966411428095088`}, {-0.6420167610072093, \
-1.496291806346859}, {-0.4814081877672898, -1.496019806790162}, \
{-0.32069314973978813`, -1.4958251441394173`}, {-0.10144528945533363`, \
-1.4956846027952764`}, {0.11768659793211295`, -1.495688565721492}, {
             0.12781346922676595`, -1.4956954305568382`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15142545679958025`, -1.4957114367251962`}, {
             0.33670251242255245`, -1.4958370329180644`}, {
             0.5556024540159858, -1.4961300043849932`}, {
             0.7743864227124121, -1.4965674801222786`}, {
             0.9930544185118305, -1.4971494601299207`}, {
             1.0959031580376224`, -1.4974913375066898`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1195150205862687`, -1.4975698252126741`}, {
             1.2116064414142418`, -1.4978759444079193`}, {
             1.430042491419647, -1.4987469329562744`}, {
             1.6513228926226093`, -1.499775684711487}, {
             1.8722154703505414`, -1.5009487113412394`}, {
             2.0639835673120603`, -1.5020943392595971`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.08759513897702, -1.5022353954421648`}, {
             2.0927202246034424`, -1.5022660128455319`}, {
             2.312837155381313, -1.5037275892243644`}, {
             2.5324725199523868`, -1.5053300262353246`}, {
             2.7515325755848967`, -1.507069909636}, {
             2.970017322278843, -1.5089472394263908`}, {
             3.0320464435119128`, -1.5095207565591071`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0556574273119748`, -1.5097390621462319`}, {
             3.1879267600342263`, -1.510962015606497}, {
             3.4052352567516664`, -1.5131132386670847`}, {
             3.6219171803317822`, -1.5153999090989205`}, {
             3.837972530774575, -1.5178220269020046`}, {
             4.000083780416474, -1.5197466076921735`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023694109608272, -1.5200269089427805`}, {
             4.053401308080044, -1.5203795920763372`}, {
             4.224871210934753, -1.52251756098064}, {
             4.395811797365901, -1.52473524616368}, {
             4.611532420865206, -1.5276494814357373`}, {
             4.826239575371754, -1.5306776536756967`}, {
             4.968087653082109, -1.5327633594372851`}}]}, 
           {Arrowheads[{{0.014086952772555122`, 1.}}], 
            ArrowBox[{{4.99169709401698, -1.5331105079343292`}, {
             5.039933260885547, -1.5338197628835584`}, {
             5.252613477406584, -1.5370758090593222`}, {
             5.280954410210372, -1.5375183428055423`}, {
             5.309276997757687, -1.5379628345005392`}, {
             5.507880252396954, -1.5412058163023543`}, {
             5.656854249492381, -1.5437280487340181`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.5379947423455007`}, {-5.611199881910641, 
             1.5372211800981948`}, {-5.400219759562455, 
             1.5337909095143683`}, {-5.188185490220406, 
             1.5304686824079676`}, {-5.159815458153794, 
             1.530032540833956}, {-5.131427253851321, 
             1.5295983671376774`}, {-4.936689993620868, 
             1.52674118337556}, {-4.741113501016551, 
             1.5239784107370347`}, {-4.712484895200399, 
             1.5235809572011092`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688875177363816, 
             1.5232531813430528`}, {-4.585220942503124, 
             1.5218141401817895`}, {-4.428963442992502, 
             1.5197205440350683`}, {-4.272341002484685, 
             1.5176976222968717`}, {-4.115353620979672, 
             1.5157453749671992`}, {-3.9580012984774635`, 
             1.513863802046051}, {-3.80028403497806, 
             1.5120529035334274`}, {-3.744469699598522, 
             1.5114384798410765`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720859137165477, 
             1.5111785665257975`}, {-3.6422018304814614`, 
             1.5103126794293278`}, {-3.483754684987667, 
             1.5086431297337526`}, {-3.324942598496677, 
             1.5070442544467018`}, {-3.1657655710084924`, 
             1.5055160535681753`}, {-3.0062236025231126`, 
             1.5040585270981732`}, {-2.8463166930405372`, 
             1.5026716750366953`}, {-2.7764233910697618`, 
             1.5020977002440559`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7528121942223565`, 
             1.501903801380612}, {-2.6860448425607664`, 
             1.5013554973837417`}, {-2.525408051083801, 
             1.5001099941393126`}, {-2.3644063186096393`, 
             1.4989351653034078`}, {-2.2030396451382823`, 
             1.497831010876027}, {-1.9792166688884856`, 
             1.4964264144199948`}, {-1.8083547000945175`, 
             1.495470332684044}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7847430767473755`, 
             1.4953382105857345`}, {-1.7551084878497147`, 
             1.4951723861521438`}, {-1.5307151020219698`, 
             1.4940689260724738`}, {-1.3060365114052515`, 
             1.4931160341809848`}, {-1.0810727159995592`, 
             1.4923137104776771`}, {-0.8558237158048929, 
             1.4916619549625505`}, {-0.8402709666088592, 
             1.4916273932835502`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8166590319119387, 
             1.49157492229612}, {-0.6302895108212527, 
             1.491160767635605}, {-0.40447010104863856`, 
             1.4908101484968406`}, {-0.2398985241378906, 
             1.4906504082513943`}, {-0.07535485040062173, 
             1.4905722829328818`}, {0.08916092016316857, 
             1.4905757725413027`}, {0.12781985435696663`, 
             1.4905957743243161`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15143184419454941`, 1.490607990954368}, {
             0.2536487875534811, 1.4906608770766574`}, {0.41810875177031503`, 
             1.4908275965389457`}, {0.5825408128136704, 
             1.4910759309281676`}, {0.7469449706835471, 
             1.4914058802443233`}, {0.9113212253799445, 
             1.4918174444874126`}, {1.075592005702941, 1.4923094381881536`}, {
             1.095909572192704, 1.4923801696157504`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1195214221102652`, 1.4924623694133348`}, {
             1.2396797404526159`, 1.4928806758772637`}, {1.4035844296289683`, 
             1.4935311575547434`}, {1.567306073231998, 1.4942608832205924`}, {
             1.7308446712617052`, 1.4950698528748105`}, {1.8942002237180888`, 
             1.4959580665173982`}, {2.05737273060115, 1.4969255241483552`}, {
             2.0639900768776096`, 1.4969680200680764`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.087601583002277, 1.4971196507409852`}, {
             2.220362191910889, 1.4979722257676815`}, {2.3840646883330168`, 
             1.4991278632005411`}, {2.5461290614539265`, 1.500314530310062}, {
             2.7079766806371612`, 1.50157932447409}, {2.8695906917005445`, 
             1.5029216872256945`}, {3.0309542404618997`, 
             1.5043410600979445`}, {3.032053335540406, 
             1.5043512655096514`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.055664310732153, 1.5045705001576286`}, {
             3.19205047273905, 1.505836884623909}, {3.352862534349818, 
             1.5074086023366569`}, {3.51337357111203, 1.5090556547692573`}, {
             3.672251339470365, 1.5107633171209944`}, {3.8308118229596007`, 
             1.5125448573925415`}, {3.9890425184877283`, 1.514400022456584}, {
             4.000091136418566, 1.5145349764169942`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.023701368213545, 1.5148233649110923`}, {
             4.146930922962734, 1.5163285591858067`}, {4.3044238771140995`, 
             1.5183271610241287`}, {4.461444989569305, 1.5203907765990312`}, {
             4.617946909083332, 1.5225165355585424`}, {4.773882284411166, 
             1.5247015675506905`}, {4.929253732251674, 1.5269453004190356`}, {
             4.968095414102901, 1.527523057725}}]}, 
           {Arrowheads[{{0.014086745965420446`, 1.}}], 
            ArrowBox[{{4.991704795388006, 1.5278742395450617`}, {
             5.084092422414504, 1.5292484752617266`}, {5.23839383332083, 
             1.531610191608676}, {5.392153443391821, 1.534029548989796}, {
             5.543645523824917, 1.5364799197082732`}, {5.656854249492381, 
             1.5383652898643796`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.180640411362521}, {-5.583082336808344, 
             2.1788629939873223`}, {-5.380158844285832, 
             2.1741533276081877`}, {-5.3529774432826525`, 
             2.173534403236142}, {-5.325782042085978, 
             2.1729183386889086`}, {-5.124980850459934, 
             2.1685645053996314`}, {-4.923407987483646, 
             2.1643645369835}, {-4.743736598422442, 
             2.1606929233736865`}, {-4.7125990666839135`, 
             2.1600814809113835`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688991624822821, 
             2.159617905554755}, {-4.563568707344245, 
             2.1571549968651302`}, {-4.382904314249053, 
             2.1537507574578307`}, {-4.201743419136869, 
             2.1504802051517884`}, {-4.020086022007691, 
             2.147343339947003}, {-3.8379321228615186`, 
             2.144340161843475}, {-3.744661020527829, 2.1428748456590374`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7210519408669684`, 
             2.142503940141024}, {-3.655281721698354, 
             2.1414706708412043`}, {-3.472134818518195, 
             2.1387348669401907`}, {-3.288491413321043, 
             2.136132750140434}, {-3.104351506106897, 
             2.1336643204419343`}, {-2.919715096875758, 
             2.131329577844692}, {-2.7766606185115954`, 2.129628795181545}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753050294110159, 
             2.129348090719354}, {-2.734582185627626, 
             2.1291285223487066`}, {-2.5489527723625, 
             2.1270611539539783`}, {-2.36282685708038, 
             2.125127472660507}, {-2.1762044397812668`, 
             2.123327478468293}, {-1.9890855204651603`, 
             2.1216611713773363`}, {-1.8086154074176988`, 
             2.120205288439357}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785004182707261, 
             2.120014812694536}, {-1.7727708892379443`, 
             2.119916124646213}, {-1.5562254240077373`, 
             2.1183721621549183`}, {-1.3394491247745381`, 
             2.117029283903453}, {-1.1224419915383477`, 
             2.1158874898918163`}, {-0.9052040242991658, 
             2.114946780120009}, {-0.840539938900408, 2.114726853361367}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.816928082464087, 
             2.1146465479024785`}, {-0.6877352230569925, 
             2.1142071545880308`}, {-0.47003558781182864`, 
             2.1136686132958817`}, {-0.25210511856367246`, 
             2.1133311562435617`}, {-0.09454106097747972, 2.1132131859259}, {
             0.06298150640860245, 2.1132017184238654`}, {0.12754990653144127`,
              2.113240683601546}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1511618952299321, 2.113254932759544}, {
             0.22046258359457394`, 2.1132967537374583`}, {0.3779021705804344, 
             2.1134982918666783`}, {0.535300267366184, 2.1138063328115253`}, {
             0.6926568739518226, 2.1142208765720003`}, {0.8499719903373504, 
             2.1147419231481024`}, {1.0072456165227663`, 
             2.1153694725398315`}, {1.0956375506779572`, 
             2.115781541275047}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1192492871037099`, 2.1158916153271448`}, {
             1.1644120871642678`, 2.1161021569119356`}, {1.321405736918049, 
             2.1169386084291615`}, {1.47822656578411, 2.1178788270915088`}, {
             1.6348745737624508`, 2.118922812898978}, {1.791349760853071, 
             2.1200705658515684`}, {1.947652127055971, 2.121322085949281}, {
             2.0637063985749027`, 2.122329498565186}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0873175020223513`, 2.122534455463171}, {
             2.1037816723711518`, 2.1226773731921154`}, {2.259738396798612, 
             2.1241364275800714`}, {2.416260908045311, 2.1257328563303486`}, {
             2.57141122914973, 2.1273784800047153`}, {2.7263609447504944`, 
             2.129126606602867}, {2.881096162539634, 2.130976604014135}, {
             3.031739976694491, 2.1328790548955663`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.055349915004162, 2.1331904901329652`}, {
             3.189867535451172, 2.134979682833349}, {3.343875905957632, 
             2.1371315000199576`}, {3.4976142094205986`, 2.13938265957701}, {
             3.6504792562164803`, 2.141721522741928}, {3.8030329526455233`, 
             2.1441536183929117`}, {3.9552598075531114`, 2.146677865499357}, {
             3.999721428569827, 2.147443455404153}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023329921891316, 2.147849972839664}, {
             4.107144329784627, 2.149293183030661}, {4.258671028185451, 
             2.1519984899562195`}, {4.409824411600966, 2.154792705245429}, {
             4.560588988876553, 2.157674747867687}, {4.710949268857596, 
             2.1606435367923886`}, {4.860889760389474, 2.163697990988931}, {
             4.9676357602584655`, 2.16593924928586}}]}, 
           {Arrowheads[{{0.01409839344073234, 1.}}], 
            ArrowBox[{{4.991242550425786, 2.1664349017167828`}, {
             5.010394972317572, 2.1668370294267105`}, {5.15944941348727, 
             2.170059571075124}, {5.308037592743949, 2.1733645349035666`}, {
             5.456144018932993, 2.1767508398814366`}, {5.603753200899783, 
             2.180217404978129}, {5.656854249492381, 2.1814974001012257`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQfS6rKrpN9I190be5N8V3X9rvdUfaJMH6jf27011b
lIH8533/3WbGvrEP/FiVoAfk75pxSCNs4ht7GZ/yXDsg/8sL47n1e97Yf3x2
aZ83kP+ipIyrgeGtvZ+F4rQEIL/Y1bWHqfqtvcXtwD2tQP6Kix4fEhXe2TPm
583eDuSzNi+unizx3n6elkcp055L+9etEVPaY/DB/rj8npo0IL9Q8y/L1OgP
9h7Oq7c1APksxX6fgto/2Mtv+7NyNpCfkiS+y2T2B/sCIzeuFUC+VcLpvh+z
P9l3La8r+r330n6GTa9kM+d8sRe/UplZuv/S/u3hpeltc77Zi+0wfy968NL+
+MDs7IA5P+w7gncw3z10aX/Vy/VCm2b/smdLUnc7deTS/t4sNbdps/7Ya87f
EHr32KX9hjPuzo1U/2tfubLUour4pf0AN/6vKA==
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8457189284963686`, -0.2934508354056562}, {
             1.9123506762382811`, -0.2935233584868647}, {
             2.036840743052812, -0.293667998229088}, {
             2.1611732558831194`, -0.29382128634227633`}, {
             2.2853103014419176`, -0.2939828586935898}, {
             2.409251879729207, -0.2941527152830285}, {
             2.532997990744988, -0.2943308561105924}, {
             2.65654863448926, -0.29451728117628145`}, {
             2.7799038109620238`, -0.29471199048009566`}, {
             2.7901977717683066`, -0.294729317086191}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.813809731318772, -0.2947690603035948}, {
             3.0260277620930247`, -0.2951262618020997}, {
             3.2713698441379906`, -0.2955736700766045}, {
             3.515930057096922, -0.29605421530361004`}, {
             3.7582877324985877`, -0.2965649038944937}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.7818996661551574`, -0.29661783486750604`}, {
             4.00270487575668, -0.2971147166151233}, {
             4.172369517872322, -0.2975167853364233}, {
             4.341536402775819, -0.297933732902516}, {
             4.5658647921530715`, -0.29851087185622327`}, {
             4.726376511529631, -0.2989434238798202}}]}, 
           {Arrowheads[{{0.019203587422604793`, 1.}}], 
            ArrowBox[{{4.749988418791547, -0.2990070539892402}, {
             4.789219667658179, -0.2991127755910734}, {
             5.011601029291141, -0.2997394441070664}, {
             5.233008877051956, -0.30039087740420223`}, {
             5.262489767912779, -0.30047946051669705`}, {
             5.291952187492173, -0.30056846270224835`}, {
             5.490065051632368, -0.30119150968023467`}, {
             5.656854249492381, -0.3017338764407644}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.30426533906375197`}, \
{-5.589135266796396, -0.3040427058754678}, {-5.38989659562358, \
-0.30341048633563067`}, {-5.1896091321704585`, -0.3027974589849054}, \
{-4.988474874135042, -0.3022041298316123}, {-4.786516374217528, \
-0.3016309524995238}, {-4.712378800569222, -0.30142890919329746`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688766895253652, -0.30136456088539504`}, \
{-4.583756185118113, -0.30107838061241216`}, {-4.3802611392551505`, \
-0.30054743631519515`}, {-4.176098069046994, -0.3000391417527905}, \
{-3.971266974493644, -0.2995534969251982}, {-3.7657678555951, \
-0.2990905018324183}, {-3.7442900369555487`, -0.29904462809333265`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7206780978154406`, -0.2989941961591778}, \
{-3.5596007123513616`, -0.2986501564744508}, {-3.352765544762429, \
-0.2982324608512956}, {-3.1452623528283032`, -0.29783741496295285`}, \
{-2.9370911365489825`, -0.29746501880942244`}, {-2.820233890137134, \
-0.29726660430468893`}, {-2.776200103163856, -0.2971948166073827}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7525881415442113`, -0.29715632234036476`}, \
{-2.703209997784642, -0.29707582180926334`}, {-2.4718129090422893`, \
-0.2967221961316417}, {-2.239881322092299, -0.2963992887687829}, \
{-2.007415236934671, -0.29610709972068705`}, {-1.8081092913592975`, \
-0.2958834407452693}}]}, 
           {Arrowheads[{{0.019124695779507116`, 1.}}], 
            ArrowBox[{{-1.7844973132287063`, -0.2958569436389184}, \
{-1.7744146535694059`, -0.29584562898735406`}, {-1.7449510951300065`, \
-0.29581454316328687`}, {-1.7154805697246103`, -0.295783959203015}, \
{-1.629557786024958, -0.29570068891860135`}, {-1.543593278253079, \
-0.29562190842390984`}, {-1.3184852648972234`, -0.2954309289112807}, \
{-1.0931168546232457`, -0.2952700929605675}, {-1.036736137439445, \
-0.2952345469768274}, {-0.9840885932351371, -0.29520266686342206`}, \
{-0.9434475524337805, -0.29517850127565015`}, {-0.915714488216824, \
-0.29516203420884896`}, {-0.9020678987117425, -0.2951538679179773}, \
{-0.8948527757099467, -0.2951494996020166}, {-0.8907520900679631, \
-0.29514700426474827`}, {-0.885526471700618, -0.29514381150637387`}, \
{-0.8813532402468378, -0.29514125000208313`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.8978776829815154}, \
{-5.5040256504162475`, -0.8963951846470526}, {-5.305107729920807, \
-0.894530600384229}, {-5.086170907887096, -0.8925567721165673}, \
{-4.86632842499487, -0.8906596803810349}, {-4.712412774261683, \
-0.8893904458998896}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688801584047623, -0.8891957409649606}, \
{-4.6455802812441265`, -0.8888393251776322}, {-4.4239264766348665`, \
-0.887095706506359}, {-4.394423402722376, -0.8868691931078041}, \
{-4.364906389061274, -0.8866441032152896}, {-4.194797882267856, \
-0.8854062947929657}, {-4.024241147861241, -0.884215795317732}, \
{-3.866594738730969, -0.8831377352353947}, {-3.7443468908837567`, \
-0.8823362730040797}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207354053113337`, -0.8821814750731158}, \
{-3.708652908176651, -0.8821022616940343}, {-3.550415656198287, \
-0.8811093746936507}, {-3.3918829827958787`, -0.8801590742342439}, \
{-3.2330548879694243`, -0.8792513603158141}, {-3.073931371718925, \
-0.878386232938361}, {-2.91451243404438, -0.8775636921018849}, \
{-2.776270624159446, -0.8768885975515521}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75265890991136, -0.8767738799632411}, \
{-2.594788294423154, -0.8760463700518631}, {-2.434483092476473, \
-0.8753515888383177}, {-2.273882469105746, -0.8746993941657489}, \
{-2.1129864243109746`, -0.874089786034157}, {-1.9517949580921576`, \
-0.873522764443542}, {-1.8081866055831595`, -0.873056390643317}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.784574732292411, -0.8729812533584802}, \
{-1.6285257613823865`, -0.8725164808852426}, {-1.4664480308914334`, \
-0.8720772189175582}, {-1.4583791215041635`, -0.8720565498847286}, \
{-1.450309937422151, -0.872036000490645}, {-1.4422404751797913`, \
-0.8720155706074061}, {-1.434170730627178, -0.8719952601956502}, \
{-1.4261007025845076`, -0.8719750688184238}, {-1.4099600738196076`, \
-0.8719349231071503}, {-1.3938182864799442`, -0.8718952508548965}, \
{-1.3776753188998772`, -0.8718560501718827}, {-1.2161746406032865`, \
-0.8714893300896159}, {-1.0545329382731183`, -0.8711674584065843}, \
{-0.8927714953984489, -0.8708910399170563}, {-0.840097596262224, \
-0.8708199825378413}}]}, 
           {Arrowheads[{{0.008263164309112005, 1.}}], 
            ArrowBox[{{-0.8164856247489644, -0.8707881298585952}, \
{-0.647877797756248, -0.8705606769740035}, {-0.5878856521724662, \
-0.8704954494913155}, {-0.5315150331603793, -0.8704393852632973}, \
{-0.48322830895722646`, -0.8703950358800656}, {-0.4504924497431447, \
-0.870366675766215}, {-0.4262663269082932, -0.8703465415828894}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8811228708709246, 0.2941680955514091}, {
             0.8864706803105166, 0.2941713689285067}, {0.8931270601289114, 
             0.29417541911083134`}, {0.8983703440564222, 
             0.2941785925319666}, {0.9064435873345345, 
             0.29418344837596627`}, {0.9242114242770154, 
             0.29419400700541515`}, {0.9588611182693939, 
             0.29421449566809665`}, {1.012085334568911, 0.2942462526835609}, {
             1.0396681809265906`, 0.2942628227151675}, {1.068048009922284, 
             0.29428023892713223`}, {1.133425217446019, 0.2943239400478827}, {
             1.1987816921792005`, 0.2943701380090611}, {1.4124359362325039`, 
             0.2945342804931489}, {1.6256946300877133`, 
             0.29472438052279515`}, {1.8256022754545933`, 
             0.2949272881768907}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8492142548656674`, 0.2949525765588512}, {
             2.05102536720385, 0.2951824532187631}, {2.2630974104647774`, 
             0.2954504258850847}, {2.474773903527611, 0.29574435609696476`}, {
             2.68605484639235, 0.2960642438544033}, {2.793693083577345, 
             0.2962407671227178}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.817305044823208, 0.2962794899844019}, {
             2.896940239058995, 0.29641008915740025`}, {3.107289018685087, 
             0.2967804547016985}, {3.3169601224281653`, 
             0.29717390318304093`}, {3.5259535502882295`, 
             0.29759043460142753`}, {3.734269302265281, 
             0.29803004895685825`}, {3.761783015187137, 
             0.2980913600646972}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.785394949560363, 0.298143976513039}, {
             3.9419073783593186`, 0.29849274624933314`}, {4.148867778570343, 
             0.2989785264788522}, {4.355150502898355, 0.29948738964541544`}, {
             4.560755551343353, 0.3000193357490228}, {4.729871776648559, 
             0.3004766621897255}}]}, 
           {Arrowheads[{{0.019129572417359932`, 1.}}], 
            ArrowBox[{{4.753483683312434, 0.30054051383502633`}, {
             4.765613485071002, 0.3005733154130811}, {4.9696548652469685`, 
             0.3011482792609969}, {5.172856375083512, 0.3017437592148364}, {
             5.375194697792892, 0.3023592871966659}, {5.576525404080755, 
             0.30299437170546706`}, {5.656854249492381, 
             0.303256872596937}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(inc\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(inc\\)]\\)}\"", 
           TraditionalForm]}}], {972., -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAB1U0MLsX8D8aIhKuscUqP67vMq/4
/+8/Tr1LRSa4Kj9uUg1QhKzvP5CEDW8+oCo/HmbKRdI57z+/zNNpFH8qPxfH
mse35e4/mSLE9JNmKj/CUVb7H4HuP/BNIcIhSSo/iaPb9vgX7j8O2OVgUSoq
P9pJ5FG1g+w/d77ovjK0KT9ajFWW0wfrP0EyURTBRSk/ytSyUsnP5T/a5PcN
T8UnP+htlW5OGt8/hezsY9sAJj+w5BH7IQbVP0z97QXXmyQ/rmXjFoLwxT+X
4yMluD0jP5gdNEa90qM/yVBF8swZIj+YA8ivo4yTP50DzI/Q7iE/AF3QOkcj
Gr96n/7FsMQhPy6jI5DeZp+/ZCw2A1iDIT/+LtEp/NSuv3AP/SKyQyE/zomB
Plfwx7+NGf9xFTQgP883HgNWEtO/BHnX55uQHj93JRiprq/UvwbGd0e0JR4/
w/qg2Q==
             "]]}, 
           {Arrowheads[{{0.009692545577561135, 1.}}], 
            ArrowBox[{{-0.35644820830931645`, 
             0.00011290481206337316`}, {-0.39666348745579716`, 
             0.00011036551054880032`}, {-0.5313085526255972, 
             0.00010186467497369669`}, {-0.6481458591246388, 
             0.00009443623578515112}, {-0.7505824080839971, 
             0.00008783960660753923}, {-0.8411825795316917, 
             0.00008189361326284221}, {-0.8864852980143684, 
             0.00007886236024564322}, {-0.9290283758276592, 
             0.00007597353284577588}, {-0.9671863710890907, 
             0.00007336738364007761}, {-0.9999929959827308, 
             0.00007118321610835804}, {-1.0005258805386683`, 
             0.00007114874723854071}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.009380674205805106, 1.}}], 
            ArrowBox[{{-0.1841461096370365, 
             0.9406841540316915}, {-0.2561350626493132, 
             0.9057235765703391}, {-0.3427628727406718, 
             0.8636518673305004}, {-0.41570808940019655`, 
             0.8282091440046093}, {-0.48236753129955845`, 
             0.7958878294832946}, {-0.5409976242794742, 
             0.7675905893336228}, {-0.5677948086469065, 
             0.7547629460454073}, {-0.5940792681404313, 
             0.742139661927722}, {-0.6204561158985727, 
             0.729399384843643}, {-0.6330000599073398, 
             0.723325057563138}, {-0.6435407827285056, 
             0.7182812678716848}, {-0.6615240650467782, 
             0.7098255486681881}, {-0.6774786005823484, 
             0.7023764246501373}, {-0.7057373055759032, 
             0.6892333187212232}, {-0.7387272436373586, 
             0.6740015735616508}, {-0.7459679570148045, 
             0.6706654157687201}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.015196792928587251`, 1.}}], 
            ArrowBox[{{0.6608723773727787, 0.7509958741832026}, {
             0.6604420708996785, 0.7508737568310727}, {0.6324825154939229, 
             0.742879428078772}, {0.6027329592072035, 0.7342623400408422}, {
             0.5689550545899261, 0.7244622709670021}, {0.5357255096941534, 
             0.7148520200933981}, {0.49986708923462664`, 
             0.7045029023374229}, {0.46564246874393717`, 
             0.6946706990560423}, {0.4218883815327611, 0.6822074823137106}, {
             0.38044960390504745`, 0.6704546419844593}, {0.2712145331361925, 
             0.6396797339099868}, {0.17519301314857794`, 0.612978632458451}, {
             0.08946261110677273, 0.5893878300133885}, {-0.03018895487224463, 
             0.5568576672822041}, {-0.13509454266435594`, 
             0.5286465473998594}, {-0.22835616402574047`, 
             0.5037773644277068}, {-0.3123184052438421, 
             0.48152185380603096`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAOLhYe5iC5j84YH4yCEDnv6iJ2Kso
GuY/ckzSlhUk5798LCjqtk3lP6Q4PZPs7Oa/hNtn/nDw5D+vedwLjtPmv/Gg
/ODfgOQ/ugbW5ga15r+pymKnqvvjPwH2AklUkOa/zsUyB4az4z+eo7q5Y3zm
v/Tr5sGWZ+M/oXWHvFdn5r+3Yf/0muDhP8IucXyN++W/XkYClmJv4D9/Qi2b
ZZblv1i52LjHAto/nP3vGUan5L/e9LsMNfzTP+ued7TI1+O/m1iz8cY0zT+l
vIdhaSDjv6p7+p2TIrw/B7a5anMh4r/QPD85XEt7P8OEuTy+ReG/MuGwV3HJ
tb//ubmnfYTgv/phRifGvsm/CMeRjm4l37+H64FqjWzTv/ax8MDqfd2/uUPU
3klF2b8funsPwwXcvwcIS0Vci96/xKSABUSz2r8W7PD7GaPivzN/2V16Atm/
EajELA==
             "]]}, 
           {Arrowheads[{{0.0024184905571429474`, 1.}}], 
            ArrowBox[{{-0.6146340752141588, -0.3826813389937213}, \
{-0.6370355561905569, -0.3770539613521495}, {-0.7703791450368171, \
-0.34304095808347557`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0068490386217851095`, 1.}}], 
            ArrowBox[{{-0.23552486100803258`, -0.9582567402819138}, \
{-0.2622627458287634, -0.9450862250190194}, {-0.2911189551514802, \
-0.9308100699417277}, {-0.3258231274799177, -0.9133987353547424}, \
{-0.3761359751188175, -0.8881461411741939}, {-0.3984154682758863, \
-0.8770718506334644}, {-0.4199221137022983, -0.8664156697827733}, \
{-0.44017919492644164`, -0.8563643133667883}, {-0.46111848290252583`, \
-0.845918489991144}, {-0.4842311343404959, -0.8342740374813806}, \
{-0.4989484974235778, -0.8268189718623611}, {-0.5109886816680548, \
-0.8207970397112329}, {-0.5326231132060014, -0.8101437030280602}, \
{-0.5525458166630978, -0.8003793062182556}, {-0.5884278826391118, \
-0.7828084885561317}, {-0.6191541688626672, -0.7677331044543941}, \
{-0.6431977756545566, -0.7559266604903807}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.005251174396710474, 1.}}], 
            ArrowBox[{{0.9104100249861009, 0.4137139073293842}, {
             0.8793178132934838, 0.40919469863656766`}, {0.7999293953079274, 
             0.397474689575587}, {0.7468929463703992, 0.38961481849091384`}, {
             0.6972885631378825, 0.3823023887478616}, {0.65069108752896, 
             0.3754668274253902}, {0.565166836269825, 
             0.3630232628866278}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sp\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(x\\), \\(sp\\)]\\)}\"", 
           TraditionalForm]}}], {1360.8000000000002`, -192.}, 
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.6163577447388975`}, \
{-5.576429663348106, -2.6154801730924744`}, {-5.335333968381049, \
-2.6121063220356437`}, {-5.09209918763722, -2.607592827306972}, \
{-4.969679640099015, -2.6049087135656954`}, {-4.846725321116618, \
-2.6019396889064588`}, {-4.723236230690028, -2.5986857533292618`}, \
{-4.712557268720973, -2.598381044166315}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688954881898282, -2.5977075832481904`}, \
{-4.599212368819245, -2.5951469068341044`}, {-4.474763660369432, \
-2.591190112286541}, {-4.350000030205751, -2.5866823325521264`}, \
{-4.224921478328203, -2.58162356763086}, {-4.099528004736787, \
-2.5760138175227425`}, {-3.973819609431504, -2.569853082227773}, \
{-3.8477962924123537`, -2.5631413617459526`}, {-3.745382213256162, \
-2.557253965177038}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7218091386719676`, -2.5558988386205215`}, \
{-3.721458053679336, -2.555878656077281}, {-3.59480489323245, \
-2.5480649652217573`}, {-3.4586573487256747`, -2.5389976507559373`}, \
{-3.3221553083792417`, -2.5291239317252296`}, {-3.1171703813469978`, \
-2.5127353334771825`}, {-2.9115284636230534`, -2.494373960840755}, \
{-2.7803352740574008`, -2.4814601305649284`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7568368470189424`, -2.4791470935884803`}, \
{-2.7055844291949085`, -2.474102128775927}, {-2.4996931520500625`, \
-2.45198215224268}, {-2.472809628598259, -2.448972871738967}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.3370654879963375`, \
-2.43293180546127}, {-2.228350435458769, -2.4193911120721228`}, \
{-2.0428757996467635`, -2.395635911258411}, {-1.8588815487083294`, \
-2.370757222772144}, {-1.8193312777754227`, -2.3651226201301667`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7959553216974955`, -2.3617923212278185`}, \
{-1.6763676826434666`, -2.3447550466133222`}, {-1.495334201452175, \
-2.3176293827819454`}, {-1.3501982932197716`, -2.2951903074603295`}, \
{-1.2072564575212592`, -2.2727866906127683`}, {-1.0665086943566382`, \
-2.2504185322392622`}, {-0.9279550037259081, -2.2280858323398105`}, \
{-0.8625576094644676, -2.217636867596017}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8392413556421495, -2.2139114788875194`}, \
{-0.7918575259187498, -2.206340657881618}, {-0.6584784012248439, \
-2.1857350758318903`}, {-0.5278176296441907, -2.1662690861906264`}, \
{-0.39987521117678937`, -2.147942688957827}, {-0.2104913704987893, \
-2.123524180303668}, {-0.024904876128551634`, -2.1039333769471797`}, {
             0.09729391247086763, -2.093861896342184}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12084431638790827`, -2.0921775352335166`}, {
             0.2435893433497705, -2.0847788326328915`}, {
             0.3790128775042998, -2.0795783163132944`}, {
             0.5164354563645996, -2.0772116040987942`}, {
             0.6564573485874343, -2.0775307480788077`}, {
             0.8001590377549797, -2.0802694420142855`}, {
             1.0340509818721564`, -2.0890592217003454`}, {
             1.0647478683358491`, -2.0906583687800446`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0883278865256052`, -2.091886764281067}, {
             1.2786793607063427`, -2.1018030795533855`}, {
             1.4053233842106274`, -2.109247711181207}, {
             1.5343611623714546`, -2.1172521485003357`}, {
             1.665695910514588, -2.125673486893959}, {
             1.7992308439657927`, -2.134368821745264}, {
             1.9347214324295812`, -2.143235131842393}, {
             2.0310352485889256`, -2.149526739070697}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0545970233502264`, -2.151065889301798}, {
             2.0718387195411814`, -2.152192186490602}, {
             2.210359281522429, -2.1611312668487535`}, {
             2.35005969459516, -2.1699436540757104`}, {
             2.4907531208626708`, -2.178619461235611}, {
             2.632273628646236, -2.187205276767037}, {
             2.7744291534946584`, -2.195677094890517}, {
             2.917027630956742, -2.2040109098265788`}, {
             2.997320286407148, -2.2085981044197647`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0208938393689495`, -2.2099448835751176`}, {
             3.1477985010211786`, -2.2171950657308286`}, {
             3.3792678681771124`, -2.2300999297968542`}, {
             3.610913785658965, -2.2427057393181427`}, {
             3.842214306701157, -2.25499273158818}, {
             3.9639744767928944`, -2.2613111488233755`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9875547425186, -2.262534783426214}, {
             4.072889519644249, -2.2669630026554257`}, {
             4.3027978186037386`, -2.2786311392854692`}, {
             4.5316247154764495`, -2.2899961148474874`}, {
             4.759055722159211, -2.301056902710659}, {
             4.930876570011256, -2.309272886103547}}]}, 
           {Arrowheads[{{0.014890144564992085`, 1.}}], 
            ArrowBox[{{4.954461615038602, -2.310400655758322}, {
             4.985089967866039, -2.3118652163243274`}, {
             5.209905791706495, -2.3225029063265015`}, {
             5.433457520420713, -2.333014151869359}, {
             5.655699480748829, -2.3434431321050764`}, {
             5.656854249492381, -2.3434973969016073`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.6172061421266655`}, {-5.574918311626435, 
             2.6163109994425464`}, {-5.333779878683142, 
             2.6129318627220672`}, {-5.090516473521453, 
             2.6084114357572243`}, {-4.9680879063587104`, 
             2.6057232384331668`}, {-4.845128096141369, 
             2.602749718548018}, {-4.721637042869429, 
             2.5994908761017785`}, {-4.712557247484222, 2.599231404264608}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688954889782777, 
             2.5985569235241797`}, {-4.59761474654289, 
             2.5959467110944483`}, {-4.473169630172964, 
             2.5919842201330616`}, {-4.348410116770865, 
             2.5874703998246535`}, {-4.223336206336594, 
             2.582405250169224}, {-4.097947898870148, 
             2.5767887711667727`}, {-3.972245194371528, 
             2.5706209628173}, {-3.846228092840735, 
             2.563901825120806}, {-3.7453824968794582`, 
             2.5580980897874936`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721809509466345, 
             2.556741447698594}, {-3.7198965942777686`, 
             2.55663135807729}, {-3.5932506986826276`, 
             2.5488095616867525`}, {-3.45714902522793, 
             2.5397358066023923`}, {-3.3206930960461634`, 
             2.529855714839455}, {-3.1157219034890815`, 
             2.513453928372259}, {-2.910097573894786, 
             2.4950806077283225`}, {-2.780335986807604, 2.482299286086332}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.756837708276065, 
             2.47998474090631}, {-2.7041734635965753`, 
             2.47479739181949}, {-2.4983029289277487`, 
             2.452665919557604}, {-2.471422683914384, 
             2.449655188368602}, {-2.444546998600464, 
             2.446612201231679}, {-2.335725834580995, 
             2.4336105475404675`}, {-2.2270550063361894`, 
             2.420068031046654}, {-2.0416631746343645`, 
             2.39631193610886}, {-1.8577522368524013`, 
             2.3714351161351406`}, {-1.8193322272500887`, 
             2.3659599986174245`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.795956401993586, 
             2.3626287815855256`}, {-1.6753221929902995`, 
             2.345437571125496}, {-1.4943730430480593`, 
             2.3183193010799257`}, {-1.3492076444137937`, 
             2.295873300748825}, {-1.2062368426381813`, 
             2.2734648884244106`}, {-1.0654606377212223`, 
             2.2510940641066832`}, {-0.9268790296629169, 
             2.228760827795642}, {-0.8625565484587463, 
             2.218486734016635}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.839240118166346, 
             2.2147624499571408`}, {-0.7907526483806178, 
             2.2070176490359192`}, {-0.6573421237916784, 
             2.1864169973721466`}, {-0.526647455896099, 
             2.1669588728043236`}, {-0.39866864469387925`, 
             2.1486432753324505`}, {-0.20958601911526836`, 
             2.124289273019664}, {-0.024271361901458816`, 
             2.104750432489488}, {0.09729908041144114, 
             2.094744798290549}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.12084862795442869`, 2.0930483945768996`}, {
             0.24430441763835206`, 2.0856203672776177`}, {
             0.37977626224663047`, 2.080431008846022}, {0.5172504255057483, 
             2.078073936142166}, {0.6573255040520047, 2.0784008693369587`}, {
             0.8010789718307396, 2.081144904738041}, {1.0348646204033933`, 
             2.089930959216232}, {1.0647534243493144`, 
             2.0914873345135483`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0883334701962275`, 2.092715198998595}, {
             1.2793578010775537`, 2.1026622530964425`}, {1.405921299065715, 
             2.1100983677463194`}, {1.5348720051471334`, 2.118093445511235}, {
             1.666113361011102, 2.126505037479368}, {1.7995488083469142`, 
             2.1351906947388963`}, {1.9349346448658455`, 2.14404748164129}, {
             2.0310427141226652`, 2.1503239759930834`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0546045155539034`, 2.1518627178983656`}, {
             2.0719430860060184`, 2.152995041545614}, {2.210351450046996, 
             2.1619247940514392`}, {2.3499370552683425`, 
             2.1707281587583367`}, {2.4905137598561287`, 
             2.1793954153194988`}, {2.631916301943, 2.18797333484733}, {
             2.7739533197283834`, 2.196438074130219}, {2.916433451411706, 
             2.2047657899565554`}, {2.997328202967424, 
             2.2093882104126266`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.020901742195359, 2.2107352299392784`}, {
             3.147011099314587, 2.21794126569363}, {3.37828648620279, 
             2.2308380275601554`}, {3.609738647926282, 2.2434359689782295`}, {
             3.8408466203350278`, 2.255714983369951}, {3.9639821388882712`, 
             2.262105871294867}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9875623937047053`, 2.263329716108641}, {
             4.0713315307954066`, 2.2676774394382186`}, {4.301052844683175, 
             2.279338548903531}, {4.5296971048623735`, 2.290697469714387}, {
             4.75695085419703, 2.301753359819285}, {4.930883943116245, 
             2.3100735338795877`}}]}, 
           {Arrowheads[{{0.014889998015829653`, 1.}}], 
            ArrowBox[{{4.9544689675075295`, 2.3112017350135483`}, {
             4.982812337320409, 2.3125575539193357`}, {5.207457914162474, 
             2.323191202002857}, {5.430841300532311, 2.3336981849491574`}, {
             5.6529162122390035`, 2.344122383637546}, {5.656854249492381, 
             2.344307483233843}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.0004719622179518145}, {-5.6332827523640745`, 
             0.0004719024055326162}, {-5.483066059482972, 
             0.00047140994608526303`}, {-5.332088377254166, 
             0.00047080426942293016`}, {-5.180349705677655, 
             0.0004700853755456176}, {-5.027850044753439, 
             0.00046925326445332533`}, {-4.87458939448152, 
             0.0004683079361460533}, {-4.7205677548618965`, 
             0.00046724939062380163`}, {-4.712374529586459, 
             0.0004671873648258193}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688762536589166, 
             0.0004670086131549723}, {-4.5657851258945685`, 
             0.0004660776278865702}, {-4.401808813380067, 
             0.00046467603803506123`}, {-4.236758469438113, 
             0.0004630467103015325}, {-4.005961464712855, 
             0.00046029341980554777`}, {-3.7727913790806435`, 
             0.00045688474875899926`}, {-3.7442828167335223`, 
             0.00045639286325860237`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7206708237390673`, 
             0.0004559854629538087}, {-3.5372482125414773`, 
             0.000452820697161887}, {-3.2993319650953574`, 
             0.000448101265014211}, {-3.2680043995756844`, 
             0.00044743998431656635`}, {-3.2366356812913755`, 
             0.00044676377772158367`}, {-3.101942388193728, 
             0.00044352283908423635`}, {-2.9665927593998402`, 
             0.0004399637965907454}, {-2.7761911040753082`, 
             0.000434414795509724}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525791110873663`, 
             0.0004337266556172854}, {-2.744149950538696, 
             0.0004334809990292849}, {-2.522572911051914, 
             0.0004257537181229445}, {-2.301861640939495, 
             0.0004167819538717242}, {-2.0820161402014388`, 
             0.00040656570627562393`}, {-1.8672990690359808`, 
             0.0003947699669965069}, {-1.8080993921897996`, 
             0.00039071078382627895`}}]}, 
           {Arrowheads[{{0.013705723584440856`, 1.}}], 
            ArrowBox[{{-1.7844873992473362`, 
             0.0003890917647796611}, {-1.6661763103309184`, 
             0.00038097945054813763`}, {-1.4887237166573992`, 
             0.0003651961907814329}, {-1.2893298630100258`, 
             0.00033903710477803465`}, {-1.2556884956410297`, 
             0.00033232689143180357`}, {-1.2280645122011067`, 
             0.00032568404020402676`}, {-1.2058111803722609`, 
             0.0003191638249694493}, {-1.1882087901849345`, 
             0.00031277782658486276`}, {-1.1638969930526057`, 
             0.0003004776758378624}, {-1.1502509944772206`, 
             0.0002887549699240893}, {-1.1430544597610228`, 
             0.00027762323660672847`}, {-1.1372485547650464`, 
             0.0002586198951911787}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1994972665968267`, 0.000285951971478376}, {
             1.204499689968664, 0.000299358345971161}, {1.211065966223293, 
             0.000307798913710361}, {1.2231990698944617`, 
             0.0003165747895358887}, {1.246683152468466, 
             0.00032576350147404444`}, {1.3157915977977361`, 
             0.0003397547949406696}, {1.4410381655287798`, 
             0.00035412946007922814`}, {1.6272032437906603`, 
             0.00036776220425233477`}, {1.776047970777003, 
             0.0003758089488067793}, {1.9407125783953112`, 
             0.0003829982291486705}, {2.117060972833694, 
             0.0003893797553958859}, {2.1439769549120293`, 
             0.0003902028373336806}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1675889478989587`, 0.0003909248843645605}, {
             2.300957060280261, 0.0003950032376663033}, {2.4105921310503233`, 
             0.00039794281598585867`}, {2.5214363293143895`, 
             0.00040068348005569776`}, {2.649056527630131, 
             0.00040363795383721574`}, {2.7768786398992815`, 
             0.00040644588375900723`}, {2.9049026661218407`, 
             0.00040910726982107225`}, {3.03312860629781, 
             0.0004116221120234108}, {3.112068667551305, 
             0.00041307782128134174`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.13568066054526, 0.0004135132427423047}, {
             3.1615564604271875`, 0.0004139904103660228}, {
             3.2901862285099743`, 0.00041621216484890835`}, {3.41901791054617,
              0.00041828737547206743`}, {3.548051506535776, 
             0.00042021604223550004`}, {3.5819145607657434`, 
             0.00042070258386532665`}, {3.615757011350229, 
             0.0004211831502160463}, {3.7612798471060285`, 
             0.0004231321415346113}, {3.906307206898605, 
             0.00042499320704055633`}, {4.036998693835812, 
             0.00042665103637345905`}, {4.0801603803635995`, 
             0.00042718574433049764`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.1037723733597575`, 0.0004274782611794038}, {
             4.167199530838472, 0.00042826402764324146`}, {4.296909717906587, 
             0.0004298321808499036}, {4.4261292550401565`, 
             0.00043135549599344534`}, {4.55485814223918, 
             0.00043283397307386685`}, {4.683096379503658, 
             0.00043426761209116807`}, {4.81084396683359, 
             0.00043565641304534893`}, {4.9381009042289765`, 
             0.00043700037593640955`}, {5.048252093218165, 
             0.00043814027662441283`}}]}, 
           {Arrowheads[{{0.012387564305926172`, 1.}}], 
            ArrowBox[{{5.0718640862148785`, 0.00043838382938274627`}, {
             5.1910703150821, 0.0004396039066112818}, {5.316764660006333, 
             0.0004408760041656215}, {5.441932097929014, 
             0.0004421283231978969}, {5.5665726288501425`, 
             0.000443360863708108}, {5.656854249492381, 
             0.0004442430401709767}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.4839096438539405`}, \
{-5.557664491336232, -4.482573769576144}, {-5.337795884995518, \
-4.479214209723655}, {-5.114014673110667, -4.475051869336719}, \
{-4.88632085568168, -4.470086748415332}, {-4.712555901751, \
-4.465759324685524}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688951227473491, -4.4651714764152475`}, \
{-4.654714432708557, -4.464318846959497}, {-4.420824762531864, \
-4.457277391916293}, {-4.1862812034921655`, -4.448491610232802}, \
{-3.951083755589462, -4.437961501909022}, {-3.7452667325133833`, \
-4.4272501457688}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7216866510630946`, -4.426022965205916}, \
{-3.7152324188237533`, -4.425687066944955}, {-3.479060495099449, \
-4.4114329650111985`}, {-3.242901286320959, -4.394963855778352}, \
{-3.0067547924882843`, -4.376279739246415}, {-2.7798439709425606`, \
-4.356196897306395}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75633474989522, -4.353998297592981}, \
{-2.550809049542224, -4.334111933712065}, {-2.3313257086735133`, \
-4.311308631306894}, {-2.112170990995291, -4.286970708199875}, \
{-1.8933448965075572`, -4.261098164391006}, {-1.8174369997330206`, \
-4.251784309770165}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7940007656587271`, -4.248908697530817}, \
{-1.674944923398552, -4.234300615187729}, {-1.4570685698565158`, \
-4.207187675897485}, {-1.2397158358814484`, -4.179759346520274}, \
{-1.0228867214733497`, -4.1520156270560955`}, {-0.8568916104407411, \
-4.1311547007947125`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8334638947460054, -4.128210494507308}, \
{-0.8064307161251932, -4.124813182729199}, {-0.5901973093299526, \
-4.099008678763836}, {-0.37418650108762774`, -4.074602115160005}, \
{-0.15839829139821848`, -4.051593491917704}, {-0.12394469741740877`, \
-4.048055125607368}, {-0.0894916711234352, -4.044568051076284}, {
             0.06799770286755596, -4.0294898007352655`}, {
             0.10545456976401085`, -4.026256175719835}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12897906442395193`, -4.0242253226157025`}, {
             0.22588121091895313`, -4.0158598283574305`}, {
             0.3841588530307564, -4.0036781339427785`}, {
             0.5428306292029658, -3.9929447174913095`}, {
             0.5624548086156164, -3.9917083274421317`}, {
             0.5820859280012016, -3.990494797995529}, {
             0.6321599254136714, -3.987609432314746}, {
             0.682277706042523, -3.9848717291661986`}, {
             0.9133179672485645, -3.9738417303178886`}, {
             1.0716781114057163`, -3.9684357735133093`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0952763583941105`, -3.9676301976876367`}, {
             1.146231311366157, -3.9658907431284587`}, {
             1.3810177383953006`, -3.961018767597909}, {
             1.6176772483359954`, -3.9592258037262393`}, {
             1.8561462020470918`, -3.960033132349496}, {
             2.0396540555535556`, -3.96227061565179}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0632642936024235`, -3.9625584916875463`}, {
             2.096360960387441, -3.9629620343037235`}, {
             2.3383215233570427`, -3.9680125095889234`}, {
             2.5820278909558967`, -3.975184558205094}, {
             2.8270180658228714`, -3.9840242590228576`}, {
             3.007273219567981, -3.991396490741583}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.030865489210503, -3.9923613878608144`}, {
             3.0728300505968345`, -3.9940776909128326`}, {
             3.1960442216989366`, -3.9995595560098995`}, {
             3.3194638452777863`, -4.00534485387502}, {
             3.4430889213333833`, -4.011433584508192}, {
             3.5669194498657264`, -4.017825747909418}, {
             3.714285129080649, -4.025718925351767}, {
             3.861571700802336, -4.03383197996463}, {
             3.9741233056986887`, -4.040203157205039}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9976975591694255`, -4.041537618382298}, {
             4.008779165030785, -4.042164911748005}, {
             4.155907521765998, -4.0507177207018925`}, {
             4.302956771007976, -4.059490406826294}, {
             4.449926912756715, -4.068482970121208}, {
             4.596817947012219, -4.077695410586634}, {
             4.743629873774486, -4.087127728222574}, {
             4.89024017514454, -4.096736954135575}, {
             4.940357952329052, -4.100074971852495}}]}, 
           {Arrowheads[{{0.014707677221307905`, 1.}}], 
            ArrowBox[{{4.963917747268784, -4.101644135876396}, {
             5.0365263332234065`, -4.1064801194321845`}, {
             5.182324456887189, -4.116314480398083}, {
             5.3274706550119895`, -4.126197293318954}, {
             5.468653165756574, -4.135904160084719}, {
             5.602560227279704, -4.145210682585298}, {
             5.656854249492381, -4.149029008988245}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.4844035615861655`}, {-5.55159254323962, 
             4.482985219073057}, {-5.331495320643308, 
             4.4796163766677015`}, {-5.107642624290712, 
             4.475440587811761}, {-4.880034454181832, 
             4.470457852505235}, {-4.712555773807318, 4.466266838548719}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.6889511703576625`, 
             4.4656761530819225`}, {-4.648670810316672, 
             4.464668170748125}, {-4.415103236582244, 
             4.457602782231287}, {-4.1808832768655675`, 
             4.448792926645581}, {-3.9460109311666427`, 
             4.438238603991006}, {-3.745267050202228, 4.427756024252451}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7216871839919246`, 
             4.426524714851705}, {-3.7104861994854708`, 
             4.4259398142675614`}, {-3.474643500091184, 
             4.41166424091861}, {-3.2388172512529163`, 
             4.395179567387515}, {-3.0030074529706683`, 
             4.376485793674276}, {-2.7798448090570687`, 
             4.35670262061673}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7563332998207724`, 
             4.35452870731581}, {-2.547617252648598, 
             4.334306761457299}, {-2.3283499733772195`, 
             4.311501973830321}, {-2.1094122674303053`, 
             4.28716855689796}, {-1.8908041348078561`, 
             4.261306510660216}, {-1.817436856911054, 4.252300669219841}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7940007664789486`, 
             4.24942388653873}, {-1.6726220553264142`, 
             4.234524636379628}, {-1.4549625088025235`, 
             4.207431735318735}, {-1.2378254952361842`, 
             4.180027807477539}, {-1.0212110146273965`, 
             4.1523128528560385`}, {-0.8568921449819886, 
             4.131665497867975}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8334643778767352, 
             4.128721700694567}, {-0.8049683503904632, 
             4.125141055352201}, {-0.5889467859396879, 
             4.099366598863994}, {-0.3731463212750705, 
             4.074989483391417}, {-0.15756695639661128`, 
             4.05200970893447}, {-0.12313809319664779`, 
             4.048474984499584}, {-0.0887097943728129, 4.044991473717717}, {
             0.06876760959500217, 4.02991922603631}, {0.10545253447195391`, 
             4.026753418291246}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.12897709374432037`, 4.024723313767563}, {
             0.2266396421419033, 4.016295305446521}, {0.38490630326789066`, 
             4.00411971194835}, {0.5435675929729642, 3.9933924455417964`}, {
             0.5631921950361897, 3.9921567119516514`}, {0.5828237358014915, 
             3.990943835171207}, {0.6329210920087381, 3.9880588806970114`}, {
             0.6830622610746742, 3.9853216943132073`}, {0.914122987583787, 
             3.9742987306564794`}, {1.0716756200884738`, 
             3.9689254480825573`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0952738931522428`, 3.9681206364623867`}, {
             1.147057644328893, 3.966354568048382}, {1.381866231309992, 
             3.961489206488916}, {1.6185487485270842`, 3.9597026459780804`}, {
             1.857040755652677, 3.960516017355761}, {2.0396513532465606`, 
             3.9627465590259656`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0632615849873264`, 3.9630349519584396`}, {
             2.0972778123592786`, 3.963450451461842}, {2.3392599186468885`, 
             3.968505948296325}, {2.582987074515507, 3.9756825078592084`}, {
             2.827997122874181, 3.9845263048740622`}, {3.007270805687962, 
             3.9918605894694656`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0308630635401697`, 3.992825774825288}, {
             3.073827906631957, 3.9945835140644563`}, {3.197051074285509, 
             4.00006714822548}, {3.320479425788836, 4.00585413543039}, {
             3.444112961141938, 4.011944475679185}, {3.5679516803448164`, 
             4.018338168971864}, {3.7153230038646896`, 4.0262329403797255`}, {
             3.8626150034276017`, 4.034347636918209}, {3.9741212006636895`, 
             4.040660693615931}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.9976954415293267`, 4.041995377453058}, {
             4.009827679033553, 4.042682258587317}, {4.156961030682544, 
             4.051236805387047}, {4.304015058374575, 4.060011277317401}, {
             4.4509897621096455`, 4.069005674378379}, {4.5978851418877555`, 
             4.078219996569978}, {4.744701197708905, 4.087654243892202}, {
             4.891315237419374, 4.097265308894478}, {4.940355870974769, 
             4.100532053957131}}]}, 
           {Arrowheads[{{0.014707726048637354`, 1.}}], 
            ArrowBox[{{4.963915650977934, 4.102101442226057}, {
             5.037604568865439, 4.107010084126234}, {5.18340105214958, 
             4.116845661747945}, {5.3285365473742745`, 4.126729133920087}, {
             5.469688965984652, 4.136435350433582}, {5.603536219425839, 
             4.145739161079357}, {5.656854249492381, 4.14948945410397}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.3098064213888567`}, \
{-5.607201929428061, -1.309491339769072}, {-5.405214244463376, \
-1.3079175078192797`}, {-5.191599436777332, -1.3057504063791798`}, \
{-4.976526871723516, -1.3029231810968405`}, {-4.759996549301928, \
-1.299435831972262}, {-4.71244792109667, -1.2985311648442195`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688840200641255, -1.2980820009152028`}, \
{-4.5420084695125675`, -1.2952883590054445`}, {-4.5129228570180135`, \
-1.2946929234910223`}, {-4.483808034793217, -1.294081283645871}, \
{-4.309316513622002, -1.2897168034126745`}, {-4.133697226973322, \
-1.284653221897009}, {-3.9055809652426015`, -1.2773134994062145`}, \
{-3.7447660415888593`, -1.271077510911815}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7211717811377936`, -1.2701625862682322`}, \
{-3.675555911615416, -1.2683937203505637`}, {-3.4436220660917654`, \
-1.2578938847300567`}, {-3.2097794286716503`, -1.2458139925446932`}, \
{-2.974799982209266, -1.231736425787888}, {-2.778179237231836, \
-1.2179573002000772`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7546250127500693`, -1.216306626883307}, \
{-2.739455709558809, -1.215243566453056}, {-2.5037466107202793`, \
-1.1963354145401972`}, {-2.267672685693677, -1.1750119700493116`}, \
{-2.027855152403476, -1.1501120416591062`}, {-1.8147532067959422`, \
-1.1242524804296679`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7913185147652597`, -1.1213671335566073`}, \
{-1.6251618020751295`, -1.09810095316645}, {-1.4653224214970857`, \
-1.072402704455623}, {-1.3176175914585975`, -1.0446162853807304`}, \
{-1.185637936119082, -1.0147738138742208`}, {-1.0159399564502167`, \
-0.9643194170618062}, {-0.9061066711915622, -0.9127794400463001}, \
{-0.883979816503758, -0.8912992812470277}}]}, 
           {Arrowheads[{{0.00038585571979124993`, 1.}}], 
            ArrowBox[{{-0.8670378729325612, -0.8748524955012795}, \
{-0.8539635812699075, -0.8621603227969232}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.3106838696204386`}, {-5.607139965763899, 
             1.3103681581462334`}, {-5.40515424651559, 
             1.308793312682845}, {-5.191548333473303, 
             1.3066249582927387`}, {-4.976484661164041, 
             1.3037961734657908`}, {-4.759963229587802, 
             1.3003069582020008`}, {-4.712448001134082, 
             1.2994024160633464`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6888402855038676`, 
             1.2989529985969923`}, {-4.541984038744587, 
             1.2961573125013695`}, {-4.512899576199249, 
             1.2955615670091043`}, {-4.483785905015014, 
             1.2949496094920177`}, {-4.309295053101756, 
             1.2905827125161147`}, {-4.133676413399737, 
             1.285516322511812}, {-3.9055803151915636`, 
             1.2781733597312683`}, {-3.7447665485165387`, 
             1.2719343611088105`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7211723054245094`, 
             1.2710189889165369`}, {-3.6755771405644495`, 
             1.2692500596971403`}, {-3.443666889518395, 
             1.2587464224094278`}, {-3.2098495620533996`, 
             1.2466624478681307`}, {-2.9748957306921713`, 
             1.2325804696081963`}, {-2.778181140249203, 
             1.2187893280604387`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75462696119548, 
             1.2171380066376625`}, {-2.7395759679574176`, 
             1.2160828211645716`}, {-2.503890273849139, 
             1.1971695025372562`}, {-2.267838648367335, 
             1.1758405137262506`}, {-2.0279355236397762`, 
             1.1509238483775734`}, {-1.814758611716718, 
             1.12504839090791}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7913239870452333`, 
             1.1221624865038335`}, {-1.625084686123365, 
             1.098878917207235}, {-1.4651728278167924`, 
             1.073162263210624}, {-1.317397402611516, 
             1.0453570352332935`}, {-1.1853509098549777`, 
             1.0154973010082295`}, {-1.0155808193671831`, 
             0.9650225006355491}, {-0.9056778672475114, 
             0.9134571093614466}, {-0.8838689528409458, 
             0.8922945338108276}}]}, 
           {Arrowheads[{{0.00039660234855838265`, 1.}}], 
            ArrowBox[{{-0.8669235398223863, 
             0.875851322720332}, {-0.8534823586214815, 
             0.8628084904476683}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.92165216777977, -0.8715538123695665}, {
             0.9324472389703483, -0.8797807217391735}, {
             0.9467296885802007, -0.8881746732646734}, {
             0.9650026283097273, -0.896750174905894}, {
             1.0905667527824434`, -0.9329051791007232}, {
             1.3054681336036513`, -0.9697992280288052}, {
             1.4443699026425265`, -0.9873948320073231}, {
             1.6007709813692603`, -1.0040213267622673`}, {
             1.7711951012122331`, -1.0195156929362441`}, {
             1.8479823944459486`, -1.0255405266537712`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.8715220414476677`, -1.027387478837943}, {
             1.9521659935998248`, -1.0337149111718598`}, {
             2.073945442634214, -1.04225955426356}, {
             2.1977401847681977`, -1.050318108698008}, {
             2.323550220001775, -1.057890574475204}, {
             2.4513755483349478`, -1.064976951595148}, {
             2.6885362956959673`, -1.077067805586971}, {
             2.8143232062941346`, -1.082947131697612}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.8379094493669923`, -1.084049561307265}, {
             2.926851705539881, -1.0882067548226309`}, {
             3.1663217778666883`, -1.0983937993021278`}, {
             3.40694651267639, -1.1076289390254614`}, {
             3.5562804582832728`, -1.1129290175251525`}, {
             3.705266520602544, -1.1179875458639619`}, {
             3.7816771507472966`, -1.1205003095579502`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.805276386811024, -1.1212763704734858`}, {
             3.8287553803587766`, -1.1220484772136923`}, {
             3.951876753888783, -1.126010260363718}, {
             4.197017042270117, -1.1336363820646562`}, {
             4.440687385746548, -1.1408659109667767`}, {
             4.682887784318075, -1.1476988470700793`}, {
             4.714949778857749, -1.1485798004445555`}, {
             4.746982674148833, -1.1494562849065393`}, {
             4.749332581943545, -1.1495189921712359`}}]}, 
           {Arrowheads[{{0.01872388432925857, 1.}}], 
            ArrowBox[{{4.772936172512458, -1.1501488537364108`}, {
             4.927772594464733, -1.1542806620217738`}, {
             5.107607139218703, -1.1589952580114233`}, {
             5.287202015388045, -1.163672609788729}, {
             5.465829432585203, -1.1682626763947725`}, {
             5.643489555070193, -1.1727776887271686`}, {
             5.656854249492381, -1.1731144431407254`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9211852223907746, 0.8722435168434176}, {
             0.9320003677665671, 0.8804697479265143}, {0.9463047211997652, 
             0.8888630750945459}, {0.9646013677413978, 0.8974379756074349}, {
             1.0902571422692007`, 0.9335893518700443}, {1.305228925275963, 
             0.9704863247994567}, {1.4441561915845242`, 0.9880868604679481}, {
             1.600577683263513, 1.0047174241449457`}, {1.771019545500463, 
             1.0202163221394793`}, {1.84753050669242, 1.0262215663781744`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8710701034966088`, 1.0280691582249806`}, {
             1.952007923482907, 1.0344218607605793`}, {2.0738097800491797`, 
             1.0429717972284798`}, {2.1976269326561857`, 1.051035251543603}, {
             2.323459381303925, 1.0586122237059492`}, {2.4513071259923978`, 
             1.0657027137155184`}, {2.6884885559824627`, 
             1.0777996259922673`}, {2.8138692205918896`, 
             1.0836625990706124`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.8374554405409596`, 1.0847655232975024`}, {
             2.926825691407707, 1.0889445996843516`}, {3.166318532268131, 
             1.0991376347917718`}, {3.4069670785637336`, 
             1.1083787313145277`}, {3.556301937585649, 1.1136819120928372`}, {
             3.7052887700010224`, 1.118743416185417}, {3.781222141699226, 
             1.1212419485329224`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.8048213628194167`, 1.1220184637333679`}, {
             3.8287721890167004`, 1.1228065482430514`}, {3.9518880929219984`, 
             1.1267704855075862`}, {4.197017355401452, 1.1344007756573582`}, {
             4.440676557439384, 1.1416342866347329`}, {4.682865699035795, 
             1.1484710184397104`}, {4.71492623633322, 1.1493524646784414`}, {
             4.746957673240436, 1.1502294396300659`}, {4.748876970422637, 
             1.1502806870588826`}}]}, 
           {Arrowheads[{{0.01873354347693302, 1.}}], 
            ArrowBox[{{4.772480550821118, 1.1509109296380458`}, {
             4.927746690518897, 1.155056713061061}, {5.107580220316067, 
             1.1597741344976746`}, {5.287164924389271, 1.1644540498771798`}, {
             5.465782155304796, 1.1690466287054875`}, {5.643432077626147, 
             1.1735641062756856`}, {5.656854249492381, 
             1.17390251256033}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.077042755261816}, {-5.654082608112235, 
             2.0770176821461117`}, {-5.644001367108335, 
             2.0769255140615526`}, {-5.638960223436488, 
             2.076879180531525}, {-5.633918555654883, 
             2.0768325955802545`}, {-5.628876363069831, 
             2.076785757840558}, {-5.623833644775496, 
             2.076738664567967}, {-5.618790399968036, 
             2.0766913136571756`}, {-5.448661534627596, 
             2.074934297285718}, {-5.27790634321271, 
             2.0728159570732236`}, {-5.106488528465167, 
             2.070256106002934}, {-4.934371793126757, 
             2.0671745570580895`}, {-4.761516912165659, 
             2.0635011004647033`}, {-4.712499424693103, 
             2.0622748705297265`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688894816526873, 
             2.061684373573859}, {-4.587887002768938, 
             2.0591575446545702`}, {-4.413449281006714, 
             2.0540517299196055`}, {-4.238170962949108, 
             2.048091496551725}, {-4.0619049661910385`, 
             2.041164707855586}, {-3.884595647107586, 
             2.0331752087256523`}, {-3.745121129584131, 2.026038741282471}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721539984639455, 
             2.0248321690988296`}, {-3.7063473799391096`, 
             2.024054811838548}, {-3.5272645389259636`, 
             2.0137353298708978`}, {-3.3473529417148913`, 
             2.0021453819141493`}, {-3.166697251227529, 
             1.989216141927892}, {-2.985520109616571, 
             1.9748832548909616`}, {-2.8040441590347096`, 
             1.9590823657821936`}, {-2.779575192258908, 
             1.9567559916967299`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.756069197433289, 
             1.9545211716605424`}, {-2.6499876033051986`, 
             1.944435520158153}, {-2.49566981903356, 
             1.9285624312882936`}, {-2.341477395928282, 
             1.9114882426234208`}, {-2.1877969236978525`, 
             1.89323809761434}, {-2.0347675863896266`, 
             1.8737518810412237`}, {-1.8827264925798655`, 
             1.8530376846207512`}, {-1.818219868711163, 
             1.8436794352791572`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7948524964165362`, 
             1.8402894315357265`}, {-1.7323571187704196`, 
             1.831222962208486}, {-1.5843429414631394`, 
             1.8084351676599923`}, {-1.4393687325890465`, 
             1.7846791643028292`}, {-1.2981182277358285`, 
             1.7600578878869604`}, {-1.161273348890329, 
             1.7348459009015547`}, {-1.0295160180393943`, 
             1.7093177658357817`}, {-0.9041573163653205, 
             1.6837578930518666`}, {-0.8650542606531081, 
             1.6753797508904331`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8419662657696033, 
             1.6704329634889554`}, {-0.7860049976940445, 
             1.6584428146135906`}, {-0.5710272331690891, 
             1.6095980209399603`}, {-0.3422349108383131, 
             1.5549267669213707`}, {-0.1550361653224851, 
             1.5105585967166182`}, {0.00036131988442130125`, 
             1.4771843545545906`}, {0.07956677245616084, 
             1.464390450791066}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.10287663108101008`, 1.460625254351874}, {
             0.13853974937528665`, 1.4548646597393893`}, {0.2562283891263718, 
             1.4445584033331644`}, {0.3821511103635646, 
             1.4423836391789846`}, {0.5269058359523514, 
             1.4485637540221412`}, {0.6464225654337781, 
             1.4578121174395626`}, {0.7841941410317343, 
             1.4706723520078262`}, {0.941297697623868, 1.4864022132415027`}, {
             1.044032813761001, 1.4967370583572168`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0675262321401653`, 1.4991004259117269`}, {
             1.1188103700878274`, 1.5042594566551635`}, {1.3148997158295999`, 
             1.5233233777561608`}, {1.5277332922551734`, 
             1.5426732720518466`}, {1.7541990446282705`, 
             1.5617977109978463`}, {1.9911849182126118`, 
             1.5801852660497853`}, {2.008381431139312, 
             1.5814305277939267`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0319317590628603`, 1.583135892279749}, {
             2.147403424541556, 1.5914976135290402`}, {2.3055465050004655`, 
             1.6023376377690588`}, {2.4656141595893413`, 
             1.6127053387698413`}, {2.6276063883081835`, 
             1.6226007165313876`}, {2.7817126412479936`, 
             1.6315833107063862`}, {2.935896606721145, 1.6402662384314786`}, {
             2.974537795905626, 1.642366171409673}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.998114999106623, 1.643647460820798}, {
             3.090158284727638, 1.6486494997066652`}, {3.244497675267474, 
             1.656733094531946}, {3.398914778340651, 1.6645170229073207`}, {
             3.55340959394717, 1.6720012848327894`}, {3.7079821220870306`, 
             1.6791858803083524`}, {3.862632362760234, 1.686070809334009}, {
             3.941477213939382, 1.6894607576065055`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.96506741275883, 1.6904750223624136`}, {
             4.027459985669192, 1.6931576020311037`}, {4.1918637111976675`, 
             1.7000613690960447`}, {4.426169346077258, 1.709691459418566}, {
             4.659151754445858, 1.7190631312600388`}, {4.890810936303468, 
             1.7281763846204636`}, {4.908765925076313, 
             1.7288666305727525`}}]}, 
           {Arrowheads[{{0.015352433076398891`, 1.}}], 
            ArrowBox[{{4.932360489612329, 1.7297736794644585`}, {
             5.121146891650087, 1.73703121949984}, {5.151753856987838, 
             1.7381940177429829`}, {5.182329933787344, 1.7393526907878702`}, {
             5.37657111076123, 1.7465927802557548`}, {5.5695517852271355`, 
             1.7537048842239025`}, {5.656854249492381, 
             1.7569408833880704`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAHI3EyvCt1D9OBdGFlJrzvxqSaD4L
NdQ/6QaRPnCR879epwcDFkXTP88aj5X/gvO/BDJBzceR0j+yUwiKDXnzvwVZ
5rMZo9E/DnC2wT9s879C6tltn2XQP2c5OkedW/O/Lc68+a1Fzz+d225JiFHz
v4v6VbnWhs0/fEDh2AZG87+i7+YdAxfKP+y3vN1NL/O/afUGEa/jxT8/h9QG
yRLzv9VqgyPiG74/nCuzpYvi8r9y0W06wn6pPwwMSpNMo/K/yhMrBKwRpT86
zXGHIpvyv5c9oEoziKA/WZM6mbyS8r/c73tf8taAPxA4ZDmoe/K/M111fMBz
kb8U0p2zA2Pyv1n+Tq7XzrG/wZG9U7Qu8r/9gT6kShzAvzINfHVD9PG/qfM3
LWC8x79zo/6AbrPxvy8MPt/2/9S/0RYBvz8H8b8MT9iMw3ndv+rvkr5TQ/C/
4EQ08rVU4r/ZYEVyYtruvzeWmA70keK/PttqZQW27r89Ysk6
             "]]}, 
           {Arrowheads[{{0.002671987053017991, 1.}}], 
            ArrowBox[{{-0.6006193572579371, -0.9476643679325377}, \
{-0.6650823359360617, -0.9093887677171053}, {-0.7071856202159833, \
-0.8802344789370343}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.6584046094829025}, {-5.586858280748716, 
             0.6581655987376541}, {-5.369744671533376, 
             0.6572379454210847}, {-5.151109359538976, 
             0.6560546849874249}, {-5.121848982868995, 
             0.6558777986196569}, {-5.092559731473365, 
             0.6556951650600847}, {-4.898590168898482, 
             0.6541732468927305}, {-4.712395583736141, 0.6524058713438308}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.6887847752413245`, 
             0.6521695636055448}, {-4.574233842390117, 
             0.6509855919272802}, {-4.444519831586817, 
             0.6494278273403927}, {-4.314093579714128, 
             0.6476456303186078}, {-4.182955086772053, 
             0.6456390008619253}, {-4.05110435276059, 
             0.6434079389703454}, {-3.91854137767974, 
             0.6409524446438679}, {-3.7852661615295027`, 
             0.638272517882493}, {-3.7444262040215324`, 
             0.6373872566153191}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720819756284681, 
             0.636875554960563}, {-3.651278704309878, 
             0.6353681586862205}, {-3.5166639111197693`, 
             0.6321447415245804}, {-3.3815066870580783`, 
             0.6285076408671026}, {-3.245807032124806, 
             0.6244568567137871}, {-3.109564946319953, 
             0.6199923890646339}, {-2.972780429643518, 
             0.615114237919643}, {-2.8354534820955006`, 
             0.6098224032788144}, {-2.7768165302919967`, 
             0.6073958006798275}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.75322473024566, 
             0.6064194893002888}, {-2.6975841036759025`, 
             0.6041168851421481}, {-2.559172294384723, 
             0.597997683509644}, {-2.4206990909860977`, 
             0.5913539427761761}, {-2.282645530244162, 
             0.5840748073366188}, {-2.145651093224479, 
             0.5760907560402575}, {-2.0103552609926094`, 
             0.5673322677363778}, {-1.877756366680111, 
             0.5577355343860704}, {-1.8103694947005096`, 
             0.552186020496833}}]}, 
           {Arrowheads[{{0.014856822282519201`, 1.}}], 
            ArrowBox[{{-1.7868371652664046`, 
             0.5502480615857827}, {-1.749651409923784, 
             0.5471857015192979}, {-1.5759426631547797`, 
             0.5304792504636938}, {-1.4211982504281349`, 
             0.5117633960207403}, {-1.1963355115499512`, 
             0.4703025595571503}, {-1.1618184559655484`, 
             0.45971191676339124`}, {-1.1348991951633605`, 
             0.44928050400938224`}, {-1.1147040457241588`, 
             0.43906321829032274`}, {-1.1001498450280582`, 
             0.42908967466942294`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.004905534416090961, 1.}}], 
            ArrowBox[{{-0.8159014266422745, -0.45090680504071273`}, \
{-0.8199104080342142, -0.4504976538571666}, {-0.8253998165902828, \
-0.4499398923074077}, {-0.8299917854710108, -0.4494753585075257}, \
{-0.8380152908222718, -0.44866923588289265`}, {-0.8535579237269983, \
-0.4471055608427022}, {-0.8817847211729442, -0.44396203393898137`}, \
{-0.9194654182336337, -0.43887129868537367`}, {-0.9595810406586356, \
-0.4318501741666905}, {-0.9717459700778497, -0.4293875256486686}, \
{-0.9830040805076469, -0.4268113856750281}, {-0.9962757245933183, \
-0.4225976967132335}, {-1.0074550446365302`, -0.4183180783473606}, \
{-1.0263731461656853`, -0.4096800965588636}, {-1.039799618444169, \
-0.400961912410121}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.6671358197649734}, \
{-5.5666170281834715`, -0.6668043372917901}, {-5.438591870924171, \
-0.6662649283407251}, {-5.310011976784686, -0.6656200236191331}, \
{-5.1808246803036155`, -0.6648350858469859}, {-5.051029981480957, \
-0.6639101150242837}, {-4.920627880316712, -0.6628451111510262}, \
{-4.789618376810879, -0.6616400742272137}, {-4.71239749564072, \
-0.6608509089753227}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688786735563143, -0.6606096168385119}, \
{-4.658001470963459, -0.660295004252846}, {-4.525777162774453, \
-0.6588099012279233}, {-4.392945452243859, -0.6571847651524454}, \
{-4.2613601440179325`, -0.6553956654986179}, {-4.12903952939824, \
-0.6533698358929585}, {-3.995983608384779, -0.6511072763354668}, \
{-3.86219238097755, -0.6486079868261431}, {-3.744422270409515, \
-0.6461754258612602}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7208156506393095`, -0.6456723089885443}, \
{-3.5923714736611427`, -0.64272795326673}, {-3.456333660421802, \
-0.6393043930453236}, {-3.31954427412837, -0.6355584705294505}, \
{-3.182092530746762, -0.6314335027891839}, {-3.0440676462428944`, \
-0.6268728068945969}, {-2.905469620616768, -0.6218763828456897}, \
{-2.776789252390675, -0.6168537092409245}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753196806903292, -0.6158937572216241}, \
{-2.654403927014292, -0.611742916133335}, {-2.5424038727318368`, \
-0.6066853586786257}, {-2.3921755928584143`, -0.5992547821775368}, \
{-2.242553504294525, -0.5910518230117691}, {-2.025801317038229, \
-0.5774523235343573}, {-1.8157946436831902`, -0.5616825804832969}, \
{-1.8103672957179782`, -0.561181298830126}}]}, 
           {Arrowheads[{{0.010622141275372188`, 1.}}], 
            ArrowBox[{{-1.7868553771424327`, -0.5590096869326918}, \
{-1.618447805585508, -0.5434551976282168}, {-1.5920755977245682`, \
-0.5407347552561106}, {-1.5661250378769234`, -0.5379624191786903}, \
{-1.4899410162890372`, -0.5285003485087185}, {-1.4345970056754027`, \
-0.520927249770918}, {-1.3831127885249168`, -0.5131412286493439}, \
{-1.28925930328073, -0.4972678055155236}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.6924408997816742`}, {-5.5362279961896395`, 
             1.6913649522430996`}, {-5.331150392637362, 
             1.6890202085574995`}, {-5.1232955884681175`, 
             1.6861351759764571`}, {-4.912663583681908, 
             1.682709854499973}, {-4.884393457689756, 
             1.6822171133004544`}, {-4.8560970904690866`, 
             1.6817099050184328`}, {-4.712484292590218, 
             1.6785458578658892`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688878028135387, 
             1.6780257695803487`}, {-4.6697408898282085`, 
             1.6776041441481937`}, {-4.482321457976043, 
             1.6727036864096825`}, {-4.253922225323734, 
             1.6659591276797747`}, {-4.02399002320705, 
             1.6576292829130777`}, {-3.7925248516259913`, 
             1.647714152109591}, {-3.74498754098563, 
             1.6453677862314047`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721404257925247, 
             1.6442037529715696`}, {-3.559526710580558, 
             1.636213735269315}, {-3.32514401610475, 
             1.6227240414498332`}, {-3.0895251842325657`, 
             1.6068410797087298`}, {-2.8526702149640064`, 
             1.5885648500460048`}, {-2.7790252670618543`, 
             1.5821714820026318`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755501750937027, 
             1.580129325676307}, {-2.614579108299072, 
             1.567895352461658}, {-2.4452422619777403`, 
             1.5515850028789058`}, {-2.276870457694976, 
             1.5337653902079327`}, {-2.1094636954507795`, 
             1.5144365144487386`}, {-1.9430219752451492`, 
             1.4935983756013234`}, {-1.8168998970025536`, 
             1.476069685300704}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.793512696991276, 
             1.4728192870222379`}, {-1.7216149418631765`, 
             1.4628267979948522`}, {-1.5077537353981734`, 
             1.429107899726827}, {-1.3455973410090671`, 
             1.4002851075758092`}, {-1.1930837649604127`, 
             1.3697586977346583`}, {-1.052782905336244, 
             1.3379942317451692`}, {-0.9272646602205954, 
             1.3054572711491372`}, {-0.8687976051553815, 1.28595884912102}}]}, 
           {Arrowheads[{{0.006690406877262051, 1.}}], 
            ArrowBox[{{-0.8463983827871411, 
             1.2784888390384113`}, {-0.7284477750976128, 
             1.2391529989719314`}, {-0.5849976813474842, 
             1.1565108752476034`}, {-0.5681922976985564, 
             1.1365957510806342`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAA7w3QYkyc5j9EG0ZqqszvPwQW3KFy
weU/EZ6FK04w8D+xej8RO9HkP8qijn11dfA/Wu8E+FGz4z9IlJRle7XwP3HW
kX5NWOI/RBHK3Wvt8D86IeP2YJ/gP0ILmPUbGfE/mjWW4wxl3z9WmsV/pibx
P2jdbM4nPd0/cHbHQ4Yw8T/gfuSfD7LaP891DY0UNvE/72EmmB9A2T+TtEEY
BDfxP/W+Dyaurtc/I2qQvXE28T9YtkVn6ZHTP35+LVkmLvE/w2StW+pEzT9c
9kibNxvxP0ZXu13dqcc/mQ6fjJUN8T+R8TkYGqDBPyEt814E/fA/f+Hi/KGl
tj+EyfkI1enwP1a7C9/6Nq8/DteqdJ/e8D9A5DopbcCgP415vHup0vA/qDKm
13yybb/DxoUr48LwP/easjXbu5y/6eAKhd238D82l2z5JL6qv18JGK+SrPA/
iKO6hvaNtL9YdVuQuZ7wP/TfwuNgGL+/fbSnhc2I8D9ik6Vf9CXFv5F5TpXg
cPA/wwr0Rfjfyr8LpljpQFfwP6uZ3fv16cu/AY5KlmZS8D9yNt8o
             "]]}, 
           {Arrowheads[{{0.0040444767062358476`, 1.}}], 
            ArrowBox[{{-0.24142659971112762`, 
             1.0166057733462646`}, {-0.2485347345311331, 
             1.0155046058819477`}, {-0.28716180505776606`, 
             1.0087860938634359`}, {-0.32707513806119515`, 
             1.0015337500578951`}, {-0.3802059981463093, 
             0.9912257433907967}, {-0.4289280499494352, 
             0.9804106578523998}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.1391434450951277`}, \
{-5.598825336194745, -2.138615571581974}, {-5.435194437462172, \
-2.1368514658458353`}, {-5.270855485611483, -2.1347221028658443`}, \
{-5.105744854895294, -2.132152579251101}, {-4.93988007168904, \
-2.129077622310422}, {-4.773278662368155, -2.1254319593526234`}, \
{-4.712508504795108, -2.1238768837663606`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688904238811279, -2.1232728633190057`}, \
{-4.605958153308074, -2.1211503176865207`}, {-4.437936070884229, \
-2.116167424620931}, {-4.269229941472053, -2.11041800746467}, \
{-4.09985729144698, -2.1038367935265536`}, {-3.9591680263863256`, \
-2.097678441460522}, {-3.8178358569539927`, -2.090800373683006}, \
{-3.7451578865840953`, -2.086899585424913}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7215798299065965`, -2.085634098700832}, \
{-3.6759251527099615`, -2.0831837106695033`}, {-3.533492113069863, \
-2.0747780960337954`}, {-3.390701722588373, -2.065620771795441}, \
{-3.2476064382751835`, -2.055667260136848}, {-3.104148803241478, \
-2.0448352609511757`}, {-2.9603176401346554`, -2.0330583993060025`}, \
{-2.8161439989290646`, -2.0202741111217946`}, {-2.7796748210581037`, \
-2.0167832237762076`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7561702641950063`, -2.014533330444163}, \
{-2.6717095094389784`, -2.00644861350813}, {-2.5271467948093274`, \
-1.9915781409189541`}, {-2.382632772965702, -1.9756689194373946`}, \
{-2.2383164063712315`, -1.9587749362465603`}, {-2.0944676259970936`, \
-1.9409200882713582`}, {-1.9514847037963077`, -1.9220943281508607`}, \
{-1.8183264800137118`, -1.903509641588851}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7949575490676093`, -1.9001315357029525`}, \
{-1.6694209174089434`, -1.8816232148657408`}, {-1.530868389066625, \
-1.8600916583029172`}, {-1.3949590583031544`, -1.8378365160474415`}, \
{-1.262380486677624, -1.8149968974056423`}, {-1.1023443706684553`, \
-1.7858368563669194`}, {-0.9492659082998818, -1.756344062300976}, \
{-0.8644226534557453, -1.7392163422714708`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.841277571953938, -1.7345439322283709`}, \
{-0.8042778083022845, -1.7270746101927232`}, {-0.668062567032193, \
-1.6985757022528791`}, {-0.5410221874902273, -1.6714657752107722`}, \
{-0.42305844450760777`, -1.6461998352193432`}, {-0.2128113236711215, \
-1.6024134282943845`}, {-0.0823537080395025, -1.5782250599113028`}, {
             0.03923653587646961, -1.5595488424055173`}, {
             0.08552620188475754, -1.5544147501083407`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.10899428936393482`, -1.5518118510696062`}, {
             0.15668369879082514`, -1.5465225100414886`}, {
             0.19542765578965718`, -1.54347378284422}, {
             0.23434206762118806`, -1.5410585413601512`}, {
             0.2830670078363038, -1.5389404535126834`}, {
             0.44940484271333925`, -1.5384604924357443`}, {
             0.5700821892458501, -1.5431372485787693`}, {
             0.7028213276835824, -1.5515300866845037`}, {
             0.7204493751153513, -1.5528322625004745`}, {
             0.7383083032212472, -1.5541854902356953`}, {
             0.7955146374598803, -1.5589263428563236`}, {
             0.8549854181103144, -1.564133010682737}, {
             1.0512935524685227`, -1.5815168368869228`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.074811392382414, -1.58362326461936}, {
             1.290059105616502, -1.603050009180957}, {
             1.4126414475911169`, -1.613977663770881}, {
             1.5393762645280171`, -1.624833714686196}, {
             1.6702635564272028`, -1.6356181619269021`}, {
             1.805303323288674, -1.6463310054929994`}, {
             1.9457879151427921`, -1.6571354303869172`}, {
             2.0160018835218367`, -1.6621866072509528`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.039553012723937, -1.6638808701119459`}, {
             2.0843940151508416`, -1.66710672159489}, {
             2.2261187100968867`, -1.6768758611263106`}, {
             2.3704450599687834`, -1.6863775749802072`}, {
             2.55320411510556, -1.6978432948473128`}, {
             2.7380842728694947`, -1.7089034529371583`}, {
             2.9240444258148397`, -1.7195109150531596`}, {
             2.9821901984205352`, -1.7226706951602908`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.005767404216826, -1.7239519368141263`}, {
             3.1100434664958456`, -1.7296185469987322`}, {
             3.2958614816543794`, -1.7392532145999453`}, {
             3.481747811853804, -1.7484840694100987`}, {
             3.667365230380612, -1.7573274058234543`}, {
             3.8523765105212977`, -1.765799518234273}, {
             3.9491156344205014`, -1.770077637182549}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.972704572286086, -1.7711208167978372`}, {
             4.036742916739055, -1.7739528008367451`}, {
             4.2205962798837655`, -1.7818602762821631`}, {
             4.403855222821952, -1.7895691816504415`}, {
             4.586438368420137, -1.7971267540214948`}, {
             4.768280333177189, -1.8045462214191852`}, {
             4.91636250514686, -1.8104968068829363`}}]}, 
           {Arrowheads[{{0.015192440002618072`, 1.}}], 
            ArrowBox[{{4.939955457093953, -1.8114448742636073`}, {
             4.949324872810455, -1.8118213781210595`}, {
             5.129504319014182, -1.8189703105875588`}, {
             5.308751003482617, -1.8260111052791241`}, {
             5.490544580080317, -1.8330876840526253`}, {
             5.656854249492381, -1.8394992634107177`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0000992866877597732, 1.}}], 
            ArrowBox[{{1.1594388759779233`, -0.46642186043608347`}, {
             1.1636503020182958`, -0.46848290913310614`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.3099416087549427`, -0.469271555920915}, {
             1.442863460048467, -0.4850770635659358}, {
             1.6178527007577546`, -0.4997426524540304}, {
             1.642509376668608, -0.5015058238652418}, {
             1.6676855086631395`, -0.503239949857659}, {
             1.757023973484906, -0.5085028991389486}, {
             1.8504980701421154`, -0.5134308527136447}, {
             2.0858772182032297`, -0.5245097454368032}, {
             2.2090606026224022`, -0.5294251829921068}, {
             2.2520773386584243`, -0.530982480476338}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.275673873977782, -0.5318367253232421}, {
             2.334729437287081, -0.5339746625227174}, {
             2.46231978428014, -0.5381957045260174}, {
             2.5912677056844524`, -0.542125829499389}, {
             2.815614743575224, -0.548343760198634}, {
             3.041441367114508, -0.5539403845361861}, {
             3.2197850876270815`, -0.5579313479351599}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.2433911707347356`, -0.5584596032244686}, {
             3.2678294174273805`, -0.5590064806127227}, {
             3.4938607356389175`, -0.563632826528921}, {
             3.719153770628678, -0.567888013453865}, {
             3.9433269712762207`, -0.5718406325566389}, {
             4.185117748267388, -0.5758656431212443}, {
             4.187708579420122, -0.5759069231249447}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.211317575870325, -0.5762830879166176}, {
             4.425162914844277, -0.5796903097167918}, {
             4.663462471006888, -0.5833146323432808}, {
             4.90001641675522, -0.5867386110007118}, {
             5.1341420857881355`, -0.5900147012552073}, {
             5.155692852842263, -0.590311416569722}}]}, 
           {Arrowheads[{{0.010113415251755638`, 1.}}], 
            ArrowBox[{{5.17930260817368, -0.5906364804507978}, {
             5.365156811804499, -0.5931953586728902}, {
             5.593060594804308, -0.5962805832537605}, {
             5.656854249492381, -0.5971290521913116}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.00009117195155632894, 1.}}], 
            ArrowBox[{{1.0856860769904035`, 0.4413658912317316}, {
             1.0817434355759994`, 0.44309590118727865`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.267441955692971, 0.46668100376157506`}, {
             1.381233660572781, 0.4827465826714658}, {1.5389320476697828`, 
             0.4980569936650568}, {1.5617745617676368`, 
             0.49993314220956736`}, {1.585215331892346, 0.501782408268986}, {
             1.6504877958123636`, 0.5062553541182699}, {1.7189718707196884`, 
             0.5105199263887537}, {1.8610457789274553`, 0.5186458541393731}, {
             2.0119820821629624`, 0.5259900854437192}, {2.1693635528568413`, 
             0.5326160097863472}, {2.2090398623895373`, 
             0.5340572952583076}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.232636291769179, 0.534914461442753}, {
             2.365213927889797, 0.5397304895234403}, {2.5653077002557607`, 
             0.5460659021590238}, {2.767489231303296, 0.5517610127860785}, {
             2.9710729164447534`, 0.5569240619705207}, {3.175103996289887, 
             0.5616469394244519}, {3.1767276185369577`, 
             0.5616815066940188}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.2003342620101156`, 0.5621840972504002}, {
             3.3790935736777468`, 0.5659899217426257}, {3.5825513288957955`, 
             0.5700120299593445}, {3.7852184507945568`, 0.5737552229897851}, {
             3.99366396336572, 0.5773705762191963}, {4.144647607435888, 
             0.5798403054813434}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.168256442126471, 0.5802264892315079}, {
             4.201087042141509, 0.5807635188816421}, {4.407286077428382, 
             0.5839783617037955}, {4.612059459532797, 0.5870594154123292}, {
             4.8153994266007665`, 0.5900245790451009}, {5.01740898697233, 
             0.5928766592463593}, {5.112632768676312, 
             0.5941868490714839}}]}, 
           {Arrowheads[{{0.01102530394169272, 1.}}], 
            ArrowBox[{{5.136242526977582, 0.5945116971771403}, {
             5.218052686244991, 0.5956373281523644}, {5.417295070016253, 
             0.5983282578993759}, {5.615132689513037, 0.6009614279458384}, {
             5.656854249492381, 0.6015125272590902}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.722565627977844}, \
{-5.54430020707557, -1.721556517033116}, {-5.339745028571303, \
-1.7192087873979047`}, {-5.132357382726032, -1.7163218868541543`}, \
{-4.922137269539756, -1.712895815401864}, {-4.893915962918689, \
-1.7124030065423497`}, {-4.86566848116174, -1.7118957075623074`}, \
{-4.712486783406465, -1.7085109031349917`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688880552724243, -1.707989284199464}, \
{-4.6790049664933555`, -1.7077710666938057`}, {-4.491407498466289, \
-1.702844361938267}, {-4.270766654531026, -1.6963296303504625`}, \
{-4.048698918995653, -1.6883369492579017`}, {-3.8252042918601687`, \
-1.6788663186605841`}, {-3.7450034036193274`, -1.6749623531614244`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7214193351134432`, -1.6738143435595818`}, \
{-3.6002827731245746`, -1.66791773855851}, {-3.3740321354442036`, \
-1.6551265476038601`}, {-3.1465501514743894`, -1.6401280844488149`}, \
{-2.9178368212151318`, -1.6229223490933744`}, {-2.779078134595261, \
-1.611207690279697}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7555498419991786`, -1.6092213215200493`}, \
{-2.6878921446664306`, -1.6035093415375385`}, {-2.5083803784075354`, \
-1.586661341502448}, {-2.329742463073591, -1.5681431705505935`}, \
{-2.151978398664597, -1.5479548286819746`}, {-1.975088185180554, \
-1.5260963158965914`}, {-1.8170297617806919`, -1.504381525088176}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7936374957623984`, -1.5011677883432701`}, \
{-1.7461352176465281`, -1.494641707606657}, {-1.5245655807283942`, \
-1.4601185792801634`}, {-1.3572594810730292`, -1.4307493221396352`}, \
{-1.199473420505012, -1.3995931997084126`}, {-1.053849048555912, \
-1.3671769767086186`}, {-0.9230280147572983, -1.3340274178623766`}, \
{-0.868353513824732, -1.316396850904069}}]}, 
           {Arrowheads[{{0.00293347754118864, 1.}}], 
            ArrowBox[{{-0.8458810118881056, -1.3091502744679522`}, \
{-0.7140358524372821, -1.2666349360162408`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            
            ArrowBox[{{-5.656854249492381, -5.447880167621219}, \
{-5.562552588779967, -5.446288146916713}, {-5.426599747617034, \
-5.443990030280458}, {-5.291347239290225, -5.441700804972593}, \
{-5.156795063799539, -5.439420470993118}, {-5.022943221144973, \
-5.437149028342035}, {-4.889419968633847, -5.43470583937499}, \
{-4.755853563573475, -5.431910266447628}, {-4.7125289810245805`, \
-5.4308895017622225`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688923538978102, -5.430333337104496}, \
{-4.622244005963855, -5.42876230955995}, {-4.488591295804989, \
-5.425261968711955}, {-4.3548954330968765`, -5.4214092439036445`}, \
{-4.2211564178395165`, -5.417204135135017}, {-4.08737425003291, \
-5.412646642406074}, {-3.9535489296770576`, -5.407736765716813}, \
{-3.750325410709744, -5.399287414041916}, {-3.7449793010491663`, \
-5.399027024436409}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721395265809078, -5.397878331644392}, \
{-3.546622621833449, -5.389365790243709}, {-3.342440563048171, \
-5.377971894322195}, {-3.13777923435391, -5.365105726277371}, \
{-2.9330301274452686`, -5.35077136516292}, {-2.778805349100208, \
-5.338853677587197}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7552635401850223`, -5.337034489214037}, \
{-2.7285847340168474`, -5.334972890032522}, {-2.524443054068646, \
-5.317710300886176}, {-2.320605087600664, -5.2989835977238835`}, \
{-2.11710475312418, -5.279014265842421}, {-1.9139759691504723`, \
-5.258023790538568}, {-1.8150904421867917`, -5.247288634609443}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7916163718632168`, -5.244740255559925}, \
{-1.7112187356795405`, -5.236012171812324}, {-1.508833052711384, \
-5.212979409663689}, {-1.2980548355676393`, -5.18837032587676}, \
{-1.0875931747040166`, -5.163664247594308}, {-0.8774480701205146, \
-5.138861174816333}, {-0.8534196124019591, -5.136009750553485}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8299721387600214, -5.133227270877584}, \
{-0.6676195218171338, -5.113961107542834}, {-0.4578993100894966, \
-5.089594871992626}, {-0.24807921523322535`, -5.066393294384524}, \
{-0.038159237248320266`, -5.044356374718527}, {
             0.10880129559737436`, -5.029751095539813}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13229753931016366`, -5.027415984252235}, {
             0.1718606238652184, -5.023484112994635}, {
             0.3822806926599974, -5.004226368828349}, {
             0.5934012936886235, -4.987033001835169}, {
             0.8052224269510959, -4.971904012015095}, {
             1.0177440924474153`, -4.958839399368126}, {
             1.0739792694466277`, -4.955765313111298}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0975583742078752`, -4.954520264474159}, {
             1.1537003635746494`, -4.951658368637809}, {
             1.2890347582942803`, -4.9454727763440145`}, {
             1.42478619477226, -4.94019818090802}, {
             1.5609546730085886`, -4.935834582329825}, {
             1.6975401930032665`, -4.932381980609431}, {
             1.715577694936966, -4.931986786081436}, {
             1.7336211289628547`, -4.931606699039343}, {
             1.8202198619819725`, -4.930201321361174}, {
             1.9070483429622251`, -4.929134968805958}, {
             2.0415781530823893`, -4.928162610570026}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0651895293417026`, -4.927991951619814}, {
             2.1448798864259575`, -4.927415963480337}, {
             2.384157666144576, -4.928082870077415}, {
             2.62463998753154, -4.931014768206678}, {
             2.8660851560003087`, -4.936090737477614}, {
             3.0095361487658563`, -4.940200785274492}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.033138456264903, -4.9408770204825405`}, {
             3.1084319999641417`, -4.943034273335478}, {
             3.3516193478362983`, -4.951568871225523}, {
             3.5130968633653676`, -4.9580150137218295`}, {
             3.6745996699999393`, -4.9649852880680285`}, {
             3.8361277677400123`, -4.972479694264118}, {
             3.9768116590934337`, -4.97946239604051}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.000394172444975, -4.9806416695439975`}, {
             4.159259836536665, -4.989040902205973}, {
             4.320863807593245, -4.998107703951737}, {
             4.482493069755326, -5.007698637547393}, {
             4.644147623022909, -5.01781370299294}, {
             4.805646536639163, -5.028354677705831}, {
             4.943141457459456, -5.037627226792367}}]}, 
           {Arrowheads[{{0.014653741943730857`, 1.}}], 
            ArrowBox[{{4.966699938688583, -5.039215992197649}, {
             4.966808879847257, -5.039223339103523}, {
             5.12763465264719, -5.0504196871860145`}, {
             5.288123855038963, -5.0619437219533046`}, {
             5.448276487022574, -5.073795443405395}, {
             5.608092548598027, -5.085974851542283}, {
             5.656854249492381, -5.089798962167973}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.448184095604056}, {-5.561657503548295, 
             5.446576651257855}, {-5.4256247224455425`, 
             5.444276605953081}, {-5.290293296684252, 
             5.44198533916288}, {-5.155663226264427, 
             5.439702850887251}, {-5.021734511186064, 
             5.437429141126194}, {-4.888134554800035, 
             5.434983145876564}, {-4.754490760457215, 
             5.432183801135214}, {-4.712528954750472, 5.431194235080485}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688923524758367, 
             5.430637559031063}, {-4.6208031281576005`, 
             5.429031106902146}, {-4.487071657901194, 
             5.425525063177358}, {-4.353296349687996, 
             5.421665669960851}, {-4.219477203518005, 
             5.417452927252626}, {-4.085614219391221, 
             5.412886835052681}, {-3.9517073973076453`, 
             5.407967393361017}, {-3.748578186661497, 
             5.399511427600225}, {-3.7449790402073817`, 5.399335938560243}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7213950647548146`, 
             5.398186018915711}, {-3.544972892370759, 
             5.389583935600137}, {-3.340891514435431, 
             5.378184917360752}, {-3.136334052855512, 
             5.365314372882071}, {-2.9316906105110934`, 
             5.35097697995298}, {-2.778805484401099, 5.339155866574857}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755263757683457, 
             5.337335614809843}, {-2.7273512902822628`, 
             5.3351774163623675`}, {-2.5233160921690208`, 
             5.3179156821102325`}, {-2.319585016171368, 
             5.299191777196575}, {-2.1161916178932803`, 
             5.279227187287072}, {-1.913169452938736, 
             5.258243398047397}, {-1.8150902744463506`, 5.247594372030397}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7916162402942597`, 
             5.245045659813879}, {-1.7105185213077345`, 
             5.236240409477551}, {-1.5082388230002755`, 
             5.2132182215775345`}, {-1.2974431603603889`, 
             5.188606776213883}, {-1.0869638294997586`, 
             5.163899268960053}, {-0.8768008304183852, 
             5.1390956998160435`}, {-0.8534187716246511, 
             5.136321271018728}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.829971264166095, 
             5.133539076324404}, {-0.6669541631162684, 
             5.114196068781855}, {-0.45721544941637193`, 
             5.089831221530192}, {-0.24737631114165914`, 
             5.066632003733762}, {-0.03743674829212995, 5.044598415392564}, {
             0.1088028433631151, 5.030069173491609}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.13229915645416743`, 5.027734760404042}, {
             0.1726032391322161, 5.023730456506599}, {0.3830439893067621, 
             5.004477787026591}, {0.5941858404068915, 4.987290066903263}, {
             0.8060287924326046, 4.972167296136617}, {1.0185728453839011`, 
             4.959109474726651}, {1.0739807446018845`, 
             4.9560828064041695`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0975597328602207`, 4.954835550686874}, {
             1.154584990562176, 4.951930927376331}, {1.2899138185811705`, 
             4.945750958461195}, {1.4256593784944744`, 4.940481720735933}, {
             1.5618216703020882`, 4.936123214200544}, {1.6984006940040115`, 
             4.9326754388550285`}, {1.716437622595328, 4.932280856568418}, {
             1.7344804781866545`, 4.931901377751235}, {1.821107399050456, 
             4.930498460756582}, {1.9079640853751383`, 4.92943471679015}, {
             2.041579397203971, 4.928476454296981}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.065190782987043, 4.928307118125116}, {
             2.1469522381722768`, 4.927720741198561}, {2.387398495753524, 
             4.928414788399499}, {2.6290596978662237`, 4.931392154637118}, {
             2.8716926842577184`, 4.936528136155575}, {3.009537491538359, 
             4.940500116085439}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0331396881573505`, 4.94118021026614}, {
             3.1152328148625457`, 4.943545712877994}, {3.3596154496152426`, 
             4.9521678647275005`}, {3.521787356105115, 4.958673652839096}, {
             3.683980982324191, 4.9657052925484475`}, {3.8461963282724723`, 
             4.973262783855556}, {3.9768125097167277`, 
             4.979770639376295}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.000395249283026, 4.9809456320929995`}, {
             4.008433393949958, 4.981346126760419}, {4.1706921793566485`, 
             4.989955321263039}, {4.332972684492544, 4.999090367363416}, {
             4.4952749093576445`, 5.008751265061549}, {4.65759885395195, 
             5.018938014357437}, {4.819762291802002, 5.029552748052241}, {
             4.943144333497521, 5.037897774435184}}]}, 
           {Arrowheads[{{0.014653650558000945`, 1.}}], 
            ArrowBox[{{4.966702503576039, 5.039491146923899}, {
             4.981582996434343, 5.040497598947121}, {5.143060967848973, 
             5.0517725670420734`}, {5.304196206045892, 5.063377652337102}, {
             5.464988711025099, 5.075312854832204}, {5.6254384827865955`, 
             5.087578174527382}, {5.656854249492381, 5.090049616824095}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.5496966943209487`}, \
{-5.589523218758712, -3.548873659558299}, {-5.456875280844836, \
-3.5470924056641375`}, {-5.323869849293734, -3.5451025740215383`}, \
{-5.1905164187775, -3.5428598772636413`}, {-5.0568244839682315`, \
-3.540320028023588}, {-4.922803539538024, -3.5374387389345197`}, \
{-4.788463080158973, -3.5341717226295772`}, {-4.712548680042168, \
-3.5320873789067133`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688945582076624, -3.5314393204486483`}, \
{-4.6538126005031755`, -3.530474691741902}, {-4.518806032458445, \
-3.5262404718048375`}, {-4.383417512561426, -3.5213847563880174`}, \
{-4.247686842457459, -3.5158975601790186`}, {-4.111653823791885, \
-3.5097688978654156`}, {-3.9753582582100435`, -3.5029887841347853`}, \
{-3.8388399473572763`, -3.4955472336747033`}, {-3.745416976001167, \
-3.4900027490936685`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.72184645665234, -3.4886038813505476`}, \
{-3.7021386928789237`, -3.487434261172745}, {-3.5652942964203262`, \
-3.4786398813164867`}, {-3.3936045991765424`, -3.466531973853635}, \
{-3.2217636711625017`, -3.453151841260398}, {-3.049880555410589, \
-3.4385558376780656`}, {-2.8769011692744075`, -3.4221992064075013`}, \
{-2.78050491741059, -3.4125228060118027`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7570109953384487`, -3.4101644508637565`}, \
{-2.704370289046091, -3.404880297783647}, {-2.532015307144675, \
-3.386458226453277}, {-2.3598362235701593`, -3.366932992416393}, \
{-2.1878330383225437`, -3.3463045956729927`}, {-2.016178167856605, \
-3.324818869381587}, {-1.8450440286271208`, -3.302721646700687}, \
{-1.819102606808689, -3.29926883213417}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.795697027055082, -3.2961535392532837`}, \
{-1.674430620634091, -3.28001292763029}, {-1.504337943877515, \
-3.2566927121703984`}, {-1.3537650567505457`, -3.2356452928843757`}, \
{-1.203836211469935, -3.2144860662806947`}, {-1.054553847008322, \
-3.1935357784945793`}, {-0.9059204023383454, -3.1731151756612537`}, \
{-0.8600942415049624, -3.166990111875471}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8366903739405916, -3.1638619820243368`}, \
{-0.7579610390167139, -3.1533391236951323`}, {-0.6107009186001359, \
-3.1343224885106302`}, {-0.5627130375617204, -3.128275463839084}, \
{-0.5147875262254644, -3.12233977766438}, {-0.338039790676367, \
-3.1017169822386395`}, {-0.16172146772241916`, -3.0832185342795744`}, {
             0.014469266444681411`, -3.067026534652701}, {
             0.10194784569217484`, -3.060229502453805}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12548888469683456`, -3.0584003780957443`}, {
             0.19083423563323637`, -3.0533230842235346`}, {
             0.2110083935999122, -3.05189859905004}, {
             0.2311914820729104, -3.050509259041308}, {
             0.27015972922541814`, -3.0480286772737855`}, {
             0.30916377190597577`, -3.0456784757802806`}, {
             0.4704299492601128, -3.0370571790798007`}, {
             0.6328885391759234, -3.0305557334854814`}, {
             0.796539541653408, -3.026174138997322}, {
             0.9613829566925662, -3.0239123956153224`}, {
             1.069089211743227, -3.0236380196439216`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.0927011281267205`, -3.0235778695394426`}, {
             1.127691183848019, -3.02348873422856}, {
             1.295736622674387, -3.024621385726111}, {
             1.46551927317167, -3.027310350107975}, {
             1.6370391353398681`, -3.031555627374152}, {
             1.8101466666790773`, -3.036994144528548}, {
             1.9846923246893944`, -3.043262828575069}, {
             2.0368627271862483`, -3.0453672833201733`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0604555333266505`, -3.046318972217638}, {
             2.160676109370819, -3.050361679513714}, {
             2.3380980207233515`, -3.0582906973444834`}, {
             2.577503215033762, -3.0697596503729883`}, {
             2.8180628389087587`, -3.081793163265545}, {
             3.0038491458173304`, -3.091476296613854}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0274291334077703`, -3.0927052793520815`}, {
             3.0597768923483417`, -3.0943912360221533`}, {
             3.3026453753525113`, -3.107553868642814}, {
             3.5459804840998665`, -3.1210679633885254`}, {
             3.789094414769008, -3.134720422520286}, {
             3.970458416808474, -3.145017802404742}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.994032442877583, -3.1463562747537743`}, {
             4.031987167359936, -3.1485112460380957`}, {
             4.274658741872648, -3.1624404339419545`}, {
             4.516768353779484, -3.176473576355464}, {
             4.75797521855278, -3.1905762634022246`}, {
             4.9369223907179265`, -3.2011298935576984`}}]}, 
           {Arrowheads[{{0.014772546984075692`, 1.}}], 
            ArrowBox[{{4.960493426955946, -3.202520024487556}, {
             4.998279336192538, -3.2047484950822365`}, {
             5.237680706698756, -3.2189902713954996`}, {
             5.416322678978444, -3.2297243558382043`}, {
             5.594393731627333, -3.2405458498589725`}, {
             5.656854249492381, -3.2443889857072867`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.55046323029151}, {-5.552994094032241, 
             3.5491611712014546`}, {-5.420699705336638, 
             3.547331107026179}, {-5.288052985330595, 
             3.5452813848064597`}, {-5.155063705120329, 
             3.5429684209225836`}, {-5.021741635812057, 
             3.5403486317548367`}, {-4.888096548511994, 
             3.5373784336835046`}, {-4.754138214326358, 
             3.5340142430888735`}, {-4.712548941492724, 3.532836598350262}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688946408851664, 
             3.532168267396416}, {-4.619876404361366, 
             3.5302124763512293`}, {-4.485265919866712, 
             3.525864842053727}, {-4.3502815511308235`, 
             3.5208865788875694`}, {-4.214963052818022, 
             3.5152693983951138`}, {-4.079350179592629, 
             3.5090050121187177`}, {-3.9434826861189642`, 
             3.5020851316007384`}, {-3.8074003270613486`, 
             3.4945014683835334`}, {-3.745418398020652, 
             3.4907460313991385`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.72184962650919, 
             3.4893180178219425`}, {-3.6711428570841016`, 
             3.48624573400946}, {-3.534750030851546, 
             3.4773096400208763`}, {-3.3646987252133878`, 
             3.465109372869696}, {-3.1945068240078442`, 
             3.4516612670699987`}, {-3.0242823831751204`, 
             3.4370232588802136`}, {-2.8529808619599137`, 
             3.420635297802186}, {-2.7805045807845765`, 
             3.4132890949963017`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7570129543655426`, 
             3.4109079814910874`}, {-2.6821330528484433`, 
             3.403318147497005}, {-2.5114688159901997`, 
             3.3849269673185964`}, {-2.340988151385183, 
             3.36546175726696}, {-2.170691059033394, 
             3.344922517342096}, {-2.0007454797223985`, 
             3.3235549228999006`}, {-1.8313193542397637`, 
             3.301604649296271}, {-1.8191089532887952`, 
             3.2999757237767757`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7957043060758786`, 
             3.2968534326028007`}, {-1.66241268258549, 
             3.2790716965312074`}, {-1.4940254647595768`, 
             3.255956064604709}, {-1.3450550596562865`, 
             3.2351191016515513`}, {-1.1967183855037786`, 
             3.2141762260881275`}, {-1.0490153728320248`, 
             3.1934475623631746`}, {-0.9019459521709963, 
             3.1732532349254288`}, {-0.8601049413134428, 
             3.1676648691925817`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8367007765101575, 
             3.164538964012187}, {-0.7555356451381714, 
             3.153698393252425}, {-0.6098099733510286, 
             3.1348881868216987`}, {-0.5618496151694633, 
             3.128846367223032}, {-0.513951059122989, 
             3.1229163137648284`}, {-0.33721646596432386`, 
             3.10230546235707}, {-0.16091036042762885`, 3.08381833093493}, {
             0.015269917397098043`, 3.0676373168424402`}, {
             0.10193775341558736`, 3.060908360498353}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12547889898432996`, 3.059080608149857}, {
             0.19162702741985854`, 3.053944817423632}, {0.2118043053824504, 
             3.052521309295349}, {0.23199052260628225`, 
             3.0511329446068207`}, {0.27098409858550454`, 
             3.0486530739615025`}, {0.3100135333137299, 
             3.0463037044832513`}, {0.47132155899853495`, 
             3.037689706509926}, {0.6338231052128841, 3.0311956813431777`}, {
             0.7975181719567774, 3.0268216289830066`}, {0.962406759230215, 
             3.024567549429412}, {1.0690785719924571`, 
             3.0243007063875678`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0926904911127846`, 3.024241640396668}, {
             1.128760722825363, 3.0241514095277915`}, {1.296851918534388, 
             3.0252911761235417`}, {1.46668034635729, 3.0279868492166626`}, {
             1.638246006294069, 3.032238428807154}, {1.8113988867837425`, 
             3.037682791884236}, {1.9859889762653284`, 3.0439568154371273`}, {
             2.036852503840875, 3.046009442680828}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0604452933645048`, 3.046961543426479}, {
             2.1620162747388276`, 3.0510604994658284`}, {2.339480782204239, 
             3.058993843970339}, {2.57894392550981, 3.0704681973477306`}, {
             2.8195593787366966`, 3.082506753129965}, {3.003839181014884, 
             3.0921128054697498`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.027419159042967, 3.0933419716632686`}, {
             3.0613271418848984`, 3.0951095113170415`}, {3.304247214954415, 
             3.1082764719089604`}, {3.5476318717722095`, 
             3.1217946755608663`}, {3.7907933861652436`, 
             3.1354511629279043`}, {3.970448544976517, 3.1456525229249}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9940225635906037`, 3.146991126570069}, {
             4.033731758133519, 3.1492459340100742`}, {4.2764469876770335`, 
             3.163178988807376}, {4.518598798159207, 3.177216128813864}, {
             4.759846912943463, 3.191323155523594}, {4.936912349454957, 
             3.201767506057699}}]}, 
           {Arrowheads[{{0.014772764930932842`, 1.}}], 
            ArrowBox[{{4.960483372406745, 3.2031578622503374`}, {
             5.000191332029798, 3.205500068936566}, {5.239632055418213, 
             3.2197468690527793`}, {5.418411770831476, 3.230491510140469}, {
             5.596619382202165, 3.2413238401402658`}, {5.656854249492381, 
             3.2450310862785705`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.024482629283799}, \
{-5.55789225955656, -4.023137520000415}, {-5.409571116152852, \
-4.0209895299196905`}, {-5.255865680613877, -4.01842725436189}, \
{-5.101465662100033, -4.015305317746731}, {-4.9463710606113205`, \
-4.0116237200742155`}, {-4.790581876147739, -4.007382461344343}, \
{-4.712590246766592, -4.004989679250306}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688989358460347, -4.004265604328539}, \
{-4.6340981087092885`, -4.002581541557113}, {-4.47691975829597, \
-3.9972209607125264`}, {-4.319046824907781, -3.991300718810582}, \
{-4.160479308544724, -3.984820815851281}, {-3.9411261124074883`, \
-3.97453495646729}, {-3.745413161919166, -3.9636588250694853`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.721837544334201, -3.9623486843046627`}, \
{-3.7212718343423825`, -3.9623172467519168`}, {-3.500916474349406, \
-3.9481676867051614`}, {-3.280060032428559, -3.932086276327023}, \
{-3.059006803677305, -3.914067646428057}, {-2.8380610831931037`, \
-3.894106427818819}, {-2.780313591329129, -3.888378750881597}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.756816891469328, -3.886048233978719}, \
{-2.6172228709759557`, -3.872202620499308}, {-2.3964921670258628`, \
-3.8483562244695255`}, {-2.17609465423231, -3.822974351892308}, \
{-1.9562560154847857`, -3.7964641149304934`}, {-1.8184462473652305`, \
-3.779094207370246}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7950196076651146`, -3.776141451759445}, \
{-1.736976250783289, -3.768825513584082}, {-1.5182553601278193`, \
-3.740058547853074}, {-1.3527178404178568`, -3.7179203041437447`}, \
{-1.1876314616515546`, -3.6960211321048972`}, {-1.0229962238289136`, \
-3.6743610317365314`}, {-0.858812126949934, -3.652940003038647}, \
{-0.8586145314630979, -3.6529149885291035`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8351894992354869, -3.649949507375639}, \
{-0.6949763020308937, -3.632199282328475}, {-0.5313858800880722, \
-3.612580105923246}, {-0.3680408611214695, -3.5940824738229598`}, \
{-0.20494124513108547`, -3.5767063860276163`}, {-0.04179409170168849, \
-3.56077365166718}, {0.1037104246460061, -3.5481644673163553`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12723915185487636`, -3.5461862559890975`}, {
             0.28552164871984137`, -3.534203670640919}, {
             0.44969023571197453`, -3.5235664239750943`}, {
             0.6633968004004946, -3.512458350271972}, {
             0.8788634978256367, -3.5043996288303707`}, {
             1.070431624368171, -3.4999819633501303`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0940373415729048`, -3.499437602636718}, {
             1.0960903279874004`, -3.4993902596502915`}, {
             1.3150772908857853`, -3.497430242731734}, {
             1.3927694923923783`, -3.497426775763906}, {
             1.470756202534151, -3.497720286295536}, {
             1.646563051322074, -3.4993276271487304`}, {
             1.8236387894268358`, -3.5021771833084734`}, {
             2.001983416848437, -3.5062689547747654`}, {
             2.038413924573841, -3.5073508324077176`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0620155125895288`, -3.5080517293144746`}, {
             2.181596933586877, -3.511602941547606}, {
             2.2052295780895834`, -3.512383725022003}, {
             2.2288808725244094`, -3.5131784636525882`}, {
             2.3313146523714776`, -3.5169207183283513`}, {
             2.43405528729473, -3.520910537590191}, {
             2.6628028946891726`, -3.530202848251289}, {
             2.8924507370048764`, -3.540348417693405}, {
             3.005728996068056, -3.545752618534217}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0293141645487416`, -3.5468778034407302`}, {
             3.1229988142418406`, -3.551347245916539}, {
             3.3544471264000655`, -3.56319933292069}, {
             3.5863618305940888`, -3.5757081515242826`}, {
             3.8183090839384484`, -3.58867717454574}, {
             3.972426654109749, -3.597598985323958}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9959991818926746`, -3.5989635904900648`}, {
             4.050288886433145, -3.602106401985062}, {
             4.282301238078177, -3.6159958338422493`}, {
             4.514947647435531, -3.6305709463766864`}, {
             4.744819565987292, -3.6445540407851897`}, {
             4.938717281250892, -3.6566083859627145`}}]}, 
           {Arrowheads[{{0.014738161690284956`, 1.}}], 
            ArrowBox[{{4.9622837767158305`, -3.6580734814671807`}, {
             4.974242826839803, -3.6588169586040498`}, {
             5.202976826568268, -3.6732695093295122`}, {
             5.447201162229506, -3.688923876829868}, {
             5.656854249492381, -3.7025732458327525`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.969621373006802}, \
{-5.590626355747438, -4.968567697120147}, {-5.4490323972759995`, \
-4.9661667291545575`}, {-5.307126808152409, -4.96361257393353}, \
{-5.164909588376668, -4.960905231457066}, {-5.022380737948778, \
-4.958044701725164}, {-4.8795402568687365`, -4.955030984737825}, \
{-4.7363881451365435`, -4.9518640804950484`}, {-4.712554969771366, \
-4.95126869206689}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68895034115689, -4.950679013078978}, \
{-4.578140000061594, -4.947910804739233}, {-4.419703790187295, \
-4.943210002631137}, {-4.261079515513647, -4.937761674170762}, \
{-4.102267176040649, -4.931565819358107}, {-3.943266771768301, \
-4.924622438193172}, {-3.7840783026966047`, -4.9169315306759565`}, \
{-3.745180963659769, -4.914872051684982}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7216019973984964`, -4.913623627323666}, \
{-3.6247017688255583`, -4.9084930968064615`}, {-3.4651371701551614`, \
-4.899307136584687}, {-3.305525539051112, -4.889281676933732}, \
{-3.1460079078791066`, -4.8783247447766955`}, {-2.9865842766391446`, \
-4.866436340113578}, {-2.8272546453312257`, -4.85361646294438}, \
{-2.7793484845717233`, -4.849479358940007}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7558240487807013`, -4.8474478240399295`}, \
{-2.6680190139553503`, -4.839865113269101}, {-2.508877382511519, \
-4.825182291087741}, {-2.349829750999731, -4.8095679964003}, \
{-2.1908761194199866`, -4.793022229206778}, {-2.032088305748104, \
-4.77584126121221}, {-1.873538127959902, -4.758321364121633}, \
{-1.8162258234505437`, -4.75185611208113}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7927626489257704`, -4.749209292375107}, \
{-1.71522558605538, -4.740462537935046}, {-1.5571506800345385`, \
-4.7222647826524495`}, {-1.3993134098973772`, -4.703728098273843}, \
{-1.241713775643896, -4.684852484799227}, {-1.0843517772740952`, \
-4.665637942228601}, {-0.9272274147879744, -4.6460844705619655`}, \
{-0.8698636497863049, -4.638878287067407}, {-0.8549784126714829, \
-4.637008573546591}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8315505134049495, -4.634065828349786}, \
{-0.8125308745111486, -4.631676798485736}, {-0.6668777494649871, \
-4.613694489480208}, {-0.5212129891843555, -4.596331645288773}, \
{-0.375536593669254, -4.579588265911428}, {-0.22984856291968245`, \
-4.563464351348174}, {-0.21250088943737122`, -4.561581366778057}, \
{-0.1951532045974458, -4.559707937514451}, {-0.15735939684866812`, \
-4.555693253425829}, {-0.11956591523134295`, -4.551724905839311}, {
             0.05962161215530071, -4.5337220567507615`}, {
             0.1070709565924539, -4.529383299082475}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13058485163431155`, -4.5272331936672305`}, {
             0.2392519779672409, -4.517296695423466}, {
             0.419325182204478, -4.502448821857425}, {
             0.5998412248670119, -4.489178436052637}, {
             0.7810069380798418, -4.477598110383078}, {
             0.9630291539679667, -4.4678204172227245`}, {
             1.0727765351343221`, -4.463034502120181}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0963661086584613`, -4.462005796970301}, {
             1.145907872531387, -4.459845356571576}, {
             1.3296430937701023`, -4.453672928429633}, {
             1.5143015103662854`, -4.449204663978513}, {
             1.6999498150021082`, -4.446342094399836}, {
             1.8865880076775714`, -4.445085219693602}, {
             2.040614475972282, -4.445371570958648}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0642264281656613`, -4.445415468039816}, {
             2.0742160883926744`, -4.445434039859809}, {
             2.259294579580866, -4.447076560502761}, {
             2.4449795128660092`, -4.449741776366854}, {
             2.631270888248104, -4.453429687452088}, {
             2.8181687057271514`, -4.458140293758464}, {
             3.0056729653031504`, -4.463873595285982}, {
             3.00849440976323, -4.463974927477236}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.032091189069471, -4.4648224059186745`}, {
             3.1937836669761013`, -4.4706295920346415`}, {
             3.382500810746004, -4.478408284004443}, {
             3.5718243966128584`, -4.4872096711953855`}, {
             3.761367799301079, -4.496755821077669}, {
             3.950744393535083, -4.506768801121492}, {
             3.975559144919404, -4.5081432220254065`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.9991350032160193`, -4.509449024044889}, {
             4.13995417931487, -4.517248611326854}, {
             4.328997156640439, -4.528195251693758}, {
             4.51787332551179, -4.5396087222222}, {
             4.7065826859289235`, -4.551489022912182}, {
             4.895125237891839, -4.563836153763703}, {
             4.941852249706127, -4.567014684589874}}]}, 
           {Arrowheads[{{0.014679664794888742`, 1.}}], 
            ArrowBox[{{4.965409803031559, -4.568617149770649}, {
             5.083500981400537, -4.576650114776765}, {
             5.103410013198209, -4.578035165951101}, {
             5.123314357070086, -4.579424758287816}, {
             5.143213953652763, -4.580818887800873}, {
             5.1631087432972205`, -4.582217550147579}, {
             5.1829986667672046`, -4.583620741291399}, {
             5.2227686210957005`, -4.586436170601755}, {
             5.262518553260059, -4.589269676906977}, {
             5.3022479900353, -4.59212122592602}, {
             5.497883676698986, -4.6064135771715025`}, {
             5.656854249492381, -4.618344475881155}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.970219379747241}, {-5.631331343685838, 
             4.969854225635865}, {-5.48960115848603, 
             4.967728149742534}, {-5.347569266883209, 
             4.9653554189626625`}, {-5.205235668877376, 
             4.962736033296252}, {-5.062600364468529, 
             4.959869992743301}, {-4.91966335365667, 
             4.956757297303812}, {-4.776424636441798, 
             4.953397946977783}, {-4.7125592222400705`, 4.951793527743746}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688954676585802, 
             4.951200537194294}, {-4.632884212823915, 
             4.949791941765214}, {-4.48904208280302, 
             4.945939281666106}, {-4.340605640807286, 
             4.941480162142819}, {-4.19205645120131, 
             4.936297054285188}, {-4.043394513985089, 
             4.930389958093211}, {-3.8946198291586254`, 
             4.92375887356689}, {-3.745732396721918, 
             4.916403800706225}, {-3.7451490259715396`, 
             4.9163721692814155`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721571666325485, 
             4.915093761890652}, {-3.5967322166749662`, 
             4.908324739511214}, {-3.447619289017772, 
             4.89952168998186}, {-3.298393613750334, 
             4.889994652118161}, {-3.1491631688356994`, 
             4.879705823846379}, {-3.000035932236914, 
             4.868617403092777}, {-2.851011903953978, 
             4.856729389857356}, {-2.7793377676647832`, 4.850622969132825}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7558110051078915`, 
             4.848618559761516}, {-2.7020910839868915`, 
             4.844041784140114}, {-2.553273472335655, 
             4.830554585941053}, {-2.4045590690002685`, 
             4.816267795260172}, {-2.2559478739807313`, 
             4.801181412097471}, {-2.107439887277044, 
             4.785295436452951}, {-1.9590868111462307`, 
             4.768874954553193}, {-1.8162411468624235`, 4.752782230672551}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7927816137962005`, 
             4.750103397032385}, {-1.6630004973743, 
             4.735225730667721}, {-1.5152672597331822`, 
             4.717996988682005}, {-1.367740634921963, 
             4.700498826667637}, {-1.2204206229406427`, 
             4.682731244624615}, {-1.073307223789221, 
             4.664694242552941}, {-0.9264004374676975, 
             4.646387820452615}, {-0.8690615217531049, 
             4.639184852169582}, {-0.8550532881658054, 
             4.637425390320847}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.831625369769258, 
             4.634482797426667}, {-0.8117534563334496, 
             4.631986845789812}, {-0.666109747417396, 
             4.614007631080073}, {-0.5204542424388945, 
             4.5966481878830745`}, {-0.37478694139794516`, 
             4.579908516198817}, {-0.2291078442945479, 
             4.563788616027299}, {-0.2117633437104047, 
             4.561906357638194}, {-0.19441883226958456`, 
             4.560033650553475}, {-0.15664824895581286`, 
             4.556022223522875}, {-0.11887799325062066`, 4.552057072808883}, {
             0.06016951745197818, 4.5340714264891755`}, {0.10699503008103778`,
              4.529790292648025}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.13050895156806575`, 4.527640476460988}, {
             0.2396595981573444, 4.51766111904106}, {0.4195922488654783, 
             4.502826150464536}, {0.5999674695763799, 4.489566520759602}, {
             0.7809915120270758, 4.477994421025858}, {0.9628706279545922, 
             4.468222042362906}, {1.0726998711357982`, 
             4.463430213574082}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0962894227432092`, 4.462401005967495}, {
             1.1456048173589293`, 4.460249384770743}, {1.329194080240087, 
             4.4540764482493715`}, {1.5137049624669594`, 4.449605126008921}, {
             1.699204009908441, 4.446737311259524}, {1.8856912225645317`, 
             4.4454730040011805`}, {2.0405376029335986`, 
             4.445753168409179}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0641495572837134`, 4.445795889648102}, {
             2.073166600435232, 4.44581220423389}, {2.2582182477825956`, 
             4.447445116041118}, {2.4438767092158136`, 4.450101048411587}, {
             2.6301419847348866`, 4.453780001345297}, {2.817014074339815, 
             4.458481974842249}, {3.0044929780305987`, 4.464206968902441}, {
             3.0084176727370484`, 4.464347776495833}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0320144839084, 4.4651943672350605`}, {
             3.1925786958072373`, 4.470954983525875}, {3.3812712276697305`, 
             4.47872601871255}, {3.5705705736180797`, 4.4875200744624655`}, {
             3.7600902604098114`, 4.49705922386895}, {3.949443814802452, 
             4.507065540025332}, {3.975482796700408, 4.508507067315737}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.999058690003727, 4.509812237146324}, {
             4.138631236796003, 4.517539022931611}, {4.327652526390464, 
             4.528479672587786}, {4.516507683585834, 4.539887488993859}, {
             4.705196708382115, 4.551762472149828}, {4.8937196007793045`, 
             4.5641046220556944`}, {4.941776230216366, 
             4.567372742530235}}]}, 
           {Arrowheads[{{0.014681276873479983`, 1.}}], 
            ArrowBox[{{4.96533381193304, 4.568974790281832}, {
             5.082076360777404, 4.576913938711457}, {5.101983994291511, 
             4.578298555731432}, {5.121886944894413, 4.579687713823979}, {
             5.141785153233445, 4.581081409002886}, {5.1616785596671875`, 
             4.5824796369288725`}, {5.18156710496707, 4.583882393563034}, {
             5.221334313061496, 4.586696953681992}, {5.261081519236287, 
             4.589529590455294}, {5.300808250325041, 4.592380269604283}, {
             5.49645719332425, 4.606670585877384}, {5.656854249492381, 
             4.618706759799756}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.008099726375872, -5.656854249492381}, \
{-0.9795268523707485, -5.653576581498008}, {-0.7688075462176986, \
-5.629587157399044}, {-0.5582941577164477, -5.60580408506696}, \
{-0.3479866868669961, -5.582227364501756}, {-0.13765617437386354`, \
-5.559388633701768}, {-0.0694185041141174, -5.552399329049592}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.04592940248281066, -5.549993436722345}, {
             0.07292633905842894, -5.537819530665327}, {
             0.2837608534298821, -5.517520055392435}, {
             0.49484736874049595`, -5.498490207883092}, {
             0.7064243168844699, -5.481078448238833}, {
             0.8948841516712496, -5.4673680273999254`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9184339079219176, -5.4656547866491}, {
             0.9187301297560034, -5.4656332365611915`}, {
             1.1317648073550965`, -5.452154572850169}, {
             1.3455283496817496`, -5.440642457105765}, {
             1.424501338841789, -5.436912621569057}, {
             1.5036077354667343`, -5.433480882404047}, {
             1.626481081820938, -5.428730817725075}, {
             1.749605074475341, -5.424662362027204}, {
             1.8618134264509538`, -5.4215820491549405`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8854182350853692`, -5.421003328612634}, {
             1.9966049986847456`, -5.4185702775747675`}, {
             2.0130501521601096`, -5.418256069280364}, {
             2.029503427715468, -5.417954157726912}, {
             2.12556127849218, -5.416679470917321}, {
             2.221857619689492, -5.415808161670046}, {
             2.4416823988493186`, -5.414770350873192}, {
             2.6623012002672986`, -5.415627774301589}, {
             2.829836104749314, -5.417710608662395}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.8534462732165946`, -5.418004135974211}, {
             2.883714023943432, -5.418380431955238}, {
             3.1059208698777194`, -5.423028323834138}, {
             3.3282122605326214`, -5.429289981270026}, {
             3.5498787183705978`, -5.436883935594641}, {
             3.770920243391649, -5.445810186807981}, {
             3.7974479599916564`, -5.447044830053564}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.821034421213415, -5.448142582471299}, {
             3.991336835595775, -5.456068734910048}, {
             4.211889557573458, -5.467534443125879}, {
             4.433339471915181, -5.480082174680514}, {
             4.655686578620944, -5.493711929573952}, {
             4.764024414959536, -5.500851382760509}}]}, 
           {Arrowheads[{{0.01845914767573325, 1.}}], 
            ArrowBox[{{4.78758530329754, -5.502404043077603}, {
             4.878930877690747, -5.508423707806195}, {
             5.0852757212988156`, -5.522938291631008}, {
             5.296424768760146, -5.538669842925104}, {
             5.512378020074737, -5.555618361688482}, {
             5.656854249492381, -5.567506888644174}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0089560008983456`, 
             5.656854249492381}, {-0.9786753601164679, 
             5.653380302611041}, {-0.7679149315097106, 
             5.629385060062039}, {-0.5573601070305635, 
             5.60559765563083}, {-0.3470108866790269, 
             5.582018089317415}, {-0.13663801464245096`, 
             5.559178247874396}, {-0.07027658274931613, 5.552382789989697}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.04678742115984917, 5.54997748311529}, {
             0.07398776489181486, 5.537610018054375}, {0.2848664519237697, 
             5.517313399857352}, {0.4959980464534143, 5.498288393283329}, {
             0.7076211040170308, 5.480883260303831}, {0.8940243697863156, 
             5.467332683199293}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9175742195196654, 5.465620727921605}, {
             0.9199741801509019, 5.465446262890388}, {1.133057274855028, 
             5.451977401042997}, {1.3468703881294086`, 5.440476674761661}, {
             1.4258886845955496`, 5.4367501445911275`}, {1.5050403888414186`, 
             5.433321973534767}, {1.627920061111772, 5.42858030462592}, {
             1.7510508845685075`, 5.424520257536178}, {1.8609516797053482`, 
             5.421510971741982}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.8845562117077042`, 5.420921012062466}, {
             1.9980659850411253`, 5.418445028814008}, {2.0145124302348947`, 
             5.418131938083634}, {2.030966990130886, 5.417831141749324}, {
             2.127071060956911, 5.416562488683555}, {2.223413540269896, 
             5.415697443614149}, {2.443296838150251, 5.414674414751834}, {
             2.6639729259547815`, 5.415546809939548}, {2.8289739554213083`, 
             5.417608919199723}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.852584104670196, 5.417903988312672}, {
             2.8854418036834866`, 5.418314629177291}, {3.1077034713363663`, 
             5.422977872465062}, {3.3300451732244176`, 5.429254636886999}, {
             3.5517541536586377`, 5.436863019527239}, {3.7728304126390264`, 
             5.4458030203857835`}, {3.7965867935687325`, 
             5.446909954607092}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.82017319603897, 5.448008968641641}, {
             3.9932739501655834`, 5.456074639462631}, {4.213852763925315, 
             5.467552764060796}, {4.435334851605229, 5.480112281483293}, {
             4.657720213205325, 5.4937531917301206`}, {4.763163934143677, 
             5.500705513387637}}]}, 
           {Arrowheads[{{0.01847739114947491, 1.}}], 
            ArrowBox[{{4.786724769828132, 5.502258972491134}, {
             4.881008848725603, 5.508475494801279}, {5.08707219356009, 
             5.522975835014565}, {5.297932991679937, 5.538689878122199}, {
             5.513591243085146, 5.555617624124181}, {5.656854249492381, 
             5.567406833721271}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.0831123196625994`}, \
{-5.524045081206728, -3.081420336058891}, {-5.329310067313333, \
-3.078371402289177}, {-5.131182663703945, -3.074711232289594}, \
{-4.9296628703785625`, -3.0704398260601415`}, {-4.726058251140839, \
-3.065245381190906}, {-4.712561169922236, -3.0648208005301654`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6889608509641185`, -3.064078400091535}, \
{-4.521676369794427, -3.0588160952719736`}, {-4.316517226339328, \
-3.0511519683033446`}, {-4.1105808207755405`, -3.0422530002850188`}, \
{-3.9039135256186426`, -3.03185407074987}, {-3.7454330883449645`, \
-3.0225570318488106`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.721861620199787, -3.021174243789472}, \
{-3.6965617133842112`, -3.019690059230772}, {-3.488525384072247, \
-3.0057609657277244`}, {-3.279804537682749, -2.990066790240728}, \
{-3.0706424134713255`, -2.9724953890042958`}, {-2.8612822506935824`, \
-2.9529346182529417`}, {-2.7805547134118633`, -2.9446329161930174`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.757066590240924, -2.9422174900933524`}, \
{-2.6517240493495207`, -2.931384477986666}, {-2.4419678094391393`, \
-2.907844968205468}, {-2.2325806064396234`, -2.882631758611602}, \
{-2.0241295158281587`, -2.85606051890732}, {-1.8195033752743528`, \
-2.8285200553726138`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7961223470107697`, -2.825226010313132}, \
{-1.6100356717693811`, -2.798843949167512}, {-1.4050317520183941`, \
-2.769121311893431}, {-1.2022416120481099`, -2.739886030031827}, \
{-1.0016652518585287`, -2.7111381035827002`}, {-0.8612114133929437, \
-2.6911277484484555`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8378354651874366, -2.6877973942886686`}, \
{-0.8033026714496503, -2.6828775325460503`}, {-0.749402878703633, \
-2.675278777808597}, {-0.695687647457764, -2.6678222721197393`}, \
{-0.5125599691431973, -2.6433737596628437`}, {-0.3313422126370212, \
-2.6211746620121446`}, {-0.15185293659685978`, -2.601904934685411}, {
             0.026686716091732583`, -2.585734611730194}, {
             0.04611235546214436, -2.584139603390403}, {
             0.06554347155168057, -2.5825870221692795`}, {
             0.09925899615871267, -2.5800966742426836`}, {
             0.10028420254226884`, -2.580024875616248}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12383850317480441`, -2.5783752892898324`}, {
             0.1329973930674516, -2.5777338616470526`}, {
             0.3360628258676698, -2.5658245621612394`}, {
             0.540834935645656, -2.558419840096567}, {
             0.7483163610743861, -2.5552538081188865`}, {
             0.959509740826836, -2.5560605788940474`}, {
             1.0677669385713942`, -2.558161973567905}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0913744844208366`, -2.5586202227388095`}, {
             1.1748797665380943`, -2.5602411547298094`}, {
             1.3948911298432496`, -2.5671965379339334`}, {
             1.5673648056669687`, -2.5740458816391643`}, {
             1.742140675569596, -2.5817364963003944`}, {
             1.9192187395511324`, -2.5902683819176233`}, {
             2.035060030136061, -2.59632143684149}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.058639854184806, -2.5975535533807785`}, {
             2.0985989976115778`, -2.599641538490851}, {
             2.279728902722762, -2.60952373858338}, {
             2.4620559078565143`, -2.619582754758512}, {
             2.645580013012835, -2.629818587016247}, {
             2.8303012181917246`, -2.640231235356585}, {
             3.001657327797518, -2.6500768193339663`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0252312775169967`, -2.651416489022106}, {
             3.201782408236467, -2.6612502637759867`}, {
             3.387494441845319, -2.671629360211419}, {
             3.573704941305405, -2.6820337503003677`}, {
             3.6971493172830137`, -2.6889238882864794`}, {
             3.8206530253768154`, -2.6958176974423544`}, {
             3.9441505905384027`, -2.702706397503497}, {
             3.968243378697871, -2.7040483629626304`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.9918188288728644`, -2.70536151275704}, {
             4.067576537719368, -2.7095812082054116`}, {
             4.190865391871305, -2.7164333492836032`}, {
             4.313951677945805, -2.7232540404735763`}, {
             4.436769920894464, -2.730034501510836}, {
             4.559254645668874, -2.736765952130886}, {
             4.803202963018549, -2.750111234950115}, {
             4.934870117524921, -2.757285111021715}}]}, 
           {Arrowheads[{{0.014810966076488654`, 1.}}], 
            ArrowBox[{{4.958447140987226, -2.75856970356182}, {
             5.045652050706077, -2.7633210572118894`}, {
             5.2862849562161145`, -2.7763804915620223`}, {
             5.524784727033316, -2.7892746106463258`}, {
             5.656854249492381, -2.7964355204685996`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.014417273247122}, {-5.562984965720684, 
             4.013148648485308}, {-5.410797149232199, 
             4.010942268058681}, {-5.252690749685744, 
             4.008431344283517}, {-5.0914291125974955`, 
             4.005422777284421}, {-4.929775583483628, 
             4.001723467185995}, {-4.767730162344142, 
             3.99733341398824}, {-4.71257584520796, 3.995608269408996}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688975394077836, 
             3.9948700825824903`}, {-4.605292849179037, 
             3.9922526176911557`}, {-4.442463643988313, 
             3.986481078294742}, {-4.27924254677197, 
             3.9800187957989994`}, {-4.115629557530009, 
             3.9728657702039274`}, {-3.951624676262428, 
             3.965022001509526}, {-3.8223524605491566`, 
             3.9582347850462676`}, {-3.7454167573628907`, 
             3.953791123005333}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7218440509147954`, 
             3.9524296076554064`}, {-3.692976635039919, 
             3.950762279811109}, {-3.5634971997347153`, 
             3.9426044858040505`}, {-3.4339141546335448`, 
             3.9337614030250925`}, {-3.304227499736408, 
             3.924233031474235}, {-3.174437235043306, 
             3.9140193711514777`}, {-3.0445433605542376`, 
             3.9031204220568205`}, {-2.914545876269203, 
             3.8915361841902634`}, {-2.7845482902718977`, 
             3.87932386802053}, {-2.7802859085713036`, 
             3.878904397265707}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.756787432510695, 
             3.8765918583654586`}, {-2.654654110646017, 
             3.866540684016344}, {-2.5248633373915617`, 
             3.853186632177705}, {-2.3951759705085314`, 
             3.8392617125046127`}, {-2.265592009996926, 
             3.824765924997068}, {-2.136111455856745, 
             3.80969926965507}, {-2.0067343080879887`, 
             3.794061746478619}, {-1.877460566690658, 
             3.7778533554677156`}, {-1.8183479789555486`, 
             3.7703002420792373`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.7949264075670348`, 
             3.7673075498082356`}, {-1.7483733265094754`, 
             3.761359227914658}, {-1.6195556823891633`, 
             3.7448644951117442`}, {-1.4910076343297223`, 
             3.7283691570589754`}, {-1.362729182331153, 
             3.711873213756351}, {-1.2347203263934543`, 
             3.6953766652038706`}, {-1.1069810665166266`, 
             3.678879511401535}, {-0.9795114027006706, 
             3.662381752349344}, {-0.8581861634541903, 
             3.646645377114266}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.834769425750157, 
             3.6436150978117374`}, {-0.7971411333280304, 
             3.6387494992425604`}, {-0.742025832845349, 
             3.6316835875235647`}, {-0.5727459866610545, 
             3.6107553147705773`}, {-0.40365257729425597`, 
             3.5912057176311953`}, {-0.23474560474495354`, 
             3.5730347961054196`}, {-0.06602506901314704, 
             3.5562425501932493`}, {-0.047517485380779934`, 
             3.554475185787437}, {-0.02901093280104365, 
             3.5527271400537668`}, {0.0035263956424113063`, 
             3.5497479462327366`}, {0.036084410057639765`, 
             3.5468448134871036`}, {0.10412606270537411`, 
             3.542107741818188}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.12768103959231974`, 3.5404678402383305`}, {
             0.1703921597987087, 3.5374942846351938`}, {0.3046999095397776, 
             3.5281437557832835`}, {0.4399206410927934, 3.521965473254019}, {
             0.5747761799210305, 3.514518292195696}, {0.7701217697494169, 
             3.505945968199556}, {0.9670726604683706, 3.4998585455458104`}, {
             1.0710865615864142`, 3.497971360399797}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0946946691311055`, 3.4975430246734667`}, {
             1.1656288520778912`, 3.496256024234459}, {1.365790344577979, 
             3.495138404265502}, {1.5676163693118828`, 3.496108380274104}, {
             1.7711661576228503`, 3.4987686468954333`}, {1.976439709510882, 
             3.5031192041294883`}, {2.0390671198410515`, 
             3.504946873517337}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0626690645591514`, 3.5056356542225835`}, {
             2.1834370249759782`, 3.509160051976269}, {2.391841136058929, 
             3.516520193309865}, {2.6013350748005277`, 3.524828631004364}, {
             2.8119188412007725`, 3.5340853650597674`}, {3.006373542472425, 
             3.5434602526072383`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0299572978328664`, 3.544614336165458}, {
             3.1611986677423154`, 3.5512938864864823`}, {3.2988657558587295`, 
             3.558458285457169}, {3.4365936996089084`, 3.565783592388134}, {
             3.5743824989928514`, 3.5732698072793774`}, {3.7122321540105583`, 
             3.5809169301308996`}, {3.8501426646620294`, 3.5887249609427}, {
             3.9730453362501126`, 3.5958235632917237`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.9966174793218254`, 3.5971947373526914`}, {
             4.126146252866264, 3.6048237464471367`}, {4.264063929065205, 
             3.613060798414171}, {4.4016916581902645`, 3.6213513528902816`}, {
             4.539029440241441, 3.6296954098754672`}, {4.676077275218736, 
             3.638092969369729}, {4.81283516312215, 3.6465440313730655`}, {
             4.939360883184493, 3.6544290052519766`}}]}, 
           {Arrowheads[{{0.014724477519564714`, 1.}}], 
            ArrowBox[{{4.962926712289601, 3.6559047676502026`}, {
             5.085481097707331, 3.6636066629069663`}, {5.221369144389099, 
             3.67221823243753}, {5.356910414646268, 3.6808821579911553`}, {
             5.492048079128118, 3.689597293081827}, {5.624289170567823, 
             3.698197047889028}, {5.656854249492381, 3.7003323731012396`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.083834490010257}, {-5.523748808865216, 
             3.082138483524317}, {-5.328961517565244, 
             3.0790879423250384`}, {-5.130792320422092, 
             3.075425714218605}, {-4.929241217435762, 
             3.0711517992050155`}, {-4.7256103342725915`, 
             3.0659542947500844`}, {-4.7125611466346475`, 
             3.065543620233009}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688960838099401, 
             3.064800888533576}, {-4.5212017965989215`, 
             3.0595212983196247`}, {-4.3160156044147495`, 
             3.0518528099136364`}, {-4.110051757720076, 
             3.0429488295321194`}, {-3.903357204123268, 
             3.0325442827649622`}, {-3.745433216547534, 3.023276367896288}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7218617791178312`, 
             3.021893056350118}, {-3.695978891232688, 
             3.0203740952020537`}, {-3.4879168190483365`, 
             3.0064382668433933`}, {-3.279170987570214, 
             2.990736797688981}, {-3.069984249761415, 
             2.973157415061912}, {-2.860599458585033, 
             2.95358784628528}, {-2.78055474672006, 2.945353659108835}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7570667043096826`, 
             2.942937447805063}, {-2.651016614041069, 
             2.932028091359085}, {-2.441235716129522, 
             2.9084781502833272`}, {-2.231824484833638, 
             2.8832552759771253`}, {-2.023350640136663, 
             2.8566767213595967`}, {-1.8195035698163489`, 
             2.829239074962086}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7961217637206361`, 
             2.8259506575071076`}, {-1.6092151105394392`, 
             2.7994525711905602`}, {-1.404191287035273, 
             2.7697296379128447`}, {-1.2013805729221811`, 
             2.740496348871387}, {-1.0007829682001634`, 
             2.7117527040661877`}, {-0.8612076844083532, 
             2.6918743353404198`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8378315767510942, 
             2.68854510057363}, {-0.8023984728692195, 
             2.683498703497247}, {-0.7485260623020006, 
             2.675906780284982}, {-0.6948378750478599, 
             2.6684569895495995`}, {-0.511773820512114, 
             2.6440270965633084`}, {-0.330613779514043, 
             2.621847092384824}, {-0.15108124027323383`, 2.602587262353856}, {
             0.02750665762239671, 2.5864283028960804`}, {
             0.046937785884635375`, 2.58483461799037}, {0.06637441307152171, 
             2.583283362988322}, {0.10011631787549835`, 
             2.5807941577664386`}, {0.10028941061121378`, 
             2.5807820515474087`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.12384386329162683`, 2.5791346377371154`}, {
             0.13388118704606086`, 2.578432620755622}, {0.33744358423766224`, 
             2.5665170096482357`}, {0.5427287133197649, 
             2.5591242614552643`}, {0.7507428277492086, 
             2.5559845109721406`}, {0.9624921809828332, 2.556827892994298}, {
             1.0677720100493808`, 2.558888509760666}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0913794815528524`, 2.5593505731209785`}, {
             1.1784372023701306`, 2.561054532946412}, {1.399038321260593, 
             2.56806455625316}, {1.572597130714087, 2.574984563688723}, {
             1.7484764832538409`, 2.5827499348735965`}, {1.9266763788798538`, 
             2.5913606698077807`}, {2.0350654131859756`, 
             2.5970383504732983`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0586450780042327`, 2.5982735105417967`}, {
             2.1071968175921265`, 2.600816768491276}, {2.2894751742080417`, 
             2.610782026841051}, {2.4729488235449817`, 2.6209202407740753`}, {
             2.6576177656029474`, 2.631231410290348}, {2.8434820003819383`, 
             2.64171553538987}, {3.001662052673601, 2.650805912299926}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.025235151109136, 2.652160623887211}, {
             3.0311324476638717`, 2.6524995329193946`}, {3.217220562017886, 
             2.6628642074139823`}, {3.4040312332673923`, 2.673300304014416}, {
             3.591328093499625, 2.6837570559819937`}, {3.7150374108787982`, 
             2.690655075001462}, {3.8388018075736143`, 2.697556520639282}, {
             3.9625562784364723`, 2.7044530407937493`}, {3.9682485089672106`, 
             2.7047698353382716`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.991824019377486, 2.7060819032599723`}, {
             4.086235818319772, 2.71133628336316}, {4.209775422075911, 
             2.7181978962458087`}, {4.333110084557287, 2.7250295273399914`}, {
             4.456174800616299, 2.7318228245440035`}, {4.578904565105348, 
             2.7385694357561405`}, {4.823266033868394, 2.7519447049589814`}, {
             4.934873976760666, 2.758029868743867}}]}, 
           {Arrowheads[{{0.014810926295132905`, 1.}}], 
            ArrowBox[{{4.958450951864442, 2.759315348534469}, {
             5.06593658765672, 2.765175753102179}, {5.3065391696483, 
             2.778243346081534}, {5.544696723021109, 2.791128249792847}, {
             5.656854249492381, 2.7972167235992638`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            
            ArrowBox[{{-2.4053920400054625`, -5.656854249492381}, \
{-2.3762963283160774`, -5.654363969869278}, {-2.2252101619477136`, \
-5.640585828866906}, {-2.072742664398189, -5.625842668758836}, \
{-1.9812337463608531`, -5.6166307918555125`}, {-1.8898074721946267`, \
-5.607225042911068}, {-1.764741850109382, -5.594090336139258}, \
{-1.6398338846964369`, -5.580674837239586}, {-1.5150835759557921`, \
-5.566978546212051}, {-1.4657669817509635`, -5.561446100062949}}]}, 
           {Arrowheads[{{0.004977177627914182, 1.}}], 
            ArrowBox[{{-1.4423021776985119`, -5.5588137657156045`}, \
{-1.390490923887447, -5.5530014630566535`}, {-1.3741149361836802`, \
-5.551144740170999}, {-1.3577416652891552`, -5.549283622411326}, \
{-1.2832388508942738`, -5.540698501059796}, {-1.2087916646464567`, \
-5.5320272918069096`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.407241597256745, 
             5.656854249492381}, {-2.255159665189984, 
             5.643220309602689}, {-2.0735371741913093`, 
             5.625752997410685}, {-1.98200463472585, 
             5.6165406064892585`}, {-1.8905547083596907`, 
             5.607133570519409}, {-1.765484060402642, 
             5.593999830119753}, {-1.6405710758364287`, 
             5.580585232589317}, {-1.515815754661051, 
             5.566889777928104}, {-1.4676125190736695`, 5.561482746512497}}]}, 
           {Arrowheads[{{0.005002015816482693, 1.}}], 
            ArrowBox[{{-1.4441476872123986`, 
             5.558850660066643}, {-1.3912180968765087`, 
             5.552913466136111}, {-1.3748412269967523`, 
             5.551056814999731}, {-1.3584670740291545`, 
             5.549195767830767}, {-1.2839413498033303`, 
             5.540608738189394}, {-1.209471283095085, 
             5.531935554927744}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5914466132786341, -1.131675345777657}, {
             0.6098031197566337, -1.1461260678187097`}, {
             0.6452633023568956, -1.1620375501418418`}, {
             0.7211785883672056, -1.1843483279776805`}, {
             0.7296525142507962, -1.186462544015087}, {
             0.7384927611220655, -1.1886022425636675`}, {
             0.7620639773240008, -1.1937841312989108`}, {
             0.7879250712876488, -1.1991257601021912`}, {
             0.8442763187258556, -1.2101236452758037`}, {
             0.9100873847599574, -1.2217529606400164`}, {
             0.9856443165033792, -1.2340052609998684`}, {
             1.1782537527542305`, -1.2609448975205446`}, {
             1.4113310520388433`, -1.2879618941816346`}, {
             1.51564420063222, -1.2984983346393608`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.5391366560047284`, -1.3008712556045128`}, {
             1.5740872758908344`, -1.3044015404282032`}, {
             1.7471194474203686`, -1.320050685643024}, {
             1.9283616960397048`, -1.3348268285356284`}, {
             2.115748151161101, -1.3486474678155478`}, {
             2.308056322683734, -1.3615577358363649`}, {
             2.480857922120849, -1.3722619649896641`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.504425105897983, -1.3737157345569406`}, {
             2.6435454375851535`, -1.3816995231314098`}, {
             2.785048016130088, -1.3893577516754885`}, {
             2.9270520279915093`, -1.3966346325170078`}, {
             3.0690160370999995`, -1.4035512417062117`}, {
             3.2108754179247065`, -1.4101485194528371`}, {
             3.3528380080996723`, -1.4164787569149033`}, {
             3.4477321022480236`, -1.4205579849028056`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.471322309178262, -1.4215720609969384`}, {
             3.494771066302821, -1.4225800565650766`}, {
             3.6365418512120784`, -1.4284905208760241`}, {
             3.7780802318533646`, -1.4342240912044035`}, {
             3.919351854594317, -1.439780902554868}, {
             4.060277644125429, -1.4451783478720768`}, {
             4.200778525137196, -1.4504338201006892`}, {
             4.340805835760338, -1.4555547697029592`}, {
             4.415089248456412, -1.458210544481058}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.438686165481547, -1.4590541796184562`}, {
             4.480328293234274, -1.4605429657226239`}, {
             4.619292890912552, -1.4654072789765666`}, {
             4.757646622148718, -1.470156580281671}, {
             4.9263500491220675`, -1.4758374822429168`}, {
             5.094179603057519, -1.4813899046833023`}, {
             5.261136783635386, -1.486832118786891}, {
             5.382633654116068, -1.490742354688675}}]}, 
           {Arrowheads[{{0.005309762467541581, 1.}}], 
            ArrowBox[{{5.406233427959334, -1.4915018860460743`}, {
             5.427211847552518, -1.4921770521563733`}, {
             5.591554698413599, -1.4974183317414698`}, {
             5.656854249492381, -1.4994916910211744`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.3348319691396322}, {-5.539370266219553, 
             0.33461371443096044`}, {-5.320747130702276, 
             0.3340992382222268}, {-5.291474056685177, 
             0.3340221671129849}, {-5.262173497458879, 
             0.33394253064371276`}, {-5.0628322328637845`, 
             0.33325186177634253`}, {-4.862092885351006, 
             0.3323999020736515}, {-4.712380238252782, 0.3316892737620681}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688768619497095, 
             0.3315565557405002}, {-4.555936189564126, 
             0.3307938416000196}, {-4.401375647395135, 
             0.3297544972404386}, {-4.245826975709107, 
             0.3285576101323475}, {-4.089290174506046, 
             0.3272031802757463}, {-3.93176524378595, 
             0.3256912076706351}, {-3.773252183548819, 
             0.3240216923170137}, {-3.7443229936035527`, 
             0.32369031352943817`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207125495533653`, 
             0.32341986004151557`}, {-3.6137509937946537`, 
             0.3221946342148823}, {-3.4534518192738948`, 
             0.32011497157591984`}, {-3.292544804736984, 
             0.3176876426118051}, {-3.131029950183921, 
             0.31491264732253826`}, {-2.968907255614706, 
             0.3117899857081192}, {-2.8061767210293396`, 
             0.308319657768548}, {-2.7763706919205946`, 
             0.3076229491814264}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7527651468303214`, 
             0.30707117538062667`}, {-2.6428383464278205`, 
             0.3045016635038246}, {-2.4788921318101496`, 
             0.3003360029139491}, {-2.314338077176327, 
             0.29582267599892137`}, {-2.1507875307196187`, 
             0.29082340846344984`}, {-1.9898518406332915`, 
             0.28519992601224275`}, {-1.8339963554247738`, 
             0.27888642301456185`}, {-1.8087613329393255`, 
             0.2776835724806001}}]}, 
           {Arrowheads[{{0.010284009098895666`, 1.}}], 
            ArrowBox[{{-1.785176118013509, 
             0.2765593615398934}, {-1.6856864236014937`, 
             0.27181709383966884`}, {-1.4675690518271063`, 
             0.2584961828842873}, {-1.3007011780947513`, 
             0.24366710462028443`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.003742165117077063, 1.}}], 
            ArrowBox[{{1.1100139520382521`, -0.2080192693462435}, {
             1.0812705458884748`, -0.20991603267711248`}, {
             1.0452696559641932`, -0.21111073106764022`}, {
             0.9991023428180799, -0.21175699748311375`}, {
             0.9587037882012215, -0.21194175367748647`}, {
             0.9442818792929132, -0.21195384761944694`}, {
             0.9333812855134688, -0.21194587243163843`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.33306137100061994`}, \
{-5.524772053681097, -0.33281356435295195`}, {-5.306041509450836, \
-0.3322932454127883}, {-5.276755649755437, -0.3322153034881301}, \
{-5.247442189361805, -0.3321347711209192}, {-5.048568466648605, \
-0.3314390852337513}, {-4.8482985215648915`, -0.3305819697522474}, \
{-4.712380201262335, -0.329931791049}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688768514932566, -0.329811928982531}, \
{-4.542104177865134, -0.3289639969678778}, {-4.387521075368978, \
-0.3279180096098441}, {-4.23194735244197, -0.326714021607911}, \
{-4.075383009084109, -0.32535203296207876`}, {-3.917828045295397, \
-0.32383204367234714`}, {-3.7592824610758324`, -0.32215405373871625`}, \
{-3.7443225694779185`, -0.32198189081134293`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720712139922393, -0.32171017489400383`}, \
{-3.5997462564254166`, -0.3203180631611861}, {-3.439423291276222, \
-0.3182287331121699}, {-3.278517425560321, -0.3157907247640811}, \
{-3.117028659277715, -0.31300403811691957`}, {-2.9549569924284023`, \
-0.30986867317068534`}, {-2.7923024250123842`, -0.3063846299253784}, \
{-2.776368580627522, -0.30601051245459576`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.752763093388497, -0.3054562692368796}, \
{-2.629064957029661, -0.30255190838099877`}, {-2.4652445884802314`, \
-0.29837050853754643`}, {-2.3008413193640966`, -0.29384043039502145`}, \
{-2.1375236895886394`, -0.28882253892730525`}, {-1.9769602390612433`, \
-0.2831776991082796}, {-1.8216840930052738`, -0.2768420667822454}, \
{-1.8087536248668385`, -0.27622031742240843`}}]}, 
           {Arrowheads[{{0.006907850696255299, 1.}}], 
            ArrowBox[{{-1.7851688809932964`, -0.2750862672667373}, \
{-1.6742283766440949`, -0.26975179779350344`}, {-1.4594890020711973`, \
-0.2565051085704919}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.9791158109459713}, {-5.534533651975317, 
             0.9784834336640722}, {-5.505746012990511, 
             0.9783207137049867}, {-5.476932297807433, 
             0.9781525745078476}, {-5.270957143554969, 
             0.9765828162164162}, {-5.063742955872711, 
             0.9746023304952428}, {-4.937943379578171, 
             0.9732811094436327}, {-4.81159102420238, 
             0.9717168657670044}, {-4.712419236580596, 0.9703045523045923}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688809637573617, 
             0.9699683260922862}, {-4.684685889745337, 
             0.9699095994653579}, {-4.557227976207044, 
             0.9678593105386932}, {-4.4292172835875, 
             0.9655659989870103}, {-4.300653811886704, 
             0.9630296648103093}, {-4.171537561104659, 
             0.96025030800859}, {-4.041868531241361, 
             0.9572279285818525}, {-3.9115994413273985`, 
             0.9538609900764523}, {-3.7806830103933544`, 
             0.9500479560387449}, {-3.7445754479824154`, 
             0.948879041644749}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7209758181738963`, 
             0.948115048034153}, {-3.6491192384392304`, 
             0.9457888264687304}, {-3.516908125465026, 
             0.9410836013664086}, {-3.38404967147074, 
             0.9359322807317797}, {-3.250543876456374, 
             0.9303348645648435}, {-3.1163907404219273`, 
             0.9242913528656002}, {-2.9815902633674, 
             0.9178017456340497}, {-2.788394325994083, 
             0.9074459176537688}, {-2.777424786250876, 0.9067717786117151}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7538572560463423`, 
             0.9053234232014076}, {-2.5952435543115255`, 
             0.8955757317351065}, {-2.4021379483197265`, 
             0.8821911878780627}, {-2.209077508018686, 
             0.8672922860826373}, {-1.9971664340362176`, 
             0.8485740525787486}, {-1.8125241932819074`, 
             0.8294766454508129}}]}, 
           {Arrowheads[{{0.014997996773248205`, 1.}}], 
            ArrowBox[{{-1.7890419233306254`, 
             0.8270078659219734}, {-1.641117291175619, 
             0.8091709881498629}, {-1.4998602391609133`, 
             0.7892718248502142}, {-1.258621754503517, 
             0.7445995185413494}, {-1.0943722191642422`, 
             0.6960396980236089}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0052001991328419015`, 1.}}], 
            ArrowBox[{{0.9752429601981297, 0.5650192040120466}, {
             0.9479230929835587, 0.5685831787740174}, {0.9112604791271811, 
             0.5713419194074905}, {0.8654779377590002, 0.5729685398694986}, {
             0.8056983888261204, 0.5736474609922785}, {0.7898373759471458, 
             0.5736305467321774}, {0.7766358372147679, 0.5735539884693841}, {
             0.7658432967510289, 0.5734247437238388}, {0.7573515683344654, 
             0.5733179139751702}, {0.7459987809817764, 0.573173805696151}, {
             0.7396129679048931, 0.5730909752514466}, {0.735554345808632, 
             0.5730377113254115}, {0.7300406658250844, 
             0.5729646745504886}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.9920337670985099}, \
{-5.558778687498586, -0.9915436094455347}, {-5.530018372524591, \
-0.9913835487189832}, {-5.501236459710249, -0.9912180006147534}, \
{-5.294489748258743, -0.9896631452380412}, {-5.086501122989173, \
-0.9876984092939242}, {-4.960654326769094, -0.9863909467664025}, \
{-4.834257045248585, -0.9848409480059435}, {-4.712420242557587, \
-0.9831205811355658}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688811115302308, -0.9827531534392582}, \
{-4.579811026306277, -0.9810133417862129}, {-4.451762288884476, \
-0.9787357343269414}, {-4.3231630661622455`, -0.9762155906347325}, \
{-4.194013358139584, -0.9734529107095861}, {-4.064313164816492, \
-0.9704476945515023}, {-3.934012453819596, -0.9670979045958775}, \
{-3.803061192775522, -0.9633015032781085}, {-3.7445830383352914`, \
-0.9614160919092956}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.720983308123376, -0.9606552060696452}, \
{-3.6714593816842687`, -0.9590584905981953}, {-3.539207020545837, \
-0.9543688665561376}, {-3.406304109360227, -0.9492326311519358}, \
{-3.2727506481274387`, -0.9436497843855897}, {-3.1385466368474715`, \
-0.9376203262570993}, {-3.0036920755203265`, -0.9311442567664646}, \
{-2.806646969399249, -0.9205922734803228}, {-2.777456623463502, \
-0.918796025650649}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7538892089630633`, -0.9173457887387392}, \
{-2.6096072938865356`, -0.9084673027698554}, {-2.4125730489821855`, \
-0.8947693446350625}, {-2.2155442346861993`, -0.8794983990759442}, \
{-2.00192887493277, -0.8605319871963018}, {-1.812610380015431, \
-0.8408421332644729}}]}, 
           {Arrowheads[{{0.015075553496827146`, 1.}}], 
            ArrowBox[{{-1.7891351443059214`, -0.8383100659932721}, \
{-1.6430342252368155`, -0.8205916686682558}, {-1.5006493079997205`, \
-0.800417916041377}, {-1.3708289933740903`, -0.778561758833823}, \
{-1.2571789235058108`, -0.7551603076583128}, {-1.09104566711357, \
-0.7059520368858346}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.323318101815545}, {-5.524944212529217, 
             2.3219287817815286`}, {-5.36267865108806, 
             2.3199232388888795`}, {-5.19979852659197, 
             2.317550158311905}, {-5.036273907169866, 
             2.3147326383343945`}, {-4.8720748609506614`, 
             2.3113937772401347`}, {-4.71251520882355, 
             2.307584295562047}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688911809987407, 
             2.306948502730752}, {-4.541386711439006, 
             2.302841043065504}, {-4.374883697278638, 
             2.2974744233561517`}, {-4.207641672285936, 
             2.2912801238293343`}, {-4.039668928139388, 
             2.284172855893525}, {-3.8709872924371083`, 
             2.276075054988753}, {-3.7452185003807448`, 
             2.2692777839137355`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7216409166884237`, 
             2.2680035152733975`}, {-3.7016422806365483`, 
             2.2669226736102743`}, {-3.5316794081951626`, 
             2.2566516642533423`}, {-3.3609040300436823`, 
             2.245146439806904}, {-3.1893136295342166`, 
             2.2323326448449516`}, {-3.0172419147562843`, 
             2.2182080793903096`}, {-2.845022593799406, 
             2.202770543465801}, {-2.779940308617112, 2.196454963102712}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7564387106493315`, 
             2.194174369693756}, {-2.693882985985955, 
             2.1881039665851953`}, {-2.543089371636898, 
             2.172391527766981}, {-2.3928864137248413`, 
             2.155655059145138}, {-2.240909036847907, 
             2.137683516757851}, {-2.090623299784711, 
             2.1187861891698505`}, {-1.941417545103733, 
             2.0989084960461835`}, {-1.8187693727067171`, 
             2.081638018838765}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7953880483843838`, 
             2.07834562058369}, {-1.7932917728049724`, 
             2.07805043738685}, {-1.6462459828884297`, 
             2.0562120131918498`}, {-1.5011460552455924`, 
             2.033675805544022}, {-1.3588578697679474`, 
             2.0107243965262045`}, {-1.219381426455496, 
             1.987357786138397}, {-1.0827167253082375`, 
             1.9635759743806005`}, {-0.926622874824791, 
             1.9356838912017442`}, {-0.8636199417933559, 
             1.924248883745085}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8403875108385175, 
             1.9200322067044726`}, {-0.7763540015791024, 
             1.9084101500695516`}, {-0.632149441866131, 
             1.8822674434809652`}, {-0.4942485319808363, 
             1.8577684639329282`}, {-0.36227071242332254`, 
             1.8353401801490037`}, {-0.23583542369369465`, 
             1.8154095608527552`}, {-0.19855283051444972`, 
             1.80988969930148}, {-0.16163884032151676`, 
             1.8046526537740935`}, {0.015193761687191124`, 
             1.7831735424328852`}, {0.09274871797954903, 
             1.7768381145611147`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.11628231956982256`, 1.774915665725271}, {
             0.18865045626404464`, 1.76900394670486}, {0.40513953979122924`, 
             1.7618299620056617`}, {0.42303764514055936`, 
             1.7616963993557964`}, {0.44103055248949713`, 
             1.761630896259377}, {0.4872721836018575, 1.7620683471432879`}, {
             0.5342284984371317, 1.7629340175616048`}, {0.6630980787027364, 
             1.766528798349389}, {0.7984244550729078, 1.7726805857455978`}, {
             0.9406606727602616, 1.7810197386045548`}, {1.0596833419596818`, 
             1.7891006602019648`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.0832411015631227`, 1.7907000900387051`}, {
             1.090259776977413, 1.791176615780583}, {1.2470037750477698`, 
             1.8026568004013215`}, {1.4106746742947407`, 
             1.8149658755944083`}, {1.5543434678906856`, 1.825779728414843}, {
             1.7014629504521914`, 1.8366096865861021`}, {1.852033121979258, 
             1.8474557501081856`}, {2.0060539824718857`, 
             1.8583179189810937`}, {2.025200527277278, 
             1.8596302312011654`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.04875725284292, 1.8612448190622588`}, {
             2.162582257759821, 1.869046432691267}, {2.3206746736728103`, 
             1.8794915307251467`}, {2.480331230210854, 1.8896532130827326`}, {
             2.641551927373952, 1.899531479764025}, {2.805011963798975, 
             1.9091024746145326`}, {2.9668852138769894`, 
             1.9185013825097046`}, {2.991408721169835, 
             1.9198765554743031`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0149836777148957`, 1.9211985377868335`}, {
             3.1297824456705614`, 1.9276359596521757`}, {3.293433579724943, 
             1.9365157485037423`}, {3.482537777406668, 1.9464344578655814`}, {
             3.671692788056162, 1.9560144374645234`}, {3.860425823640924, 
             1.965261076267494}, {3.9582034010986096`, 
             1.9699036211273104`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9817888234104037`, 1.971023472773948}, {
             4.048264096128455, 1.9741797632414189`}, {4.235204311546328, 
             1.9828143343732674`}, {4.421511458242155, 1.9912305953757494`}, {
             4.6071151716635015`, 1.9994668898043992`}, {4.791945087257928, 
             2.007561561214752}, {4.9253193315924895`, 
             2.0133417220181826`}}]}, 
           {Arrowheads[{{0.015004895702344171`, 1.}}], 
            ArrowBox[{{4.9489091820568225`, 2.0143640568002317`}, {
             4.97599197659642, 2.015537768473173}, {5.159281546177629, 
             2.0234099934807865`}, {5.341795833840621, 2.0312035643452684`}, {
             5.523516877424465, 2.038943809174294}, {5.656854249492381, 
             2.0446121066146734`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.004989069079935393, 1.}}], 
            ArrowBox[{{0.9871326559182281, -0.5129396668390777}, {
             0.9504094247222495, -0.5161122985674648}, {
             0.9284999492285256, -0.5172167438743216}, {
             0.9020204808807323, -0.5179144221040886}, {
             0.8724493728760886, -0.518138310592642}, {
             0.857427646251272, -0.5181362869468563}, {
             0.8449939816325, -0.5181069876419949}, {
             0.8328769181350602, -0.5180378651499133}, {
             0.82274619729212, -0.5179653899256604}, {
             0.805719593247553, -0.5178291989808708}, {
             0.7939340298739791, -0.5177178348992769}, {
             0.785381164495338, -0.5176337639846599}, {
             0.7753410455025692, -0.517532967045195}, {
             0.768522585879771, -0.5174630529633413}, {
             0.7635734419459934, -0.5174115877449491}, {
             0.7581460798677808, -0.5173544880262296}, {
             0.7517073503402272, -0.5172857577771922}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.3926638538460874`, 0.2420486177442458}, {
             1.5696077208750814`, 0.25176738579293095`}, {1.7112393612480734`,
              0.2574359812547932}, {1.8698644828728104`, 
             0.26253355775969583`}, {2.041250534320832, 
             0.26707869429593056`}, {2.2211649641636795`, 
             0.27108996985178924`}, {2.336555637425219, 
             0.27329066802683716`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.3601633373949293`, 0.27374090738130097`}, {
             2.4071074389450056`, 0.2746362119643357}, {2.5965776252084636`, 
             0.2777862481706338}, {2.7877377438821638`, 
             0.28065332173262936`}, {2.9787500158942146`, 
             0.28335067591226804`}, {3.169614441244615, 
             0.28587831070954994`}, {3.30454074554894, 
             0.28754646570155645`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.328150934148588, 0.2878383691534281}, {
             3.3603310199333665`, 0.288236226124475}, {3.550899751960468, 
             0.2904244221570433}, {3.7413206373259196`, 0.2924428988072547}, {
             3.931593676029721, 0.2942916560751094}, {4.1217188680718735`, 
             0.2959706939606072}, {4.272583435795749, 
             0.29721162202300716`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.296194630504154, 0.29740578018710057`}, {
             4.4694247371109075`, 0.2987783097940706}, {4.594435456822534, 
             0.29974398614386566`}, {4.718946359567469, 
             0.30069106027926057`}, {4.842957445345713, 0.3016195322002553}, {
             4.9664687141572665`, 0.30252940190684974`}, {5.211991800880301, 
             0.30429333467683817`}, {5.240647728577128, 
             0.3044921442852897}}]}, 
           {Arrowheads[{{0.00831366155083524, 1.}}], 
            ArrowBox[{{5.264259153333834, 0.30465595605088763`}, {
             5.45551561973657, 0.3059828585892258}, {5.487834119155616, 
             0.3062030448204974}, {5.520116598773953, 0.30642236782895205`}, {
             5.656854249492381, 0.307334550398204}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9223275547835267, 1.1860258015547482`}, {
             1.1616459380148727`, 1.2228629212484226`}, {1.311175229681273, 
             1.2416578052692975`}, {1.4780425297744275`, 
             1.2601737659911947`}, {1.6591608543674858`, 
             1.2779290700140267`}, {1.8514432195335968`, 
             1.2944419839377053`}, {1.8601856010512265`, 
             1.295123449592375}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.8837261843100128`, 1.2969584300206944`}, {
             1.9765723651218052`, 1.3041957581174934`}, {2.103930746363761, 
             1.3135363252669554`}, {2.2335183632594657`, 
             1.3224636853860918`}, {2.3653352158089174`, 1.330977838474902}, {
             2.5821990852813137`, 1.3440352369371753`}, {2.800354609257278, 
             1.3561823479044883`}, {2.8262358062948505`, 
             1.3575075982192992`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.849816905106639, 1.3587150716827}, {
             3.0198017877368106`, 1.3674191713768407`}, {3.240540620719911, 
             1.3777457073542327`}, {3.383792589875163, 1.3840150970446048`}, {
             3.5269941907894276`, 1.390062134490677}, {3.769745904568756, 
             1.399930596708302}, {3.7933493928511246`, 
             1.4008491945421946`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.816943524752981, 1.40176742824555}, {
             4.011307474092304, 1.4093316620026122`}, {4.25167889936007, 
             1.418265330373607}, {4.490860180372056, 1.4267316018212872`}, {
             4.522516248811481, 1.4278239151410597`}, {4.554143411419078, 
             1.4289101244123248`}, {4.728877308291927, 1.4347458971948301`}, {
             4.7608083456977655`, 1.4357910697225298`}}]}, 
           {Arrowheads[{{0.01848403333943986, 1.}}], 
            ArrowBox[{{4.784407699956312, 1.4365635280811164`}, {
             4.902694317839249, 1.4404353071853917`}, {5.07166161963162, 
             1.44592396413964}, {5.239744792321926, 1.451299658580313}, {
             5.40694181578442, 1.456576326662127}, {5.573250669893357, 
             1.4617679045397975`}, {5.656854249492381, 
             1.4643709464458132`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.00366205577321243, 1.}}], 
            ArrowBox[{{-0.7202644985320446, 
             0.5689798780108258}, {-0.7242752884261126, 
             0.5684989862554168}, {-0.7294567102924996, 
             0.5678795693515862}, {-0.7350855036783189, 
             0.5672087475952194}, {-0.743266337260497, 
             0.5662396241706029}, {-0.7613705266090154, 
             0.5641137520005842}, {-0.8000091819493561, 
             0.5591969370755941}, {-0.809343083776172, 
             0.5579647148736392}, {-0.8196350201004449, 
             0.5565559990003971}, {-0.8358238180973094, 
             0.5541173261725298}, {-0.853873718778695, 
             0.5512137780477536}, {-0.8914248282791644, 
             0.5445523524889533}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.009072861652557544, 1.}}], 
            ArrowBox[{{-3.014323486494222, -5.656854249492381}, \
{-2.985400467011201, -5.654994986570539}, {-2.86185920601146, \
-5.646511780267139}, {-2.7384631576822875`, -5.637483230658179}, \
{-2.7219878081648106`, -5.636240637451657}, {-2.705497365992033, \
-5.6349868299745856`}, {-2.587029910846539, -5.625387744205995}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0038497969510511653`, 1.}}], 
            ArrowBox[{{0.4646939690952623, -0.9499783251563293}, {
             0.4174059471229958, -0.9487056737626058}, {
             0.3975712852633286, -0.9480349616807637}, {
             0.377368621982436, -0.9472415600997778}, {
             0.33343875920092736`, -0.9448563793072715}, {
             0.3239946773207894, -0.9443424267178504}, {
             0.31849410116537824`, -0.9440412916760221}, {
             0.31332463337562455`, -0.9437565023086026}, {
             0.28307868490960075`, -0.9420396705220302}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.011666241857602162`, 1.}}], 
            ArrowBox[{{-3.0176394850841692`, 
             5.656854249492381}, {-2.9867693435359635`, 
             5.654871149263439}, {-2.863207612848817, 
             5.646392030566297}, {-2.7398010288530528`, 
             5.637368309143011}, {-2.723324817636542, 
             5.636126401548892}, {-2.7068337007816967`, 
             5.634873294539298}, {-2.588331453213056, 
             5.625276628515172}, {-2.46831555231906, 5.61503040345253}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.0069292632386286305`, 1.}}], 
            ArrowBox[{{-0.6508724747284048, -1.4270121079391762`}, \
{-0.44658018887754175`, -1.3559397667434276`}, {-0.4360399194032051, \
-1.3514683323234522`}, {-0.4258617149171611, -1.3470336209640903`}, \
{-0.4038319191517066, -1.336428296079594}, {-0.38383446299249546`, \
-1.325997816602006}, {-0.3479227980943667, -1.3054602180836827`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.4402203191180314`, -0.2448773648516983}, {
             1.5685931319437327`, -0.2514159752608206}, {
             1.7221793558211862`, -0.25740681313123986`}, {
             1.8529285757404805`, -0.26163125705906665`}, {
             1.993111484679754, -0.2654457192577233}, {
             2.139624572244854, -0.2688960542462789}, {
             2.2907436659945857`, -0.27200773675754936`}, {
             2.384208571680841, -0.2737094371868769}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.407816652093984, -0.27413926569073804`}, {
             2.4452395406808054`, -0.2748206181738684}, {
             2.6018829710553693`, -0.2773745498775695}, {
             2.7596030607836854`, -0.27973566547477374`}, {
             2.9173289135311617`, -0.2819700985716023}, {
             3.0750605292977973`, -0.2840778491680551}, {
             3.232797908083592, -0.2860589172641322}, {
             3.352201080450999, -0.28746258857678386`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3758114420628726`, -0.28774014558485017`}, {
             3.390541049888547, -0.2879133028598335}, {
             3.548289954712661, -0.2896410059551591}, {
             3.706044622555935, -0.291242026550109}, {
             3.8638050534183686`, -0.2927163646446832}, {
             4.029142341648973, -0.29416290870074474`}, {
             4.193757076944977, -0.2955434441000528}, {
             4.319813768660152, -0.296569916544019}, {
             4.32024936066856, -0.29657339730155474`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.343860599843174, -0.29676207155888484`}, {
             4.445381015331094, -0.29757330763397494`}, {
             4.570458816957804, -0.2985536173699205}, {
             4.695047173540282, -0.29951084575185577`}, {
             4.819146085078527, -0.3004449927797807}, {
             4.9427555515725405`, -0.3013560584536953}, {
             5.1885061494278695`, -0.3031089457394936}, {
             5.221078651708966, -0.3033360646770132}, {
             5.253615281714796, -0.3035621241183752}, {
             5.288314057446379, -0.3037978281863859}}]}, 
           {Arrowheads[{{0.007304265935722407, 1.}}], 
            ArrowBox[{{5.311925505699072, -0.3039582175455908}, {
             5.450047419184746, -0.3048964609332492}, {
             5.645155406149089, -0.3062009187923132}, {
             5.651116399149018, -0.30624075978488585`}, {
             5.656854249492381, -0.30627909260324865`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.77574237263874, -0.7545653069985505}, {
             2.021326078587812, -0.7709507294063783}, {
             2.1503377491224773`, -0.7783084625070846}, {
             2.282154901612857, -0.7851309774427494}, {
             2.4161090341893714`, -0.791453266950517}, {
             2.5515316449824397`, -0.7973103237675319}, {
             2.6877654079011966`, -0.8028085436103642}, {
             2.7188803714139773`, -0.8040052962659948}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.742474918594255, -0.804912796510525}, {
             2.8241529968547763`, -0.8080543221955844}, {
             2.9606944118431784`, -0.8130476595231924}, {
             3.0973896528664033`, -0.8177885555931882}, {
             3.2342387199244502`, -0.8222770104055718}, {
             3.3712416130173204`, -0.8265130239603433}, {
             3.508398332145013, -0.8304965962575026}, {
             3.645708877307528, -0.8342277272970496}, {
             3.686459757684488, -0.8352747159831417}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.7100639613956945`, -0.8358811650708974}, {
             3.8032840290382723`, -0.8382762140915733}, {
             3.9603937202675192`, -0.8421528276730844}, {
             4.085265220281505, -0.8451478101269189}, {
             4.209745063125359, -0.8480787464031417}, {
             4.333833248799081, -0.8509456365017533}, {
             4.457529777302671, -0.8537484804227532}, {
             4.58083464863613, -0.8564872781661418}, {
             4.65428202212377, -0.8580855886372781}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.677888426326649, -0.8585992947268456}, {
             4.703747862799457, -0.8591620297319188}, {
             4.948399319615714, -0.8643193943306385}, {
             4.980817319347721, -0.8649879480194744}, {
             5.013199358646367, -0.8656530392893519}, {
             5.202110689910383, -0.8694364084888783}, {
             5.389776056531003, -0.8731278864087635}, {
             5.5815936190780455`, -0.876875227303148}, {
             5.62217563347968, -0.8776570007897115}}]}, 
           {Arrowheads[{{0.00023447950986433129`, 1.}}], 
            ArrowBox[{{5.64578324645387, -0.8781117787541964}, {
             5.656854249492381, -0.8783250509826155}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1548333646174862`, 0.6868493630517364}, {
             1.3004888776784311`, 0.715618478823114}, {1.519405745734681, 
             0.7429087870876384}, {1.65203260163425, 0.7553548906472075}, {
             1.7965224339148385`, 0.7668371649048497}, {1.983626610451531, 
             0.7795397766674346}, {2.093150579352266, 
             0.7859107876314968}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.116722724898251, 0.7872819797023033}, {
             2.180222231616888, 0.790975746989751}, {2.3248913832267255`, 
             0.7984284455590644}, {2.471146150257296, 0.8053476284006479}, {
             2.618986532708599, 0.8117332955145015}, {2.7684125305806346`, 
             0.817585446900625}, {2.895248271812547, 0.822160584116769}, {
             3.0223520718938053`, 0.8264820444320548}, {3.060311337943187, 
             0.8277150330557488}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0839108846005234`, 0.828481590884211}, {
             3.1485499914182578`, 0.8305811911043083}, {3.2745693126491564`, 
             0.8345354094506734}, {3.4004100355865003`, 0.83834469947115}, {
             3.52607216023029, 0.842009061165738}, {3.6515556865805254`, 
             0.8455284945344376}, {3.7768606146372066`, 0.8489029995772486}, {
             3.901986944400333, 0.852132576294171}, {4.026934675869906, 
             0.8552172246852051}, {4.028008604680622, 
             0.8552431329988492}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.051613729518114, 0.8558126018237802}, {
             4.059895655577208, 0.8560124016017312}, {4.092832437668226, 
             0.8568013451323545}, {4.253273738154913, 0.8604987651216824}, {
             4.413077322118827, 0.8640799549574174}, {4.568196050797442, 
             0.8675295079889473}, {4.722582671640029, 0.8709093556309448}, {
             4.876237184646586, 0.8742194978834097}, {4.995861024651087, 
             0.8767543357340427}}]}, 
           {Arrowheads[{{0.01349986932228204, 1.}}], 
            ArrowBox[{{5.019467718314804, 0.8772545632858822}, {
             5.029159589817113, 0.877459934746342}, {5.181349887151611, 
             0.8806306662197418}, {5.33280807665008, 0.8837316923036092}, {
             5.483534158312518, 0.8867630129979439}, {5.633528132138928, 
             0.8897246283027461}, {5.656854249492381, 
             0.8901802767887097}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(tot\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(tot\\)]\\)}\"", 
           TraditionalForm]}}], {194.4, -576.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAldgS2UAW578yc5fy9NnhvwmQa4hD
K+e/tHBNTaD04b97Pna8oz/nv6pX1reSDuK/zzDxOVxW57/k06OVmiviv9Ll
Wq6Ncee/jmYVYntO4r+OnEaKA5rnv3oQLXOnguK/7SfaKomx579rt+AZIqHi
v7UgEOJ+0ue/+nNnEgnM4r/J/XuH2fTnv5hY5df6+OK/z+Q0s1Qm6L8OVCeV
KDrjv7mc5AMjc+i/O/LGJ1Og47/liSD4eKjov1FVomXG5+O/ghRXweHt6L9q
Ce0oZkXkv/1iMW+CROm/2gHTFiS75L+NOSynNKHpvy2QOEFhOeW/WOW8qwZP
6r/v+Q/VmSTmv2W5AfDI6uq/hqsmZtn05r8HMla8g3jrvwpojecAsOe/5mjZ
YHta7b+1LWN2CB7qv9XPnevQh++/xAGkKVXR7L9r4dpxcAvxv6CPwGp/3e+/
bqanV1CF8r8PaQ0UFaDxvyXtudt3TfS/WduDP0qa87+Ok3igYC71v/PZz+VE
jfS/zVnh9A==
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3398620554149543`, -1.3018176240639074`}, \
{-1.3947046044339502`, -1.3610663791867277`}, {-1.5426348678012587`, \
-1.517675815340271}, {-1.711365596588287, -1.693653786384609}, \
{-1.8127791283083254`, -1.7985260712179596`}, {-1.903444649946508, \
-1.8918964465546069`}, {-1.9931169923136238`, -1.9839098861102453`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0095966871263014`, -2.00081982023836}, \
{-2.01389992190098, -2.0052354005876785`}, {-2.113038729635039, \
-2.106686966758006}, {-2.2030219879932234`, -2.19856283299383}, \
{-2.2860106118200716`, -2.2831746872233905`}, {-2.3628925309781037`, \
-2.3614590464457685`}, {-2.4349504479025565`, -2.4347659761497593`}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.5214749056721026`, \
-2.522690803518704}, {-2.592833018040274, -2.5951546248752075`}, \
{-2.671275800885279, -2.6747789794007644`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.6878467320946426`, -2.691599516020941}, \
{-2.7284921232774106`, -2.7328571425353063`}, {-2.8515778409595836`, \
-2.8576993958967236`}, {-2.9646860729282873`, -2.972356542785858}, \
{-3.0857608832779313`, -3.0950380080191273`}, {-3.1978955391867014`, \
-3.2086180987572823`}, {-3.3024164124022555`, -3.3144527003660595`}, \
{-3.3512371125752387`, -3.3638755173096024`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.367830673300964, -3.3806737301841263`}, \
{-3.4006498746722507`, -3.4138976982111964`}, {-3.493381638442867, \
-3.5077542739606935`}, {-3.5813974161602835`, -3.5968236092825507`}, \
{-3.720804712954504, -3.7378765826336853`}, {-3.850396107020988, \
-3.8689750115070662`}, {-3.9715713900125498`, -3.9915413566733338`}, \
{-4.0317616855606975`, -4.052415895270591}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.0483632559699565`, -4.069206192268636}, \
{-4.085730353582004, -4.106998078903127}, {-4.193720905063981, \
-4.216205799072152}, {-4.296390951793107, -4.32002513805612}, \
{-4.463261852240973, -4.488750465023793}, {-4.618434990086139, \
-4.645634385632633}, {-4.712507780041062, -4.740737270760529}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.729112820461279, -4.757524136042027}, \
{-4.763571595024337, -4.792360233498995}, {-4.900332896751296, \
-4.930611342239233}, {-5.029727832874645, -5.061409478365786}, \
{-5.15276534100201, -5.185776408391089}, {-5.253745276671963, \
-5.28784407456766}, {-5.351206080339233, -5.386352225996555}, \
{-5.393357839498263, -5.4289558117636325`}}]}, 
           {Arrowheads[{{0.0062381996614206065`, 1.}}], 
            ArrowBox[{{-5.40996479725979, -5.445740780254607}, \
{-5.4451477520038205`, -5.481300862677774}, {-5.535570291665725, \
-5.572689984611316}, {-5.615407609109345, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAALPEEsX881T8Txw1ENQbsv47Ce36R
fNU/HTnfFB4O7L8naYeTZbvVPy8omqehFey/QnOfkNFJ1j8hp/Rn4yXsv3u2
L2oCqNc/LdE4fLBI7L+XctKhO17aP9oRgl6Fguy/EUyU81u82z8CD/r1cZvs
v5V/LxsdVN0/q+yceliz7L+WCSOnJDjfP/KctWbnxuy/T1Lj8bRV4D/32vlQ
2s/svyxJq6obEeE/ng/47ubX7L/r7xckMdvhP+UPBZ6J5Oy/GnsExv2c5T8/
QgCOP3jtv4BdeshnLOc/fsCqeELt7b+Svs+1w5noPzUq65TUee6/3LjnaKns
6T/K2Wittxjvv2Adt8KthO4/zmRdGOPs8L/966BnmNnxPxP4MhTH6fK/iiBC
2IrW8j+07mUD+sTzv7uBq4A=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1952225927982787`, -1.2510533308632579`}, {
             1.2877673081329803`, -1.3312507757125978`}, {
             1.3845897490229657`, -1.4194598366554487`}, {
             1.4708016552974448`, -1.4995155068602835`}, {
             1.574837572043617, -1.5976464104650114`}, {
             1.667609165963053, -1.6860617563263867`}, {
             1.7820039543820128`, -1.796032139604437}, {
             1.8840428713724606`, -1.8947101224521004`}, {
             1.8851856341885178`, -1.895820731449386}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9021183522703389`, -1.9122770151032895`}, {
             1.9979687631378917`, -2.0054304912290792`}, {
             2.1006691900387495`, -2.1055703694337264`}, {
             2.1941895523606068`, -2.197003543767715}, {
             2.280575250389036, -2.2816038009327158`}, {
             2.360702362558432, -2.3601921287464065`}, {
             2.4358442723018845`, -2.4339656237941805`}, {
             2.446513457451672, -2.4444459204077544`}, {
             2.5247205545467155`, -2.5213331267585883`}, {
             2.577125116874477, -2.572886086116698}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.5939575250062528`, -2.5894449583555152`}, {
             2.598625216724198, -2.5940367975149834`}, {
             2.7391600771478863`, -2.7323515579655826`}, {
             2.8667136230472305`, -2.8579953403196807`}, {
             2.983935001209206, -2.973531199172445}, {
             3.1096316318882, -3.0974745933667482`}, {
             3.2260110297882596`, -3.212275218192116}, {
             3.266668507495944, -3.252394209701409}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.283475637532393, -3.2689787384337565`}, {
             3.334453152302638, -3.3192810837227698`}, {
             3.4363379568245884`, -3.4198402000329295`}, {
             3.532485103097533, -3.514755523848623}, {
             3.6237142508648943`, -3.6048300118958774`}, {
             3.767331832515476, -3.7466527131461023`}, {
             3.9008293471073126`, -3.878504137624973}, {
             3.9555578371025044`, -3.9325655354138704`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.9723561016264894`, -3.949159043852968}, {
             4.025646953909028, -4.001800327469761}, {
             4.143224812189247, -4.117957324817739}, {
             4.2544370551056785`, -4.227835683390112}, {
             4.36015781581603, -4.332295956908092}, {
             4.5314894288668395`, -4.501597568125071}, {
             4.6442026987033485`, -4.612984388079284}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.660997429791518, -4.629581472793541}, {
             4.690810180835224, -4.659043376770436}, {
             4.839823099113439, -4.806312778133519}, {
             4.980231211093739, -4.945085167503651}, {
             5.113069729040177, -5.07638198138656}, {
             5.239373865216806, -5.201224656287978}, {
             5.3335951424716646`, -5.292638855519119}}]}, 
           {Arrowheads[{{0.00869142470019154, 1.}}], 
            ArrowBox[{{5.350665384104337, -5.308950890831246}, {
             5.44712685291859, -5.398946888092006}, {
             5.548872338882944, -5.489978540410373}, {
             5.649197152922941, -5.575790550339642}, {
             5.656854249492381, -5.582186124312089}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAUNMtg8MV57+pLMT3a93hP52I18e1
Kue/iUwqmQr44T+XbGQiBT/nv8ciYGvvEeI/JzuS0KlV57+TCjC65i7iPwF1
3EC8cOe/nXxrK6pR4j+FPtx2AJnnv2mRT5elheI/7Fonq2mw578/BgtIBKTi
P43itGw50ee/+caHMcbO4j9Y0+2PX/Pnv5rQGO9/++I/OhCeBoUk6L/zbwWH
TjzjP0LSlJ7mcOi/wMdb+gSi4z8kLpKnDqbov7u06y9P6eM/nIT+pGrr6L/o
cwL6+UbkP6W1gGcjQum/9X3ffP685D++QaJV1p7pvwllQMBjO+U/RG4Mgn9M
6r8RpSaxqCbmPx/ApG0b6Oq/NtRLs+725j880cQPtHXrvyaIIcMcsuc/xpVT
mjpX7b/GK9orOiDqPw4OfAsmhO+/CzjkKrnT7D92pQlTXAnxv+Ce450U4O8/
HuqwufeC8r+MZXQsfKHxP+D85NDQSvS/DpLOxdOb8z+2yY5owCz1v8TykHMj
kPQ//RbV1g==
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.3394572287267712`, 
             1.3025254488798705`}, {-1.39397488415785, 
             1.3614770179315174`}, {-1.5418113889854732`, 
             1.5181272775805297`}, {-1.7104368036840805`, 
             1.6941504386910542`}, {-1.8117885731710546`, 
             1.7990504321267433`}, {-1.9023995315111009`, 
             1.8924457848334566`}, {-1.9924204685106572`, 
             1.9848969534809684`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.008892841782751, 
             2.0018140197786742`}, {-2.0127828858448256`, 
             2.0058090806124764`}, {-2.1118581194348525`, 
             2.107283178636263}, {-2.2017844288342645`, 
             2.1991800298664574`}, {-2.284721010596145, 
             2.2838115852647016`}, {-2.3615551106354076`, 
             2.3621144775486647`}, {-2.4335684583542494`, 
             2.4354389522193522`}, {-2.444546998600464, 
             2.446612201231679}, {-2.520044304924255, 
             2.52338971577361}, {-2.5913582670730424`, 
             2.595870735345052}, {-2.670284933285201, 2.6760548533318076`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.686848666403677, 
             2.6928824781943974`}, {-2.7269337319730136`, 
             2.733606175030631}, {-2.849944069507522, 
             2.8584786957360437`}, {-2.9629833957951344`, 
             2.973163946037288}, {-3.0839855524733286`, 
             3.095876551396213}, {-3.1960531083700676`, 
             3.209485620909801}, {-3.300511587875262, 
             3.3153473438393584`}, {-3.349952689579659, 
             3.3654409316404106`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.3665390839009826`, 
             3.3822462205922177`}, {-3.398686515378823, 
             3.4148179094461955`}, {-3.491363111473119, 
             3.50869868720743}, {-3.5793265967505192`, 
             3.5977910466001797`}, {-3.718650012675157, 
             3.7388793899240684`}, {-3.8481636165033186`, 
             3.870010856833325}, {-3.9692663115893794`, 
             3.9926082242762404`}, {-4.030184042364926, 4.054270992830511}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.046778457602151, 
             4.071068361561081}, {-4.083357001287714, 
             4.108094269201104}, {-4.191283057683795, 
             4.217329805560895}, {-4.293891852863094, 
             4.321175647308588}, {-4.460662798664357, 
             4.4899436264810255`}, {-4.615743153461358, 
             4.646867359581959}, {-4.710637057648532, 4.7428820986787255`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.727234947668515, 
             4.75967603390013}, {-4.760793109060602, 
             4.793630565945444}, {-4.897472857268592, 
             4.931916964905535}, {-5.026790710242614, 
             5.062748561460183}, {-5.149754980139959, 
             5.18714736060734}, {-5.250674618351772, 
             5.289240988806592}, {-5.348077696436102, 
             5.387774673452901}, {-5.391194111649557, 5.431390384680351}}]}, 
           {Arrowheads[{{0.0061640496473372875`, 1.}}], 
            ArrowBox[{{-5.407793920942699, 
             5.448182422816548}, {-5.44196421439295, 
             5.4827484145462675`}, {-5.532334172222317, 
             5.574162212086692}, {-5.610725385828728, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3347707918935973, 0.8766376944881277}, {
             0.3393804843399218, 0.8777462062267902}, {0.3480341822113954, 
             0.8797255595853858}, {0.3694669792202196, 0.8839918745432618}, {
             0.41215623704768056`, 0.8911132791084847}, {0.4333325165476006, 
             0.8941346861539489}, {0.4579445754401615, 0.8970365029252292}, {
             0.4870797713016781, 0.8994315161154842}, {0.5096716097605671, 
             0.9005496119191447}, {0.5325385568945293, 0.9015472394141908}, {
             0.5572282272813295, 0.9030991522555595}, {0.6747833137713735, 
             0.9211770655071791}, {0.7235752496373973, 0.9354823638957063}, {
             0.7681971991713448, 0.9526624383336277}, {0.8095815021678283, 
             0.972074909886293}, {0.9531700667915373, 1.0582073952460216`}, {
             1.1149436331128326`, 1.1824169990599949`}, {1.1794384457856768`, 
             1.2383467983575887`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1972770756184679`, 1.2538164298666072`}, {
             1.2869665773727883`, 1.3315950235911296`}, {1.3837315968835595`, 
             1.4198178619736421`}, {1.4698915508335206`, 
             1.4998868115415518`}, {1.5738697744662906`, 
             1.5980403092117184`}, {1.6665890779649548`, 1.686476233422455}, {
             1.7809213594797861`, 1.7964751881378214`}, {1.8829037176566725`, 
             1.8951787111966627`}, {1.8868433091844183`, 
             1.8990105919598634`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9037692893282556`, 1.915473805786653}, {
             1.996777632084241, 2.005939245392207}, {2.0994297451095427`, 
             2.106114427621631}, {2.1929049997962173`, 2.19757904334615}, {
             2.279248339207904, 2.2822078780269814`}, {2.3593355814975454`, 
             2.3608223177468526`}, {2.4344397105366147`, 
             2.4346200240485416`}, {2.4451078456962634`, 
             2.4451080079266476`}, {2.523276925267649, 2.522021850277909}, {
             2.5784860535362797`, 2.576379076913346}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.5953115618229785`, 2.592944960054018}, {
             2.59714531801631, 2.5947504205660925`}, {2.737610698964396, 
             2.7331121167582895`}, {2.8651003302542515`, 
             2.8587978071586497`}, {2.982262387089649, 2.9743716997179916`}, {
             3.107893664812156, 3.0983542316905357`}, {3.224212221369581, 
             3.2131908244022913`}, {3.267741373603273, 3.25617940208807}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.284541566171123, 3.272770958465316}, {
             3.332597387731997, 3.3202299902271277`}, {3.4344284948694757`, 
             3.4208202415389133`}, {3.5305248141290537`, 
             3.5157648205420853`}, {3.621705616857768, 3.6058669694410805`}, {
             3.7652489136855345`, 3.7477350468781117`}, {3.8986770541720843`, 
             3.879628359570859}, {3.9563444274823656`, 
             3.9366405508987454`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.9731357417748803`, 3.9532410923858823`}, {
             4.0234295392145665`, 4.002963481973655}, {4.140945869710132, 
             4.119156988540834}, {4.252099760196951, 4.2290697388475}, {
             4.3577649252131945`, 4.3335625924687555`}, {4.529008211944294, 
             4.502918772516135}, {4.6447035782573085`, 
             4.617348447163805}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.661491354096608, 4.633952567005146}, {
             4.688246491960791, 4.660415007278413}, {4.83718199900225, 
             4.807731313295967}, {4.977516966808234, 4.946547707109176}, {
             5.1102861320046475`, 5.077886010264792}, {5.236524231217394, 
             5.202768044309566}, {5.333843473303244, 5.297258724569156}}]}, 
           {Arrowheads[{{0.008679888999766404, 1.}}], 
            ArrowBox[{{5.350967580784651, 5.313514141985978}, {
             5.444176816935664, 5.400524649261752}, {5.5458791512297205`, 
             5.491549817769432}, {5.646165513147058, 5.5773395636315035`}, {
             5.656854249492381, 5.586267308416822}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAA5gZE72y4zb8Kj1/F8tvrP+tWSntW
lM2/KEOSLZT76z94SonP22zNv739EjG0Hew/OmqGnj9Gzb8asQNInj7sP+f5
ODYWB82/VmGM/4Bz7D/4lUHeNd3Mv+oGXD/0lew/mMaacr2ezL9BSe9wb8js
P3D/PwhHX8y/Ur3DOb/67D+oQpU45QLMv/0hr5c9Qu0/HRk/gKtuy7+Tg4rV
vrDtP4pX8UF92cq/D/HkkxAc7j/p1GMX2PXJv6i6/gj9uO4/Q2R7A8J4yL/5
BkUvXrDvPxSj3gHs3ca/KREeOyBZ8D+EAwyGi0fFv7MZBlbO2vA/HW/4A+Tp
w78d1K0ibVDxPzt2B4rqhL+/E+Zo5dHf8j+OBVdaUg+4v0+Ijq0dn/Q/K+37
5TB4sb99K8Nqm6P2PxpjsMrLhqe/UerJ4b8A+T+6CHKtluiavxYHOV1z5Ps/
epBd1+Fpl78J5SfmcZf8P5SXv1o=
             "]]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.02102630418949621, 
             1.8105141623485046`}, {-0.009957845924117404, 
             1.9522323896514457`}, {0.003478081796820913, 
             2.1858580175939233`}, {0.009811477838004016, 
             2.321603509361907}, {0.014872693136806815`, 
             2.4430200633338988`}, {0.02055746464617849, 
             2.5951011474589065`}, {0.02521095357422414, 
             2.7311680873854396`}, {0.025921568449891873`, 
             2.753726210643989}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.026665013025173972`, 2.777326496733349}, {
             0.029980088614836555`, 2.8825619573515184`}, {0.0340382387582181,
              3.0195452668552276`}, {0.040689591295512306`, 
             3.2606170654751803`}, {0.043509201426379485`, 
             3.368404210584276}, {0.04609491689657914, 3.469685246922172}, {
             0.0464766197946232, 3.484829449437277}, {0.04906747307054478, 
             3.589843842002848}, {0.05147989176191134, 3.689265930388063}, {
             0.0522513559571478, 3.7214570303095305`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.05281705823353721, 3.7450622457135605`}, {
             0.056017667157377396`, 3.878614939815326}, {0.0600538834829642, 
             4.050974731818807}, {0.06370818347447627, 4.209738514738763}, {
             0.06760212502007118, 4.381112923598348}, {0.07117046223747855, 
             4.540013279046567}, {0.07446646460491345, 4.6882646221351125`}, {
             0.07448916228352213, 4.689293137726551}}]}, 
           {Arrowheads[{{0.019993601940010857`, 1.}}], 
            ArrowBox[{{0.07501011400857925, 4.712899383142465}, {
             0.07754340160059092, 4.827691993915677}, {0.08043106414016403, 
             4.959386157110135}, {0.08315924313928583, 5.084437874440364}, {
             0.08741730513364844, 5.280638384753757}, {0.0913581822004847, 
             5.463233290422791}, {0.09502931989996653, 5.634136099248009}, {
             0.0955155990814619, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAUXpPSyCtzb8uv1d7p9zrv1lVKhMA
ic2/3Y1w4D78679dTzRsfWHNv0H8nAhSHuy/IzGvPuA6zb8nhSA8Kj/svz2N
R42y+8y/8MVTI/Nz7L/XFy/Mx9HMv+DheiZcluy/NGQTYzaTzL8oBfAt0Mjs
vx615k0VVMy/gX48ZsL67L+J2dzcY/jLv/geUsSXQe2/9qV3+Nxly7+PxDbo
sK7tv9O1l3CS0Mq/5BiY6/IZ7r/zjRYSKOvJvxH1Gm3Ft+6/h5J91lxnyL/p
h5O0uLLvv2B865I3ysa/8a66J7la8L+IGLkPSDPFv0IJJIRj3PC/DbqGtRzV
w7/qeshtAVLxv/D2eKLKV7+//CYK3HPh8r+tZlX5SN+3v/6BhoOooPS/ieK3
U9tEsb8SqvKiAKX2v6RiqdNmF6e/5hD+6RAC+b/0FaZoMPeZv2vJX/UQ5fu/
DfdzT8B2lr8l2eirOJf8v3bz0JY=
             "]]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.020086673281205083`, -1.810458633063391}, \
{-0.008917699275805423, -1.9525184930094823`}, {
             0.004632263477134929, -2.186064780817372}, {
             0.011030926493516792`, -2.3217520106406635`}, {
             0.01615235992662269, -2.4431265492245284`}, {
             0.021916400746164435`, -2.595226246880108}, {
             0.026640733417712302`, -2.731309343207008}, {
             0.0273559070509617, -2.7536458275691467`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.0281115329315101, -2.777245726782169}, {
             0.0314883077197629, -2.8827100136988686`}, {
             0.0356175035591823, -3.019700194919168}, {
             0.0423940219548485, -3.260785373293862}, {
             0.04526962895001552, -3.3685787669791036`}, {
             0.047907965200094944`, -3.4698656478284837`}, {
             0.04829743003487858, -3.485006562434004}, {
             0.050942841464967935`, -3.590026179777471}, {
             0.05340692442921915, -3.689453334828007}, {
             0.05418818352497327, -3.7213628458039474`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.05476611647367763, -3.744967764927786}, {
             0.05804310440857175, -3.8788120722066584`}, {
             0.06216891650027596, -4.051180917145601}, {
             0.06590575952959195, -4.209953186629788}, {
             0.0698888862811903, -4.381340147669669}, {
             0.07353991737041077, -4.540251964322814}, {
             0.0769130715072646, -4.688513848326642}, {
             0.07692828248741852, -4.689187281787602}}]}, 
           {Arrowheads[{{0.01999607790022682, 1.}}], 
            ArrowBox[{{0.07746147543651909, -4.7127932538839845`}, {
             0.0800625674017631, -4.827951011418572}, {
             0.08301876385772906, -4.959654325723488}, {
             0.08581201967898534, -5.08471466336627}, {
             0.09017210567368633, -5.280925065887487}, {
             0.0942079381853876, -5.4635293409700605`}, {
             0.09796795556917769, -5.634441042991583}, {
             0.09845933821028095, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.091260877573144, 0.0005807015929846177}, {
             1.0957623046941067`, 0.00044221799025128094`}, {
             1.1001876283914922`, 0.0004060559385729125}, {
             1.1045357224907262`, 0.00038603243723690886`}, {
             1.1108659713652824`, 0.0003683918990145189}, {
             1.1192924462931761`, 0.0003530213785047836}, {1.129428608301909, 
             0.0003395335328196691}, {1.2093295721155635`, 
             0.00031283498485546043`}, {1.3401497567848517`, 
             0.0003192755287183934}, {1.4473798468783592`, 
             0.0003339107119110817}, {1.5552192427797404`, 
             0.00035197634483954753`}, {1.658670692647187, 
             0.00037093299802838783`}, {1.8481472114622355`, 
             0.0004073125415127609}, {2.0144675360146715`, 
             0.00044047563590763077`}, {2.0357382102764086`, 
             0.00044483214624769986`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.059350202779136, 0.0004496681889712165}, {
             2.1616511221831605`, 0.0004706207458905765}, {2.293717425846368, 
             0.0004979463361391775}, {2.4839056030712015`, 
             0.0005376292118694553}, {2.6510401091658014`, 
             0.0005727053034646265}, {2.7999085042363134`, 
             0.0006040908466053928}, {2.9352983483888844`, 
             0.0006327020769724559}, {3.0038299020351635`, 
             0.0006472208620909021}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0274418945032475`, 0.0006522231920633396}, {
             3.1747461648845547`, 0.0006834304088110343}, {3.282113643914456, 
             0.0007062161936858611}, {3.3831009896359077`, 
             0.0007276639616888488}, {3.398523732007143, 
             0.0007309407182351753}, {3.502832477739721, 
             0.0007531162433531297}, {3.60164815485255, 
             0.0007741338164198716}, {3.789919125700303, 
             0.0008141917082490459}, {3.961403582661182, 
             0.000850700674388353}, {3.9719215930940237`, 
             0.0008529409624633499}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.99553358555639, 0.0008579702087716807}, {
             4.119405299473418, 0.0008843543168013935}, {4.289890878613812, 
             0.0009206788812024088}, {4.447974657705426, 
             0.0009543709193011033}, {4.595462733576572, 
             0.000985812455365768}, {4.734161203055559, 
             0.0010153855136646936`}, {4.8651531233295975`, 
             0.0010433196882857695`}, {4.940013284020025, 
             0.0010592856145547125`}}]}, 
           {Arrowheads[{{0.014679595001697972`, 1.}}], 
            ArrowBox[{{4.963625276480975, 0.0010643215018306344`}, {
             4.989521551585899, 0.0010698445733168852`}, {5.1840421467756395`,
              0.001111336373765741}, {5.365066220928731, 
             0.0011499543055376441`}, {5.5344891665715705`, 
             0.0011861013112171594`}, {5.656854249492381, 
             0.0012122104724202817`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAJTCFq/XN37+7epzHCDvoP/lultkB
29+/OLGsLr5b6D+bKDun3enfvzp0xU6Ggeg/ct2+ZKX3379q7EDzFaXoPxyG
fntcBuC/fAc0J4Xc6D/XjqZo0Qzgv+nad5kf/+g/mq7Fnf4V4L+SFfuePTHp
P7qpe+K4HeC/zIY6VUFc6T8DMvIJ/Sfgv4oiGUexluk/6aGUJX824L/HEvB9
G+zpPzsNpkdEReC/tCx/mYhG6j9106o0XVrgv4gZFwHSzuo/a/O1x/p54L8O
qT45JqvrP8uErncEm+C/Ic1zqhqd7D/IP3DSIL3gv5bochRdku0/mprNVwze
4L/zb5bJ12/uPxNmdvI4WuG/SIDxpduq8D8GTFsnlQPiv+Ig9MytTvI/arS9
8ubj4r8jn9yRZST0P8ON7ud5FOS/Np9S2M5O9j+IE6GT3Izlv+VDPLKRtPg/
5SonMyLu5r+pT0BuScj6P7quxPM=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7240129256143051, 
             1.696306072450264}, {-0.7310917967223965, 
             1.7176152139754803`}, {-0.799989515481792, 
             1.9134522482545817`}, {-0.8804078223227318, 
             2.133253440453061}, {-0.9288810152479269, 
             2.262934836241338}, {-0.9726401091833404, 
             2.3788242492460885`}, {-1.0276234146514909`, 
             2.5231607468421307`}, {-1.0503946160587103`, 
             2.5825412849157297`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0588490024908659`, 
             2.604587816692677}, {-1.0771559784475477`, 
             2.6523269791271877`}, {-1.138766655489786, 
             2.8120640401386137`}, {-1.1942265140774555`, 
             2.9552326193747738`}, {-1.2641142631636222`, 
             3.1349671566692137`}, {-1.326918234877569, 
             3.2960238861467945`}, {-1.3959739087312557`, 
             3.472684024728378}, {-1.4007935037169466`, 3.484992695217392}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.4094025914454857`, 
             3.5069792779854914`}, {-1.4587190122097196`, 
             3.632927531871296}, {-1.5162508823859535`, 
             3.7796504239843993`}, {-1.56966685633295, 
             3.9157487174765406`}, {-1.6194497320998462`, 
             4.042483542589169}, {-1.666304661281702, 
             4.161693966135661}, {-1.6696534800362153`, 
             4.170211723992976}, {-1.7180526185861527`, 
             4.293255108821644}, {-1.7545944171721881`, 
             4.3861176515676705`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-1.7632405129781425`, 
             4.4080897074717145`}, {-1.7639350125160438`, 
             4.409854617671019}, {-1.85140988888048, 
             4.63208727942912}, {-1.9311927844714725`, 
             4.8346702904492345`}, {-2.0047929964335576`, 
             5.021481010304384}, {-2.0845543138156652`, 
             5.223870475547104}, {-2.1093827583225746`, 5.286854443632117}}]}, 
           {Arrowheads[{{0.007921990470156957, 1.}}], 
            ArrowBox[{{-2.1180421376922243`, 
             5.308821267760075}, {-2.158577291264056, 
             5.411649490373009}, {-2.2276937367481766`, 
             5.586942447172154}, {-2.255263908201259, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAJ+r6XVjH37//A3WWKT/ov0Vf+aRV
1N+/m9qvleVf6L9H1wXcIOPfv17Gazy3hei/FiVrEtbw379SG06RSKnov612
QtXmAuC/gojfD73g6L/qiWZRVAngvyYc+QtiA+m/yvPnK3gS4L/YJj0gmDXp
vwnPQD8SGuC/gAoltShg6b+0YiGEJCTgv1ekYbLRmem/V2H0C08y4L/AnJYS
qu3pv15exc/kQOC/elAxFmxH6r9orRZO0lXgv8WdI2N3z+q/X8g//mp14L+p
EHHmeq3rv2+X5jY+luC/U1PRkN6f7L/GplXzFLjgv1WCj3X0lO2/7JCOWsPY
4L+DPRacQXLuv9OmrcAmVOG/fBNTkM6r8L8HW+ZAw/zhv0P6YLS6T/K/9kXz
skTc4r91TxUZjyX0v/N1/pvtC+S/X8uCtB9Q9r/JxZOxWYPlv8lmyMYUtvi/
q17wmovk5r+tmghgFMv6v8Thza4=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7228249102777808, -1.6969937268444162`}, \
{-0.7297980627932383, -1.7180397762198922`}, {-0.7985481323969411, \
-1.9139378605372226`}, {-0.8788017338115568, -2.133805894777889}, \
{-0.9271776504290038, -2.263525320894617}, {-0.9708501543021991, \
-2.3794491853153765`}, {-1.0257246979053598`, -2.5238257282850425`}, \
{-1.0485464963225897`, -2.5834718071765277`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.0569843667469891`, -2.605524665404821}, \
{-1.075160209907102, -2.653028273807079}, {-1.136650501725509, \
-2.812809046316895}, {-1.1920026784012747`, -2.9560172249881194`}, \
{-1.2617540073352809`, -3.1357981477357963`}, {-1.3244359670705022`, \
-3.2968969618539563`}, {-1.3933558446442649`, -3.473598165260307}, \
{-1.3982731290586805`, -3.486183948065033}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.4068658251602553`, -3.5081769421095497`}, \
{-1.455978080411796, -3.6338796929681507`}, {-1.513397685825837, \
-3.780637986421685}, {-1.5667096723391285`, -3.916769487065106}, \
{-1.6163958206356257`, -4.043535494943496}, {-1.663159841719467, \
-4.16277544037016}, {-1.666502755755501, -4.171296813497623}, \
{-1.714807764247215, -4.2943699014321774`}, {-1.7514030650930854`, \
-4.387572056163051}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.760032794925457, -4.40955054510921}, \
{-1.7606010645059151`, -4.4109978333714315`}, {-1.847906202147782, \
-4.633284841769853}, {-1.9275344886362653`, -4.835917701413721}, \
{-2.000992239292816, -5.022774673992132}, {-2.0805983472258887`, \
-5.225212049354595}, {-2.105520792239026, -5.28857270594532}}]}, 
           {Arrowheads[{{0.007880420577425187, 1.}}], 
            ArrowBox[{{-2.114163813489177, -5.310545971451512}, \
{-2.1544774553516466`, -5.413035868274355}, {-2.223459703890091, \
-5.5883709269716215`}, {-2.2504076436431255`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8092776517014912, 0.6640127691079387}, {
             0.8605218190849441, 0.6250536888018962}, {0.9052700928097591, 
             0.5926867848643561}, {0.933576731066304, 0.5744377202452504}, {
             0.9615585182212673, 0.5596041659078744}, {0.9896894920053747, 
             0.5482382734170959}, {1.0184708478996263`, 0.5405483230736102}, {
             1.143827980695652, 0.540070569695524}, {1.2456073614537548`, 
             0.5596773879338479}, {1.3468347426261955`, 0.5876977969132063}, {
             1.443663779516755, 0.6187427199909177}, {1.6205316520106208`, 
             0.6797418632539673}, {1.6924675260130477`, 
             0.7060090084977029}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7146471434980681`, 0.7141078220870097}, {
             1.7751253633476873`, 0.7361912430074107}, {1.9113834319778218`, 
             0.7879648532400507}, {2.03324437635089, 0.8349366879406898}, {
             2.1750782496268126`, 0.8902350635499455}, {2.3020939930410256`, 
             0.9401043596044142}, {2.45596910184618, 1.0008698641822313`}, {
             2.59375974612365, 1.0554950329380202`}, {2.5950449007530927`, 
             1.056006156745811}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6169853394149234`, 1.0647321732861692`}, {
             2.748711441769842, 1.1171214698568714`}, {2.888531111790139, 
             1.1728492870903793`}, {3.006721601503687, 1.2200308388773526`}, {
             3.1177833069096383`, 1.264397978422112}, {3.3185203647987485`, 
             1.3446890207849886`}, {3.494108668288543, 
             1.4150121132657094`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.5160262185912465`, 1.4237954610567822`}, {
             3.6591251025299307`, 1.4811467596573509`}, {3.8079410337820576`, 
             1.5408237236816977`}, {3.946138330623904, 1.596263573766911}, {
             4.0749524670500135`, 1.6479567629502603`}, {4.196190420218849, 
             1.6966211233207202`}, {4.20428609776738, 1.6998710628143447`}, {
             4.329157105658671, 1.7500091213565525`}, {4.392587070493097, 
             1.7754813576959456`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.414498293751548, 1.7842804774618377`}, {
             4.447536969631231, 1.7975481651003957`}, {4.6732271246878705`, 
             1.8881911746460134`}, {4.879061406059001, 1.9708766315201924`}, {
             5.068925005112918, 2.047158037988941}, {5.274842146893378, 
             2.1298984991899887`}, {5.290903947542091, 
             2.136353008883598}}]}, 
           {Arrowheads[{{0.007851892220783429, 1.}}], 
            ArrowBox[{{5.312813092830902, 2.145157301362266}, {
             5.4659031585541165`, 2.2066772601026914`}, {5.643549137907119, 
             2.278101379582605}, {5.656854249492381, 2.2834561681009298`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8130483261304753, -0.6609527602259618}, {
             0.8625115196834369, -0.6231799180476634}, {
             0.9059390995082298, -0.59165714528966}, {
             0.9341500525119844, -0.5733794178611625}, {
             0.9620670412608202, -0.5585341771462218}, {
             0.9901243978127638, -0.5471416386494847}, {
             1.0188259571006164`, -0.5394069400716721}, {
             1.143978712271981, -0.5387365324934592}, {
             1.245664865106267, -0.5582000509800418}, {
             1.3468637931576677`, -0.586097199203558}, {
             1.4437020373223588`, -0.6170376929827421}, {
             1.620621571068928, -0.6778593080926452}, {
             1.6966753058598365`, -0.7055456988579696}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.7188628436776787`, -0.7136227886134436}, {
             1.7752819595871114`, -0.734161447155291}, {
             1.9116105229519402`, -0.7858094074568708}, {
             2.033534581238447, -0.8326684862835764}, {
             2.175414128167208, -0.8878243405701035}, {
             2.3024711354385365`, -0.9375656542841323}, {
             2.456382048087991, -0.998170004348617}, {
             2.5942053204921884`, -1.0526507132927188`}, {
             2.599552311993467, -1.0547711656791987`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.6215013671519896`, -1.0634754859274609`}, {
             2.7491961021627187`, -1.1141152906718021`}, {
             2.8890509848112957`, -1.169696809357616}, {
             3.0072565092724997`, -1.2167486890066026`}, {
             3.1183328920048727`, -1.260994128771547}, {
             3.3190982322831286`, -1.341065688649309}, {
             3.4975158946441787`, -1.4123166210117608`}, {
             3.498967184707561, -1.412896599307254}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.52089317008663, -1.4216588694750254`}, {
             3.659754768086139, -1.4771520578797608`}, {
             3.8085942069584586`, -1.5366669947877012`}, {
             3.9468135656105865`, -1.5919564272699753`}, {
             4.0756484963216835`, -1.6435094663946854`}, {
             4.196906200067901, -1.6920419661650012`}, {
             4.205009487910598, -1.6952856182424758`}, {
             4.3299011539245615`, -1.7452879576306313`}, {
             4.397801619814246, -1.7724771530175858`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.419721574198417, -1.7812544996059378`}, {
             4.448300761702938, -1.7926983844582636`}, {
             4.674028677178657, -1.883096211460804}, {
             4.879897644739286, -1.9655581165735023`}, {
             5.069793408855157, -2.0416333576336267`}, {
             5.275747821091274, -2.12415115503061}, {
             5.296476222195736, -2.1324570403378527`}}]}, 
           {Arrowheads[{{0.007721397697538584, 1.}}], 
            ArrowBox[{{5.3183941073340755`, -2.1412395527573556`}, {
             5.466843381782577, -2.200723284343737}, {
             5.6446028965498245`, -2.2719836167263177`}, {
             5.656854249492381, -2.276899211039729}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.35244322021297403`, 1.1822119406044165`}, {
             0.40071505898056164`, 1.2416838539586388`}, {0.441010121783222, 
             1.2973730103547305`}, {0.5617614667069813, 
             1.4912903303953748`}, {0.6504777571791972, 
             1.6578680774622216`}, {0.7204600467152981, 
             1.7991345948524529`}, {0.7792821540260905, 1.922574685544491}, {
             0.8162224267697529, 2.0019892434878623`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8261810548232784, 2.0233983990206643`}, {
             0.830450840854691, 2.032577626595685}, {0.9183763398303583, 
             2.22503045424048}, {0.9923004659106553, 2.3897045202711635`}, {
             1.0610870359176998`, 2.544762306425965}, {1.122054862128951, 
             2.6831714995339584`}, {1.177049294439774, 2.808624697795502}, {
             1.2108340246000249`, 2.885982081379368}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2202842726922678`, 2.907620450641658}, {
             1.275309336606184, 3.0336121325560996`}, {1.3606936408103736`, 
             3.229899503442504}, {1.4361091984554148`, 3.4038313190880203`}, {
             1.50446300094438, 3.5617520881259517`}, {1.5670044208217928`, 
             3.706452599424783}, {1.5961999467914023`, 
             3.7740659354752206`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.60556028267384, 3.7957433505772133`}, {
             1.6249828306321765`, 3.8407236418529975`}, {1.678941776879631, 
             3.9657925869227126`}, {1.729673813983215, 4.083452003868954}, {
             1.7333088806811352`, 4.091885010575246}, {1.7855972111430958`, 
             4.213248326748949}, {1.835130626332682, 4.328262126858347}, {
             1.9295125631122692`, 4.54747463718284}, {1.979284813974955, 
             4.6631370358147075`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9886181280541348`, 4.684826098994927}, {
             2.015503209133171, 4.747302537394155}, {2.0947638210995345`, 
             4.931562015804677}, {2.1805988597481774`, 5.131162351247019}, {
             2.260208577099291, 5.316334131850767}, {2.334489979769493, 
             5.489145739558403}, {2.3617149871751417`, 
             5.552490009020823}}]}, 
           {Arrowheads[{{0.0019055646786452828`, 1.}}], 
            ArrowBox[{{2.3710386139676354`, 5.574183238304875}, {
             2.4043400743754035`, 5.6516655563124045`}, {2.4065830466457836`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.35296392106737, -1.1820083890509705`}, {
             0.40126941208217226`, -1.241451652031648}, {
             0.4415966752777676, -1.2971212731169064`}, {
             0.5624507008683408, -1.4909838343049175`}, {
             0.6512520314319198, -1.657532126492156}, {
             0.7213066182646815, -1.7987797131423648`}, {
             0.7801918137517526, -1.9222051649910001`}, {
             0.8171464491231292, -2.001554643235545}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8271149746417836, -2.0229591921053554`}, {
             0.831416647988408, -2.0321958015916306`}, {
             0.9194402232970198, -2.224627527644483}, {
             0.993448003288826, -2.3892835052287715`}, {
             1.0623118407919114`, -2.544321158288866}, {
             1.1233485804244598`, -2.6827123088385596`}, {
             1.1784054220739841`, -2.8081490505276334`}, {
             1.2121704668309772`, -2.8853632647429546`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.2216307945820657`, -2.9069972290624717`}, {
             1.2767772775563935`, -3.033106712412688}, {
             1.3622589732376167`, -3.229367737417964}, {
             1.4377607039920588`, -3.4032759066062703`}, {
             1.5061926646941246`, -3.5611750010404166`}, {
             1.56880563558741, -3.7058554913014814`}, {
             1.5979513538539667`, -3.7732669385116777`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.607321814707427, -3.7949399788320832`}, {
             1.6268503969155106`, -3.840107847970542}, {
             1.6808711053143952`, -3.9651592827013786`}, {
             1.7316612104404785`, -4.082802140195691}, {
             1.7352997835792432`, -4.091232441126294}, {
             1.7876480155822203`, -4.2125786811507195`}, {
             1.8372381609060173`, -4.3275762089039365`}, {
             1.9317281873602026`, -4.546757615284294}, {
             1.9814519824457417`, -4.662158779405948}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.990795436137498, -4.68384347646277}, {
             2.017817289782251, -4.746556979363443}, {
             2.09716862667071, -4.930789998756877}, {
             2.1831014210548068`, -5.130360454670969}, {
             2.2628018096408, -5.315504470824832}, {
             2.3371662047637063`, -5.4882856811281036`}, {
             2.3642986755270363`, -5.5513325296439575`}}]}, 
           {Arrowheads[{{0.001932757349220535, 1.}}], 
            ArrowBox[{{2.37363254945684, -5.573021351898721}, {
             2.407091018758544, -5.6507677194904185`}, {
             2.409725666747302, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.121385848013006, -0.8248642413672399}, {
             1.2737880177089336`, -0.8975433045600729}, {
             1.4071582961296116`, -0.9698434317941231}, {
             1.5246697629606472`, -1.0391196297524778`}, {
             1.6294954978876564`, -1.1027269051182285`}, {
             1.7498945737604783`, -1.1774409983010332`}, {
             1.857450285094003, -1.2450635818869813`}, {
             1.938607823416249, -1.2966350404618754`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9585366063576934`, -1.309298761234577}, {
             1.9856822767569786`, -1.3265484443253308`}, {
             2.100362924941204, -1.3999258380803046`}, {
             2.2392474405943674`, -1.4893012037278728`}, {
             2.3635795401264685`, -1.5696250960983693`}, {
             2.514931129888573, -1.6677278191849498`}, {
             2.6505790266599716`, -1.7558553903935976`}, {
             2.7518732621061, -1.8217940809194806`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.7716618844094523`, -1.8346757205927302`}, {
             2.8186690064441726`, -1.8652755672543726`}, {
             2.9692763506578648`, -1.9634546013945204`}, {
             3.1391796634336666`, -2.074345332934581}, {
             3.2926761965064406`, -2.174611178818616}, {
             3.4239417993546417`, -2.26040843537009}, {
             3.547331301139371, -2.341080964055494}, {
             3.5625107851382793`, -2.351008614237459}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.5822717535867583`, -2.3639326360307855`}, {
             3.6628447018606285`, -2.4166287648748273`}, {
             3.7704820015184137`, -2.48705183782809}, {
             3.9689491895399502`, -2.6169451967558603`}, {
             4.149553757100362, -2.735182437458261}, {
             4.315357337934383, -2.843756123390109}, {
             4.372515617753831, -2.881191318660131}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.392268243937922, -2.8941280868874633`}, {
             4.469421565776747, -2.9446588180062214`}, {
             4.613107270750673, -3.038777838350546}, {
             4.7484054717719095`, -3.127411782303605}, {
             4.753052993866188, -3.130456523521341}, {
             4.892168477129424, -3.221603095284652}, {
             5.024111082559376, -3.308055914836333}, {
             5.152992908899657, -3.3925052782249403`}, {
             5.182300479624089, -3.4117099676499327`}}]}, 
           {Arrowheads[{{0.011519646134902774`, 1.}}], 
            ArrowBox[{{5.2020500123362075`, -3.424651457942364}, {
             5.2757531770606, -3.472947729287401}, {
             5.393019967912984, -3.5497939539309518`}, {
             5.505421362327589, -3.6234546380628285`}, {
             5.656854249492381, -3.7231355512207647`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7932722056707954, -1.0684810380346803`}, \
{-0.8224846523757974, -1.1262271299412354`}, {-0.8489957218321578, \
-1.1769826808124733`}, {-0.8734174959030458, -1.222565683223284}, \
{-0.9578366917515038, -1.3744799087390522`}, {-1.0299280369264543`, \
-1.498110533552715}, {-1.0920384033108315`, -1.6018657896549566`}, \
{-1.1471694139620412`, -1.6924325174916672`}, {-1.197037917344564, \
-1.7734037532600582`}, {-1.2668277951667581`, -1.8852490267770479`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.2793275154488957`, -1.9052810812449372`}, \
{-1.3193610957085276`, -1.969438905756545}, {-1.421400068003356, \
-2.1308712432453754`}, {-1.5100450477576683`, -2.2700945139759794`}, \
{-1.5888980778490078`, -2.3933535561175017`}, {-1.6607143851888004`, \
-2.5052994434956912`}, {-1.7269332577502658`, -2.608317190610597}, \
{-1.78709068619178, -2.701650013535534}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.7998827779983522`, -2.721496640466788}, \
{-1.8452617470499921`, -2.791901034283764}, {-1.9582162074882872`, \
-2.966692782110404}, {-2.059170673849582, -3.122658649799742}, \
{-2.150801505872807, -3.2640579059051036`}, {-2.235684700582179, \
-3.394952823026012}, {-2.3131414954179657`, -3.514343872076619}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.325996256427801, -3.534149965295445}, \
{-2.389928594747386, -3.6326457626280777`}, {-2.4592892942032205`, \
-3.739443785109234}, {-2.5870389027456713`, -3.936044758015367}, \
{-2.703193260718709, -4.114720183235639}, {-2.8097592511778995`, \
-4.2785845532501225`}, {-2.8406592318900445`, -4.326086758395129}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.853534389611896, -4.345879598690893}, \
{-2.9087437571788093`, -4.4307523605388885`}, {-3.0010321940421383`, \
-4.572593981378857}, {-3.0879184043563406`, -4.7061110890938735`}, \
{-3.0910863189249502`, -4.7109788153200975`}, {-3.1805440024587917`, \
-4.848418611515683}, {-3.2653779419764515`, -4.978740466248304}, \
{-3.3482403154119282`, -5.106028550637686}, {-3.3687159027508846`, \
-5.137479205634962}}]}, 
           {Arrowheads[{{0.012627247787902009`, 1.}}], 
            ArrowBox[{{-3.3815986067127324`, -5.15726713508621}, \
{-3.4271595566830393`, -5.227249094340587}, {-3.5025416741474005`, \
-5.343027867591751}, {-3.574792676162627, -5.453990640625917}, \
{-3.7071704368228913`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.121296158626235, 0.8259488543512439}, {
             1.2736237633773744`, 0.8987656354729969}, {1.4069020015849467`, 
             0.9711552939024228}, {1.5243178056517463`, 
             1.0404926079997556`}, {1.62905810798057, 1.1041523561252318`}, {
             1.7493971277046243`, 1.178948945367545}, {1.8568986242866732`, 
             1.2466449997112528`}, {1.9381521054196253`, 
             1.2983591283895655`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.9580718163747242`, 1.3110371143810975`}, {
             1.9850802033004953`, 1.3282267187820167`}, {2.0997152005073785`, 
             1.4016906710460884`}, {2.2385512642789407`, 
             1.4911756007991948`}, {2.362839404093462, 1.5715974588919874`}, {
             2.5141416362634326`, 1.6698224103915995`}, {2.6497447858278615`, 
             1.7580593852952944`}, {2.7510400266165593`, 
             1.8241023374280536`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.770819393970811, 1.8369981832863802`}, {
             2.8177835814159073`, 1.8676181172461648`}, {2.9683444076588223`, 
             1.9659210094456019`}, {3.1381911154015447`, 2.07694890661051}, {
             3.2916364235809312`, 2.1773387001565463`}, {3.4228701104574086`, 
             2.263249790717584}, {3.5462290923924433`, 2.344029010697015}, {
             3.5612970767850873`, 2.353899212162922}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.5810487485011806`, 2.366837437611408}, {
             3.661713369386035, 2.4196763600948414`}, {3.769322941438184, 
             2.4901918389110618`}, {3.9677379972623905`, 
             2.6202549721812867`}, {4.148294286409299, 2.7386461978902914`}, {
             4.314052901995231, 2.8473608582382255`}, {4.370920509674428, 
             2.8846641561927147`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.390663825830623, 2.897615128376017}, {
             4.468074937136508, 2.948394295425238}, {4.611720943567816, 
             3.042635038637753}, {4.746981521254616, 3.1313834520265185`}, {
             4.7516251023892355`, 3.1344303875699087`}, {4.890702568572275, 
             3.225695110993335}, {5.022608890083799, 3.312259848734956}, {
             5.151455205593034, 3.396818491650971}, {5.1803235948079385`, 
             3.4157650931237367`}}]}, 
           {Arrowheads[{{0.011575580129270121`, 1.}}], 
            ArrowBox[{{5.200063812380403, 3.428720787760765}, {
             5.274181509097691, 3.4773649449157733`}, {5.391415731119277, 
             3.554310440876161}, {5.503785802179298, 3.6280662118789313`}, {
             5.656854249492381, 3.7289923239386917`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7934053934193744, 
             1.0682943850820616`}, {-0.8226091901921221, 
             1.1260003062108377`}, {-0.849113067297052, 
             1.176723159159448}, {-0.8735286382742571, 
             1.222278370818003}, {-0.9579284113534801, 
             1.3741058796058603`}, {-1.030034779277403, 
             1.4977212380906508`}, {-1.0921561199110121`, 
             1.6014597825096897`}, {-1.1472958701429228`, 
             1.6920099318997408`}, {-1.1971717041491168`, 
             1.7729652209262448`}, {-1.2670946737949516`, 
             1.8849848591663994`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.279597520108942, 
             1.9050149626954602`}, {-1.319525865075236, 
             1.9689819077681199`}, {-1.4215877329626025`, 
             2.13039375727438}, {-1.5102511752491896`, 
             2.269596874174728}, {-1.5891197830237371`, 
             2.3928366255765}, {-1.6609498195831647`, 
             2.5047642188928636`}, {-1.7271810592519703`, 
             2.607764643544321}, {-1.7874909805795236`, 2.701300808988998}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.8002862841903866`, 
             2.7211453653922537`}, {-1.8455309280358794`, 
             2.7913164151807743`}, {-1.958510132467917, 
             2.9660842516644834`}, {-2.059485880197109, 
             3.122027448182707}, {-2.151135474422275, 
             3.2634052694298123`}, {-2.236035726194285, 
             3.3942798322586363`}, {-2.313674510497986, 3.513908743116367}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.3265325545916067`, 
             3.5337127051326473`}, {-2.390310035515455, 
             3.6319348967940184`}, {-2.4596840930646158`, 
             3.738715398500576}, {-2.5874579288412685`, 
             3.9352835263595947`}, {-2.7036340021231515`, 
             4.11392861052526}, {-2.8102196755119597`, 
             4.277764778725248}, {-2.8413248841451075`, 4.325565418708162}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.854203270175822, 
             4.345356158628135}, {-2.909222311609389, 
             4.429906158687234}, {-3.0015275220501887`, 
             4.57172294217185}, {-3.0884294350727544`, 
             4.705216531101257}, {-3.091598651597568, 
             4.710084520261078}, {-3.1810728201566834`, 
             4.847500591100353}, {-3.265922315115152, 
             4.9777998284963205`}, {-3.3487998543441844`, 
             5.105065778295448}, {-3.369514067965517, 5.136871610705172}}]}, 
           {Arrowheads[{{0.01264401130357814, 1.}}], 
            ArrowBox[{{-3.3824000013752955`, 
             5.15665743728621}, {-3.427733482114344, 
             5.226265152900896}, {-3.50312929125549, 
             5.342023629536518}, {-3.5753933745974815`, 
             5.452966885426169}, {-3.708486188194901, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7096337218782942, 1.2094755130993255`}, {
             0.8139682817206229, 1.322494509849107}, {0.8988548845480131, 
             1.4247663727276445`}, {0.9711877850250127, 
             1.5170926646528202`}, {1.0936825742307161`, 
             1.6793187144744777`}, {1.1948733559202382`, 
             1.8179074883671147`}, {1.2909124082175056`, 
             1.9528008159027148`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.3046069999006047`, 1.9720357937287836`}, {
             1.3300956680796767`, 2.007836347596011}, {1.4431047149693348`, 
             2.1688591314628995`}, {1.54121998175209, 2.30976905497924}, {
             1.6283913398647203`, 2.4355902662310958`}, {1.707683243221792, 
             2.5503692318380735`}, {1.7807030249809717`, 
             2.6562796240994815`}, {1.843530357776752, 
             2.747657134780136}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.856907997838906, 2.7671138806463804`}, {
             1.9109382231478662`, 2.845696676868143}, {2.0307678460456873`, 
             3.0204241152916604`}, {2.1380348636848914`, 
             3.1770750074341314`}, {2.2354921506023677`, 3.319552466372058}, {
             2.3258214050352968`, 3.45169494730466}, {2.390532943711646, 
             3.546399247830213}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.4038541756165057`, 3.5658946573892116`}, {
             2.410664822704767, 3.575861930333317}, {2.4900224036107796`, 
             3.6920534154580293`}, {2.563894147753334, 3.8002694026787975`}, {
             2.6999793448143374`, 3.9997166477838793`}, {2.823719632954048, 
             4.181145430023941}, {2.9361693126655197`, 
             4.346075704547362}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.9494687011360883`, 4.365586021797042}, {
             3.042689513077414, 4.502344264674213}, {3.140992570981686, 
             4.646587638803307}, {3.233532953598167, 4.782394675365811}, {
             3.2365818088616307`, 4.786869305166735}, {3.3317476691709498`, 
             4.9265550527678394`}, {3.4219894756852534`, 
             5.0590257900936795`}, {3.4813014655167835`, 
             5.146096009940433}}]}, 
           {Arrowheads[{{0.012597921415547561`, 1.}}], 
            ArrowBox[{{3.494594696979768, 5.165610522760581}, {
             3.5101315889671576`, 5.188418737506365}, {3.5940743157842636`, 
             5.311656105092743}, {3.674055441276938, 5.429033085470019}, {
             3.7503127505855485`, 5.5408448712554}, {3.8301730248619643`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7100996834598449, -1.2090613204423255`}, {
             0.8144913145634753, -1.3220307906052529`}, {
             0.8994309572071885, -1.4242707232137803`}, {
             0.9718120518266984, -1.5165732203430597`}, {
             1.094391225252338, -1.6787613086652666`}, {
             1.1956534984305174`, -1.8173196169306567`}, {
             1.2917166239900455`, -1.9521211418571638`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.305419680344834, -1.9713500903430705`}, {
             1.3309732599447115`, -2.0072084020243808`}, {
             1.444063782017471, -2.1681964296821774`}, {
             1.5422496290669234`, -2.309075209248199}, {
             1.629483507840159, -2.434868017864732}, {
             1.708832116545823, -2.5496206516874644`}, {
             1.7819039892162536`, -2.6555064331992155`}, {
             1.84468666941531, -2.7467325519238823`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8580729133349703`, -2.766183379337119}, {
             1.9122317669852154`, -2.844878681885916}, {
             2.032151121041861, -3.0195711455404686`}, {
             2.1394977843199183`, -3.176189538424494}, {
             2.2370269464428025`, -3.318636626496688}, {
             2.3274225121956054`, -3.450750431968783}, {
             2.3920433366306613`, -3.545232064238647}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.405373206358375, -3.5647215687571907`}, {
             2.4123280238718428`, -3.5748901563070428`}, {
             2.4917434814715147`, -3.6910557995114677`}, {
             2.565668884994621, -3.799247361582057}, {
             2.7018525484377136`, -3.998648959805783}, {
             2.825682032827695, -4.180035668462274}, {
             2.9380344481549083`, -4.344666357147888}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9513425170251195`, -4.364170754491869}, {
             3.044809063479187, -4.501158896187997}, {
             3.1431824342079975`, -4.64536793351453}, {
             3.2357889002075373`, -4.78114246886904}, {
             3.238839441414097, -4.785615307274854}, {
             3.334073511983016, -4.925267975303623}, {
             3.4243799094775036`, -5.057707200154631}, {
             3.483521585859178, -5.1444446612454815`}}]}, 
           {Arrowheads[{{0.012644431220154077`, 1.}}], 
            ArrowBox[{{3.4968234746121207`, -5.16395327393169}, {
             3.5125850733226494`, -5.18706930882494}, {
             3.5965877698691093`, -5.310277185133851}, {
             3.676624096132365, -5.42762237843151}, {
             3.7529301491278972`, -5.539396438068064}, {
             3.8338694459801106`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3409050411330318, 
             1.3798097664239128`}, {-0.3460855396357953, 
             1.469564290188452}, {-0.35233115434363654`, 
             1.5480823075074155`}, {-0.3590461734713392, 
             1.618430520069957}, {-0.38603652023593044`, 
             1.8522835786672749`}, {-0.413959323443599, 
             2.051479698392027}, {-0.4391071007303274, 
             2.216859473984116}, {-0.455000799778307, 2.3169168503131354`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.4587050254973658, 
             2.340236475635135}, {-0.4618647178792248, 
             2.360128039504641}, {-0.4826332160717173, 
             2.4873359909086092`}, {-0.5197094770011047, 
             2.7096711793426125`}, {-0.5521059295852004, 
             2.899943199363959}, {-0.5829726588804791, 
             3.0786993971856043`}, {-0.6108193239334501, 
             3.2385666281927423`}, {-0.6165768473767326, 
             3.2714209369813796`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.6206525986964805, 
             3.294678504879071}, {-0.6362598382258055, 
             3.383738509911779}, {-0.65992119211903, 
             3.5182617216029044`}, {-0.6821949056194273, 
             3.6446073937932306`}, {-0.7225794114417402, 
             3.872766119671489}, {-0.758595312104132, 
             4.075390129955253}, {-0.7851993341642216, 
             4.2247137619257265`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.7893409116947511, 
             4.247959698105944}, {-0.7914245640179906, 
             4.2596548670532215`}, {-0.8216063142502577, 
             4.428732437102154}, {-0.8496797098678751, 
             4.585794946238807}, {-0.8758864674019212, 
             4.732243717831014}, {-0.9005806796670781, 
             4.870126925758124}, {-0.90190152053362, 
             4.877499100190066}, {-0.9273453622253833, 
             5.019416347602748}, {-0.951488840009586, 
             5.154007466647742}, {-0.9557337765814993, 
             5.177666785815479}}]}, 
           {Arrowheads[{{0.009809347215829215, 1.}}], 
            ArrowBox[{{-0.9599036370244787, 
             5.200907665257149}, {-0.975076509065266, 
             5.285474258001885}, {-0.9975525606639005, 
             5.41069239397433}, {-1.0396231222492454`, 
             5.644952533589608}, {-1.0417617068242764`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3400573261137225, -1.3799076236523196`}, \
{-0.34516541057854533`, -1.469533178346213}, {-0.3513456858115506, \
-1.547954574403869}, {-0.3580016347570572, -1.6182260149699474`}, \
{-0.38479714290835615`, -1.8518623770676377`}, {-0.41260344854157227`, \
-2.051224535466088}, {-0.43765638405890045`, -2.21671680962878}, \
{-0.45353331286841725`, -2.317089338415221}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.45722239150590727`, -2.3404113647453357`}, \
{-0.46033195327529036`, -2.3600697370889554`}, {-0.48102732571731005`, \
-2.48734447678144}, {-0.5179748995410045, -2.709784439712279}, \
{-0.5502602148227599, -2.9001352989894102`}, {-0.5810107814553371, \
-3.0788949100718033`}, {-0.6087538349995266, -3.2387666230961982`}, \
{-0.6145029975449493, -3.271695864124627}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.6185640189039557, -3.2949560085536254`}, \
{-0.6341003960527005, -3.383943074721534}, {-0.6576747930814729, \
-3.5184710307536005`}, {-0.6798668944517771, -3.6448214413576583`}, \
{-0.7201042102169803, -3.87298962628175}, {-0.7559895586648927, \
-4.075622818235496}, {-0.7825225744933303, -4.225095137432155}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-0.7866494533205559, -4.248343687590855}, \
{-0.7887001551120966, -4.259896205960583}, {-0.818773096341716, \
-4.4289820431448765`}, {-0.8467454791368754, -4.586052583476244}, \
{-0.8728580830845266, -4.732509013378868}, {-0.8974636498327997, \
-4.870399419116316}, {-0.898780089392499, -4.877773872975347}, \
{-0.924133221283564, -5.019701475514144}, {-0.9481906982868494, \
-5.154302573850907}, {-0.9524548541454005, -5.178155724235938}}]}, 
           {Arrowheads[{{0.009797661731872642, 1.}}], 
            ArrowBox[{{-0.9566100264264977, -5.201399234225838}, \
{-0.9716943523841953, -5.285779052286251}, {-0.9940903606696624, \
-5.411006290918756}, {-1.036011148405969, -5.645283311538488}, \
{-1.0380827491079645`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0762585224675973`, 0.306551410078501}, {
             1.0927250569763547`, 0.2968863963496185}, {1.1117183707904044`, 
             0.2894122854287231}, {1.21715323280638, 0.27983758023341}, {
             1.3113493715279643`, 0.286213055088622}, {1.4121447024470075`, 
             0.2986520868176742}, {1.5124212489965863`, 
             0.31372850222298393`}, {1.699191387927467, 
             0.34443221238261823`}, {1.8646405868599802`, 
             0.3734815682637754}, {2.0067419517134106`, 
             0.3995587212901855}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0299570309721404`, 0.40386982674828764`}, {
             2.1432585199133425`, 0.42497749153847486`}, {2.293968126604172, 
             0.45338832260827}, {2.4290063816923952`, 0.4790235273133594}, {
             2.5897774739889443`, 0.5097192106485002}, {2.7339752618094684`, 
             0.5373545908110642}, {2.9101811604622814`, 0.5712312005642258}, {
             2.9577901313145616`, 0.5804044133408884}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.9809756659189772`, 0.584871761373403}, {
             3.0681945916873996`, 0.6016769506035619}, {3.247150230634503, 
             0.6362212205612044}, {3.408789339631769, 0.6674620217147078}, {
             3.543387519948467, 0.6935005587299093}, {3.670030695890384, 
             0.7180104370323996}, {3.8994520346498724`, 0.7624442174992465}, {
             3.9082830880711743`, 0.7641559078637152}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.931463664368139, 0.7686489130803563}, {
             4.10384965718599, 0.8020618513560923}, {4.290019864774493, 
             0.838161826843781}, {4.461058285387173, 0.8713391987217267}, {
             4.620060546995823, 0.9021890217493435}, {4.768411949442099, 
             0.9309783337401772}, {4.858662302773001, 0.948495013461571}}]}, 
           {Arrowheads[{{0.016717875525040966`, 1.}}], 
            ArrowBox[{{4.881841736995361, 0.9529939069330181}, {
             4.90814133232133, 0.9580983920804409}, {4.915180358685748, 
             0.959464690894845}, {5.058801432429702, 0.9873453309671065}, {
             5.195046269361537, 1.0137965694907407`}, {5.328140879447659, 
             1.0396370959514731`}, {5.454935035842355, 1.0642561982864014`}, {
             5.656854249492381, 1.1034655911305788`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.0763447237496784`, -0.30566272037775655`}, {
             1.092738609059701, -0.2959929139229361}, {
             1.1116563501530123`, -0.2885048298919354}, {
             1.216853388978155, -0.27883258618555873`}, {
             1.3109084922540868`, -0.2851237720794259}, {
             1.4116293172493841`, -0.29748024767266035`}, {
             1.511878510815686, -0.31248171804372393`}, {
             1.6986431356351124`, -0.34305327044290856`}, {
             1.8641153027550965`, -0.37198990375787455`}, {
             2.006869591080441, -0.3980854370630408}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.030087331266862, -0.4023821965136108}, {
             2.1427990017995846`, -0.42329950301921415`}, {
             2.293510746461619, -0.4516026518917125}, {
             2.428550830464565, -0.477140998931134}, {
             2.5893122667115054`, -0.5077187556493395}, {
             2.7335012505177687`, -0.5352481000886521}, {
             2.9096868783397083`, -0.5689930669330556}, {
             2.95804231920967, -0.578274999889705}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.98123097595494, -0.5827261134229921}, {
             3.067682167098027, -0.5993206092186261}, {
             3.2466183383427163`, -0.6337310542741582}, {
             3.408239765099079, -0.6648508591176315}, {
             3.542822023497412, -0.6907883479084445}, {
             3.669450125900775, -0.7152031051412739}, {
             3.8988438627225905`, -0.7594644249329827}, {
             3.908663762269203, -0.7613606221075524}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.9318474895768567`, -0.765837339818166}, {
             4.1032165662945, -0.7989282647851849}, {
             4.2893638273464765`, -0.8348880709903075}, {
             4.460380944756085, -0.8679365917576072}, {
             4.619363217400888, -0.8986665752963405}, {
             4.767695853308587, -0.9273440358200884}, {
             4.859172260138679, -0.9450319402336663}}]}, 
           {Arrowheads[{{0.01670453045925356, 1.}}], 
            ArrowBox[{{4.8823548522299856`, -0.9495145329281043}, {
             4.907407521827457, -0.95435872434861}, {
             4.9144520996957475`, -0.9557209608382148}, {
             5.058053435212159, -0.9834929847542973}, {
             5.1942794107279875`, -1.0098411517602393`}, {
             5.327355565596875, -1.0355809814282706`}, {
             5.454132079171881, -1.0601041364204802`}, {
             5.656854249492381, -1.099321492612092}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15051807738106163`, 1.2807168464758476`}, {
             0.19682306246561773`, 1.3852088254113073`}, {
             0.23173561646972304`, 1.4763212101390668`}, {0.2598410061374254, 
             1.5577807458436592`}, {0.30521549185005126`, 
             1.701179925479507}, {0.3407808593685694, 1.824495345971844}, {
             0.39191413105293377`, 2.017181187373097}, {0.4324726930342819, 
             2.1793384665686593`}, {0.4327516600010335, 
             2.1804926323659846`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.4382990410306072, 2.2034437277003884`}, {
             0.4666536702720414, 2.3207549048887777`}, {0.4964441493327007, 
             2.446793603074379}, {0.5477280057239814, 2.667615282312072}, {
             0.5909346928880462, 2.8569729893779594`}, {0.6305420315106842, 
             3.032672788276169}, {0.6509024506736089, 3.123669937593938}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.6560581059537808, 3.146712190781684}, {
             0.6657605098482868, 3.1900753007876594`}, {0.6976095952990444, 
             3.333165310974109}, {0.7270461435611435, 3.465838957993486}, {
             0.7546474610057039, 3.590486833112818}, {0.8043444034422085, 
             3.8157052676513463`}, {0.8483407218325915, 4.015823534815478}, {
             0.859988588894712, 4.068912401629989}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8650487740901309, 4.091975808557939}, {
             0.8882767154008865, 4.197844554830999}, {0.9248641198982479, 
             4.364885590226031}, {0.9588146710758303, 4.520063903528697}, {
             0.9904397308198696, 4.664760132820408}, {1.0201936414755945`, 
             4.800992767292937}, {1.0218031268987608`, 4.8083645708903875`}, {
             1.0523969521151566`, 4.948573650442492}, {1.0668088980091417`, 
             5.014653794489025}}]}, 
           {Arrowheads[{{0.013418258803141883`, 1.}}], 
            ArrowBox[{{1.0718403512326966`, 5.037723486550155}, {
             1.0813970038683682`, 5.081541648747905}, {1.1097185268383414`, 
             5.211420860283798}, {1.136682992241838, 5.335122498280654}, {
             1.1871028746276964`, 5.56653345580593}, {1.2067726897142077`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1511875216564527, -1.280725871945972}, {
             0.19752392457235987`, -1.3851437012498604`}, {
             0.23247227787959343`, -1.4762071786189879`}, {
             0.2606127219882613, -1.5576313873785692`}, {
             0.30604936214303435`, -1.7009729038159132`}, {
             0.3416676760154849, -1.8242395353369851`}, {
             0.39290642838277834`, -2.0169366407449285`}, {
             0.4335523016589284, -2.179102819482319}, {
             0.43385783466875494`, -2.1803641785300036`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.43941650763818846`, -2.20331254161226}, {
             0.4678085161809159, -2.3205257909355823`}, {
             0.49766556017673175`, -2.4465693445399004`}, {
             0.5490653680879943, -2.667397709511895}, {
             0.5923708741275456, -2.8567592463143683`}, {
             0.6320664388558926, -3.0324475827385724`}, {
             0.6524715508116754, -3.1234342963173956`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{0.6576385461199253, -3.146474009267445}, {
             0.667364037325322, -3.189840126769585}, {
             0.6992850803285171, -3.332921191231503}, {
             0.7287883767422174, -3.4655866443942753`}, {
             0.7564524164044718, -3.5902268552414847`}, {
             0.8062627254746425, -3.815431549989214}, {
             0.8503598099028674, -4.015537702085749}, {
             0.8620234711538362, -4.068573610025534}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{0.8670950281593331, -4.091634519003199}, {
             0.8903874720529846, -4.197547738142147}, {
             0.9270590084932953, -4.364578703868188}, {
             0.9610877157921003, -4.519747644973649}, {
             0.9927856487666338, -4.66443510918624}, {
             1.0226081639913784`, -4.800659458139493}, {
             1.0242210788642196`, -4.808029520751847}, {
             1.0548855858662254`, -4.948230407121485}, {
             1.069310330271026, -5.014212854414965}}]}, 
           {Arrowheads[{{0.013429315107989299`, 1.}}], 
            ArrowBox[{{1.0743531647979807`, -5.037280061295511}, {
             1.0839526590416282`, -5.081190587901774}, {
             1.1123396425248158`, -5.211062144740933}, {
             1.1393664466235731`, -5.33475645369783}, {
             1.1899029358101867`, -5.566153646490377}, {
             1.209702475891327, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBQQG+/iFib1JlAgAAABMAAAACAAAAzH1FuXzR7r9X8Pqx08cjP9UZLArw
AO+/g+r7eFLxIz9VdLPmhzjvvyJdxYngISQ/VnpAos+v779ZC9FMcookPzrK
fCBYPPC/hyHIYDI8JT8ztTkTYa7wv3qcUCQqBiY/hFG3wiQj8r8pZS95apMo
P5XZCj6Lg/O/TE5GYbX0Kj98y90C7RX0v7QdkIVB7ys/nMqnkLGb9L+8PK2q
idIsPyidqC2Mzva/jmQxFw9BMD8VGugui+72v+2PVdKHWzA/ypU3AH2c97+2
BTKeWOowP30SqCHPPfi/azZ6Yf5tMT9dAXYrzWz5v9NSBX8lZDI//KfatKp5
+r9PPjY/pTwzPw/jRaYDbfu/TOGWMjP/Mz8HQubYdkr9v8E/xC3neTU/VJm2
G1WF/r8zFV+ucXE2P5rwlTo=
             "]]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.9311638612449362`, 
             0.0003469871648147621}, {-1.9312778096857124`, 
             0.00034700903572269716`}, {-2.0206704580229182`, 
             0.0003640581615873402}, {-2.1629031947410833`, 
             0.0003910250742798547}, {-2.286423248321587, 
             0.0004143104710710023}, {-2.3966151754451386`, 
             0.0004350026316476716}, {-2.5721823327081466`, 
             0.00046785506228280585`}, {-2.724934147302524, 
             0.0004963429638125761}, {-2.8612716008467243`, 
             0.0005217131536241838}, {-2.8756435645032, 
             0.000524382391345375}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.8992555570939347`, 
             0.000528767736507814}, {-3.0737454135926456`, 
             0.0005611749230318162}, {-3.2590635474303076`, 
             0.0005955321517776198}, {-3.424684099776797, 
             0.0006262017039756325}, {-3.5567656817107767`, 
             0.0006506426058154283}, {-3.6794683755745208`, 
             0.0006733357549745716}, {-3.8437352608131636`, 
             0.0007036968998185106}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.8673472534078233`, 
             0.0007080610607763263}, {-3.9021454742919404`, 
             0.0007144927516374466}, {-4.101385514426013, 
             0.0007512960855190659}, {-4.259850243355013, 
             0.0007805565724773368}, {-4.40715501335819, 
             0.0008077489809114987}, {-4.544898500938264, 
             0.000833170507617465}, {-4.6746793825979545`, 
             0.0008571183493911492}, {-4.811826957232483, 
             0.0008824202694436845}}]}, 
           {Arrowheads[{{0.017394027554207186`, 1.}}], 
            ArrowBox[{{-4.835438949828632, 
             0.0008867763708952837}, {-4.914195258881687, 
             0.000901305871986377}, {-5.103682281283436, 
             0.0009362572205565887}, {-5.27993372511077, 
             0.0009687628476744829}, {-5.444824118279059, 
             0.0009991696899622662}, {-5.600227988703669, 
             0.0010278246840421457`}, {-5.656854249492381, 
             0.0010382652470641753`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAI2jlDhYY7L8+6BFn5jnTP6js4gRH
Nuy/mbJbfRNX0z/dXZwHzFfsv8HjE3aId9M/wsdyngp37L8xumLj2JXTP+qZ
bJ/qpuy/BQwQeGnE0z9xkc+KBMTsv5htVW/I4NM/YlV1+1nt7L/JVyRoKwnU
P99VqbE1Fe2/wM8KxDQw1D84EkGgcUztv0P+pk91ZtQ/k9AVSWOh7b+C77i1
RrrUP6PbuKgv3u2/m7hLGH/21D/oezO1PCzuv7ps/pIMRNU/VbQSp/yK7r8a
IWiEe6LVPw3oXvbBgu+/bxNIp5WZ1j+qF11oUzbwv1xKOrQQgtc/u5yMLUGf
8L++8dCEZlHYP1noBieS+/G/Jt0Nvk752j8QpGGR/oPzv/nA3RGu5t0/FW1s
IKJF9b8L30zmcpbgP1h3vvcdSPe/x/N+a61q4j8+wqYfXJT5vx97G398duQ/
Klb78D2/+7/IJskyh1vmP7dgwCE=
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7558256670005585`, 
             0.7081291418090123}, {-1.7629490327295918`, 
             0.7112425330705548}, {-1.9483561130628537`, 
             0.7910908106855876}, {-2.162088954968226, 
             0.8821135514827041}, {-2.2890092403363513`, 
             0.9358065704294498}, {-2.4023184313177794`, 
             0.9835839155937962}, {-2.5442981783880465`, 
             1.0432752686464781`}, {-2.625199169975794, 
             1.0772107410716576`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.6469731292701604`, 
             1.0863442458744943`}, {-2.6712598759165584`, 
             1.0965317875218947`}, {-2.8289843515377315`, 
             1.162560037879113}, {-2.9702676351383905`, 
             1.2216149600037283`}, {-3.148159397385606, 
             1.2958715186384189`}, {-3.307499426733816, 
             1.362315191053985}, {-3.4841959182267277`, 
             1.4359308725558872`}, {-3.5185398339973903`, 
             1.4502302316316287`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.54033790897462, 
             1.4593060313552466`}, {-3.6443071910861122`, 
             1.5025944585598474`}, {-3.7907882157865167`, 
             1.563550811477422}, {-3.926593962802487, 
             1.6200447937201676`}, {-4.053001550221829, 
             1.6726125108383563`}, {-4.171871258603959, 
             1.7220344399639}, {-4.180299399967326, 
             1.7255381867648745`}, {-4.303101392051088, 
             1.7765798795001992`}, {-4.412400540885544, 
             1.8220024165303308`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.434204871914655, 
             1.8310631759642129`}, {-4.641164668627723, 
             1.9170619319879547`}, {-4.843222855912721, 
             2.0010066887760853`}, {-5.029516600736618, 
             2.078390380120065}, {-5.231203597623025, 
             2.1621586682674456`}, {-5.306418957923734, 
             2.1933952410072393`}}]}, 
           {Arrowheads[{{0.0075355421225675985`, 1.}}], 
            ArrowBox[{{-5.328225247148951, 
             2.202451286698508}, {-5.418320777488061, 
             2.2398675215701687`}, {-5.592508873880254, 
             2.3122253418731393`}, {-5.656854249492381, 
             2.338972831509297}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAANGcU56gC7L9nhYdiWhPTv6zpCTJ7
IOy/G0l37QQw078U8u5HkEHsv2d8f+PhT9O/m62OHUpf7L/J8+askWzTvyRb
aIX/g+y/vIlk7BCQ07+ujqKWYbvsvyKKIpfGxdO/zwHroLjb7L+b/9SyOOXT
v63zV865CO2/ftLxRRYR1L9RBXzEazntv+zPYgKuQNS/vYldSSyA7b8efqa6
GIbUvzpfu7rI8e2/xo+osi321L8PBNjiwjjuvwqdfZJbPNW/QjnLQsWN7r+L
K/hgoZDVvwtE8u5LhO+/ERx1TYGF1r+vkQkPOTfwv4+BJ7VXbde/VJ0kEEKg
8L+mGfnhFjzYv+dCQDH8/PG/PcvW+Tvi2r+OTyOWdIXzv6QDD7nrzN2/eZHo
Th1H9b/YJgN9DYjgvxlj1SOuSfe/pf1MCaVa4r/dKlNs75X5vxbCMYuOZOS/
OHgiFK+2+7821XfHAj/mv7fSyJw=
             "]]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.753748891060887, -0.7046191645091446}, \
{-1.763339363075726, -0.7087956211207805}, {-1.9487576881903506`, \
-0.788358796159767}, {-2.1624993555593273`, -0.8790545574958963}, \
{-2.2894290471581096`, -0.9325563530102929}, {-2.402746561396262, \
-0.9801634415346956}, {-2.544738203047052, -1.0396426075860898`}, \
{-2.6235896363809914`, -1.072597970704557}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.645375441493028, -1.081703183989073}, \
{-2.671710524592291, -1.0927097337700478`}, {-2.8294491546729943`, \
-1.1585034840413488`}, {-2.9707452454162366`, -1.217348658539763}, \
{-3.148655811999454, -1.2913425144604587`}, {-3.308012745540243, \
-1.357551092540845}, {-3.484732044283806, -1.4309079344105349`}, \
{-3.517410881778649, -1.4444644275056302`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.5392206843175664`, -1.4535120087597333`}, \
{-3.6448638772681914`, -1.4973370443352785`}, {-3.791363645647214, \
-1.55807893987793}, {-3.9271867505746902`, -1.6143741386013435`}, \
{-4.0536104755764155`, -1.6667568647570643`}, {-4.172495361704966, \
-1.7160048645889925`}, {-4.180935525870228, -1.7195008145369004`}, \
{-4.303753480244122, -1.7703629807059007`}, {-4.41175133280594, \
-1.8150810467692415`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.43356733987601, -1.82411365705917}, \
{-4.64186097963556, -1.910351013213562}, {-4.843945692370187, \
-1.9940005916864394`}, {-5.030263998048778, -2.071112210255168}, \
{-5.231981467201783, -2.154587577610857}, {-5.306249030066723, \
-2.185318037999952}}]}, 
           {Arrowheads[{{0.00753504549770191, 1.}}], 
            ArrowBox[{{-5.328067007117955, -2.1943458888365606`}, \
{-5.419126775936636, -2.2320246345874013`}, {-5.593418545584316, \
-2.3041568266536063`}, {-5.656854249492381, -2.3304245875127645`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1083121995622411`, -0.6791775423538522}, \
{-1.2044054601191625`, -0.753193215439818}, {-1.3155921625870282`, \
-0.8363587213806924}, {-1.4443382183766973`, -0.930138500162156}, \
{-1.5935887906428923`, -1.0364549308478122`}, {-1.7643035560029785`, \
-1.1559404431985103`}, {-1.8740919497228912`, -1.2317798241514601`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.8935194458242324`, -1.2451999064376658`}, \
{-1.961564812396747, -1.2922041325013183`}, {-2.0787438099289375`, \
-1.3725302879575347`}, {-2.1832569388749583`, -1.443907591096134}, \
{-2.3142036709977303`, -1.533043421700993}, {-2.4311976973659624`, \
-1.61248120697649}, {-2.576983157129513, -1.7112489846030003`}, \
{-2.6740945799204505`, -1.7769302406449419`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.6936531017034473`, -1.7901586358235038`}, \
{-2.707429227146825, -1.7994761104985515`}, {-2.8694030005425093`, \
-1.9088657563046942`}, {-3.0145154434496275`, -2.0067590087814504`}, \
{-3.193549672722987, -2.127418586753465}, {-3.354175210390407, \
-2.2355923979799806`}, {-3.476790240556107, -2.318114935891241}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.4963789645424437`, -2.331298566116762}, \
{-3.5556090954652486`, -2.371161711099565}, {-3.736263644355303, \
-2.49268669753392}, {-3.932386319985027, -2.624562057474354}, \
{-4.110546069901645, -2.744323816075038}, {-4.27387606181541, \
-2.854090024981792}, {-4.280153650068831, -2.8583081943798536`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.299752175932731, -2.871477248913046}, \
{-4.425509463436579, -2.955978735840435}, {-4.566821294623305, \
-3.0509178898155183`}, {-4.6998189724364865`, -3.1402618477261717`}, \
{-4.704620973892749, -3.143487530952861}, {-4.841586715562735, \
-3.2354845426816197`}, {-4.971442376490728, -3.3226996754726947`}, \
{-5.083762896186817, -3.398135702020767}}]}, 
           {Arrowheads[{{0.014124549585224466`, 1.}}], 
            ArrowBox[{{-5.103364478322561, -3.4113002069883094`}, \
{-5.219036646252348, -3.488982916031702}, {-5.334372207937798, \
-3.56643575181954}, {-5.444901675326893, -3.640658043647191}, \
{-5.648437486890613, -3.77779013212788}, {-5.656854249492381, \
-3.783537868608596}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.1079832451858465`, 
             0.6802396288677175}, {-1.2040298422390867`, 
             0.7543594283950604}, {-1.3151619044285199`, 
             0.837639832297455}, {-1.4438516331574012`, 
             0.9315530869099491}, {-1.5930200560522465`, 
             1.03800834567908}, {-1.7637034052602298`, 
             1.15769342427341}, {-1.8732720821857576`, 
             1.2335211631914151`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.8926879586916374`, 
             1.2469580509577314`}, {-1.9609261160210916`, 
             1.294182726142415}, {-2.078080538472626, 
             1.3746407009211876`}, {-2.1825715701103228`, 
             1.4461350347868809`}, {-2.313489531830354, 
             1.535416307548167}, {-2.4304575916273414`, 
             1.6149835743611631`}, {-2.5762089551918077`, 
             1.713911212613664}, {-2.672802781450118, 1.779363476168718}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.692349925043305, 
             1.792608678722227}, {-2.706624265095988, 
             1.8022810139365315`}, {-2.868559004061386, 
             1.9118470434972532`}, {-3.0136362143594995`, 
             2.009898008407734}, {-3.1926266293146037`, 
             2.1307517908584086`}, {-3.3532125166190787`, 
             2.239099514491729}, {-3.4750322879948503`, 
             2.3212389377020206`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.494609681405847, 
             2.3344393877158356`}, {-3.554595744317406, 
             2.3748861932923533`}, {-3.7352045598057106`, 
             2.496605852114704}, {-3.9312799552274256`, 
             2.6286940867115476`}, {-4.109396299714932, 
             2.748648875900297}, {-4.272686135728823, 
             2.858591772645697}, {-4.277931041348847, 2.8621225814411035`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.297518251354342, 
             2.8753084609163895`}, {-4.424282005729691, 
             2.9606443299124923`}, {-4.565558641745783, 
             3.055736014516449}, {-4.698523044372914, 
             3.145223416741681}, {-4.703319201410008, 
             3.148451154320604}, {-4.840250862382386, 
             3.2405960018151836`}, {-4.970074105569473, 
             3.3279512174989847`}, {-5.081076268920857, 
             3.4026402054549427`}}]}, 
           {Arrowheads[{{0.014202001318038062`, 1.}}], 
            ArrowBox[{{-5.100666517327468, 
             3.415821570355641}, {-5.217606319903899, 
             3.494501377141935}, {-5.332912811350366, 
             3.572078433401433}, {-5.44341434339509, 
             3.646419714261629}, {-5.646795393890723, 
             3.783717609168163}, {-5.656854249492381, 
             3.7906010103366716`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.4152948856675631`, 
             0.2675277959668153}, {-1.5485921352243073`, 
             0.2965019527044061}, {-1.701087278134368, 
             0.3290236598771593}, {-1.8732644869800017`, 
             0.36514772832070475`}, {-2.07285633827671, 
             0.40647462123781153`}, {-2.298188026939739, 
             0.45265746996798845`}, {-2.339713338333134, 
             0.4611171700129754}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.3628500849613436`, 
             0.4658306791938517}, {-2.431933213420199, 
             0.47990456630801737`}, {-2.5514051541747964`, 
             0.5041708653555643}, {-2.7009363268926565`, 
             0.5344613731050066}, {-2.8347318962386674`, 
             0.5615078512727555}, {-3.001426693159962, 
             0.5951427011830145}, {-3.1507814226904047`, 
             0.6252359152337005}, {-3.288603870380767, 0.6529707726351882}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.311751815369341, 
             0.6576289757374719}, {-3.3354905272837305`, 
             0.6624060624956447}, {-3.5012318451102935`, 
             0.6957273170361032}, {-3.7094549049452517`, 
             0.737554040379256}, {-3.8962306819220647`, 
             0.7750482781477113}, {-4.099386188633569, 
             0.815808110559714}, {-4.237749894447311, 
             0.8435576510327514}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.260900884036078, 
             0.8482006989968551}, {-4.283952607193322, 
             0.8528238385764374}, {-4.453175080138586, 
             0.8867511932453105}, {-4.610298750006629, 
             0.9182459056137622}, {-4.756745766101847, 
             0.9475946975563184}, {-4.894592433180091, 
             0.9752160303944434}, {-4.901922942188249, 
             0.9766847975018949}, {-5.043924223055001, 
             1.0051333535053586`}, {-5.178570702955588, 
             1.0321058890379968`}, {-5.1869674774607235`, 
             1.033787882201398}}]}, 
           {Arrowheads[{{0.009647799029480821, 1.}}], 
            ArrowBox[{{-5.2101195415358275`, 
             1.0384255693834379`}, {-5.310083233064446, 
             1.0584497162313298`}, {-5.435327863589846, 
             1.0835361267460522`}, {-5.656854249492381, 
             1.127903603872272}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.4149662063770125`, -0.26629354701491753`}, \
{-1.5481994102605245`, -0.29513088536494736`}, {-1.700639318885037, \
-0.32750271628897076`}, {-1.8727411530144316`, -0.36345722620706467`}, \
{-2.072253717619333, -0.4045912870842686}, {-2.2975001096618355`, \
-0.4505589983287076}, {-2.3395506263845673`, -0.45908894562368513`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.3626913207125972`, -0.46378303545589344`}, \
{-2.431194333328642, -0.47767887152884625`}, {-2.55062000247949, \
-0.5018316093151582}, {-2.7000976139617614`, -0.5319811220382545}, \
{-2.8338447366506054`, -0.558901514361743}, {-3.0004830597916565`, \
-0.592380247801447}, {-3.1497865569133756`, -0.6223335860988495}, \
{-3.288601499799924, -0.6501478093686801}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.3117533191175186`, -0.65478671825134}, \
{-3.3344367945229845`, -0.6593317854922566}, {-3.500124538077025, \
-0.6924986914181037}, {-3.7082791084472677`, -0.7341313698913532}, \
{-3.8949928951917245`, -0.7714515090526148}, {-4.098092619360315, \
-0.8120243665350741}, {-4.237906016216593, -0.839943669666345}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.261060860705199, -0.8445674549170487}, \
{-4.282607321276302, -0.8488700623753953}, {-4.451781570086627, \
-0.88264139126516}, {-4.608859934938235, -0.9139911478959495}, \
{-4.755264356379024, -0.9432047777830955}, {-4.893070657117602, \
-0.9706988433726831}, {-4.900410180999177, -0.9721630695693118}, \
{-5.042369860194152, -1.0004805344908305`}, {-5.176976753282264, \
-1.0273287487714597`}, {-5.187281552191777, -1.029384036216069}}]}, 
           {Arrowheads[{{0.009639331008967482, 1.}}], 
            ArrowBox[{{-5.210437464209443, -1.034002472311358}, \
{-5.308450514651746, -1.0535511305385419`}, {-5.43365801258397, \
-1.0785218472785303`}, {-5.656854249492381, -1.1230307966778774`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.4319856590957536`, -1.7266190883995374`}, \
{-1.5483753012889732`, -1.8758839349172516`}, {-1.6487678079052452`, \
-2.0036608814725643`}, {-1.7354548852349414`, -2.113272058563117}, \
{-1.8139043098219536`, -2.212133018839971}, {-1.952474996927126, \
-2.3861606907098896`}, {-2.0175588243538836`, -2.4676530145551907`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.032293924576521, -2.4861030290474613`}, \
{-2.073239809549491, -2.537371914887108}, {-2.1808887598426794`, \
-2.6718952194081296`}, {-2.2790521838365034`, -2.7944208502660492`}, \
{-2.3696399226054656`, -2.90739648283379}, {-2.4535537093459836`, \
-3.01196502641927}, {-2.5316952772544763`, -3.1092693903304047`}, \
{-2.6230867475022706`, -3.2229918399595503`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.6378778136420893`, -3.2413970179207565`}, \
{-2.6825650790768076`, -3.2970033592859305`}, {-2.817847656184673, \
-3.465225708801881}, {-2.940933974074735, -3.6182077809002458`}, \
{-3.05513545155332, -3.7601044905110537`}, {-3.162481847769762, \
-3.8934585611413146`}, {-3.229951891744397, -3.9772571738450386`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.244759814036144, -3.9956487928802877`}, \
{-3.2629731627240615`, -4.018269992791028}, {-3.356609396416218, \
-4.134538785460195}, {-3.44488067525012, -4.244126252289862}, \
{-3.5292771256296582`, -4.348893706421079}, {-3.6097987475548314`, \
-4.448841147853846}, {-3.6864455410256403`, -4.543968576588163}, \
{-3.83077387701034, -4.72307697183752}, {-3.837279898993993, \
-4.731149900445568}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.8520963071539347`, -4.749534683897493}, \
{-3.9649213679899344`, -4.88953246804522}, {-4.090067769381446, \
-5.044803373433505}, {-4.207938925392206, -5.191037256877837}, \
{-4.210536599399923, -5.194259886981338}, {-4.328622850866377, \
-5.340703483965347}, {-4.439170432416683, -5.476877164551583}, \
{-4.445344602638167, -5.484447289505623}}]}, 
           {Arrowheads[{{0.004216692524402434, 1.}}], 
            ArrowBox[{{-4.460268258402796, -5.502745123037356}, \
{-4.54618753863541, -5.60809040248215}, {-4.586373474285818, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.4314538093337075`, 
             1.7264913979767458`}, {-1.5477955078784185`, 
             1.8757462762985642`}, {-1.6481469190352231`, 
             2.003514142758485}, {-1.734802174548131, 
             2.1131215002896453`}, {-1.8132226007461452`, 
             2.2119784400971416`}, {-1.951741842467817, 
             2.3859981995203476`}, {-2.0169076743330927`, 
             2.4676195629824793`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0316398684097194`, 
             2.4860718980928325`}, {-2.072461552704953, 
             2.5372017837342233`}, {-2.1800701884727993`, 
             2.6717179052803375`}, {-2.278196828024229, 
             2.7942368364155574`}, {-2.368750576379785, 
             2.907206148300813}, {-2.452632837772335, 
             3.0117687150273253`}, {-2.5307450164347483`, 
             3.1090674106863183`}, {-2.6223183737127407`, 
             3.223052346803063}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.637106588616672, 
             3.2414598157570316`}, {-2.6815602104659253`, 
             3.296792975938796}, {-2.8167935886267945`, 
             3.465007396971395}, {-2.9398349680835327`, 
             3.617981971322779}, {-3.053994643171081, 
             3.7598715523746256`}, {-3.1613016902800863`, 
             3.893218830625382}, {-3.229067336574325, 3.9774111428729837`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.243872424404807, 
             3.995805043700918}, {-3.261756109410548, 
             4.018023806075049}, {-3.3553579005624656`, 
             4.1342864787236255`}, {-3.4435966662289546`, 
             4.243868104072034}, {-3.527962008903128, 
             4.348629937621194}, {-3.6084539285849866`, 
             4.448571979371107}, {-3.68507242527453, 
             4.543694229321772}, {-3.8293474224638535`, 
             4.722792786529023}, {-3.8362795436111243`, 4.731397142230691}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.851093125869157, 
             4.749784202735857}, {-3.9634452732582797`, 
             4.889239041946612}, {-4.08854532544959, 
             5.044501262681715}, {-4.206372815589666, 
             5.190726942851545}, {-4.208970894621201, 
             5.193951088903256}, {-4.326993880428151, 
             5.340361792690469}, {-4.437477686128514, 
             5.476497162290442}, {-4.4442341014439375`, 5.484783406691652}}]}, 
           {Arrowheads[{{0.004207082193988382, 1.}}], 
            ArrowBox[{{-4.459155343735142, 
             5.503083208379739}, {-4.544426344615237, 
             5.6076617934195605`}, {-4.584957067228043, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.7536654846236395`, 1.4540831780047012`}, {
             1.8564540500931206`, 1.5347468519928678`}, {1.9812005786432305`, 
             1.6333886688999402`}, {2.0927208569242164`, 
             1.7220282663235293`}, {2.2289315274548094`, 1.830764819745765}, {
             2.3508328734046557`, 1.9283750134648634`}, {2.492657810978632, 
             2.0422330060773355`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.511062615923568, 2.0570245326657695`}, {
             2.6340951568622963`, 2.1559781389303487`}, {2.7980515619308868`, 
             2.288054277881717}, {2.9451036513563063`, 2.4066476802139936`}, {
             3.1279183681601217`, 2.5542267404269903`}, {3.2463055779082435`, 
             2.6498645312580935`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.2646730035923297`, 2.664702451835982}, {
             3.2918393834205646`, 2.6866485096675565`}, {3.4774447330424714`, 
             2.8366789169530637`}, {3.645212968038237, 2.972348989266084}, {
             3.7876524875700066`, 3.0875729425735536`}, {3.9216337251211524`, 
             3.1959708903738715`}, {3.9990499028676822`, 
             3.258615300736008}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.017405197814342, 3.273468225052697}, {
             4.047156680691675, 3.297542832667038}, {4.164221354281573, 
             3.392288769453053}, {4.274647732294585, 3.481674579973452}, {
             4.380255801134446, 3.5671661434697697`}, {4.481045560801157, 
             3.648763459942007}, {4.577017011294717, 3.7264665293901635`}, {
             4.75149101476101, 3.8677408458806353`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.769841187208744, 3.882600098360351}, {
             4.925858441463197, 4.008940471354162}, {5.082687812288051, 
             4.1359481789321135`}, {5.230421706567544, 4.2555963838251785`}, {
             5.233512808059153, 4.258099898891848}, {5.376014321752175, 
             4.373667135693489}, {5.503259254550958, 4.477694424583663}}]}, 
           {Arrowheads[{{0.003710164146485716, 1.}}], 
            ArrowBox[{{5.521517109098973, 4.492666948973824}, {
             5.635892584207798, 4.586569336226663}, {5.656854249492381, 
             4.60394082615042}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.6356154848352296`, -1.3600956420057937`}, {
             1.7506399191049686`, -1.4493571248550883`}, {
             1.8533500087330372`, -1.5298017902804246`}, {
             1.977974020296422, -1.6281625141853993`}, {
             2.089383396855135, -1.7165530746272026`}, {
             2.225443874022403, -1.8249770477166831`}, {
             2.3472093829353047`, -1.9223082437889756`}, {
             2.376533279195943, -1.9458091149403693`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.394958343384014, -1.9605754016435875`}, {
             2.49644364725478, -2.0419081491348647`}, {
             2.6301349593780374`, -2.149251051158063}, {
             2.7938907633224814`, -2.280942395116821}, {
             2.9407610214324844`, -2.3991898959176097`}, {
             3.123347600966197, -2.5463380515126453`}, {
             3.130957850993488, -2.5524756522243743`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.1493373774660527`, -2.567298581084099}, {
             3.2870623075217305`, -2.6783725439238526`}, {
             3.472422028657032, -2.827955221388976}, {
             3.6399672120712445`, -2.963220063859075}, {
             3.782241320768491, -3.0781195113836963`}, {
             3.8842671353895057`, -3.1605271497481158`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.902635685879877, -3.1753636778533987`}, {
             3.9160655741717245`, -3.1862111813184795`}, {
             4.041439972280945, -3.2874950736634236`}, {
             4.158364515096152, -3.3819711884185297`}, {
             4.268657551793398, -3.4711016095552125`}, {
             4.374137431548734, -3.556348421044888}, {
             4.474804154362158, -3.6377116228875557`}, {
             4.570657720233674, -3.715191215083215}, {
             4.637230332599114, -3.769007204125347}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.655592897338903, -3.783851139907788}, {
             4.751206821575224, -3.861143553651917}, {
             4.9190661759976315`, -3.9968494198693976`}, {
             5.075698848071914, -4.123488824393458}, {
             5.223246715213654, -4.2427895253332935`}, {
             5.226351994412568, -4.245300380760459}, {
             5.369274960879241, -4.361002751227218}, {
             5.389908000794929, -4.377839973750743}}]}, 
           {Arrowheads[{{0.00680651885914937, 1.}}], 
            ArrowBox[{{5.40820193412721, -4.392768410258635}, {
             5.501857190815779, -4.469194104378692}, {
             5.629791543176384, -4.5740565111228175`}, {
             5.656854249492381, -4.596457989072706}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.7432759712886592`, -1.4078888735449993`}, \
{-1.8794587516366799`, -1.5234797537392775`}, {-1.9973541565478774`, \
-1.6229755606117409`}, {-2.1069273755983415`, -1.7149798388498454`}, \
{-2.2056342189895073`, -1.7976268884120115`}, {-2.379178297550516, \
-1.9425219743366189`}, {-2.466538378335811, -2.0152801097450723`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.484681896047757, -2.0303909991422078`}, \
{-2.529807912382616, -2.067974352745155}, {-2.6637119571743573`, \
-2.179316443545331}, {-2.785614645607946, -2.2805819702621632`}, \
{-2.8979774188149943`, -2.373859301618553}, {-3.001944564624163, \
-2.460110721588191}, {-3.0986603708641107`, -2.540298514144768}, \
{-3.2113672225185126`, -2.633690214427978}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2295484888640384`, -2.6487556638872283`}, \
{-3.286226574838209, -2.6957205355008615`}, {-3.454154127795189, \
-2.834791425178445}, {-3.60676891208122, -2.96113093404729}, \
{-3.748264292863111, -3.0782369579347955`}, {-3.881205063968616, \
-3.1882461722534776`}, {-3.957086033898174, -3.251027216386369}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.9752785809773967`, -3.266079041661279}, \
{-4.005591225397735, -3.2911585770033356`}, {-4.121422777150469, \
-3.38697417218437}, {-4.230569392941484, -3.477246922032789}, \
{-4.334900746485445, -3.5635307907848017`}, {-4.434416837782353, \
-3.6458257784404076`}, {-4.529117666832208, -3.7241318849996072`}, \
{-4.703112772336613, -3.867992094967475}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.7213107986379175`, -3.883037295261134}, \
{-4.873041623249057, -4.00847794320413}, {-5.027535207822321, \
-4.136192287674235}, {-5.1730193369143205`, -4.2564518970976355`}, \
{-5.176202518382255, -4.259083096855253}, {-5.324459112917812, \
-4.381627189091351}, {-5.449016563784464, -4.485104986186588}}]}, 
           {Arrowheads[{{0.005234931754475771, 1.}}], 
            ArrowBox[{{-5.467172530551611, -4.500200905367808}, \
{-5.596768695705283, -4.608250066744223}, {-5.656854249492381, \
-4.658742941162704}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.742509734524507, 
             1.4090105732011111`}, {-1.8788692264954527`, 
             1.5248970622922386`}, {-1.9968936332662441`, 
             1.6246262125928679`}, {-2.1064234664973402`, 
             1.7167084483187174`}, {-2.2050933484926074`, 
             1.7994274116124558`}, {-2.3785763956819337`, 
             1.944452082931343}, {-2.465395566440882, 2.0168499287689365`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.483529814987901, 
             2.0319719406380994`}, {-2.5291558708469983`, 
             2.070019161423422}, {-2.663017124248964, 
             2.1814646204614427`}, {-2.78488182414533, 
             2.2828250123371103`}, {-2.897210101438529, 
             2.3761901810784516`}, {-3.0011458044737616`, 
             2.4625232390581537`}, {-3.0978327815962285`, 
             2.5427872986489044`}, {-3.209843678798382, 
             2.6357183090373546`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.228015696354691, 
             2.650794913140049}, {-3.285366285465714, 
             2.69837642820319}, {-3.453263129702845, 
             2.837595682008795}, {-3.6058491610348176`, 
             2.9640692947683016`}, {-3.7473173091193757`, 
             3.0812991586033274`}, {-3.880232114002345, 
             3.1914244016075517`}, {-3.9551829836129944`, 
             3.2535134532746275`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.973366288274914, 
             3.268576442516739}, {-4.004593575683725, 
             3.294445023780976}, {-4.120401694163517, 
             3.3903610251235983`}, {-4.2295259292229925`, 
             3.480728131401505}, {-4.3338357406434245`, 
             3.567102068380779}, {-4.433331128424812, 
             3.649482836061421}, {-4.528012092567156, 
             3.727870434443431}, {-4.700830565111487, 3.870936517343264}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.71901930907164, 
             3.8859929381084894`}, {-4.871863038352171, 
             4.012511718157128}, {-5.026323435764525, 
             4.140358354843185}, {-5.17177610839798, 
             4.2607423718214985`}, {-5.174956245255001, 
             4.2633743434254034`}, {-5.323474898238327, 
             4.386287167405852}, {-5.446373397618602, 4.488485514346247}}]}, 
           {Arrowheads[{{0.005309480966476924, 1.}}], 
            ArrowBox[{{-5.464525279631434, 
             4.503586349524798}, {-5.5965413448126675`, 
             4.613742858208336}, {-5.656854249492381, 
             4.664450725070502}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.526857610038786, -1.8773730440741834`}, {
             1.63097459419286, -1.998852388511281}, {
             1.7237937518787236`, -2.107792120891567}, {
             1.8379629053958417`, -2.242464034176723}, {
             1.9398876684841346`, -2.3631192307020754`}, {
             2.0655486418700035`, -2.5123227842589047`}, {
             2.1374772361556396`, -2.597911784726125}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1526684723287537`, -2.615988082933137}, {
             2.177869747194863, -2.645975488466526}, {
             2.315324265748904, -2.8098372710349144`}, {
             2.438416686778521, -2.9567727390570666`}, {
             2.5913303224313844`, -3.1395144618435693`}, {
             2.728294778555354, -3.303332752602659}, {
             2.759029976147418, -3.3401201091532613`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{2.774168977801093, -3.358240176544587}, {
             2.882998515296582, -3.488499661198671}, {
             3.0227607949852717`, -3.6558660989786325`}, {
             3.141902237713846, -3.7985916886192483`}, {
             3.253924772679929, -3.9328124952360284`}, {
             3.3588283998835213`, -4.0585285188289735`}, {
             3.3794642385611064`, -4.083264001687731}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.394590187798757, -4.101394966168314}, {
             3.456613119324622, -4.175739759398082}, {
             3.548818145823323, -4.286280914028261}, {
             3.636982694199713, -4.391986679804414}, {
             3.721106764453793, -4.4928570567265425`}, {
             3.801190356585563, -4.588892044794645}, {
             3.9520004929920045`, -4.769758765393318}, {
             3.9995048439564163`, -4.8267363979576885`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.014625191753752, -4.844872034032107}, {
             4.092177489928872, -4.937889752624975}, {
             4.222950951298475, -5.094755813197331}, {
             4.346120300150872, -5.24250972497358}, {
             4.3486260940314345`, -5.245515761510195}, {
             4.471502755580938, -5.392863032849266}, {
             4.586833173677306, -5.53035640264352}, {
             4.619993831204316, -5.569833482661163}}]}, 
           {Arrowheads[{{0.0019065693005520742`, 1.}}], 
            ArrowBox[{{4.635180854162547, -5.587913320796565}, {
             4.693091077640432, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.440804175839719, 1.7793275360765648`}, {
             1.5255631423546239`, 1.8774618937581655`}, {1.6296042183410784`, 
             1.9989523933657782`}, {1.722354603321767, 2.1079019745190957`}, {
             1.83644141798316, 2.2425899194311256`}, {1.9382915019078315`, 
             2.36325884589495}, {2.052484473940323, 2.4989614505213606`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0676825000876065`, 2.5170320369932666`}, {
             2.17610275736741, 2.646153526973307}, {2.313446934741339, 
             2.810024493395429}, {2.4364404590761866`, 2.9569684169846906`}, {
             2.5892313433261056`, 3.1397211217136896`}, {2.6740015826600905`, 
             3.2411994652726412`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.689139200879566, 3.2593206884095483`}, {
             2.7260859582834644`, 3.3035496037774794`}, {2.880666955777991, 
             3.4887298382252694`}, {3.020318181929814, 3.6561082639446125`}, {
             3.139360418238077, 3.7988387282414897`}, {3.2512898148034184`, 
             3.9330643288693192`}, {3.29420385338924, 3.984536965640126}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.3093240775926387`, 4.002672704758649}, {
             3.3561063716258386`, 4.0587850658281}, {3.4538100887053376`, 
             4.1760009391178325`}, {3.5459388626596833`, 4.286546648619559}, {
             3.6340305901066428`, 4.392256894214322}, {3.718085271046217, 
             4.493131675902121}, {3.798102905478405, 4.589170993682956}, {
             3.9139635247109803`, 4.728243562565379}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.9290769991613783`, 4.746384926995138}, {
             3.948788959907088, 4.770046055657953}, {4.088850678479156, 
             4.938184898273533}, {4.21951669025712, 5.095058432162465}, {
             4.342584889830987, 5.242819466784076}, {4.345090732856517, 
             5.245828178219291}, {4.467483042244643, 5.392710282814141}, {
             4.5338334364496164`, 5.471857700547656}}]}, 
           {Arrowheads[{{0.004614116168540377, 1.}}], 
            ArrowBox[{{4.549002589948162, 5.489952533939365}, {
             4.582325439676168, 5.529702373244705}, {4.689084338654595, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.0827163779047726`, -2.0231904512655077`}, \
{-1.1869060644528713`, -2.2332590555891048`}, {-1.2748393516748109`, \
-2.4084829135548653`}, {-1.3517383699295795`, -2.560687198374919}, \
{-1.420445420255962, -2.6960761695929465`}, {-1.4831879412843438`, \
-2.8193858473871956`}, {-1.5073657085395757`, -2.8668143037475766`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.5180894703854546`, -2.887850632923767}, \
{-1.541148516933438, -2.9330845443667832`}, {-1.644985616095067, \
-3.1362512896694947`}, {-1.7418115581496085`, -3.325237336251402}, \
{-1.8287106596174851`, -3.4945870572803925`}, {-1.907826342814323, \
-3.648600887112791}, {-1.948837923494451, -3.728384332878555}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.9596326778430866`, -3.749384320780665}, \
{-1.9812610451320962`, -3.791459891631336}, {-2.0503058327745713`, \
-3.9257223366708685`}, {-2.1149607057417485`, -4.051388222231388}, \
{-2.1752256640336274`, -4.168457548312895}, {-2.286390994981077, \
-4.384297327632144}, {-2.387606984006506, -4.580732480221888}, \
{-2.391931465477457, -4.589122143215283}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.4027497423702866`, -4.610110023013067}, \
{-2.4805765547403666`, -4.761097079385285}, {-2.5670026308131115`, \
-4.928725198425493}, {-2.647642001220219, -5.085094583076153}, \
{-2.723601943510676, -5.232366468755751}, {-2.7260248415619235`, \
-5.237063652415201}, {-2.8041225107984333`, -5.388448876815274}, \
{-2.835685079163237, -5.4495198604728365`}}]}, 
           {Arrowheads[{{0.004446112278003454, 1.}}], 
            ArrowBox[{{-2.8465259587541194`, -5.470496074216793}, \
{-2.877968552391669, -5.531334916607435}, {-2.943247665626818, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.976230523447248, -1.0536032058828997`}, {
             2.0940386651621066`, -1.1132412268419989`}, {
             2.235030064641087, -1.1851605042457711`}, {
             2.3612785929448856`, -1.2498829068726636`}, {
             2.5143818941927227`, -1.3287024004481962`}, {
             2.6515988275408278`, -1.3995478174956673`}, {
             2.8164851504831674`, -1.48488748704954}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.837448097268567, -1.4957539974849916`}, {
             2.968633841795654, -1.5637688902809517`}, {
             3.154174610474654, -1.6601070748007754`}, {
             3.3205924053395597`, -1.7466085548847858`}, {
             3.509341703485085, -1.8448064566950184`}, {
             3.6755024204847158`, -1.931307218172512}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{3.6964447090515336`, -1.9422134897392034`}, {
             3.8233285828192307`, -2.008298308219225}, {
             3.9582544988550614`, -2.078586975033881}, {
             4.084712536023328, -2.144480642205296}, {
             4.20270269432403, -2.2059793097334723`}, {
             4.420530315629067, -2.3195440487637784`}, {
             4.534004495382254, -2.3787172343195024`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.5549408556161435`, -2.3896348821198745`}, {
             4.6189883040765, -2.423033595028473}, {
             4.801366443911478, -2.5181556248230317`}, {
             4.97095451937915, -2.6066178144429326`}, {
             5.129223156629928, -2.6891846446746057`}, {
             5.278326156756332, -2.7669759816334336`}, {
             5.282814265269525, -2.7693176438422293`}, {
             5.392332053767277, -2.826461985513828}}]}, 
           {Arrowheads[{{0.005826266416507863, 1.}}], 
            ArrowBox[{{5.4132657263134805`, -2.8373847858445354`}, {
             5.435880116455987, -2.8491845533044557`}, {
             5.579135724007963, -2.9242812033711485`}, {
             5.656854249492381, -2.965315223965463}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.9756722984746824`, 1.055513567413231}, {
             2.093427148638821, 1.1152500460821462`}, {2.234367499871843, 
             1.1872942071493555`}, {2.3605698080979836`, 
             1.2521285804370592`}, {2.513623754246866, 1.331087752441084}, {
             2.6507957876567607`, 1.4020583186617759`}, {2.815559436233762, 
             1.4875130507012027`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.836513110567333, 1.4983974302470393`}, {
             2.9677306946375968`, 1.5665712554671707`}, {3.1532174768220944`, 
             1.6630830087893962`}, {3.3195862575283126`, 
             1.7497400089289856`}, {3.5082756167487985`, 
             1.8481121770637412`}, {3.6741943615894295`, 
             1.9346677338425289`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.6951273154845827`, 1.9455919112034317`}, {
             3.8221742658096085`, 2.011900137730814}, {3.9570677550818436`, 
             2.082318966973759}, {4.083494846447081, 2.1483343660531755`}, {
             4.2014555399053215`, 2.2099463349690622`}, {4.419227768734074, 
             2.3237197732669554`}, {4.532312672139321, 
             2.382813357683136}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.553239662827282, 2.393748954332709}, {
             4.617634477201367, 2.4273990728241452`}, {4.7999648603750575`, 
             2.5226951788276066`}, {4.969508113323001, 2.6113190364643137`}, {
             5.127734604004712, 2.694036592242037}, {5.276797681636658, 
             2.7719698211280046`}, {5.2812826911489825`, 
             2.7743147625222058`}, {5.390255974261559, 
             2.831293959312594}}]}, 
           {Arrowheads[{{0.00587862007907173, 1.}}], 
            ArrowBox[{{5.4111802705077325`, 2.8422347106550987`}, {
             5.434339063570803, 2.8543438202430456`}, {5.577659914493232, 
             2.9296201119997898`}, {5.656854249492381, 2.971511374067603}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.0834218941422256`, 
             2.0222566545940666`}, {-1.18771430886037, 
             2.232295268525796}, {-1.2757290536869739`, 
             2.407483619608384}, {-1.3526965827193487`, 
             2.559651753262519}, {-1.4214632016559539`, 
             2.6950054139083313`}, {-1.4842592097417482`, 
             2.8182812124292704`}, {-1.5084532228120007`, 
             2.865688104630572}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.519186575068655, 
             2.886719542115222}, {-1.5422685798735376`, 
             2.931947512787042}, {-1.6461915670160425`, 
             3.1350534952624107`}, {-1.7431013544303169`, 
             3.3239904464068912`}, {-1.8300744725950226`, 
             3.493293839170527}, {-1.9092567032063326`, 
             3.647263949927342}, {-1.9503190297671698`, 
             3.7270563415024025`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.961123387504006, 
             3.748051390138465}, {-1.982752684553033, 
             3.7900814815672175`}, {-2.0518547848417446`, 
             3.9243043807084357`}, {-2.1165630040724674`, 
             4.049932647350996}, {-2.176877342245201, 
             4.166966281494899}, {-2.28813317575235, 
             4.3827391625202985`}, {-2.389431085698842, 
             4.579112534018202}, {-2.393806407175729, 4.587591297853715}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-2.4046342884850955`, 
             4.608574224238908}, {-2.482475531887511, 
             4.75941971592636}, {-2.568970974121193, 
             4.926994028182526}, {-2.6496748611863765`, 
             5.083312839529501}, {-2.7256954294862066`, 
             5.230536821725889}, {-2.7281211236443794`, 
             5.235234147563613}, {-2.8062815343435434`, 
             5.3865709396352255`}, {-2.8379515707368883`, 
             5.44778696125137}}]}, 
           {Arrowheads[{{0.004488527512878022, 1.}}], 
            ArrowBox[{{-2.8488012390263777`, 
             5.468758630506444}, {-2.8802019156054377`, 
             5.529453997962012}, {-2.9465234362472006`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.9327535392843918`, -1.01430734724633}, \
{-2.0217485047165575`, -1.0632418745734573`}, {-2.233675932357826, \
-1.1791044893233382`}, {-2.4092920996440634`, -1.2745673756330014`}, \
{-2.561312195937128, -1.3569308467254373`}, {-2.696245750002843, \
-1.4298778566240562`}, {-2.7624292533221406`, -1.4656110287141166`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.7832063503243427`, -1.4768288027133223`}, \
{-2.818992059190342, -1.4961498846920807`}, {-2.9320826266276203`, \
-1.5571522535480764`}, {-3.133949072047758, -1.6659016153321278`}, \
{-3.323641657236305, -1.7679675785295763`}, {-3.493350342111429, \
-1.859209963676478}, {-3.614851585089664, -1.9244981518646875`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.635650941530057, -1.9356745996456974`}, \
{-3.6475125840341116`, -1.9420484039710135`}, {-3.790406430229998, \
-2.018805816380967}, {-3.9246436337833086`, -2.090897873802425}, \
{-4.050224194694043, -2.1583245762353886`}, {-4.167148112962202, \
-2.221085923679858}, {-4.382611902235869, -2.336711388863841}, \
{-4.46779623215088, -2.382414041300659}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.488602794037736, -2.3935770693748237`}, \
{-4.5786208822693855`, -2.441873104614903}, {-4.758531191176989, \
-2.538379610614514}, {-4.925698967072921, -2.628039446544143}, \
{-5.081607547569789, -2.7116508931834624`}, {-5.228425322289785, \
-2.790380663200431}, {-5.233074210859704, -2.7928734936575936`}, \
{-5.320928784656767, -2.8399797817894377`}}]}, 
           {Arrowheads[{{0.007577727649628275, 1.}}], 
            ArrowBox[{{-5.341738206448457, -2.8511374776999623`}, \
{-5.38405191749327, -2.8738254469001636`}, {-5.526639306886138, \
-2.9503899674375784`}, {-5.656854249492381, -3.0207212360498086`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-1.932116405150806, 
             1.016600055496294}, {-2.021085256074339, 
             1.0656470595282077`}, {-2.232935678972645, 
             1.1817678884378915`}, {-2.408492519888233, 
             1.2774460606160825`}, {-2.5604628523354918`, 
             1.3599961749212384`}, {-2.6953530203199425`, 
             1.4331089358104512`}, {-2.761300195290664, 
             1.4688069033701086`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.782065118416627, 
             1.4800471961113595`}, {-2.818060297667193, 
             1.4995318024157425`}, {-2.9311150744557106`, 
             1.5606731182952434`}, {-3.1329180886098835`, 
             1.6696704547939683`}, {-3.3225669321417186`, 
             1.7719777382713453`}, {-3.492235392296406, 
             1.8634352835505716`}, {-3.6132248793742567`, 
             1.9286172503303216`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.634012133562331, 
             1.9398161912024108`}, {-3.64636023943184, 
             1.9464686189960858`}, {-3.7892187963528583`, 
             2.0234062886462114`}, {-3.9234224873141113`, 
             2.0956674588260995`}, {-4.048971312315598, 
             2.163252129535751}, {-4.16586527135732, 
             2.226160300775165}, {-4.381273151593085, 
             2.3420558958145725`}, {-4.465673653022521, 2.387455588927007}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.486468134628142, 
             2.3986411040286755`}, {-4.577230688053025, 
             2.447462994915612}, {-4.75709328762655, 
             2.544194434422558}, {-4.92421635720307, 
             2.6340630506796843`}, {-5.080082932580128, 
             2.7178690331549253`}, {-5.2268609489558155`, 
             2.7967818770253037`}, {-5.231505008884273, 
             2.7992785851262223`}, {-5.318310972121706, 
             2.8459434961640886`}}]}, 
           {Arrowheads[{{0.007645178737762182, 1.}}], 
            ArrowBox[{{-5.339108321592679, 
             2.8571236781088682`}, {-5.382441570905464, 
             2.8804186471265125`}, {-5.525046310920801, 
             2.957181470631608}, {-5.656854249492381, 
             3.028541812208051}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.0693536955564267`, 2.022245712232894}, {
             1.1335722352627409`, 2.1338655079968216`}, {1.212478489071621, 
             2.2724994409161754`}, {1.28256068709424, 2.3965671662882997`}, {
             1.3677117854315302`, 2.548289689629467}, {1.4436452940832003`, 
             2.684208043788563}, {1.5331276527345792`, 
             2.845006682559902}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.544591270079178, 2.86564915177029}, {
             1.6189649465808014`, 2.9996740838512617`}, {1.7215686288253866`, 
             3.1850193870026473`}, {1.8134012322450699`, 
             3.3512023349807416`}, {1.9171428477254946`, 
             3.5392196180275364`}, {2.00149433282271, 3.6922570967773916`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0128908974057738`, 3.712936664466232}, {
             2.090335981652627, 3.853554914015666}, {2.1651036874475675`, 
             3.9893622166908527`}, {2.2351189176120045`, 4.116590786121149}, {
             2.3003816721459382`, 4.235240622306557}, {2.3619198489741287`, 
             4.347158265493728}, {2.420761346021335, 4.454190255929316}, {
             2.468165432690931, 4.540443134173836}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{2.4795380482915754`, 4.561135882365803}, {
             2.5303543007727973`, 4.653597278545742}, {2.631005846168535, 
             4.836793388786752}, {2.724561291976756, 5.007110285283261}, {
             2.8118412262780588`, 5.166033113924303}, {2.894046561401785, 
             5.3157361577958975`}, {2.8964292938232563`, 5.320075596231946}, {
             2.9342455156763263`, 5.388954127136601}}]}, 
           {Arrowheads[{{0.005978918375397882, 1.}}], 
            ArrowBox[{{2.945609124180838, 5.409651823025089}, {
             2.9805034478044834`, 5.473208403517098}, {3.0594841251890563`, 
             5.616271292130184}, {3.0820325435270766`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.070282422304214, -2.021757078288997}, {
             1.1345511632477274`, -2.1333470849887664`}, {
             1.2135275117990074`, -2.271957753866147}, {
             1.2836721732877368`, -2.396004396935837}, {
             1.368898352882315, -2.547699016549724}, {
             1.4448989024853605`, -2.6835920758670975`}, {
             1.5344305735169834`, -2.8443070149955445`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.5459036593707378`, -2.8649442230880164`}, {
             1.6203727742822798`, -2.9989971009490155`}, {
             1.7230671036910894`, -3.184306663695739}, {
             1.814980786546419, -3.350457224650022}, {
             1.9188127352108995`, -3.5384353394835957`}, {
             2.0031839972566003`, -3.6913435191222375`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0145900353072306`, -3.7120178631330005`}, {
             2.092159447804556, -3.852709772399899}, {
             2.1669947268695626`, -3.9884929874220543`}, {
             2.237073118727946, -4.115698728440518}, {
             2.3023946233797066`, -4.234326995455291}, {
             2.3639881056996037`, -4.346224088911707}, {
             2.4228824305623964`, -4.453236309255101}, {
             2.470242677591355, -4.539316194774531}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.4816247490403116`, -4.5600037432727705`}, {
             2.53257360791667, -4.652606130602822}, {
             2.633315179217844, -4.835767670870927}, {
             2.7269541682412353`, -5.006052141431888}, {
             2.8143119427592334`, -5.1649444988657445`}, {
             2.8965905432085677`, -5.314618725262271}, {
             2.8989751796551286`, -5.31895692856374}, {
             2.936710671384503, -5.387613996088483}}]}, 
           {Arrowheads[{{0.006012816509856574, 1.}}], 
            ArrowBox[{{2.94808374103968, -5.4083064947281985`}, {
             2.983184201309306, -5.472169308234491}, {
             3.0623150332603855`, -5.615372830380507}, {
             3.085382460596112, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.6432899580944594, 2.1463337635615254`}, {
             0.6907739523226165, 2.284369245689017}, {0.7326272922329783, 
             2.4078979848872692`}, {0.7833084473237253, 
             2.5594553135691083`}, {0.8282836026929636, 2.695222564738663}, {
             0.8829569219293156, 2.861613664223001}, {0.9317025110779498, 
             3.0108431299248313`}, {0.941938023852224, 
             3.042338709240554}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.9492358070229455, 3.064794634385809}, {
             0.9920306241490421, 3.196478076810352}, {1.045917280660321, 
             3.3629188690164775`}, {1.106684756821307, 3.551217409449317}, {
             1.1614906836411325`, 3.7214291543960454`}, {1.2080388741215222`, 
             3.8662399010901516`}, {1.2393170033125487`, 
             3.9636237016388267`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.2465375086522328`, 3.986104593880367}, {
             1.2517852784790195`, 4.002443415394148}, {1.292729896713625, 
             4.130039697308035}, {1.330872728825338, 4.249028746831813}, {
             1.4011915838526598`, 4.468600093352104}, {1.465180392733558, 
             4.668572399598084}, {1.5239266068519595`, 4.852287833078294}, {
             1.5345713633870022`, 4.885592403648202}}]}, 
           {Arrowheads[{{0.016645295506825124`, 1.}}], 
            ArrowBox[{{1.5417599417255656`, 4.908083525336693}, {
             1.5785176775917915`, 5.023088561301273}, {1.6294358005782066`, 
             5.18246421689423}, {1.6773862441710183`, 5.332595302771473}, {
             1.6791528468490198`, 5.3381272463770815`}, {1.7284016336271382`, 
             5.492382266960527}, {1.7750823384086045`, 5.63851562965511}, {
             1.7809842120544421`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.6443256230286969, -2.14602226280529}, {
             0.6918807851287256, -2.284049350309656}, {
             0.7337976075036438, -2.407570491705896}, {
             0.7845554233816291, -2.5591153319499886`}, {
             0.8295991518134997, -2.6948712949599}, {
             0.8843559397382074, -2.861247007450199}, {
             0.9331763353918215, -3.0104625788219717`}, {
             0.9434043070207253, -3.041883566202209}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.9507128826545181, -3.0643359811177877`}, {
             0.9935971168826456, -3.1960791098027808`}, {
             1.0475668213934999`, -3.3625032845775444`}, {
             1.1084280017827879`, -3.550782258489091}, {
             1.1633186069413803`, -3.72097623082082}, {
             1.2099391785263436`, -3.865772904909456}, {
             1.241226752625682, -3.9630252957807786`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{1.2484580787344242`, -3.9855027096899716`}, {
             1.2537536322189213`, -4.001963085803478}, {
             1.2947619680191143`, -4.129546773502888}, {
             1.3329641859269217`, -4.248523968007684}, {
             1.403392567487116, -4.468073241750532}, {
             1.467481076321239, -4.668025271349117}, {
             1.5263188406885648`, -4.851721923093248}, {
             1.5369253023015037`, -4.884851631044815}}]}, 
           {Arrowheads[{{0.01666439955628788, 1.}}], 
            ArrowBox[{{1.5441247155332294`, -4.907339286824264}, {
             1.5809949888483683`, -5.022505063272734}, {
             1.6319924657436307`, -5.181864195570689}, {
             1.6800176392485313`, -5.331979642430273}, {
             1.681786830238889, -5.337510492875767}, {
             1.731112300383865, -5.491749121600068}, {
             1.7778682908034111`, -5.637882015857372}, {
             1.7839836241975513`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0353326686493602`, -0.6040489453710818}, \
{-2.250174193623534, -0.670697269140348}, {-2.4272315149807935`, \
-0.7252587251941788}, {-2.580084724178245, -0.7721786393310383}, \
{-2.7155439514289292`, -0.8136521468331288}, {-2.838668885842514, \
-0.8512908014480006}, {-2.938093364680711, -0.8816507298039699}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.9606771174714748`, -0.8885427758636273}, \
{-3.1543140167361634`, -0.9475800778609408}, {-3.3454851017920726`, \
-1.0057794951953676`}, {-3.51637355785772, -1.0577548738397424`}, \
{-3.6715220024706428`, -1.1049113512030608`}, {-3.8152848073251007`, \
-1.1485891610432946`}, {-3.8642588054377316`, -1.163464506585167}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.8868516061832237`, -1.1703268362049575`}, \
{-3.9503152545843614`, -1.1896032632008444`}, {-4.0766133442484245`, \
-1.2279536576757104`}, {-4.19417907631729, -1.2636403444678925`}, \
{-4.410786886857975, -1.329370583288908}, {-4.60781210539496, \
-1.3891419679485941`}, {-4.788638560511659, -1.4439865663179579`}, \
{-4.790633039064082, -1.4445913965262656`}}]}, 
           {Arrowheads[{{0.01866826979793781, 1.}}], 
            ArrowBox[{{-4.81322889991296, -1.4514436432989921`}, \
{-4.956650080791483, -1.4949364462680064`}, {-5.113340163248305, \
-1.5424463960459818`}, {-5.260891775120932, -1.5871809903677976`}, \
{-5.266764881711811, -1.5889615096566685`}, {-5.418542215919476, \
-1.6349712491022492`}, {-5.562509792674133, -1.6786105879791753`}, \
{-5.656854249492381, -1.70736789116598}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.289730557668752, -0.22210138113764466`}, \
{-2.469073455856086, -0.2400979570333014}, {-2.6238299379697247`, \
-0.2555659014377894}, {-2.760947482640442, -0.2692346616157181}, \
{-3.0003350045649615`, -0.2930472256860004}, {-3.2050552629155633`, \
-0.31336685911947804`}, {-3.229551497723283, -0.3157945283713769}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.2530483846480838`, -0.3181231584792458}, \
{-3.398650462804613, -0.33255287353250707`}, {-3.5717131970813885`, \
-0.3496871486472694}, {-3.7288451770618956`, -0.36523332009452264`}, \
{-3.8744542753647173`, -0.3796332310992068}, {-4.011225844808098, \
-0.39315548507474773`}, {-4.139159885392036, -0.40580008202114537`}, \
{-4.192939185397197, -0.41111356923239645`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.21643676782175, -0.4134351707351344}, \
{-4.258256397116533, -0.41756702193839973`}, {-4.477701194357108, \
-0.4392415197750709}, {-4.677324596899727, -0.45895256767435366`}, \
{-4.860550423142239, -0.4770401440450368}, {-5.030802491482495, \
-0.49384422729590927`}, {-5.156346532287307, -0.5062337433417562}}]}, 
           {Arrowheads[{{0.010150075169408997`, 1.}}], 
            ArrowBox[{{-5.179844379208023, -0.5085526662440364}, \
{-5.189592142547179, -0.5095146399827131}, {-5.339128431382783, \
-0.5242703134612604}, {-5.3455373044092775`, -0.5249026848419429}, \
{-5.499354613231552, -0.5400787034632528}, {-5.64526417300934, \
-0.5544734969524104}, {-5.656854249492381, -0.5556266529723798}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.23457638947771658`, 2.3155373262432577`}, {
             0.25158376541917477`, 2.438202031798026}, {0.2719066716984589, 
             2.5895803074688892`}, {0.28967630911772024`, 
             2.725171519635454}, {0.3110664037665952, 2.891894439466527}, {
             0.32994819073712983`, 3.041415350470817}, {0.35316921374531685`, 
             3.2278723945062966`}, {0.35616104108415797`, 
             3.2521479952297496`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3590492307222119, 3.2755826826386056`}, {
             0.37377196153040915`, 3.395042495716293}, {0.3968665225227114, 
             3.5841227480807176`}, {0.41761152488079023`, 
             3.7550595110581813`}, {0.43523919674529216`, 
             3.9010106249797807`}, {0.4517798542354888, 4.038276873456934}, {
             0.46723349735138, 4.16685825648964}, {0.472785063854068, 
             4.213188784187152}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.4755942809161762, 4.236633069478756}, {
             0.4816001260929658, 4.286754774077899}, {0.5080370264113461, 
             4.507986412803507}, {0.532055241148754, 4.709464989516188}, {
             0.5540762254170633, 4.894561567950656}, {0.5745214343281473, 
             5.066647211841625}, {0.587317388248512, 5.174481561856741}}]}, 
           {Arrowheads[{{0.009786011916486074, 1.}}], 
            ArrowBox[{{0.5900997390295809, 5.197929050794093}, {
             0.5935758916343393, 5.227223362028749}, {0.611509788196543, 
             5.378487523090091}, {0.6122402037082361, 5.38465078834972}, {
             0.6306480045881169, 5.5400869568582385`}, {0.6444683579384063, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.2357513134662181, -2.3154445363372274`}, {
             0.2528223686557512, -2.4381131908738207`}, {
             0.2732233117641379, -2.589493380254399}, {
             0.291062800465903, -2.7250864019630927`}, {
             0.31253848667119416`, -2.891809653413644}, {
             0.3314970240860004, -3.0413309248565032`}, {
             0.35481356082551546`, -3.227786962938211}, {
             0.35780930958691154`, -3.251993638180439}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.3607093383953274, -3.275426863443866}, {
             0.37550194883922583`, -3.394956218379947}, {
             0.39869341875002634`, -3.584035867654152}, {
             0.4195260241334012, -3.7549720102616018`}, {
             0.4372281907768851, -3.9009200740294006`}, {
             0.45383892096162165`, -4.03818351712439}, {
             0.46935821468761096`, -4.166762339546571}, {
             0.4749194030737254, -4.21297531698189}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{0.47774047579281576`, -4.236418178625677}, {
             0.48378607195485296`, -4.286656541295942}, {
             0.5103359696888281, -4.507884011959137}, {
             0.5344571067392799, -4.709358858296852}, {
             0.5565726560678182, -4.894452060480092}, {
             0.577105790636053, -5.066534598679861}, {
             0.5899381349162582, -5.174210017292581}}]}, 
           {Arrowheads[{{0.00979242066859891, 1.}}], 
            ArrowBox[{{0.5927323487782461, -5.197656095476995}, {
             0.59624229874555, -5.227107871690803}, {
             0.6142534911267667, -5.37836932910288}, {
             0.6149869832040957, -5.384531871654503}, {
             0.6334741888196521, -5.53996503892095}, {
             0.6473689549145483, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.938065708561636, -3.234506335061191}, {
             3.02400438314515, -3.3281214432923516`}, {
             3.1821718055129606`, -3.500486962235439}, {
             3.2739219391852195`, -3.6005109833559272`}, {
             3.3613607640455823`, -3.6958485457442647`}, {
             3.5233044873306185`, -3.872464294324488}, {
             3.576516513720483, -3.9305109820748134`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.592472136459238, -3.9479162777159305`}, {
             3.660325506309168, -4.0219345709421495`}, {
             3.789227461455848, -4.162563759836728}, {
             3.9100103527706587`, -4.294351861008224}, {
             4.022674180253599, -4.417298874456635}, {
             4.12896414836671, -4.533302450722943}, {
             4.230592329391199, -4.644224078376236}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.24654277006088, -4.6616341230567695`}, {
             4.327658119869565, -4.75017224333219}, {
             4.42006212325931, -4.851038459675129}, {
             4.508625421442442, -4.9477169574690745`}, {
             4.594135964120141, -5.041065804806157}, {
             4.755998782959234, -5.217774548109735}, {
             4.8845105686829395`, -5.358081556674065}}]}, 
           {Arrowheads[{{0.008079245828928824, 1.}}], 
            ArrowBox[{{4.900458828659303, -5.375493598974223}, {
             4.9070566577700925`, -5.38269699794919}, {
             5.051540207949505, -5.540448347054129}, {
             5.1581495810808065`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-0.6198710106976907, 
             2.03042826914259}, {-0.674152809031897, 
             2.2405836830017023`}, {-0.7208134278565583, 
             2.416118268914585}, {-0.7620404850851096, 
             2.568709087720096}, {-0.7991203532769414, 
             2.7045089603922228`}, {-0.8331129354150029, 
             2.8282267923634503`}, {-0.8645999750776525, 
             2.942321928689232}, {-0.8646803795072664, 
             2.942611517455533}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.8709972935574689, 
             2.965362842916229}, {-0.921219343856792, 
             3.1462451855573677`}, {-0.9740626586635102, 
             3.3354863244238038`}, {-1.0216016448072027`, 
             3.5051257948856254`}, {-1.0649550435072865`, 
             3.6594415355313923`}, {-1.1052365790420744`, 
             3.802602029280728}, {-1.1255933166666137`, 3.874879945545737}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-1.1319944852580228`, 
             3.897607709492076}, {-1.1431341351654272`, 
             3.9371597584539053`}, {-1.1786477118773444`, 
             4.063114723050925}, {-1.2117773091778266`, 
             4.180466923071784}, {-1.2729338135213448`, 
             4.396849780034868}, {-1.3286528961728412`, 
             4.593795079992995}, {-1.3798597223108897`, 
             4.774639702400475}, {-1.3888809006525142`, 4.806481271829313}}]}, 
           {Arrowheads[{{0.018218247909585705`, 1.}}], 
            ArrowBox[{{-1.395317194638565, 
             4.829199113563537}, {-1.4274794571140637`, 
             4.942720526711618}, {-1.4719249778971233`, 
             5.099517528989497}, {-1.5138007416518273`, 
             5.247195334476559}, {-1.515475774094797, 
             5.253101435189533}, {-1.5585477884178573`, 
             5.40492651768913}, {-1.59941860346302, 
             5.548957592260097}, {-1.6301974197593025`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.208100881686843, 
             2.0593401291691373`}, {-0.2187836540780153, 
             2.269913325715993}, {-0.2292373891838712, 
             2.446694491143534}, {-0.23909491553706452`, 
             2.6007853825435077`}, {-0.2483173181711483, 
             2.7381472196546244`}, {-0.26509328845163443`, 
             2.978981676877438}, {-0.266752839508187, 3.0019726045491835`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.26845279789108123`, 
             3.025523323324469}, {-0.2800163634694797, 
             3.1857215280080347`}, {-0.2940918545176768, 
             3.3761675238568074`}, {-0.3069073186472312, 
             3.5470801269255032`}, {-0.31869234773180927`, 
             3.702677455025458}, {-0.329698119228347, 
             3.84709689629472}, {-0.3388990396590756, 3.967371172627995}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.34070273738805396`, 
             3.9909141731623903`}, {-0.3498536905965895, 
             4.1100180021861}, {-0.3590034904682942, 
             4.228519666808221}, {-0.3759555796545866, 
             4.447093826901821}, {-0.3914499621432001, 
             4.646088166458904}, {-0.40572719570243615`, 
             4.828855051772023}, {-0.4138459331490469, 
             4.932557328385618}}]}, 
           {Arrowheads[{{0.014884827282538628`, 1.}}], 
            ArrowBox[{{-0.41568885103749065`, 
             4.956097291575747}, {-0.41902783810059613`, 
             4.998746849133731}, {-0.43146154914461216`, 
             5.1572529320365135`}, {-0.4431894172519507, 
             5.306552603638609}, {-0.44369347382348157`, 
             5.312965151022413}, {-0.4557705942152434, 
             5.466433264554799}, {-0.46723912170494114`, 
             5.612032414351325}, {-0.4708015531683752, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.90728207273693, -3.235124040476515}, \
{-2.989678658254009, -3.327797041077728}, {-3.141412989571193, \
-3.4983879145990118`}, {-3.229326549619015, -3.5971900835179382`}, \
{-3.31314178709201, -3.6913727746222222`}, {-3.4684772943135194`, \
-3.8658797233868647`}, {-3.535113757059375, -3.9407225631281153`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-3.5508151184309806`, -3.958357569916161}, \
{-3.6016891083489693`, -4.015496765448667}, {-3.7269879690026833`, \
-4.15621001682741}, {-3.8443738762746613`, -4.288019477523096}, \
{-3.9538468301649035`, -4.410925147535724}, {-4.057113515802127, \
-4.5268502233464325`}, {-4.155880618315052, -4.63771790143636}, \
{-4.178986841137923, -4.663653408501956}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.194693698146562, -4.6812835207037065`}, \
{-4.250148137703676, -4.743528181805505}, {-4.339916073968, \
-4.84428106445387}, {-4.425951792185541, -4.940839969821646}, \
{-4.509022657433813, -5.034068318349024}, {-4.666269829022554, \
-5.210533344882589}, {-4.813024766127748, -5.375213330883729}, \
{-4.823026340570795, -5.386436007870523}}]}, 
           {Arrowheads[{{0.007170384659935082, 1.}}], 
            ArrowBox[{{-4.838735973742802, -5.404063646366281}, \
{-4.953516414652561, -5.532857749741432}, {-5.064027895438795, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.9062456424688454`, 
             3.2360476382068266`}, {-2.9886106197649327`, 
             3.3287450397407663`}, {-3.140287075193891, 
             3.4993811794473033`}, {-3.228168398612285, 
             3.598211010703279}, {-3.31195293402446, 
             3.6924201019256957`}, {-3.4672316408301516`, 
             3.866976064269852}, {-3.5338507001228856`, 
             3.9418477448884532`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.5495463987642415`, 
             3.959487791869567}, {-3.6003880277619387`, 
             4.01662756911737}, {-3.725635096593383, 
             4.157373613385237}, {-3.842972847324485, 
             4.289214197073451}, {-3.9524012799552444`, 
             4.4121493201820146`}, {-4.055626240363792, 
             4.528102478777762}, {-4.154353574428258, 
             4.63899716892753}, {-4.177491675661533, 4.664985249238637}}]}, 
           {Arrowheads[{{0.02000000000000001, 1.}}], 
            ArrowBox[{{-4.193192872444548, 
             4.682620402567066}, {-4.248583282148644, 
             4.744833390631318}, {-4.338315363524948, 
             4.845611143889127}, {-4.424316832294846, 
             4.942194012465395}, {-4.507354702196011, 
             5.0354455801245575`}, {-4.664539645392149, 
             5.211954812691574}, {-4.811236761420698, 
             5.376676337703608}, {-4.8212991380476735`, 
             5.38797453972311}}]}, 
           {Arrowheads[{{0.007124562890289119, 1.}}], 
            ArrowBox[{{-4.837003112007405, 
             5.405607220041435}, {-4.951673428457326, 
             5.534360937867719}, {-5.060774661543296, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.223654788975264, -2.918063592674194}, \
{-3.3267264798227396`, -3.0122555665312403`}, {-3.428176073009749, \
-3.104939794764906}, {-3.5236800374676336`, -3.1921717638546223`}, \
{-3.700458532768859, -3.3535979110910423`}, {-3.861417871076088, \
-3.500539780719784}, {-3.9210626441423897`, -3.5549813209356684`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-3.938502194131474, -3.5708994963811893`}, \
{-4.0108297529322865`, -3.636917413773448}, {-4.151315562960371, \
-3.7651343186719766`}, {-4.2828753011603435`, -3.8851904954153693`}, \
{-4.405508967532202, -3.997085944003626}, {-4.521149955196237, \
-4.102590565437274}, {-4.631731657272739, -4.203474260716838}, \
{-4.636174657335094, -4.207527385194629}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.6536186667461985`, -4.223440673635473}, \
{-4.737254073761706, -4.299737029842318}, {-4.837717204663139, \
-4.391378872813715}, {-4.933986711412235, -4.479191196873865}, \
{-5.026928255444189, -4.563965409265604}, {-5.202827455356673, \
-4.7243994990438525`}, {-5.3514236595461435`, -4.85992329868402}}]}, 
           {Arrowheads[{{0.008253377233283569, 1.}}], 
            ArrowBox[{{-5.368869634595237, -4.8758344321414215`}, \
{-5.5240105300310205`, -5.017321288480583}, {-5.656854249492381, \
-5.138466626877546}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1496475078279276`, -2.842463730985178}, {
             3.2414307484738276`, -2.9244579368770487`}, {
             3.410427563994797, -3.075492948297738}, {
             3.5085393540717553`, -3.1632107049924674`}, {
             3.6020537473624654`, -3.2468303004466605`}, {
             3.7752903435851395`, -3.4017750076334385`}, {
             3.853752839445879, -3.4719695517681655`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.871350446345523, -3.487712818415903}, {
             3.921842552717796, -3.532884340814253}, {
             4.059727680078526, -3.656253833041825}, {
             4.188945725667328, -3.771883484316154}, {
             4.309496689484205, -3.8797732946372405`}, {
             4.423240546665821, -3.981581784677476}, {
             4.53203727234884, -4.078967475109253}, {
             4.575149941686912, -4.11756058088162}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.592742799724312, -4.133309154131666}, {
             4.635886866533264, -4.171930365932569}, {
             4.734789329219093, -4.260470457147427}, {
             4.829585857206788, -4.3453389924026204`}, {
             4.921117647296811, -4.4272872153469445`}, {
             5.094387013783839, -4.582422724302985}, {
             5.256099744363992, -4.727219640797547}, {
             5.2964049884271915`, -4.763310316108889}}]}, 
           {Arrowheads[{{0.009745743406644622, 1.}}], 
            ArrowBox[{{5.313995528127622, -4.779061478808314}, {
             5.41099933496423, -4.865921960065161}, {
             5.567368434287909, -5.00594759416568}, {
             5.656854249492381, -5.08608293326077}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.4460893640240577`, -2.5341786345715347`}, {
             3.553162479987091, -2.612210409137386}, {
             3.751347353445489, -2.7566819583462907`}, {
             3.9318716837367047`, -2.888316641778627}, {
             4.097012843768221, -3.008767385594619}, {
             4.209235228772066, -3.090640947544976}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.228310276048356, -3.1045574408081316`}, {
             4.24904820644752, -3.1196871159544934`}, {
             4.351029793515365, -3.1941002823604565`}, {
             4.44924875885233, -3.2657721197679064`}, {
             4.632223848749939, -3.399309842373889}, {
             4.801888432190975, -3.5231478211565235`}, {
             4.9604174847591205`, -3.6388680213291886`}, {
             4.991214814078953, -3.6613505821360692`}}]}, 
           {Arrowheads[{{0.016995276575872957`, 1.}}], 
            ArrowBox[{{5.01028576313428, -3.6752726910088405`}, {
             5.109297247848406, -3.7475527157651225`}, {
             5.250013962852869, -3.8502841773375627`}, {
             5.383015593287321, -3.947437335537414}, {
             5.510212155014124, -4.040783138099051}, {
             5.613266650407194, -4.117708497525034}, {
             5.656854249492381, -4.1507436128215645`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.66072202719239, -3.625520331908275}, \
{-2.7933915079411, -3.808335038646735}, {-2.914156091520691, \
-3.974672174240922}, {-3.0248375571542767`, -4.127059133750277}, \
{-3.1063082078418103`, -4.2392017141856915`}, {-3.1844508722671776`, \
-4.346753098777058}, {-3.215696913233292, -4.389748552598997}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.2295780249595967`, -4.408849362806368}, \
{-3.3286332983030413`, -4.54515227668516}, {-3.4611989345129355`, \
-4.727530674211053}, {-3.58426672492523, -4.8968182950972166`}, \
{-3.6992017046607213`, -5.054899630303911}, {-3.784931952157046, \
-5.172802208263402}}]}, 
           {Arrowheads[{{0.012216558016196024`, 1.}}], 
            ArrowBox[{{-3.7988180484432243`, -5.191899395052747}, \
{-3.8073689088402047`, -5.203659170791397}, {-3.9094230648702686`, \
-5.343994957589148}, {-4.007669523393648, -5.478675582517663}, \
{-4.085625457383511, -5.5839940341154515`}, {-4.140339620358986, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.657800644882386, 
             3.6213878998697346`}, {-2.790542887543473, 
             3.8042997310618434`}, {-2.9113559201421912`, 
             3.970700321573649}, {-3.022066881026535, 
             4.123124520631567}, {-3.1037724083036338`, 
             4.235587758525274}, {-3.1821306517278645`, 
             4.343433260911283}, {-3.2127829995216097`, 
             4.3856106965907165`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.2266643436725944`, 
             4.404711337886183}, {-3.3266683469989915`, 
             4.542316210647206}, {-3.4595264588736327`, 
             4.725092097162734}, {-3.58284192737052, 
             4.894715768970867}, {-3.6979890041035466`, 
             5.053084402269269}, {-3.7820276785013016`, 5.168657344356349}}]}, 
           {Arrowheads[{{0.012325233708918394`, 1.}}], 
            ArrowBox[{{-3.795914030959286, 
             5.187754344873414}, {-3.806341940686605, 
             5.202095173255602}, {-3.908561379599295, 
             5.34265505384102}, {-4.0069700985858985`, 
             5.477560795642611}, {-4.084978427154233, 
             5.582960586950891}, {-4.140461647156974, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.7523988707211204`, -3.676377582174764}, {
             2.8990808680877995`, -3.87025208112132}, {
             3.033137634377388, -4.047494659194037}, {
             3.156165766263709, -4.210205035566869}, {
             3.2697618604205863`, -4.360482929413774}, {
             3.3220792237435486`, -4.429707661429157}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.33631577977763, -4.448545036130124}, {
             3.407780269327639, -4.5431046588537765`}, {
             3.5350555067220295`, -4.711540916681746}, {
             3.653860750665823, -4.86878828110288}, {
             3.7654588778601683`, -5.016511517786734}, {
             3.87074964344279, -5.155897535387458}, {
             3.905666592164366, -5.202124221123899}}]}, 
           {Arrowheads[{{0.011618760512976915`, 1.}}], 
            ArrowBox[{{3.9198981190820987`, -5.220965395581082}, {
             3.970632802551414, -5.288133242559206}, {
             4.065015549648528, -5.4128625620829185`}, {
             4.155445210196897, -5.531522878303721}, {
             4.235624285000453, -5.634685299259825}, {
             4.253129327840145, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.296135013620443, 
             3.909875532266394}, {-2.3836712813145065`, 
             4.06089142424559}, {-2.4660243123832277`, 
             4.202928445136308}, {-2.543194106826607, 
             4.335986594938547}, {-2.6151806646446443`, 
             4.46006587365231}, {-2.6830992685914414`, 
             4.577104679474448}, {-2.7480652014211, 
             4.689041410601814}, {-2.7700222526870006`, 4.726865610076769}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-2.7818764978448307`, 
             4.747286263471659}, {-2.8691390537290005`, 
             4.897608648772234}, {-2.980412840631976, 
             5.08925025856926}, {-3.083897181193655, 
             5.267448910398582}, {-3.1804884835821703`, 
             5.433754725932827}, {-3.2561675182492507`, 5.564042017618028}}]}, 
           {Arrowheads[{{0.0017729144609922572`, 1.}}], 
            ArrowBox[{{-3.2680272608771888`, 
             5.584459478726972}, {-3.271499267723878, 
             5.590436806143443}, {-3.273710737513418, 
             5.59424384508865}, {-3.3100834140701383`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.9423589147751044`, -4.220219807665487}, \
{-1.9973233550640614`, -4.341439713452049}, {-2.0987691479608346`, \
-4.565055713464907}, {-2.19118401083251, -4.768671509084801}, \
{-2.2761070543239463`, -4.955709374139966}, {-2.3326790284651158`, \
-5.080273361655022}}]}, 
           {Arrowheads[{{0.012914684809692767`, 1.}}], 
            ArrowBox[{{-2.3424428714700847`, -5.101772049594301}, \
{-2.3550773890800016`, -5.129591582458635}, {-2.4287809082908, \
-5.291839034873802}, {-2.4982216475010435`, -5.444677123781615}, \
{-2.5003362109377933`, -5.449330881305516}, {-2.564511378970911, \
-5.590349184215911}, {-2.5951087337023173`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-1.5415205037066322`, 
             4.467593394314945}, {-1.6191592547136329`, 
             4.696847940756343}, {-1.689920613020138, 
             4.905666114458004}, {-1.754971874536626, 
             5.097535598881729}, {-1.8154803351735755`, 
             5.275944077489317}, {-1.8447057574788892`, 
             5.3620880070471415`}}]}, 
           {Arrowheads[{{0.0060916830310415344`, 1.}}], 
            ArrowBox[{{-1.8522917430795, 
             5.3844482180435405`}, {-1.8719675008474803`, 
             5.442443858737962}, {-1.9251972007884413`, 
             5.599307220619122}, {-1.9268837031260566`, 
             5.604276677112311}, {-1.944763479096768, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.15204486402902903`, 
             4.4310763108397735`}, {-0.15831453938016493`, 
             4.658760238285972}, {-0.1640787868635795, 
             4.866169455021893}, {-0.1694158780375175, 
             5.056758487294365}, {-0.1744040844602238, 
             5.233981861350215}, {-0.1783967067167544, 
             5.375188306528797}}]}, 
           {Arrowheads[{{0.005466872583944648, 1.}}], 
            ArrowBox[{{-0.17906407077543854`, 
             5.3987908665287065`}, {-0.17908071269462636`, 
             5.399379438674648}, {-0.1835009274598026, 
             5.555205490101657}, {-0.18366888215255814`, 
             5.561117373330003}, {-0.1863958932461953, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.011813288478356715`, 1.}}], 
            ArrowBox[{{-0.6884496560782425, 
             5.10362468624933}, {-0.711614951076695, 
             5.282274812355606}, {-0.7332550544970502, 
             5.449006522369047}, {-0.7536567406866929, 
             5.6060920031826456`}, {-0.7543933629650429, 
             5.611761934746607}, {-0.7602592558159543, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.7488940946727034`, -0.7518770258248358}, {
             2.9233197993565327`, -0.7986018071106016}, {
             3.0798853899158516`, -0.8406262656973533}, {
             3.272803008716115, -0.8924963099999603}, {
             3.445925423447862, -0.9391008239348082}, {
             3.6427419361434894`, -0.9921383899600119}, {
             3.660994276000315, -0.997060511719096}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.6837918687407365`, -1.0032083551278086`}, {
             3.820633193148077, -1.0401104545676993`}, {
             3.9683311927667355`, -1.079961435568233}, {
             4.107381004254459, -1.1174881854104566`}, {
             4.237782627611246, -1.1526907040943697`}, {
             4.359536062837098, -1.1855689916199725`}, {
             4.584451701145228, -1.2463225213741362`}, {
             4.595635629408605, -1.2493442506192418`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.618430272790138, -1.2555030205000608`}, {
             4.789481251428083, -1.3017184228508363`}, {
             4.977985280469465, -1.3526599704084346`}, {
             5.153324355053175, -1.4000504384052934`}, {
             5.317005743949624, -1.444295622971428}, {
             5.471238204262596, -1.4859903286034553`}, {
             5.476616012928991, -1.4874442088259143`}, {
             5.530193941390794, -1.5019354659200956`}}]}, 
           {Arrowheads[{{0.0022790415570417694`, 1.}}], 
            ArrowBox[{{5.552986944310698, -1.5081003042171983`}, {
             5.629554183927917, -1.5288094952243856`}, {
             5.656854249492381, -1.5362923206329298`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.021142157977811, 3.3274328070615797`}, {
             3.1791667048105094`, 3.499767456815732}, {3.2708304889727646`, 
             3.5997698775212728`}, {3.358187037351829, 3.695086903330463}, {
             3.5199784267603897`, 3.8716647702597937`}, {3.656887020311744, 
             4.021121051238295}, {3.659275407740364, 4.023728625493935}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.675223757556729, 4.041140585506266}, {
             3.785682495077123, 4.161736330073156}, {3.906364851056527, 
             4.293510606764373}, {4.018934088249956, 4.41644388131195}, {
             4.125134242135518, 4.532433897397953}, {4.226709348191322, 
             4.643378398704453}, {4.3130644306010435`, 
             4.737704445289415}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.3290083641210515`, 4.755120449340855}, {
             4.415984416813654, 4.850130856978941}, {4.504471758045894, 
             4.9467968804269775`}, {4.589908808779802, 5.040133522055605}, {
             4.751632038752613, 5.216818659854631}, {4.90255911805986, 
             5.381718526808691}, {4.966710084264638, 5.45181152600873}}]}, 
           {Arrowheads[{{0.005385798275390847, 1.}}], 
            ArrowBox[{{4.982651652880979, 5.469229694781212}, {
             5.046920825266238, 5.539451849100869}, {5.1543644460864995`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.266676449944482, -1.1005930384716234`}, {
             3.4391673773693627`, -1.1579703180927217`}, {
             3.6352138148032718`, -1.22324707299311}, {
             3.812412680878534, -1.2822886047729236`}, {
             3.959883389908274, -1.3314497815584323`}, {
             4.098707783579374, -1.3777394031220964`}, {
             4.162744017622143, -1.399097296048398}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.1851430109030465`, -1.4065679930264712`}, {
             4.2288858618918335`, -1.4211574694639162`}, {
             4.350417624845653, -1.4617039805838916`}, {
             4.5749031424724045`, -1.5366192333479805`}, {
             4.779525274254662, -1.6049220576040344`}, {
             4.967643421976453, -1.6677282877960546`}, {
             5.081037399389497, -1.7055917014695654`}}]}, 
           {Arrowheads[{{0.012355815147431325`, 1.}}], 
            ArrowBox[{{5.1034338233627246`, -1.7130700974571824`}, {
             5.142616987421803, -1.726153758368042}, {
             5.305951764373452, -1.7806994045402977`}, {
             5.459854340518478, -1.8320994717633439`}, {
             5.464995580734408, -1.833816600441903}, {
             5.622970322750973, -1.8865823459378475`}, {
             5.656854249492381, -1.8979682509670905`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.749193533353965, 3.6754810748381717`}, {
             2.895772989238019, 3.8693954315956205`}, {3.029731574124962, 
             4.0466687126216}, {3.1526656426994717`, 4.209402190648634}, {
             3.2661715496462245`, 4.359697138409242}, {3.3185453325789775`, 
             4.429059499073817}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.3327736577327918`, 4.447903091529967}, {
             3.4041709228096386`, 4.542459615298418}, {3.531419227083807, 
             4.711013368809544}, {3.6501927368035143`, 4.868361753002742}, {
             3.7617560488214186`, 5.016173297911411}, {3.867009864841634, 
             5.155637240088984}, {3.90179487413519, 5.2017311825926615`}}]}, 
           {Arrowheads[{{0.011624908792303691`, 1.}}], 
            ArrowBox[{{3.9160181536337784`, 5.2205785838363665`}, {
             3.9668548865682722`, 5.287942816088892}, {4.061205139705965, 
             5.412746255837926}, {4.151606664829405, 5.531486373648661}, {
             4.2316360979754535`, 5.63456113618394}, {4.249221424119492, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.6234790953647122`, -2.691181856947606}, \
{-3.805143809626856, -2.8272152480950563`}, {-3.9704311234935523`, \
-2.9509459124269304`}, {-4.121853013985597, -3.064263976014656}, \
{-4.232848696048477, -3.1473144136997564`}, {-4.339314006104144, \
-3.2269695915352443`}, {-4.3796225718495885`, -3.2571226323179827`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.398529799634585, -3.271266286401084}, \
{-4.535769736518034, -3.373929364020874}, {-4.716410997843713, \
-3.5090399400172636`}, {-4.884121563756983, -3.6344661231609248`}, \
{-5.04075895949244, -3.751600760682596}, {-5.154877591792689, \
-3.8369339936437576`}}]}, 
           {Arrowheads[{{0.012824325742704975`, 1.}}], 
            ArrowBox[{{-5.173787507851226, -3.8510740533322894`}, \
{-5.188180710284684, -3.861836699813015}, {-5.327249627429046, \
-3.9658284752749187`}, {-5.46065017345827, -4.065906061140132}, \
{-5.566392501821605, -4.146429543622266}, {-5.656854249492381, \
-4.2163189518562865`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.9009913239553953`, -2.3307644458368686`}, \
{-4.051749523695484, -2.421525649164805}, {-4.193488315253592, \
-2.506844012122427}, {-4.326207698629716, -2.5867195347097356`}, \
{-4.4499076738238585`, -2.66115221692673}, {-4.5665452774214845`, \
-2.731325261060324}, {-4.678077546008061, -2.798421869397432}, \
{-4.710233636535171, -2.817764248080879}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.73046721498594, -2.829935053987339}, \
{-4.885826078148066, -2.9233857786821895`}, {-5.076650864872813, \
-3.0381544814358397`}, {-5.254049500811244, -3.1448385143132205`}, \
{-5.4195751018966, -3.2443741783842204`}, {-5.539852830331048, \
-3.316696663364428}}]}, 
           {Arrowheads[{{0.002390949127442198, 1.}}], 
            ArrowBox[{{-5.560088370518585, -3.328864207350571}, \
{-5.57550011126684, -3.3381312213131102`}, {-5.57926508691012, \
-3.340395022779951}, {-5.656854249492381, -3.3870455291896917`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.9028803583258713`, 
             2.336437804125104}, {-4.053694193397973, 
             2.427408214545408}, {-4.195486312196528, 
             2.512923896850883}, {-4.328256714721536, 
             2.5929848510415305`}, {-4.452005400972998, 
             2.66759107711735}, {-4.568689726484479, 
             2.7379282441647113`}, {-4.680267046789545, 
             2.8051820212699843`}, {-4.711705837413403, 
             2.8241295841675766`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.7319289949705405`, 
             2.836317697711327}, {-4.888100671780434, 
             2.930439405654265}, {-5.079004816123099, 
             3.0454784081364012`}, {-5.256478019994976, 
             3.1524142065826}, {-5.422073893459932, 
             3.25218520895927}, {-5.540897641021184, 3.323771970858054}}]}, 
           {Arrowheads[{{0.002366610572392909, 1.}}], 
            ArrowBox[{{-5.561122759139603, 
             3.3359568307436733`}, {-5.578065598019825, 
             3.3461642429630425`}, {-5.58182084295985, 
             3.348426572253853}, {-5.656854249492381, 
             3.393627921518501}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.895913755760061, 2.300956272538164}, {
             4.046146273508818, 2.389001533301802}, {4.187559733278139, 
             2.471891236470272}, {4.320154135068023, 2.549625382043574}, {
             4.443929478878473, 2.6222039700217077`}, {4.560766685762696, 
             2.690724260780922}, {4.672546676773901, 2.7562835146974667`}, {
             4.710682327341281, 2.7786529357686502`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.731049073732172, 2.7905995610153576`}, {
             4.88093501117726, 2.878518912002546}, {5.072518987201721, 
             2.990912245982719}, {5.250723109960452, 3.0954656006837573`}, {
             5.417080963207794, 3.1930764940279577`}, {5.545677542725001, 
             3.2685351177107687`}}]}, 
           {Arrowheads[{{0.0022296556807420488`, 1.}}], 
            ArrowBox[{{5.566042417390553, 3.2804849333240975`}, {
             5.573839267393261, 3.2850600127894656`}, {5.577561761663792, 
             3.2872443764809787`}, {5.656854249492381, 
             3.3337754122806973`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.4464012615075648`, -4.022383230671817}, {
             2.532994227446207, -4.16307419803641}, {
             2.6141230151379755`, -4.2949256052914375`}, {
             2.6897876245828707`, -4.417937452436898}, {
             2.76116411341711, -4.534005918248469}, {
             2.829428539276911, -4.645027181501826}, {
             2.9412168712362985`, -4.82687028540905}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.953582618491056, -4.846985317304814}, {
             2.9566212020731992`, -4.851928100333898}, {
             3.0734867771836605`, -5.042072113127915}, {
             3.182146428820219, -5.218891124078678}, {
             3.2835458866720444`, -5.3839178165522}, {
             3.379069650613242, -5.539396540017935}, {
             3.381324475832387, -5.543066755991056}, {
             3.448050517390616, -5.651686151791538}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.254206347536488, 1.9771293909483587`}, {
             4.376359763849396, 2.0335165374895494`}, {4.49166397548007, 
             2.086751895103163}, {4.601974613517717, 2.1376864861191076`}, {
             4.807615168813931, 2.2326533683579894`}, {4.996662652207481, 
             2.31997214510313}, {5.111673033297987, 2.373100118638943}}]}, 
           {Arrowheads[{{0.012221604053391084`, 1.}}], 
            ArrowBox[{{5.133108482292612, 2.383002024502715}, {
             5.172498286167808, 2.4011977772514643`}, {5.3366366394381, 
             2.4770276986212982`}, {5.491296597731291, 2.5484838756781563`}, {
             5.495740663263924, 2.550537197852926}, {5.623979906191854, 
             2.6100338665463196`}, {5.656854249492381, 2.625478683255618}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.211238977379569, -0.5967127700461875}, {
             4.344402500325369, -0.6154359139034362}, {
             4.468774081859115, -0.6329282949901863}, {
             4.6985945823531425`, -0.6652606799663503}, {
             4.908153640524351, -0.6947498360888389}, {
             5.100867362561114, -0.721874028425833}, {
             5.146507434315762, -0.728298683488174}}]}, 
           {Arrowheads[{{0.010413519059126259`, 1.}}], 
            ArrowBox[{{5.169888904886443, -0.7315900429775816}, {
             5.280151854651805, -0.7471115220455135}, {
             5.44754152738726, -0.7706774858659764}, {
             5.6052855534265245`, -0.7928873974479722}, {
             5.610829592534772, -0.7936680141423315}, {
             5.656854249492381, -0.8001494999291069}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.599388403188757, -0.2556939455050871}, {
             3.7761537614091853`, -0.2681182529582592}, {
             3.9223734853829484`, -0.2784019992573725}, {
             4.06004055327846, -0.28808698686568596`}, {
             4.189154965095721, -0.2971732157831995}, {
             4.3097167208347305`, -0.30566068600991314`}, {
             4.532443442717488, -0.321345706824309}, {
             4.541538735410708, -0.32198640926197536`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.5650923611364655`, -0.32364560440031587`}, {
             4.735481897566224, -0.3356484057422418}, {
             4.922156714701235, -0.3488015701845804}, {
             5.0957925234428165`, -0.3610379875721938}, {
             5.25788153163379, -0.372462340841775}, {
             5.410610682196793, -0.3832280956830131}, {
             5.416674724513295, -0.38365556592002925`}, {
             5.5072355189187245`, -0.390039966412697}}]}, 
           {Arrowheads[{{0.0026761455953276895`, 1.}}], 
            ArrowBox[{{5.53078905346905, -0.39170045535357306`}, {
             5.573483126050979, -0.3947103235842532}, {
             5.656854249492381, -0.40059042070450523`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.3965073695970482`, -0.23340161660963282`}, {
             2.558987532292861, -0.2486662065803638}, {
             2.703770021666996, -0.26234361041550863`}, {
             2.8354402478136587`, -0.274817715542859}, {
             3.068285625053837, -0.2969434016770194}, {
             3.1726748923792374`, -0.30688329792704827`}, {
             3.2708481162647756`, -0.31623961026264275`}, {
             3.2869766185218086`, -0.3177774316204387}, {
             3.3367722667097155`, -0.322528862085258}}]}, 
           {Arrowheads[{{0.002642203324320363, 1.}}], 
            ArrowBox[{{3.3602774980429246`, -0.3247716980820461}, {
             3.3884096487574413`, -0.32745602819542147`}, {
             3.4844882177699037`, -0.33662879516855376`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.9446270059930946`, 
             4.218528976555379}, {-1.9996596810823484`, 
             4.339707262552972}, {-2.101230829418473, 
             4.563245288809036}, {-2.193759403287562, 
             4.766789089993832}, {-2.2787865625585044`, 
             4.953760048257767}, {-2.3354598118934113`, 5.078349669892979}}]}, 
           {Arrowheads[{{0.012963175582628522`, 1.}}], 
            ArrowBox[{{-2.345236471743094, 
             5.099842532324953}, {-2.35785346710019, 
             5.127579545751243}, {-2.431646904501149, 
             5.289768048932567}, {-2.5011722194872763`, 
             5.4425503154523005`}, {-2.5032900620281064`, 
             5.447203919701187}, {-2.567631256633363, 
             5.588365370617789}, {-2.5991904615661334`, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.221071209855939, -1.9915455852455513`}, \
{-4.342189462711122, -2.0490795855602295`}, {-4.456352355283049, \
-2.1032996543655886`}, {-4.565499062566007, -2.1551325131249044`}, \
{-4.768743921265016, -2.2516366005054045`}, {-4.955372418307337, \
-2.3402358034536466`}, {-5.074253078981866, -2.3966661008632233`}}]}, 
           {Arrowheads[{{0.013161955332525248`, 1.}}], 
            ArrowBox[{{-5.095583904011283, -2.4067914214458295`}, \
{-5.128832933192156, -2.422574077721547}, {-5.290653152268858, \
-2.4993788480876353`}, {-5.443067333174209, -2.5717137821632967`}, \
{-5.4476755368909995`, -2.5739007324377163`}, {-5.58300176733998, \
-2.6382840415457056`}, {-5.656854249492381, -2.6738329200739046`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.2198257675345365`, 
             1.9970449135841664`}, {-4.340913473978235, 
             2.0547403295117626`}, {-4.4550473567198265`, 
             2.109112416483696}, {-4.564166211670984, 
             2.1610905465897234`}, {-4.767358838201999, 
             2.2578649362040593`}, {-4.953938974433146, 
             2.3467121168467657`}, {-5.072527158839931, 
             2.4031757683898927`}}]}, 
           {Arrowheads[{{0.013210329328369803`, 1.}}], 
            ArrowBox[{{-5.093845977430138, 
             2.413326344100365}, {-5.127354241226292, 
             2.429280707009837}, {-5.289131991203579, 
             2.5063001961638802`}, {-5.441506000252427, 
             2.578837274108905}, {-5.446109103663863, 
             2.581028486259598}, {-5.581307708996053, 
             2.645551683005857}, {-5.656854249492381, 
             2.6820310377169037`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.6184696415801163, -2.0308014839132493`}, \
{-0.6725965460196979, -2.240960822929862}, {-0.7191295519607882, \
-2.416505522829235}, {-0.7602466134798663, -2.5691085406667367`}, \
{-0.7972291516894877, -2.7049212199851427`}, {-0.8311333707241235, \
-2.8286517506631434`}, {-0.8625391224552933, -2.942759270281328}, \
{-0.8626483539304058, -2.9431537386614712`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.8689495836532821, -2.965909413059645}, \
{-0.9190137044982504, -3.1467063182800583`}, {-0.9717214392560946, \
-3.3359650310101943`}, {-1.0191392656088432`, -3.5056215445094336`}, \
{-1.0623827056219535`, -3.659953665445658}, {-1.102562378542903, \
-3.803129852882216}, {-1.1229198689985669`, -3.875601442324499}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-1.1293054025309086`, -3.8983336040088505`}, \
{-1.140364279244592, -3.9377026202749934`}, {-1.1757884077270204`, \
-4.06367196762399}, {-1.2088347639901882`, -4.181037894929207}, \
{-1.2698379467788574`, -4.397446610962922}, {-1.325417614530715, \
-4.594415889930762}, {-1.3764965258621789`, -4.775282870115516}, \
{-1.3855672627135365`, -4.80738346055384}}]}, 
           {Arrowheads[{{0.018194746354328724`, 1.}}], 
            ArrowBox[{{-1.3919879432487632`, -4.830105720010169}, \
{-1.4239974393896666`, -4.943384689799978}, {-1.468332169718014, \
-5.100201455002369}, {-1.5101036234028193`, -5.247897994885378}, \
{-1.511774750473732, -5.253805786143574}, {-1.554739443282636, \
-5.405649825683486}, {-1.59550847387809, -5.549698975077772}, \
{-1.6259968624876653`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.0359204595238514`, 
             0.6065573125367626}, {-2.2507303559836966`, 
             0.6734492577361689}, {-2.4277810351418787`, 
             0.7282168381849863}, {-2.5806374648032264`, 
             0.7753170856782472}, {-2.716104377928668, 
             0.8169516503142946}, {-2.839238895991643, 
             0.8547373594231308}, {-2.9383827735411727`, 
             0.885127574337325}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.9609591044212578`, 
             0.8920438936806341}, {-3.1549175810527417`, 
             0.951405916391182}, {-3.346110415623822, 
             1.0098352078020127`}, {-3.5170205617742356`, 
             1.0620166407153366`}, {-3.6721902573333383`, 
             1.1093605948993217`}, {-3.8159735886652566`, 
             1.153212334974008}, {-3.8642464982520597`, 
             1.1679310239256235`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.886831962152113, 
             1.1748174623197098`}, {-3.951023779457451, 
             1.1943899181804292`}, {-4.077340829709923, 
             1.2328933445185852`}, {-4.194924739422674, 
             1.2687226139884764`}, {-4.411566904731752, 
             1.3347157668123473`}, {-4.608624042887437, 
             1.3947264611409265`}, {-4.789480276443821, 
             1.4497908107577928`}, {-4.790320154108912, 
             1.4500464840617562`}}]}, 
           {Arrowheads[{{0.018681403640002137`, 1.}}], 
            ArrowBox[{{-4.812908693805845, 
             1.4569228266722012`}, {-4.957519727954998, 
             1.500944929446526}, {-5.114236096526189, 
             1.5486454116053336`}, {-5.261812627254755, 
             1.593559466059766}, {-5.267678287583046, 
             1.5953445603678338`}, {-5.419480590203911, 
             1.6415386837184884`}, {-5.563471993806329, 
             1.6853529558369653`}, {-5.656854249492381, 
             1.713926360673502}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-0.2069183158401217, -2.05930964529774}, \
{-0.21747734010614755`, -2.2698724031560666`}, {-0.2278278484178459, \
-2.446648242491731}, {-0.23759572944686805`, -2.600736046994509}, \
{-0.24673840963758245`, -2.73809596478399}, {-0.2633748536320671, \
-2.97892807959859}, {-0.2650251885365525, -3.0019758571284085`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.2667116062295295, -3.025527549396714}, \
{-0.27817836136684726`, -3.185666694897132}, {-0.2921435536690439, \
-3.3761082202813237`}, {-0.30486011174344263`, -3.547017326418011}, \
{-0.3165551475052467, -3.702611781381878}, {-0.327477418040904, \
-3.8470287187410412`}, {-0.33661751730754813`, -3.967415656698114}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.3384077524922012, -3.9909596847634567`}, \
{-0.3474810189291474, -4.109945537369027}, {-0.35656234928173347`, \
-4.2284454186378495`}, {-0.3733881754077176, -4.447016446689397}, \
{-0.3887676258307067, -4.646008043162311}, {-0.4029393145290209, \
-4.828772484564957}, {-0.4110114743839835, -4.932644588725078}}]}, 
           {Arrowheads[{{0.014882283466805792`, 1.}}], 
            ArrowBox[{{-0.41284090529086476`, -4.9561856039090735`}, \
{-0.4161418554809804, -4.998662047405702}, {-0.42848404616765434`, \
-5.157166073566769}, {-0.44012571351698443`, -5.306463821977289}, \
{-0.4406261574395315, -5.312877436192158}, {-0.45261467856764726`, \
-5.466343632789226}, {-0.46399915145401205`, -5.6119409662542585`}, \
{-0.467542871250292, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-2.290927279060248, 
             0.22351856380399082`}, {-2.4703279639253735`, 
             0.24162540717497538`}, {-2.6251414347324054`, 
             0.2571889623281462}, {-2.7623134981546342`, 
             0.27094268589433484`}, {-3.001801646212545, 
             0.2949039090208062}, {-3.2066123839184546`, 
             0.315350922332958}, {-3.230694255719189, 
             0.3177514340715669}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.2541898071595923`, 
             0.3200935006478061}, {-3.400269107628479, 
             0.33465487189190724`}, {-3.5733907974256685`, 
             0.351894898512166}, {-3.730578860751971, 
             0.3675372954737822}, {-3.876241401969248, 
             0.38202649548865686`}, {-4.0130640321217825`, 
             0.3956326889944091}, {-4.141046751209575, 
             0.40835587599103906`}, {-4.194027316568387, 
             0.41362098151093885`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.217523570151103, 
             0.41595599348367823`}, {-4.260189559232624, 
             0.4201960564785466}, {-4.479721297529977, 
             0.4420056380703947}, {-4.679425102459322, 
             0.46183967391415365`}, {-4.86272576650662, 
             0.4800402199475933}, {-5.033048082157831, 
             0.49694933210848374`}, {-5.157380231937818, 
             0.5092908513967997}}]}, 
           {Arrowheads[{{0.010128675301955669`, 1.}}], 
            ArrowBox[{{-5.180876752566102, 
             0.5116231746378554}, {-5.191903804926838, 
             0.5127177473581382}, {-5.34150265151428, 
             0.5275657388809261}, {-5.347904767763255, 
             0.5282011300354552}, {-5.501785237424854, 
             0.5434719826541435}, {-5.647755012002066, 
             0.5579567601223959}, {-5.656854249492381, 
             0.5588674089595075}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.219257050384723, 0.6663325833739585}, {
             2.3501575543495523`, 0.7039985493112332}, {2.506374620883821, 
             0.7492246622660008}, {2.6464244193205584`, 0.7899335862018741}, {
             2.8157059530283624`, 0.8393052924054422}, {2.967611869096877, 
             0.8837123146306671}, {3.1261426359314606`, 
             0.9301473875494093}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.148802567919229, 0.9367846833576335}, {
             3.1546488257896446`, 0.9384971043339213}, {3.3224473343510645`, 
             0.9877159273438552}, {3.5129505355924553`, 
             1.0436607654069385`}, {3.685106901836633, 1.0942593029400354`}, {
             3.8285295850682255`, 1.1364383510363538`}, {3.9635203597259507`, 
             1.1761487575190601`}, {4.054970185675838, 
             1.2030591828470543`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.077621817303696, 1.2097247509347697`}, {
             4.090079225809809, 1.213390522388154}, {4.2082061833198, 
             1.2481636456436358`}, {4.426352739365521, 1.3124005331700408`}, {
             4.625148394610456, 1.370955985954554}, {4.807870752262256, 
             1.4247897547080224`}, {4.977797415528577, 1.4748615901412938`}, {
             4.983619393221481, 1.4765773801826374`}}]}, 
           {Arrowheads[{{0.014363428911141786`, 1.}}], 
            ArrowBox[{{5.006268294883005, 1.4832522185224641`}, {
             5.13639661895178, 1.5216022250513572`}, {5.285819215407812, 
             1.5656428312505688`}, {5.291472149812826, 1.5673090480475191`}, {
             5.444925220717437, 1.6125434062492927`}, {5.590533981004592, 
             1.6554683953918266`}, {5.656854249492381, 
             1.6751543675704377`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.375479893546136, 0.2335768549632881}, {
             2.535199457619991, 0.24872300187468738`}, {2.678424135554611, 
             0.26236575404053575`}, {2.850775993952367, 0.2788441252913372}, {
             3.005469761709078, 0.293671729716309}, {3.1954005248676784`, 
             0.3119158727220152}, {3.3156703371038763`, 
             0.32348614756544947`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.339173818814195, 0.32574724482759493`}, {
             3.365833723184732, 0.32831199831919433`}, {3.559501864358799, 
             0.3469671903113194}, {3.7345164790558263`, 
             0.36384047632019606`}, {3.8794223461527815`, 
             0.3778200740918573}, {4.015842299910413, 0.3909849271380034}, {
             4.1437763403287216`, 0.4033350354586345}, {4.263224467407707, 
             0.4148703990537506}, {4.279290796629906, 
             0.4164224977331595}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.302793373568484, 0.41869298018901946`}, {
             4.483872915115508, 0.4361862926573567}, {4.684997576601613, 
             0.455622008538741}, {4.869897621875136, 0.4734943571677488}, {
             5.0418722209451925`, 0.4901201490142254}, {5.202401463950807, 
             0.5056417982645932}, {5.242892102711228, 
             0.5095572744890164}}]}, 
           {Arrowheads[{{0.00830682978417345, 1.}}], 
            ArrowBox[{{5.2663944656308574`, 0.5118299712418156}, {
             5.353654416339675, 0.5202680762657027}, {5.359805894198468, 
             0.5208629590207317}, {5.515115887011158, 0.5358836165366708}, {
             5.656854249492381, 0.5495926696190482}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.329256251073926, 
             3.0170975295579194`}, {-3.430751694015712, 
             3.1099005244648827`}, {-3.5263007547980165`, 
             3.197246128510592}, {-3.703166619056042, 
             3.358886292063375}, {-3.864209385987177, 
             3.50602667740855}, {-4.013701086730036, 
             3.642590813844269}, {-4.0264567702365275`, 
             3.6542422190190735`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.043890541593619, 
             3.6701667230805763`}, {-4.154263377162956, 
             3.7709844195102464`}, {-4.285896257285937, 
             3.891207494406482}, {-4.408599727098978, 
             4.003260038532976}, {-4.52430767076593, 
             4.108913857686508}, {-4.634953972450644, 
             4.2099407576638574`}, {-4.740538632153119, 
             4.306340738465025}, {-4.741323348539286, 4.307057149759663}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.75876122504142, 
             4.322977158441585}, {-4.841061649873355, 
             4.39811380009001}, {-4.937389012753654, 
             4.486052302519977}, {-5.030386707936317, 
             4.57094860573609}, {-5.206393095208733, 
             4.731614614526755}, {-5.3706204499227965`, 
             4.881519649816594}, {-5.456313797970923, 4.95973641298882}}]}, 
           {Arrowheads[{{0.0052494625247268365`, 1.}}], 
            ArrowBox[{{-5.4737534444001055`, 
             4.975654482776369}, {-5.527766547203167, 
             5.024955043045895}, {-5.656854249492381, 
             5.142773527932908}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.621472268430762, 
             2.6938445484921263`}, {-3.803131363757145, 
             2.830084586214057}, {-3.968405987343978, 
             2.953997487522809}, {-4.119809891237848, 
             3.06747764942234}, {-4.230880771059304, 
             3.150713106593585}, {-4.337414160265934, 
             3.2305427008795595`}, {-4.377194985400367, 
             3.2603470579927865`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.396091705396379, 
             3.2745047480137077`}, {-4.533977781929763, 
             3.377810947723113}, {-4.71470398905824, 
             3.5131944254836514`}, {-4.882483466556313, 
             3.6388664872337575`}, {-5.039177189447451, 
             3.7562247272868166`}, {-5.152019179538405, 3.840734022733954}}]}, 
           {Arrowheads[{{0.01290792557292079, 1.}}], 
            ArrowBox[{{-5.170918593202071, 
             3.854888116717879}, {-5.186646132755122, 
             3.866666739956214}, {-5.325754365066893, 
             3.97084908748192}, {-5.459192487078053, 
             4.071110373663011}, {-5.5650854658140245`, 
             4.151874671968732}, {-5.656854249492381, 
             4.222884078472203}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.548927083905736, 4.209800548280111}, {
             2.630410369456782, 4.342896788728453}, {2.7064157028158444`, 
             4.467084957877502}, {2.778120725132045, 4.584273919393127}, {
             2.8467030775545066`, 4.696372536941197}, {2.9744997727182123`, 
             4.905298740134673}, {3.0418589964158422`, 
             5.015443179582851}}]}, 
           {Arrowheads[{{0.015419823329393227`, 1.}}], 
            ArrowBox[{{3.0541779588501137`, 5.035586897657704}, {
             3.0919322954034407`, 5.097322024758797}, {3.2011271527066714`, 
             5.275900848114433}, {3.303032930916221, 5.44258043360269}, {
             3.3990384876783653`, 5.5996237589472155`}, {3.401243718461633, 
             5.603231170215029}, {3.434021385344769, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.31380463857831, 2.9833151411701264`}, {
             3.486171972715151, 3.1370904027849513`}, {3.5863358755222934`, 
             3.226481785663501}, {3.681809485777652, 3.3116986906070935`}, {
             3.858685828633018, 3.469609066689406}, {4.007856024586733, 
             3.602813412369321}, {4.018421166802377, 3.612248733217138}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.036032454281087, 3.6279766945179044`}, {
             4.148229665801177, 3.7281756949019025`}, {4.27980675227635, 
             3.845695914287151}, {4.402587284012254, 3.9553740705250653`}, {
             4.518455206660268, 4.058887395265147}, {4.629294465871773, 
             4.157913120156896}, {4.735105061646768, 4.252451245200311}, {
             4.740403360758992, 4.257185373695625}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.758010648884496, 4.272917812101723}, {
             4.835886993985253, 4.342501770395395}, {4.932493913649039, 
             4.428825754339413}, {5.025779471399937, 4.512184255629632}, {
             5.2023865011630654`, 4.670004810248674}, {5.367234199646226, 
             4.817324940459069}, {5.462266059638387, 4.902255763265711}}]}, 
           {Arrowheads[{{0.005026391811705404, 1.}}], 
            ArrowBox[{{5.479871682195295, 4.917990065529233}, {
             5.525004360350543, 4.958325543457464}, {5.656854249492381, 
             5.076166898862826}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.783999038855764, 2.7841278020952944`}, {
             3.963833311946193, 2.9154389774121885`}, {4.128510716209915, 
             3.0357145142899378`}, {4.280259732581891, 3.146574300081554}, {
             4.475830363046076, 3.289471704952885}, {4.546670342003546, 
             3.3412403657272742`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.5657343294006605`, 3.35517200589844}, {
             4.655033641388812, 3.42043043564016}, {4.821516657833982, 
             3.5421068952352233`}, {4.977305573617079, 3.655976863233543}, {
             5.12380214565762, 3.763062518385495}, {5.262408130875126, 
             3.8643860394414538`}, {5.328222622013465, 
             3.912535020258228}}]}, 
           {Arrowheads[{{0.008163034516738154, 1.}}], 
            ArrowBox[{{5.347279315282637, 3.9264766361968793`}, {
             5.3934099032468925`, 3.9602251428941155`}, {5.518562158946887, 
             4.052256696062991}, {5.6212005836992605`, 4.129075326779145}, {
             5.656854249492381, 4.156175192920942}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-1.538238778290699, -4.468542173547639}, \
{-1.6157071658594666`, -4.697838233980944}, {-1.6863135919372378`, \
-4.906694929752308}, {-1.751222680909527, -5.098600341153066}, \
{-1.8115990571618488`, -5.277042548474553}, {-1.8407784959027458`, \
-5.363255328445988}}]}, 
           {Arrowheads[{{0.006063997664690258, 1.}}], 
            ArrowBox[{{-1.8483483473540196`, -5.385621006668251}, \
{-1.8679630711606603`, -5.443574138760963}, {-1.9210768153443165`, \
-5.6004676599161884`}, {-1.922759696550131, -5.605438226307958}, \
{-1.940207410861599, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-4.478538520640567, 
             1.6028351094560165`}, {-4.707950080456099, 
             1.6854633324093875`}, {-4.916815145326512, 
             1.760676028426343}, {-5.108656578814731, 
             1.8297468637720815`}, {-5.28699724448368, 
             1.8939495047118011`}, {-5.367166473448651, 1.922807450702942}}]}, 
           {Arrowheads[{{0.0060196093075204245`, 1.}}], 
            ArrowBox[{{-5.389382963288247, 
             1.930804562215439}, {-5.453400246846912, 
             1.9538484075322344`}, {-5.610152037412725, 
             2.010269083574232}, {-5.615081803898248, 
             2.012043424276002}, {-5.656854249492381, 
             2.027077679084875}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{2.0336026266817973`, 4.229101147007146}, {
             2.0928105142287556`, 4.35051181573323}, {2.1486493713471835`, 
             4.465057724258532}, {2.2020467507009274`, 4.574616275950538}, {
             2.3015170761143633`, 4.778771308834662}, {2.3928894808541714`, 
             4.966371433598766}, {2.4473185963216193`, 
             5.078148263581862}}]}, 
           {Arrowheads[{{0.013136676665838704`, 1.}}], 
            ArrowBox[{{2.4576558958963703`, 5.099377169602616}, {
             2.4778319553054615`, 5.140811169456014}, {2.557087012140618, 
             5.303605559972019}, {2.631741366431877, 5.456972867033421}, {
             2.6338982813630247`, 5.461404271405641}, {2.697512874390047, 
             5.591574343290668}, {2.729817509463929, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0356286838118165`, -4.228298431654273}, {
             2.0948963482383327`, -4.349689347240445}, {
             2.150791527165692, -4.464216463172319}, {
             2.2042427351440725`, -4.573756954779615}, {
             2.303813238253897, -4.77787806502048}, {
             2.3952775664632773`, -4.96544674321082}, {
             2.4497368347623794`, -5.077154337589156}}]}, 
           {Arrowheads[{{0.013163237828227748`, 1.}}], 
            ArrowBox[{{2.4600839419408023`, -5.09837846504765}, {
             2.4803054286676844`, -5.139857054598416}, {
             2.559640095314659, -5.302623821434569}, {
             2.634369392811587, -5.4559649850556955`}, {
             2.6365281961435953`, -5.460395065529346}, {
             2.7002659196796572`, -5.590664926032072}, {
             2.733058790810616, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-4.470835823798606, -1.5934535620204076`}, \
{-4.699902748212185, -1.6756176037175767`}, {-4.908449205616563, \
-1.7504059155781007`}, {-5.099994390542509, -1.8190856314450408`}, \
{-5.278057497520797, -1.882923885161458}, {-5.359883873448317, \
-1.912256797639284}}]}, 
           {Arrowheads[{{0.006180352675305364, 1.}}], 
            ArrowBox[{{-5.382110865312236, -1.920224673517927}, \
{-5.4441993131319215`, -1.9424819834028482`}, {-5.6007035072689675`, \
-1.9985810505437729`}, {-5.605656092687371, -2.000356246904976}, \
{-5.656854249492381, -2.0187074176389457`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.255374891759003, -1.9728685226482252`}, {
             4.37755710402059, -2.0291320336660457`}, {
             4.49288884779756, -2.0822508292478807`}, {
             4.603226003170783, -2.1330739784190387`}, {
             4.808916548705989, -2.2278333375293236`}, {
             4.998010540448698, -2.31496156045461}, {
             5.113207254217845, -2.3680464222270663`}}]}, 
           {Arrowheads[{{0.01218023194144048, 1.}}], 
            ArrowBox[{{5.1346518495203055`, -2.377928504277416}, {
             5.173889778221403, -2.3960100966526072`}, {
             5.338069126697654, -2.471674822279155}, {
             5.492767914694576, -2.5429754257444763`}, {
             5.49721529467231, -2.545025290874427}, {
             5.625537985398065, -2.6044123210785393`}, {
             5.656854249492381, -2.619087885321152}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.6471090895445124`, 4.483080736078743}, {
             1.7330921705429072`, 4.713099052824202}, {1.811397941773646, 
             4.922693757615243}, {1.883336928486918, 5.115334082536185}, {
             1.9502196559329112`, 5.294489259671344}, {1.977599671637344, 
             5.367850699896695}}]}, 
           {Arrowheads[{{0.006032055882865438, 1.}}], 
            ArrowBox[{{1.9858558796985366`, 5.389972210735389}, {
             2.0126295282730573`, 5.461708963581598}, {2.071420587323897, 
             5.619262947971593}, {2.073197107898847, 5.624024273538128}, {
             2.0854445302962454`, 5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{1.6493561284128548`, -4.482447488820544}, {
             1.735451893364683, -4.712427544351985}, {
             1.8138606749845576`, -4.921988249657447}, {
             1.8858945398135105`, -5.114597851114448}, {
             1.9528655543925735`, -5.293724595100503}, {
             1.9802753104138842`, -5.3670572382170905`}}]}, 
           {Arrowheads[{{0.006051174332398276, 1.}}], 
            ArrowBox[{{1.988542235892679, -5.389174746134218}, {
             2.0153579207339694`, -5.460917998604775}, {
             2.0742267399288177`, -5.618447298987725}, {
             2.0760053003358836`, -5.623207048779418}, {
             2.0885761691318296`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.709997397978703, 1.6458241036589298`}, {
             4.919934006404439, 1.7187500505807227`}, {5.1129775111716205`, 
             1.78581938051585}, {5.292560149023643, 1.848219215635181}, {
             5.460221447530697, 1.9064827639641746`}, {5.6021579563044455`, 
             1.9558103568342533`}}]}, 
           {Arrowheads[{{0.0007263249435395724, 1.}}], 
            ArrowBox[{{5.624461150606529, 1.963562371259071}, {
             5.656854249492381, 1.9748395308917541`}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-0.14953728392014162`, -4.430867624439358}, \
{-0.15567774227504022`, -4.658541943525229}, {-0.16132428989250863`, \
-4.865942462286052}, {-0.16655323360695232`, -5.056523541896787}, \
{-0.17144088025277665`, -5.233739543532398}, {-0.17535488476209005`, \
-5.3749943804809}}]}, 
           {Arrowheads[{{0.00547088578611689, 1.}}], 
            ArrowBox[{{-0.1760088941497492, -5.398597314303987}, \
{-0.176023661624593, -5.399130266487929}, {-0.18035546139332695`, \
-5.554949862652367}, {-0.1805200997204264, -5.5608628653563}, \
{-0.18320000660153238`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.011809808991249632`, 1.}}], 
            ArrowBox[{{-0.6853445761162862, -5.103744690402126}, \
{-0.7084013124227773, -5.282398852053846}, {-0.7299401154410599, \
-5.449134417589312}, {-0.7502463718920451, -5.606223582280831}, \
{-0.7509796284924645, -5.611894255863376}, {-0.7568013984097357, \
-5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.011578830579290083`, 1.}}], 
            ArrowBox[{{-5.116158300535009, 
             0.766902156789152}, {-5.294660261363588, 
             0.7937996084344829}, {-5.461207385607317, 
             0.8188926784621605}, {-5.6180914717601205`, 
             0.8425278528541759}, {-5.623784579972162, 
             0.8433855064158897}, {-5.656854249492381, 
             0.8483670360325786}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.01159723355504751, 1.}}], 
            ArrowBox[{{-5.115241720389326, -0.7631065187421199}, \
{-5.293713691738182, -0.7898711693514074}, {-5.460232568576379, \
-0.8148403037616393}, {-5.617089882457524, -0.8383587162471362}, \
{-5.622786408477571, -0.8392127908981551}, {-5.656854249492381, \
-0.844320205193429}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.2945452669321846`, -3.9097538873370925`}, \
{-2.382019971127102, -4.060765424083826}, {-2.4643151150029174`, \
-4.2027983568749345`}, {-2.5414306985596316`, -4.335852685710418}, \
{-2.613366721797244, -4.459928410590276}, {-2.681237672141507, \
-4.576963872845181}, {-2.7461580370181733`, -4.688897413805803}, \
{-2.7681936349547227`, -4.726882473288006}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-2.780041914289811, -4.747306588694404}, \
{-2.867147010368715, -4.8974587318442016`}, {-2.9783428054199805`, \
-5.089094879711346}, {-3.0817545857430813`, -5.267288372413112}, \
{-3.178278157757481, -5.433589341442078}, {-3.2540944865715757`, \
-5.564200763400494}}]}, 
           {Arrowheads[{{0.0017686425282637235`, 1.}}], 
            ArrowBox[{{-3.2659482687637573`, -5.584621685541193}, \
{-3.2692251182389445`, -5.590266827902904}, {-3.271436445887399, \
-5.594076181748941}, {-3.3078820218805545`, -5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.0577322744542, -2.389972569570051}, {
             4.199480956026086, -2.4728576788787}, {
             4.332393087324419, -2.550589370936675}, {
             4.456468668349198, -2.623167645743976}, {
             4.573591868015509, -2.6916890493113867`}, {
             4.685646855238434, -2.75725012764969}, {
             4.872972470962563, -2.866863911633488}}]}, 
           {Arrowheads[{{0.018733455778204258`, 1.}}], 
            ArrowBox[{{4.8933518706744445`, -2.878788939126938}, {
             4.894552192354133, -2.8794913086389764`}, {
             5.086615981043609, -2.9918924406543455`}, {
             5.26526952265418, -3.0964547756383083`}, {
             5.43204948278908, -3.1940754722553617`}, {
             5.589207448808526, -3.286069293410449}, {
             5.592917079742178, -3.2882408156686433`}, {
             5.656854249492381, -3.325669670954563}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.011996842828305217`, 1.}}], 
            ArrowBox[{{5.096318490474589, 0.7517584680134812}, {
             5.275456118943955, 0.778042277660799}, {5.442707782848094, 
             0.8025851272876906}, {5.600321088339623, 0.8257156137061904}, {
             5.605864242175281, 0.8265291303748137}, {5.656854249492381, 
             0.8340129762760589}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012780440142328394`, 1.}}], 
            ArrowBox[{{0.8234766118249293, 5.061643164582762}, {
             0.8532978228397583, 5.239097234040015}, {0.8811102091343131, 
             5.404719086211872}, {0.9073003141666202, 5.5607613471121216`}, {
             0.908251811637624, 5.566431822990793}, {0.9234181289469778, 
             5.656854249492381}}]}}, 
          {RGBColor[0, 0, 1], 
           {Arrowheads[{{0.012785351613285575`, 1.}}], 
            ArrowBox[{{0.8260367379875438, -5.061464384170154}, {
             0.8559480964491089, -5.2389131353971345`}, {
             0.8838446329641441, -5.40453006957362}, {
             0.9101140306717023, -5.560567726689497}, {
             0.9110683242102381, -5.566237527552211}, {
             0.9263137306894876, -5.656854249492381}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sca\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(sca\\)]\\)}\"", 
           TraditionalForm]}}], {583.2, -576.}, 
      ImageScaled[{0.5, 0.5}], {360.00000000000006`, 360.}], InsetBox[
      GraphicsBox[{
        {RGBColor[1, 0.5, 0], DiskBox[{0, 0}]}, 
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.509618658038815}, \
{-5.650950386179752, -2.5094539641924456`}, {-5.451559709214463, \
-2.5040691351555204`}, {-5.249788874322055, -2.4988093438511108`}, \
{-5.046424422790572, -2.493704727753227}, {-4.8422528959080555`, \
-2.4887854243358816`}, {-4.712675931860511, -2.485792838081411}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689070233441884, -2.4852476633342326`}, \
{-4.637274293674505, -2.484051433599074}, {-4.43148861608992, \
-2.479502755542804}, {-4.224895863154301, -2.4751393901670724`}, \
{-4.017496034867649, -2.4709613374718784`}, {-3.8092891312299626`, \
-2.466968597457222}, {-3.7447917238361503`, -2.465793703830111}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721183647419646, -2.4653636558692567`}, \
{-3.6002751522412426`, -2.463161170123104}, {-3.463861482047055, \
-2.460786651920513}, {-3.327167312805484, -2.4584972740584092`}, \
{-3.1212336361436566`, -2.4552206749234586`}, {-2.914758123363276, \
-2.452145434184163}, {-2.7768260767582356`, -2.450230616534971}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.753216358671033, -2.4499028587295983`}, \
{-2.7077407744643414`, -2.4492715518405213`}, {-2.500181589446853, \
-2.4465990278925345`}, {-2.4730598433122144`, -2.446263403171289}, \
{-2.4459306482055423`, -2.4459313358002763`}, {-2.336833924873502, \
-2.444668637588712}, {-2.2276018237721136`, -2.443461480337032}, \
{-2.0643346749686455`, -2.4417238814233584`}, {-1.9008804043157297`, \
-2.44011764681754}, {-1.8087971893552544`, -2.4392877174420353`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785186155310719, -2.4390749154590896`}, \
{-1.7372390118133656`, -2.438642776519577}, {-1.5734104974615537`, \
-2.4372992705294694`}, {-1.4093948612602938`, -2.436087128847217}, \
{-1.2451921032095858`, -2.43500635147282}, {-1.0808022233094299`, \
-2.4340569384062785`}, {-0.9162252215598261, -2.4332388896475923`}, \
{-0.8407273544070037, -2.4329250233340107`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.817115565449858, -2.4328268623469986`}, \
{-0.7515396925611215, -2.432554244612754}, {-0.5868242309136629, \
-2.432005042717756}, {-0.42207883661745005`, -2.431591283962599}, \
{-0.2573035096724835, -2.4313129683472825`}, {-0.09249825007876311, \
-2.431170095871806}, {0.07233694216371156, -2.4311626665361703`}, {
             0.12736183890379477`, -2.4312053920450514`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15097382478375632`, -2.4312237261841805`}, {
             0.2372020670549403, -2.4312906803403753`}, {
             0.40209712459492253`, -2.4315541372844205`}, {
             0.5680853160333115, -2.431968852522881}, {
             0.7323769879344981, -2.432493329866481}, {
             0.8966585974531037, -2.433152655422476}, {
             1.0609101470734603`, -2.4339465317271443`}, {
             1.0954481597140775`, -2.434141753774567}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1190597755262928`, -2.4342752156511893`}, {
             1.2251116392799013`, -2.4348746613167638`}, {
             1.3892430765567587`, -2.4359367467276116`}, {
             1.5532844613883663`, -2.4371324904959653`}, {
             1.7172157962590546`, -2.4384615951581026`}, {
             1.933899863217916, -2.44041926396066}, {
             2.0635092079489814`, -2.441724086977687}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0871200044813207`, -2.4419617851994446`}, {
             2.150273658732457, -2.4425975753258995`}, {
             2.3662868296418726`, -2.4449945488336264`}, {
             2.58188902278536, -2.4476082040636475`}, {
             2.7970298850021167`, -2.4504365605957688`}, {
             3.0116590631313387`, -2.453477638009795}, {
             3.0315249579720622`, -2.4537794137596594`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.055134227140607, -2.454138053778858}, {
             3.225726204012223, -2.456729455885533}, {
             3.4391809544839678`, -2.4601900338027884`}, {
             3.651972961385768, -2.4638573913413673`}, {
             3.864051871556822, -2.467729548081075}, {
             3.999474092188693, -2.4703410097947427`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.023081696152007, -2.4707962552752405`}, {
             4.075367331836327, -2.471804523601718}, {
             4.285868989063478, -2.476080337483102}, {
             4.495506490077474, -2.4805550093050326`}, {
             4.704229481717511, -2.4852265586473163`}, {
             4.911987610822786, -2.4900930050897583`}, {
             4.967334694385892, -2.4914474456792504`}}]}, 
           {Arrowheads[{{0.014105943173714912`, 1.}}], 
            ArrowBox[{{4.990939620335265, -2.4920250997805966`}, {
             5.118730524232496, -2.4951523682121652`}, {
             5.12772280239059, -2.4953775463974734`}, {
             5.13671326212576, -2.4956030515993004`}, {
             5.145701904905681, -2.4958288837687133`}, {
             5.154688732119001, -2.4960550428599313`}, {
             5.1636737449435115`, -2.496281528833944}, {
             5.181640145387477, -2.4967351544709215`}, {
             5.19959930045363, -2.4971900873375206`}, {
             5.217551220097529, -2.4976463271288196`}, {
             5.39667535730195, -2.502280522105985}, {
             5.574973469611246, -2.507041981176256}, {
             5.656854249492381, -2.5092955403457307`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.5103366035457677`}, {-5.648459766701725, 
             2.5101024177172357`}, {-5.449087764826464, 
             2.5047187667274358`}, {-5.247393375330116, 
             2.499461636303281}, {-5.044134884710521, 
             2.4943603669693695`}, {-4.840070579465519, 
             2.4894442992503003`}, {-4.712676144447289, 
             2.4865025036635346`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689070444381837, 
             2.4859574002273828`}, {-4.635200459595108, 
             2.484713433146073}, {-4.42952452509929, 
             2.480167768656688}, {-4.2230427759780635`, 
             2.4758073057821446`}, {-4.015755212231429, 
             2.4716320445224436`}, {-3.807661833859388, 
             2.467641984877585}, {-3.744792071119371, 2.466496884610924}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.721183993718512, 
             2.4660668906909713`}, {-3.598762640861938, 
             2.463837126847568}, {-3.462394051455578, 
             2.4614636819889544`}, {-3.3257448968849186`, 
             2.459175317452859}, {-3.119819165119707, 
             2.4558992516384412`}, {-2.9133521259322412`, 
             2.452824621563813}, {-2.7768264901249675`, 2.450929699500109}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753216771146565, 
             2.450602005897765}, {-2.7063437793225207`, 
             2.449951427228975}, {-2.4987941252905452`, 
             2.447279668633927}, {-2.4716742916008054`, 
             2.446944156683084}, {-2.444546998600464, 
             2.446612201231679}, {-2.335493945630991, 
             2.4453503357202337`}, {-2.226305429791719, 
             2.4441439618066116`}, {-2.0631293493666445`, 
             2.4424077666043305`}, {-1.8997665022795176`, 
             2.4408028330853484`}, {-1.8087976451914123`, 
             2.4399831537260286`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7851866106638912`, 
             2.4397704053385705`}, {-1.7362168885303388`, 
             2.4393291612496664`}, {-1.5724805081191078`, 
             2.437986751097283}, {-1.4085573610458246`, 
             2.4367756026281997`}, {-1.2444474473104892`, 
             2.4356957158424155`}, {-1.0801507669131019`, 
             2.434747090739931}, {-0.9156673198536622, 
             2.433929727320746}, {-0.8407278253086613, 
             2.4336182681629177`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8171160362390931, 
             2.4335201342218884`}, {-0.7510755759907635, 
             2.4332456607115396`}, {-0.5864540051829974, 
             2.432696926038991}, {-0.421802607430365, 
             2.4322835233030995`}, {-0.25712138273286556`, 
             2.432005452503866}, {-0.09241033109049929, 
             2.4318627136412907`}, {0.07233054749673334, 
             2.4318553067153728`}, {0.12736136641060095`, 
             2.4318980316529024`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15097335229228478`, 2.431916363573845}, {
             0.23710125302883264`, 2.4319832317261123`}, {
             0.40190178550579914`, 2.43224648867351}, {0.5677932367493892, 
             2.432660896945141}, {0.7319914880924849, 2.4331849492450774`}, {
             0.8961796507006322, 2.433843738394992}, {1.0603377667339238`, 
             2.434636966851544}, {1.0954476833877553`, 
             2.4348353719809737`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.119059299388248, 2.4349688005440435`}, {
             1.2244458783524506`, 2.4355643370713937`}, {1.3884840277163066`, 
             2.4366255515112014`}, {1.5524322569855837`, 
             2.4378203126276268`}, {1.7162706083203738`, 2.43914832287733}, {
             1.9341616313305514`, 2.441117042049121}, {2.0635087119017923`, 
             2.442420046768179}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.087119506923223, 2.442657895022641}, {
             2.1517390112538735`, 2.443308853039739}, {2.3689516100485917`, 
             2.4457217390598625`}, {2.5857482896729547`, 
             2.4483536833201702`}, {2.8020779120852133`, 
             2.4512026690313413`}, {3.0178893392436166`, 2.454266679404054}, {
             3.0315244821975766`, 2.454474271754744}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.055133739105034, 2.4548337180147506`}, {
             3.233131433106415, 2.4575436976489864`}, {3.4477530556318587`, 
             2.4610317069768177`}, {3.661703068778197, 2.4647286905982266`}, {
             3.8749303345036785`, 2.4686326317238914`}, {3.999473525028572, 
             2.4710413166470726`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.023081103330045, 2.471497890930162}, {
             4.087383714766554, 2.472741513564491}, {4.299012071525074, 
             2.4770533193307034`}, {4.509764266737488, 2.481566032233208}, {
             4.719589162362045, 2.4862776354826828`}, {4.928435620356995, 
             2.4911861122898067`}, {4.967334276059514, 
             2.4921413417854428`}}]}, 
           {Arrowheads[{{0.014105955826735374`, 1.}}], 
            ArrowBox[{{4.990939152785404, 2.4927210038349967`}, {
             5.1362525026805885`, 2.496289445865258}, {5.145253379332883, 
             2.4965156335039347`}, {5.15425243485867, 2.496742148989984}, {
             5.16324967044186, 2.4969689922840335`}, {5.172245087292702, 
             2.497196163347467}, {5.181238686652568, 2.497423662142338}, {
             5.199222254128518, 2.4978793151210334`}, {5.217198564071106, 
             2.498336278719367}, {5.235167626470322, 2.4987945526229525`}, {
             5.414462505096029, 2.5034492766747563`}, {5.592756403716549, 
             2.5082267495146637`}, {5.656854249492381, 
             2.5099966435166885`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.304273632984294}, \
{-5.494438968809937, -4.296412786866923}, {-5.316180648981428, \
-4.288050613157377}, {-5.131149546874441, -4.279636426561433}, \
{-4.9451879176231, -4.27146330756364}, {-4.758433115004895, \
-4.263552237381084}, {-4.713336238897657, -4.261716691575069}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689743780340378, -4.260756424654242}, \
{-4.5710224927973115`, -4.255924197230855}, {-4.382956051000352, \
-4.248579187112951}, {-4.194233789614016, -4.241517207027375}, \
{-4.004855708638302, -4.234738256974124}, {-3.8148218080732104`, \
-4.228242336953199}, {-3.7459066717118636`, -4.225997002698078}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7223072011787015`, -4.225228104856637}, \
{-3.624132087918743, -4.2220294469646005`}, {-3.4327865481748976`, \
-4.216099587008329}, {-3.240897550452847, -4.210470639388915}, \
{-3.0485774563637626`, -4.205160486410893}, {-2.8558262659076443`, \
-4.200169128074261}, {-2.7782145907986973`, -4.198291908887117}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7546095015975345`, -4.197720964808143}, \
{-2.662643979084492, -4.19549656437902}, {-2.4690305958943055`, \
-4.191142795325171}, {-2.274986116337085, -4.187107820912712}, \
{-2.0805105404128303`, -4.183391641141644}, {-1.885603868121542, \
-4.179994256011967}, {-1.81032258489484, -4.178773101512832}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7867135426710326`, -4.178399922451994}, \
{-1.7140851274107547`, -4.177275803800049}, {-1.5440838153255747`, \
-4.1748354908254575`}, {-1.3739035815484855`, -4.172648458420589}, \
{-1.2035444260794872`, -4.170714706585442}, {-1.0330063489185797`, \
-4.169034235320018}, {-1.011449243693456, -4.16883792411292}, \
{-0.9898897181714179, -4.168645675033699}, {-0.9269428912541505, \
-4.168130939399584}, {-0.8639744505845147, -4.1676505587588295`}, \
{-0.8422995312339951, -4.167503171781825}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186880841080428, -4.167342616637037}, \
{-0.6766171650338204, -4.166376550607264}, {-0.48923990236399395`, \
-4.165413037928153}, {-0.3018426625750348, -4.164760020721496}, \
{-0.11442544566694324`, -4.164417498987293}, {
             0.07301174836028079, -4.164385472725544}, {
             0.12578436232767704`, -4.164463866889227}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14939632927298, -4.164498942665514}, {
             0.26046891950663714`, -4.164663941936249}, {
             0.447946067772126, -4.165252906619409}, {
             0.6354431931567472, -4.166152366775022}, {
             0.8228381215208673, -4.16735869315762}, {
             1.0100086787248528`, -4.168868256521731}, {
             1.0938589318770549`, -4.1696813448821395`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1174698148346998`, -4.169910297489795}, {
             1.196954864768703, -4.170681056867355}, {
             1.3836766796524187`, -4.172797094194493}, {
             1.5701741233759994`, -4.175216368503144}, {
             1.7564471959394452`, -4.1779388797933095`}, {
             1.9424958973427566`, -4.180964628064988}, {
             2.061854468324176, -4.183102899851676}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.085462673263272, -4.183525833522384}, {
             2.1283202275859328`, -4.18429361331818}, {
             2.3152256781797034`, -4.18803538746751}, {
             2.4997868685771087`, -4.191902505520686}, {
             2.684074578415856, -4.196068739480219}, {
             2.8680642529966844`, -4.200532028808526}, {
             3.0297021058832634`, -4.2047195991428765`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.053306109654114, -4.205333704415562}, {
             3.23505127758754, -4.210341531421152}, {
             3.4179995181990437`, -4.215683623630313}, {
             3.600551504755584, -4.221314529057933}, {
             3.745247848011824, -4.225985987335669}, {
             3.8895789054717067`, -4.230820596335845}, {
             3.997330937969373, -4.234557309549483}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.020928745627622, -4.235375653646067}, {
             4.033503239042318, -4.235811722225084}, {
             4.176979410630743, -4.240952731170006}, {
             4.320024761392236, -4.246246607505307}, {
             4.462690220623863, -4.251701831661725}, {
             4.604984732445423, -4.257320013949944}, {
             4.746917240976719, -4.263102764680651}, {
             4.8884674822153205`, -4.269046394678168}, {
             4.964682186927808, -4.272339373100699}}]}, 
           {Arrowheads[{{0.014172838044234552`, 1.}}], 
            ArrowBox[{{4.98827217117777, -4.273358616164305}, {
             5.0295985018032345`, -4.2751441864888955`}, {
             5.170294208326922, -4.281393208006637}, {
             5.31053851037284, -4.287790527125197}, {
             5.448149380078791, -4.2942223204513015`}, {
             5.579707111611912, -4.300511398141919}, {
             5.656854249492381, -4.30428562555572}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -5.208706421699353}, \
{-5.495298410129127, -5.1990257460592595`}, {-5.3224115951105535`, \
-5.188987604248594}, {-5.148815248155279, -5.1792316509509275`}, \
{-4.9744695311869185`, -5.169759286773467}, {-4.799360047284173, \
-5.1605729676689025`}, {-4.713836702436469, -5.1562463088268835`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.690254867674088, -5.155053294754908}, \
{-4.623516921547147, -5.151676996444517}, {-4.4469702790759476`, \
-5.143075675907592}, {-4.269750244970678, -5.13477330886541}, \
{-4.091886944331443, -5.126774198125252}, {-3.913410502258347, \
-5.119082646494402}, {-3.746751190085609, -5.112214011780716}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7231583756330573`, -5.111262788318292}, \
{-3.554738694210995, -5.104639431789749}, {-3.374603578436947, \
-5.097896374330512}, {-3.1939758216294587`, -5.091478087209709}, \
{-3.012885548888634, -5.085388873234624}, {-2.8313628853145776`, \
-5.079633035212539}, {-2.779265679367151, -5.078081455888072}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755664151218022, -5.0773785459635175`}, \
{-2.649437956007395, -5.0742148759507355`}, {-2.46714088606719, \
-5.069138698256496}, {-2.284501800594068, -5.064408804937101}, \
{-2.1248515899071605`, -5.060569282009102}, {-1.9649737850037876`, \
-5.057003167073164}, {-1.8114817754826678`, -5.053848377567284}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7878742225866098`, -5.053390815076772}, \
{-1.644393679847676, -5.050674985149195}, {-1.483787035667417, \
-5.047923836980249}, {-1.3230165679856796`, -5.045453376016083}, \
{-1.1620822768024635`, -5.043263602256701}, {-1.0009841621177689`, \
-5.041354515702101}, {-0.8434969649322261, -5.039765932620326}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8198858489926485, -5.039562992946404}, \
{-0.6784694119252033, -5.038387109651381}, {-0.5170960138376473, \
-5.0373309665162935`}, {-0.3556452670892422, -5.036559863308056}, \
{-0.3153304847892946, -5.036411850231281}, {-0.27501258629375824`, \
-5.03628163980075}, {-0.12737468302136254`, -5.035956670522608}, {
             0.020260526422096248`, -5.035870175538975}, {
             0.12458276455661207`, -5.035977569372879}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14819474504314423`, -5.036001876569081}, {
             0.16789304203661803`, -5.036022154849851}, {
             0.31552286382220285`, -5.036412608455236}, {
             0.3334964429179675, -5.036474662656263}, {
             0.35146939504239816`, -5.036540254750798}, {
             0.394202849768592, -5.036724654917348}, {
             0.4369324545057098, -5.036929074189196}, {
             0.6080520958107866, -5.037907465211809}, {
             0.7790657364739778, -5.039204851692262}, {
             0.9499733764952836, -5.040821233630553}, {
             1.0926483038859978`, -5.042437903297601}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.116258781201974, -5.042705436936477}, {
             1.1207750158747036`, -5.042756611026685}, {
             1.2914293847688025`, -5.045009793603692}, {
             1.4618952133341447`, -5.04757959108461}, {
             1.6321725015707307`, -5.050466003469441}, {
             1.8022612494785595`, -5.053669030758182}, {
             1.972236830439846, -5.057198599009905}, {
             2.060590491529454, -5.059180073253356}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0841965489000587`, -5.059709477401327}, {
             2.1416721286220426`, -5.060998460556546}, {
             2.310858587769711, -5.065106996159842}, {
             2.479766058529966, -5.0695202353961655`}, {
             2.6749483334153834`, -5.075006416113151}, {
             2.869694844425833, -5.080892286076615}, {
             3.0283054308829596`, -5.0860195328662625`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0519050966212102`, -5.086782415805517}, {
             3.0639638840033214`, -5.087172228240317}, {
             3.257713744589859, -5.093840625558017}, {
             3.4509027186274515`, -5.1008918609834755`}, {
             3.643489098558108, -5.108320317470452}, {
             3.835431176823837, -5.116120377972707}, {
             3.9956875133489413`, -5.122962831956985}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.0192780130668675`, -5.1239700739312255`}, {
             4.026687245866646, -5.124286425444}, {
             4.217246533915951, -5.132809490992416}, {
             4.407107787904988, -5.141679574388908}, {
             4.596243578331491, -5.15088951158154}, {
             4.784626475693195, -5.1604321385183765`}, {
             4.9626416380175025`, -5.169795980107618}}]}, 
           {Arrowheads[{{0.0142243360418258, 1.}}], 
            ArrowBox[{{4.986219588895527, -5.17106323959031}, {
             5.159023873213149, -5.180486805416914}, {
             5.344983514366867, -5.190984517274742}, {
             5.5300805444467285`, -5.20178626266903}, {
             5.656854249492381, -5.209383624856843}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.477418763193844, -5.656854249492381}, \
{-5.428143575086973, -5.6536898811129035`}, {-5.246826610948429, \
-5.642225411635835}, {-5.062173623870148, -5.630926339822216}, \
{-4.828587318768502, -5.617180984242045}, {-4.593677671188081, \
-5.603994797235783}, {-4.534606070055975, -5.600839747850665}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            
            ArrowBox[{{-4.511027684040484, -5.599580412216035}, \
{-4.357514838160103, -5.591381199722716}, {-4.120168976715789, \
-5.5793536126221275`}, {-3.8817102438863564`, -5.5679254568533025`}, \
{-3.642208796703026, -5.557110153335528}, {-3.5676559801846444`, \
-5.553951304995336}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.5440651536264234`, -5.552951747275088}, \
{-3.401734792197016, -5.546921122988087}, {-3.160358387399545, \
-5.537371786730264}, {-2.973030806318242, -5.530441273621718}, \
{-2.785272932499105, -5.523927172539818}, {-2.600240164711564, \
-5.517932559418329}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.5766391206290176`, -5.5172138034651415`}, \
{-2.4083063841099994`, -5.512137367600588}, {-2.219205657252729, \
-5.506868979970632}, {-2.029746602799423, -5.502021881852236}, \
{-1.8399292207500821`, -5.4975960732454014`}, {-1.6497535111047061`, \
-5.493591554150128}, {-1.6324680907774085`, -5.4932669699002}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.6088602595948256`, -5.49282366392142}, \
{-1.459282359412593, -5.490014901992746}, {-1.2685786512230401`, \
-5.486872694199587}, {-1.077642386536048, -5.48416493077065}, \
{-0.8864735653516166, -5.481891611705937}, {-0.830381561254948, \
-5.4813079066170864`}, {-0.7742790532101987, -5.480762508130044}, \
{-0.6644752173638845, -5.479822903998173}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.6408640888034421, -5.479620860838363}, \
{-0.639026039740755, -5.479605132439801}, {-0.5037222043980841, \
-5.478669704223025}, {-0.3683746234998623, -5.477956031910341}, \
{-0.23299037336376546`, -5.4774639239323735`}, {-0.2166065914953231, \
-5.477417783314651}, {-0.20022237623896555`, -5.477374886401207}, \
{-0.1622659581458828, -5.477300440349056}, {-0.12430763947431873`, \
-5.477243405735533}, {0.0009859783411950707, -5.47714998429281}, {
             0.12626645575192202`, -5.477246261816241}, {
             0.2515337927578623, -5.477532238305825}, {
             0.3036085436218193, -5.4777300015865915`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.3272203663510705, -5.477819671752082}, {
             0.3767879893590158, -5.478007913761563}, {
             0.5020139660149296, -5.478673429407457}, {
             0.6271966431851508, -5.479528926467506}, {
             0.7523360208696794, -5.480574404941711}, {
             0.8774320990685156, -5.481809864830072}, {
             1.0024607711812608`, -5.483233244850949}, {
             1.1273979306075161`, -5.4848424837227014`}, {
             1.252243577347282, -5.486637581445331}, {
             1.2716507528662302`, -5.486945745757554}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.2952597696749015`, -5.487320630625266}, {
             1.3769977114005583`, -5.488618538018837}, {
             1.536875928760565, -5.491427524487894}, {
             1.696474046534301, -5.494532313084762}, {
             1.8557920647217665`, -5.497932903809442}, {
             2.0148299833229615`, -5.501629296661934}, {
             2.1735878023378863`, -5.505621491642237}, {
             2.2395207583172883`, -5.507405466863412}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.2631241128456328`, -5.508044112575404}, {
             2.3320655217665403`, -5.509909488750352}, {
             2.4902631416089234`, -5.514493287986278}, {
             2.6481806618650365`, -5.5193728893500165`}, {
             2.772381861447144, -5.523420028384986}, {
             2.8963708008426687`, -5.527639460178768}, {
             3.0201474800516106`, -5.5320311847313635`}, {
             3.1437118990739696`, -5.536595202042773}, {
             3.207090290857081, -5.539028720175492}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.2306848974614715`, -5.539934674103806}, {
             3.267064057909746, -5.541331512112996}, {
             3.3902039565589397`, -5.546240114942033}, {
             3.5131315950215507`, -5.551321010529883}, {
             3.635846973297579, -5.556574198876547}, {
             3.8793511665280067`, -5.567513358688704}, {
             4.119426753488342, -5.578973499220892}, {
             4.174233509661526, -5.581748292244815}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.19781529885068, -5.582942206803942}, {
             4.356073734178586, -5.590954620473112}, {
             4.589292108598737, -5.603456722445363}, {
             4.7793822220456645`, -5.614137762066101}, {
             4.970493129080115, -5.625278193345502}, {
             5.140823038791584, -5.635561747737168}}]}, 
           {Arrowheads[{{0.006704908418980852, 1.}}], 
            ArrowBox[{{5.164391892894224, -5.636988340482729}, {
             5.355777323911586, -5.648937230880293}, {
             5.480400529001575, -5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.9626094564588596, 0.0005252366926755919}, {
             0.9671553429467746, 0.0005252417086207639}, {0.9714914653611848, 
             0.0005252464716955861}, {0.9991086656254479, 
             0.0005252758337020564}, {1.0452490394996974`, 
             0.0005253254568599443}, {1.0948451775476242`, 
             0.0005253808337095827}, {1.194003977329075, 
             0.0005254992202841897}, {1.2931154549207375`, 
             0.0005256277670245545}, {1.39217575402739, 
             0.0005257664478344846}, {1.590118019187854, 
             0.0005260740132858679}, {1.7878098224940495`, 
             0.0005264217454372492}, {1.907089176376536, 
             0.0005266559401243426}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.93070116937446, 0.000526702300228852}, {
             1.9852212817208201`, 0.0005268093457504419}, {
             2.1823225146430083`, 0.0005272365156872597}, {2.289918277693839, 
             0.0005274866594496033}, {2.397407945084965, 
             0.0005277484605058513}, {2.6289750439521806`, 
             0.0005283523299160882}, {2.859935221113327, 
             0.000529008797299738}, {2.8751808892902706`, 
             0.0005290557259838072}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.898792882288128, 0.0005291284075971532}, {
             3.090288476568405, 0.0005297178626568009}, {3.3200348103174138`, 
             0.0005304795259872768}, {3.3502243042332718`, 
             0.0005305832040108312}, {3.380401719564123, 
             0.0005306877651669452}, {3.5186603619500008`, 
             0.000531190420991285}, {3.6566479483796135`, 
             0.0005317113382460309}, {3.843272602201078, 
             0.0005324355065943133}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.86688459519887, 0.0005325271293119914}, {
             3.87849832503934, 0.0005325721946095487}, {4.099498499142147, 
             0.0005334765383646077}, {4.319648470688033, 
             0.0005344243695112082}, {4.538948239677, 
             0.0005354156880493502}, {4.757397806109045, 
             0.0005364504939790335}, {4.811364315108318, 
             0.0005367179199732433}}]}, 
           {Arrowheads[{{0.017403824011583705`, 1.}}], 
            ArrowBox[{{4.834976308105998, 0.0005368349269988926}, {
             4.974997169984171, 0.0005375287873002584}, {5.191746331302376, 
             0.0005386505680130246}, {5.407645290063662, 
             0.0005398158361173324}, {5.566287336744341, 
             0.0005407867282721841}, {5.656854249492381, 
             0.0005413409993933403}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.00037788544585843405`}, {-5.613018147787441, 
             0.00037770428184359564`}, {-5.490022489216744, 
             0.00037720675209254183`}, {-5.366704953085265, 
             0.00037671867368179026`}, {-5.243065539393005, 
             0.0003762400466113409}, {-5.11911466011089, 
             0.00037577111733174025`}, {-4.994862727209849, 
             0.00037531213229353495`}, {-4.870309740689881, 
             0.00037486309149672493`}, {-4.745455700550987, 
             0.0003744239949413102}, {-4.712374529580382, 
             0.0003743111291898817}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.68876253658255, 
             0.00037423057021164025`}, {-4.575322055740379, 
             0.00037384353599438}, {-4.404667946626321, 
             0.0003732821766877326}, {-4.1785966596361925`, 
             0.00037257118407852964`}, {-3.95171994650173, 
             0.0003718952178700616}, {-3.7442828166682993`, 
             0.0003713112690608432}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-3.720670823670422, 
             0.0003712453493467906}, {-3.495550241799801, 
             0.00037064836465533035`}, {-3.465413632714931, 
             0.00037057089353192025`}, {-3.435264460578042, 
             0.0003704940522069211}, {-3.294745301526161, 
             0.0003701533502683364}, {-3.153972071400098, 
             0.0003698264768031073}, {-2.9345119126562285`, 
             0.00036933499045416934`}, {-2.776191103754314, 
             0.0003690064588886543}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.752579110756395, 
             0.0003689574616337872}, {-2.7146077276375427`, 
             0.0003688786672034951}, {-2.4942595163440417`, 
             0.0003684575070510846}, {-2.2734672787757253`, 
             0.00036807150999693784`}, {-2.0522310149325937`, 
             0.0003677206760410548}, {-1.8305507248146462`, 
             0.00036740500518343556`}, {-1.8080993908389567`, 
             0.00036737665271176413`}}]}, 
           {Arrowheads[{{0.017393466616273345`, 1.}}], 
            ArrowBox[{{-1.7844873978410059`, 
             0.00036734683451195}, {-1.6084264084218833`, 
             0.0003671244974240801}, {-1.385858065754305, 
             0.0003668791527629883}, {-1.3814662656569938`, 
             0.00036687467193955564`}, {-1.375610376191446, 
             0.0003668687123294643}, {-1.369754306820445, 
             0.00036686277104979766`}, {-1.3404711499468183`, 
             0.0003668334741495877}, {-1.3111833511979016`, 
             0.0003668048079448916}, {-1.2818910234247558`, 
             0.0003667768005921833}, {-1.2086411350919495`, 
             0.0003667095355591373}, {-1.1353651234252384`, 
             0.00036664630213410136`}, {-1.0620645252798928`, 
             0.0003665870125252962}, {-1.0254054412621263`, 
             0.0003665588416403438}, {-0.9947123491969682, 
             0.00036653577188233244`}, {-0.9762900298616436, 
             0.00036652184906848747`}, {-0.969118705628988, 
             0.00036651634076416374`}, {-0.9630985739337169, 
             0.00036651165010937424`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.307771563002431}, {-5.526866215865615, 
             4.3014488606862145`}, {-5.388563186028041, 
             4.294882655628357}, {-5.2450189401951635`, 
             4.288230697543684}, {-5.097422055450617, 
             4.281559038643208}, {-4.947937626656267, 
             4.27498726073469}, {-4.7979495344513925`, 
             4.268592121948494}, {-4.713341584885475, 4.265096652271976}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.689749716886796, 
             4.264121984293081}, {-4.647474534585746, 
             4.262375438979541}, {-4.49652938280908, 
             4.256339028522758}, {-4.345130834871148, 
             4.250484707273065}, {-4.193295646521703, 
             4.244814291925387}, {-4.041040573510496, 
             4.2393295991746465`}, {-3.8883823715872805`, 
             4.2340324457157665`}, {-3.7459156583652193`, 
             4.229277679875508}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7223162402229475`, 
             4.228507332835184}, {-3.581923604003835, 
             4.224008023453283}, {-3.4281565498431106`, 
             4.219284388039526}, {-3.274053389769388, 
             4.214755558697323}, {-3.1196308795324206`, 
             4.210423352121597}, {-2.9649057748819603`, 
             4.206289585007271}, {-2.8098948315677608`, 
             4.202356074049269}, {-2.7782226786618156`, 4.201594980165226}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7546175001937656`, 
             4.201027738746018}, {-2.654614805339573, 
             4.198624635942514}, {-2.4478651934399283`, 
             4.1939854693913}, {-2.2407186923717077`, 
             4.189717864214503}, {-2.033212750806195, 
             4.185824654728325}, {-1.824985364920976, 
             4.182278442542834}, {-1.8103310438549294`, 4.182056322372795}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7867217627491176`, 
             4.181698469046799}, {-1.6165670575592441`, 
             4.17911938047086}, {-1.4078642070427896`, 
             4.176340382721905}, {-1.1988768133716121`, 
             4.1739414492959686`}, {-0.9896048765457109, 
             4.1719225801930495`}, {-0.8423080822226356, 
             4.1707728067061405`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8186968085424431, 
             4.170588501157643}, {-0.7801300146801752, 
             4.170287455386337}, {-0.5705338458900925, 
             4.169039754849015}, {-0.36081637017546286`, 
             4.168179478581086}, {-0.15097758753628654`, 
             4.16770662658255}, {-0.11674895852819192`, 
             4.167666274672624}, {-0.08251794490556053, 4.167636252495248}, {
             0.08874722990402012, 4.1676415168306855`}, {0.12577564432436253`,
              4.1676987277762985`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1493876091391586, 4.167735209566188}, {
             0.25997500270280266`, 4.167906073197745}, {0.4311653734907869, 
             4.168429921596427}, {0.602318342267973, 4.169213062026732}, {
             0.6233345095092957, 4.169325156891524}, {0.6443501207438941, 
             4.169441190448955}, {0.6963457245030927, 4.169762199262265}, {
             0.7483357413140238, 4.170107199172116}, {0.9034445090803271, 
             4.171985704623976}, {1.0585532768466306`, 4.173864210075838}, {
             1.0938365120177447`, 4.174291521507568}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1174467735770839`, 4.1745774628228}, {
             1.213662044612934, 4.175742715527698}, {1.3687708123792373`, 
             4.1776212209795585`}, {1.5221463135763205`, 4.181248896949065}, {
             1.6769492107715849`, 4.1834360795510985`}, {1.8315481942528233`, 
             4.185829046919913}, {1.985943264020036, 4.1884277990555105`}, {
             2.061796807279133, 4.1898061317232935`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.08540490308806, 4.190235113788988}, {
             2.140099659834731, 4.191228970723567}, {2.293982621458417, 
             4.1942291966897605`}, {2.4475921488910934`, 4.197428476954092}, {
             2.60092824213276, 4.200826811516561}, {2.753990901183418, 
             4.204424200377166}, {2.9067801260430666`, 4.208220643535909}, {
             3.02964380278185, 4.211439336536815}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0532476975280383`, 4.212057694157474}, {
             3.0592959167117053`, 4.21221614099279}, {3.211538273189335, 
             4.216410692747807}, {3.363447002311225, 4.220794933126889}, {
             3.514961910912641, 4.225359496455964}, {3.666082998993584, 
             4.230104382735031}, {3.816810266554055, 4.23502959196409}, {
             3.967143713594053, 4.2401351241431415`}, {3.997275268127409, 
             4.241197358562243}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.020872602415795, 4.242029240656225}, {
             4.117083340113578, 4.245420979272184}, {4.26662914611263, 
             4.250887157351221}, {4.415781131591211, 4.256533658380248}, {
             4.639910117582285, 4.265379306971856}, {4.863036009845088, 
             4.274613994959214}, {4.964625036206622, 4.2790154571291}}]}, 
           {Arrowheads[{{0.014174107534909252`, 1.}}], 
            ArrowBox[{{4.9882148986601855`, 4.280037515228296}, {
             5.08515880837962, 4.284237722342323}, {5.30627851318588, 
             4.294250489121183}, {5.520118213818732, 4.304328422849004}, {
             5.656854249492381, 4.311019787936259}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.408159397219442}, \
{-5.623935099948645, -3.4068901023130067`}, {-5.4560313606245, \
-3.4006113502951076`}, {-5.287554294979911, -3.3945057638775085`}, \
{-5.1185039030148785`, -3.3885733430602083`}, {-4.948880184729403, \
-3.382814087843207}, {-4.778683140123484, -3.377227998226506}, \
{-4.71295340569499, -3.3751445568417404`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689353265317135, -3.3743965010405566`}, \
{-4.607912769197123, -3.3718150742101036`}, {-4.436569071950318, \
-3.366575315794001}, {-4.2646907256328195`, -3.3615162143827364`}, \
{-4.092316407494377, -3.356645261380849}, {-3.9194461175349904`, \
-3.3519624567883386`}, {-3.746079855754659, -3.347467800605206}, \
{-3.745259711408409, -3.347447485911615}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7216549584814618`, -3.3468628042940383`}, \
{-3.572217622153384, -3.3431612928314505`}, {-3.3978594167311647`, \
-3.339042933467072}, {-3.223005239488001, -3.335112722512071}, \
{-3.0476550904238944`, -3.3313706599664474`}, {-2.9276131467173405`, \
-3.328923133469759}, {-2.807335271353688, -3.3265628289598}, \
{-2.777407068408965, -3.3260065627833324`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753799152912873, -3.325567769818996}, \
{-2.617977147991103, -3.3230432885630545`}, {-2.428263319352065, \
-3.3197659769004852`}, {-2.2381937854365743`, -3.3167308939720916`}, \
{-2.04776854624463, -3.3139380397778733`}, {-2.022985324551589, \
-3.3135906460404154`}, {-1.998194935502307, -3.3132471561632735`}, \
{-1.903276810683504, -3.3120054585888243`}, {-1.8094360623928756`, \
-3.310841466243327}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785824604753227, -3.3106854360895204`}, \
{-1.5868381891332108`, -3.3094281383864805`}, {-1.3653644680408903`, \
-3.3080287544137335`}, {-1.1438907469485697`, -3.3066293704409864`}, \
{-0.9224170258562494, -3.3052299864682393`}, {-0.8413638767487339, \
-3.305763664622846}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8177523955593836, -3.3059191296707486`}, \
{-0.7000832282211124, -3.3066938986312477`}, {-0.47845772891535365`, \
-3.3057998022118693`}, {-0.2567310441339694, -3.305242564161403}, \
{-0.03490317387695985, -3.3050221844798497`}, {
             0.1267221517940648, -3.3050753539492184`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15033412292027246`, -3.3051061971636297`}, {
             0.2945448750666947, -3.3053161617364633`}, {
             0.4591555333678894, -3.3057415124347864`}, {
             0.6236906142219958, -3.306352437846454}, {
             0.788150117629014, -3.307148937971466}, {
             0.9525340435889436, -3.3081310128098225`}, {
             1.0948035515358268`, -3.309142044377472}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1184149346608683`, -3.3093116195973717`}, {
             1.281075163167538, -3.310651886626568}, {
             1.445155591063396, -3.3121872934989547`}, {
             1.6090069100665554`, -3.31390149087268}, {
             1.7726291201770148`, -3.3157944787477436`}, {
             1.9360222213947735`, -3.317866257124146}, {
             2.062836835506518, -3.3196154483500755`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0864465826756353`, -3.3199411045284575`}, {
             2.0991862137198325`, -3.320116826001887}, {
             2.262121097152192, -3.3225461853809666`}, {
             2.424826871691852, -3.325154335261385}, {
             2.587303537338811, -3.3279412756431417`}, {
             2.75037243287274, -3.3309771161968404`}, {
             2.9118785095206503`, -3.334077901454472}, {
             3.0307796067626644`, -3.3364942801574524`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0543867253016064`, -3.336974038038577}, {
             3.0731245805192584`, -3.3373548398590622`}, {
             3.234095197490263, -3.3408066127334206`}, {
             3.394774912055364, -3.344431901400358}, {
             3.5551482758362605`, -3.3482293871826836`}, {
             3.7151998404546513`, -3.3521977514032075`}, {
             3.8749141575322343`, -3.35633567538474}, {
             3.9985920214126804`, -3.359669355683821}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.0221954414659375`, -3.3603055750843964`}, {
             4.02224440719987, -3.3603068949333768`}, {
             4.169181723096061, -3.3644093360690968`}, {
             4.315687494774893, -3.3686381004074066`}, {
             4.461723111790448, -3.372988289563811}, {
             4.6072937018218845`, -3.3774595581550404`}, {
             4.752429385762688, -3.3820541625128095`}, {
             4.8971290429884355`, -3.386771106825102}, {
             4.966235013284515, -3.3890887887960095`}}]}, 
           {Arrowheads[{{0.014133737611032197`, 1.}}], 
            ArrowBox[{{4.989833738051804, -3.3898802448553806`}, {
             5.041391552874703, -3.3916093952799016`}, {
             5.185226284981217, -3.3965702546599386`}, {
             5.328648603258652, -3.4016561818020867`}, {
             5.471666378669002, -3.406868085975542}, {
             5.614287482174256, -3.4122068764495}, {
             5.656854249492381, -3.4138429418372986`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.2063359125072706`}, {-5.51031590606774, 
             1.2044463930640197`}, {-5.352184096200734, 
             1.202461001544217}, {-5.200793999074204, 
             1.200611899448041}, {-5.048956721036972, 
             1.1988106759247947`}, {-4.896672262089042, 
             1.197057330974478}, {-4.74394062223041, 
             1.1953518645970909`}, {-4.712442609053775, 
             1.1950110164155734`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-4.688831998412602, 
             1.1947555198654756`}, {-4.5907618014610785`, 
             1.1936942767926333`}, {-4.437135799781046, 
             1.1920845675611051`}, {-4.283062617190314, 
             1.1905227369025067`}, {-4.128542253688881, 
             1.1890087848168378`}, {-3.9736127625753017`, 
             1.187545260497745}, {-3.8183121971481286`, 
             1.186134713138875}, {-3.7443979143995176`, 
             1.1854901266074822`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207868192098132`, 
             1.185284220612257}, {-3.662640557407363, 
             1.1847771427402278`}, {-3.5065978433530036`, 
             1.1834725493018032`}, {-3.350184054985051, 
             1.1822209328236015`}, {-3.1933991923035054`, 
             1.1810222933056225`}, {-3.036243255308367, 
             1.179876630747866}, {-2.8787162439996354`, 
             1.1787839451503326`}, {-2.7763345299865185`, 
             1.1781110388094922`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7527230469684136`, 
             1.1779558517549222`}, {-2.7208859773536793`, 
             1.1777466018295422`}, {-2.5628202743468678`, 
             1.1767669661020157`}, {-2.4045191349792012`, 
             1.175845037967753}, {-2.2459825592506792`, 
             1.1749808174267538`}, {-2.0872105471613023`, 
             1.1741743044790185`}, {-1.9282030987110703`, 
             1.173425499124547}, {-1.8082570316007465`, 
             1.1729049455152352`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7846452609621364`, 
             1.1728024728562787`}, {-1.7689602138999825`, 
             1.1727344013633392`}, {-1.6094818927280399`, 
             1.1721010111953951`}, {-1.5319393479453767`, 
             1.1718141710572862`}, {-1.4543500047682307`, 
             1.1715408193254948`}, {-1.2242795703028033`, 
             1.1708132653645968`}, {-0.9939910996464627, 
             1.1702107902602998`}, {-0.8401702269482001, 
             1.1698922157070353`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8165582845901349, 
             1.1698433136051523`}, {-0.7634845927992091, 
             1.1697333940126042`}, {-0.5327600497610425, 
             1.1693810766215096`}, {-0.5070102823589565, 
             1.169348751533669}, {-0.4812588839442166, 
             1.1693179779812717`}, {-0.4344107725621175, 
             1.1692697834623085`}, {-0.38756006967482426`, 
             1.1692268405313324`}, {-0.24741884940833925`, 
             1.1694698744412872`}, {-0.10727762914185424`, 
             1.1697129083512419`}, {0.032863591124630886`, 
             1.1699559422611965`}, {0.1279201942140314, 
             1.1701207901044786`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15153215170584722`, 1.1701617381306197`}, {
             0.1730048113911158, 1.1701989761711513`}, {0.31314603165760074`, 
             1.170442010081106}, {0.4532872519240858, 1.1706850439910605`}, {
             0.5934284721905709, 1.1709280779010154`}, {0.7335696924570558, 
             1.17117111181097}, {0.8985647672348814, 1.171716584073909}, {
             1.0635598420127066`, 1.172262056336848}, {1.0960090157447813`, 
             1.1723693330191973`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1196208797092522`, 1.1724473936333475`}, {
             1.2285549167905319`, 1.1728075285997872`}, {1.3935499915683573`, 
             1.1733530008627262`}, {1.5569252979299906`, 
             1.1744358704584659`}, {1.7216345312226058`, 
             1.1750761775448402`}, {1.8861532035250808`, 
             1.1757797078468382`}, {2.0504813148374152`, 
             1.1765464613644598`}, {2.0640908028388045`, 
             1.176615185702969}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0877024947914355`, 1.1767344185433495`}, {
             2.214566459486135, 1.1773750482315062`}, {2.3783562317977647`, 
             1.1782640785817786`}, {2.5418506317723044`, 
             1.1792135524152771`}, {2.7050496594097546`, 
             1.1802234697320018`}, {2.867953314710115, 1.1812938305319525`}, {
             3.030561597673385, 1.182424634815129}, {3.0321648113228394`, 
             1.182436401129168}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0557761684290843`, 1.1826096897252878`}, {
             3.1928745082995658`, 1.1836158825815317`}, {3.354892046588656, 
             1.1848675738311605`}, {3.5165332737741455`, 1.186176072590681}, {
             3.6777172510895255`, 1.1875377428867593`}, {3.838443978534793, 
             1.1889525847193951`}, {3.9987134561099498`, 
             1.1904205980885885`}, {4.000223294764842, 1.19043496960324}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.023834218173279, 1.1906597119825655`}, {
             4.158525683814995, 1.1919417829943397`}, {4.31788066164993, 
             1.1935161394366485`}, {4.476778389614754, 1.195143667415515}, {
             4.635218867709466, 1.1968243669309389`}, {4.79303676921584, 
             1.198554164739185}, {4.9500667674156515`, 1.2003289875965184`}, {
             4.9682620674323505`, 1.2005409194620293`}}]}, 
           {Arrowheads[{{0.014082511638767283`, 1.}}], 
            ArrowBox[{{4.991872458909668, 1.200815924232857}, {
             5.106308862308897, 1.2021488355029386`}, {5.261763053895576, 
             1.204013708458446}, {5.416429342175692, 1.20592360646304}, {
             5.570307727149243, 1.2078785295167214`}, {5.656854249492381, 
             1.209009158614472}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.2057445850391748`}, \
{-5.513101452910997, -1.2038910889688168`}, {-5.354846879027562, \
-1.2019041957196102`}, {-5.203381620901341, -1.2000541668996105`}, \
{-5.051468744076286, -1.198252044776942}, {-4.8991082485523965`, \
-1.196497829351605}, {-4.746300134329672, -1.1947915206235995`}, \
{-4.712442544091266, -1.1944251428357366`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688831933419988, -1.194169649067665}, \
{-4.593044401408112, -1.1931331185929253`}, {-4.439341049787719, \
-1.1915226232595826`}, {-4.28519007946849, -1.189960034623571}, \
{-4.130591490450426, -1.1884453526848908`}, {-3.975583201875725, \
-1.186981120494161}, {-3.8202031328865833`, -1.185569881102}, \
{-3.7443978046977153`, -1.1849088146094804`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7207867094772213`, -1.184702912144906}, \
{-3.6644512834830008`, -1.1842116345084077`}, {-3.5083276536649777`, \
-1.1829063807133844`}, {-3.3518322434325136`, -1.18165411971693}, \
{-3.1949650527856086`, -1.1804548515190445`}, {-3.0377260817242635`, \
-1.179308576119728}, {-2.880115330248477, -1.1782152935189802`}, \
{-2.7763343936425526`, -1.1775331797807884`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7527229106408546`, -1.1773779902299781`}, \
{-2.7222008476030846`, -1.1771773799907868`}, {-2.5640506830329204`, \
-1.1761972118091333`}, {-2.405664836537984, -1.1752747889740194`}, \
{-2.2470433081182755`, -1.1744101114854453`}, {-2.0881860977737956`, \
-1.173603179343411}, {-1.9290932055045436`, -1.1728539925479164`}, \
{-1.808256881412935, -1.1723295966984029`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7846451107561916`, -1.1722271282177936`}, \
{-1.7697646313105193`, -1.1721625510989617`}, {-1.6102003751917233`, \
-1.1715288549965466`}, {-1.5326364004427702`, -1.1712419553144822`}, \
{-1.4550256694695287`, -1.1709685494275048`}, {-1.2249527072408182`, \
-1.1702410171698028`}, {-0.9946613915171261, -1.169638494085764}, \
{-0.8401700714496324, -1.1693184565159103`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8165581291151423, -1.1692695430323503`}, \
{-0.7641517222984524, -1.1691609801753882`}, {-0.5334236995847973, \
-1.1688084754386754`}, {-0.5076700726996276, -1.1687761212268148`}, \
{-0.48191482076159436`, -1.1687453188638866`}, {-0.43504598123262206`, \
-1.1686970609865106`}, {-0.388174449306551, -1.168654049923935}, \
{-0.24792584634436754`, -1.1688972235856951`}, {-0.10767724338218398`, \
-1.1691403972474552`}, {0.03257135957999968, -1.1693835709092153`}, {
             0.12792034998498042`, -1.1695488942183405`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15153230749036323`, -1.1695898344205715`}, {
             0.17281996254218324`, -1.1696267445709752`}, {
             0.3130685655043667, -1.1698699182327352`}, {0.45331716846655035`,
              -1.1701130918944953`}, {
             0.5935657714287339, -1.1703562655562554`}, {
             0.7338143743909175, -1.1705994392180155`}, {
             0.8988288019812867, -1.1711448607313286`}, {
             1.063843229571656, -1.171690282244642}, {
             1.0960091736648667`, -1.1717966002082325`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1196210376836047`, -1.1718746444059025`}, {
             1.2288576571620253`, -1.1722357037579552`}, {
             1.3938720847523944`, -1.1727811252712683`}, {
             1.5572637192311727`, -1.1738636618613116`}, {
             1.7219917715665556`, -1.1745038683881655`}, {
             1.8865289070652802`, -1.1752072649240461`}, {
             2.050875125727347, -1.1759738514689542`}, {
             2.064090969633069, -1.1760405652165817`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.087702661791285, -1.1761597573380187`}, {
             2.2149781208912493`, -1.1768022454695484`}, {
             2.3787855858954763`, -1.1776910643724878`}, {
             2.5422975207400293`, -1.1786403081777725`}, {
             2.7055139254249094`, -1.1796499768854027`}, {
             2.8684347999501147`, -1.1807200704953782`}, {
             3.031060144315646, -1.181850589007699}, {
             3.0321649970634574`, -1.1818586948329326`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0557763546269276`, -1.1820319211188068`}, {
             3.193389958521504, -1.183041532422365}, {
             3.355424242567688, -1.1842929007393765`}, {
             3.5170821385262494`, -1.1856010614011478`}, {
             3.678282788469242, -1.1869623818500934`}, {
             3.839026192396665, -1.1883768620862132`}, {
             3.9993123503085193`, -1.1898445021095074`}, {
             4.000223514672842, -1.1898531719964267`}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.023834438845882, -1.190077834033985}, {
             4.159141262204804, -1.191365301919976}, {
             4.31851292808552, -1.1929392615176186`}, {
             4.477427347950665, -1.1945663809024356`}, {
             4.635884521800241, -1.196246660074427}, {
             4.793718704961855, -1.1979760213480137`}, {
             4.950764152763117, -1.199750387037617}, {
             4.968262339845172, -1.1999541266273108`}}]}, 
           {Arrowheads[{{0.014082504814185444`, 1.}}], 
            ArrowBox[{{4.991872732462689, -1.2002290334894816`}, {
             5.107020865204025, -1.2015697571432362`}, {
             5.26248884228458, -1.203434131664872}, {
             5.417168084004781, -1.2053435106025243`}, {
             5.571058590364628, -1.207297893956193}, {
             5.656854249492381, -1.208418317256539}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.4128634368910125`}, {-5.454607476619563, 
             3.405253420198616}, {-5.222450049616829, 
             3.396891968822082}, {-4.989224102431195, 
             3.38886088035293}, {-4.754875992293604, 
             3.381151276929252}, {-4.712953813223917, 3.3798362009750527`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689353429264345, 
             3.3790958697674713`}, {-4.519389863670305, 
             3.373764205165038}, {-4.282774835995214, 
             3.366712413947358}, {-4.045065653237538, 
             3.3600050965689086`}, {-3.8063226839017785`, 
             3.353647890728012}, {-3.745260739981948, 3.352119165009201}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7216561433167796`, 
             3.351528208487221}, {-3.5666062964924423`, 
             3.3476464341229906`}, {-3.3259768595140318`, 
             3.342006364452166}, {-3.084494741471049, 
             3.33673331941386}, {-2.842220310868, 
             3.331832936706395}, {-2.777409435744259, 3.3306268772514755`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753801529999444, 
             3.330187559962826}, {-2.599213936209387, 
             3.327310854028093}, {-2.3555253753321863`, 
             3.3231805514489245`}, {-2.111208244497929, 
             3.3194526572673526`}, {-1.86632869984795, 
             3.316128531524436}, {-1.80943859908789, 3.315451765328059}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7858282766437292`, 
             3.3151708962857778`}, {-1.6209528975235896`, 
             3.313209534261233}, {-1.4980995735276847`, 
             3.311902383822355}, {-1.3751469936661838`, 
             3.310697025518803}, {-1.2521034274567555`, 
             3.3095936293557084`}, {-1.128977144417068, 
             3.3085923653382046`}, {-1.0057764140647876`, 
             3.307693403471423}, {-0.8825095059175805, 
             3.306896913760496}, {-0.8413886065892859, 
             3.3066655602010306`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8177769872882229, 
             3.3065327169933365`}, {-0.7591846894931153, 
             3.3062030662105575`}, {-0.6358102343090587, 
             3.3056120308267376`}, {-0.512389850468779, 
             3.3051264144945116`}, {-0.3889280410172622, 
             3.304748400294076}, {-0.26543426488460015`, 
             3.304477522522648}, {-0.1419179810008872, 
             3.304313315477445}, {-0.01838864829621556, 
             3.3042553134556845`}, {0.10514427429932283`, 
             3.3043030507545827`}, {0.12669840994006165`, 
             3.304329749505664}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15031038482367845`, 3.304358997268156}, {
             0.2286713278556336, 3.3044560616713574`}, {0.3521830534426247, 
             3.3047138805032263`}, {0.4756699921302031, 
             3.3050760415474056`}, {0.5991226849882764, 3.305542079101113}, {
             0.722531673086752, 3.3061115274615664`}, {0.8458874974955358, 
             3.306783920925982}, {0.9691806992845361, 3.307558793791577}, {
             1.0924018195236602`, 3.3084356803555695`}, {1.0947795884001674`, 
             3.3084545734787074`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1183908360651882`, 3.308642182213089}, {
             1.215541399282814, 3.3094141149151763`}, {1.3385899796319058`, 
             3.3104936317676144`}, {1.5545063543456221`, 3.31263394933656}, {
             1.770010504009703, 3.3150826889257137`}, {1.9850654221393098`, 
             3.3178372284563244`}, {2.0628125845813226`, 
             3.3189532478858124`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.0864221453195158`, 3.319292150653166}, {
             2.200028838087885, 3.320922914689653}, {2.4143764933202103`, 
             3.3243026015100576`}, {2.6282009040483842`, 3.327982844114417}, {
             2.8415020702724054`, 3.3319636425027306`}, {3.030756399433413, 
             3.335771672984577}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.054363611537366, 3.336246800227058}, {
             3.2664839124386336`, 3.3408219268339976`}, {3.4780630748421215`, 
             3.3456894531825045`}, {3.6890174792027395`, 
             3.3508475757205205`}, {3.8993471255204866`, 
             3.3562962944480446`}, {3.998567688870878, 
             3.358995553553093}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.022170949190956, 3.359637671609839}, {
             4.065620971547709, 3.360819713562643}, {4.231361106689843, 
             3.3655075230057667`}, {4.415584992741058, 3.370918880937377}, {
             4.5990987751190415`, 3.376522945125012}, {4.781902453823793, 
             3.3823197155686717`}, {4.963996028855313, 3.388309192268356}, {
             4.966211700448255, 3.3883833878765937`}}]}, 
           {Arrowheads[{{0.014134416152255047`, 1.}}], 
            ArrowBox[{{4.989810457736799, 3.389173873119218}, {
             5.012635332112538, 3.3899418816280895`}, {5.202049501620034, 
             3.3965867152592923`}, {5.390756862514018, 3.4034501440330387`}, {
             5.533304499024523, 3.4087060516301113`}, {5.656854249492381, 
             3.4133860949491024`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             5.2079980286349326`}, {-5.490891341505952, 
             5.198373420530422}, {-5.282999265750664, 
             5.186674998730889}, {-5.07477106049803, 
             5.175314848551636}, {-4.8662067257480475`, 
             5.1642929699926645`}, {-4.713782145194261, 5.156497657941546}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.690200970500304, 
             5.155291667315864}, {-4.657306261500718, 
             5.153609363053973}, {-4.447831322409838, 
             5.14331602249043}, {-4.237543563129206, 
             5.133464943056904}, {-4.02644298365882, 
             5.124056124753393}, {-3.814529583998681, 
             5.115089567579897}, {-3.7467012250041694`, 5.112371571591341}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7231081665573535`, 
             5.111426158210171}, {-3.601803364148789, 
             5.106565271536417}, {-3.3882643241091444`, 
             5.098483236622954}, {-3.1739124638797467`, 
             5.090843462839506}, {-2.9587477834605957`, 
             5.083645950186074}, {-2.7792222455377207`, 5.078052862081603}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7556217033834316`, 
             5.077317591138486}, {-2.742950228277657, 
             5.076922813451143}, {-2.5266997437568954`, 
             5.070706167423199}, {-2.309996329898311, 
             5.064996012102243}, {-2.092839986701903, 
             5.059792347488274}, {-1.8752307141676727`, 
             5.055095173581291}, {-1.8114374943940834`, 5.053869206072554}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7878298604400813`, 
             5.053415518481796}, {-1.6571685122956195`, 
             5.0509044903812965`}, {-1.4386533810857434`, 
             5.047220297888289}, {-1.2196853205380442`, 
             5.044042596102269}, {-1.1537067761883355`, 
             5.043185976903933}, {-1.0877012937067638`, 
             5.042376265609827}, {-0.9405250388587483, 
             5.0407422798666}, {-0.8434523453698457, 5.039821230899661}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8198414151548956, 
             5.039597204738428}, {-0.793269401253716, 
             5.039345083105932}, {-0.6459343808916672, 
             5.038184675327823}, {-0.4985199777726016, 
             5.037261056532274}, {-0.48031666208582113`, 
             5.037161651003664}, {-0.4621126375556891, 
             5.03706588316789}, {-0.4158722727410282, 
             5.0368553442017125`}, {-0.36962771955113627`, 
             5.036668248312998}, {-0.1902852555185438, 
             5.036118688660846}, {-0.010940763046878355`, 
             5.0359211664621695`}, {0.12462726347947609`, 
             5.036037964535838}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1482392477143163, 5.036058307343392}, {
             0.16840575786386017`, 5.03607568171697}, {0.34775430721367173`, 
             5.036582234425247}, {0.5270520808256984, 5.0374402490322945`}, {
             0.7062462745230826, 5.038649149983405}, {0.8853368883058241, 
             5.040208937278578}, {1.0643239221739231`, 5.042119610917815}, {
             1.0926928535521299`, 5.042478522129095}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.116302957086133, 5.0427772267487665`}, {
             1.243271303633653, 5.044383574286008}, {1.4218167768161307`, 
             5.046987208202094}, {1.6002075280789474`, 5.049939805754329}, {
             1.7784179864195935`, 5.053240405588754}, {1.9540109474217098`, 
             5.0568297047522135`}, {2.060635332526029, 
             5.059208172856135}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0842414530352666`, 5.059734754131456}, {
             2.129354429640358, 5.060741088431279}, {2.304421151803343, 
             5.06497199680754}, {2.479183832638464, 5.069519870062586}, {
             2.6536151908735235`, 5.074382148378004}, {2.827687945236323, 
             5.079556271935383}, {3.001374814454664, 5.08503968091631}, {
             3.0283534378341996`, 5.085941201792176}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0519522588501586`, 5.086729782791748}, {
             3.1746485172563483`, 5.090829815502375}, {3.3474817723691785`, 
             5.096924115875166}, {3.519847298520955, 5.103320022216272}, {
             3.691717814439479, 5.11001497470728}, {3.863066038852554, 
             5.117006413529778}, {3.995743892176619, 5.122665747629613}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.019334434334079, 5.123671995140561}, {
             4.03386469048798, 5.124291778865357}, {4.2040864880735604`, 
             5.131868510895602}, {4.373704150337095, 5.1397340498021045`}, {
             4.542690396006386, 5.147885835766451}, {4.671618540373013, 
             5.154302020222704}, {4.800358270385314, 5.160858046579919}, {
             4.928920626290903, 5.1675499873684885`}, {4.962705518194768, 
             5.169345569955314}}]}, 
           {Arrowheads[{{0.014221852385844492`, 1.}}], 
            ArrowBox[{{4.986284233784688, 5.170598719773092}, {
             5.057316648337391, 5.174373915118809}, {5.185557376772385, 
             5.181325902361276}, {5.313653851843497, 5.18840202162628}, {
             5.441617113798337, 5.195598345444219}, {5.569458202884514, 
             5.202910946345487}, {5.656854249492381, 5.207991284108276}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.9610768363280244`}, {-5.5632191052759685`, 
             2.957997112946055}, {-5.427782965349718, 
             2.9536562246309495`}, {-5.288725892018538, 
             2.949310841663963}, {-5.1480032899432855`, 
             2.945025812113752}, {-5.006864766097661, 
             2.940843064813117}, {-4.865324781502821, 
             2.936764419932111}, {-4.723397797179925, 
             2.9327916976407855`}, {-4.712808030299099, 
             2.93250396718041}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689204748163501, 
             2.9318626515299644`}, {-4.5852266775322885`, 
             2.9290375035858847`}, {-4.446721086156771, 
             2.925387064943104}, {-4.307890900338707, 
             2.921841580897318}, {-4.168745997363432, 
             2.918402250633402}, {-4.02929625451628, 
             2.9150702733362306`}, {-3.889551549082584, 
             2.9118468481906783`}, {-3.74952175834768, 
             2.90873317438162}, {-3.7450119405723195`, 
             2.908633964755179}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.7214056588707187`, 
             2.908114659872822}, {-3.6083738979150217`, 
             2.9056281206512846`}, {-3.4674858490887774`, 
             2.902698973289701}, {-3.3263324695319936`, 
             2.89988197563436}, {-3.1849137592446715`, 
             2.8971771276852634`}, {-3.0432297182268098`, 
             2.89458442944241}, {-2.9012803464784085`, 
             2.8921038809058004`}, {-2.7771003145848607`, 
             2.8900358257950067`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7534915211806332`, 
             2.889647212796964}, {-2.6165856107899903`, 
             2.887479232951311}, {-2.473840246849972, 
             2.8853351335334323`}, {-2.330881560107064, 
             2.883307184410003}, {-2.1877615584889143`, 
             2.88139938616923}, {-2.0444802419955233`, 
             2.879611738811113}, {-1.9010376106268905`, 
             2.8779442423356523`}, {-1.8090983457985315`, 
             2.8769535883880493`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7854877233879483`, 
             2.8766991817823397`}, {-1.7574336643830168`, 
             2.8763968967428477`}, {-1.613668403263901, 
             2.8749697020326996`}, {-1.4697418272695444`, 
             2.873662658205207}, {-1.3256539363999458`, 
             2.8724757652603716`}, {-1.256528211576083, 
             2.871949506190655}, {-1.18737278977158, 
             2.871450922979805}, {-0.9841977944856523, 
             2.8701489727580554`}, {-0.8410374517442346, 
             2.869403495351872}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8174257788695981, 
             2.869280542526298}, {-0.7808789205821415, 
             2.869090232440428}, {-0.5774161680610478, 
             2.868274702026923}, {-0.3738095369223709, 
             2.8677023815175398`}, {-0.35097476385933035`, 
             2.867651850980897}, {-0.32813971054646573`, 
             2.867604429888156}, {-0.2861388833759561, 
             2.867533424054092}, {-0.2441363475351681, 
             2.867472899495779}, {-0.11126142746083922`, 
             2.8673334463334554`}, {0.02159118071554411, 2.867298057583668}, {
             0.12705070600004975`, 2.8673525820633614`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1506626958421864, 2.867364789888659}, {
             0.15442147699398145`, 2.867366733246417}, {0.28722946137447325`, 
             2.867539473321702}, {0.4200151338570192, 2.8678162778095233`}, {
             0.5527784944416194, 2.868197146709881}, {0.6855195431282739, 
             2.8686820800227752`}, {0.8182382799169825, 
             2.8692710777482056`}, {0.9508937605782696, 2.869963187580431}, {
             1.0834450408826588`, 2.8707574572137107`}, {1.0951348224510045`, 
             2.870836576091099}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1187462746508576`, 2.8709963833193726`}, {
             1.2158921208301505`, 2.871653886648045}, {1.3482350004207446`, 
             2.872652475883433}, {1.4804736796544409`, 2.8737532249198754`}, {
             1.61260815853124, 2.8749561337573724`}, {1.7446384370511414`, 
             2.876261202395923}, {1.8765645152141448`, 2.877668430835528}, {
             2.0089129853301726`, 2.879208006356271}, {2.063183048966431, 
             2.87986587504128}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.08679330731162, 2.880152081626818}, {
             2.140302161620527, 2.8808007228345467`}, {2.271567328438877, 
             2.8824944635422125`}, {2.4026985812276687`, 
             2.8842886606934353`}, {2.5336860154293497`, 
             2.8861827465023837`}, {2.664519726486366, 2.8881761531832244`}, {
             2.7951898098411645`, 2.8902683129501257`}, {2.9256863609361914`, 
             2.8924586580172553`}, {3.0311652106450975`, 
             2.894334416449584}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.054773470946369, 2.8947542484202105`}, {
             3.1345839442535635`, 2.8961735392894914`}, {3.3429261441373286`, 
             2.900132612234383}, {3.5506578829779536`, 2.904332007095342}, {
             3.757724083165906, 2.908767854115779}, {3.9640935078145776`, 
             2.9134354049048508`}, {3.9990503350702236`, 
             2.9142672778281535`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.022655645118356, 2.914829016973746}, {
             4.1697485433076045`, 2.918329408994993}, {4.3746545469408185`, 
             2.923445243514541}, {4.57877687601005, 2.9287782855918287`}, {
             4.782100603480204, 2.93432651314041}, {4.966809761364424, 
             2.9395825297104197`}}]}, 
           {Arrowheads[{{0.014119173983185908`, 1.}}], 
            ArrowBox[{{4.990412004349826, 2.940260909260945}, {
             5.186323527248588, 2.9460645232538694`}, {5.387187236428321, 
             2.9522495185643627`}, {5.585754901309635, 2.958590448204724}, {
             5.656854249492381, 2.9609477257335493`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.7265414222521266, 0.5882881029913737}, {
             0.7310214182233881, 0.5882925899043098}, {0.7356698553255345, 
             0.588297235990896}, {0.7424213237405087, 0.5883039602982459}, {
             0.7559351889621894, 0.5883173557426427}, {0.783976049277569, 
             0.5883452048225912}, {0.8380619350765156, 0.5883997764496935}, {
             0.9119499167062575, 0.5884774021242979}, {0.9923490801263064, 
             0.5885680822501351}, {1.0003880211977039`, 0.5885775477742956}, {
             1.0120441297445544`, 0.5885914332615494}, {1.0800065104527297`, 
             0.5886757832298959}, {1.1479434498193364`, 0.5887653788516148}, {
             1.3805405682635135`, 0.5891126654895819}, {1.612762581135616, 
             0.5895224853130674}, {1.671020127282168, 
             0.5896411762524463}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.6946320712760783`, 0.5896892820172539}, {
             1.844609488435644, 0.5899948383220716}, {2.0760812901635974`, 
             0.5905297245165942}, {2.1057869487950636`, 0.5906024399803977}, {
             2.1354844703358067`, 0.5906761566757983}, {2.2345449056208775`, 
             0.5909368535835415}, {2.3335113786356176`, 0.5912087192868352}, {
             2.4594218122456044`, 0.5915635214063832}, {2.5851201004733317`, 
             0.5919355808505921}, {2.639108654624744, 0.592103078623506}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.66272053398717, 0.5921763337285867}, {
             2.7106062433187996`, 0.5923248976194617}, {2.835880240782008, 
             0.5927314717129921}, {2.960942092862957, 0.5931553031311833}, {
             3.0857917995616466`, 0.5935963918740352}, {3.2104293608780767`, 
             0.594054737941548}, {3.3348547768122474`, 0.5945303413337214}, {
             3.459068047364158, 0.5950232020505557}, {3.58306917253381, 
             0.5955333200920507}, {3.607193868617107, 0.595636097984333}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.630805647339609, 0.5957366907064862}, {
             3.7068581523212023`, 0.5960606954582065}, {3.8304349867263348`, 
             0.5966053281490231}, {3.953799675749208, 0.5971672181645005}, {
             4.076952219389822, 0.5977463655046386}, {4.199892617648176, 
             0.5983427701694374}, {4.322620870524271, 0.598956432158897}, {
             4.567277478859986, 0.6002314484553612}, {4.575274412043783, 
             0.6002753245227559}}]}, 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{4.598886049654947, 0.6004048724105918}, {
             4.81075858312727, 0.6015673347375936}, {5.053024830302707, 
             0.6029624970284531}, {5.294036867362883, 0.6044153413507988}, {
             5.53327072546622, 0.6059241190807549}, {5.543349207560053, 
             0.6059906035951633}}]}, 
           {Arrowheads[{{0.0019035987044386565`, 1.}}], 
            ArrowBox[{{5.566960686822943, 0.6061463609521385}, {
             5.656854249492381, 0.6067393599580277}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.575578209049944, 
             5.656854249492381}, {-5.486186618508002, 
             5.651075781029539}, {-5.303845665964938, 
             5.639438390285692}, {-5.120649063140495, 
             5.628122329081915}, {-5.083907270034934, 
             5.625897553310817}, {-5.047131694480484, 
             5.623685359872158}, {-5.01032239581123, 
             5.621485700194321}, {-4.991909322387379, 
             5.620388997827421}, {-4.973487826889075, 
             5.6192954140021385`}, {-4.9550579110246575`, 
             5.618204943912444}, {-4.936619573243127, 
             5.617117583618172}, {-4.918172807275154, 
             5.616033330482833}, {-4.770408003858257, 
             5.6075085812581555`}, {-4.632826406308743, 
             5.5998158897834776`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6092499569490135`, 
             5.598520969033319}, {-4.474185017554608, 
             5.591208345559865}, {-4.325726834667858, 
             5.583432859086252}, {-4.177037525291157, 
             5.575907126862994}, {-4.028117089424504, 
             5.56863114889009}, {-3.8789655270679013`, 
             5.561604925167542}, {-3.729582838221347, 
             5.554828455695347}, {-3.6659189459632047`, 
             5.55205418728778}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.6423293399314227`, 
             5.551026227852068}, {-3.5798024478032873`, 
             5.548301506266541}, {-3.4294577807321653`, 
             5.5420238426741575`}, {-3.2785488370079814`, 
             5.535995464918196}, {-3.127075616630736, 
             5.530216372998657}, {-2.9750381196004287`, 
             5.524686566915539}, {-2.8224363459170596`, 
             5.519406046668844}, {-2.6985292226894257`, 5.515335916371095}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.6749299581392614`, 
             5.514560722184125}, {-2.6692702955806293`, 
             5.514374812258571}, {-2.5155399685911366`, 
             5.50959286368472}, {-2.361416393815723, 
             5.505076675786665}, {-2.20707060012153, 
             5.500842723403781}, {-2.0525025875085574`, 
             5.4968910065360665`}, {-1.8977123559768043`, 
             5.4932215251835235`}, {-1.742699905526272, 
             5.489834279346152}, {-1.7307852434838105`, 5.489595961779736}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7071779724318124`, 
             5.489123768160918}, {-1.5874652361569597`, 
             5.486729269023949}, {-1.4320083478688674`, 
             5.483906494216918}, {-1.2763292406619962`, 
             5.4813659549250575`}, {-1.0685156561802127`, 
             5.478424643302936}, {-0.8604605168841255, 
             5.475998319332467}, {-0.7628076031396703, 
             5.475104530040701}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.7391965990937776, 
             5.474888425248997}, {-0.6522236125788698, 
             5.474092386287749}, {-0.44386473306958163`, 
             5.4727122474428835`}, {-0.235409453319596, 
             5.471857400054956}, {-0.026883348292248338`, 
             5.471527341381051}, {0.005967616347849036, 5.471523200077208}, {
             0.03881851320467761, 5.471532090568081}, {0.17403313846367022`, 
             5.471705821464676}, {0.20527264706085002`, 5.471796954370427}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.22888453958754157`, 5.471865835747659}, {
             0.3092138442765748, 5.47210017499568}, {0.44436063064339126`, 
             5.472715151161095}, {0.5794734975641196, 5.4735507499609195`}, {
             0.5965918700963324, 5.473670608823421}, {0.6137094743878958, 
             5.473794013501836}, {0.664732020130775, 5.474204017780731}, {
             0.7157467552618714, 5.47464556810571}, {0.8901245908533234, 
             5.4763369040405925`}, {1.064341374258363, 5.4783909159127235`}, {
             1.1733246974967315`, 5.479904101757579}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.196934414850769, 5.480231912371529}, {
             1.23839710547699, 5.480807603722104}, {1.4122917845092045`, 
             5.4835869674687325`}, {1.5859814442534415`, 5.486726748436731}, {
             1.759422117608135, 5.490224687910222}, {1.9326138045732857`, 
             5.494080785889206}, {2.1055565051488934`, 5.49829504237368}, {
             2.1412175677696883`, 5.499237568347412}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.1648213179957088`, 5.499861418172137}, {
             2.278104940895206, 5.502855517313731}, {2.450113833372473, 
             5.50775027065944}, {2.6215831825806926`, 5.512979302410808}, {
             2.7925129885198663`, 5.518542612567835}, {2.934345243666335, 
             5.523412581916186}, {3.075217108384079, 5.528465310468189}, {
             3.10882393490811, 5.529722878009858}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.1324194138224186`, 5.530605820896226}, {
             3.2151285826730978`, 5.533700798223844}, {3.3540796665333916`, 
             5.539119045183151}, {3.49207035996496, 5.5447200513461095`}, {
             3.6291006629678035`, 5.5505038167127205`}, {3.7651705755419216`, 
             5.556470341282983}, {3.9002800976873147`, 5.562619625056898}, {
             4.076030070775892, 5.570992473978945}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.0996153139993075`, 5.572116091097225}, {
             4.101341592015579, 5.572198332162607}, {4.303738027311532, 
             5.582356158930821}, {4.507469403575172, 5.593093105361542}, {
             4.7125357208065, 5.604409171454769}, {4.917740728131066, 
             5.616209636203525}, {5.042682056874427, 5.623670187949232}}]}, 
           {Arrowheads[{{0.010722306413067841`, 1.}}], 
            ArrowBox[{{5.06625206693565, 5.625077610789034}, {
             5.121888174674422, 5.628399778600834}, {5.324978060436568, 
             5.640979598646696}, {5.527010385417504, 5.653949096341111}, {
             5.57160338426206, 5.656854249492381}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.7541553213746535}, {-5.566730436420229, 
             0.7534122300443351}, {-5.328032293575825, 
             0.7515265954144852}, {-5.088022793589572, 
             0.7497099875360637}, {-4.846737736848686, 
             0.7479644293325355}, {-4.712401423818845, 0.7470380270114101}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688789992256001, 
             0.7468751992211309}, {-4.604212923740381, 
             0.7462919437273654}, {-4.394714426898278, 
             0.7449149357960554}, {-4.184470244771319, 
             0.7435980303530949}, {-3.973480377359504, 
             0.742341227398484}, {-3.7617448246628333`, 
             0.7411445269322224}, {-3.744328306605779, 0.7410514805816233}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720716650560845, 
             0.7409253372032863}, {-3.5493457707404525`, 
             0.740009802024899}, {-3.3363653996515072`, 
             0.7389389257471018}, {-3.1228037113959974`, 
             0.7379318980988312}, {-2.908660705973925, 
             0.7369887190800869}, {-2.7762476295916345`, 
             0.7364465745256688}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7526358345027075`, 
             0.7363498997373681}, {-2.6939676158451418`, 
             0.7361096919260883}, {-2.478755673469503, 
             0.7352951198720546}, {-2.2630248788470086`, 
             0.7345450029179859}, {-2.0467752319776586`, 
             0.7338593410638821}, {-1.9562393757095697`, 
             0.7335922149724385}, {-1.8656451928403346`, 
             0.7333373356409437}, {-1.808161481783686, 0.7331894788038623}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7845495668933937`, 
             0.7331287453719224}, {-1.6334492988670304`, 
             0.7327400925291978}, {-1.4009397995632002`, 
             0.7322217339907586}, {-1.1681166949288446`, 
             0.7317822600256264}, {-0.9349799849639635, 
             0.7314216706338008}, {-0.9073150680690314, 
             0.7313835876718038}, {-0.8796462725367314, 
             0.7313465743303933}, {-0.8400716981166224, 
             0.7312987560883567}}]}, 
           {Arrowheads[{{0.004223099000248346, 1.}}], 
            ArrowBox[{{-0.8164597219920525, 
             0.7312705370724493}, {-0.7620684672314032, 
             0.731209349405018}, {-0.6965784027693727, 
             0.731137382585284}, {-0.6506832413338797, 
             0.7310892551743878}, {-0.6265247993546007, 
             0.7310645968809225}, {-0.6212438028368829, 
             0.7310592350495837}, {-0.6170282706166202, 
             0.7310549550071244}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             0.38094704706404575`}, {-5.521173498577246, 
             0.38039518376232223`}, {-5.3263978076137795`, 
             0.37962921918931636`}, {-5.13078719890355, 
             0.3788861665211512}, {-4.934371856210927, 
             0.3781668294115601}, {-4.737168548293893, 
             0.37747165433483953`}, {-4.712381253945723, 
             0.37738770332927857`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688769396370766, 
             0.3773077333592312}, {-4.53919922492473, 
             0.3768011606724972}, {-4.340485835875724, 
             0.37615586780604093`}, {-4.141092622765418, 
             0.3755369378714464}, {-3.941083827212358, 
             0.37494553300468936`}, {-3.7442941942744907`, 
             0.3743924312343114}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7206822866669493`, 
             0.3743289421305055}, {-3.539219488777971, 
             0.3738452984746877}, {-3.3373639458966453`, 
             0.3733364688114431}, {-3.134892820572565, 
             0.372855164216036}, {-2.931806112805729, 
             0.3724013846884664}, {-2.776205272276609, 0.3720757842637222}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7525933309734882`, 
             0.37202637541675715`}, {-2.728103822596138, 
             0.37197513022873424`}, {-2.6174280459252426`, 
             0.37175580977867334`}, {-2.5066094810029655`, 
             0.3715451387555593}, {-2.2747370587045688`, 
             0.37113393119251037`}, {-2.042409709705244, 
             0.3707623559381679}, {-1.809627434004991, 
             0.37043041299253193`}, {-1.8081149818488425`, 
             0.3704285174722267}}]}, 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQvfFHK1tw75/9a7rrNs7dct3evm/5tycWP/en7lbf
Gb7hur3f66JjwQd/7J/RmXrxxPrr9m1Bz/7v8fyx39L4SZcNkP9HqyUgj/n7
fuk2j/U31l63Zwvaz/Njz9f9lTKtth1rrttzPixXc1r2dT+7z8+nBUC++Yc/
TL/av+7ff9HyZSCQv+u8av/GzK/7p6wpFjEG8i/rS/o7Xfqyvz22NHv26uv2
rL3/zpyy+rL/39Hlr9iB/Ke/ExW8F3/ev/8Gz8SKVdftZY9++5qh8Wl/2IQF
fiorr9tXzam8H7r2w/7JFY/vvFx+3d7RdWpIee27/XY6J+0uLrtuHztp+cMP
du/263LwhewC8rWDHviKS77bryygWboGyG8+5rnA9evb/W12TiHzgfwSE6vV
vG/e7H+j+OG9LZA/+77LpseBb/YLHpnJxArkc51dOMPj/ev9zzSKwx4svW4v
eIP9WuuC1/u/17ZePgTkx3sH3piX+Xr/ikU+CuuAfK04rQPyjq/3Hwk3PjUP
yJfM2/m8Uej1/j8XfAV7gfwrIVcVbD692s/+3u5AA5D/SMy0ofLhq/02MyND
qoB8APGC8yI=
             "]]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQLZG0S3li3FX7tDRPBdeXr+33XbnpKbT0qn1f4Mlw
byB/qmuHORPTNfs1Ifqzg4H874w/ZO0rrtkvsRe1jwPyN4U79taXXrf/drB4
bimQ/036XJdk2k37jQHuS5cC+bsbL9+3y79l7yOVZ38AyLedJdV/bfVte4nA
SP6HQL7UzAlPP6rftXde8uM256vX9odF1xzyf33Xfu6+NxHyQH5fwcakIyfv
2UedNzK1APLfLupn6L5z3/6RtHJcOJD/7fTDKc0+D+xzw/Pv5gD5qz6vSmfY
/MC+RP7j9BYgv1K4V39//UP7OTO6Y7YC+ada3p2c4/fI/sukhR9eAPlu0523
Hb/+2P76im2c/q+B9rEl+ExNfmV/Z6rdbcW3r+3fWNkVbiz/YP+w6diaL+9e
208o8rGZsfez/bN8v7rjH17b86/Vb7cq+WJfOCffTvfja3sAMyu4YA==
             "]]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.3019881082374063`, 0.8732162124383449}, {
             1.438353565909563, 0.8733645972560259}, {1.4672535989337339`, 
             0.8734376502513974}, {1.4961500347943846`, 0.8735122376459552}, {
             1.575038374705704, 0.8737307860787996}, {1.6538743958531417`, 
             0.8739596308601262}, {1.7792119779439914`, 0.8743370284609016}, {
             1.9044098072049531`, 0.874741157061083}, {2.029467883636027, 
             0.8751720166606705}, {2.1543862072372124`, 0.875629607259664}, {
             2.246463429621093, 0.8759870002578807}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.2700752447561485`, 0.8760786483027063}, {
             2.2791647780085103`, 0.8761139288580635}, {2.4038035959499195`, 
             0.8766249814558691}, {2.5283026610614407`, 0.8771627650530808}, {
             2.652661973343074, 0.8777272796496984}, {2.77684704519368, 
             0.8783175375798273}, {2.9008233890121202`, 0.8789325511775722}, {
             3.0245910047983946`, 0.8795723204429332}, {3.148149892552503, 
             0.8802368453759103}, {3.2145440004501444`, 
             0.8806078556013588}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.238155624805821, 0.8807397973406605}, {
             3.271500052274446, 0.8809261259765035}, {3.394641483964223, 
             0.881640162244713}, {3.517574187621834, 0.8823789541805385}, {
             3.640298163247279, 0.8831425017839801}, {3.8850766346644594`, 
             0.8847426088688025}, {4.1289336024785515`, 0.8864392283742706}, {
             4.182615564629574, 0.8868354605197174}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.206226914454915, 0.8870097383483084}, {
             4.371869066689556, 0.8882323603003844}, {4.613883027297472, 
             0.8901220046471442}, {4.785983424301676, 0.8915281325632242}, {
             4.957529472267734, 0.8929806611730935}, {5.128521171195646, 
             0.8944795904767521}, {5.150675371285331, 
             0.8946804593003415}}]}, 
           {Arrowheads[{{0.010219155693196232`, 1.}}], 
            ArrowBox[{{5.174286393798364, 0.8948945369152739}, {
             5.298958521085411, 0.8960249204742001}, {5.468031850331608, 
             0.8976079901831181}, {5.634931487328814, 0.8992201386211864}, {
             5.656854249492381, 0.8994385634291201}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.6053586477125096}, \
{-5.454640035895746, -0.6040537821165008}, {-5.215002245358075, \
-0.6025699621110936}, {-4.974099198003488, -0.6011425917785813}, \
{-4.731960882829503, -0.5997730193601029}, {-4.712391718918747, \
-0.5996676511423992}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688780068190067, -0.5995405165562886}, \
{-4.488626992765052, -0.598462812218912}, {-4.24413722073907, \
-0.597213537718262}, {-4.121499960686731, -0.5966127487577354}, \
{-3.9986558935364656`, -0.5960291900565351}, {-3.875605019288272, \
-0.5954628616146609}, {-3.7523473379421506`, -0.5949137634321131}, \
{-3.744311899868002, -0.594879147877353}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720700125958784, -0.5947774316242753}, \
{-3.628882849498101, -0.5943818955088914}, {-3.505211553956124, \
-0.593867257844996}, {-3.3813334513162197`, -0.5933698504404269}, \
{-3.2572485415783867`, -0.5928896732951839}, {-3.1329568247426263`, \
-0.5924267264092673}, {-3.0084583008089383`, -0.5919810097826769}, \
{-2.883752969777322, -0.5915525234154128}, {-2.7762272353901545`, \
-0.5911985096607095}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7526153674937537`, -0.5911216620127543}, \
{-2.6337218864203074`, -0.590747241458863}, {-2.508396134094908, \
-0.5903704458695777}, {-2.382863574671581, -0.5900108805396184}, \
{-2.2571242081503264`, -0.5896685454689854}, {-2.1603768769135443`, \
-0.5894174170145622}, {-2.063542367403525, -0.5891769210489496}, \
{-1.8312327262012895`, -0.588644841022648}, {-1.8081390653967353`, \
-0.5885982695964731}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7845271204113227`, -0.5885506529815916}, \
{-1.5985481740054288`, -0.5881756017999734}, {-1.3654887108159426`, \
-0.5877692033809259}, {-1.1320543366328317`, -0.587425645765505}, \
{-1.1037750807130469`, -0.5873878624463786}, {-1.0754913560219328`, \
-0.5873509859243886}, {-1.0098347140804687`, -0.5872723809046717}, \
{-0.9441657829127628, -0.5871991369047606}, {-0.9382615668688037, \
-0.5871925731328532}, {-0.9127911759681743, -0.5871647446483521}, \
{-0.8896749514702995, -0.5871401605054711}, {-0.8671485530223348, \
-0.5871167134783378}, {-0.840048581237221, -0.5870890462917921}}]}, 
           {Arrowheads[{{0.0019181059876386326`, 1.}}], 
            ArrowBox[{{-0.8164366004477467, -0.5870650358749995}, \
{-0.7878259725944118, -0.5870363667991376}, {-0.7652020856685215, \
-0.5870139368298062}, {-0.7488234725931306, -0.5869977476402356}, \
{-0.7401948077748451, -0.5869891799356376}, {-0.735143610925027, \
-0.5869841473366142}, {-0.7298618412424202, -0.5869788730662768}, \
{-0.7258560350322862, -0.5869748643101383}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7bFl99db7s/tTWPYD7YefrT/k8eMfIfc5/aebAuC
+4F8qSi1jxMWPLffFrI9dw6Qf0Ni1f1pZ5/bd98LebocyJ9+4uoiO60X9rt2
BafsB/JNved/2Xf3hX3Cedlbb4D8mxMzPieKv7K/n72fyfbIo/1/S+1aN79/
Za+5te9HCZD/dPNSs9R3r+3jH4bc2w7k3ypQZitkfmufFddTwXT00X6ti+ev
eZa8tVcvN56iCOTXe3lmKj59a/8p+ouWI5B/u57jcUfOO/s4hpPb0oH8NU0m
+9mmvLP/s+SvaDGQz+K306i+6r09tyT30q1Avl3G9MxKgw/2ESIJjr+A/HSJ
Yv8fJh/tl+9evHXxsUf7fQr0E+MtP9mL78jfE3b80X7msiQ23c6v9ln/cg0u
nny0/37e566+6z/sX93acX3jmUf7zd/s0W8+8MtebC+zy/Rzj/YDAFWawME=

             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.6956120577834812`, -0.5877643973719333}, {
             1.7589148837484385`, -0.5878871424378531}, {
             1.9648563347178662`, -0.5883358720772794}, {
             2.1704505266686915`, -0.5888333346589864}, {
             2.375697459600914, -0.5893795301829737}, {
             2.580597133514534, -0.5899744586492416}, {
             2.640088683014948, -0.5901616596391093}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.663700559115439, -0.590235958705376}, {
             2.7851495484095516`, -0.59061812005779}, {
             2.989222404402752, -0.5913085553859023}, {
             3.192683401610921, -0.592043805610862}, {
             3.3955325400340577`, -0.5928238707326692}, {
             3.5977698196721626`, -0.5936487507513236}, {
             3.608173902402653, -0.5936936279191574}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.631785675746237, -0.5937954753902551}, {
             3.799395240525235, -0.5945184456668254}, {
             4.0004088025932765`, -0.5954329554791747}, {
             4.2008105058762855`, -0.5963922801883713}, {
             4.400600350374263, -0.5973964197944153}, {
             4.576254509560871, -0.59831981837084}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.599866176097278, -0.5984439815982069}, {
             4.798000956679723, -0.5995297650160033}, {
             4.995504535679315, -0.6006557669723934}, {
             5.192181890278094, -0.6018201765073231}, {
             5.388016788613774, -0.6030222603111199}, {
             5.544329421496737, -0.6040151835802928}}]}, 
           {Arrowheads[{{0.0018828402310336586`, 1.}}], 
            ArrowBox[{{5.567940938137514, -0.6041651677745367}, {
             5.582980013334237, -0.6042606984263736}, {
             5.656854249492381, -0.6047478097739163}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.960925988215735}, \
{-5.6340016405495525`, -2.960158342876653}, {-5.507122308985041, \
-2.9560379203714495`}, {-5.3793714990805075`, -2.951986777571447}, \
{-5.250780500429264, -2.948006794530858}, {-5.121380602624623, \
-2.944099851303894}, {-4.991203095259899, -2.9402678279447683`}, \
{-4.860279267928402, -2.9365126045076932`}, {-4.728640410223447, \
-2.9328360610468804`}, {-4.712806478257422, -2.9324057599672555`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68920319949911, -2.9317643200296466`}, \
{-4.596317811738344, -2.929240077616543}, {-4.463342762066407, \
-2.9257265342708934`}, {-4.32974655080095, -2.9222973110641433`}, \
{-4.195560467535282, -2.9189542880505055`}, {-4.060815801862719, \
-2.9156993452841924`}, {-3.9255438433765715`, -2.9125343628194162`}, \
{-3.789775881670153, -2.90946122071039}, {-3.745011632864175, \
-2.908482222287959}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721405284662495, -2.90796594918464}, \
{-3.6535432063367757`, -2.9064817990113245`}, {-3.5168771069697518`, \
-2.9035979777764336`}, {-3.3637821945428885`, -2.9004968232197603`}, \
{-3.2104133873465193`, -2.8975309687496895`}, {-3.0567843741042346`, \
-2.894701260953985}, {-2.9029088435396266`, -2.892008546420411}, \
{-2.7770991993902654`, -2.889922820009818}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.753490450535015, -2.8895314240135783`}, \
{-2.7488004843762877`, -2.8894536717367303`}, {-2.5944729853378083`, \
-2.887037483490708}, {-2.4399400351477807`, -2.8847608282701085`}, \
{-2.284047218116646, -2.88255231050684}, {-2.128704111185433, \
-2.8805300291939693`}, {-1.973182930549854, -2.878648974082049}, \
{-1.8174836762099105`, -2.876909145171078}, {-1.8090974001949014`, \
-2.8768231395682573`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            
            ArrowBox[{{-1.7854866488022898`, -2.8765809990874356`}, \
{-1.6616063481656016`, -2.875310542461057}, {-1.5055509464169279`, \
-2.873853165951986}, {-1.3493174709638884`, -2.8725370156438648`}, \
{-1.1929059218064841`, -2.8713620915366933`}, {-1.036316298944715, \
-2.8703283936304715`}, {-0.8796189796622853, -2.8694381284417356`}, \
{-0.8410365809923603, -2.869254828465837}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8174248544603068, -2.869142652213104}, \
{-0.7228843412429009, -2.8686935024870217`}, {-0.5661123836865614, \
-2.8680945157663293`}, {-0.4093031069932671, -2.867641168279659}, \
{-0.25245651116301804`, -2.8673334600270106`}, {-0.09557259619581404, \
-2.867171391008384}, {0.06134863790834477, -2.8671549612237786`}, {
             0.1270515902507497, -2.867209048383235}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15066357524814777`, -2.8672284859450508`}, {
             0.2183071911494583, -2.8672841706731953`}, {
             0.447015248840019, -2.8677305081952524`}, {
             0.6754627668084672, -2.868480492674472}, {
             0.9036497450548038, -2.8695341241108534`}, {
             1.0951357780368565`, -2.8706744036541774`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1187473523959437`, -2.8708150081400925`}, {
             1.1315761835790288`, -2.870891402504397}, {
             1.359242082381142, -2.872552327855103}, {
             1.5866474414611442`, -2.8745169001629707`}, {
             1.8137922608190342`, -2.8767851194280007`}, {
             2.040676540454813, -2.8793569856501935`}, {
             2.063184598688983, -2.87964170519748}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0867947027866216`, -2.879940365263139}, {
             2.267109888309582, -2.882221293162688}, {
             2.492901912324443, -2.885366836298623}, {
             2.7180526124993967`, -2.888793615058}, {
             2.9425619888344428`, -2.892501629440818}, {
             3.031167325580613, -2.8940805453970238`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0547755705965334`, -2.8945012360249534`}, {
             3.1664300413295807`, -2.8964908794470774`}, {
             3.3896567699848115`, -2.9007613650767783`}, {
             3.6122421748001345`, -2.9053130863299206`}, {
             3.83418625577555, -2.910146043206504}, {
             3.998140108685934, -2.9138999688439333`}, {
             3.9990543417669357`, -2.9139217395084667`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.022659642894801, -2.91448385337499}, {
             4.161604680391238, -2.9177925564429255`}, {
             4.355416202188149, -2.922606821794991}, {
             4.548602774067428, -2.927624839939787}, {
             4.741164396029075, -2.9328466108773115`}, {
             4.933101068073089, -2.9382721346075655`}, {
             4.958722558342851, -2.9390111865160167`}, {
             4.966813515503528, -2.9392458497993905`}}]}, 
           {Arrowheads[{{0.014119255290070073`, 1.}}], 
            ArrowBox[{{4.990415357015892, -2.9399380360133196`}, {
             5.172852382342611, -2.945459013411788}, {
             5.3604123316919425`, -2.9513177095053966`}, {
             5.585344295516415, -2.958482662500688}, {
             5.656854249492381, -2.960860867831883}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -4.757583999163666}, \
{-5.5581677981115325`, -4.752109265093802}, {-5.3541944199917015`, \
-4.741230843776668}, {-5.14719271644956, -4.730627294812394}, \
{-4.937394361061459, -4.720317127312642}, {-4.72503102740375, \
-4.710318850389073}, {-4.713587569879337, -4.709803546827042}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.68999947999917, -4.708741365514199}, \
{-4.510334389052783, -4.700650973153349}, {-4.293536119584909, \
-4.691332004717131}, {-4.074867892576476, -4.68238045419208}, \
{-3.8548753426959275`, -4.673836461532833}, {-3.7463240530014486`, \
-4.669853776112736}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.722727936201087, -4.668988047933769}, \
{-3.6339899369418527`, -4.6657323009329446`}, {-3.412272097385825, \
-4.658074682862454}, {-3.1897822460994187`, -4.650870317791398}, \
{-2.9665808051542077`, -4.644125916189817}, {-2.7787324582873256`, \
-4.638857892863524}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.755129744845363, -4.638195977829136}, \
{-2.7427281966217647`, -4.637848188527747}, {-2.518284842573664, \
-4.632043845275229}, {-2.293311165081479, -4.6267195969023}, \
{-2.1221692149448006`, -4.623001793031343}, {-1.9507725623317447`, \
-4.619567639153289}, {-1.8108912354727627`, -4.61700219561491}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.787283212548252, -4.616569221098399}, \
{-1.7791500571345498`, -4.616420057865027}, {-1.6070228170615797`, \
-4.613530797396646}, {-1.4347995489195422`, -4.610941261204048}, \
{-1.2624081279778419`, -4.608644142795014}, {-1.0898485542364784`, \
-4.606639442169545}, {-0.9171208276954527, -4.604927159327642}, \
{-0.8428865089073387, -4.604318012872621}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8192753108134121, -4.604124265858403}, \
{-0.7442720754652352, -4.60350880988503}, {-0.5713494246562973, \
-4.602385909457438}, {-0.3983528752686393, -4.601558458044865}, \
{-0.22528242730226053`, -4.601026455647312}, {-0.18884404152606976`, \
-4.60095211846286}, {-0.15240312454438537`, -4.600890876748506}, {
             0.007194527870163753, -4.600776925895765}, {
             0.1251952300502437, -4.600878423409325}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1488072143135929, -4.6008987330994255`}, {
             0.16676728457662499`, -4.600914181333558}, {
             0.32631514557499847`, -4.601302643061885}, {
             0.485838110865284, -4.601942311080746}, {
             0.5054099304041242, -4.60203620927231}, {
             0.524981050333136, -4.602133904479879}, {
             0.5732008358550315, -4.602407074560304}, {
             0.6214162996459799, -4.6027033425442925`}, {
             0.8499513279747936, -4.604363993966522}, {
             1.0782302973841908`, -4.6065358314027485`}, {
             1.093265613699836, -4.606712743916363}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{1.1168759723310318`, -4.606990554359794}, {
             1.3062532078741724`, -4.609218854852974}, {
             1.534020059444738, -4.612413064317196}, {
             1.7614199776627393`, -4.616109881683996}, {
             1.9883420880950278`, -4.620300728841951}, {
             2.0612358448342833`, -4.621808818366352}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.084842786140536, -4.622297219327966}, {
             2.214786390741603, -4.6249856057910606`}, {
             2.4407528856024663`, -4.6301645125313255`}, {
             2.666374017213905, -4.635855230229714}, {
             2.8908992665369504`, -4.641956998940075}, {
             3.0290210687313848`, -4.6460163575658}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.052622870847007, -4.646710007499977}, {
             3.1148407524452515`, -4.648538572508017}, {
             3.338145497124293, -4.655592838466753}, {
             3.5284387010666975`, -4.661990539463264}, {
             3.7181868168162917`, -4.668723156439504}, {
             3.9073540210380266`, -4.675786018635526}, {
             3.996537159747214, -4.679280700846415}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.020131045485493, -4.680205238084829}, {
             4.095904490396855, -4.683174455291381}, {
             4.283797938260081, -4.690877435132629}, {
             4.470991527539212, -4.698880292305119}, {
             4.657445609215502, -4.707172904179336}, {
             4.843120534270206, -4.715745148125767}, {
             4.96370346106926, -4.721520698863874}}]}, 
           {Arrowheads[{{0.014197571861369374`, 1.}}], 
            ArrowBox[{{4.987288416266761, -4.722650345564407}, {
             5.028032799565335, -4.724601876011382}, {
             5.212230985323338, -4.733756496558287}, {
             5.395723567566119, -4.743211722419666}, {
             5.5785190223155805`, -4.752970266248708}, {
             5.656854249492381, -4.757349233054968}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.8596062989157227`}, {-5.635581901871712, 
             1.8591625340771032`}, {-5.434323248502308, 
             1.8551226263164518`}, {-5.229591760196643, 
             1.8511688430208033`}, {-5.021387436954715, 
             1.8473011841901577`}, {-4.993374754354958, 
             1.8467908629908822`}, {-4.965349645765006, 
             1.846283321861361}, {-4.776142718577518, 
             1.8430124252191729`}, {-4.712540050997036, 
             1.8419578713610578`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688931302889119, 
             1.841566430288701}, {-4.586363897211615, 
             1.8398658278220326`}, {-4.393374265983725, 
             1.836736864288409}, {-4.199896872364964, 
             1.833741553854354}, {-4.005931716355329, 
             1.830879896519868}, {-3.811478797954822, 
             1.8281518922849505`}, {-3.744560397395175, 
             1.8272613145575984`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.72095049512513, 
             1.826947104221864}, {-3.6165381171634423`, 
             1.8255575411496017`}, {-3.421109673981189, 
             1.8230968431138217`}, {-3.225193468408063, 
             1.8207697981776103`}, {-3.0287895004440646`, 
             1.8185764063409677`}, {-2.831897770089193, 
             1.8165166676038937`}, {-2.7765349884437094`, 
             1.8159764217197023`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7529241195815, 
             1.815746020097062}, {-2.6345182773434486`, 
             1.8145905819663886`}, {-2.4366510222068323`, 
             1.812798149428452}, {-2.2382960046793423`, 
             1.8111393699900842`}, {-2.0394532247609796`, 
             1.809614243651285}, {-1.8401226824517443`, 
             1.8082227704120546`}, {-1.808476423775457, 1.808023562929198}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7848648985732591`, 
             1.8078749326424381`}, {-1.6403043777516362`, 
             1.8069649502723928`}, {-1.439998310660655, 
             1.8058407832322998`}, {-1.2380726375255184`, 
             1.8048512587866337`}, {-1.0360398271865376`, 
             1.8040113077884652`}, {-0.8403965088622225, 
             1.8033431184644262`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8167846149426435, 
             1.8032751644093825`}, {-0.6316527948970467, 
             1.8027801261346204`}, {-0.4292985729465364, 
             1.8023888954789442`}, {-0.2268372137921817, 
             1.8021472382707657`}, {-0.024268717433983455`, 
             1.8020551545100845`}, {0.12769389365168374`, 
             1.8020982592620745`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1513058856997499, 1.802104956890221}, {
             0.17840691612805737`, 1.8021126441969009`}, {0.3339253845887402, 
             1.802258111442914}, {0.48936306204628466`, 
             1.8024915156064862`}, {0.6447199485006911, 
             1.8028128566876176`}, {0.7999960439519604, 1.803222134686308}, {
             0.955191348400092, 1.8037193496025572`}, {1.0957826926830272`, 
             1.8042497144349487`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1193944966862786`, 1.8043439603217006`}, {
             1.2653395842869395`, 1.804977590187733}, {1.4202925157256563`, 
             1.8057386158566593`}, {1.5750985742988086`, 
             1.8065856803308278`}, {1.729691678143968, 1.8075168854979216`}, {
             1.8840718272611352`, 1.8085322313579406`}, {2.038239021650311, 
             1.8096317179108852`}, {2.0638578336806934`, 
             1.8098286798392653`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.087469128880216, 1.8100102076255085`}, {
             2.1921932613114943`, 1.810815345156755}, {2.345934546244685, 
             1.8120831130955501`}, {2.4994628764498827`, 
             1.8134350217272706`}, {2.6527782519270886`, 
             1.8148710710519163`}, {2.8066205591153093`, 
             1.8164274940193015`}, {2.959048465884611, 1.818009221729757}, {
             3.031907412316799, 1.8188060967276332`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.0555179931729417`, 1.8190643310624806`}, {
             3.1112355852072113`, 1.8196737271381607`}, {3.2631680007237565`, 
             1.8214203287470234`}, {3.414831796074892, 1.823248345058857}, {
             3.5662130549012634`, 1.8251570945761726`}, {3.717297860843516, 
             1.8271458958014815`}, {3.8680722975422976`, 1.829214067237295}, {
             3.9999206040390476`, 1.8310949452494296`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{4.023530155412802, 1.831434459553645}, {
             4.168613774393105, 1.8335826750054498`}, {4.318342025656374, 
             1.8358800909782653`}, {4.467684907821018, 1.8382512264106636`}, {
             4.616649674164675, 1.8406967192160864`}, {4.765257884548145, 
             1.8432182955154741`}, {4.913513215603276, 1.845816321170394}, {
             4.967884409243835, 1.846799608966675}}]}, 
           {Arrowheads[{{0.014092097845678402`, 1.}}], 
            ArrowBox[{{4.991492541953863, 1.8472265554291751`}, {
             5.061419343961913, 1.8484911620424127`}, {5.2089161116549425`, 
             1.8512382542267665`}, {5.355906883798411, 1.8540502168093596`}, {
             5.502340621651913, 1.8569231901377612`}, {5.6481662864750435`, 
             1.8598533145595404`}, {5.656399214071849, 1.8600209023507253`}, {
             5.656854249492381, 1.8600301794259282`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             4.763197973190364}, {-5.599587891452205, 
             4.759974958247492}, {-5.451719622065682, 
             4.751897112760139}, {-5.431793483662753, 
             4.750838931495854}, {-5.411858987659376, 
             4.749784361753324}, {-5.208241694913875, 
             4.739471283345655}, {-5.0037667165994, 
             4.729527050897892}, {-4.817652296192434, 
             4.7206545245980225`}, {-4.713564548176867, 4.715891455995363}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.6899772380511955`, 
             4.714812097680646}, {-4.630964444420238, 
             4.71211166473001}, {-4.443703161282812, 
             4.703898471293856}, {-4.2558684467801555`, 
             4.69601494428956}, {-4.067460300912268, 
             4.688461083717123}, {-3.8784787236791507`, 
             4.681236889576545}, {-3.7462814763446293`, 4.676428588326665}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7226850864332204`, 
             4.675570336332835}, {-3.6889237150808034`, 
             4.674342361867825}, {-3.4987952751172244`, 
             4.6677775005909625`}, {-3.308093403788416, 
             4.661542305745959}, {-3.1168181010943767`, 
             4.655636777332814}, {-2.9249693670351076`, 
             4.650060915351527}, {-2.77866941925624, 4.646072195376227}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7550661970615447`, 
             4.645428677416866}, {-2.732547201610608, 
             4.644814719802099}, {-2.5395516048208773`, 
             4.639898190684528}, {-2.345982576665917, 
             4.635311327998817}, {-2.151840117145726, 
             4.631054131744964}, {-1.9571242262603046`, 
             4.627126601922969}, {-1.8108224132986595`, 4.624457818250332}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7872143478496618`, 
             4.624027168634053}, {-1.7458807057362342`, 
             4.6232731755907}, {-1.534403007544928, 
             4.619860528278965}, {-1.3226911316863867`, 
             4.6168886599877625`}, {-1.110745078160611, 
             4.614357570717092}, {-0.8985648469675993, 
             4.612267260466956}, {-0.8428169851716806, 
             4.611834343323955}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8192057041018291, 
             4.611650986904282}, {-0.6861504381073523, 
             4.610617729237352}, {-0.4735018515798708, 
             4.609408977028281}, {-0.2606190873851535, 
             4.608641003839742}, {-0.10594128158854466`, 4.608361295136896}, {
             0.04869863142058273, 4.608317563160105}, {0.12526486501417416`, 
             4.608412771853745}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14887683975718768`, 4.608442132907097}, {
             0.2033006516422291, 4.60850980790937}, {0.35786477907639413`, 
             4.608938029384691}, {0.512391013723078, 4.609602227586069}, {
             0.6668793555822807, 4.610502402513502}, {0.8213298046540023, 
             4.611638554166991}, {0.9757423609382426, 4.613010682546536}, {
             1.0933352403925833`, 4.614233616507799}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1169459566243287`, 4.614479161534535}, {
             1.1300464735076394`, 4.614615403346804}, {1.284171591434831, 
             4.6164493322624605`}, {1.4381177147198176`, 4.618512469293506}, {
             1.5918848433625987`, 4.620804814439941}, {1.7454729773631745`, 
             4.623326367701765}, {1.8988821167215448`, 4.626077129078977}, {
             2.05211226143771, 4.62905709857158}, {2.0613067950000796`, 
             4.629249889616992}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0849135991161614`, 4.629744877254321}, {
             2.20516341151167, 4.63226627617957}, {2.358833557008129, 
             4.635793366519191}, {2.511028912083333, 4.639405624249396}, {
             2.663015254081295, 4.6432437532442234`}, {2.8147775737844976`, 
             4.647306085078289}, {2.966300861975423, 4.651590951326207}, {
             3.029092318044659, 4.653461268608334}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0526938435359083`, 4.654164267770548}, {
             3.1175701094365538`, 4.656096683562596}, {3.2685703069503713`, 
             4.66082161336207}, {3.4192864452993574`, 4.665764072299247}, {
             3.566993081560928, 4.670827243074352}, {3.7143829400632975`, 
             4.676095975133295}, {3.8614370855143934`, 4.681568349196379}, {
             3.996606115880778, 4.6867964663753465`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.020199791800465, 4.687726191547805}, {
             4.15444934825529, 4.693109719797247}, {4.300335786231623, 
             4.699157838412674}, {4.44576569168263, 4.705379202762834}, {
             4.590708859739794, 4.711766213780375}, {4.7351778416807075`, 
             4.718321746415115}, {4.879209620866448, 4.725054660769541}, {
             4.963768800254047, 4.729124586910198}}]}, 
           {Arrowheads[{{0.014196193234552842`, 1.}}], 
            ArrowBox[{{4.987353490877435, 4.730259743963313}, {
             5.022810640553733, 4.731966335505306}, {5.165987343999283, 
             4.73905814928406}, {5.3084999267889454`, 4.746318102255318}, {
             5.4499678715537945`, 4.753726549704518}, {5.590186552118374, 
             4.761273402997196}, {5.656854249492381, 4.764960836557281}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.01999999999999999, 1.}}], 
            ArrowBox[{{-5.656854249492381, -3.856441289406867}, \
{-5.606948558678145, -3.854288219289714}, {-5.410279369177292, \
-3.8460107873928053`}, {-5.240372008732655, -3.8390728498440367`}, \
{-5.069613145730752, -3.8323094528469217`}, {-4.898002780171583, \
-3.8257205964014602`}, {-4.725540912055148, -3.8193062805076528`}, \
{-4.713124541290018, -3.8188518873908084`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.689528269020013, -3.817990409141079}, \
{-4.679253148409687, -3.8176160200386606`}, {-4.49889904794002, \
-3.8113043060487586`}, {-4.318058505767593, -3.8052435389369035`}, \
{-4.116793452116884, -3.7986577828574393`}, {-3.914869885971983, \
-3.7923690107634247`}, {-3.745546982041453, -3.787360932215242}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721945310207267, -3.7866628634739774`}, \
{-3.7122878073328915`, -3.7863772226548593`}, {-3.509047216199609, \
-3.7806824185317436`}, {-3.305188272440836, -3.7752903522966386`}, \
{-3.100751135925274, -3.770206777852104}, {-2.895735806652922, \
-3.765431695198141}, {-2.7777675127524972`, -3.7628687929310605`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7541610901039584`, -3.762355935178157}, \
{-2.690142284623781, -3.760965104334749}, {-2.4840376752609403`, \
-3.7568140446518177`}, {-2.2774890839874913`, -3.7529855555392357`}, \
{-2.0704965108034337`, -3.749479636997003}, {-1.8630599557087668`, \
-3.7462962890251204`}, {-1.8098327996239711`, -3.7455715746685496`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7862229949391861`, -3.745250115367143}, \
{-1.6256693980414378`, -3.7430640978296763`}, {-1.3880378703246383`, \
-3.740273524953117}, {-1.1501653725583698`, -3.737924570395442}, \
{-0.9120519047426306, -3.7360172341566513`}, {-0.8417951056499305, \
-3.7355852025555296`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8181835590729897, -3.735440007579323}, \
{-0.6736974668774218, -3.734551516236745}, {-0.43510205896274384`, \
-3.7335274166357233`}, {-0.19626568099859612`, -3.732944935353586}, {
             0.04281166701502215, -3.732804072390333}, {
             0.1262904454923584, -3.732879388832417}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1499024288801859, -3.732900692097891}, {
             0.18848075437158895`, -3.7329354983357224`}, {
             0.3340877756610414, -3.733232382560405}, {
             0.47963273088337954`, -3.7336947250643813`}, {
             0.6251156200386031, -3.734322525847651}, {
             0.7705364431267123, -3.735115784910214}, {
             0.9158952001477072, -3.736074502252071}, {
             1.061191891101587, -3.7371986778732214`}, {
             1.0943687595586276`, -3.7374932771418607`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1179798217284325`, -3.7377029353154776`}, {
             1.206426515988353, -3.738488311773665}, {
             1.3515456967909407`, -3.739940718764506}, {
             1.4964960554922846`, -3.7415532136568475`}, {
             1.6412775920923859`, -3.74332579645069}, {
             1.785890306591246, -3.745258467146033}, {
             1.930334198988863, -3.7473512257428774`}, {
             2.0623847962081157`, -3.7494131878333383`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{2.0859937031801974`, -3.74979469473339}, {
             2.2187155174803666`, -3.7520170066410676`}, {
             2.3626529435742554`, -3.754590028942414}, {
             2.50709432851935, -3.757387290208162}, {
             2.650274413202171, -3.760240469310889}, {
             2.793260367409363, -3.7632513231089884`}, {
             2.9360395369537335`, -3.7664186449993973`}, {
             3.0302838986539102`, -3.7686151611423915`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.0538894812713995`, -3.7691653271401098`}, {
             3.0785992676480873`, -3.769741228379051}, {
             3.2209269053052303`, -3.7732178666448855`}, {
             3.3630097957379705`, -3.7768473531938374`}, {
             3.5048352847591153`, -3.780628481422842}, {
             3.6463809307287836`, -3.784558275589285}, {
             3.7876186991769836`, -3.788632749013663}, {
             3.928527546671363, -3.792849178687583}, {
             3.9980135660520473`, -3.7950024234419475`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.021614230301445, -3.7957337648966383`}, {
             4.069086429779568, -3.7972048416026505`}, {
             4.209299544547513, -3.8017006296772378`}, {
             4.349185509580128, -3.8063395005021543`}, {
             4.488744915283571, -3.8111218295776625`}, {
             4.627978352064007, -3.816047992404024}, {
             4.766843911821716, -3.8211098561639805`}, {
             4.905275401596475, -3.826294426144546}, {
             4.965519453318756, -3.8286089479588803`}}]}, 
           {Arrowheads[{{0.014151594784280136`, 1.}}], 
            ArrowBox[{{4.989114039617959, -3.8295154305597094`}, {
             5.04323698450369, -3.831594785002394}, {
             5.180692823658767, -3.837004015394197}, {
             5.316631154324682, -3.8424751126221524`}, {
             5.449482538705883, -3.84793816492876}, {
             5.578374630329978, -3.8533518943811425`}, {
             5.656854249492381, -3.8567192616794252`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.8620552241128758`}, \
{-5.53291635671387, -1.859546502130368}, {-5.375850952412119, \
-1.8564516062791103`}, {-5.21802458896918, -1.8534301272472622`}, \
{-5.059732219554577, -1.8504924698755}, {-4.900973844168309, \
-1.8476386341638245`}, {-4.741749462810379, -1.8448686201122348`}, \
{-4.7125404557452955`, -1.8443772880173377`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688931802598991, -1.8439801608920565`}, \
{-4.582059075480784, -1.8421824277207317`}, {-4.421902682179525, \
-1.8395800569893146`}, {-4.2612802829066005`, -1.837061507917984}, \
{-4.100191877662013, -1.8346267805067393`}, {-3.9386729541316488`, \
-1.832278763657458}, {-3.7767590000013938`, -1.8300203462720164`}, \
{-3.7445621755057177`, -1.829590123323478}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{-3.7209522901920526`, -1.829274641451169}, \
{-3.614450015271249, -1.827851528350415}, {-3.451745999941214, \
-1.8257723098926535`}, {-3.2886469540112895`, -1.823782690898732}, \
{-3.125152877481474, -1.8218826713686505`}, {-2.961263770351769, \
-1.8200722513024088`}, {-2.7969796326221745`, -1.8183514307000073`}, \
{-2.77653855483, -1.8181486647377694`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7529277234227285`, -1.8179144562973824`}, \
{-2.6461382673637557`, -1.8168551546776333`}, {-2.4950352272115017`, \
-1.8154377207187402`}, {-2.343670512165412, -1.8140991288233286`}, \
{-2.194137521376171, -1.8122086424835486`}, {-2.0423802939893276`, \
-1.8109883136833587`}, {-1.8906230666024837`, -1.8097679848831685`}, \
{-1.8084902422723577`, -1.8091075283586466`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7848790126469463`, -1.808917662847686}, \
{-1.73886583921564, -1.8085476560829785`}, {-1.5871086118287967`, \
-1.8073273272827886`}, {-1.5102379996163169`, -1.8068806759432923`}, \
{-1.4333119992772247`, -1.806454040863304}, {-1.2570099895527502`, \
-1.8055286626249938`}, {-1.0788652627777797`, -1.8047110331052993`}, \
{-0.9007205360028092, -1.803893403585605}, {-0.8404149838709319, \
-1.8036166196441594`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8168032395656247, -1.803508248997972}, \
{-0.7225758092278388, -1.8030757740659105`}, {-0.5444310824528683, \
-1.802258144546216}, {-0.5192335294287737, -1.8022079674744411`}, \
{-0.4940349236051495, -1.802160144322307}, {-0.44678479262359444`, \
-1.802083052891593}, {-0.39952926655300147`, -1.802014061101952}, \
{-0.16384685550366396`, -1.8017714687317372`}, {
             0.07181787535756573, -1.8017318973219392`}, {
             0.1276732613666407, -1.8017706397450535`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15128524868464158`, -1.8017870174960386`}, {
             0.3074649260306872, -1.8018953468725576`}, {
             0.5430942965157004, -1.8022618173835923`}, {
             0.778601324041909, -1.8028308802986917`}, {
             1.0138813458386153`, -1.8036021070615038`}, {
             1.0957619924384971`, -1.8039411873843927`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1193737829762425`, -1.8040389674324502`}, {
             1.2489343619058197`, -1.804575497672029}, {
             1.4837603722435224`, -1.8057510521302669`}, {
             1.7185161676278797`, -1.807134102149503}, {
             1.952313266994003, -1.8086944346877867`}, {
             2.0638370057058384`, -1.8095343960537902`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0874483290225334`, -1.809712229039084}, {
             2.185757928009699, -1.8104526657031548`}, {
             2.4187874343645044`, -1.812406662510293}, {
             2.546645353352152, -1.813562631862269}, {
             2.674347676259539, -1.8147758639711495`}, {
             2.8018838977164204`, -1.8160459095509975`}, {
             2.929243512352552, -1.8173723193158757`}, {
             3.031886786002737, -1.8184880190625143`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.055497384245961, -1.8187446587578513`}, {
             3.0564160147976898`, -1.8187546439798474`}, {
             3.183390899681589, -1.8201924342569755`}, {
             3.3101576616340047`, -1.8216852408613233`}, {
             3.4367057952846918`, -1.823232614506954}, {
             3.5630247952634067`, -1.82483410590793}, {
             3.689104156199905, -1.826489265778315}, {
             3.814933372723942, -1.828197644832172}, {
             3.940501939465272, -1.8299587937835635`}, {
             3.9998994775637065`, -1.8308184733738484`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{4.023508997865435, -1.8311601815218557`}, {
             4.065799351053651, -1.8317722633465534`}, {
             4.190815102118836, -1.833637604235204}, {
             4.315538687290581, -1.835554367163579}, {
             4.439959601198641, -1.8375221028457411`}, {
             4.564093151546197, -1.8395413053400795`}, {
             4.687969396364098, -1.8416130077588841`}, {
             4.811599955773606, -1.8437375693970686`}, {
             4.934996449895983, -1.8459153495495473`}, {
             4.967863359257754, -1.8465174064008874`}}]}, 
           {Arrowheads[{{0.014092543901262852`, 1.}}], 
            ArrowBox[{{4.991471391750021, -1.8469498589187732`}, {
             5.180946623276187, -1.8504206708543867`}, {
             5.425538678498399, -1.8551091825874029`}, {
             5.656854249492381, -1.8597485210841365`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             3.864397020012038}, {-5.6046725864068225`, 
             3.8621473011102343`}, {-5.476395919675825, 
             3.8567133806241056`}, {-5.345230396013963, 
             3.85127934623416}, {-5.21166114644106, 
             3.84586814276632}, {-5.0761733019769375`, 
             3.8405027150465085`}, {-4.939621266075517, 
             3.8352187096883377`}, {-4.8025640242434395`, 
             3.8300416118752683`}, {-4.713126840942381, 
             3.8267491949935364`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.689530830820425, 
             3.825880564081877}, {-4.665043580579615, 
             3.8249791242879976`}, {-4.527101939182954, 
             3.820038949607224}, {-4.3888232477342175`, 
             3.8152366161970472`}, {-4.250257939048685, 
             3.8105813918748463`}, {-4.111397444927047, 
             3.8060715885012355`}, {-3.972233197169989, 
             3.801705517936827}, {-3.8327292145950604`, 
             3.79747742776831}, {-3.745560731113485, 3.794926645794293}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.721958841143159, 
             3.7942359916371426`}, {-3.6928714464063224`, 
             3.7933848170015128`}, {-3.5526842199842283`, 
             3.7894308746257592`}, {-3.4121918627092334`, 
             3.785618789630374}, {-3.271428047744799, 
             3.7819533926556694`}, {-3.130418971627978, 
             3.778438201021168}, {-2.989177746799619, 
             3.775074433735007}, {-2.847717485700568, 
             3.7718633098053234`}, {-2.7777833261975595`, 
             3.7703540786642344`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7541768296685665`, 
             3.769844632923458}, {-2.706051300771671, 
             3.768806048240254}, {-2.5641923044537758`, 
             3.7659038680479364`}, {-2.4221536091877276`, 
             3.7631579882365074`}, {-2.2788293991288042`, 
             3.7604656057864028`}, {-2.136048859775095, 
             3.757996772332752}, {-1.9931148463549264`, 
             3.7556866772762634`}, {-1.8500273588682983`, 
             3.753535320616938}, {-1.8098498930641682`, 3.752976413784558}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.786240184367468, 
             3.752647980240108}, {-1.7067863973152109`, 
             3.7515427023547763`}, {-1.563391961695664, 
             3.749708822489777}, {-1.4198440520096576`, 
             3.748033681021941}, {-1.2761426682571917`, 
             3.7465172779512677`}, {-1.1322878104382665`, 
             3.745159613277757}, {-0.9883276518407373, 
             3.743962682501514}, {-0.84431036575246, 
             3.742928481122643}, {-0.8418127937870008, 
             3.742913373901759}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8182012327294743, 
             3.742770553164961}, {-0.7002359521734343, 
             3.742057009141144}, {-0.5561044111036602, 
             3.7413482665570164`}, {-0.4119157425431378, 
             3.7408022533702603`}, {-0.26766994649186704`, 
             3.740418969580876}, {-0.12336702294984803`, 3.740198415188864}, {
             0.02099302808291903, 3.7401405901942235`}, {0.12627280083472497`,
              3.7402554223572606`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.14988477978712103`, 3.7402811767310196`}, {
             0.260707370600484, 3.74040205463077}, {0.5001634771499257, 
             3.741108244488066}, {0.7393613477312452, 3.742259159766111}, {
             0.9783009823444428, 3.7438548004649053`}, {1.094351055631812, 
             3.744846853633063}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.117962185933538, 3.745048693200726}, {
             1.216982380989518, 3.745895166584449}, {1.4554055436664708`, 
             3.7483802581247416`}, {1.6935704703753012`, 
             3.7513100750857835`}, {1.9314771611160078`, 
             3.7546846174675745`}, {2.062366821110235, 
             3.756767040538136}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.0859758263361075`, 3.757142654143959}, {
             2.136055054256323, 3.757939402638695}, {2.34018731478759, 
             3.7615076421252924`}, {2.5438739427098094`, 
             3.7653893359273667`}, {2.747114938022981, 3.769584484044918}, {
             2.949845351703174, 3.7740859917474974`}, {3.030265104521572, 
             3.775995799398988}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{3.053870442140544, 3.7765563787693637`}, {
             3.152000234726458, 3.778886764304656}, {3.3535795870928333`, 
             3.7839868017163942`}, {3.554583408802299, 3.7893861039827126`}, {
             3.7549784727162487`, 3.7950798773778094`}, {3.954731551696075, 
             3.801063328175885}, {3.9979935526386248`, 
             3.8024263264530402`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{4.021593835636647, 3.8031698691548534`}, {
             4.153842645741777, 3.8073364563769396`}, {4.352311754853356, 
             3.813899261980972}, {4.534083752143327, 3.8201882609399553`}, {
             4.71521048832065, 3.826705899546227}, {4.931849467775661, 
             3.834802873632194}, {4.965496771696726, 
             3.8361114890062322`}}]}, 
           {Arrowheads[{{0.014152256404041772`, 1.}}], 
            ArrowBox[{{4.989090927202292, 3.8370291160085164`}, {
             5.147340001626864, 3.8431837598458083`}, {5.273980926776081, 
             3.848263074608426}, {5.400077890973749, 3.853435074518663}, {
             5.422809479313694, 3.8543778222119696`}, {5.445466537095915, 
             3.8553210664051205`}, {5.600762030572584, 3.861971034458775}, {
             5.656854249492381, 3.864425451949297}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -2.184628285054146}, \
{-5.443981030343043, -2.179603597837657}, {-5.205866857878852, \
-2.1742274005460387`}, {-4.96666737531425, -2.169069866130829}, \
{-4.726382582649236, -2.1641309945920284`}, {-4.7126034903539225`, \
-2.163861531711661}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-4.688996011077693, -2.1633998656434152`}, \
{-4.484970726554517, -2.1594099627051775`}, {-4.242390053700801, \
-2.1549059472458167`}, {-3.998640564088088, -2.150618948213946}, \
{-3.753722257716378, -2.146548965609566}, {-3.7446697551260377`, \
-2.146405672564271}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-3.721060719690739, -2.146031962581838}, \
{-3.612688301498202, -2.1443165238206943`}, {-3.4714016305551203`, \
-2.1421683914417615`}, {-3.260255771596648, -2.139120870157792}, \
{-3.04852747315003, -2.136255869498456}, {-2.8362167352152667`, \
-2.133573389463753}, {-2.776673330392331, -2.132874183895042}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            
            ArrowBox[{{-2.753062965191068, -2.132596932386212}, \
{-2.623323557792358, -2.131073430053683}, {-2.595486743269647, \
-2.130758911210296}, {-2.5676384227183133`, -2.130447363666523}, \
{-2.4546991431867933`, -2.1292523807317134`}, {-2.341666352296625, \
-2.1281139665390763`}, {-2.108983662482056, -2.1258879360699123`}, \
{-1.8758719528707704`, -2.1238924694701242`}, {-1.808628872271521, \
-2.1233843033063384`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7850175534915373`, -2.1232058689874553`}, \
{-1.6423312234627667`, -2.122127566739712}, {-1.4083614742580453`, \
-2.120593227878676}, {-1.1740629766761188`, -2.119292073522832}, \
{-0.9395360021365007, -2.118226724307996}, {-0.8405535894463265, \
-2.1178769549061074`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8169417438648722, -2.1177935188604295`}, \
{-0.7047805506391904, -2.1173971802341685`}, {-0.469796622184188, \
-2.1168034413013492`}, {-0.2344414672220132, -2.116444053658608}, {
             0.0004760001336110431, -2.116327255794549}, {
             0.12753620565357637`, -2.1163922209351824`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15114819556520265`, -2.1164042936076526`}, {
             0.23550774480734285`, -2.116447426152243}, {
             0.47059666697938995`, -2.1168051462720605`}, {
             0.5958063707106096, -2.1170923201722833`}, {
             0.7209929713769889, -2.1174460319160286`}, {
             0.8461462306521947, -2.117866246732421}, {
             0.9712559102098959, -2.1183529298505843`}, {
             1.0956239347394487`, -2.118903004226508}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{1.1192356394330498`, -2.1190196674627555`}, {
             1.2213035768674532`, -2.119525561908722}, {
             1.3462210873146447`, -2.1202114413069455`}, {
             1.4710540647390031`, -2.120963649923437}, {
             1.5957922708141958`, -2.121782152987321}, {
             1.7204254672138888`, -2.1226669157277227`}, {
             1.8449434156117512`, -2.1236179033737654`}, {
             1.9693358776814516`, -2.1246350811545742`}, {
             2.0636927543459724`, -2.1254577321757364`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0873038499935417`, -2.125663585661268}, {
             2.0935926150966573`, -2.1257184142992727`}, {
             2.2177033895310343`, -2.1268678680369857`}, {
             2.3416579626582523`, -2.1280834075968373`}, {
             2.4654460961519797`, -2.129364998207952}, {
             2.589066173327423, -2.1307108263347305`}, {
             2.7125179569624356`, -2.1321187938392163`}, {
             2.8357932779246546`, -2.1335884390470006`}, {
             2.9588839670817197`, -2.1351193002836735`}, {
             3.0317254285587896`, -2.136081303601105}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.0553353626262916`, -2.1363931155065323`}, {
             3.204478773450931, -2.1383628241460486`}, {
             3.4492370230111695`, -2.141845672031066}, {
             3.6930933627035336`, -2.1455641505434504`}, {
             3.9359824394691207`, -2.149514566287926}, {
             3.9997073145834467`, -2.1506155687548616`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023315784164536, -2.151023462582864}, {
             4.177838900249031, -2.1536932258692167`}, {
             4.418597391984363, -2.1580964358920482`}, {
             4.65823158504253, -2.1627190677575188`}, {
             4.896754173217255, -2.1675545576631023`}, {
             4.967622581052831, -2.1690609715828497`}}]}, 
           {Arrowheads[{{0.014098653137929245`, 1.}}], 
            ArrowBox[{{4.99122924145341, -2.169562766429274}, {
             5.134174873294087, -2.1726012894629996`}, {
             5.370519936763545, -2.1778618770663267`}, {
             5.605803613161231, -2.1833370750526173`}, {
             5.656854249492381, -2.184577379176868}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.5854034726616073, -0.8737530760562366}, {
             0.7225754598811849, -0.8739119512219075}, {
             0.8620912272666966, -0.8741066449224368}, {
             1.0015357334391155`, -0.8743353689372376}, {
             1.140897808066582, -0.8745985481058136}, {
             1.2801583737095386`, -0.8748957074428538}, {
             1.4193174303679865`, -0.8752268469483583}, {
             1.5298814364920956`, -0.8755171518943607}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.553493348098061, -0.875579149057489}, {
             1.5583749780419252`, -0.8755919666223271}, {
             1.6973038655065906`, -0.8759904476350452}, {
             1.8360769415372182`, -0.876421671156798}, {
             1.9746942061338082`, -0.8768856371875855}, {
             2.1131556592963605`, -0.8773823457274076}, {
             2.218380108984825, -0.8777824533697947}, {
             2.323520640653644, -0.8782023087290396}, {
             2.4979669441289793`, -0.8789492756081634}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{2.52157872066786, -0.8790503795850344}, {
             2.5519880850745262`, -0.8791805903580601}, {
             2.7798064997409746`, -0.8802442021662374}, {
             3.0069758846529893`, -0.8813931441535715}, {
             3.2334962398105707`, -0.8826274163200623}, {
             3.263249631430649, -0.8827953823366212}, {
             3.2929907215095082`, -0.882964787712366}, {
             3.4284876473777555`, -0.8837748444419677}, {
             3.4660453086647407`, -0.8840080894446543}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.489656846341689, -0.8841547245912575}, {
             3.5637215532883375`, -0.8846146899399715}, {
             3.7108090325758756`, -0.8855456890033415}, {
             3.8574911504298597`, -0.886509248864892}, {
             4.00376790685029, -0.8875053695246228}, {
             4.1496393018371664`, -0.888534050982534}, {
             4.295105335390489, -0.8895952932386255}, {
             4.434114185306658, -0.8906434636516483}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.457725473956369, -0.8908258237187999}, {
             4.584821318196474, -0.8918154601453498}, {
             4.729071267449136, -0.8929743847959825}, {
             4.872915855268245, -0.8941658702447955}, {
             5.016355081653799, -0.895389916491789}, {
             5.1593889466058, -0.8966465235369628}, {
             5.302017450124247, -0.897935691380317}, {
             5.402170857763831, -0.89886645149069}}]}, 
           {Arrowheads[{{0.004893341408082612, 1.}}], 
            ArrowBox[{{5.425781831188195, -0.8990858763984231}, {
             5.444240592209141, -0.8992574200218516}, {
             5.586058372860481, -0.9006117094615665}, {
             5.656854249492381, -0.9013060139568299}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -1.5436654853656882`}, \
{-5.5580601648721935`, -1.5420181455753386`}, {-5.430609310014495, \
-1.539940092096916}, {-5.302416861193531, -1.5378969744265374`}, \
{-5.173574692602599, -1.5358905030219352`}, {-5.044248118034135, \
-1.5339233171898854`}, {-4.914543699601263, -1.5319973131579292`}, \
{-4.78446518397831, -1.5301130867649442`}, {-4.712487185727637, \
-1.5290968043714837`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688877545973863, -1.528763451655642}, \
{-4.654016317839603, -1.5282712338498081`}, {-4.5231759583778635`, \
-1.5264713011539903`}, {-4.3919428743710975`, -1.5247136746968866`}, \
{-4.260350679871558, -1.5230002092342656`}, {-4.1284329889314995`, \
-1.5213327595218962`}, {-3.9729175230182983`, -1.519434506169013}, \
{-3.8170834174437673`, -1.5176072987534748`}, {-3.744474030059436, \
-1.5167908589566215`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7208635295955492`, -1.5165253760363442`}, \
{-3.6609417996950078`, -1.515851599727943}, {-3.5045037972591206`, \
-1.5141678715450797`}, {-3.3477805376232035`, -1.5125565766575462`}, \
{-3.190783148274357, -1.5110181775180045`}, {-3.033522756699682, \
-1.5095531365791164`}, {-2.8750609448204316`, -1.5081224536664084`}, \
{-2.776429259522943, -1.5072916513914796`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75281810413523, -1.5070927680250377`}, \
{-2.7169499970870206`, -1.5067906409261933`}, {-2.558598302101981, \
-1.505533111291955}, {-2.40000585986531, -1.504349864763694}, \
{-2.2411726703770096`, -1.5032409013414096`}, {-2.0820987336370784`, \
-1.5022062210251024`}, {-1.922784049645517, -1.5012458238147721`}, \
{-1.8083609593939882`, -1.5006103586767598`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.784749330519527, -1.5004792280896693`}, \
{-1.763228618402326, -1.5003597097104189`}, {-1.6034324399075048`, \
-1.4995478787120426`}, {-1.4434626553930776`, -1.498811857719631}, \
{-1.2833864060910685`, -1.498153173633172}, {-1.1232036920014763`, \
-1.4975718264526652`}, {-0.9629145131243029, -1.4970678161781108`}, \
{-0.8402773343056136, -1.4967415852593224`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8166654248499159, -1.496678774495162}, \
{-0.8025188694595475, -1.4966411428095088`}, {-0.6420167610072093, \
-1.496291806346859}, {-0.4814081877672898, -1.496019806790162}, \
{-0.32069314973978813`, -1.4958251441394173`}, {-0.10144528945533363`, \
-1.4956846027952764`}, {0.11768659793211295`, -1.495688565721492}, {
             0.12781346922676595`, -1.4956954305568382`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{0.15142545679958025`, -1.4957114367251962`}, {
             0.33670251242255245`, -1.4958370329180644`}, {
             0.5556024540159858, -1.4961300043849932`}, {
             0.7743864227124121, -1.4965674801222786`}, {
             0.9930544185118305, -1.4971494601299207`}, {
             1.0959031580376224`, -1.4974913375066898`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1195150205862687`, -1.4975698252126741`}, {
             1.2116064414142418`, -1.4978759444079193`}, {
             1.430042491419647, -1.4987469329562744`}, {
             1.6513228926226093`, -1.499775684711487}, {
             1.8722154703505414`, -1.5009487113412394`}, {
             2.0639835673120603`, -1.5020943392595971`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.08759513897702, -1.5022353954421648`}, {
             2.0927202246034424`, -1.5022660128455319`}, {
             2.312837155381313, -1.5037275892243644`}, {
             2.5324725199523868`, -1.5053300262353246`}, {
             2.7515325755848967`, -1.507069909636}, {
             2.970017322278843, -1.5089472394263908`}, {
             3.0320464435119128`, -1.5095207565591071`}}]}, 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{3.0556574273119748`, -1.5097390621462319`}, {
             3.1879267600342263`, -1.510962015606497}, {
             3.4052352567516664`, -1.5131132386670847`}, {
             3.6219171803317822`, -1.5153999090989205`}, {
             3.837972530774575, -1.5178220269020046`}, {
             4.000083780416474, -1.5197466076921735`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023694109608272, -1.5200269089427805`}, {
             4.053401308080044, -1.5203795920763372`}, {
             4.224871210934753, -1.52251756098064}, {
             4.395811797365901, -1.52473524616368}, {
             4.611532420865206, -1.5276494814357373`}, {
             4.826239575371754, -1.5306776536756967`}, {
             4.968087653082109, -1.5327633594372851`}}]}, 
           {Arrowheads[{{0.014086952772555122`, 1.}}], 
            ArrowBox[{{4.99169709401698, -1.5331105079343292`}, {
             5.039933260885547, -1.5338197628835584`}, {
             5.252613477406584, -1.5370758090593222`}, {
             5.280954410210372, -1.5375183428055423`}, {
             5.309276997757687, -1.5379628345005392`}, {
             5.507880252396954, -1.5412058163023543`}, {
             5.656854249492381, -1.5437280487340181`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             1.5379947423455007`}, {-5.611199881910641, 
             1.5372211800981948`}, {-5.400219759562455, 
             1.5337909095143683`}, {-5.188185490220406, 
             1.5304686824079676`}, {-5.159815458153794, 
             1.530032540833956}, {-5.131427253851321, 
             1.5295983671376774`}, {-4.936689993620868, 
             1.52674118337556}, {-4.741113501016551, 
             1.5239784107370347`}, {-4.712484895200399, 
             1.5235809572011092`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688875177363816, 
             1.5232531813430528`}, {-4.585220942503124, 
             1.5218141401817895`}, {-4.428963442992502, 
             1.5197205440350683`}, {-4.272341002484685, 
             1.5176976222968717`}, {-4.115353620979672, 
             1.5157453749671992`}, {-3.9580012984774635`, 
             1.513863802046051}, {-3.80028403497806, 
             1.5120529035334274`}, {-3.744469699598522, 
             1.5114384798410765`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.720859137165477, 
             1.5111785665257975`}, {-3.6422018304814614`, 
             1.5103126794293278`}, {-3.483754684987667, 
             1.5086431297337526`}, {-3.324942598496677, 
             1.5070442544467018`}, {-3.1657655710084924`, 
             1.5055160535681753`}, {-3.0062236025231126`, 
             1.5040585270981732`}, {-2.8463166930405372`, 
             1.5026716750366953`}, {-2.7764233910697618`, 
             1.5020977002440559`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.7528121942223565`, 
             1.501903801380612}, {-2.6860448425607664`, 
             1.5013554973837417`}, {-2.525408051083801, 
             1.5001099941393126`}, {-2.3644063186096393`, 
             1.4989351653034078`}, {-2.2030396451382823`, 
             1.497831010876027}, {-1.9792166688884856`, 
             1.4964264144199948`}, {-1.8083547000945175`, 
             1.495470332684044}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.7847430767473755`, 
             1.4953382105857345`}, {-1.7551084878497147`, 
             1.4951723861521438`}, {-1.5307151020219698`, 
             1.4940689260724738`}, {-1.3060365114052515`, 
             1.4931160341809848`}, {-1.0810727159995592`, 
             1.4923137104776771`}, {-0.8558237158048929, 
             1.4916619549625505`}, {-0.8402709666088592, 
             1.4916273932835502`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.8166590319119387, 
             1.49157492229612}, {-0.6302895108212527, 
             1.491160767635605}, {-0.40447010104863856`, 
             1.4908101484968406`}, {-0.2398985241378906, 
             1.4906504082513943`}, {-0.07535485040062173, 
             1.4905722829328818`}, {0.08916092016316857, 
             1.4905757725413027`}, {0.12781985435696663`, 
             1.4905957743243161`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.15143184419454941`, 1.490607990954368}, {
             0.2536487875534811, 1.4906608770766574`}, {0.41810875177031503`, 
             1.4908275965389457`}, {0.5825408128136704, 
             1.4910759309281676`}, {0.7469449706835471, 
             1.4914058802443233`}, {0.9113212253799445, 
             1.4918174444874126`}, {1.075592005702941, 1.4923094381881536`}, {
             1.095909572192704, 1.4923801696157504`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{1.1195214221102652`, 1.4924623694133348`}, {
             1.2396797404526159`, 1.4928806758772637`}, {1.4035844296289683`, 
             1.4935311575547434`}, {1.567306073231998, 1.4942608832205924`}, {
             1.7308446712617052`, 1.4950698528748105`}, {1.8942002237180888`, 
             1.4959580665173982`}, {2.05737273060115, 1.4969255241483552`}, {
             2.0639900768776096`, 1.4969680200680764`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.087601583002277, 1.4971196507409852`}, {
             2.220362191910889, 1.4979722257676815`}, {2.3840646883330168`, 
             1.4991278632005411`}, {2.5461290614539265`, 1.500314530310062}, {
             2.7079766806371612`, 1.50157932447409}, {2.8695906917005445`, 
             1.5029216872256945`}, {3.0309542404618997`, 
             1.5043410600979445`}, {3.032053335540406, 
             1.5043512655096514`}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{3.055664310732153, 1.5045705001576286`}, {
             3.19205047273905, 1.505836884623909}, {3.352862534349818, 
             1.5074086023366569`}, {3.51337357111203, 1.5090556547692573`}, {
             3.672251339470365, 1.5107633171209944`}, {3.8308118229596007`, 
             1.5125448573925415`}, {3.9890425184877283`, 1.514400022456584}, {
             4.000091136418566, 1.5145349764169942`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{4.023701368213545, 1.5148233649110923`}, {
             4.146930922962734, 1.5163285591858067`}, {4.3044238771140995`, 
             1.5183271610241287`}, {4.461444989569305, 1.5203907765990312`}, {
             4.617946909083332, 1.5225165355585424`}, {4.773882284411166, 
             1.5247015675506905`}, {4.929253732251674, 1.5269453004190356`}, {
             4.968095414102901, 1.527523057725}}]}, 
           {Arrowheads[{{0.014086745965420446`, 1.}}], 
            ArrowBox[{{4.991704795388006, 1.5278742395450617`}, {
             5.084092422414504, 1.5292484752617266`}, {5.23839383332083, 
             1.531610191608676}, {5.392153443391821, 1.534029548989796}, {
             5.543645523824917, 1.5364799197082732`}, {5.656854249492381, 
             1.5383652898643796`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{-5.656854249492381, 
             2.180640411362521}, {-5.583082336808344, 
             2.1788629939873223`}, {-5.380158844285832, 
             2.1741533276081877`}, {-5.3529774432826525`, 
             2.173534403236142}, {-5.325782042085978, 
             2.1729183386889086`}, {-5.124980850459934, 
             2.1685645053996314`}, {-4.923407987483646, 
             2.1643645369835}, {-4.743736598422442, 
             2.1606929233736865`}, {-4.7125990666839135`, 
             2.1600814809113835`}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688991624822821, 
             2.159617905554755}, {-4.563568707344245, 
             2.1571549968651302`}, {-4.382904314249053, 
             2.1537507574578307`}, {-4.201743419136869, 
             2.1504802051517884`}, {-4.020086022007691, 
             2.147343339947003}, {-3.8379321228615186`, 
             2.144340161843475}, {-3.744661020527829, 2.1428748456590374`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7210519408669684`, 
             2.142503940141024}, {-3.655281721698354, 
             2.1414706708412043`}, {-3.472134818518195, 
             2.1387348669401907`}, {-3.288491413321043, 
             2.136132750140434}, {-3.104351506106897, 
             2.1336643204419343`}, {-2.919715096875758, 
             2.131329577844692}, {-2.7766606185115954`, 2.129628795181545}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.753050294110159, 
             2.129348090719354}, {-2.734582185627626, 
             2.1291285223487066`}, {-2.5489527723625, 
             2.1270611539539783`}, {-2.36282685708038, 
             2.125127472660507}, {-2.1762044397812668`, 
             2.123327478468293}, {-1.9890855204651603`, 
             2.1216611713773363`}, {-1.8086154074176988`, 
             2.120205288439357}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.785004182707261, 
             2.120014812694536}, {-1.7727708892379443`, 
             2.119916124646213}, {-1.5562254240077373`, 
             2.1183721621549183`}, {-1.3394491247745381`, 
             2.117029283903453}, {-1.1224419915383477`, 
             2.1158874898918163`}, {-0.9052040242991658, 
             2.114946780120009}, {-0.840539938900408, 2.114726853361367}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-0.816928082464087, 
             2.1146465479024785`}, {-0.6877352230569925, 
             2.1142071545880308`}, {-0.47003558781182864`, 
             2.1136686132958817`}, {-0.25210511856367246`, 
             2.1133311562435617`}, {-0.09454106097747972, 2.1132131859259}, {
             0.06298150640860245, 2.1132017184238654`}, {0.12754990653144127`,
              2.113240683601546}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.1511618952299321, 2.113254932759544}, {
             0.22046258359457394`, 2.1132967537374583`}, {0.3779021705804344, 
             2.1134982918666783`}, {0.535300267366184, 2.1138063328115253`}, {
             0.6926568739518226, 2.1142208765720003`}, {0.8499719903373504, 
             2.1147419231481024`}, {1.0072456165227663`, 
             2.1153694725398315`}, {1.0956375506779572`, 
             2.115781541275047}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.1192492871037099`, 2.1158916153271448`}, {
             1.1644120871642678`, 2.1161021569119356`}, {1.321405736918049, 
             2.1169386084291615`}, {1.47822656578411, 2.1178788270915088`}, {
             1.6348745737624508`, 2.118922812898978}, {1.791349760853071, 
             2.1200705658515684`}, {1.947652127055971, 2.121322085949281}, {
             2.0637063985749027`, 2.122329498565186}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.0873175020223513`, 2.122534455463171}, {
             2.1037816723711518`, 2.1226773731921154`}, {2.259738396798612, 
             2.1241364275800714`}, {2.416260908045311, 2.1257328563303486`}, {
             2.57141122914973, 2.1273784800047153`}, {2.7263609447504944`, 
             2.129126606602867}, {2.881096162539634, 2.130976604014135}, {
             3.031739976694491, 2.1328790548955663`}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.055349915004162, 2.1331904901329652`}, {
             3.189867535451172, 2.134979682833349}, {3.343875905957632, 
             2.1371315000199576`}, {3.4976142094205986`, 2.13938265957701}, {
             3.6504792562164803`, 2.141721522741928}, {3.8030329526455233`, 
             2.1441536183929117`}, {3.9552598075531114`, 2.146677865499357}, {
             3.999721428569827, 2.147443455404153}}]}, 
           {Arrowheads[{{0.020000000000000007`, 1.}}], 
            ArrowBox[{{4.023329921891316, 2.147849972839664}, {
             4.107144329784627, 2.149293183030661}, {4.258671028185451, 
             2.1519984899562195`}, {4.409824411600966, 2.154792705245429}, {
             4.560588988876553, 2.157674747867687}, {4.710949268857596, 
             2.1606435367923886`}, {4.860889760389474, 2.163697990988931}, {
             4.9676357602584655`, 2.16593924928586}}]}, 
           {Arrowheads[{{0.01409839344073234, 1.}}], 
            ArrowBox[{{4.991242550425786, 2.1664349017167828`}, {
             5.010394972317572, 2.1668370294267105`}, {5.15944941348727, 
             2.170059571075124}, {5.308037592743949, 2.1733645349035666`}, {
             5.456144018932993, 2.1767508398814366`}, {5.603753200899783, 
             2.180217404978129}, {5.656854249492381, 2.1814974001012257`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQfS6rKrpN9I190be5N8V3X9rvdUfaJMH6jf27011b
lIH8533/3WbGvrEP/FiVoAfk75pxSCNs4ht7GZ/yXDsg/8sL47n1e97Yf3x2
aZ83kP+ipIyrgeGtvZ+F4rQEIL/Y1bWHqfqtvcXtwD2tQP6Kix4fEhXe2TPm
583eDuSzNi+unizx3n6elkcp055L+9etEVPaY/DB/rj8npo0IL9Q8y/L1OgP
9h7Oq7c1APksxX6fgto/2Mtv+7NyNpCfkiS+y2T2B/sCIzeuFUC+VcLpvh+z
P9l3La8r+r330n6GTa9kM+d8sRe/UplZuv/S/u3hpeltc77Zi+0wfy968NL+
+MDs7IA5P+w7gncw3z10aX/Vy/VCm2b/smdLUnc7deTS/t4sNbdps/7Ya87f
EHr32KX9hjPuzo1U/2tfubLUour4pf0AN/6vKA==
             "]]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8457189284963686`, -0.2934508354056562}, {
             1.9123506762382811`, -0.2935233584868647}, {
             2.036840743052812, -0.293667998229088}, {
             2.1611732558831194`, -0.29382128634227633`}, {
             2.2853103014419176`, -0.2939828586935898}, {
             2.409251879729207, -0.2941527152830285}, {
             2.532997990744988, -0.2943308561105924}, {
             2.65654863448926, -0.29451728117628145`}, {
             2.7799038109620238`, -0.29471199048009566`}, {
             2.7901977717683066`, -0.294729317086191}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{2.813809731318772, -0.2947690603035948}, {
             3.0260277620930247`, -0.2951262618020997}, {
             3.2713698441379906`, -0.2955736700766045}, {
             3.515930057096922, -0.29605421530361004`}, {
             3.7582877324985877`, -0.2965649038944937}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{3.7818996661551574`, -0.29661783486750604`}, {
             4.00270487575668, -0.2971147166151233}, {
             4.172369517872322, -0.2975167853364233}, {
             4.341536402775819, -0.297933732902516}, {
             4.5658647921530715`, -0.29851087185622327`}, {
             4.726376511529631, -0.2989434238798202}}]}, 
           {Arrowheads[{{0.019203587422604793`, 1.}}], 
            ArrowBox[{{4.749988418791547, -0.2990070539892402}, {
             4.789219667658179, -0.2991127755910734}, {
             5.011601029291141, -0.2997394441070664}, {
             5.233008877051956, -0.30039087740420223`}, {
             5.262489767912779, -0.30047946051669705`}, {
             5.291952187492173, -0.30056846270224835`}, {
             5.490065051632368, -0.30119150968023467`}, {
             5.656854249492381, -0.3017338764407644}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.019999999999999993`, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.30426533906375197`}, \
{-5.589135266796396, -0.3040427058754678}, {-5.38989659562358, \
-0.30341048633563067`}, {-5.1896091321704585`, -0.3027974589849054}, \
{-4.988474874135042, -0.3022041298316123}, {-4.786516374217528, \
-0.3016309524995238}, {-4.712378800569222, -0.30142890919329746`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-4.688766895253652, -0.30136456088539504`}, \
{-4.583756185118113, -0.30107838061241216`}, {-4.3802611392551505`, \
-0.30054743631519515`}, {-4.176098069046994, -0.3000391417527905}, \
{-3.971266974493644, -0.2995534969251982}, {-3.7657678555951, \
-0.2990905018324183}, {-3.7442900369555487`, -0.29904462809333265`}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7206780978154406`, -0.2989941961591778}, \
{-3.5596007123513616`, -0.2986501564744508}, {-3.352765544762429, \
-0.2982324608512956}, {-3.1452623528283032`, -0.29783741496295285`}, \
{-2.9370911365489825`, -0.29746501880942244`}, {-2.820233890137134, \
-0.29726660430468893`}, {-2.776200103163856, -0.2971948166073827}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-2.7525881415442113`, -0.29715632234036476`}, \
{-2.703209997784642, -0.29707582180926334`}, {-2.4718129090422893`, \
-0.2967221961316417}, {-2.239881322092299, -0.2963992887687829}, \
{-2.007415236934671, -0.29610709972068705`}, {-1.8081092913592975`, \
-0.2958834407452693}}]}, 
           {Arrowheads[{{0.019124695779507116`, 1.}}], 
            ArrowBox[{{-1.7844973132287063`, -0.2958569436389184}, \
{-1.7744146535694059`, -0.29584562898735406`}, {-1.7449510951300065`, \
-0.29581454316328687`}, {-1.7154805697246103`, -0.295783959203015}, \
{-1.629557786024958, -0.29570068891860135`}, {-1.543593278253079, \
-0.29562190842390984`}, {-1.3184852648972234`, -0.2954309289112807}, \
{-1.0931168546232457`, -0.2952700929605675}, {-1.036736137439445, \
-0.2952345469768274}, {-0.9840885932351371, -0.29520266686342206`}, \
{-0.9434475524337805, -0.29517850127565015`}, {-0.915714488216824, \
-0.29516203420884896`}, {-0.9020678987117425, -0.2951538679179773}, \
{-0.8948527757099467, -0.2951494996020166}, {-0.8907520900679631, \
-0.29514700426474827`}, {-0.885526471700618, -0.29514381150637387`}, \
{-0.8813532402468378, -0.29514125000208313`}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-5.656854249492381, -0.8978776829815154}, \
{-5.5040256504162475`, -0.8963951846470526}, {-5.305107729920807, \
-0.894530600384229}, {-5.086170907887096, -0.8925567721165673}, \
{-4.86632842499487, -0.8906596803810349}, {-4.712412774261683, \
-0.8893904458998896}}]}, 
           {Arrowheads[{{0.019999999999999997`, 1.}}], 
            ArrowBox[{{-4.688801584047623, -0.8891957409649606}, \
{-4.6455802812441265`, -0.8888393251776322}, {-4.4239264766348665`, \
-0.887095706506359}, {-4.394423402722376, -0.8868691931078041}, \
{-4.364906389061274, -0.8866441032152896}, {-4.194797882267856, \
-0.8854062947929657}, {-4.024241147861241, -0.884215795317732}, \
{-3.866594738730969, -0.8831377352353947}, {-3.7443468908837567`, \
-0.8823362730040797}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-3.7207354053113337`, -0.8821814750731158}, \
{-3.708652908176651, -0.8821022616940343}, {-3.550415656198287, \
-0.8811093746936507}, {-3.3918829827958787`, -0.8801590742342439}, \
{-3.2330548879694243`, -0.8792513603158141}, {-3.073931371718925, \
-0.878386232938361}, {-2.91451243404438, -0.8775636921018849}, \
{-2.776270624159446, -0.8768885975515521}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-2.75265890991136, -0.8767738799632411}, \
{-2.594788294423154, -0.8760463700518631}, {-2.434483092476473, \
-0.8753515888383177}, {-2.273882469105746, -0.8746993941657489}, \
{-2.1129864243109746`, -0.874089786034157}, {-1.9517949580921576`, \
-0.873522764443542}, {-1.8081866055831595`, -0.873056390643317}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{-1.784574732292411, -0.8729812533584802}, \
{-1.6285257613823865`, -0.8725164808852426}, {-1.4664480308914334`, \
-0.8720772189175582}, {-1.4583791215041635`, -0.8720565498847286}, \
{-1.450309937422151, -0.872036000490645}, {-1.4422404751797913`, \
-0.8720155706074061}, {-1.434170730627178, -0.8719952601956502}, \
{-1.4261007025845076`, -0.8719750688184238}, {-1.4099600738196076`, \
-0.8719349231071503}, {-1.3938182864799442`, -0.8718952508548965}, \
{-1.3776753188998772`, -0.8718560501718827}, {-1.2161746406032865`, \
-0.8714893300896159}, {-1.0545329382731183`, -0.8711674584065843}, \
{-0.8927714953984489, -0.8708910399170563}, {-0.840097596262224, \
-0.8708199825378413}}]}, 
           {Arrowheads[{{0.008263164309112005, 1.}}], 
            ArrowBox[{{-0.8164856247489644, -0.8707881298585952}, \
{-0.647877797756248, -0.8705606769740035}, {-0.5878856521724662, \
-0.8704954494913155}, {-0.5315150331603793, -0.8704393852632973}, \
{-0.48322830895722646`, -0.8703950358800656}, {-0.4504924497431447, \
-0.870366675766215}, {-0.4262663269082932, -0.8703465415828894}}]}}, 
          {RGBColor[1, 0, 0], 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{0.8811228708709246, 0.2941680955514091}, {
             0.8864706803105166, 0.2941713689285067}, {0.8931270601289114, 
             0.29417541911083134`}, {0.8983703440564222, 
             0.2941785925319666}, {0.9064435873345345, 
             0.29418344837596627`}, {0.9242114242770154, 
             0.29419400700541515`}, {0.9588611182693939, 
             0.29421449566809665`}, {1.012085334568911, 0.2942462526835609}, {
             1.0396681809265906`, 0.2942628227151675}, {1.068048009922284, 
             0.29428023892713223`}, {1.133425217446019, 0.2943239400478827}, {
             1.1987816921792005`, 0.2943701380090611}, {1.4124359362325039`, 
             0.2945342804931489}, {1.6256946300877133`, 
             0.29472438052279515`}, {1.8256022754545933`, 
             0.2949272881768907}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{1.8492142548656674`, 0.2949525765588512}, {
             2.05102536720385, 0.2951824532187631}, {2.2630974104647774`, 
             0.2954504258850847}, {2.474773903527611, 0.29574435609696476`}, {
             2.68605484639235, 0.2960642438544033}, {2.793693083577345, 
             0.2962407671227178}}]}, 
           {Arrowheads[{{0.02, 1.}}], 
            ArrowBox[{{2.817305044823208, 0.2962794899844019}, {
             2.896940239058995, 0.29641008915740025`}, {3.107289018685087, 
             0.2967804547016985}, {3.3169601224281653`, 
             0.29717390318304093`}, {3.5259535502882295`, 
             0.29759043460142753`}, {3.734269302265281, 
             0.29803004895685825`}, {3.761783015187137, 
             0.2980913600646972}}]}, 
           {Arrowheads[{{0.020000000000000004`, 1.}}], 
            ArrowBox[{{3.785394949560363, 0.298143976513039}, {
             3.9419073783593186`, 0.29849274624933314`}, {4.148867778570343, 
             0.2989785264788522}, {4.355150502898355, 0.29948738964541544`}, {
             4.560755551343353, 0.3000193357490228}, {4.729871776648559, 
             0.3004766621897255}}]}, 
           {Arrowheads[{{0.019129572417359932`, 1.}}], 
            ArrowBox[{{4.753483683312434, 0.30054051383502633`}, {
             4.765613485071002, 0.3005733154130811}, {4.9696548652469685`, 
             0.3011482792609969}, {5.172856375083512, 0.3017437592148364}, {
             5.375194697792892, 0.3023592871966659}, {5.576525404080755, 
             0.30299437170546706`}, {5.656854249492381, 
             0.303256872596937}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(inc\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(inc\\)]\\)}\"", 
           TraditionalForm]}}], {972., -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
      GraphicsBox[{
        {Thickness[0.007], CircleBox[{0, 0}]}, {{}, {
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAJQ4wg7MX8D8uBp4P0JcsP/joMqsC
APA/NnnduoeHLD8ofUdLOazvPz5Sxbmdaiw/f+KXME057z8chlPZnEIsP665
HQII5e4/WX3yfhIlLD8au7fDWIDuP8ZQFA2fASw/Rg/ecDIX7j+UML0LkNwr
P37hKF7xguw/SXiMAHxOKz9g36nNEQfrP89YjsaaySo/NWP5Cw7P5T9HW7YQ
4vooP+pkGSi3GN8/8MwYnhraJj9BoJhhcwTVPwKnPuxvLCU/ipkfnR3vxT/I
zuAT7ocjP0mFMMK/0qM/ZL1/f2AqIj/wu0I0pYyTP6pyRY/+9iE/AF3QOkcj
Gr96n/7FsMQhP+ZIiqjiZp+/llyeBat2IT/x5ERl/dSuv1YTeLHRKiE/BF/B
G3L0x7+jPecTkc8fP7g+QPL0FdO/T8lqJM+iHT/WNcFbza/Uvwvauf7PJh0/
Mkqdjw==
             "]]}, 
           {Arrowheads[{{0.009693006554300112, 1.}}], 
            ArrowBox[{{-0.35645552723275775`, 
             0.00010875042546070756`}, {-0.3969597581126815, 
             0.00010575864006676729`}, {-0.5316206387438911, 
             0.00009593519804927248}, {-0.6484692112141531, 
             0.00008749044766247896}, {-0.750911742638166, 
             0.00008012591945596369}, {-0.8415144684790424, 
             0.00007361460024970806}, {-0.886816920925812, 
             0.00007034596208606002}, {-0.9293589244628533, 
             0.00006726511058996722}, {-0.9674478625939843, 
             0.00006451931132239485}, {-1.0000017117658457`, 
             0.00006225041158392587}, {-1.000563831420901, 
             0.00006221242183877403}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.02, 1.}}], ArrowBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAPezXyVpA5j8NUjHTfXXnPyC6oR+f
4uU/dyNWyJBY5z8ChY/W3zXlP/ByYsvfIuc/c4XTRr+95D+M+x0jQP3mPz50
Xjw0HuQ/NQZHV9LK5j9oTW7TJl7jP3wC8OuvjeY/g+wLeU2Z4j9ztjj2/07m
Py2YMOnzIOE/XpgB/LHX5T/4Hi01VXvfP5Ncn53FZ+U/YQjCaN7a3D+oYYxs
cf7kP6sxb7/6gdM/bi50cr+L4z9/h9eZqbfRP6+Bb552ReM/6TXLqHT6zz+P
sH9R3gHjP8ia/cXDKMs/azWFCFKk4j8aj40El4vGPzyQyiBCS+I/lGWojEeT
tT/A27FpnGnhP6DlbLou7V0/UWybJnWh4D+8o6OpIreyv6qhihUa298/Y2md
oaPUyL8Ycoyt157dPxx3FYtrMtO/y2XBKUiw2z9MKwU+eDnZv/eMDXUI/tk/
4S224Myk3r+NmPb0onvYP7/wn99XhOK/f1iC6me51j+62MVD
             "]]}, 
           {Arrowheads[{{0.00032356356482446104`, 1.}}], 
            ArrowBox[{{-0.6106894930664141, 
             0.3462497568267722}, {-0.6314197644382454, 
             0.34054434586521853`}}]}}, 
          {GrayLevel[0], 
           {Arrowheads[{{0.019387909969850875`, 1.}}], 
            ArrowBox[{{0.6538336575733757, -0.7088310704135371}, {
             0.6148621614417142, -0.6966695309765374}, {
             0.5705354545340942, -0.6827837047473412}, {
             0.5284669182105721, -0.6696697997276015}, {
             0.3792281552371088, -0.62368634842476}, {
             0.2542675214756867, -0.5858721834532428}, {
             0.22783381098241173`, -0.5779466669345276}, {
             0.20228256900074784`, -0.5703087346179757}, {
             0.16589012193127448`, -0.5595239106688279}, {
             0.13103250347967174`, -0.5492420164885587}, {
             
             0.00761120187923426, -0.5131165658219252}, \
{-0.09957611752331558, -0.4822371080458169}, {-0.19455431835649956`, \
-0.45524914583230414`}, {-0.30941227735460913`, -0.4230888619257848}, \
{-0.41079696931069837`, -0.3950558838909669}, {-0.5013019808568796, \
-0.3702883705109291}, {-0.5828895157147559, -0.34815232270642754`}}]}}}}},
       Frame->True,
       FrameLabel->{{
          FormBox["\"y/R\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z/R\"", TraditionalForm], 
          FormBox[
          "\"{\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(z\\), \
\\(sp\\)]\\),\\!\\(\\*SubsuperscriptBox[\\(S\\), \\(y\\), \\(sp\\)]\\)}\"", 
           TraditionalForm]}}], {1360.8000000000002`, -576.}, 
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 360.}]}}, {}},
  ContentSelectable->True,
  ImageSize->1050,
  PlotRangePadding->{6, 5}]], "Output",
 Editable->False,
 CellChangeTimes->{
  3.532430720466063*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Exact", "\[Equal]", "1"}], ",", 
    RowBox[{"gnET", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        RowBox[{"gnTME", "[", 
         RowBox[{"n", ",", 
          RowBox[{"ArcSin", "[", 
           RowBox[{"NA", "/", "nmed"}], "]"}], ",", "f", ",", "wa", ",", 
          RowBox[{"2", 
           RowBox[{"\[Pi]", "/", "\[Lambda]"}]}], ",", "n1", ",", "n2", ",", 
          "d", ",", "ds", ",", "z0"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "Nmax"}], "}"}]}], "]"}]}], ",", "0"}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.53315052900491*^9, 3.533150552410561*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"P2", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"EHVi", "[", 
           RowBox[{"r", ",", 
            RowBox[{"90", "*", 
             RowBox[{"\[Pi]", "/", "180"}]}], ",", 
            RowBox[{"0", "*", 
             RowBox[{"\[Pi]", "/", "4"}]}]}], "]"}], "\[LeftDoubleBracket]", 
          "1", "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
         "\[RightDoubleBracket]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", 
        RowBox[{"R", "*", "1.1"}], ",", "1000", ",", "10"}], "}"}]}], "]"}], 
    ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"P2", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"EHVi", "[", 
           RowBox[{"r", ",", 
            RowBox[{"0", "*", 
             RowBox[{"\[Pi]", "/", "180"}]}], ",", 
            RowBox[{"0", "*", 
             RowBox[{"\[Pi]", "/", "4"}]}]}], "]"}], "\[LeftDoubleBracket]", 
          "1", "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
         "\[RightDoubleBracket]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", 
        RowBox[{"R", "*", "1.1"}], ",", "1000", ",", "10"}], "}"}]}], "]"}], 
    ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.532892100115574*^9, 3.532892171269969*^9}, {
   3.532892417602191*^9, 3.5328924482514133`*^9}, {3.532892479388062*^9, 
   3.53289248130033*^9}, {3.532892547434635*^9, 3.5328925922547283`*^9}, {
   3.5328926236823683`*^9, 3.532892624198758*^9}, {3.532926006079576*^9, 
   3.5329260497498627`*^9}, {3.532926275528619*^9, 3.532926288382082*^9}, {
   3.5329285680681763`*^9, 3.532928634105356*^9}, {3.532932438474296*^9, 
   3.532932438602133*^9}, {3.5329324692014837`*^9, 3.532932519863338*^9}, 
   3.5329326534057426`*^9, {3.5329327257774763`*^9, 3.532932735472752*^9}, {
   3.5329330682632732`*^9, 3.5329330683822002`*^9}, 3.532935226245676*^9, {
   3.532939684754094*^9, 3.532939684841773*^9}, {3.53294383418582*^9, 
   3.5329438401865187`*^9}, {3.532945654533513*^9, 3.532945674772254*^9}, {
   3.533025956245741*^9, 3.533025963021494*^9}, {3.533026079312158*^9, 
   3.533026080281681*^9}, {3.533123510620707*^9, 3.533123511877748*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw10g001XcYB3As4ZKQvDalmV0ZsyIvY31LL162xDFzNzMqm0oixSW53i6X
cBF5aYmOl9vR6GQzS+blGjq3F8uZXU2ll3mbg+P9jNXafs/uOffc8znPfX7f
//d/fqYHT/iEKCkoKAS//v77+98nEbCufKs7Trl+J/MexLhWdVh61pE98Hl3
42pB8LdkL5RMLA+qeFxjhg8kYzIFDZVa5jZflBmWfFJ18SrNP8Vc7R2T39Ul
NOfhhs54UV1ANc0DINa736lfUEnzQHB7uy9NN11hLg9C3Qd1zvcelDMPBaM4
4kRmft8l5k2HsN++MTtCo5Q56DCGzKO92oIu0H4IPBasvXYM5dP+V3i5WzU1
fKuY9kPBH2xB93sZtH8EpdlHHR/LUmj/KByGuTbu3ATaPwZ/3znpkY3RtH8c
NvKPLzxfCaf9cDzcfllUfeow7Z+ArLZKbfOsP3NEBDgj5qb5Np7MWpHQup6s
VTrjwHw9Eos63q3N6abMB04iaH+//qREhXn6JG7a3Z15dUOHOTcK/PpgPWms
ObPNKXxYfftLdVdb5t5T6HWtOBbQ5kL5p/G4RiYT6rpSfjScti1bhtntpfxo
VBYZ3ObN76P8GLQeX7Vln4sb5cege5jzINiM5rl8WIsGfeL+2E35sSjw4phs
7dtJ+bHI/i3HeqTImfLjkDdQJOR9YUf5Z7A3TNk6YbcV5Z+BdCMEJU//7x+P
nv619ZHl1Hc6HgOlg4HN8a/A8s9ivF379J8GE8w2CViv3+kdf3WWuTcBXA9V
3dCnypQvgG3S/TypsS6zaiLynaZMnGUmzP6JsBePzMgbzJgliZBcFPOe7LFg
XkpEsE7Tuum8d5ndkhC3rqs4ZKc1c3ESHPm33CpsyaNJuOUXKBtJpP87JGNc
Wmg5F0rniZIRbbVYfNb7bWZ5MmKsxt93bNjEzE1Bu3HH90oGBsz8FLxUMbyy
smstc08KjM6r5cwKFZkNUiGp+OmXIuVp1j80Ff1Vfn0/3BtgbkqFQ/TD8jsL
cmZVIUpOchbOF9L78xcC7n3PON+tMEuEMM94R7Usle7fkhBvOFr0y2q0qH8a
nmRpVtbar6f+afhIXlHw6Bk972gaXgR+Y6exw5j6p7++z+oeZWs3UP90zEeU
aRq501yeDr1tk8tTmobUX4RV8Z0HPa/R+XwRQjZ8JlXO0Kb+Ing2iQSHHDjU
PwNcXqHJzWZ6H6EZuKwyVpo7PEf9M9BV8WJszYYX1D8TAWlNDxf/vkv9M8Ez
Eio6KXRQ/0wkzXP8041+ZV7KxF+LB0Q1JqPMbudw/c2Wyu0x88zF56Bkc0/6
tbYC9T+Hdr/VFYa+dP8csmAxoC63GFSj/llo/FmiwTddQ/2zgOelgpYeTeqf
jR/tNwtcasn8bERFmfG2yDWofzbMwrrcpsR0nkEOwsQCcycnygvNQW9DziOu
Pz1PUw6U18ws3BhdoP5iTOq2Tih6TuAfBoPTQw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200., 0},
  Frame->True,
  PlotRange->{{33., 993.}, {9216.453171384683, 2.6022640356961197`*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.532892142277568*^9, 3.5328921741341267`*^9}, {
   3.532892443507032*^9, 3.532892499280987*^9}, {3.532892568387742*^9, 
   3.532892642705612*^9}, {3.532925993175476*^9, 3.5329260508841*^9}, {
   3.532926264121419*^9, 3.532926289278162*^9}, {3.53292856224367*^9, 
   3.532928636921164*^9}, {3.532932432102071*^9, 3.532932441225712*^9}, {
   3.532932471816942*^9, 3.5329325167639017`*^9}, {3.5329326505993423`*^9, 
   3.532932655909343*^9}, {3.532932719253975*^9, 3.532932731165173*^9}, 
   3.53293294229412*^9, 3.532933074341196*^9, {3.5329352217691813`*^9, 
   3.532935228773191*^9}, {3.532939682555365*^9, 3.532939687373418*^9}, 
   3.532945622248913*^9, {3.532945664320332*^9, 3.532945679402759*^9}, 
   3.5330259667131643`*^9, {3.533025999729939*^9, 3.533026083744137*^9}, 
   3.533027212773075*^9, 3.533123681420465*^9, 3.53312404018853*^9, 
   3.533124218305552*^9, 3.53312468163663*^9, 3.533124732275666*^9, 
   3.533126754750021*^9, 3.533149838855138*^9, 3.5331498819523487`*^9, {
   3.5331499953607264`*^9, 3.533150083663909*^9}, {3.5331501310471687`*^9, 
   3.533150151070601*^9}, 3.533150454744238*^9, 3.533150494034857*^9, 
   3.5331506255826607`*^9, 3.533150729923133*^9, 3.533150764149706*^9, {
   3.533150845350398*^9, 3.533150872920323*^9}, {3.533152051762888*^9, 
   3.5331520777598658`*^9}, 3.533197345775446*^9, 3.533202471002026*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJw1zw0s3Hccx3GpNSWmp0+pEk13q2CG1tZM23U+Og93bT30JqPpDYfjMO48
HOfhuAcPh/NYbU09tZ7qaYgpq7bM2qpMO0XMGCmTjW5T6zpluu7p/90l/1xe
+eWbT96vBYp5wk06OjqCf75////7KYDaJDvOuLrNibELVJkYLtr3v0+gwmeu
6pPaT8meCJCUue3eRgYPA23rfZGhrYz7vcGperfBvrGF3n3QVBHaYznZTO9n
0DJh1HZ4tYne+XBfrW8Vbyb3++GS9abjy1saGVcHwEteaP7TXw2MHwkwKBV+
U/+knvG+IJSd/c5W+G0d44BgxBvyNof01dK9EOZlX+ycramh+xAYHhyyWNFc
oXsRNg6OddVLLtN9GE4NT+ku86vpPhxiFrvPrKqS7iMwEGLF8i4pp/tI3L9u
Wi0qL6P7KFz6rXfvj5+X0r0Yb4Ze7FpbvsBYIsH2qABbwbHzjI2i4W9Z0Cuv
P8e4PRqXXywEulgXM/aKwcai0R8nhgsZr8SgQqNyVO4oYFwYiyiWyRvrd7WM
D8RBmjbW9LIjh/FIHFTjP2t/H9XQvhSz3Y2Nn1lk0X48dip8qi+2ZtB+PITi
vJYiQTrtJ6DT393BCWraTwBvUTio66qifRmOLNlM64uVtJ+ID3Q8osO7FbSf
iGVu+51DpmRJEpq/DzbcapNG+8mYvskLsTqZSvvJ2Ou6cDc1W077KZjhLBYf
m0uh/RRwZ3vke06RC+WwHwrP5t9Opv1UmN4xHnzmTB5JRWdYwwP5UBLtp4GV
2bbh4kHWUyBsSHTOcySRsa8C911fGni4k68q4Knn2l/1pYzxmgI6tboRzvZk
jhLz7PDRkdIExqVKPOce2R3wPJ7xohLrtWlstQfZQQWZJqnDtkrKWKNCrkO3
4urjOMaTKjj63doVZ0+2VONp3+krjrJYxjI1IiJ1pQ9vxjC+p8af8QLB6itk
43Q0Lr6fGu0ZzViUjidHz+b+Uilh3JOOeqsaxaMlMfVnwOEtM0lVXRT1Z4B7
+vbb3rGR1J8Bt6YZ6z7vj6k/A+907vE1OxlB/ZmY6J9SmvuEU38mSt1uNOgn
hlF/Jkx5r0amtIuoPwvL7P1m11+EUn8WzB1zBkv45MksqJvnl1QPQqhfg6OV
7O3tXmSZBh0lQTNb54TUr4Frl8G1CDnZOBv56vZraa+TRdmYil0w030YTP3Z
4Ce2Dt1Sk/VyYOfs4Vh+mOybg1+1X493rgRRfw5M7AZrfRvIazk4s6Ncn80n
c3Kxq+bD2KeG5NJcND7jKDd6A6k/Fz8cmvXrE5IdtDi+f5uMZUDWaOH3cqxV
r0VA/VqYuJx3NuSSLfMwyi6auDEfQP15MOwUVT9OJN/LgzrrPU0xi2ycjy1f
8bRlXH/qz0cn1+KARupH/fkwktpMcOo+ov4CsNo8Byym+U5/A+zw32o=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{200., 5.*^7},
  Frame->True,
  PlotRange->{{33., 993.}, {7.564447036113515*^6, 2.6436662809273255`*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.532892142277568*^9, 3.5328921741341267`*^9}, {
   3.532892443507032*^9, 3.532892499280987*^9}, {3.532892568387742*^9, 
   3.532892642705612*^9}, {3.532925993175476*^9, 3.5329260508841*^9}, {
   3.532926264121419*^9, 3.532926289278162*^9}, {3.53292856224367*^9, 
   3.532928636921164*^9}, {3.532932432102071*^9, 3.532932441225712*^9}, {
   3.532932471816942*^9, 3.5329325167639017`*^9}, {3.5329326505993423`*^9, 
   3.532932655909343*^9}, {3.532932719253975*^9, 3.532932731165173*^9}, 
   3.53293294229412*^9, 3.532933074341196*^9, {3.5329352217691813`*^9, 
   3.532935228773191*^9}, {3.532939682555365*^9, 3.532939687373418*^9}, 
   3.532945622248913*^9, {3.532945664320332*^9, 3.532945679402759*^9}, 
   3.5330259667131643`*^9, {3.533025999729939*^9, 3.533026083744137*^9}, 
   3.533027212773075*^9, 3.533123681420465*^9, 3.53312404018853*^9, 
   3.533124218305552*^9, 3.53312468163663*^9, 3.533124732275666*^9, 
   3.533126754750021*^9, 3.533149838855138*^9, 3.5331498819523487`*^9, {
   3.5331499953607264`*^9, 3.533150083663909*^9}, {3.5331501310471687`*^9, 
   3.533150151070601*^9}, 3.533150454744238*^9, 3.533150494034857*^9, 
   3.5331506255826607`*^9, 3.533150729923133*^9, 3.533150764149706*^9, {
   3.533150845350398*^9, 3.533150872920323*^9}, {3.533152051762888*^9, 
   3.5331520777598658`*^9}, 3.533197345775446*^9, 3.533202474292745*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Axial Scans of the total field intenisty for various particle radii\
\>", "Title",
 CellChangeTimes->{{3.591328997360614*^9, 3.591329021143317*^9}},
 Background->RGBColor[1, 1, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RNearfieldScan", "[", "RR_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"R", "=", "RR"}], ",", "Itot", ",", "ItotT"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Exact", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"anL", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"aMie", "[", 
          RowBox[{"n", ",", 
           RowBox[{"k", " ", "R"}], ",", 
           RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", 
       SubscriptBox["a", "n"], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"bnL", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"bMie", "[", 
          RowBox[{"n", ",", 
           RowBox[{"k", " ", "R"}], ",", 
           RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", 
       SubscriptBox["b", "n"], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"cnL", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"cMie", "[", 
          RowBox[{"n", ",", 
           RowBox[{"k", " ", "R"}], ",", 
           RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", 
       SubscriptBox["c", "n"], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"dnL", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"dMie", "[", 
          RowBox[{"n", ",", 
           RowBox[{"k", " ", "R"}], ",", 
           RowBox[{"nParticle", "/", "nmed"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", 
       SubscriptBox["d", "n"], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Itot", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"EHVi", "[", 
            RowBox[{
             RowBox[{"Abs", "[", "z", "]"}], ",", 
             RowBox[{"ArcTan", "[", 
              RowBox[{"z", ",", "0.1"}], "]"}], ",", "0"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"-", "2000"}], ",", "3000", ",", "10.0001371"}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ItotT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Itot", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{
                RowBox[{
                "Itot", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "2"], "<", 
              SuperscriptBox["R", "2"]}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                "Itot", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                "Itot", "\[LeftDoubleBracket]", "i", 
                 "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "4", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "7", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "Itot", "]"}]}], "}"}]}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591253739284232*^9, 3.591253820269425*^9}, {
   3.591253858215629*^9, 3.591253921675706*^9}, {3.5912542575334253`*^9, 
   3.5912542713787317`*^9}, {3.591257044846673*^9, 3.591257065273264*^9}, {
   3.59125893841096*^9, 3.591258953853559*^9}, {3.5912671558254538`*^9, 
   3.5912671592899218`*^9}, {3.5912677178428087`*^9, 3.591267724813624*^9}, 
   3.591267968504882*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ItotTRT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"R", ",", 
       RowBox[{"RNearfieldScan", "[", "R", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "25", ",", "2000", ",", "25"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ITSave", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"ItotTRT", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "[", 
             RowBox[{"[", "j", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ItotTRT", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"ItotTRT", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "[", 
             RowBox[{"[", "j", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{
             RowBox[{"ItotTRT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "ItotTRT", "]"}]}], "}"}]}], "]"}], ",", 
     "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MaxVT", "=", 
    RowBox[{"Max", "[", 
     RowBox[{"Last", "/@", 
      RowBox[{"N", "[", "ITSave", "]"}]}], "]"}]}], ";", 
   RowBox[{"MinVT", "=", 
    RowBox[{"Min", "[", 
     RowBox[{"Last", "/@", 
      RowBox[{"N", "[", "ITSave", "]"}]}], "]"}]}], ";", 
   RowBox[{"NContT", "=", "7"}], ";", 
   RowBox[{"ContoursTT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"MaxVT", "/", 
       RowBox[{"Exp", "[", 
        RowBox[{"n", "/", "2"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "NContT"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"|", 
    RowBox[{
     SuperscriptBox["E", "inc"], "+", 
     SuperscriptBox["E", "sca"]}], 
    SuperscriptBox["|", "2"]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListDensityPlot", "[", 
    RowBox[{"ITSave", ",", 
     RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ColorData", "[", "\"\<PigeonTones\>\"", "]"}], "[", 
         RowBox[{"1", "-", "#"}], "]"}], "&"}], ")"}]}], ",", 
     RowBox[{"LabelStyle", "\[Rule]", "Larger"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<R\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<z\>\"", ",", 
          "\"\<Total Field Intensity: |\!\(\*SuperscriptBox[\(E\), \(tot\)]\)\
\!\(\*SuperscriptBox[\(|\), \(2\)]\)\>\""}], "}"}]}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"ITSave", ",", 
     RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "2"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     RowBox[{"Contours", "\[Rule]", "ContoursTT"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ColorData", "[", "\"\<SolarColors\>\"", "]"}], "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"n", "-", "1"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"NContT", "-", "1"}], ")"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "NContT"}], "}"}]}], "]"}]}]}], "]"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.5912681661451893`*^9, 3.591268187082221*^9}, {
  3.591268220994265*^9, 3.591268338537874*^9}, {3.5912683849930773`*^9, 
  3.5912685354466057`*^9}, {3.591268565644698*^9, 3.5912686313228407`*^9}, {
  3.5912780101003723`*^9, 3.59127801408911*^9}, {3.5912781658175783`*^9, 
  3.591278169428657*^9}, {3.591278637670937*^9, 3.591278640121262*^9}, {
  3.591278877296286*^9, 3.591278879056405*^9}, {3.591329065534931*^9, 
  3.591329066208251*^9}}],

Cell[CellGroupData[{

Cell["Export", "Subsubsection",
 CellChangeTimes->{{3.5988719944639606`*^9, 3.5988720009403057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\</Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PSLensesB_zR.dat\>\"", ",", "ITSave", ",", 
   "\"\<Table\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.591278053802684*^9, 3.591278070878942*^9}, {
   3.591278661431243*^9, 3.591278662262526*^9}, 3.591291815178913*^9}],

Cell[BoxData["\<\"/Users/markusselmke/Documents/Igor \
Pro/MathematicaTractorBeam/PSLensesB_zR.dat\"\>"], "Output",
 CellChangeTimes->{3.591278664089477*^9, 3.591278897449089*^9, 
  3.591301288958274*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1328, 618},
WindowMargins->{{60, Automatic}, {Automatic, 74}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 20, \
2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 2141, 58, 263, "Title"],
Cell[2711, 82, 565, 15, 97, "Subtitle"],
Cell[CellGroupData[{
Cell[3301, 101, 189845, 3117, 478, "Input"],
Cell[193149, 3220, 608616, 10464, 283, "Output"],
Cell[801768, 13686, 610559, 10458, 283, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1412364, 24149, 617, 10, 97, "Subtitle"],
Cell[1412984, 24161, 223, 4, 29, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1413232, 24169, 3579, 95, 87, "Input"],
Cell[1416814, 24266, 907, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1417758, 24286, 174, 2, 29, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1417957, 24292, 12420, 318, 494, "Input"],
Cell[1430380, 24612, 181, 5, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1430622, 24624, 334083, 5616, 300, "Subtitle"],
Cell[1764708, 30242, 80710, 1923, 1650, "Input"],
Cell[1845421, 32167, 629, 15, 52, "Input"],
Cell[CellGroupData[{
Cell[1846075, 32186, 1996, 42, 97, "Input"],
Cell[1848074, 32230, 579, 10, 28, "Output"],
Cell[1848656, 32242, 579, 10, 28, "Output"],
Cell[1849238, 32254, 579, 10, 28, "Output"],
Cell[1849820, 32266, 579, 10, 28, "Output"],
Cell[1850402, 32278, 579, 10, 28, "Output"]
}, Open  ]],
Cell[1850996, 32291, 537, 14, 45, "Input"],
Cell[1851536, 32307, 6924, 188, 272, "Input"],
Cell[1858463, 32497, 2123, 62, 100, "Input"],
Cell[1860589, 32561, 509, 14, 51, "Input"],
Cell[1861101, 32577, 7166, 196, 275, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1868316, 32779, 148, 2, 108, "Title"],
Cell[1868467, 32783, 349, 8, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1868841, 32795, 423, 11, 28, "Input"],
Cell[1869267, 32808, 1490278, 25293, 527, 1206413, 20637, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3359582, 58106, 405, 9, 45, "Subsubtitle"],
Cell[CellGroupData[{
Cell[3360012, 58119, 423, 11, 28, "Input"],
Cell[3360438, 58132, 1361686, 23112, 527, 1097672, 18781, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[4722139, 81247, 792, 22, 35, "Input"],
Cell[CellGroupData[{
Cell[4722956, 81273, 2926, 67, 46, "Input"],
Cell[4725885, 81342, 3277, 56, 223, "Output"],
Cell[4729165, 81400, 3239, 55, 223, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4732465, 81462, 193, 4, 108, "Title"],
Cell[4732661, 81468, 4715, 117, 196, "Input"],
Cell[4737379, 81587, 4868, 129, 167, "Input"],
Cell[CellGroupData[{
Cell[4742272, 81720, 101, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[4742398, 81725, 341, 7, 28, "Input"],
Cell[4742742, 81734, 204, 3, 28, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
