(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1243568,      24957]
NotebookOptionsPosition[   1238117,      24785]
NotebookOutlinePosition[   1238553,      24802]
CellTagsIndexPosition[   1238510,      24799]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Radiation Forces, Examples",
  FontSize->50],
 StyleBox["\n",
  FontSize->12],
 StyleBox["Implemented by ",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Markus Selmke (selmke@zr.uni-leipzig.de, markus.selmke@gmx.de)\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["If any of this code shall be used, please ",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["cite the appropriate Journal Article",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" reference:",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\"Nano-lens diffraction around a single heated nano particle\", \
Optics Express, Vol. 20, No. 7, pp. 8055-8070, ",
  FontSize->12,
  FontColor->GrayLevel[0]],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 StyleBox[", M. Selmke, M. Braun, F. Cichos, (early version: \
arXiv:1109.2772v1)",
  FontSize->12,
  FontColor->GrayLevel[0]],
 StyleBox["\n",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 StyleBox["\"Photothermal Single Particle Microscopy: Detection of a Nanolens\
\", ACS Nano, ",
  FontSize->12,
  FontColor->GrayLevel[0]],
 StyleBox["2012",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],
 StyleBox[", 6 (3), pp 2741\[Dash]2749 + Suppl., M. Selmke, M. Braun, F. \
Cichos, (early version: arXiv:1105.3815v1) ",
  FontSize->12,
  FontColor->GrayLevel[0]]
}], "Title",
 CellChangeTimes->{{3.4977910729476*^9, 3.497791085493401*^9}, {
  3.4978102134039383`*^9, 3.497810253191922*^9}, {3.554278519147341*^9, 
  3.5542785311826763`*^9}, {3.554452113235936*^9, 3.554452115897767*^9}},
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[{
 "Paper Check: Gaussian Radiation Pressures, d=10\[Mu]m sphere, Fig.1,2,3\n",
 StyleBox["\"Radiation pressure forces exerted on a particle arbitrarily \
located in a Gaussian beam by using the generalized Lorenz-Mie theory, and \
associated resonance effects\", K.F. Ren l, G. Ghan, G. Gouesbet, inverse \
z-axis (different sign convention)!\n",
  FontSize->14],
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJztfYdbVNfe9fs83z/wPe/33Pe99ybXXJPYsNzEmHij0WjUG3tvqFijxqhX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     "], {{0, 224}, {223, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->{206., Automatic},
   ImageSizeRaw->{223, 224},
   PlotRange->{{0, 223}, {0, 224}}]], "Input"],
 " \nNote: ",
 StyleBox["negative x corresponds to situation depicted. A negative force \
will result in a force directed towards the beam axis, i.e. trapping. x is \
the position of the beam-waist viewed from the particle!",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.4977848742107267`*^9, 3.497784925892029*^9}, {
  3.497784963815771*^9, 3.497784967404561*^9}, {3.497810549577422*^9, 
  3.4978105640790873`*^9}, {3.4981565475082483`*^9, 3.498156566417741*^9}, {
  3.49819423391671*^9, 3.4981942349131536`*^9}, {3.498200411061678*^9, 
  3.498200413625567*^9}, {3.498287182362884*^9, 3.4982871827531643`*^9}, {
  3.554279229676455*^9, 3.5542792363777103`*^9}, {3.55452335958846*^9, 
  3.5545233811708527`*^9}, {3.554524256205166*^9, 3.554524323726712*^9}, {
  3.554524354181527*^9, 3.5545243589497128`*^9}},
 Background->GrayLevel[0.85]],

Cell["\<\
Test parameters : R = 5000; nParticle = 1.5; nmed = 1.0; \[Lambda] = 500; w0 \
= 5000; nmax = 70; jmax = 10;\
\>", "Text",
 CellChangeTimes->{{3.4977848105638*^9, 3.497784868078752*^9}, {
  3.497784942116777*^9, 3.4977849433542337`*^9}, {3.554523402338562*^9, 
  3.5545234093937473`*^9}, {3.554524390358423*^9, 3.554524390572575*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{
        RowBox[{"CprG", "[", 
         RowBox[{
          RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", "500",
           ",", "1", ",", "0", ",", "5000"}], "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{
        RowBox[{"-", "4"}], "w0"}], ",", 
       RowBox[{"4", "w0"}], ",", 
       RowBox[{"8", 
        RowBox[{"w0", "/", "100"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{
        RowBox[{"CprG", "[", 
         RowBox[{"0", ",", 
          RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", "500", ",", "1",
           ",", "0", ",", "5000"}], "]"}], "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{
        RowBox[{"-", "4"}], "w0"}], ",", 
       RowBox[{"4", "w0"}], ",", 
       RowBox[{"8", 
        RowBox[{"w0", "/", "100"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"z0", "/", "l"}], ",", "s", ",", "500", ",", "0", ",", "0",
            ",", "5000"}], "]"}], "[", 
         RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{
         RowBox[{"-", "3.2"}], " ", "l"}], ",", 
        RowBox[{"3.2", "l"}], ",", 
        RowBox[{"6.4", 
         RowBox[{"l", "/", "100"}]}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTz", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fz\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498283478331419*^9, 3.498283562443993*^9}, {3.498283720102106*^9, 
   3.498283729449223*^9}, {3.554451687787977*^9, 3.554451689180066*^9}, {
   3.5544517262620068`*^9, 3.554451734406662*^9}, {3.554451780361518*^9, 
   3.554451789290182*^9}, 3.554451828609294*^9, {3.5544518618807583`*^9, 
   3.554451870446776*^9}, {3.554451907681484*^9, 3.55445192056098*^9}, {
   3.554452301097803*^9, 3.55445230261423*^9}, {3.554462357249023*^9, 
   3.554462362379797*^9}, {3.5544625041879463`*^9, 3.554462504490073*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "25"}]}], ";", 
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "nm"}]}], ";", 
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "nm"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"CPrxT", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"CPryT", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"CPrzT", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}], 
        RowBox[{"dz", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4982863505931997`*^9, 3.498286352524819*^9}, {
  3.498286389775704*^9, 3.4982863920247726`*^9}, {3.554451692262846*^9, 
  3.554451693885708*^9}, {3.554451961168315*^9, 3.554451961465105*^9}, {
  3.554462525937138*^9, 3.554462543192112*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJwt1QtMk1cUAOAGmIi4CegccZaJA3G6SXmODP5x1C2GiYAkIDKYEYEyycBB
UBgYg5uk9UUHiCAwFiO+Iw9FYCCcljcUaXkpMiYuW8aIYubQVdC5M85t0jRf
bu/9z7n33PM7xiSHxpnJZLI4+v7/O/9RDWJJf19Rcdtg47ydBrFScTLSy2mK
jQNYOq2OtPxZ1jTvqAHMrB718fN+k20yYmyGcWDbwnXsAiN+3Ty+23udP1th
xP2Xi4oK3UPZegOuqHPNC2mMZScYcGR965Oziw6wLQyYmLrm9v05FRv6MaLg
lPaNpDPs9Nv4oHrI89iWK+yqPlRKBwOfpTeyJ/UY5Rn93PxVD3uVHt+tC5q6
8+soO6IXL2xNc/vNZ5Kt6cHtq70+ynR4xu7qxisa2bnMm+a3eIO60e6m4t8S
Z1u2TxfqkuUvtXI5e18n/uX6WYPScS37YgfOvAhs7jviwZ5ox2u/XNhrf+dj
tn07Tj+3Dcrr2sIOacPp4MHm3sntbFUr/tF21bI3PJKNOrz3KjVpx1QM26TF
+tjk9+TqvWyFFr1tPvkyfkMKOwFxY/zj2L7wdDa04OJvRp5GDR9iV93CPK3j
B2E7vmOvakK73PROG6WarfkJLx/etrBMlivyb8CsWq9ZOJgn8q3DR63u39ed
OCXyq8WpipVj7ieLRD438IfNS18LCy8R8ddg1ltWZqcby0S81Wij121IKSgX
8VVi/gqrNEP0jyKeq5gVkKFUq4Vll/Dw1myVw2bhiQo0VCy4ftRazMezmF3m
t3L4XKlYrxzXDhtNf39RLOYX4+sjd53zQ0S8mIct+DBQU6QR42pMapzICKjP
Ec7AA66/HwtedkBYJptZ/HlhSLDWV4zDqMVODY1LYj6cVgRk0XxJrA+aPZ8G
0fpivBiWXNvlQs+XRHzwT+rxWYpP/P8sjN9d70DxSyI/8FetqaX8xPxLEL27
Qk35S2J/YPbIlQTaH7FeJQxJm/bT/klif6HexcON9lesXwPm00oL2n9JnA+M
hYVa0vmI59XCUTvFOJ2fJM4X3m6wzafzFc9vALOOe3N0/pKoD7Bqfsea6kPE
0wSO94e6qX4kUV9g67DElepLxNcCN7InTVR/7ASEnXGhSqpPEa8WYr5dmkj1
yzZpITJN/j7Vt4hfB2E5e/ZR/bNVrdC8SbmI7ofIpw12VV9Huj9s+3YYaSgM
ofsl8muHdJj5iu4f+2IHeGQlIN1PkW8nzIxMNdL9Zft0QXtdsEwnl4v8u8F6
+3JZqbMtu6sbXj5wP0/9QexHD2THV/lR//Cbd0QvpKS6eVJ/Ya/Sw8Mc/0fU
f9iTenAcSnlB/Yld1QeSW0Uw9S92+m04tHruQ+pvbOiHNbrzbdT/2BYG2Ohi
Y6T+yE4wwJgp7Sn1T7beAP5/lhdQf2UrjLCgp/kM9V92gRGO5+TGUX9mm4zQ
mzg1TP2bHTUAj5fH+FJ/Z+MALLPMjaL+z3YahD25NdH0fuD7oBqEwCeuJfT+
8P0Puhcwvw==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw11X9M1HUYB/AveU2LzcNdc/SDIjzDYE7KkSRcPl1tmaCma4YM/nHRjn4Y
MAbHbCuX2MFKLgWJsUFCKaibJ4oGYTyHHL885I5DXbn0htmOP3Ipa54YreL9
9rbb7bXP9/v5PM/n83yee3bHx1sLHzIMo/C/7/+/8x9XSONSt5R+W3L2x3lb
Q2q3fxZanj4O64Te6Klwr3vzNzh/Qtf4pmXaew+OBtX4aLGp+09z77zrgnom
3Vqf+c4yOC2ocUWDSXPXX4L9Af1pzlWy4MMNsCOgFUUL3v5jrAA2BfTqmjTj
y/eLYRlX76Fti0wdu2HnRS3wpaz85qv9sGdM/3nK3nZmURsc8eu6R6I7B5ac
ghP9mpLc9nBCez+ce0Fr6++kPhcKwu5RrR0tPFx2KAwPj2jV01PmDZtuwcaI
DpnX92+7OwtnDKskzy77defCc/MuHtJHU5rtsTcscPugHlxxP7dvVyIc9qlz
y6sL4z0pcLxPYy4fjVnxRDr81oDOJGxv2pwjsOu8phv3L9U2rIe1Xy23bzt+
eWYrHPVqQX9qXunjeXCaV0uPxyXF5O+AHapJN48dq88qgqVPp5s3tbTdKYY9
57RjxmQxv1IOJ/bqxnez67L3fgK7e/SL1R90fnp9N2x0a3XF4o2TU1XM96xa
c/7e7lpVw/y69LGEmD2VTfuYz2lNPtkyd8D5NePv1NOrm69YKw8w3pMaPnLr
ZmhlPeM7oT2NmjdbdpDxHNfySM3z7lUNXL9Drz1ZZRl7jQ5/ry9cvlvubOHz
2qqe17MuHX35wXwt2loVW3rFwvWMRr239trvsWvdfH6/Ls0Kfz65p5rj1Tr5
197vIg0P8q1U9xvvNSXPlNCGcXXpqWn7rpwfOC4ct/F94fs2zi+cn+ONwvVt
jE8YH59vFcZvY37yIvLj+x3C/G3cH+H+cL4Twv2zcX+F+8v5O4X7b+P5CM+H
63UJz8/G85XlOF+u3y01OH8b60NcqA/G0yvZqB8b60uOoL4YX59EUH+wQ4X1
yXi9Uob6haNeYX0z/n5h/cOu88L7wXwGhPcHjvcJ7xfz80kF7h/cPii8n8x3
SHh/4Yxh4f1m/iPC+581z+ERYX+A3aOyD/0Dzr0g7C9wol9S0X/giF/Yn2DP
mLB/wc6Lwv4Gy7iw/8GmgPyM/gg7AsL+CfsDwv4KpwXFjP4L1wWlC/0ZjgaF
/RvOn5AM9PdM7P+ETKH/w9aQ8P8BdoVkCf4/Mv8FmHwp5A==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJwtlQtUjGkYx5PTdNfNpdSqVFR0O7Fl6pnmjSWpKMtGSqIlpKYiQ+kyKV1P
95rCTNPMhME62Tosq3mNJB20XUaJ0UrRjm5rW1mxa793vnO+853vvN/3Ps/z
f/7P77WOiguJVldTU4v+ev//1F8THvDpijOWmz/yCA6KhfdFRaMjhs6YF+P+
0iv+CPS/bsnuSnTC9MtPXQYFcdBCn7K5I1+JRzp2ht1NjAdx8VJ8cc1K3MF2
CW2zZEHByNaIirMr8Ls9L3/2lbMgwfv0p/R/HfHswZsautUJEFraXH04yhFb
mfSM6/6YCIy3b1aHtjpg9Moozw8lgS3DrHutvQM29J+zWOF4FHTK/eNd8u0x
1y3MRNP2GEyOntQ3H1+O9Svf5CxxTga5z5VLtODlOJVW+KXe/zjcrlBs+PP6
Mrw90a3V5yQb6pUGwy8WLsNX195ob8MnIBehzHa2Hf7sWKf5nVUKxFUlWDY9
t8XzdPyrPlanwrax+tt8H1uca+V0cL9zGnit7d1RILDBq03VFBJWOizl0j4k
a9jgWNGqc6zwDNCa8Cjfe2ApttAOi4VdmTC+LsZtc4c1Ftz7XjATx4GemprH
dGdrHGS+eMvdmiz4ZbLj0LISKxww0vftX4rTwCz8x8j2rSVGJxoOLffJAT2q
H0uwcshpk+edM9BH6f8NjpFzaRt354GQ0tsCG8qYMmxXoNJ3Md6HrB8ELChS
6WmGZzaF+o6YFqv0M8VxbXPthD4lKr0W4b0xj4TD6aUgoPRZiIM3OA5VKcrg
CKXHfNxIz3bdv7MC6FT9JlhDvYLLma4EGlWvMZZkTKKAa9XQRdVnhKWzCu+B
3BpVPQY42aN5Y2zaWVX++ljSdaBYnH8e4ql8dfD2wBLG7yF80KLy08LRGyQN
ByPrgE/lQ8MhZU/2NEcLwJOKPxevvxdrqBlaD51UvDl4dX/PH9wVQtX+n6UK
5hBP3CtU7Tcj5Vxr7PLbLFL9/146ctV46Ey1CDqp78ekFsN+Fh9uisCVWh+S
ShOUz7xlIrCi3rulcrc2fuB9EahR1yDgie75yk4RRJJ1pttLWcnWNyLYQv5n
cjSsgqPUxTBJ9mdeunvpqtJIDH4kPnMgVcFjf103JfkxN4dxsz5/jafKn5n0
ImIgK0ik8ssc9I5twgmsF4I3qR+NXsm/cOdhPQiJPshO5mOs95sA9Ih+iNck
kFnK6iCJ6IvqXMu9iy7z4TnRHwW0z1xkOPFgHekPqg1yjwDDcyAn/UOzOmMG
Hrq1oEP6i7bXji+S2HCBQfqP6K+SAiN2VUEC8Qdql4TX2jZXgJj4Bx02C/k1
07UcnhF/oVM5vZH2D0thHvEfsixKifTLKAFf4k/kUuXuJd9aDMeIf9Gu48zR
iLQiFU8s0BrNqSeHTxfAM+J/VJZt3NjalAfzyHyga917lJV6ueBL5gcV2DQ5
b8vOgVtkvtCSae3HLZbZ0EvmD0k5Ev3B3iyYIPOJZH9jQ5qYA9pkfpErLj90
rzATbMh8oxsNs3rKvAwAMv/IX9E5lVGbDj8QPiD+ubKenJNpwCL8QD0pvZ7u
g6mQT/iC3B6kNjtEpYCI8Aexpxxu9305AS2ET0ijrLJp4jobnhJ+Ial2nPqO
tOMwRfiG1M1TRO67k0GX8A/1M+x4j4KPgR3hI/qpsOP1+W1HwYfwEz3n00fW
xSTBDsJXdMGru/RUfiIkEv6iA5JXnfa3EqCQ8BkNr+Lt9PrAggbCb/RAHD7d
ymABJnxH/iaNM2PF8TBA+I/2fcz07OuPg2lyPiBFu5nWAuERMCDnB7q/pU9z
fVos/AcQiAFQ
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxN1A1Q03UYB/DpCcJQEsML7iimjEtEYSLEiy88SWR0lhCHzcklyknQMEba
iBQhkZjyNt7DAh0FgSEggjgReBgvY4i8DcSiK96igAhn1IHHS8bv//vj7na7
z/3/+70+z3fzibD3Tq7mcDgnn33//13+yLTIG7jtuv1gTd2y+VqERAtuya+P
iLEHW1y7pBMDOmL/HtRN6Rz3p6+tX/ZsNwZldfQvqF4mzuhG3LJQq7fLgVjQ
jYf7leK11z2J27swQOQ6GG59hDi4C8cqxFs/PhtKvKYL0y0j4mujoomhE3f+
G3F235Kc+LMOdC6KcY6dUBCXP8AQb/56p/AK4j/a0dHD8dszl1XEvHbs1Du+
5qljD7HwPvZaz1sJIoaI5W3YqGc2LP7gMXGrBttC3qpTPV0g5mgwr/S23K6X
i8t0aUWLf/IyD0W8RCxRY0JEjaf7Bj5xUQsWfzE1fq5ZQDzYjJUGxnEm4t3E
Zs1ootsr/HTSk9i7CTNrW/xj+T7Eskb0O+Eb9PYeETGqcJ3yR8v+gkDi2QZc
HKsMXOgIJRY0oN1FV+27pWeIgxFNJ3khfpuiiKEeZ0Ji1ELDi8Tltbh7nVel
0QsJxLx7eH77rIXBRCqx/C665X5vtOCRTcxRotfEg436hbnMfquRK+pdCEvI
Z/ZXhRPCGztiWwuZ/VRiYMLQdxdifmDWX4GTR7bl2PmUM+u9iUGLrn6T3FvM
+spwz3ji482/VDHrKUHTK6ZZo3fuMPMXY1TSVFp0fA0zXwG6XZk5L3aqY8bP
R/1DmjH++8iMdxU3teU9Eoc1MP/PQdu+lPwRkYp5Pw1/9/V5x21jI/P8Ela2
5JkrU6gjMWP+aKG0k/pZSaw+/JwjYTIm8bn3L4Fxw86V8TANTAKPr8zHyYHX
Pz+2sh64Cud+k66sF/PBx9B6ZT+DBXDfaDqV3S+nGKJvjGSw58ErASnv1Wn2
vKAMpFvzfNnzFNwEe4Uwmz1vrIBYUd819j68KyFgdK8Ne1+DVSDbZjjH3qek
Guwd0gzY++YoIUb2E4etB/ldgFOlJmy98O6BxV+j37D1VF4LnXPhZWy9QT18
UjbjzNZjMIKryE3B1qugAfSypIvztJ5nGyAgpVT5kNY7qkDyZ+FXXrQfZI3Q
xLdJvkD7xbsJ1CbVytO0n8yaIczS401j2m+DzcA1WyqOpP1Y1ALx1h81udB+
laghfNg2dT/tZ5dW4CR/HWdK+52jAcg6XZBM86BVA226OrUzzQt5GwQfS59S
S4dovoDe+pJMG5o3vHYIv6xq1MpUNJ9gvMTy4N+nKmh+QW68162lEQXNN6gd
+1ni/ERO8w/cFR1ChVc0zUdYO2eqdnoxlOYnlM51m6/yE9J8hS+3JA1YG75B
8xfsXxE6xQ3voPkMmSDx1NVsoPkNr6mSrlU/1O5btn8PZLscnbbirXIn598D
SQccrls90Sfma+FA8pSmepchsUwLH+b02Zobc93/A3SlT7M=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxV1QtMU2cUB/C7ilmcsriJiCG6shA0EbQ+tjjn42jGWDKCFVHYRsweEhlx
CuiUqttSFVa3xFWGCcVVFCVQ1kGhPGyh7Sm2QOmDe6k4gkPLhqgIRrpp6lDZ
xnfXfrdJ0/xyb7/7Pc7535hP96dmiRiGyfr3+9/v9EfhxTXfNwO34oJ52rFe
XGJn5ooum4ixF8e2OW9pc/qIM3txNGXDcNTXY8QBDr1v6NLT4kSWaZdwKJ+a
ijB9EUks4fDJk0/OxIiWEbtY3PqaQ5No2USczeKErHDRjbdSicNYXKQuUhTn
7yaGHjx25MuVXM4h4gIP7otd/rA9TEGsc6P+pTq9KU5FfNeFKWukeyZNGmKx
C+crJVlVaCDOcOKIPvmOf7mDWNmNhbe7vS/O6yfucqCmtHFi8JsRYsaBCSXG
y6//8Bfx2i5Mv+GyFe4S4bRzOzExXyxn58wlru7Ac79stu3YF03ss2Nb68yF
HeNxxFF2dPaMP/3VsopYasPK5lb1T8xGYsVVND1VJei+SiLGdkzu3FlWwaQS
B6xoPreQWT/jI2KJFSdeGPo2vv8z4mzEpMe+hqLTe4nBgubwpWmvxBwk1plw
e8um352eo8TiNoy6VbRk0HucWGnE2SnylblTCmLGgF5PX/j1d5X8elsw770e
vd9Zwq+vCatks/LyI8r49TSiZqnavfHlC/z8G3DdXnamOecSP996tP58xaJ+
tYqfXx3u6jt/7ZG/hp+PFu9Z3vcd/7OWf74GV4+KojuP1vPPq8Rj8rzn6v16
fvwKNCx+lvfjO038eOVYkzanP2K0mf+/CmeczBpSSa/w9xfj4dOtW07kGPjr
pzBx1kX7zXgjbxkOjBUowpT/m2GEloHw/lMgGA+LQfA8RgWC+UA5COaLFSBY
j68SBOtlNCDYD7EWBPsFdSDYT0k9CPYbG0BwHtJGqKbPy9cE+fR55rbANfq8
GQOE0/WgNEI0XS/iNviAriedCWx0vYEFUul6zEaYpOtVYgWOrueAFT6m6x3b
YZjuB8VV8NP9IrXBApbqpyg77Gyj+s1nB3ct1Y/VHSA7QPVrbieYB6l+XtsF
f5dS/c44YEsFlQddDmgOUHmh7IbkASpPMpww9BuVN2IX3HZTeXTXBX9s0IXy
SucG93eSUJ4VeODtpCOhvIMeKHtTGcrDMBYeaEtDeZnNQuL9+TXBPHWxMHxm
MpS3Eg7SV6yODOZxCQfys5EfBvM6wEG5+/p4MM8ze2HH1uf+YN5jL3iMrszg
+yDWCycOpQwE3xcKL4xomz5/tmq76R9QW2gP
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1lQswVXkcx73yKgmxWOUtpOtRF/d1nK/KqlWLq6WZXWtr6aYHEW1jt9du
suMRSStrSvRgMbat7kQ2999rtAqTKKKsJJTrSm3cpN09f3tmzpw5c875/3+/
7+/7/Rz7DQnhsVoaGhqx/57/XY0EX4a8q+aRXTbNv1Q11rDjOTlDA/N4hFXl
dY35KNjO/ob0e8lLSFGNTK/nViPbIBxzvNrhQYSjPqabOlvZs7kOpELgQaJc
465p72lnswak0QXFi8kr49A/rSO62CTxwXf7PriTJH1BTn30EzbqiLxw6wZ3
Ml25prI4tI9lBp/zo266kebVKzvyjZ+xToxV23JXNxLeI7/MVz5nDY+uTvTM
dCV37G70n1AOs6qhNKOPlYtIQkrPpLWZku0IqP5VN2wRcZXNappfo2LrCx5/
8uqCCzm+P1eJza/YshfGz3osXEhaiHVEnuA1+xNw4PZuZ1IVePlyqf3fbMLP
SbaXup1InPcCA4njBLtupKy+JMCJZL/IvBTOqlnR8vb1WaWOJEw6kq6bNsU6
HNd9u2uWIzlkFa95vn2a1R/1O7pR5kBe/OXmlVyhAeWKzd6fNdmTIsP6oqtq
TdwvKmoW8uyJQfmqztUx2qhTNW1xybMjjuNNza2PdMBmq02cBm2JVoc02TdB
F3O4eSwkH2IzNubb6OMhp/8CYqzeVMwfMMBpTm8b8jmPJzjbPBtUX2vSxx9Q
Vj80AtXTijSNpGyr0p4Hqp8lcclO2T/FMwHV6yNyysc0xCzRFKWcPhakPddV
+rjRDNs5PeaT6qF5zjKROYRc/2YkkR/0suW2BXS5fk2Jm8fSIFGqJe5x/ZmQ
5sJNQkWg9Uw/xsSDLXiywttmpn4j8umO92vDly9EIlevITHP07j6UmwHfa4+
fZJYuCcvJd4eJVw9uqTb4lnJxQoH+HP7axPx3KbsmElHtHL7aZI4c53+jZHO
M+u/V1zjjZspFS4z600oCuT8N3If15nvxxXxYXWq1Ao3tHLvjyjkW2Ybpjks
hhf3/KkizKLC0K7YA3bcfZtiajJSojbnQYM7eiWRw+VlWbmeiKHPWT2NoLGw
dC+E0u9ZsZNfRPBKb6jo+izRSv/xpo4Pgun+rFRy/nz9dR9Y0vrYk8dKagv2
Lf2/frbFduJgsmDZjF804eIWdeuHl8sgpv1D/WTYVFLIx2mqD248tXy6V+SL
OVQ/hKvldcXtvthJ9UWo+cCx4Dg/dFP9YW1Yps4Y8cMKOh90v/4j+sQWf3TQ
+eHI4N4mVa8/DOl8sWv6iIPGWgEYOn/UnKgPjrogQBL1B9go67oMEyHOUv+g
QabXvXCzEF3UX/Acux9TWifEXOo/LEwJcs/XFSGQ+hMu2y75ytaIkEr9iwfD
F3H4sAiUJzbQsTLr3HpXhC7qf0wJa2u/0BNjLs0HzpQ1rvtdIkYgzQ++/mp9
Qm2iGFdovnDAILJOXiJGO80fKi8MfDd4V4xRmk/kETu3QxNiGND8Iuew58hN
Owkcab4xKf/Gvy1IAgnNP9qutyzrjJcgkvIB5aHf86ezJNhB+YGIwT6r2GoJ
Milf0FfleW7JHQnOUP7Aayrs4c4hCRoon+D6OsN53SwGDyi/MLw74saALYMx
yjdM1mb2BggYzKb8Q6pK2rIzjIEz5SP8j50SF8oYBFB+QjrnsfTKHgbrKV9R
GCLuH8lnkEz5C/dk//1MOYNsymd8G/3byborDM5RfqMy4G3N9mYGhPIdZY1C
flwvg0eU/6guTe+qHGPwhv4fkDlacXCVVgCM6f8DETVCWbBpAP4BA5LvCg==

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.554471359921493*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polystyrene Spheres", "Title",
 CellChangeTimes->{{3.498207462726493*^9, 3.4982074631490097`*^9}, {
  3.529838059333644*^9, 3.529838065314695*^9}, {3.554279094561377*^9, 
  3.554279095477702*^9}},
 Background->RGBColor[1, 0.9, 0.8]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 1 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["w0 = 0.54 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm): Diffraction Limited, FAILS!"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
  3.529650479942967*^9, 3.52965049129294*^9}, {3.529829407257964*^9, 
  3.5298294084953537`*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", "\[Lambda]", ",", "s", ",", "w0", 
    ",", "l", ",", 
    RowBox[{"R", "=", "0.5"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
           RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", 
           "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{
        RowBox[{"-", "1.5"}], "w0"}], ",", 
       RowBox[{"1.5", "w0"}], ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{"0", ",", 
           RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", "\[Lambda]", 
           ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{
        RowBox[{"-", "1.5"}], "w0"}], ",", 
       RowBox[{"1.5", "w0"}], ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrzTB", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{"CprG", "[", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Lambda]", ",", "0", ",",
           "0", ",", "R"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "l"}], ",", "l", ",", "0.05"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CPrzTB", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CPrzTB", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzTB", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzTMLA", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"CPrzTB", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"CPrzTB", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "CPrzTB", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTz", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTzMLA", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzTMLA", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";", 
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";", 
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dz", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", 
       RowBox[{"Show", "[", 
        RowBox[{"CPrTz", ",", "CPrTzMLA"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "5.5`*^-7", ",", "1.064`", ",", 
   "0.2314980990427568`", ",", "0.55`", ",", "2.3758294442772816`", ",", 
   "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.5237777571932163`*^9, 3.52964659016206*^9, 
  3.5296471817105513`*^9, 3.5296481896562*^9, 3.52964911733494*^9, 
  3.529655819914671*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1VgtUlVUWpkRUHkMKoqmQhRI+JvFZYxw2aiqUOkCioMjjcuFyYRRxpoiH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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1VgtUzmcYby6HzJlbLmXDpj4Z5ZI7r0dGijgus0ToXt+XWe5kox1ptC07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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0], LineBox[CompressedData["
1:eJw1zHk41HkcwPGZEXnImbZQ+5hKylNWasfVx3dIIrlimHXNTEy5Om2onqfG
bLuOlETqcXU8iiilg6Xs99cWcpRKouRIckxJbiZjdtd+/fF+3v+9mDv37RAy
aDQa/9/++30/g/Y7dAVqYeLhqzZOnuA2Vha9PZNBPd9jmeTY5Al9pz21ejYy
qJPTEdYGQi8Qrx4oOP6cTjXhPaplk16g//cf9rohdEpnVX7HTDIH/vfolIlx
yIImY29wnfVoVNvjbOaiGm/i0SjXXYcyToX5wDyPdxx5lhzHOoQcpGlwwfyE
WoLZixnsnbn3MrOEC2Gl7IdChRlcqesmPsf7BbIlkYMXWDJsIi4yGlTxhRfL
8pbXh07jsRsnrxWV+hLvOy7Q3sZDQj9gzXpSzJjH8RjX9ieeFC//+Chek/In
3hSuEBmUFYcHEG8SS+l1Sz/qBBJvAtuXBt47Wx5IvHEcp+mvlOrHI944fqon
EWeO84g3hj2eRb9duYVPvFHsfbHqZkoiHxRmvREcYbKro76WT7xhfDE4W2O+
ooB4wxilXHsVbiEg3hA+OP7N3zBYQLxvOMaO9YUfJwClK/cKZywHMTMyqMvz
sgAilPW1hZcG8GSK8xHbYgG83hsbU6f0BSd5Vg6ISgRg1dTbvn6PBMeaGTf+
dlsAl6xdt1xo7MOlqvd3vc+Z83qxQ66qcHPsnPcJO3AatbJ95rxu3HPOnCFj
znldeClvzbb8Tj7xOrGbXlTFojQ+LLAP9ZFFtuNd13oWftnEhxZN1spadiuO
sM5r+F7Kg/w2xlC6WgvGHS1hcd2BsL+goSLo3Wvc0F4jyKcHAjs6K9E07yV+
mxbTV6IVAAbxr4qkvfV43m+OW1cs9ofbzAjHtNgqjO4cDQnS8QP3B4pd6/Qp
XN/5fuiDqi9Q120mTofexWZuD6cG5Vyg/Vp9XTkyAzNVfNXKh31AhMMTjKkL
aHrTyCt2jzdcemi0r3n6DlKTy1Zw3nOAnzBqnVuDkYobtez8Gy8wKOSfsHCu
Qv3584XRbzxBpFUtySmuR+INOhWWbTtg8kF6PiPpJVKoPqA3+dkDVg/WtP6M
XyOW4n7xVQUP4C6XqYcONyNWnJ29pqE7nOGY2mUZtqJgtfI/qy67AhUfdKiB
2462eyQwXTVcYDrA2Yte1YmUsp2UxanOkDbRPZDB60KxOc6mfSbbYG3KsbiN
Ux8RTb5GSn1whKfGS5jPz35CmT7qsco3tgL/SXH57rW9KLz1hdHhUw7E60Ol
df21yb9vIZ4EZXu/SU5JtSfeZxTlrrAktWQz8QaQfqOkTDRgR7xBZOIU725k
bgczRYYFtKBv6L4C1wTO2kLt0eGoZz8NoTDTrNowGRvSHfHmjOkhJDVLf7kj
mg3Bi5I0d9cMo1uSpJtmMgSmXdy2DekjqH/SWd64AhFvFCkrb1wl5dkQbwwl
uklaWLeAeGOo72vlX3YaQLxx5OvX7Ug/tol4E4hm9LRFPGVNvEmk56oerSiy
Jt4UinF5FDCqYU28KZR85mt6T54V7Jz1pKipPV+S5WAFZrPed7RW6aq7XGJJ
vGn06PG4ll6aJfFkSEftCdaztSSeDNnA0aUuQxbEm0EdCUfUl+RaEE+Oaoyc
bkq5FnC8WZsjWk9js21TDiVoWMAnOPyg5zyNXWkyVBhebQ7OuR1MlxkaW7gz
fIQrModiFYf4u8F0dtGPV3QXW5mD7oEbX3Xr6OyOHHXdmFEW8RjswjMSN+4t
FvEY7Oas6P6sMBbxGOwf1uVEma1iwT/hsuhG
          "]]}, 
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJw1zGs0FGgAxvGZIUmraE+tWZVLyHZBtjDDO+8kU8QiDEqYm1srrR2FFlGE
RKlW1saqFKmjdDkq9M5SUy4xdq0RueQ2ViF3hpnZXfv68Jz/eb789DjH3AJI
BAKB9e/+6xMf3c6HRCUBuUlrkyXwAC5TzyKdfiUJ0swKJ1a88wCDGe6aAztJ
gpSyI4qGaCY4bTxcfKqBKHhawVVk6HgC7aqzduRgoqB7oDLKqdYT/O8RBbWs
A3mkk17AedEjCMzr9TQKTLyxRxDcVP54gjzoDZQPtDEV1xRobGy3FN4+CCwT
1VPNRXLEMIy9KAk+BI6U0SsClOSIMnrOuMnUB+QO8UezLWTI7IXO/XtSHyDa
UKhfH7KAQhpdxtfVHMbePDJRqg6+muMLLBY9KWoVu/blhvlhT4p6W0nW8Xb+
2JtD80Y3peXqLOzNIs5KmpprNAt7M8gjWSUpuo+FvWmUGOcYV+DMxt408tlp
A7eWsbE3hTZuYo4yN3CwN4l8tpKuH4rnAKVFbwKtfp3Z7tvFwd44skkvq+BT
uNj799Py666nc7E3hqz6Y37+0MbF3mc0NSIxMtDlAZUbj+/KKaNoVGEY5nmY
B0JVtdcE5A8jdsSD5MAMHmgOS4iqU/mEtJi5gw5PeID6l6Rzx9EhRC645aAs
4oF8a2dG9p+DKCo3Tf9+x5InQeuftIQndCx5/WjWyPKkuGHJ60NSYvNqaumS
14Oso8ZVAhKXvG7UYctgOtnzwBd2IV4yfidannI5QUfGBa0aFga19HbEzvuw
xvEmFxR1kMay1FtRZqi4MdKaC34obqzktjUj+sj8q2QhB9Ajr50zK2xCMsNN
1EwGB+im/FEildSj6/zqWvEzNnigF2p/JUGIliVGbHtpwAau5ct6tmsLULSz
+0JbMgsI7tBmMkIeoYn97m6BNf6AEPH6jio/B91mF7W0RvuBePR96hZBNlTp
vOTnZOAL8is2HxMvPIQPBghRI3U+gJU6aV1Qg+DjeZekev4hoHuXlWjlKISG
UP5OuPEgiNd8PZRXWg9nsyTvkxq9wGx5VhHpfBOUu240Ck/xBMajNe27UDOE
xcxzRY5M4K0vWxUyLobHBb+rKb72ABeZZrbXDNthdf77wpkZNyBI4R5v9O6E
p3eJyS97D4AFX0cPorAb6jBEYYwuV3Blpm84x78HdjnYqW5ocQHbMuOSd871
Qs6Qe6xolTN4s0VLr+FSP1zJpt4oCXYCrJelz4O2SWCQ5i9Ze3v3Y28Qil1C
qJWxDtgbgiX3J/06Leyx9xGuzfrMMVHfh71h+E2Nytl5OQN7o/DtbhPvMDUG
kJcYFhO4n+HfgYE12dvtQO1P4yfemo7BdTaep88E7gFZ9mhPzsIY1Fr9lRvl
kS3grT2vEVQzDlcISXkiTVtg1uPd8W3WBDTVetb+Y/xu7E1C+wtPzTkyOvam
oMOrinDZWTr2pqBXoHp6lTYde9MwdFVt5W8REHszkF9FEb6pomFvFrZ8arJ/
oUPD3hwcHATkmFSAvTnor2KcbCW3AZxFTwppV/hnWDE2wHzRm4c0atqRyyQb
7C3A6knPW3kXrLEngzrL0/dF61tjTwanTdPewOdU7MnhGWLdR1NPKvYUMKbW
SVIwRQGnxGuY8TsIdE7sgOjLbAroB9HlA1cJ9H2s9V6qgAIcC7r0vpMT6CEN
3UK9PitQqrY35RGPSDe03eyrkW4FyOH3Rsh1RLo4I/LDJUsr7JHoR4PikiJ6
LbFHopNG3imnXbTEHomu6ypVPKZZgn8APzHvOA==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw9Vgs0FmgaFs4WasgwaUhFW1YpUZLidRfV5NLgN13sHyWayKrTYnc1pUnz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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw9Vgs0lVkUFqWipkYkppBeZCWlh1WxUVwqeZTLDUseSU3PmWpCTZlB0kNN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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1zHk4FGgcwPGZCVml6PAkm+uhi3JEB5t36FI0FErpGMTMmBnGDLW1ioxC
O6j0DJXOxwpZT6W0ye7725QcRUmPlohBrIiZjNvYXfvOH9/n+9/HLChidwiN
QqEw/+2/PwowbXlAnQEjWpBZ/psOeCmfHPO8SgOeyIRfZWgE3ak++p8daDA1
32mKe80C4pf35cfWUKHY37h3XpsVGD07u9mQTQVT6/aRtAI7+N+jgpfL6p9Z
YkdgTHsUsN1blXgnegPxKFCzc2Zxi3gjaOxq9JvKmsLsFZDm3kCHdQm6yfZv
VPhXafDbxeNuEPaYXhoyQ4XfC1JuXF61Ba71iPoz105iq+MGs/rDt8GbJXfM
X3EmsMlyPX0nvJ1443hsAmolxp6wdtobw0MpSdIeCYN4Y7ivLvpv8zPexBvF
5bR9/S7Vu4g3grWXxe8vXORDvGF8pjvcYwffl3hDuP2Wsr6lwo94Q1jznNab
FVZ7iafECQmS0r/S/Yk3iAcCaSUS2n6YMe19wwfaFmbXHg0gngJvbfMJXDJw
gHgKzDWxEbXwDxFPjtPCkhvY/YeJN4CfSKlLKSVM0Lr98K5qQz8WYufT3JOB
wNM2mhdysw9bUMc5ia5BUB9++sdqrV4cFK11qlkzGJzed7XY8XvwJC/DVl4Z
DDedGVsy33XjUQdnB9eUI8Trwuk2GZbbvUKI14lDG9v44rmhxOvAaTGBXtzX
ocSTYXx+lk5sEot4rdgtT0lzo7Nh9mbO3klRC+4SWzW4DLLhg95aiyp6E/YY
N3b7LpsDuc00uVT3A94RlPon8goDQX7t78GN9bjV53iHRBkG9GNZ52zvvMUv
Uhjrc6VcME2qKxzreoWLzZg1e+x5cM+M537pdDnWT1scwK3ggfdTTdkqI8Ci
xIvDL/z5AHkuw6mcInypqindp50PlKiXedqiK5haIbHWZYdDHOYmr4RMZDLJ
bxj6HA43S5dFNEw8QM1n0kqMmRHATB50zq7EKKvORnX1XQSY3mUmrPcoR0XO
dbJyUwHE6b/suX7/FYqNZRjp+glg5Kk0lyZ5i8w8H1cUnxXA8v7KJkdcj2Rf
fyn4+EgA/uaTcziKBjSHzXp+WSaA8362blmWTcjcYnGXjm4kQFJwdK1/C5K0
xoQwHCNh4qCHL7W8FRUIFHnigEi4NNzRd+WwDNnuWvOhKjYSrC+cSnQYbUez
rq/kb74dCRUrF5nVXOxE+7YfatUriwTm8/slLOsupKS3unvL1F43ckmfq21O
ERKvB3XwQ2OyvxcS7wuSpLr+MbhOSLw+tCBiNnv1biHx+pH9idthXK4QVIWW
+ZTgAeSQZPC1TCyEqp8UR1/byNGcmXEujKtCkLrjTVcm5KjacbDM+IEQjiyU
6LEqFUij85iGe4UQbGX+zWuk3xAnK6awsVntDSJOLjO/U6H2lKhUwbI7OlNE
PCVizC7uzjASEW8IfcpRqHxtRMQbRhpirkexm4h4I4glf8gv8xMRbxTtrhnp
jWervVGkyPHeM3ZCBEHT3hj6+PDevtUpIrCf9saRZrxup/kNtTeBTn5K2Nh0
T+1NItdDPIP9z9TeJJLJnXNuvVN7KpSzLeBJUYfam0LWTh3PLihFENswzy/O
jkLnOkV/+UErCjo3Hn/6OYNC9zRzMC42iAKP7E9mO1UUeqa15QLV0ii4r7M1
qegIla7DGz+4cF0UGEYWfDWsptKXaiTxJrZGEY9Gz67ozSjao/ZodJ35jyyd
Q9Ueje57S7kzPToK/gFHUiNh
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5237777571932163`*^9, 3.52964659016206*^9, 
  3.5296471817105513`*^9, 3.5296481896562*^9, 3.52964911733494*^9, 
  3.5296565277342997`*^9}]
}, Open  ]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 1 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["EXACT",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm): Diffraction Limited"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
  3.529650479942967*^9, 3.52965049129294*^9}, {3.5298232366357327`*^9, 
  3.529823237313415*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"w0E", "=", 
   RowBox[{"5", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"xmax", "=", "1000"}], ";", 
  RowBox[{"zmax", "=", "2000"}], ";", 
  RowBox[{"dx", "=", "100"}], ";", 
  RowBox[{"dz", "=", "100"}], ";", 
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0E", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", 
    RowBox[{"\[Lambda]", "=", "1064"}], ",", "s", ",", "w0", ",", "l", ",", 
    RowBox[{"R", "=", "500"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "x0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "0", ",", "y0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{
           "0", ",", "0", ",", "z0", ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "1", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "zmax"}], ",", "zmax", ",", "dz"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dz", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, {3.52981742446567*^9, 
   3.529817434355237*^9}, {3.52981750666547*^9, 3.529817571774962*^9}, {
   3.529822681357785*^9, 3.529822684743106*^9}, {3.529823002654579*^9, 
   3.5298230115152397`*^9}, {3.5298230459221354`*^9, 3.529823149205222*^9}, {
   3.529823179554194*^9, 3.52982319486631*^9}, {3.529823268043702*^9, 
   3.529823299249206*^9}, {3.5298275954650307`*^9, 3.529827600474769*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "5.`*^-7", ",", "1064", ",", 
   "0.25464790894703254`", ",", "0.5`", ",", "1.9634954084936207`", ",", 
   "500"}], "}"}]], "Output",
 CellChangeTimes->{3.529817619766663*^9, 3.529823301239616*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QdslOdXC+vK24L5Cj0H0q3mTZTX0YbwGToP
SCxkk17daQbhP2g98Pf9pgc2jU4Q/oGmAx27n/H9fOQN4TvUHzBrORL79FYg
VH/lgd70+wY3FgdB1Rcd+KcwdVvTfz+ofOaBlXtSZ8776wzlRx6QVRBL1RQ2
soU5cVJ1gdXpZ9t3QeUdhDzA8nuh+h3+XQHr3ws130HbFGw+VL7SwTkLbP9e
qPscsurA7oOqb3JgWQ52/16o/xwE7oL9B9Xf6cDcAfb/Xmj4OLyRBocP1Lx+
h8/f54HCby8AUhlrGA==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QeSDmx9WBLKbwvmK/QcUJxWkvrumAKEz9B5
YAqL+gmD6UYQ/oPWA9GMpXtyDR0h/ANNBzTPV7jKB3hB+A71B+7e15u0TikQ
qr/yQFLd9u/PYoKh6osO3Ciz2Mn2Mggqn3nAaZeC56wGPyg/8sBUZ9aTxkpQ
80Eilvf5trkc2AXlOfSlg+X3QvU7yF4G698LNd9BvwZsPlS+0uFLDdj+vVD3
OWjdBLsPqr7J4dlusPv3Qv3n8PxtCch/UP2dDgbP1UD+3wsNH4cTZeDwgZrX
7xAxAxx+ewH2smiO
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w+sLijjk1900wbM3zD3wOq6rM+9fxltwXyF
OQfk1U033/8pCOFPmHWg7X7u9v4OSQifYeaB7g3T2rl3y0L4BdMP1H4MuTVp
jxyE/2DqgT0rOY7d2AzlB0w5oJG39b67iwKEf2DSgSWJ7LU80soQvsHEA0a5
G/87nFKH8B36D+wR3xDerqgLdU/PgZMGCZ3nNhhA7e88kPKOJy262xBqX+sB
L6O1UupPofIHmg7c87LYIaKrBzWv/oDWX8krMks0oforD3xkmy9oXqUKVV90
oKqAh2+9hhJUPvPAtOcXs6dbQd3PEHnAaxWDzzFrMVtYEF6+9EDkgwcLTN7h
x9ww2UWPfu6B6nfY90Ig8uImyb1Q8x0citdF7Pmruhdqv0PpxD2nBe7o7IW6
zyFa01nvhpUBVH2Tw68Jm280NUH5D1odbsy16887pg/V3+kQ/jlCtMJeby80
fBzees32256lCzWv32HhMf0FCjZQvsFEhwbr42/u74fad2CSg930W1w/9mvt
hcaPg8ZW7nOzJ6lB7ZvqYNcQsJZhrsJeaPw6MP9hulPeIAK1f6bDk5Q5vFwP
WfZC04eDkl/R3Yni3/ZA049D563PVgqyP/ZA05eDjHby9bLbzFD3zXc4dZBv
k+977r0A8onRTA==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QdOdJ1SFZr5dD+Yr9BzgHUCg0DP/L8QPkPn
garavNrrOXwHwNwHrQcuXQi6Y88hA+EfaDpgeMZ4+vc16hC+Q/2B4s38TcdZ
jSB8hsoDtTNb/NdVWUDVFx0QTb0zje+mLVQ+80D932dJm5Y7QPmRB6w0dVq5
CxwPwJxoqIHMj3TY8wtZfaZDeDSSeQeKHBx7kOxjqHRwX4rkHod6h7ubkdx7
oMkhfh2Sfx60OpwNQvIvQ6dDTixSeCj0OJz3Rwovh36HeSlrJnr+ybEFAEOB
bkU=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qfm9DjP5d56dT+Yr9BzIEtVg3sNz0cIn6Hz
wPd3v4vj01kPgLkPWg+0lEVqPpgjBuEfaDpg43/z355sFQjfof6A1ao9PNGq
BhA+Q+WBBy8qL0ffMoOqLzrwblNbgGW6LVQ+80DqxB8Z58MdofzIA8Y13q8W
X3Y6AHPiqSpkfqTD/R5k9ZkOk5YimXegyGHVTST7GCodWmYjuceh3qHUDMm9
B5oc/IKQ/POg1aHuIJJ/GTodjD6rI8JDocdhphRSeDn0O0y93HA2dWKpLQD9
I3Nx
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w9cdAq+yHdo4X4wf8PcAwpeym+2x56F8BXm
HNh+/0tQ9enHEP6EWQeOhWr1vNr7CcJnmHngVf0TdXeuvxB+wfQDeyz/cb25
znwAzH8w9cAqsdVTDDU5IfyAKQd65h/dveQ0H4R/YNKB90Ehv19tEYLwDSYe
MCo39dp6WQzCd+g/wJwgJ+R7XxrCV+g5MNvs44PVlxUgfIbOA6VCLXrdd5Wh
9rUe+Lw7MnPhKTWo+U0HbrJzzpiRrgk1r/7AYW2j6WwLtKH6Kw+kzFViUK/R
haovOvD98dmkbXz6UPnMAyXLL919rGcA5Uce8N36ZqvMKhifgWH712nngx7B
5R0qrWf4l+6D8TMduO01AjgMDGDmO0yNr5zUU6EHs9/h+roH04780Ia5z0GS
9V+KrqYmzP0OpzVPrdPxVYP5z+F/f8m2Qz3KMP872OW0PTZ+pwALH4cv7f58
ykdkYOHnMClT+8v7zeKw8HU4XjP7meNOIVj4O6TlyT2u0OOBxY9D7y6bpOsx
LLD4c2izLl8eaA6PXweN1hneQbLfYPHv8NFo27MZ9Z9g6cOBN2C28o2pH2Dp
x8HETHlx9783sPTlcOoD99/Nss8gfIf5DpwXeC/rPryxHwByGuVL
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.529828687027259*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"L2", "=", 
    RowBox[{"Round", "[", 
     RowBox[{
      RowBox[{"Length", "[", "CPrxT", "]"}], "/", "2"}], "]"}]}], ";"}], " ", 
  
  RowBox[{"(*", " ", 
   RowBox[{"\[Kappa]", " ", "=", " ", 
    RowBox[{
     RowBox[{"dF", "/", "dx"}], " ", "in", " ", "linear", " ", "regime"}]}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kx", "=", 
   RowBox[{"10", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ky", "=", 
   RowBox[{"10", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kz", "=", 
   RowBox[{"10", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dz", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "\"\<\[Kappa]x [pN/\[Micro]m]\>\"", ",", "kx", ",", 
   "\"\<\[Kappa]y [pN/\[Micro]m]\>\"", ",", "ky", ",", 
   "\"\<\[Kappa]z [pN/\[Micro]m]\>\"", ",", "kz"}], "}"}]}], "Input",
 CellChangeTimes->{{3.5298286377336273`*^9, 3.529828749203747*^9}, {
  3.5298287856694613`*^9, 3.52982878758568*^9}, {3.529828842488596*^9, 
  3.5298288461040497`*^9}, {3.52982888590906*^9, 3.529828936400158*^9}, {
  3.5298290533730497`*^9, 3.529829056731206*^9}, {3.52982919023219*^9, 
  3.529829191973878*^9}, {3.529829222486904*^9, 3.529829339299202*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[Kappa]x [pN/\[Micro]m]\"\>", ",", "7.782770757873382`", 
   ",", "\<\"\[Kappa]y [pN/\[Micro]m]\"\>", ",", "9.499069287438479`", 
   ",", "\<\"\[Kappa]z [pN/\[Micro]m]\"\>", ",", "0.8321157088223411`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.529817619766663*^9, 3.5298284591286163`*^9, {3.529828681336418*^9, 
   3.529828711231002*^9}, 3.529828749635775*^9, {3.5298288870566673`*^9, 
   3.5298289371738167`*^9}, 3.5298290570844107`*^9, 3.52982929999336*^9, 
   3.5298294191155653`*^9}]
}, Open  ]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 1 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["EXACT",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm): UNDER-FILLED"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
   3.529650479942967*^9, 3.52965049129294*^9}, {3.5298232366357327`*^9, 
   3.529823237313415*^9}, {3.529828582896676*^9, 3.529828588446136*^9}, 
   3.529829424616441*^9},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"w0E", "=", 
   RowBox[{"5", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"xmax", "=", "1000"}], ";", 
  RowBox[{"zmax", "=", "2000"}], ";", 
  RowBox[{"dx", "=", "100"}], ";", 
  RowBox[{"dz", "=", "100"}], ";", 
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0E", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", 
    RowBox[{"\[Lambda]", "=", "1064"}], ",", "s", ",", "w0", ",", "l", ",", 
    RowBox[{"R", "=", "500"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "x0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "0", ",", "y0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{
           "0", ",", "0", ",", "z0", ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "1", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "zmax"}], ",", "zmax", ",", "dz"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dz", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, {3.52981742446567*^9, 
   3.529817434355237*^9}, {3.52981750666547*^9, 3.529817571774962*^9}, {
   3.529822681357785*^9, 3.529822684743106*^9}, {3.529823002654579*^9, 
   3.5298230115152397`*^9}, {3.5298230459221354`*^9, 3.529823149205222*^9}, {
   3.529823179554194*^9, 3.52982319486631*^9}, {3.529823268043702*^9, 
   3.529823299249206*^9}, {3.5298275954650307`*^9, 3.529827600474769*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "5.`*^-7", ",", "1064", ",", 
   "0.25464790894703254`", ",", "0.5`", ",", "1.9634954084936207`", ",", 
   "500"}], "}"}]], "Output",
 CellChangeTimes->{3.529817619766663*^9, 3.529823301239616*^9, 
  3.5298294423303432`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QcaON5WzfQUsQXzFXoOhO9TnnzUAspn6Dzg
/Orswqn/eCD8B60HEmuChVJ+CkP4B5oOJFzMzn9wVwPCd6g/8HGvsV9hgTlU
f+WBeyL/WSUu2kHVFx2IfN2mJx1oC5XPPLD1vfox22QTKD/ywIwfn1VdZJVt
YU7cJ/Fv8d32Dbug8g47VL6A5PdC9TtwsmuA9O+Fmu/g+wNsPlS+0qGBF2z/
Xqj7HJ4uA7sPqr7JYekSsPv3Qv3n4B8O9h9Uf6fDs59g/++Fho+D1Elw+EDN
63eI/vsGFH57AUFLaUM=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QdaeT2qVS14bcF8hZ4DIe90jlipCkL4DJ0H
onLmHN98UwTCf9B6YNsW6+73p2Qg/ANNB1709c2ddVUNwneoP/D6fMFX4fVG
UP2VBzbeLZsnesoaqr7owJrvZzhP2zhC5TMPlAYdn2Lb4QDlRx4wETd8mTLR
xBbmxPYXMedEt23cBZV3ULYDy++F6ncwjALr3ws13+HtZ7D5UPlKh5JTYPv3
Qt3nwL0X7D6o+iaHd6Vg9++F+s+hdDbYf1D9nQ4iiWD/74WGj4PLC3D4QM3r
d3BlAoffXgCb+2sM
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w9McZpaedXy8R4wf8PcA+KMPQH1LVkQvsKc
AxoZD9es4X9lA+ZPmHWghPvOJsbcbxA+w8wDzLfqriY/hPILph+48cjq+DOF
NxD+g6kH3mcVXHN/uxLCD5hyYO7XDsF7wlD7Dkw6kMHI80I7/xmEbzDxwKG9
06vdrE9B+A79ByrUjD2aVzyG6FfoOfDxoP1m/61foPZ3HvDYvODqR9nvUPta
D2xmtfqe8OYdhH+g6YB1e8iN30m7IXyH+gOMMksUz0x6CjGfofLAWYHQjuXH
30HdU3Tgol79TsUdUPcxZB4oyfziJsh3GGpf5IF1q2xjn/tA/QcEHsJXfe7U
f4LJO3Bo3bv4xOAllJ/pYGl6aFJrxDKY+Q4GbTz6Hy68gdnv4Dr7buanoK9Q
/9Y7lLyv1Cpm+ARV3+QQd3FW2Oelt/ZA/edgPDdP/7fjDZj/HaKPbdm4ce1L
WPg4GB1b9j42BRpeDv0OiS81lb/G7YGFr8MlB+Yj1qtg/p3ksK4l8mXD9O97
oPHjsNUxI2a27DeofVMdtHouiM/c+XwPNH4d3vZ/uHrMfBss/h0iolm3Ck94
AksfDhOWq9Zt/gCLrzkODL+eSuzYu8IGmr4cmirefdVQegH173yHLiZrr7WR
X/cAADu965U=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qeu3trX9V36zn4wX6HnQKHpYhV/gTcQPkPn
AXFdF5ZNvJ8h/AetB56fU8x8/uMnhH+g6YBbzzWVxpmsByDm1R94UmqhZ/la
CMJnqDzAMmX5nqfTZSH8A0UHdu8ylT1xXxkqn3lAymbqp+3p6lB+5AH3mJmZ
pfyaB2BOzIpE5kc6ZJsiq890YNqAZN6BIgexKiT7GCodmuOQ3ONQ71Cbi+Te
A00OgRuQ/POg1SFCGsm/DJ0OnTxI4aHQ4yBXhRReDv0OQVbOD9YFltgCALLC
bjA=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QfuNEyI57K7sh/MV+g58FNQSvbQ/6cQPkPn
gQyb+TYnLT5B+A9aD8htctT9ZfgHwj/QdCBU8kLqZUa2AxDz6g+IWR1dsKVS
EMJnqDwQqSLn/1ZSGsI/UHRATNN7bl2rMlQ+88DmfFuJGntNKD/ygIP/XKus
8zoHYE7U80HmRzo8SUVWn+kwSwbJvANFDj95kexjqHRI0EJyj0O9w282JPce
aHLYMQ/JPw9aHQ4bIvmXodOhjgUpPBR6HLzykMLLod9Bda0y4+1uV1sARi9o
9g==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w+4nZJNylm8yh7M3zD3wIQdlupaJ6B8hTkH
bmR9flG9fNJ+MH/CrANZ3f9Pqd47COEzzDwgsdcs5N/tCxB+wfQDqXuMXynv
vgrhP5h64M+ZrOw/TNcg/IApB7YWXDRR2noJwj8w6YDR9USvl0vOQvgGEw88
fb/ANCX+NITv0H/gr8S++17iFyF8hZ4D2teLxWc434Da33mg/KTJrH1KD6D2
tR4w6RKc63bhEdT8pgP9vb/Xack8hppXf+CJw8OAl7YPoforD7zmnnJfTv0u
VH3RAb2MVzMv7rkJlc88YPVu5l32Cbeg/MgD86QnpZ0pu78fFoSir7y15r1/
BJN3OBM284Wg3FOYfocT87/dlf7/BGa+A/vG0gleDTD1lQ6bX/pMXzv3Lsx9
Dost9U7FJ16Hud/h8oxvt+YKwcKz1cF57gvTRJ3rMP87vFrBzvZs3m1Y+Dis
4LqbsPHXPVj4OfzU4jpYEnsPFr4ODce0i27y3oSFv4OqQ5zMzYcXYPHjEKXb
WlRbeAgWfw5ex3ynRBdvgcWvw2e+R8HP4rfB4t8hWE5vYZT/IVj6cLiQebC0
1/wk1D1zHEJWrRJecwDK3zDX4ZhJTeqSFGj6cZjv8EnwunDcxSn7AYye9oo=

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.529817619766663*^9, 3.529823301239616*^9, 
  3.5298349617360764`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"L2", "=", 
    RowBox[{"Round", "[", 
     RowBox[{
      RowBox[{"Length", "[", "CPrxT", "]"}], "/", "2"}], "]"}]}], ";"}], " ", 
  
  RowBox[{"(*", " ", 
   RowBox[{"\[Kappa]", " ", "=", " ", 
    RowBox[{
     RowBox[{"dF", "/", "dx"}], " ", "in", " ", "linear", " ", "regime"}]}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kx", "=", 
   RowBox[{"10", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ky", "=", 
   RowBox[{"10", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kz", "=", 
   RowBox[{"10", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dz", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "\"\<\[Kappa]x [pN/\[Micro]m]\>\"", ",", "kx", ",", 
   "\"\<\[Kappa]y [pN/\[Micro]m]\>\"", ",", "ky", ",", 
   "\"\<\[Kappa]z [pN/\[Micro]m]\>\"", ",", "kz"}], "}"}]}], "Input",
 CellChangeTimes->{{3.5298286377336273`*^9, 3.529828749203747*^9}, {
  3.5298287856694613`*^9, 3.52982878758568*^9}, {3.529828842488596*^9, 
  3.5298288461040497`*^9}, {3.52982888590906*^9, 3.529828936400158*^9}, {
  3.5298290533730497`*^9, 3.529829056731206*^9}, {3.52982919023219*^9, 
  3.529829191973878*^9}, {3.529829222486904*^9, 3.529829339299202*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[Kappa]x [pN/\[Micro]m]\"\>", ",", "3.8477668312832454`", 
   ",", "\<\"\[Kappa]y [pN/\[Micro]m]\"\>", ",", "4.439624944950102`", 
   ",", "\<\"\[Kappa]z [pN/\[Micro]m]\"\>", ",", "0.17626320015805105`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.529835880439993*^9}]
}, Open  ]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 2 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["EXACT",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm): Underfilled: 200%"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
  3.529650479942967*^9, 3.52965049129294*^9}, {3.5298232366357327`*^9, 
  3.529823237313415*^9}, {3.5305142430551853`*^9, 3.530514250278132*^9}, {
  3.530519801991267*^9, 3.530519804181039*^9}, {3.530527101057568*^9, 
  3.530527102049541*^9}, {3.531588955306552*^9, 3.531588955488166*^9}, {
  3.531589003128653*^9, 3.531589003391317*^9}, {3.531632647085032*^9, 
  3.5316326473883743`*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"w0E", "=", 
   RowBox[{"4", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"xmax", "=", "1000"}], ";", 
  RowBox[{"zmax", "=", "2000"}], ";", 
  RowBox[{"dx", "=", "100"}], ";", 
  RowBox[{"dz", "=", "100"}], ";", 
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0E", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", 
    RowBox[{"\[Lambda]", "=", "1064"}], ",", "s", ",", "w0", ",", "l", ",", 
    RowBox[{"R", "=", "1000"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "x0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "0", ",", "y0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{
           "0", ",", "0", ",", "z0", ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "1", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "zmax"}], ",", "zmax", ",", "dz"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dz", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, {3.52981742446567*^9, 
   3.529817434355237*^9}, {3.52981750666547*^9, 3.529817571774962*^9}, {
   3.529822681357785*^9, 3.529822684743106*^9}, {3.529823002654579*^9, 
   3.5298230115152397`*^9}, {3.5298230459221354`*^9, 3.529823149205222*^9}, {
   3.529823179554194*^9, 3.52982319486631*^9}, {3.529823268043702*^9, 
   3.529823299249206*^9}, {3.5298275954650307`*^9, 3.529827600474769*^9}, {
   3.5305142540850277`*^9, 3.530514264252761*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "2.8100000000000004`*^-7", ",", "1064", 
   ",", "0.42319979669763036`", ",", "0.281`", ",", "0.6639889768207288`", 
   ",", "1000"}], "}"}]], "Output",
 CellChangeTimes->{3.5305142688981533`*^9, 3.531588982324149*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QeWBB/Xy/viuhfMV+g5MLF5mn/2ikAIn6Hz
wIO7f0SS+sMh/AetB6o04xU9D0dD+AeaDkQnbDdXj42D8B3qD3CKsSn6iyRA
9VceqPKsK5RaC+UfKDpw4OMGmxR7mHzmAf17e3i2CELNY4g8MC3k1WzfeP+9
MCcq6zfoPbl4xwoq71CwByxvC9XvUM+4F6TfFmq+w9RfYPOh8pUOrj5g+22h
7nN4KQp2H1R9kwNTLNj9tlD/ObQogf0H1d/pMOUS2P+20PBx0C8Fhw/UvH6H
IDNw+NkCAP2NY6g=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qdco/fuKlQO2AvmK/QcCGp4b/o5PhTCZ+g8
ULnk4OLvXyMh/AetB9QWySi4/omB8A80Hch5YtHwbnUchO9Qf+BCMdd+xjvx
UP2VB97GPGHdE5AAVV90oGT2EU6pYph85oF0jdCb8R+g5jNEHqhSWB734Ybv
XpgTtbdvFtQz32UFlXd4YwiWt4XqdzikCdZvCzXfIX4a2HyofKVDeCTYfluo
+xy08sDug6pvcoh8AHa/LdR/Dt/ngP0H1d/p8G022P+20PBxkCgFhw/UvH4H
zQBw+NkCAPREbfs=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w84n/LufBQTuxfM3zD3QOgT7e1+XOEQvsKc
A5mTzkmXRmpA+BNmHWBdsPpwS2mQLcSAmQc4QtsXCkyKhvALph9Q5dGR0a4N
hPAfTD1Q6R61NfKIFUR/wJQDahd3cthXx0H4ByYdeLvTJ1DDNxnCN5h4YP+V
fwHrZkRA+A79B06qailtdzKCmKfQc+Cg2Zn6l//iofZ3Hth8qiLzb0IK1L7W
A7e/bpQrdo6A8A80HTAWfvBNMNAJal79gXr/l2/UPVIgfIbKA/f0HiltX5wJ
dU/RgRd6ooyzGROh8pkHBGZcrN50WRlqX+QBicudse95k21hQci2p63VuTIL
Ju9gNH/nYf0EmHymw87pF4Jc+fWg7ilyOHuqavN/3gSY/Q53Jr3esCYpA+Y+
h2dXBP/y7k2CuqfJgd3As367tNleqP8cGOdPctuQGgPzv8NGwaxypjVpsPBx
+PbyRvjPmiRbaPg5eP28fN7zgLMtNHwdNjzgYT/BFgwLfwcH10f7K3MSYPHj
cLRuR/f5udDwfzDVYaHa4+s3Ijj3QuPX4b2zvyJDVDgs/h06HpcddV6VYAtN
Hw7LLTY5HeCDhr/CHAel/b65WYeVbKHpy2FND/vBd08Dof6d72D5PmtrXl3E
XgCjd9ZQ
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qck/BlcY7L5HMB8hZ4D3bppRWXXlCF8hs4D
E9YzV2eLGEH4D1oPmJZud/fcZA3hH2g6IHnvbXqatDOE71B/4IyW11rrtR5Q
/ZUHpB7//vK32A+qvuhAu8iq4/FcQVD5zAP8hjtKypJCoPzIA82njYNN9oU6
wJzIchKZH+kgqIWsPtOhigvJvANFDh9PI9nHUOmwRgjJPQ71DizHkNx7oMnB
1A3JPw9aHX41IfmXodPB+E4qIjwUehwmG/53gYeXQ7+DlE/TqSVz9u0FAOgN
YJI=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QcmT5zU4hsj5gDmK/QcuB3x9933P5oQPkPn
gSKuk5l9f0wh/AetB5wU5nBkMztA+AeaDnx417YoMNgVwneoP5Boaaj+6LoX
VH/lgaNTui4G2QdA1Rcd+KUiU976Iwgqn3lg+/mtYn3moVB+5AFhfjbW1KYw
B5gTG/mQ+ZEOyeeQ1Wc6dCojmXegyOHoZCT7GCod5loguceh3kH9PZJ7DzQ5
6Coi+edBq4MYH5J/GTod2NKQwkOhx6FiN1J4OfQ7OLp/rPu/ZI0tAH9WYyw=

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w+8d2L9UBuu4gDmb5h7oEx098FrakYQvsKc
A8Kiccv3mBhD+BNmHeBwnDnt8HxNCJ9h5oHq334irRJcEH7B9APPVxbEycWx
HQDzH0w90BGqeeP39Hv7wfyAKQfEXu/WV9CE2ndg0oGdcllBK4vNIXyDiQfk
s0Wv7vthD+E79B+4es4n5l2yHdQ9PQdcRdmltvlB3cPQeaBH6rGFxCERCP9B
64Ge6bprfHZwQuw/0HSg9O251XE3lkLsd6g/UPpbU1meRQeqv/KAf9ERccuj
UPsOFB1YsXoOz5JjrlD5zANKOwTnHYyA8SMPqKRn1ZvV2TrAgvBzTEWuhZ8a
TN4h7JBWf5wm0wGofodWwdUPnk/igbqnyMG3M273TmM5mP0O5XOrCtYXWkD9
W++w7FYze9U2J6h7mhyktacmdKx2hvnPgYPj4ZOPDTD7Ox2OX3jHpTNDGxY+
Dls8hF4eWvbeHhp+DmnR66exlTAfgIavw+KeyONrFgnAwt+hcsscsStC+g7Q
+HEI3V5c4CYAdc+DqQ5f+lnmN4dB+QXTHfjnsgtctDeA2j/T4eE73vX8F4Ug
/AmzHFz6NkWHcvBC7FOY43Brt+c90SOCEP6GuQ7HYtv29in+gbpvvoPAXPYt
ujUqDgBs5sWD
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5305142688981533`*^9, 
  3.531595299114694*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"L2", "=", 
    RowBox[{
     RowBox[{"Round", "[", 
      RowBox[{
       RowBox[{"Length", "[", "CPrxT", "]"}], "/", "2"}], "]"}], "+", "1"}]}],
    ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"\[Kappa]", " ", "=", " ", 
    RowBox[{
     RowBox[{"dF", "/", "dx"}], " ", "in", " ", "linear", " ", "regime"}]}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kx", "=", 
   RowBox[{"20", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ky", "=", 
   RowBox[{"20", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kz", "=", 
   RowBox[{"20", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dz", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "\"\<\[Kappa]x [pN/\[Micro]m]\>\"", ",", "kx", ",", 
   "\"\<\[Kappa]y [pN/\[Micro]m]\>\"", ",", "ky", ",", 
   "\"\<\[Kappa]z [pN/\[Micro]m]\>\"", ",", "kz"}], "}"}]}], "Input",
 CellChangeTimes->{{3.5298286377336273`*^9, 3.529828749203747*^9}, {
  3.5298287856694613`*^9, 3.52982878758568*^9}, {3.529828842488596*^9, 
  3.5298288461040497`*^9}, {3.52982888590906*^9, 3.529828936400158*^9}, {
  3.5298290533730497`*^9, 3.529829056731206*^9}, {3.52982919023219*^9, 
  3.529829191973878*^9}, {3.529829222486904*^9, 3.529829339299202*^9}, {
  3.5299441197428093`*^9, 3.529944123239312*^9}, {3.530519527745768*^9, 
  3.530519543737301*^9}, {3.5305197406762247`*^9, 3.530519742115*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[Kappa]x [pN/\[Micro]m]\"\>", ",", "44.5826884317874`", 
   ",", "\<\"\[Kappa]y [pN/\[Micro]m]\"\>", ",", "42.415731728533196`", 
   ",", "\<\"\[Kappa]z [pN/\[Micro]m]\"\>", ",", "82.8821429783299`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.531632683021289*^9}]
}, Open  ]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 2 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["EXACT",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm): Filling: 100%, f=wa"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
  3.529650479942967*^9, 3.52965049129294*^9}, {3.5298232366357327`*^9, 
  3.529823237313415*^9}, {3.5305142430551853`*^9, 3.530514250278132*^9}, {
  3.530519801991267*^9, 3.530519818692265*^9}, {3.530527096508309*^9, 
  3.530527097550761*^9}, {3.53147322825273*^9, 3.5314732376114197`*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"w0E", "=", 
   RowBox[{"4.5", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"xmax", "=", "1000"}], ";", 
  RowBox[{"zmax", "=", "2000"}], ";", 
  RowBox[{"dx", "=", "100"}], ";", 
  RowBox[{"dz", "=", "100"}], ";", 
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0E", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", 
    RowBox[{"\[Lambda]", "=", "1064"}], ",", "s", ",", "w0", ",", "l", ",", 
    RowBox[{"R", "=", "1000"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "x0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "0", ",", "y0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{
           "0", ",", "0", ",", "z0", ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "1", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "zmax"}], ",", "zmax", ",", "dz"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dz", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, {3.52981742446567*^9, 
   3.529817434355237*^9}, {3.52981750666547*^9, 3.529817571774962*^9}, {
   3.529822681357785*^9, 3.529822684743106*^9}, {3.529823002654579*^9, 
   3.5298230115152397`*^9}, {3.5298230459221354`*^9, 3.529823149205222*^9}, {
   3.529823179554194*^9, 3.52982319486631*^9}, {3.529823268043702*^9, 
   3.529823299249206*^9}, {3.5298275954650307`*^9, 3.529827600474769*^9}, {
   3.5305142540850277`*^9, 3.530514264252761*^9}, {3.531473247915064*^9, 
   3.531473248402264*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "2.8100000000000004`*^-7", ",", "1064", 
   ",", "0.42319979669763036`", ",", "0.281`", ",", "0.6639889768207288`", 
   ",", "1000"}], "}"}]], "Output",
 CellChangeTimes->{3.5305142688981533`*^9, 3.530519850713828*^9, 
  3.5314733002916183`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QfuXGbeHHQzZC+Yr9BzwF5J+DZvdwqEz9B5
IGXNMwf3SdkQ/oPWA8blcj/PTMiD8A80HXjycu8dN3Mo36H+AIeCCNvG71D1
DJUHmi8ve3HmaQZUfdGBHA37yD6hVKh85oGH8v7CSfPiofzIA2e8XYTOWgfu
hTnxYYxk/8H6J1ZQeYekGWB5W6h+hxUxYP22UPMdvtiCzYfKVzooPALbbwt1
n8MDTbD7oOqbHLjeg91vC/Wfw6xSsP+g+jsd7i8E+98WGj4Oovzg8IGa1+8Q
uAQcfrYAB5pqsQ==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QdarPec5mNJ3wvmK/QcaDL/YJa2OxvCZ+g8
YBT2i235mTwI/0HrgTOVWuaXV+RD+AeaDuicKWjKbIDKO9Qf0NIyc1TkyIHq
rzxgZSKgvvByBlR90YGPNq2K9y6lQOUzD0h6hPOpvYiD8iMPnHjcsFh7S8Be
mBOz2M/nt7gt3gWVd/hzFyxvC9XvUOAE1m8LNd/B2xpsPlS+0uEaxH5bqPsc
9uuA3QdV3+Sw7hzY/bZQ/znUQPwH1d/p4BMI9r8tNHwcvPTA4QM1r9/hhj44
/GwBGxBnHA==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w/k5/5wPKaTsBfM3zD3QJDUGRb2inAIX2HO
AZ/i3zNMHhtC+BNmHWBcmmC27JabLcSAmQfkZh0x6W/wgPALph+Y+fj5Mt8s
I4j6B1MPlAucjzLbEgvhB0w50L5Rui7DOx3CPzDpwKOtBwQ6P6dA+AYTD7w6
u8y3Vd8XwnfoP+Ca65oefzwUYr5Cz4E5mc81Fe+nQe3vPGBYKZncqp4C4T9o
PVDA2GL8z0Mfwj/QdMB0QYlfTB7UPof6A69Vz/S0upRC+AyVB57n1kWG/4by
DxQduFDtZJv+JwMqn3lgQsDaS9ENnlD7Ig/cmbj2+6wphbawIJS3TQtfsrAc
Ju9wuv3RxAkVRVB+pkNlWNwx7wvBUPcUOeyvnClw8XAyzH6HyZJP9bsmFcHc
5yCTYOn0Vq4Q6p4mhxqDQIs5C6Oh4dnqwFKzI2tVdiTM/w7FcRVLZK/nw8LH
wadtL/f/BVD3OfQ73D2q/XDarnRbaPg67FNaGmD8DRp/ByY5VIfXcS9+4g+L
H4cp/iXH59iFwuLPQdwySFVrq+leaPw6cOhnGZwyCYLFv8OlDfG1FosSbKHp
w4EpdvbOmow4qHvmOHAsUcq/vwyaPjbMdQi8P2Od/wVHqH/nOxS83VJ1+3fw
XgCwvdVg
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qei+h+bSj2WcQDzFXoObM+sWSdVYgrhM3Qe
6Gddnv3RzQXCf9B6wHZd78mIu34Q/oGmA+fUTC/GrQqB8B3qDxRVszglNkVC
9VcecH9V6+1+KRaqvuhA7/pKQa89CVD5zANbK9KUD0slQfmRB/S8+JRP3oTx
GRgyPJD5kQ7zipHVZzpcWY5k3oEiB+nrSPYxVDrsS0Vyj0O9Qxo/knsPNDks
qUXyz4NWh9aryxD+Zeh0eC2AFB4KPQ7OiY8Q4eXQ77CNT+Muc/vZvQC4qGLN

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qc87PlStj3WdwDzFXoOsE+bLCQwxRHCZ+g8
sFnh/0kjex8I/0HrgTduz5f4zA6G8A80HXB5tHXzyscREL5D/QHde3t+teyL
heqvPLCDc866RayJUPVFB55vWGrmejkJKp95QFdre8gtzRQoP/JA3KfizwyP
YXygCSj8SIcOFPWZDo0bkcw7UORQzoVkH0OlQ999JPc41DsYP0Zy74Emhyx3
JP88aHU4o4jkX4ZOh8szkMJDocfBJhwpvBz6HXyemAWZC2yxBQC1KmmT
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w+8E217Z5Wp5gDmb5h7wHyX+4ptocYQvsKc
A32nn552fGQC4U+YdeDnesNP394YQPgMMw8cufQtyjhWE8IvmH6g6p1J+/pe
HQj/wdQDqs551dcmWED4AVMOLGEpuswf5QLhH5h0IMrozcFXs70hfIOJB7LV
Eq6+UfKD8B36DyzTzOL2j/WCuqfngPcWSz6dQieo/Z0H2JMV1H+8NoPa13rg
rcKXyYYTTaHmNx3YcUv1WMQzqHqH+gPZNplHRC4GQPVXHtASiFgWkBcBVV90
YG74h2sKh2Kg8pkHzupMVStbHg3lRx7getBS3Dwh1AEWhBcf1hkwHPKCyTsc
e8JeE/PGGqbfYS5ntG4yP8w9RQ4uT457RSQ4wux3+HOq9KWGHcy/9Q7zPx1l
deENhbnfQVom/t2FwnCY/xymrkj2crOD2d/p4Bc9z1G21B8WPg6O+YIhi+yc
YeHncOxYRttXHjNY+Dr0flVReCpkBAt/h7ulFe5fZpjD4seBh5F5xYUvdrD4
czB2yfvMmu0A4RdMd+D3PHlnTrsV1P6ZDvHykatdmPUg/AmzHPhlNnEdfyII
dc8cBwaOfLHHEqfswfwNcx2aLiUvFwrggrpvvkOR7+z7KjkqDgB7ZsMd
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5305142688981533`*^9, 3.530519850713828*^9, 
  3.5314783943109293`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"L2", "=", 
    RowBox[{
     RowBox[{"Round", "[", 
      RowBox[{
       RowBox[{"Length", "[", "CPrxT", "]"}], "/", "2"}], "]"}], "+", "1"}]}],
    ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"\[Kappa]", " ", "=", " ", 
    RowBox[{
     RowBox[{"dF", "/", "dx"}], " ", "in", " ", "linear", " ", "regime"}]}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kx", "=", 
   RowBox[{"20", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrxT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ky", "=", 
   RowBox[{"20", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPryT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dx", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kz", "=", 
   RowBox[{"20", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{"L2", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{"CPrzT", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"L2", "-", "1"}], ",", "2"}], "]"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"dz", " ", "nm"}], ")"}]}], "]"}], "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], "*", 
    SuperscriptBox["10", "12"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "\"\<\[Kappa]x [pN/\[Micro]m]\>\"", ",", "kx", ",", 
   "\"\<\[Kappa]y [pN/\[Micro]m]\>\"", ",", "ky", ",", 
   "\"\<\[Kappa]z [pN/\[Micro]m]\>\"", ",", "kz"}], "}"}]}], "Input",
 CellChangeTimes->{{3.5298286377336273`*^9, 3.529828749203747*^9}, {
  3.5298287856694613`*^9, 3.52982878758568*^9}, {3.529828842488596*^9, 
  3.5298288461040497`*^9}, {3.52982888590906*^9, 3.529828936400158*^9}, {
  3.5298290533730497`*^9, 3.529829056731206*^9}, {3.52982919023219*^9, 
  3.529829191973878*^9}, {3.529829222486904*^9, 3.529829339299202*^9}, {
  3.5299441197428093`*^9, 3.529944123239312*^9}, {3.530519527745768*^9, 
  3.530519543737301*^9}, {3.5305197406762247`*^9, 3.530519742115*^9}}],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 2 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["EXACT",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm): Overfilled: 200%"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
  3.529650479942967*^9, 3.52965049129294*^9}, {3.5298232366357327`*^9, 
  3.529823237313415*^9}, {3.5305142430551853`*^9, 3.530514250278132*^9}, {
  3.530519801991267*^9, 3.530519804181039*^9}, {3.530527101057568*^9, 
  3.530527102049541*^9}, {3.531588955306552*^9, 3.531588955488166*^9}, {
  3.531589003128653*^9, 3.531589003391317*^9}, {3.531632647085032*^9, 
  3.5316326473883743`*^9}, {3.531632697067637*^9, 3.531632697323008*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"w0E", "=", 
   RowBox[{"4.5", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"xmax", "=", "1000"}], ";", 
  RowBox[{"zmax", "=", "2000"}], ";", 
  RowBox[{"dx", "=", "100"}], ";", 
  RowBox[{"dz", "=", "100"}], ";", 
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0E", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", 
    RowBox[{"\[Lambda]", "=", "1064"}], ",", "s", ",", "w0", ",", "l", ",", 
    RowBox[{"R", "=", "1000"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "x0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
          "0", ",", "y0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",",
            "1", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "xmax"}], ",", "xmax", ",", "dx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{
           "0", ",", "0", ",", "z0", ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "1", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "zmax"}], ",", "zmax", ",", "dz"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dx", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"dz", " ", "nm"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, {3.52981742446567*^9, 
   3.529817434355237*^9}, {3.52981750666547*^9, 3.529817571774962*^9}, {
   3.529822681357785*^9, 3.529822684743106*^9}, {3.529823002654579*^9, 
   3.5298230115152397`*^9}, {3.5298230459221354`*^9, 3.529823149205222*^9}, {
   3.529823179554194*^9, 3.52982319486631*^9}, {3.529823268043702*^9, 
   3.529823299249206*^9}, {3.5298275954650307`*^9, 3.529827600474769*^9}, {
   3.5305142540850277`*^9, 3.530514264252761*^9}, {3.5316327058498573`*^9, 
   3.531632706187891*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "2.8100000000000004`*^-7", ",", "1064", 
   ",", "0.42319979669763036`", ",", "0.281`", ",", "0.6639889768207288`", 
   ",", "1000"}], "}"}]], "Output",
 CellChangeTimes->{3.5305142688981533`*^9, 3.531588982324149*^9, 
  3.531632718190003*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QcUfyxY6hOdsBfMV+g5kMcpfiy2sADCZ+g8
4Ja++XPDkVII/0HrgfzzpdlXZpZD+AeaDshXltwR3l4G4TvUH0hu9ZW9EFIC
1V954E2416Pa0EKo+qIDTv5fm83eZkPlMw8E6sWIfmZNgfIjD0z6L2k2QzN0
L8yJQWx5k7WsX1pB5R2646VA8rZQ/Q484WD9tlDzHfzzweZD5SsdFFLA9ttC
3eeQ0Ad2H1R9k0NtHdj9tlD/ORRA/AfV3+nwLB7sf1to+Dj4/xIDhQ/UvH6H
/Avg8LMFAJIdaf8=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qf6gv/X/91VtBfMV+g5MC9swy0XvTIIn6Hz
gPKlzjA36woI/0HrgflfNWo/NkP5B5oOrP5heE5TrRzCd6g/0LvHt757YQlU
f+WBOz68uvdrC6Hqiw70n9FRX/EiGyqfeaDfv2ibzvlkKD/yQEjUHu+Hp0L2
wpx4aOLZ/k8tK3dB5R0uB4PlbaH6HRJ9wfptoeY7yJ4Fmw+Vr3Tg8gfbbwt1
n4PgAbD7oOqbHM79BrvfFuo/h4BvYP9B9Xc6KJ4H+98WGj4O/AHg8IGa1++w
3gscfrYAVeFwfQ==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w+s8jhu3TkhaS+Yv2HugV37FsmH8sZC+Apz
Dmy0+KX5fo4bhD9h1oHDy+ew3oxRsoUYMPPApMKr748temwD5hZMPxDS5OuQ
/CoIov7B1AMlitILuW+mQvgBUw407OJiNIrNgfAPTDpwPFxI1GhLGoRvMPEA
U81ViaWLofY59B8oXa/Eejg7BmKfQs8B1wXJYlfOZkDt7zxQKeopmVqfCOE/
aD1w71uv/1s9H6j5TQee5x87vfJHEdS8+gNGHVebjDpqIXyGygOVeosVdh6p
gaovOlDw/VRdm1o+VD7zwHmtrcvPWARD7Ys88C9mF9sxnXJbWBDGbOJLtWas
h8k77Oy80nTnegWUn+lwqeNAg7pFgi3UfIc9aw/eCUtLhdnvsLgkWN0guwzm
PgfmtFI15mulMPc7PDy6VWSCTgo0PFsdnkZeWHmxJBLmf4d5n4+ePp9bDAsf
h3vy4rn9S6Huc+h3cLcOXRS3psgWGr4OdyVnrS5ZCA2vA5McWhreadTEMdhC
48fBMyemt+W4Byz+HHqD+vR5AmX2QuPX4bPCUU/Lx7DwmOkgYrbFh2Mx1LwJ
sxxcjv7w/bUa6l+FOQ63TcKuybz1s4WmL4fXznwJAmFWUP/Od5i79tO5O+eD
9gIAtLPYig==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/Qd0PDoCNq5UcwDzFXoO1Cy62t3H5wjhM3Qe
4MzIL2oRDIDwH7QeWGl/jy/YLgLCP9B04ADDMQtvvgQI36H+gIL8trDdk5Oh
+isP3EnPTHGbkgZVX3QgKoIjMP5/BlQ+80CN1Fch591ZUH7kAak5d5ddXZrt
AHPi65nI/EgHVRFk9ZkOtX5I5h0ocrCIRrKPodIhTgDJPQ71DgUfjiLce6DJ
QUcWyT8PWh16XZH8y9DpMD8JKTwUehzmFLUjwsuh30HybqMu16XLewEgQWEL

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQYO/QdWCeb/W/PZ0gHMV+g5cD3qkOe0cB8In6Hz
wBbDrPutE8Ig/AetB0q846ty+OIh/ANNB8SexRpM7UyG8B3qDzTN3pfuL5MO
1V95QLF7yrkbyllQ9UUHtobn7+rpy4HKZx4oU/E12uSaB+VHHjh3d8EbLZ18
B5gTP6HwIx0eoajPdAiMQDLvQJHDRmT7GCodNiK7x6HeYeVTJPceaHJo8UTy
z4NWh3Z9JP8ydDpMiUAKD4UeBysxpPBy6HcwSXKtnHZrgy0AHllnWQ==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQYO8w94WHxsubVD0wHM3zD3wKH3a97OfWMG4SvM
OdD3+0WtxXUrCH/CrAOvv8bPWMcN5TPMPHDvc5ueyD9LCL9g+gGT9rlGW10d
IPwHUw+oPzz5nP+6O4QfMOVA7dmkC3JXAyD8A5MOBByv23XgcAiEbzDxgOa2
fQc27guF8B36DyQv+Zm22CMY6p6eAwXffxWc+OkLtb/zwLnmT5P0XkHNf9B6
YM6GMu8fUV5Q85sObN53zu7Ifqh+h/oDfG1n3jf/ioXqrzzw56fZ32M/kqHq
iw7smO/MGbE6DSqfeUCpvU/W41oqlB95oJ9lgeiRS4kOsCC89lTnu96LCJi8
w1/dlvdmvgEw/Q6/1m1g1/sDc0+Rw+HaxdOfGQXC7HfQnZVd8+BbBMx9Dk/c
N8lOd06Aud/BxyX14SWmJJj/HIISmKVWvEiA+d+B8f+TX8Vi0bDwcfjJZ6g9
9WkQLPwc3r5eeLrktgcsfB08w1qn8R1wgoW/w5mdbtUJK51g8eOQKqSls+Wc
Cyz+HDKqoz9oy7pC+AXTHcxFQoUzVjtC7Z/pYHvwnswbOXMIf8Ish0q/FaFx
KupQ98xx6OIrzP11WwLC3zDXIVJ1tezqvwpQ9813OCJY5/+dVc8BAGV11y0=

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [nm]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5305142688981533`*^9, 3.531588982324149*^9, 
  3.531638208630102*^9}]
}, Open  ]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 2.0 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["w0 = 5.00 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm) Gauss GLMT"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
   3.529646694879952*^9, 3.5296466954395523`*^9}, {3.529649895555183*^9, 
   3.529649917831744*^9}, 3.529659383201119*^9, 3.529686409299822*^9, {
   3.530519868675952*^9, 3.530519872026499*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", "\[Lambda]", ",", "s", ",", "w0", 
    ",", "l", ",", 
    RowBox[{"R", "=", "1"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
           RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", 
           "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{
        RowBox[{"-", "1.5"}], "w0"}], ",", 
       RowBox[{"1.5", "w0"}], ",", 
       RowBox[{"w0", "/", "100"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{"0", ",", 
           RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", "\[Lambda]", 
           ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{
        RowBox[{"-", "1.5"}], "w0"}], ",", 
       RowBox[{"1.5", "w0"}], ",", 
       RowBox[{"w0", "/", "100"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrzTB", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{"CprG", "[", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Lambda]", ",", "0", ",",
           "0", ",", "R"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "l"}], ",", "l", ",", 
       RowBox[{"l", "/", "100"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CPrzTB", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CPrzTB", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzTB", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzTMLA", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"CPrzTB", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"CPrzTB", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "CPrzTB", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTz", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTzMLA", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzTMLA", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";", 
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";", 
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dz", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", 
       RowBox[{"Show", "[", 
        RowBox[{"CPrTz", ",", "CPrTzMLA"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, 3.529659385723439*^9, {
   3.529686422503501*^9, 3.5296864548299713`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "4.9999999999999996`*^-6", ",", "1.064`", 
   ",", "0.025464790894703257`", ",", "5.`", ",", "196.34954084936206`", ",", 
   "1"}], "}"}]], "Output",
 CellChangeTimes->{3.5296569629631166`*^9, 3.5296593886031513`*^9, 
  3.529682347031542*^9, 3.5296864847175303`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw12HtYjNkfAPBpppppmqm5X5pKK1pJ2Ehkpve4l911XZdlLSIiqRbtbmgj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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw12HlcVOUaB/BhH/bZNxgKtdy7daNcmuE85oLcwszUtJtaGm4fTXPBVLTc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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0], LineBox[CompressedData["
1:eJw9lws4VWkXx6ULKRnHteR65Lgkl3PcW2O5pZopd7lVDg5qipIaNXRhokRK
GKVMGk0N1ZhKNKPpJRFyGWmIZIoMRomkphifb7+b8zznOc/77H32u961/mv9
f1szKNJdJC4mJlYz9f3/7/yMtTuMjoWTsP4XUl9FcyC7//03fl+Gk5L5y7nz
CAd0bS8mHZYOJzIpNRFrpOWgJMP9VFFDGFEnTY9sA+Rg1cBkbkdaGPGoFB4Y
vSIHj22vFsxzCyPNtpd6oyblQJTpd8uEE0ayYu5WV3nIw+iAREXAo1BSZ3RM
f/wneUjA4vqkjFDy2HWTUF1cAThZQU+ue4USN5Xj8yFAAS78I/OyUzGUhIm3
LQgqVQATuztvJNtEZPfcs2dzFBWBZG0d558WEbWqHpv3exTBdVBJcrOfiBgq
WBTHP1GELrv7cskqIqKhoqX+5edKEPFdlHrx0xBy9Psj7cKLSjAxqG7w17kQ
ouScc7J5kTKk2NebL9gcQoQv95lf3acMS7P32ZtrhJAw672zZvUrQ+Er3nrh
82Din/sqotN3MVg7PPZNuRBMWlemr3SvXwy12fGikuBgopC2MTTSYQn4vjba
+UI7mKyqqtVyKlsCfQ6dsdK9QeRtVfyzbgsViDmdfMTyUhAJs/G2CLilAhJD
FhnB4UGEqxAz9rvFUshyfPn9cb0gEn+ud75q2VJYdia98PaAkAhfDcUmOajC
zSHbkp5CIXnndidSpkEVHJ1eVchsF5LOqkbpKn81eHTmTIP1CiGZvcY7oWxQ
DYLeOLeLhgJJjZ/T8OxD6jDi9O7liaJAcqlZqsh7oQYcyrkw/NvOQLJraVJb
j68GfDbsMtFrGkhq7/9XJfhJA2xTP8pq920m7QfyCtd/1ICNll56+7ZuJvG/
zzlivU4TYrt/xqbBTWTSbo222AVNOHNcykcnchMxVrCcfemDJty2EkXGDm8k
R1qcvMzdtKC1525i866NpLNx68DNQi0YS1uSqzsWQH458LuWniQX5G12F++P
CSCcrsrO7FAu8HsbH7Z89CfDqQHh86u54HZSv0c/zp9ss4EtB/S0YcfKw58O
TvqRsMqxuv9SteH4312c1kN+xL48qCB5VBuuplvrG87xI5yJbwTLNi6Dh5Bp
l5DoS3SPn8xqrF4GA31DPk8kfckc5YbOowIdoP3hQ46ZynS4/6ADPKYffMga
Fek5uvI8Vv8byN6aVve5STwIYfS+gfyy7ib35Sceq29vcl97myyJ0oU8Rs/e
pLuX15Tyjy6rXy+Skfx+HobqwTNGr17k9maB7sMXeqw+PYnFu7erNYX6oMLo
0ZOsc218v/y5Pqs/DxJv7CLXHmQAPozePMiC+IDzn/UawNeMvtzJvThuXvHW
5ZDJ6MmdnNLvGyx4s5zVjxvpuec/v/FrQ1YvbmRnidy8iUlDVh+uZJdai9/C
oytYPbiSrqAdNU0cIwhg6u9CEq7IOy45ZwTZTL3Xk4H0bdva5YyhjanvOjKG
VW4CX2O2nl+Sfzd4d8fmGoMrU78vyLizk3lGtzGkMPVaS6pj6sJ9dE3Y+qwh
dy9vuXJxmwlIMvVYTXS3FXp5F5mAI5N/Z+KY2z1s/9YEDjL5XkVsfVYF25uZ
svl1ItcKb8zW32MK40w+HUl6+c6G+mJTsGTy50AyJMZPiI2asv1oT2Lah7Qy
jPlsfuzIUMdEvu9XfHjD5AOJ8voLVZr5fPBhzm9LchfYcu6089nzAslol7Ad
XyRgz2dDDn2Yd6QIBfCAOY8VUeV4SVyJFAAy8VuQiqo98hU5AjZeM+LfXphf
XSlg4+MTya72wlMDAihi4jEhD15djp1caAauzP5GZOgrK52/DczY/QzINRWJ
Bj1nM/b5PPL00ao5BZvMwJh5Hpek9ayTXR9lBoHM/9VJRHGytVj89P1KJCDi
zsS11Kk1c12GGA45263LNAMxZj15V34yN6Y5e2rNfhZJaJZZT60P0uu2vCWt
jxJPTa9l8EZ0v6AseWo/+nwMIX8O98TN7I9x4xXnZLZP7Ufjw8G83VwXn6nz
0PhR5Pn0xK+2U/fT86HuarW2bdzp/xth21/7kr6dbQalND/YUu6+l/uXgH0e
H9/Xt8RF3J7KP80v5ii3TaakCWA1zT/qXdzx4+UgATTR+qBWYvXooKkAfGj9
kOdS1J8oJpiuLxpNbjqfX8dn97fFkc6Et9EZfBil+sDNt4a4PH8+G48dRvT8
ljCgzp/WF9p5PdB5/cIUVlL9Ycpai9OB+aYg9orRJ2aWhJyNDDGFSqpfzEi+
NuDMNYVvqb7xqTKIKzw3YeN3RvGh1jGxXBNYSPsDm8VvrhX4mbDnWYNSi6Qb
HiuYwAnaX+jR4XhY6g9j8KT9hwePG2e+O2YMyrQ/scbd0Kx01Uz/YjT32I87
ZxnDWdrfmJ5WINwfM9P/6HPog2PM6xXAofMBM2uqC2aLVkzPD8y5cWO7y1ND
+JPOF0zR+ZCf6GkIt+j8wdjPLe821S9n/c4de/4MyXNbvRz20fmFX4h/eKBX
aQB+dL5h3vraHXvsDKbnHx72aC1xI/qgRucjDvZtqGlGffiPzk/U5v00d9E9
PXhB5ytyCpIMFJz1oILOX+R/bn7o/UNdlje80X3EbKLcUxcS6fxGocgh4sAz
HoTS+Y5NI74XLLfOzH/cKHs0ZfS9DuhTf0DPh1FbSpN0QIr6B+4s8XiRtFhn
2l+wiBu3QnR1GTRQ/8GYMhO+m8MyuEb9CaNUO/K+6NCGdOpfqLo7Q95jtzZE
UX/DBf9K6YlktcGd+h+2PSs9vf9nLphTf8T7DfFeOS5cUKT+iae2VGTeGp7x
V7yeUTtSm6kF7dR/Me352z3NNlrwK/VnHMzGoqruGf/GP+ovk/OpmrCf+jv+
KFLf7mulCZuo/+PctUKD/l4NsKd8gCMS51esztIAWcoPGD2pvCvCeYYvsETM
8+SlUXV4S/kDuzL/Lu3aqA7BlE+wrF2QEF07wy9oVSca8bRWAyfKN9ib92Qk
8qoqFFP+QfP0heE3uarAo3yEbuUrLGXPLYXvKD+h2acE792Ll07zFfatzH/Y
mK0Ceyl/YXj1jQoZFRXop3yGzziXE7XPz/AbxuRdTZ/gLYE6ynd4L6w8Pfn6
YrCh/If6mLblN9vF03yIosKLgoONyqBK+RGVJ6Rda4TKkEr5Ei0+efsmjSnB
JOVPLBtSMy1MVYJIyqeYZKonrsNTmuZXHHOSsuqvUAQ3yrcoXxmd1huoCOWU
f7Ev2Vjys1mK03yMuS2Vbzb8oAA/UH7GB/zO50XOCiBH+RorKnbclX49w9+o
a3W9VJglD+8on2OnRKPzeZSf5nfkKiaY3BmUg1bK9/jYJvHbK2fkwJnyP3Zo
tWUHrZ15P0Cr+teLWj5xQI++P6DX2bqGd9c4cJq+X2Cl78d5d4I5LF+FY3Rk
nIH6Eg78D9q7yDg=
          "]]}, 
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJw9lwlcjekXxzMzkRZx2/d9X2/33lQ6etKG0ka3Rdq7miZuMWS5DCpGkiRt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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw12HtcjNkfB/CZ6X5vbk0z070QKk0zExY9B0WUS2hddhHK3RJWspufNr+K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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw92HlclHUeB/ABhmEYYGaYmzlEEMkDlRsq8vl2mGVmHlm6mdeibmlimkft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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1lwk4lekbxs1Uk6lEJlIUlRhaZImoyUuWapos2cfOQVREiy3KlmRLiMqe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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.5296569629631166`*^9, 3.5296593886031513`*^9, 
  3.529682347031542*^9, 3.529687742784203*^9, 3.53147322372057*^9}]
}, Open  ]],

Cell[TextData[{
 "Polystyrene Sphere (",
 StyleBox["D = 0.200 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", ",
 StyleBox["w0 = 0.500 \[Micro]m",
  FontColor->RGBColor[1, 0, 0]],
 ", P = 1 mW, \[Lambda] = 1064 nm)"
}], "Text",
 CellChangeTimes->{{3.5296466147768517`*^9, 3.529646647698447*^9}, {
   3.529646694879952*^9, 3.5296466954395523`*^9}, {3.529649895555183*^9, 
   3.529649917831744*^9}, 3.529659383201119*^9, 3.529686409299822*^9, {
   3.529688874174391*^9, 3.5296888758700857`*^9}, 3.52969073277776*^9, {
   3.52969186065029*^9, 3.529691862207518*^9}, {3.529694444638372*^9, 
   3.529694445511262*^9}},
 FontSize->14,
 FontWeight->"Bold",
 Background->RGBColor[0.9, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"nmed", " ", "2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"N", "[", "P0", "]"}], ",", "c", ",", 
    RowBox[{"N", "[", "w0G", "]"}], ",", "\[Lambda]", ",", "s", ",", "w0", 
    ",", "l", ",", 
    RowBox[{"R", "=", "0.100"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
           RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", 
           "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{
        RowBox[{"-", "1.5"}], "w0"}], ",", 
       RowBox[{"1.5", "w0"}], ",", 
       RowBox[{"w0", "/", "100"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{"0", ",", 
           RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", "\[Lambda]", 
           ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{
        RowBox[{"-", "1.5"}], "w0"}], ",", 
       RowBox[{"1.5", "w0"}], ",", 
       RowBox[{"w0", "/", "100"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrzTB", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{"CprG", "[", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Lambda]", ",", "0", ",",
           "0", ",", "R"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "l"}], ",", "l", ",", 
       RowBox[{"l", "/", "100"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CPrzTB", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"CPrzTB", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzTB", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzTMLA", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"CPrzTB", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"CPrzTB", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "CPrzTB", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTz", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTzMLA", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzTMLA", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";", 
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";", 
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dz", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UzP", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"UzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", 
       RowBox[{"Show", "[", 
        RowBox[{"CPrTz", ",", "CPrTzMLA"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9, {3.523777755661434*^9, 
   3.523777756184473*^9}, {3.529646534502301*^9, 3.529646578692861*^9}, {
   3.529648157017179*^9, 3.529648185338827*^9}, {3.5296490990806847`*^9, 
   3.52964911638566*^9}, {3.5296506138035717`*^9, 3.529650619360673*^9}, {
   3.5296506683450193`*^9, 3.5296506782077703`*^9}, {3.5296555102001038`*^9, 
   3.529655524140951*^9}, {3.5296555695061913`*^9, 3.5296556219717417`*^9}, {
   3.529655677681807*^9, 3.529655764407916*^9}, 3.529659385723439*^9, {
   3.529686422503501*^9, 3.5296864548299713`*^9}, {3.529688878370751*^9, 
   3.529688879068079*^9}, {3.529690735035898*^9, 3.529690735226787*^9}, {
   3.529691722191114*^9, 3.52969172258705*^9}, {3.529694451821196*^9, 
   3.5296944525826483`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.001`", ",", "299792458", ",", "5.`*^-7", ",", "1.064`", ",", 
   "0.25464790894703254`", ",", "0.5`", ",", "1.9634954084936207`", ",", 
   "0.1`"}], "}"}]], "Output",
 CellChangeTimes->{3.5296569629631166`*^9, 3.5296593886031513`*^9, 
  3.529682347031542*^9, 3.5296864847175303`*^9, 3.529688884226591*^9, 
  3.529690735920601*^9, 3.529691880654056*^9, 3.529730145793091*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1mHlcTfkbxyspbTc/krJEGmQdJtHkHI8x9rGEDLLkV9IYUjNkEMOQih9K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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1mHlUVuUWxgEFkfHTgNWgkWaalpbLIdJz2rrUKMSVenHoSioVatm6gHnV
clh6EzIj0UITU0PxplSycMDxHDeKOYAo88fMN38kDjjgiHrx7Oeef1yuw/ee
dz+//e53P7vXxwmT4708PDwGenp4PP1Xnmbu63ItPTrdrJizElU/s5vX9J7k
+m5htZITaf06JMfN3z4b0/OtX2qU5JZJR15MdvNR2+SJ3sW1SmzaqbZXY938
4MzVYRF+9coQ43HzMA+ns/s/GhQ/Y0E3385+b595d6PydLVIq4vN7y5r/6Sz
RelYrGNFF//70UjP7sctirFcmovH//eH+NAlVmWO8bj40PNFV1JH2hTVWNDF
KQ33UzZ525UQY4MuTnvkEfFBlV258nR7LU7O8w1/XLbXoRjLnXKyzfrbYSXV
qWzJePo42We8v+9vSS4lyVjQyeuqRiv9ZrqV94wNdry3pAwyT2pWwo2AnXy2
5w/9i6L/Vu48Xa7NwRMm9SkK++CyUnzh6ePg8Rs+cRVNb1F2PZUvy8FFmZ/G
P/jsirLU2KCD3+LtA3L/c1WZbATs4LqY1hv3dl5T+hsCOri+au7gxsLrivBw
cEzGtWVDlreCh50jPQ+3FD17AzzsfL3h7vS3j9wADzsvvJs3demMm+Bh54mF
H3mv97oFHnbulvla54V7b4FHx3oJR+N6x94GDxsfH3kiNT2oDTxs7GnyH3fq
dBt42DjDqyx1x4o74GHjZP+xW/oqd5V3jAVt7HX8x/NjHt0FDxsf7vtJ2t8n
74GHlS9s5fk+a++Dh7WDx8aGlCkPwMPKYc5LU6f0eagY8iVaed29kMH/vPMQ
PKy8Nmd01tKidvCw8odrdh3elvUIPCxckBk4ZueKx+Bh4ehErp8X+wQ8LLxg
2u75c1/0UIWHhQ9tpm3mNA9VeFi44lDorCQvT1V4WPjLLr3t4Ys8VeFh4VMz
HrxRfNlTFf2beO+0R+Efz/ZSRe8mnnm5R9yZKi9JT78mtlRN+LdlQidV9Gzk
ofd2HNj4VydV9Gvk8J3dowrVzqro1cg/D/QYFXeosyr6NLBr7vyvlDe8VcnP
Bu4x8uoxZY+3KvE3sLoyMWd0Lx9V4q3n/cv3Nfff4oP46tn5Usr1su5dEE89
X0y5Meq577uokk913MvdeUa1l68q+VPHa/6VdvryV76q5EsdD/TdHjag1VcV
+Wt5dXKRT0J8V1XyoZZvPJy9YENNV1UCruV+G8d9Pi/aTzWWa6nhswkaFep+
qoE3o4ZfXXttQ+pAf1V41nCS/zuxq3/xV4VfNWdunOWd0iVAFV7VXPPrsIT4
pADwqea21z7rcqc6ADyquffSY9V+7wSCh5mvHe60bVFmIHiYeWKD65K/RxB4
mHnkwvBTW2ODwKOKy0MT9z7MCwKPKk5p633+gX8weFTxxOCQWV/MDAaPSo67
OcLae2+wKvlZyUNXZj9pvRsMHpXMg75uigk3gUcFP7N9WeT6USbwqOCo8Q9z
02eZwKOCf2q7FRe9zAQe5RzyTcD9HZtM4FHOH76V9NXKHBN4lPOCCflTywtM
4FHGs9IfrkypMoFHGW9eviQxxWUCjzJe7jgzOP+WCTxKedi+lKRej03gUcq7
Z/RZs9m7G3iU8rURC5ND/LqBRwkfW9pHSfbvBh4lnJD6KLquazfwKGHruebB
vh2/Fx4l7D04773H7Sbof4k3PN7QkHvDBL0vsqN9+LAQuwn6XuTKrfs39Sw1
Qc9i/rmuMqbguEm9IA9HRww3t+80qcZ2Xr3AK8JP7DyVYlJXGwEVcdic03FB
c02qxdCjkGN3Z7XUjjGpUuAKeXZG4fg+PU3qZiPe8/xt/PL1l5zB6m1jwXPc
fWPopci1wepEY4Pn2B7b70puv2D1TyOfzvKUoC2hgSeCVF8D0Fne8s2PYXET
gtRPjXw5w1MiaObBykD1tJEff/H0Y5He3aYFqi8ZAP9ia7y59JvSAHWZEfBp
DotWRvQYF6BWG7wLuD00ZM6Vff7qUINvAQfs9xzU9Vl/db0kHL++3f3c2sV+
qtTPk3xwT9ZH35V0Ba+TnPBMVMXLL3cFn3z+Pqzp/pIEX/DI53M16+y/53WB
/id4YEj88MY2H+it8/xfU3qMeNMH+mqcPK81ovlTb+h5jH8dm58Rkt4Z+h3l
RdGB2Vf1TtDrCPf7emqPXTYv6HOYx81Is33u5aXmG9vP4+7Hy02Le3qqS4z4
D3Ld0AvFT4Z4qG8a8R7g9Khti5elPlaajfj28aam1ILaPe1KprHBXI7ytb+S
rj9Qco3P5fCC9ie/v1J0T3nJ2O+f7IyIWh9cdkdZb+wvm93jJgdWlt1WTMZ+
dvPyF557ob34prLS+P4uXjzvl7cDT7cqrcb3dvCqkrVz+86/quQb62/nLYua
C4a9+7eSKQeE3z8/pSr+eSd+n86rI8b6mZst+Pt1XBTzRfH0+Bq8X82//7Qk
NOxmCf6/kM1DFu+ccztf+X+H5fP27lWpo6fk4T3hvYbfU7b8XsP6hPXxPp3w
fQ37I+wPf7+dMmT/GuIjxIff7yLEr0Efgj5YL5tuin7am6Iv3RR9sX4OrRL9
tT3Ch6YJH3xvH2UKPy1C+FKW8MX3D5JV+OvID0J+6MgfQv7oyC9CfunIP0L+
6chPQn7qyF9C/urIb0J+68h/Qv7rOB+E86Hj/BDOj47zRThfOs4fHZDzp+N8
Es6njvNLOL86zjfhfOs4/4Tzr6M+EOqDjvpBqB/6PKkvNFXqix4g9YdQf/Rc
qU/0odQnPUbqF6F+6fekvlGo1Dd9q9Q/Qv3TR0l9pDipj9CzkFA/ddRXQn2F
vhcI9VdHfSbUZ+hdTKjfOuo7VUl9h/4XCfVfx/1AuB/Ao4RwfyCeErLJ/QI+
JYT7B/GV0HG5n8CrlHB/IV9KKVvuN/ArpeFy/+lyP5QR7kfwLCPcn9CjjGbK
/Qq+5fSl3L/Qp5xwP4N3OeH+hl4VtFHud/CvoPfl/od+FRQq/QHyoZLQP0DP
SkJ/gfyopFnSf0DfKkJ/gnypolXSv0DvKqqU/gb5Y6YI6X+gv5nQHyGfzNQi
/RN4VBP6K/CoJvRf4FFN6M/Ao5q2Sf8GHjWE/g75V0OvSP8HHjV0UvpD8Kil
/tI/gkctXZf+EjxqCf0neNTRAOlPwaOO0L+CRx2hvwWPekL/Cx71ZJf+GDzq
6YD0z+DRQCOkvwaPBgqX/hs8Gsgq/Tl4NNJm6d/Bo5FekP4ePBoJ/T94NFGd
+APwaKLZ4h/Ao4n+EH8BHhaC/9AHiD+hRPEnOvwLwb8gPgvtF38DXhZKEv+j
XxR/RGPEH2nwTwT/pL0o/oo+Fn+lwX/R9+K/NPgzgj/T4N8I/k2DvyP4Ow3+
j+D/NPhDgj/U4B8J/lGDvyT4S03ywUabxH9q8KcEf6rZxL/SEfGvGvwtwd9q
ki92ChL/q8Ef0wfij7UU8c+0QPyzBn9N8Nea5JOdxor/1uDPCf5cEx4OqhT/
rsHfU634e014OOh18f8a5gOE+YAmPBwUJfMD8HAQ5gvg4aSLMn8ADydhPgEe
Ttok8wvw6Hgv8w3wcJJV5h/g4STMR8DDRZifgIeLVsl8BTxchPkLeLgoUuYz
4OEizG/Aw0WlMt8BDzdh/gMebhok8yHwcBPmR+Dhpj9kvgQebloj8yfwcNMK
mU+BRzNhfqX9D5Z7cps=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0], LineBox[CompressedData["
1:eJw1lws4lGkbxx2WVJSVSqlkUzoRKkv76EmldomQ0lql1arkq1glWSVsUW0O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          "]]}, 
        {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJw1lws4lGkbx2cUSaRvaROdfFKoJDpYPdOtjdLJ1pYNK9sWqXTwLVG0YtlY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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxNmHlczekXx5OlZCzZhqJCQyjKUmrkGMRgYjDWqbE0xj62GEvZ9x9lLG2T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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxVmHtYlGUaxsmssBVjU2vVzdS0UAPc1sxW9NGt1DVtAcsUsIPJwUNGrnlC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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw9lws4VPkbx8+ZbFEk0Y1S2taySrVKVuVVZGvp5lKJSKti2002aVdX0k6U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         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.5296569629631166`*^9, 3.5296593886031513`*^9, 
  3.529682347031542*^9, 3.5296864847175303`*^9, 3.529688884226591*^9, 
  3.529690735920601*^9, 3.529691880654056*^9, 3.529731728958497*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gold NPs", "Title",
 CellChangeTimes->{{3.498207462726493*^9, 3.4982074631490097`*^9}, {
  3.529838071026528*^9, 3.529838072210723*^9}, {3.554279109365293*^9, 
  3.554279110845201*^9}},
 Background->RGBColor[1, 0.9, 0.8]],

Cell["z - Pressure Ratio Red/Green, R=30nm, P=1mW", "Subtitle",
 CellChangeTimes->{{3.5091713562466*^9, 3.50917138996631*^9}, {
  3.515323718354487*^9, 3.515323718522319*^9}},
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], 
  RowBox[{"(*", 
   RowBox[{"[", "W", "]"}], "*)"}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"s", ",", "w0G", ",", 
   RowBox[{"R", "=", "0.03"}], ",", "\[Lambda]", ",", 
   RowBox[{"RR", "=", 
    RowBox[{"CprG", "[", 
     RowBox[{
     "0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "0", ",", "0", 
      ",", "R"}], "]"}]}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"FzGreen", "=", 
  RowBox[{"Pf", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RR", "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", 
     RowBox[{"RR", "[", 
      RowBox[{"[", "10", "]"}], "]"}]}], "}"}]}]}]}], "Input",
 CellChangeTimes->{{3.5165583233886766`*^9, 3.516558323708356*^9}, {
  3.516558509166939*^9, 3.516558539043171*^9}, {3.516597107441594*^9, 
  3.5165971130496407`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.2448537586029159`", ",", "2.6`*^-7", ",", "0.03`", ",", "0.532`", ",", 
   RowBox[{"{", 
    RowBox[{
    "1.0765445302307354`*^-14", ",", "2.1867172038301503`*^-15", ",", 
     "8.578728098477203`*^-15", ",", "0", ",", "0", ",", 
     "9.607366041887598`*^-15", ",", "0.561158`5.899600156533952", ",", 
     "0.035021`4.694843540729652", ",", "0.020095`4.453603008360038", ",", 
     "1.2582667028425312`*^-14"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.516558540373171*^9, {3.516558578279703*^9, 3.516558599726983*^9}, 
   3.5165586562774763`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.0179848949294393`*^-13", ",", "3.952623316749709`*^-13"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.516558540373171*^9, {3.516558578279703*^9, 3.516558599726983*^9}, 
   3.516558656280739*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"s", ",", "w0G", ",", 
   RowBox[{"R", "=", "0.03"}], ",", "\[Lambda]", ",", 
   RowBox[{"RR", "=", 
    RowBox[{"CprG", "[", 
     RowBox[{
     "0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "0", ",", "0", 
      ",", "R"}], "]"}]}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"FzRed", "=", 
  RowBox[{"Pf", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RR", "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", 
     RowBox[{"RR", "[", 
      RowBox[{"[", "10", "]"}], "]"}]}], "}"}]}]}]}], "Input",
 CellChangeTimes->{{3.509170623638093*^9, 3.5091706390950603`*^9}, 
   3.5153184577926702`*^9, {3.5153878879521646`*^9, 3.5153878881338*^9}, 
   3.516558804260174*^9, {3.5165588495984173`*^9, 3.516558850054112*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.23746097007366904`", ",", "3.2`*^-7", ",", "0.03`", ",", "0.635`", ",", 
   RowBox[{"{", 
    RowBox[{
    "9.77482483340465`*^-16", ",", "5.21017180189279`*^-16", ",", 
     "4.56465303151186`*^-16", ",", "0", ",", "0", ",", 
     "8.856991324725013`*^-16", ",", "0.565162`5.902687951176385", ",", 
     "0.036293`4.710337866544962", ",", "0.020295`4.457904053485287", ",", 
     "1.1415268857811449`*^-15"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.509170630059914*^9, 3.5091706438740396`*^9}, 
   3.515318614058926*^9, 3.515387927539249*^9, {3.516558835400468*^9, 
   3.5165588511159077`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.8367315358453592`*^-14", ",", "2.3672580826363953`*^-14"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.509170630059914*^9, 3.5091706438740396`*^9}, 
   3.515318614058926*^9, 3.515387927539249*^9, {3.516558835400468*^9, 
   3.516558851118938*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FzGreen", "/", "FzRed"}]], "Input",
 CellChangeTimes->{{3.509170678268421*^9, 3.5091706806661243`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"16.43127934611525`", ",", "16.697052787534282`"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.509170681052122*^9, 3.5153186201874533`*^9, 3.5153879749544287`*^9, {
   3.516558843383833*^9, 3.5165588725036*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cAbsGreen", "=", "8.578728098477203`*^-15"}], ",", 
   RowBox[{"cAbsRed", "=", "4.56465303151186`*^-16"}], ",", 
   RowBox[{"cAbsGreen", "/", "cAbsRed"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.515388000739665*^9, 3.5153880301184263`*^9}, {
  3.516558902018207*^9, 3.51655890833041*^9}}],

Cell[BoxData["18.793822968042416`"], "Output",
 CellChangeTimes->{3.515388030429948*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["532 nm, w0 = 300 nm", "Subsubtitle",
 CellChangeTimes->{{3.498306046654065*^9, 3.4983060503718853`*^9}},
 Background->RGBColor[0.88, 1, 0.88]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PlotFU", "[", 
    RowBox[{"RR_", ",", "\[Lambda]\[Lambda]_", ",", "cc_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Lambda]", "=", "\[Lambda]\[Lambda]"}], ",", 
       RowBox[{"R", "=", "RR"}], ",", 
       RowBox[{"c", "=", "cc"}], ",", "CPrTx", ",", "CPrTy", ",", "CPrTz", 
       ",", "UxP", ",", "UyP", ",", "UzP", ",", "CPrxT", ",", "CPryT", ",", 
       "CPrzT", ",", "UxT", ",", "UyT", ",", "UzT", ",", "dz", ",", "dx", ",",
        "kB", ",", "T", ",", "MaxPrx", ",", "MaxPry", ",", "MaxPrz", ",", 
       "MaxPrxPos", ",", "MaxPryPos", ",", "MaxPrzPos", ",", "MaxUx", ",", 
       "MaxUy", ",", "MaxUz"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"CPrxT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x0", ",", 
           RowBox[{"Pf", " ", 
            RowBox[{
             RowBox[{"CprG", "[", 
              RowBox[{
               RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", 
               "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
             RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x0", ",", 
           RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.01"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"MaxPrx", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{"Last", "/@", "CPrxT"}], "]"}], "]"}]}], ";", 
      RowBox[{"MaxPrxPos", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"CPrxT", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"Last", "[", "#", "]"}], "]"}], "==", "MaxPrx"}], 
            "&"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"CPryT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y0", ",", 
           RowBox[{"Pf", " ", 
            RowBox[{
             RowBox[{"CprG", "[", 
              RowBox[{"0", ",", 
               RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", 
               "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
             RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y0", ",", 
           RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.01"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"MaxPry", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{"Last", "/@", "CPryT"}], "]"}], "]"}]}], ";", 
      RowBox[{"MaxPryPos", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"CPryT", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"Last", "[", "#", "]"}], "]"}], "==", "MaxPry"}], 
            "&"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"CPrzT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"z0", ",", 
           RowBox[{"Pf", " ", 
            RowBox[{
             RowBox[{"CprG", "[", 
              RowBox[{"0", ",", "0", ",", 
               RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Lambda]", ",", "0",
                ",", "0", ",", "R"}], "]"}], "[", 
             RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z0", ",", 
           RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.05"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"MaxPrz", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"Abs", "[", 
         RowBox[{"Last", "/@", "CPrzT"}], "]"}], "]"}]}], ";", 
      RowBox[{"MaxPrzPos", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"CPrzT", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"Last", "[", "#", "]"}], "]"}], "==", "MaxPrz"}], 
            "&"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"CPrTx", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"CPrxT", ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"cc", ",", "0", ",", 
              RowBox[{"1", "-", "cc"}]}], "]"}], ",", "Thick"}], "}"}]}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"CPrTy", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"CPryT", ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"cc", ",", "0", ",", 
              RowBox[{"1", "-", "cc"}]}], "]"}], ",", "Thick"}], "}"}]}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"CPrTz", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"CPrzT", ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"cc", ",", "0", ",", 
              RowBox[{"1", "-", "cc"}]}], "]"}], ",", "Thick"}], "}"}]}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"kB", "=", 
       RowBox[{"1.3806505", "*", 
        SuperscriptBox["10", 
         RowBox[{"-", "23"}]]}]}], ";", 
      RowBox[{"T", "=", 
       RowBox[{"273.15", "+", "24"}]}], ";", 
      RowBox[{"dx", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"CPrxT", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
          RowBox[{"CPrxT", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";", 
      RowBox[{"dz", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"CPrzT", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
          RowBox[{"CPrzT", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"UxT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"CPrxT", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
            RowBox[{"dx", "/", 
             RowBox[{"(", 
              RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"MaxUx", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"UxT", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"Nearest", "[", 
               RowBox[{
                RowBox[{"First", "/@", "UxT"}], ",", "0"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"UyT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"CPryT", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
            RowBox[{"dx", "/", 
             RowBox[{"(", 
              RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"MaxUy", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"UyT", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"Nearest", "[", 
               RowBox[{
                RowBox[{"First", "/@", "UyT"}], ",", "0"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"UzT", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"CPrzT", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
            RowBox[{"dz", "/", 
             RowBox[{"(", 
              RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], ";", 
      RowBox[{"MaxUz", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"UzT", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"Nearest", "[", 
               RowBox[{
                RowBox[{"First", "/@", "UzT"}], ",", "0"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"UxP", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"UxT", ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"cc", ",", "0", ",", 
              RowBox[{"1", "-", "cc"}]}], "]"}], ",", "Thick"}], "}"}]}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"UyP", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"UyT", ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"cc", ",", "0", ",", 
              RowBox[{"1", "-", "cc"}]}], "]"}], ",", "Thick"}], "}"}]}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"UzP", "=", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"UzT", ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"RGBColor", "[", 
             RowBox[{"cc", ",", "0", ",", 
              RowBox[{"1", "-", "cc"}]}], "]"}], ",", "Thick"}], "}"}]}], ",", 
         RowBox[{"Joined", "\[Rule]", "True"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
           "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "CPrTx", ",", "CPrTy", ",", "CPrTz", ",", "UxP", ",", "UyP", ",", 
        "UzP", ",", "MaxPrx", ",", "MaxPry", ",", "MaxPrz", ",", "MaxPrxPos", 
        ",", "MaxPryPos", ",", "MaxPrzPos", ",", "MaxUx", ",", "MaxUy", ",", 
        "MaxUz", ",", "CPrxT", ",", "CPryT", ",", "CPrzT", ",", "UxT", ",", 
        "UyT", ",", "UzT"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499064523230731*^9, 
   3.499064681763082*^9}, {3.499064821611169*^9, 3.499064824682185*^9}, {
   3.4990651548707743`*^9, 3.4990651857236443`*^9}, {3.499065299029963*^9, 
   3.499065488473794*^9}, 3.4990656092369413`*^9, {3.499066393474626*^9, 
   3.499066440510449*^9}, {3.499066519235929*^9, 3.499066520309252*^9}, {
   3.499066738639543*^9, 3.499066747304653*^9}, 3.4990701404114313`*^9, {
   3.499073166168729*^9, 3.499073208846313*^9}, 3.499073770486094*^9, {
   3.499079457230537*^9, 3.499079474116035*^9}, {3.499083943742023*^9, 
   3.499083960154992*^9}, {3.4995917312637777`*^9, 3.4995917711529713`*^9}, {
   3.500356056690568*^9, 3.5003560607195473`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"RRT", ",", "PT", ",", "Ri", ",", "LR"}], "]"}], ";", 
  RowBox[{"RRT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"R", ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "0.005", ",", "0.075", ",", "0.005"}], "}"}]}], 
    "]"}]}], ";", 
  RowBox[{"LR", "=", 
   RowBox[{"Length", "[", "RRT", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RRT", "[", 
        RowBox[{"[", "Ri", "]"}], "]"}], ",", 
       RowBox[{"PlotFU", "[", 
        RowBox[{
         RowBox[{"RRT", "[", 
          RowBox[{"[", "Ri", "]"}], "]"}], ",", "\[Lambda]", ",", 
         RowBox[{"Ri", "/", "LR"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ri", ",", "1", ",", "LR"}], "}"}]}], "]"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.4990657414254837`*^9, 3.499065773922699*^9}, {
   3.499065817477016*^9, 3.499065822517425*^9}, {3.4990663608275337`*^9, 
   3.4990663773893003`*^9}, {3.499066879366581*^9, 3.499066914857232*^9}, {
   3.499069974953237*^9, 3.4990700629519157`*^9}, {3.49907097271624*^9, 
   3.499070991527178*^9}, {3.4990716920544367`*^9, 3.499071717100708*^9}, {
   3.499072316055421*^9, 3.499072327391192*^9}, 3.499074027861108*^9, {
   3.499074233454485*^9, 3.499074233590016*^9}, {3.499079840994349*^9, 
   3.4990798779877872`*^9}, 3.499080153434732*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "13", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prx) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Prz/10, Blue: Prx, Red: Pry\>\""}], "}"}]}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "14", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Pry) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "15", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "9", "]"}], "]"}], "/", "10"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prz) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "13", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Ux/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Ur/10/kbT, Blue: Ux/kbT, Red: Uy/kBT\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "14", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Uy/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "15", "]"}], "]"}], "/", "100"}]}], "}"}], ",", 
             
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Uz/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(F): Pos\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", "\"\<Black: z, Blue: x, Red: y\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "11", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fy): y-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "12", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fz): z-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtMlWUYx09AolR2gUUiIJUUEJcQGNhefGbMUFGHEBPiMoVxSpCEEIZc
9JDCyHDcDLkddUAwrBAWJtALD5eDgCKCXA7X0wFlJIiSBK3BqPf7vtd3Y+zs
+77/9/z/z/P8vndDT/qE68hksnD2J/yXjhazb27R1RwPJEFZbctWQX/gikfT
/SfvHSX15mnzh+s1+HT5YtajP0OJUbXnVKKRBlcVlY/GNstJjLuBuix6Ev/9
a7sJLTlO7vUIZwJTMktX7YqiiLUoOIF35y1u2unHEEHNPG0cvfw/MZw8G0uY
GFMcQ0N399szO+PJLkHOfQxjN7354wnX06SoUDijuD9A94b6dDJZsRIER7Cy
Un/XkExBfMQCR3BNczLNcTaViOVVq1HnvO3qR8/OEVHOQI1JM4rCA8bpRC6e
YVR/XL47IjiDCG6z2oZwW2505NXmC0S0az6E8qkN07tdL5Ik0fAgViT5mmra
sogkN4Dq1SX/rfY5xEk8A9jf8Y5t+Zlcki0KPsCGEN3gqvt55Ilgd74f7UJ3
2sea/UD2iob7sZ249K2G5ZNyQa6sDz94OTJ89cplIvWjD1V7nSNWugt4/r34
7eteBw9pC4l4e/Q9dDlo9Nx3soiIcVj1oNZigyqQFpNpMc87qFNe9/xBQgnP
rxuv3bE55rdZyfPqwkW9hu72BCXPpxM7v2zICahT8jw6MCXMobO1SUlEuUQV
PsyoUdnkKskO0W87hryUvX7EQcn9tWJLVFZ6bV4J99OCQwPPtN7Nxbz+Zkw1
MB42uPGiXoo+++LX4+SFpECsrwE1IXvGFmYuk41iPbcwKnRfYK5DPkkW31+H
Zmm54x6fXeLvq0XLM57ZxXa5XL8aU+GYS+tAFterQlP9n4eX/rtAEsTny9FT
1RDXOJdGasT7r6DJuS8GV64qiEK8fgl/y28vue4fz3+fx54Ir8dxp+TkxYbU
nl1v+XVbdyO/Do3BE8vsOuXPg2PVa2Xsedoi6UNSj0LN9Pn1cthYNpXA3k+v
SfVBaeXQKKuP318Nb5dkurH66aLkD5bmJnOYPyrVXwfJMdaTzD/l+UDO19og
lg/l+UHepolxlh/l+ULf4iuyeHkh5fmD09PrapY/5f0Bb+PUadYfyvsH35ia
ZbD+UWepv+BluEXm76CkUv4qqJl1us36T1XSfIDH4k9dbD7oq9L8QK/MPo/N
D/1cmi/45fvtd9l80RJp/qDQOjOUzR/VSvMJ7oMGf7P55PX2gI6DdwebX8rn
G5aCDy+x+eb198KpsMRDbP4p3w8IBr9Ith/cTx8smKfI2f5Qvl9QY+rWz/aL
++sHy15bB7Z/lO8nHIVZYT+53wFIsFwQ9peOSPsN03oNAWy/uf9BmItGM7b/
1ELiA8Qo/B4yPlDOD2jvLz3B+EE5X8Db8fdPGV8o5w8UPE4pYvyhnE/w4dwb
a4xPlPML3jJxT2f8opxvkOKGAt8o5x+Yue6vYfyjnI+QemtHBeMjlfZ9DPZ0
kU7GT5ou8RVIk4kR4yu1kfgL9ZtnBP7SXonP8P7oP2uMzzzvSXDNOLCV8Zty
vsN3vhUzjO88fw04l36VzfhP+feB6SX0se8D74cWFoOP6LHvB/0fRYA/CQ==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQ1MlWUUx+9ApimlNBhkG5HGggS9mg2Kh46FhSIsBAQMKiAJBZOP25TI
mqUQwQwlZIBhMEAl+VQYcHns8HH59N7Ll3zKx4XlskHkRgLpgs5938dnY+zu
fd//e/7/c87vfTki1i/SRKFQRNKf8b98DFj0z2hQ/qvpLDSj5ZFD6BSW+m9q
blnMYPW2ybMH6yfR8+aVk3MNmcyywnM6yXISNctxvwcPX2Lx7uuHi+ImMDbX
qv1kSC7TaY1nHHsSg9Q9PvnMURIcx0JY/qFhrIAZ1WyT76G3Qr/tY+8iRmKk
OIaN7qPhaSsl7G2jnPsYDo4PJgQvXGd5ucYzinUJrM3eqYwtOhgFR9DxuRx9
bGkl85MKHMG8aeebwbXVTCqvYhiDN0So7epuMUlu/TA+qFJuyRupZZ9JZwjd
O7OcC6zrmdFtRssg2i/HOQTEq5lk13YQlTnnD1rNcPaVZPgumjasBJ6ORCbL
DaDLMat45ydN7HXpDGC3WY3+E88WdkES7Me3Lpd9u/pTK5sz2p3tQ8M7jVlh
Exq2TzLch8OzO7zSXmpnxUa5ol6cz4lefTewg8n96EVLs6ho2687Rf56fJLv
vXI+o4tJt8fpMPeZKeVCajeT4nDQop3b2v23jtxhM1Ke3Zhu7vqBt61W5NeF
MZX9N6KrtSKvTrztEb+48oJO5NOBnodSVP4BOpFHGwY89uJ2H+mYJJekwXC7
zI2FO3Vsl+S3FS+nXe8t7NEKf83411BJa+YbWuGnCdcVPVucGXFH1P8bbvbU
tiQGPq2XY+vZoeh7Fl0sR6qvATWrvlPPZ3ewdVI9dXgsTzXmer+NnZbeX4Pa
DbWpr5hoxPuqse9I1sZPHzYL/Qr8u2bzucNHUeiVomub6fGKYjVLlJ4vxumL
dY9TC2pZlXT/FZxvDLz6S1QVOyNdz8IX9y2FG8yvit/ncM2HQcq9Dtns6YbM
H1oMGdQtq8V1iAtDRte5eB5UD5yO0vO8SdaHiZ6EUtIX14shd8/gf/R+XiDX
B27uW2OpPnF/BVgvuH1P9fOHsj+Y67S3IH9crr8GapfeTyP/XOQDAVVm45QP
F/lBZdOMgfLjIl8I8Y06TvlykT/EhIdoKH8u+gOqnXkl1B8u+gdtf2xvo/7x
3XJ/YdzGuZ/6y+X8NVBjY2FB/ecaeT6gck/rbZoPbi7PD2i7F7+g+eEB8nxB
unZkieaL/yzPH6hcleU0f9wgzycoLqb50nyKerWQ3OXjRfPLxXyDY6fNLppv
Ub8ePtcnrtL8c7EfcG1tcgzth/DTC+nzXyo8Aju42C+Ic1EeoP0S/vrAZH/Z
Jdo/LvYT2t/78TvaT+F3AFZCU3pof/mIvN9gnT1i3G/h/y7sPhAVTPvP7WQ+
QLn9qB/xgQt+QL6qwJH4wQVfIMWndDvxhQv+wI5vtm0l/nDBJ3BJ2ttIfOKC
X+AU9q+RX1zwDcq3rOklvnHBP+gqOdNO/OOCj+D/5iMV8ZHL+z4G1zqGIoif
PEXmK/TeKHMivvLXZP6C6Z/qNOIv18t8BnePXxuJzyLvCUjZ5NZB/OaC75Bj
cuI+8V3kPwm1hlOniP9cfB8g+cTZFvo+iH4YoPmC1WH6fvD/AfLrTLQ=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lXtQVHUUxxcWR2KawgmZ5A+CkUGW4pEgY9OPPRGmkKiB0hAgEYJTwExk
KA8zpYlyNJ7BhPgYE6jIWF3lzU8OK8gKsyArj93luYCwECCMqDll2e/e+/M3
wzA7997vPd/vOedzXRM+j0iylslkSexP+C8dM3rPFdw/5vwLiS24+cgjdgJL
Hf+7q1n7O2l0zl0IbxzH5bz2635fq4iDasdktsM4mryi9+3RqskXgXaGirQx
HIp/s1x/qZb06IQzil1zq8X1hgaiEAVHsTF4tv1KSgsR1JxzR3DUfrd65AAS
JsYUh/Hq+rWXQqc0RCnIBQ7jxu1ym/KQDlJ+Rjgm/PtlV8XDmU7y2EMQNGLy
n8k7G5q7SIRYoBFLqxPq0jp1RCxPZUBZ6sQRs7yPiHJ2BvS445nt2qonB8Uz
hIpXF955u7CfCG4Lbg5i8Ia+1wwZg0S06zyIkTaO6VaHDOSoaHgA17zlu8H9
qIlIcv2YlbNDYV8wQvzE048pPbH7l34bI4Wi4F0MDTSHRbZPkEXB7oIet23p
/shz0UxCRMN6dLfySWxdmSSVglxFHyozT4b8szBFpH70YU08fRY2PM3z78WG
i0+CbBrvEfH2tB6s0xeHJ+XMEDEODx06PHaSNW6eJVNint14UG0+E3V7lufX
hXt1TtFdSgvP6zb25xVadxRbeD5abPFL9NqpsfA8bmHElnP3m7UWIspld+BP
2z7Yb6ywkM2i33acsB78eWKvhfvToPKbau/CoVnupw3zN80PBLw+y+tvxcA3
PA7VhT+vl+KD4kSbk+/fI2VifU24/chpmdZxmtiK9TTgp02pRvfGSfKV+P5a
zCvcVfPQ18zfp8bBsPcyXWzHuL4KA+ZMys7PTFyvGuejx1wu5w+STPH5SrSK
SG7JOa4nV8X7L2C6qSTu+OluckK8XoKncuSrj4Y0/Pe3+LTNun7dkpo835DS
Y1XOResdWvh1iMp8qY1dp/x5UDbZPWHP0zZJH/7wu3CA6fPrlWAds3KDvZ9e
lOqDj+cTN7L6+P0qcPo3IYjVT1ckf1DdfCeb+aNS/bXQEPyjivmnPB9YPX/N
xPKhPD/wd9dbsfwozxe0edVrWL6U5w/pxpQvWf6U9wdmBzyHWH8o7x9oUud8
WP+ov9RfqPrQvoL1l0r5d8Cw6/dxrP+0Q5oPsKnrWWbzQV+U5geiUwu82fzQ
fdJ8wStltXI2X/ScNH9g0gbEsPmjZmk+IaFrtZzNJ69XB+5JblZsfimfb2ia
KYpg883r74X2G4vvsvmnfD/glLxKtmt4mvvpg61bk0LZ/lC+X+Bd9EzYL+5P
DwmJ+dFs/yjfT6i5smc320/utx9846/Hsf2lRmm/4Wx6rifbb+5/AH59GunE
9p+6SHyAE/5uhxkfKOcHvJCldWH8oJwvEPSDLojxhXL+QEbUXwJ/KOcTzLmW
ZTA+Uc4vUKCqnvGLcr5B3LqSMMY3yvkHaqrwZPyjnI9weGVJ4COV9n0YlL5D
Aj/pdxJf4fKDpmuMr9RT4i+EZLrdYvylvRKfIWvGtoTxmec9BsZPXM8yflPO
dzjvo4hkfOf5j0OrfFMd4z/l3wdQT3oNsO8D74cZ1DHFy+z7Qf8HrNNT/w==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lXtQVHUUx4FGs8UhMnGKYIc1ZfBBGWiJ/OCokIhMDx6RbUjI8JghXj3A
BgQXA6YCByGbEQRrhP4AC1tCUflNh1hei8DsthCv5aEEKEusICxLTU6/e+/P
38zOzs6997vn+z3nfK4iNi0s3s7GxiaefYRv6UxifHSSytPSRKJKWlc8oiaw
7kpF0TN7KLkpLzCF3hzHwDyFk1XVQjbXB93N2jyOjrugREs05BM/2WB1+hi2
1c+96hPWQXp7hGPEAbXWtaNTS3aIgkZ0+iovNa+6lwhq8oJRVIW6rU9d0REm
xhRHcM5O7bU/1ED8BTm/EXR9IyXhr5kBUlEunGF87BA5VNo0RCweguAQZi05
5l/SjJIwscAhbD5QHpwlmyBiefWDqCuSeUa8eZeIcrJBfHZ/3OcatymSIJ4/
cSb5vdJqp2kiuC1pHcCdyYG3PlbMEtGufABdA2Y2mA4+INmi4X7Mqd5tCkw3
EUnOgIXONrLFur+Jt3gMuCl641Y0mcl5UfAP7El0yk3bskjmBbsmPZqL1ist
3kvkqGhYjxUuzXU2IY9IjSBXrcOftx01Tr2/TKR+6PCx+7K6O3KF59+HLRdC
ijUBFiLent6L4//4HNE5rxIxDo8ezG/fErU6uEruiXl2o09YkV3kKSvPT4sh
9xu6vFasPK8urJ0O+sDx7TWeTyfaJqXNYe4az6MdN1XNz32av0ZEuaw21N/w
y70TtUa8RL8arMqAj0zr1ri/33HhwK5uVa6V+2lBs7zRWd++yuv/DStnXxtu
GbXweimmHb5sO9yyQi6K9d3C5XccY4Izl8kGsZ4m9L+tMc/+t0ROi//fiC/V
2Pl6Kp/kqcYHk5bvPnQxc/163P1ZerHC18T1avHK1i8Hnn5xlnwhPl+Dl4KS
fZV4j/wi3n8ZA7x/ikhMNxKVeP0C3s/T1Da4GPjvfOzL2x4esldDnmzIN8fj
v73+9fZmfh3sU0wn2HXKnwf3dR7X2PO0RdKHNo/nlUyfX6+B58IV/uz/6Q9S
fZCw5DPE6uP318OvDjtKWP30oeQP3F3VF5k/KtXfCMEnYwjzT3k+8EqXYpHl
Q3l+0HE49STLj/J8Ibr0XzuWL+X5Q9bCuRGWP+X9gWY3BxfWH8r7B9a4s3dY
/+heqb/w/VRZDOsvlfJvA+Wp4jOs/7RNmg84fWPfPJsPulGaHyifUJvY/NAI
ab6gk55VsvmildL8QZHntJbNH52U5hMC5I1Psfnk9fZA9qF9J9j8Uj7fEBP3
VhCbb15/Hxw5FH6OzT/l+wE5heYGth/cjw6qNK+Psf2hfL/A78fKq2y/uD89
9HeMCPtH+X7CNV+jsJ/crwFsD555me0vHZL2G0Yzj9uz/eb++6FuIWme7T91
k/gAPgp7GeMD5fwA/dV3bzN+UM4XSLQ9Vsb4Qjl/QOV9OIPxh3I+gfUFg8An
yvkFsY9sQxi/KOcbyMbDCxjfKOcf1Ogyhhn/KOcjZGcmJzI+UmnfR6A1tsyb
8ZMWSnyF64kzAl/pTom/YN1mTGP8pX0SnyGlZFXO+MzzHoOcmId7GL8p5zsc
s1GcZ3zn+Y9DrmpK4D/l7wfwSJopZu8H3o9JCNfm57H3B/0fY2NOqA==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQlFUUx9fdjRBTc5RX2SIVgj1sytcU9+OkICqaJhlMhhk4QqCIjSPW
WgKi5GgCI1aaRhbq5NgAMpAo9+Mggm8RWBBYdRFRRl015GGsKHb2u5c7s7Oz
c7/v7Dn/+///rm9MUvhyvU6nW04f57dY1zF07uF/XRafZFFZlb0BUa14YHh5
/Z94ipWaNtsXltpwwcvT9cdzz7Ex+bPazGNsGLut7rJJf4l9rbg15a2+hnU5
ib6Bj+vYxQvOdRWT2o719WMDm6AVvIpPwsKHj25qYs5qps1XsHLM3rby4CuM
ilFFK6blDCjZQ1tZkLOcYsXp3jtn5v7Uxn7d7VwtuELZPGdaYzt7FOAs2IzJ
7Y7o88EdLFxrsBnf8p9ksl2/zbT28ptwunvGcwGH7Uwr59aEzwpc3Tfue8Bi
tXUZ7bdTu+/YOplz2qzKRnQUuR7amNLFtHFNjTgsbv7r5nd62Hpt4AYsbbvV
ctTey0Q5C0Z+MKxvT+F/bJK2LOi+1fu43uxg2VrBelx/Yr5hbnA/u+cc116H
GwrWLPny+adstjZwHaatal16pmKA7XeWy6vF6tsFxS2TdYo4j1oMmRkd5Dqg
U4T+NTgvfsvjutIhivb46ot4yrEt4sUYvaLJEXABt1cvyPrjkV65oel5DiNj
LvckrzEoQr+zaPnbd0deo0ERep3BNL/e9oSXjIrQ5zQWLPYPXQBGRehRjZ/t
dpT7zDAqWjlzFRbUr6s3+hqV97R5T2Jly8jhP1oNipjvBFY0vPbkSKJBEfNU
YJeX8dO7LXrZfzmWfzLKY7zPYL8cvTIXmZuUIcourb9jeHek34HuqTrFVevn
KG61uHS1ew6w77T/L8bYXXGTd3w/qOcRtAbdWWTJ65P+zMf4sUH5idm9TNQ7
hJ9v2lfmmNPFvtHe349/xQxr/LngPivUns9F718KPyxM72Cp2v5ObH1wpyRu
hk3+3oQJE7u2p8fVsMGEZD4zj80c+W6Z3IfY3wy/0z6X70PJ8rXl9D6vEPXB
JaUvhOrL/f1g9opoof/n+0R/cPjb0yr1J5/Ph6Ky2ELqn3eK+SBz1ehImo+L
/ouBj8qZSvNzqQ+sGDeph/ThUj/onBd4kPRTpb7QnJywnvRVpf5gjx3vSfqr
8nzgVIVnBJ2PKs8Pfoif8pTOT50szhf8D5hG0PmqQv8qeH90uoXOX60S/oCV
GboK8of6gvAPlAVMmEX+URcJf4G728Ob5C91r/Af1N7wyCH/qdeFP8H6dlUv
+VP2ewEy103JJv+q0t/wUfdXkeRv2X8NTDNF9ZP/VZkPSA16Eygfcp5asFcn
lVB+VJkvWLc0LJryxWX+YFXy2S8of1zmE4ImZhkpn1zMa4F/9oSUUX55s8g3
eL3i66B8czF/A/je67BS/vk4wQcI9gj0Iz5wyQ+oPtjm5AeXfIGhraE9xBcu
+QP2+as9iD9c8gmqlPMuxCcu+QULL0X6EL+45Bt4euqWEd+45B987J4URvzj
ko/QUbQslPjIRd6tsCUlEYifPEPwFbyv2m4QX/kbgr9gfbhyBPGX1wg+w+yQ
QgfxmQu9r0HR0uBXid9c8h3W3pzRTHznkv9gO7LBQPzn8n6ATbcuWuh+4PL+
gCX3d3TS/cH/BxIVPXY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQtQVGUUxwFxFykcFRycDIQYHqLp8HDU+i7HfCAWlaATqCRBAjWY4mOm
AhtNlAEh0cEFNBIFSmSUgQEJ9Lse5SESD3kGrKIgoyaiYdOaOFidvd/nN7Oz
s3PvPXv+//M/v+savT00xsrCwiKGPuZvcQZxuk/PW/1pjSwis9bkFXEH63Ls
EotONbNq54OPQqpv45apPlcH3NqZQ+nqoUSH2/j0ixFjV0Mn26HY9hYmDOD5
Cp1VGO9hrS3mcwuj3kmKf8+un83VCt7CxSGlG16ot5i5mvPBm6gPscwt/HKQ
UTGqaMTMgcuJGcV3WYC5nGLEe8W7DfOc7rETx82nHzfd2J+6/voD9szLXLAP
w6oSwueUjLBQrcE+/OO7wGOtVx8zrb3SXsw5lvttX8oY08rZ9qK1o8Hj0Kq/
WKx2fscl6R6P7Wf/zcxqM2t7sN4yovO59TOmyXXuwZ+SF6e6WjxnSZrgbnxz
bZ670eYFE+W68MCTzre73phgftrpwrzMCB8Pn3/ZEa1gJ/pV3Hda6GahjJrl
PurA8UnxDsu9LZUgTXAHWg17bs/xtlKKzOUK23Hbmr0/N7tMUsQ82rGsYpcp
bIq1IvxvQ5dlwzX5g9aKdntCKwZmNzv+VzBZ0ezwasGPzlRXG4N1yl3Nz98w
3u+cUmbUKcK/Jky332XnuUavCL+uYzYbmO1q0CvCn0bUlQyvbL6kV4QfDbhg
7w+95y7qFa1cYj3uClw7diFTr/hqeuvwY56yJnipXuq7it1ZTr6fVOmkniu4
b0po7AqdTvZ/GVtdO7Ps577ql2N35fyojXOslVytvxo05VXdWTZipdho/fyK
2Pbh5gPplsoe7f8rMTnft2Dn5Fd+luPpgnd9Gy9MyHyWYviy4aAo53Em6p3F
kuPrQtYFm9g32vNFmHyjbt60oKesTLv/JJ6MST2+b9EI26ddP4aubTUbl+cN
yd8HcLT8+5ep5R3s1YZMy1H3Fnb6XZLXYVvkVn1aeQeXz8Met/JIep5fEfUh
+eH+k1RfXi8Ck/uKBfT//JToD5o+7VlH/cn7S2FGftwH1D8fE/pg3FDrT/q4
6L8SDq/8upD0q9IfaI/OiiR/VOkfnGmYGCT/VOkvuL/YGU3+qtJ/SP7T0UD+
q3I+sLM8O47mo8r5wejaz/xofqq/mC9srbr2Ps1XFf7XQ0F2xlOav1ov8gE7
/Bv6KB/q6yI/sKFtZiDlR10v8gUP+22cKF9qnsgfjC7JmUr5UwdFPuHseGMA
5VP22wKGRc01lF9V5husPbpnUb5l/21w1GXoIuVflfsBR4Njn9F+SD3toDjF
/kL7o8r9gq+OWCXQfkl9HXAqcOlM2j9V7ifUfV7sTPsp9XbBYNU1X9pf3if2
G2xeui2k/eZCfzeknOj2oP3nLoIPYHE4LI34wCU/wJS4pYv4wSVfIG71rCfE
Fy75AwG2OzyJP1zyCSxbIxOJT1zyC+wunzcQv7jkGyz0qthAfOOSf2B6UJBG
/OOSj/Da/d3ZxEcu9t0Ih/jpJOInTxF8Jb1NZr5yb8FfQD+7TcRf3ib4DDMq
zm8lPnPh9wBsnj99EvGbS77D2akdN4nvXPIfTM3/mPnP5fsBAjKik+j9wOX7
A34Mf+5G7w/+P/1IJnU=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtMVEcUhpeNRQoWtaKNCIhVy6O1VaFJLXM5VlBoiTRCG6zQYlrfKQWC
D16JoGJMmhRia0WymFUeiZYiz4h2rkdhCSCL5aUuj11RUWtBQyCA2CI9e2c6
CSGbuffcc/75/2+WfZsYtVOv0+l20p/9v1gDuHGD89GE+yYWl1s/7ht3DzeV
XE102d3M6rxyhrbU2XB72LN3/XeYmVt52P10Nxu69ewxrEluZ8mK892iJCv2
nHzVlTbeydrM9tWPr0/MywluuM38tIL9eHz21v54m4XZq3nl9OGK0ifVPp/1
MypGFXvxqJ63580aYMH2ckovvvrBejPV9QErOGNfPdgw1axbGDLIJnztBS24
ubFh8/zzj1mU1qAFzwc9P7zH/ynT2iu/iy++eRgc1TvEtHLOd/GNrLx1AZee
s13auoMffW56p7lzhNmnza2/jQ/Wll08EjfKtHG9bqP/V4NLvUfHWIY2cDfC
ZPnhrLxxJsp14Zb+Z9/NDZxkAdrqwsoP/zzUYnnB8rSCnTg1drQzNP0lG7aP
O9SB6dVvAV/wLwvXBu7A3NMTX3sap1mxvVxRO1o7Ug4sdp9h4jzacXVUV4xH
sE4R+t/C+uEFlw8N6BTt8aQ2bOwMK96W7KBocvia0bdp3OD63EF5oOl5Ex0R
Pp6M1itCvxb0LYssOWvUK0KvZnQpNLfe6NArQp8mPLI6xznukV4RejTiyYLw
2VU9ekUrl27Coeb01Njf9cpabd4G/Ct1jjEiXq+I+W7gsqjCcAt9X8xzHe8E
NHtirIPs/xpWxZSG+JXqZL8cu2/Y1m0rnGH5Wn9X0Ptx/n5D2TRz0vq5jBEH
PEcmMv9hmdr3a3DXtrCqRW9OST0rMbH2vYSEpAnpz3I8wF4zLS8ck/Uu4PSg
0zWnsyMsVXu/GBcPVCROj/7NKrTnz6KlyBZt/n6QZWn7v2DMiow096Q++fsY
Prn/NK8yt5X9nxCvthGjed/7f8h9SGh820j7XL4PtapHNr3Pr4v6YCuojqH6
cr8YHHf/mELf50bRH7gdmULqTz5fDgsNU43UPx8R80Ha/JWJNB8X/dfAlbqQ
GpqfS32gvthzlPThUj9oyTQcJP241BfiPR8Fkb5c6g/7My6Gkv6qPB/IazJ7
0fmo8vzgat25T+n81EBxvhDtMO8cna8q9DeBWpmZRuevmoQ/wGtRuBP5Q50j
/AOee7NdyD/qF8JfkHTFZCZ/qQbhP3Du/qSU/KcOCH9C5NJVQeRPVfoX5v7a
X0j+VaW/4edonxLytyr9Dx4pQ3b/qzIfYA09v5XyIedph8gTMwcpP1zmC4o2
JsZTvrjMHzhVZK6n/HGZT/igqbuL8snFvF1gzXdJo/xyi8g3tNct3En55mL+
bojYUZ9F+efegg/geOahN/GBS37Al5dO/0b84JIvsP2UwYf4wiV/4OHkkiDi
D5d8AltkxHriE5f8Al1sYDbxi0u+Qd/w00jiG5f8g/XuHQ7EPy75CPtOtLQS
H7nIey/cW/JTB/GTHxd8Bf3j2FriK/cX/IUL0UYr8ZffEnyGWYFrjhOfudDb
Cq45L7uJ31zyHSoWhRYS36V/bLBh5d5VxH8u7wfw26RPpvuBy/sDnE4tP0b3
B/8PiKY+bA==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lXtQVVUUxm+OFJIBCsTkEKKkXFAQRQuGDSvHTEkUMEwq+0MGTMJBQGqM
SBFEgQSKmAATrRErBO+AUMGwY/EUBOT9ft6LyONeRFJxKjRa95zdnmGYO+ec
76zvW2v9zprA4/uDlygUimD60/+Xjxq3PXROmvItY4fSqueVh0ax3+fG2E6r
P1ipdYLOr3QEl45b3LfPq2Tmql2aaPMRvBt85Pr8QjWL8DDqvRo+jLEH3T//
NLGO3WnWnyG0zVm1e9GngdlLgkPo9cqK1S7vNjG9mnXCIL6+aXrN6DctjMRI
cQAXUo+djjRoZ556OY8BHPg3QG060sEuZutPP1Y0Pozb2N7Fnij1gn2Ypoj3
SR/qYfulAvuw8qlbfdSzPiaVp+rFS+ZRP4c4DzJJzqgXXcqizUIjhtkR6fRg
2Lx/+lD5KNO7TavuxpTSomXvGGiYZNe6Gx1jTp17tGGMfSEZ7sLi02c6hvfd
ZbJcJzb5Dfa0fDLOXKTTiYeXeqaExtxjX0uCHfjky22/7oydYDN6u7p2DNKq
irSRk2y3ZLgdH6/DjY98p1iuXu5qGy7LjjAzs5xmcj/akM/bnLCvnhb5t+Bg
nLLCx0fLpNvD7+AKK/PFyXItk+JQNqNnhklinoGOjUl5NmJdtLI030En8ruN
jm4FsWH2OpFXA1bMzYSoFTqRTz1GDa59cLhQK/Kow2uOw7a33tAySS66Fs3W
ehb5Zk6zLZLfGjSZVfkXtU4Jf1X4Ykqw7TPNpPBTiSZOV2autU6I+isw3SNz
ffjFe6Jeju7Z/4x8/NY4y5LqK8OK8ledulvHmKFUz++4w2p9gTNoWIz0/hLc
7m1X5ewwKt5XhEHHHzt99cug0FdhTdXs9AuLvUIvD1fvtTH1d+liJ6Xnc9H7
u7nn7fa0sULp/suoORWUHZXVwGKl6xl4tP9Ho6STleL3WTzx4bGc4fhC9v+G
5Cgy3Vx/eqlcXIe05aO5dJ2L5+F801Fjep5XyvqwvXp7DumL67lwIXrWkN7P
f5Drg79cNq+k+sT9KkhasJih+vmc7A8Kbm/dTP64XH8JTDwXX0P+ucgH6iMD
b1A+XOQHroYhmyg/LvKFPxf91ZQvF/lDygWFkvLnoj9QN/LyLPWHi/7BVL32
Neof3yr3FybS3nyP+svl/GuhsXrgJvWf18rzATnK+HU0H3y5PD9QFdA2R/PD
/eX5gj0ProTSfPFL8vxBUnZgHM0fV8vzCcZG6jKaT1FvM1hb3kqi+eVivuGz
9+sVU+VaUX8L2O3rQZp/LvYDtrjWR9F+CD9t8PYHxha0P1zsFyR86+tE+yX8
tUPrRy7FtH9c7CdozuT/Rvsp/HbCyoDcVNpf3ifvN3yvc+6j/Rb+u8Aita6T
9p/byHyA5ODC88QHLvgBFqvajYgfXPAF3L3DMogvXPAHFvLCLIg/XPAJtIod
ecQnLvgFJVnjDcQvLvgGB7yM/IhvXPAPMp4ePEv844KPUJycoyE+cnnfB2Cv
aXos8ZOfk/kKuoy/bYmv3EHmL1gmam2Iv7xF5jMc6K30Ij6LvIdh14ab0cRv
LvgOqstF+cR3kf8IlHm4zRL/ufg+wJLE/HH6Poh+qKH/+v1k+n7w/wAn8FU6

          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lXtQVHUUxxlDcxCrIUSmiFkbkV1weAmk9MOj4gjlUIE0KkM5RTBiPJt4
+JjCACFCKIQpUR7LLibagMAaCD85QBDFK97gstACg7wXEuiPVKbfvffHb4Zh
du6933u+55zv5+76NMo/ZJORkVEI+xP+S0ePTqq28uD1YhKU1bQmD/obj+PT
39+fVJEa65R5v5oxPDpX52ZzSU3My7zHL5iP4Wnqb7t6T01iPE2GVNGjOO3g
9fV8qJp0dghHh0Yhd9cuJ6qIQhTUYWsrdXs4qiSCmnXKCJp9Nm7q+qCAMDGm
qMUwQ3+qY9WP5KAg56nFZ1sSepSNGSTvunAeYVjkKy+c7ggm/8oFwWF0cXY8
dCY7jfqLBQ5jlXdhHFUUULG8siHcYqS1X6oopaKcyRBqcpqOpJtU0VDxDGJc
i4OsX15LBbdZTQOYsbP5yaJVIxXtWg9gee7clbuFLfSiaLgfPb2a3zS+0UYl
uT6MSo0MP765m+4TTx9WfvNyxOWVXvq9KNiL+QlyJ53ZIF0Q7M734K2la0UR
QY+oj2i4B2XhTus3W3VULcipujFbFz9rYaOn0jy6cUfYuwWKhXEq9b8LfRN9
TM9WTlLx9uhO/Eh3yyo7eoqK7ZB34Pq37g6T1tN0QuxnG6oqTMzc7s9QqX9/
YmaJf5Tcfo736w+0OX+x1i9hnvenFZNL4dewnAXejxZMd484lhi/SEW5C83o
Nf2Su9NrBuoi+v0N80b2x/fGGri/Rix0SD1RnmzgfhpQf/WrTXuPGHj99XjO
c7Ptyp1FXi9Fjb/VXxYPF+hPYn0PUD7jV2PH6tkq1lONFuPPuz4cnaWXxPdr
8NAHSqvApWn+vgos6v25KLtyiuuXYeDV6ZHHeye5XimOKvS2mhA9TRCfV2Py
U7O0wHYtvSfeX4Bt5c4ln0T000Txeg4Wp5fIzmS289/J+E6WoXAG6+hGQlqD
BlaVAbvf5tch5Bc3DbtO+PMwqNfYsedJg6QPbnnyO0yfX1fDcsmTDPZ+UiTV
B7kHDtux+vj9ZZDe5z7G6ifLkj/Y/uVEMfNHpPo1cEPZbM38E94fGIl4sYf1
h/D+wf7zUMv6R3h/4djqfDfrL89vPVw/el/O+k/4fMA3f7sxmw/h8wOFx2oA
mx9xleYLPvZJCWy+ROp/M2gs3d9i8yfN0n7ACc8Yb7YfxFTaH3ivS1bN9ocE
SPsFB0961LH9Ijel/QM/22Vh/4he2k8I25Ym7CevtwO2ueYK+0v4fkPOdzPC
fvP6u+DZG1HC/hOeD7A0OSXkg/vphvbqSCE/hOcLvnBbe87yxf31wMeprkL+
CM8nLKpKHVk+ud8+cFmPDWf5JcNSviFmrf5zlm/uvx+2rh3exfJPZBIfYDzf
N4XxgXB+wONI838YPwjnC7zaUWPF+EI4f2DmpBcw/hDOJ3h9Rb+b8YlwfoHl
jomzjF8bfIM9U6E2jG8b/IOazrhzjH+U8xFkJc5zjI8871rIS8q8xvhJr0h8
hR+yZncyvlI7ib+gCJ70YPylXRKfoX045j/GZ86TUSi8fTuJ8ZtyvoPW+JQ9
4zvP1xgo9wQfYPyn/PsA1vt82tj3gedDD3mxDZXs+0H/B78oS+s=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1VQtQVFUYXjATARsDMgzCBRtFcnRUyMiz/DmmMINREKYRDqwzQGwmOhmi
i0nyMG1SdPERkCZQJvIcHkKc9YeVkOfGawGJpzNkEwQSDyUEO/ee05nZ2blz
zv3u/3//933HeV9UQJi5QqEIYz/pn68BfPlk6+652VQSfM4w5Rrcj9841v28
IO4yKXNKHPYv60Pr0EvVp50uELs878Fjdn34Yprt3yEPE8ghlWVn5sFeXLFn
4eK8szakqVFaPdhSr4jXTpyha2TAHvTaaB98KecqldCcEn/HsViPmjHzbMrA
GGI36iIe1w1+VUS9JDhVN/r62oRl7Kygqd9J6z7qdntD1NsGOu0qAXahlUVQ
V+v392iAXGAXfrDh47VRDU1ULi+vE2+WrYlYpGmlMpxlJ+4qaE/uCemg4fLq
wKzS4xln6rqp1O05gwk/9FyeFnGjn8rtOpnQYeiWY5X2AdXKDbfja6tjD+QH
DVEO14arthZN9O3/k26SVxtevGW9fXPuME2WAVtxZYNSY//SGB2R2h1uQXv1
vjA3v3HqIzfcguqclSmpjhM0S4LLbEbfZem47dEk5fNoxmkyWdRjmKacfyPO
NOMrJ759QuXjB5uwP2H+o0qff6lMh2sjarZbKZpHZukDmc96LEly2ZF2aE7w
V4e+jVsVU8Z5wVctrrvg4Vz19Jng5x7aLgmNOH9Uoed8/IoN6sHRXSaFXoY7
Vo0F57/w3PGCmX6j3O9dLH1OWx7qbKbn/VXh+a91m5TWZnreTyU2mLrwXKNC
z+u/gxUWAZuD1Qo9r5civOvwT7XuGb0i11eOKaN7rQ5bz1MLuZ7bWDh+d+mR
dU9prPz9Yuy4nKB4fm5G8FmI6tnasu7Yx4KfPFw4lDvrUjwp8G5iwoH5yMjs
cRojv5+Fuebv1Aw3j9AC+fxVrM85MeH7aIjGyfspWO8UlDmT3CueE/C0n1Vg
SVUT/d8h8ba9P/1222OL2If6dWWRbJ+I9yFrvTKPvU8qOT78+KrpCcMX+1nQ
cyqpgX2f/MDrg7hruv2sPnE+DwK17vOsfvKI9weaRK8K1h/h9RdDeOUf5qx/
IviBkMSltowfIviD5oELSxh/RPALJv0bk4xf4d87MOwa8CbjXyXmA6PX6yvZ
fFRifuC5L9qdzU/lzucL6z/z+4XNV8X5r4b41z3fYvNXVXN9wMx4yhjTh8qa
6wfuaxd8wvSjCuT6grFtwS5MXySd6w+W5/uYMf2RAa5PWLbF0pvpU9TbCD45
7ZJ+idA3LK3IDmL6FvUbYZHb+w5M/0T4A2KJppj5gwj/gE3kjOQfIvwFp5Qa
yV9E+A9W9ekk/xHhT0it3Sv5k/B+26Axf7XkX9LF/Q0G/wLJ34T33w6TJETy
P1HyfADoi5HygYj8gOjQs6ksP4jIFxhzNF1n+UJE/kD6X3ZS/hCRTzDXuSec
5RMR+QVGyHBj+UVEvsGIQdfB8o2I/INrn8aqWP4RkY+w1uWkmuUj4X7vhp1X
jtaw/CRJPF9hcfTnyPKVuPH8BWWJ63ssf4mR5zOsUH6pYfks+O6FDf6lp8vP
2lCR73DxsNY89GGC8FcfTCmOGFn+U3E/wPGK9kJ2Pwh/DMCNGKtQdn/Q/wBy
Y0ae
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQVGUUx2ErUHoois4g8coy0GRMUBC+65lJrAatEYShBzSTSDniA4IU
EcuGh6Kuq2QUCI4EaGjtRG0tj+96AIFgAwYBYXntLjKTGS5DQ8gM4tB37/fx
zezs7Nx7z57zP///7/ruORyVqHFwcEhkH+WbHxsm1ekqvs+qIXG6xmm/OCvG
vJGVl9hSS6q9csYjqy1oljrvRd2oI276t0Yz3Cx4g6wJjnClJEVy6S9LHsFl
JnqodKCOdLQrZxg3OxumP7LUEn+14DB2h6+/WThTTZRqXjlDeEDT56Z5/Bth
xVjFQTS+nhDxLa0iW5Vy0iDmTdhzXL1/IEWFyhlA32f2apd5fk0e+SkFzVhb
VPzxVs+LNEpt0IxywrW4ydN6qran78fleaecXo6mVC3n0o/t1sCRtaZm+ol6
+rDKSZ+O2k6qTKtrvIurynVnf5d6qTqu1128+dqZDUGmAXpcHbgXN0vR05YH
VsrL9eD9yHzn/TvGaKB6erBXe6m0fuwvekEt2I0Xt4frQoz/0IfKuON3UNN8
rmqlPEHfVge+gzt93zG++/m/tFwpV9aFGXee2nWucIryfXRhZpFL6Nztacr1
78Q5k8124uEMVW9P7sCIgyseBLnMUlUOv3b0aE7T/rR8jt5T9TRhbupiu/P8
E8r1a8P9G6NO+DfOC71acZV1S9uxSgeZ6/MHhuy0DNza7ShzPZrRv9fNx3/I
UVbLZTSh7hetNSZMI29U572N1fZs3XvJGpnP14Arznqe6z+ikfk89eieX3hk
zU6NzPu/hYb3FyfFTzjKvF+Kge652w7EOcrfqf3VYMmjli3+BQ7yIrUfIxal
b9IbQuZppvr/BvwzZqnus9E5oWcVjtRVXL63blboo8dAqyY7wHuG8nqV2LdX
uye4aYqmq8+X4/T6ay2HXpmkP6v3X8GKntDuiJK/6Un1+iUsl/ellRbaxO9s
LDlj1aw2dtGFhFyf2v2kzp2EieuQkj22lF0n4nk4djD+OHue1PP64HHUfYDV
F9fLoX2Dk4n9P7nK+4PDkwOJrD9xvx4a/gs+xfonk3w+SNXhFTYf4f0b4MvY
Z/PZ/EToA/viX6hi+hChH4wN+YQx/SShL6R4toczfSWhPxTEhh5g+ktiP+Bd
YDjK9iOJ/QH0+WrZ/qQgvl9omEm5wPYrcf2bYMm6BBvbv9TE/QE7yroVf0jP
cf/AofzsQeYfKZr7C0xTrYq/pGLuPzjpuu0L5j9i4/6Ep3M6FX8S4V8YH11y
nvmXCH9DdcNpxd+CP52wqD1glPmfiHxA1uwmJR9E5AfsqUuU/BCRLxh8nij5
IiJ/EJscrOSPiHxCzMrG8yyfhM/bAz4941dZfomZ5xuKoc2J5Zvw+Xth12Ht
FMs/8eF8gIyNRQGMD0TwAzwiv8pj/CCCLxBk2pfG+EIEfyApxWxm/CGCT5CZ
2PxkdTQlgl9g93lzB+PXAt8gw5gHjG8L/INPX03VM/5RwUcoeLHrG8ZHkfdB
8EibimT8pLmcr1Dz66wH4ytdy/kLrR2WKsZf2sn5DB/8aH/M+Cx4MgIvfZiZ
xvhNBd+hpDGJML6LfFlg8/XL9xn/qXg/wKjrsJa9H0Q+bFBZk17J3h/0fw40
QwI=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw1VQtQlUUY5VHGYCjYLcIxlAiiJAZIrHDhQ0qwMEN8RIM81MGJuioCIwgY
pmBEDlzGBg0FbUCUkgslIOnGx1PeJPK6gPdyL5KPBAQu0jRO1v7/rjtz584/
u3v2+86ec9Zh576QaDMTE5No9pP++dBj+upCR/u4HrI9p+GRy/ZR7M3+UJ8a
0ktq7DMebKrR4eNMc/WEfz9RqAMNyQodfuq38PIin0Gy38dysChWi0ePmmW6
vzdEujqlcQstlnZarncbIW/IgLewYElu2D82WiKh2WeMoKv2v5SLGh1hYAxx
GAO1VXc7vPXEV4LzGUY/utgra1JP8n+QxhDG1v4UFnrIQOZdJEANng+uqrs+
ZiAhcoEaXBswpwx9aYzI5akHMf0VlaHSeozIcJaDuNLhM+Vou4HslscAqlfb
tMT5GojUbU5DPw7HG1NHo/VEbte+H50Tt6m2HdSRFLnhPpz1v1wZkTZCOFwv
1nXsuFAyPEjelkcvVpVl22d810tUMuBNHLBoU0W7dpEJqd0HPejRkui+YkED
WS833IO7TLPKVPMlpFiCK7qB1tXLc5Ur1ZTfxw2MzqlOOXyxmXL+u1H7++Sd
F1bdpPLy2C5MMjPmf9MyRGU6XDoxyKoxYqZaT8dkPtvR5uQ5zcDX45Tz14YK
n5GzlR73KOerFbMUUUr3yw8o56cFXYeCgtpmpyjnoxn7Ijuulk5NUxkuuQkX
lq/wI+6z1FPutxE3jZlanfEyUt5fPYaGepZ5/m2kvJ86dDAZ35C9d07UX4tR
9WkzeXlzol6K9glnnemXc/SUXN9v+GcpJtpNGKmFXM8VNAxVBKtsjTRVPr8S
1y3LcRt4OCPO+wVPRPnvPpA0LfDVGPPxcyHZeyYFXik6L1haXrTrPk2S9xdj
wmjkmojxcVohry9Er3UZynJzPT0sz3+P3xZqwy6V94vvdAwqj2pX3m6mTx3y
Y+lXz2x0JGvEPCwO//wOmydiP9x7qyaG7Sd1HB+OfhEcz/DFfDHQ1sdr2fnk
HK8PrjslV7H6xHo1+LcsD2X1k2neH0wFOMWw/givvxICit73YP0TwQ+cPOK5
mfFDBH+gOm6ZzPgjgl/ICKpwYfwK/9bCNeNmI+Nf6K0OWs8f3MjuR+izHi5B
pprdH1nF7xdic20XsfslnP8mqN0xL90/aeL6gDTzndeYPsjzXD/wrucTST9k
C9cX+D08LemLnOH6gyseJZL+iJ7rE/4NNJX0KerthCfP1ocz/RKhb3Bz9D7F
9C3q74ayu7m3mf6J8AdsSNHFM3889Q+8nq/Zw/zz1F9wfHZpH/OX0EsPKD9p
8Wb+o8Kf8HNkwWnmT8r77QVFgctrzL9Uw/0Nv1bblTF/C/31we39SVeZ/+kK
ng+giLPLY/kg/NIPcV2daSw/qMgXcH71VhvLF+GvQehfZr2P5Q8V+QQRCW7j
LJ+EHzUwtfjAPpZfVOQbbN1j28jyTfh3CF78469wln9U5CMsedn1HZaPwu/D
kJJedp/lJz3G8xUK54vTWL7SN3n+whbfiQiWv7Sb5zMcydFZsXwWeaKF3YHd
WSy/qch3+MD0RBXLd+EvHVQc+qiC5T8V7wM82rp5jL0Pwh96uFCz14m9H/R/
SZ1RMA==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1VQtQVFUY3nWMIVILIUBL0ZrSRWcYNXUazvWvNPHtgI/RJKIHzWCCIKgI
6FBAUxYvTbRUJMEcU1eXhy56rj8vA3GhVd4gDzN1DR0QZVNQ6N97TmdmZ+fO
ufc7///93/edyZ9tDgwdodPpQunn+BerC/dtzV+9DW6yoPSy/qlBnZi6N35u
bfQtZp6Y0h1g7kBDyrll/9bdZu5G/5tx7h1YFzalak+wjUUpLk25ke1oXzq+
dJVrN6uxONYN3FxnsnfbHjCDBngDj9g37t8V2cscaBNT2tCz51WD88BDRmCE
2IqJ1ZNOXUl9xOY54JRWTHfpT+iZ0s9++dmxWrBltGvcGxV2Zp/qAGzGyY/v
Fu39+AkL1ApsxmMXstpH9TxlWnnGJvQN9ln5QvQg0+BcmjB3fOvJi7eesS+1
1YjFxplfr/IbYo5u08sa8GqTKcoePcy0dic24Dy/wRefzdcp8VrD9Xg0+n7V
c7NOEXB1WDBn++MfPfTKLG3VoS7HvzLpI72SoQFeR7fRAWNfT9Ir9x3tdl9D
wzdOW4bT9MoireFrmH4hbdaanXolzwGXa8X6bMPimuV6RczDiknboi4d1+kV
wX8tPnrfPNucpVO01yNrsL62wSPUVadodEy14NG2I7ELbg+xvzQ+qzHTfZyh
dsdzyd8VXN72wdn37gxKvqrwzR7vD/1mDEh+KrF4v+Wq/dMnko/LeOarGwVu
iXamwcVVoGvJn2s+3/uYzdT6Lcfmnb6Zxtw+JvorxTJreFa8uZeJfkrwecTf
6gnTA6mfS5jzW3j+2x7/MFEvx8HuxvgNJ+6wA1p9xWjY1HJxQswt5qzVcx4H
2ubr7yV0sQTt/EIcanqYFJLeJs8z4ZbO4KHvTzZKfCN2tPRt+33pdYl3Arcv
W7d+hNXCYrXv83BCGU54xXaZndXez8bST07daYxHlqjt/4QjrXk5WQGF8jkZ
D/PFt53u5bL/HbLb33d4ssccP7kPTzIyU2mfy++h/zXzVvqelwh82GhZohK+
3M+D5DRvFzqf54j6YEzVy/5Un3zfCE7JByOoft4r+oP1h/rs1B8X9ReCZ8wP
O6l/LvmB828dGbIldHHJH2zglmLij0t+YeWZsDjil0v+ocjjmIn453I+EPNd
uWM+XM4PdmSaHPPj74j5gnruD8d8ueC/AhbmmdfS/HmF0Ad84eNeRPrgo4R+
IChiZQ3ph68W+oLdcG8h6YsfEvqDxgXL80l/vEvoE8ZmBE8jfcp6LZDaMi6e
9MulvqF3j8GL9K1K/cPIad5zSf+q9AeEWO8i+UOV/oF5ppNLyD+q9BfENnvN
Jn+p0n9g9dwXTf5TpT/B+XSXG/lTFf3WwZkxDVXkX7VZ+Bv8Yob7yd+q6L8e
ess3VZP/1UkiHwCmR71E+aDK/AB7QXIM5QeX+QLHO21JlC9c5g+EZ0caKX+4
zCf4tT47gPKJy/yCtJC7nZRfXOYb9B10M1O+cZl/4O3hmUD5x2U+Qm5gwy7K
Ry783gqVx9pOU37yb0W+QpjnKR/KV+4j8hfcdrUfoPzltSKfoXFd4FPKZ8l3
O4yM3VFO+c1lvsOKK4uqKd+lfjrAy3Z4BeU/l/cDxPRPf5fuBy7vDxhlm7GW
7g/+H+xzVHw=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQVVUUhpFHoIIoHBvHRkKLvDJlM2KOyNksRSNBbYTi1UDMlGIgCXqT
hzAJo8CAFjQIAiMNKiMXGDENA+xsllwVHzwEgQB5qGmFXR+Ug4n5aJ1zdnvm
3jt39tnrrP9fa317/mcJwZutraysNtNH/dXXTbzreubpVykWOTLfPGGIvIFL
2ou9jN4P5Ua3LEtQ4yieWtoM49V/yVLdB7d2SaPo8mxsd+6dR/J2Nq3/aOII
1t9o/6d4/WO5o11dw1jqP/JR+q0n8iIt4DCaq4xZw4f/ldVobllD+KSh0pi7
74VMwSjidYw/sybl5w4r5quGY9exw+HQ0ECMNSsrVdcgrpKiDxyfYcseG9SA
Axg7cc4rxGzHgrUEBzDtVLQp9Wt7pqVX149Bvp/3RcBULTv6wjm1E2E9VtNZ
jLZ+wdZ0d2NCsyNT1eab+/BKXPrzHcYZTJPr1oeNe3h2itNMlqYJ7kVDUd6U
8f6ZTA/XgwXGkuUlxbOYl7Z6MKq7p+pvfxdWoAW8hsYvLZuKf3dh91S5lm68
7/l2smx0ZWs1wd244dgkb/vTlVWq4Y52YdeRBJtN6ySm16MLk1tWD28plJju
fyee7Kp4vrdFYtrjiR1o8Q3kZ3olptlhaEfTg5zdn7ZL7FfNzyt4LatibJ5J
Ev5dRqfEDcqLLZLw6xJaQpq3RjpKwp+L6NORHnu7yFX4cQFTvC8l5tm5Mi3c
rvPIEjut8yJd2BJN7zlcPJa2LfjQLKGvBYveKmvNaJ0p9JzFQbua2GNNziL/
ZjRUW+QVZieRr4Kl5VXzk2umsxItvyZs87C/KiVNZQ5aPg24NtPkedpgz9K1
99dj6GLb/p4LtuJ9J7EwuzioaaO1iF+Hr3kuku6UvJT1eNVoCV//SWHyUzlF
O1+Jb4Z+EVbkNyH/oD3/PY4WeIfbP38oZ2j7BzDKNPvyq9G/if97sUGZFugQ
0yf/PyFmh5XBl70MPmIfKormrKF9RZwHj2/WtNJ55aweHwLCa0IovtivhIOz
Pwyl9ysVen6wzH1rBOUnnq+D8Z/2uVL+yriuD45kblP1cT3/ehhytlf1c+EP
rGgbVP3hwj/wL49V/ePCX5jrxxaQv1z4DzNOnGbkPxf1gfFeUxzVh4v6QVKL
10WqH1+q1xc6F7ybQPXluv/n4VhEmQ3Vn5/X+wNSc2u3U39wR71/YPW9nXHU
P/xjvb/g9Zi2eOovfkjvP9gSFs+p//hNvT/BbrLzLvWnyLcd8tPPZVD/ctHf
4BdZ0Ez9LfLvhN7bD15Q/3MxHzDwzsERmg+hpwum9F6wpfnhYr5g3dyNSPMl
9HXDjrSMFJo/LuYTIsJ9Ymg+hd4eMMO8appfPqDPN/y4e9Cb5lvo74Whb1us
af65u84HOP5oLIf4wAU/YIg3vSR+cMEX8Frpt5P4wgV/IDDoaQTxhws+wYna
gH7iExf8AoflC2uIX1zwDe4HxL9HfOOCf+C0fqyI+McFHyFn/ysjxEeuz/t1
WMi+SyV+8mydr3D7sE0S8VXx1PkLNy6W5RB/lU6dzxD3/tUQ4rOi+z0C5ab9
k8RvRfAdompSM4nviuA/eFi/sYr4r4j7ATyXOS+j+0ER9wfsGf3jGd0fyn/D
ayaF
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1lQtQlFUUx2FdWQQWcUBwROHTHgJOE8UqM7XXAw4JDhUJaIjLYIUpOA1S
pg5QQoLgpKLxkKAXjyAeMog7CLm3AwgpCuviosAuIpaZBpMvXkZq9/u+253Z
3dm53z3f+f/POb+77P3kyG0KGxubbewj/sprFLNXBlj8Yx5qdXkdkz66G1ik
ss0JH5/Qtnhlj21oGUFroN1p/45prVtD6M1UtxF0bK5O+8v6jzaFOAxU7LqO
CY0hR02vPdX29ohrGJ+rfeWB/p4N8ZUCDuO7qpWnq28piBjNK9uKXz6vWZc7
qyQsGItowXVPijarA1RkjRiOWHB2j70m8tA8UvK1uIbQyTkEjbOOZMpHDDiI
YLJ+EpnjTCKlBAexODE01LbAhUjpNQzgSL7u0cnxBVJ27AutQ+9FLQl3JR9K
6xp6BGrsPqp3I6LavI6reOLAY880tTuR5Hpdxap7ATO3kjxImiS4HzP6JuZ7
tC8icjgzVj8rjY5xWkwCpGXGXNsljoNhnuSYFPAKHjeZ2wwfLyHjotyxPnwr
IkWhObiUhEmC+zB1c3XyF/u9SKUYrsKEftvj21y3eBO5Hib0iPv7xS4Hgcj+
G1Hx83LL7Y0CkR7f1YutCWWuh48IRLLDpwcdNfHzMxsF8pvk50VMz09S/UoF
7l83Dt6on/5KL3C/LuDy0s9XxRYI3J/zWDzT2detE7gfXRg/9Pb5S2qBSOFS
O7EpZ2KOQ4Q3eVXSew6Dxsprq6K9uL52PFXzrbLwpaVcTxvujL90e6vVk+f/
C7rv/6P5Qfxinq8BdxS8cDmDLiLFUn6teOzTa4l5U+7EXsrnDE6/EbV7WL2Q
pEvv16Nq4XRZrJ0rf98prAlMdFrxuwuP34DnMzYG2UaoebwaXHs00C7zpD3Z
J52vxDtxx72r78whjdLz32HiBz1NZuen2gxpvwBLYxyNVcsm+P8sHO169M74
y7e0/0+IMLm96l+l6nW+D0U3w8V9Az8PvtWXe9l5Q5scH4TKFjE+368Eh6ly
8f30Bzk/OFS2U8yPys83QMK+JjF/el/WB+HPGkR9VM5fD/6lm8qZfsr9gYrD
RtEfyv2DELvkJOYf5f6CIm1Y9Jdy/2F16NkzzH/K6wOCW9ufrD6U1w+MA41z
Wf2oRq4vTP5ormP1pbL/nZCZHDyX1Z92yv0BfvsVF1h/UCe5f8DZkHWF9Q+N
lvsLCtesX836i34j9x8YFZkzrP/oqNyfcLd1nT3rT55vDxT1Bruw/qW8vyGq
P9eN9TfP3wjaOLWV9T/l8wEb8i0r2HxwPSY40h3YweaH8vmCvd+np7D54vr6
ICkvSMnmj/L5BN/okg42n1yvGR6+OeDE5pcOyvMN3YPrN7H55vr7oS4kfwGb
fyrIfIDmyPbHjA+U8wOO7929lPGDcr6A8qdSFeML5fyBjU/00Yw/lPMJom6X
TDA+Uc4v0NXuCmP8opxvEOyr3MP4Rjn/IKt2bTvjH+V8hOEVI6sYH6k87xZI
HQvZwvhJD8p8hbvnzoYyvlI/mb8QPO+onvGXGmU+Q9X9lIeMz9zv6xBrPnCM
8dvA+Q7X62s+Y3w3cP7DDt1lPeO/gd8PsNVQmMvuBwO/P6Du4gkruz8M/wEk
2hYU
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYxy/cmiHNSdc/l561fgjZhjv4I/Wjz2KsI5slFm44hwlD3bQ4
TTwCtMsBBUOhkKkIHCWBmDFhyJ3rsUeOM7MhuwNPfhwcl6UZ58TWxM1Nifs8
T5+Nsdv3+31/n/f7eZ7X96Wc/I15MQaDIW/uL/qfT5i2lZzdsLdwvdpS7XmQ
sGWSDrUG+qb7MpTbXBbJcIfoYG7nBzczMpWxw/p7kTFEg++YvXX2LLVnTezw
KdsE2XyL32yxZqtr/dEzTtNVXbOXp7apRC04TufiCv09pjwVVTOXBenqXyFv
8OJONSc2pzhGL0x5ntka2q3WRuXWjNHnqZXhhX02VX8iekbpl+Cev1O2fqpm
EqKCI3QWdj7xW/erjbrAEXp/tefjIsdnSpfXMUzfuYPG+wsOKC0XO0w/lMeX
PCxwqO363KDHo6lFxTWHVNRttSdA1mV39scGSpW2aw7QgR33jmxK/VIVa8PX
KbLYueKVGxWK5YZoYUzk7eTDVSpZnyHqNn1leCO3WtVowUG6temfhPTEr9Xd
qN2In3raM9uyznyj0rVhP6nTM93BFUdVS1TulI+CSyrS17nrFPfDR0Zbmr12
9THJf4AqE2cLXj5/XOnbbdfIYrLnPTDXKx1HQj8tmYifPr33pLqp8/yN0uzh
qob2BsnvKvWO/psYd7FR8vqV/vxo1Ynk1ibJ5wq9djvNsi/bKXlcJl/WF66S
SafSckVecs176q0Li5qVRfvto4eLknYcjm8Wf710tyznXkzYKX4uUf7jW8+3
bnBK/T/T5JVCe/W+JqkXaW1Ol82+rlEd1/VdoKfzI42bB0+q+boeF5kCj/wV
z9arEv3+bvqpbeXSrifH5H2dZJm3fPN4e53od5CruK0311greu2U8u1w7x9p
NapQP99C8bsOLltVXqnO6fub6NXgoyPfJ5Uqh75+lOZvN6Q6LMXyu5TWZ9bu
huxd6v8N+eS92aWqJ98l1+Fdvo7yPMjzeIn1IYn15XoLmPj92Mz1wUquT+7v
AOT68T77gxT2h1x/N7jZP0o+IPmg5AeSH0q+IPmi5A+SP0p/QPqD0j+Q/mEK
9xdmuL/I+XtB+o9eng+Q+cA4nh+Q+cEPeb5A5gsbeP6AeP4wzPMJVp5Pqbcf
ZH5R5huSeb6l/gGo4vlH2Q+Q/RA/PpD9QdkvkP0Sf344z/uHsp9wm/dT/A5B
J+8vjvB+wwLeb/F/He7w/uOLzAcoYD6g8AOEHyh8AeELCn9A+IPCJxA+ofAL
hF8ofAPhGwr/QPiHwkdwMB+R930MnmN+YjnzFTzMV3yd+Qs/Mn9xgPkMU8xn
yXsC7MxvFL6D8F3yD4HwH+X7APJ9kH6EQb4f+B+iFDdD
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYx4E1IaZuNgQjuxllHqyBAU1yjz4NQklTB6vmpoNiI/+ohazN
tRMXFjRrCSY0+eEUB4NoeF3AUvGJhwOOAz2Ou/h10omkq9VUIC3nxqZxn+fp
szF2+36/7+/zfj/P8/o+V1icVxQRFhZWtPQX+i9nlv030l52PnME9lf1/Wvd
f4Pz5sKfjPr6KFy0VNzOvTjDH7rb0/tXVkCMfftvtpgZrvrg57aCDV9CyZbo
qaaD1/nk3IlB+PM4jHhCJ8ije9e17Or4BhKNYJBfOHTWkhyogZCapeJXbii3
uieLa2FJbElxmo+dOebK/fw0bA3JbZlm5zsbT6ZUNkJ9Xehc42WRk4OxCU3w
wBoSDLD7fqK9PLwF8kyBAc4vPVIYvrENTHn2KV72KOfFbY52MHLRU7xjtd33
RKYD3jdnklfV1Fh+f7sDQm6r+ia4u5Uf76zuAmPXMsGtm1c65x/+BIeN4XGu
sq6ebyi/BCI3xh3pNBSfRpBmzhhvX56WmRDGcMII/sKdFLyWcL8X7oTs3vYz
vuJqOVTcBznGsJ/jHmUlJ/3dD80huSYfx7q/+s79sQukHz6ujkpO3HVvUPP3
8qt7o20ZB4bA3H5whLPPv9lxyjMMJg6rh2/um620rL0KN02eV/jueNmB1/Z4
NL9h3hHX8NHughHNa4gzIhyX67K9mo+bfyj8o6R20at5uLjgzqJ1xeFRMHK2
Ac6uv3UqpWcUUo3ffs5PSn13gkfVn5Md/9x11i3dL356ObNy7b2IOa/W38MP
PvV5mmK8Wi/xY9t7LRlzHqg19V3iNaOb4npsVyHK1HOBUxr/cpZdHoZS8/4u
XlxfmrW+063v+5HfmF+80FrkUn07TzXvLssL9KleG7s/a93avqoXPjHPN/MK
v+Xb7tRucJj7z3BkrCc3fqETysz1Gn723EzJreD3+ruca+PnX3o6qgH+35A1
21yR9T1nN+l11Oukz6M+T72ij0+Jvl5vxhh5PzVKfXhF6tP77RiU+mlB/OFO
8UdSfxc+FP+k+aDmQ5ofxkp+pPmi5kuaP2r+pP1B7Q9p/1D7R+nSX9wn/SXJ
fwCzpP80IPOB+TIftFzmB3V+6C2ZL9ws80WnZf4wR+aPZmU+cUHmU+v1oM4v
6XyjzrfW70Wdf9L9QN0P9eND3R/S/ULdL/XnR90/0v1E3U/1O4avy/5SQPYb
z8t+q/9xPC77T+uED9gofCDlByo/SPmCyhdS/qDyh5RPqHwi5Rcqv0j5hso3
Uv6h8o+Uj6h8JNn3aTwq/KQvhK9YLXylJOEvPi/8Ja/wGYeEz5r3dWwQfpPy
HZXvmv8MKv9Jvw+o3wftxyzq94P+A5AHP0M=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQ1M1HUYx1HDFCWtaEtzV645oBeaxbL0p89GLNuac76MWrNQJ74wlpAU
Ri/LDsSRjlZ04guuEhsNuFkId6dPPoqHBDtuB3fnweFxdxx43KFJrOxls+J+
z9NvY+z2//+//+f7fZ7n81+6fe/GgplJSUkF03+J/3xCNFa/fm6+6ajaUtPx
e8aWIJ2KKNfU3pPKaqic2GAdJltmc1rWwm9UmnltuDxtmO6+sGl3/7YGVbI6
xXe6OEDLd/Ubulc1ql5H4lynevctU1NLs8rUgtep4k1LVU/krEqoGSqHKJo8
VHvb0aqmxaYV/VRz3rxj12KLWpOQW+2nm3mlBQ97zqvjxxJnkEoW9by0bwap
OxkJwQF6a2Zec53nstqoCxyg9I9Mtyt325Uuz+yj7Odt77Wv6VJaLsVH2z8L
dx95vUft1Oca3U0Ol73T3qsSbms6vFQ28fIjfU0upe0avDSZ3l06q75ffaAN
e6h8Sevse1s8iuXcdOHfGQ/lDF5Tz+njprVTo8mrDIPqcy3YT8ETf189XDak
bibsTvTRmaxNwWAwoF7RhvvImXbYWJoRUg0JudMuqkrPuceyLay4Hy5asm5e
V+PREcnfSRT1PenujCh9e3Ev/bPwgfsKoqNKx5HhoIO/xBfk/jGmRnSePWQ0
Fn67dPKG5NdN++J/VX3piEpeP9PHL76755mqccmnix4NHZpsXByTPDppw/pA
+68HYkrLldvpyqL7V75hjalntd8rZPuqKP6jLSb+LtOrdx5/rejTmPi5RN5j
OcVtC2JS/0Uy/ZbqNeWPS71I7T8Zs1JKoqpO12cj0xfuxvm5N9QcXY+FjLnL
sGlwVH2o33+O/EVTJ+ZlR+R9P9Ds6kPunXlh0TdTZvS7utTqYdH7nq4+2FJY
mOJX+/XzDdQ8ayRp3UqvOqvvP0W+P7c6L6S71Cf6ei3Fx+JHsuyd8ruCrL62
W8ujber/DUkd2fr2+LKnVsh1sPB1lOdBnsdLrA9B1pfrDdDK78evuT5wcH1y
vxme5vpxkv3BHPaHXP858LF/lHxA8kHJDyQ/lHxB8kXJHyR/lP6A9AelfyD9
w2zuL1i5v8j526GD+492ng+Q+cD5PD8g84Obeb5A5gtP8vxBMc8fhng+oYLn
U+p1gMwvynyDzLfU7wSZf5T9ANkP8eMC2R+U/QLZL/HXB7J/KPsJAd5P8euG
XN5fHOD9Bivvt/j3wPu8//gY8wEmmA8o/ID9zA8UvoDwBYU/IPxB4RMIn1D4
BcIvFL5BPvMNhX8g/EPhIwgfkffdD9XMTzzIfIUI8xWfYP7CAeYvOpnPUMt8
lrwDsIL5jcJ3EL5L/sMg/Ef5PoB8H6QfIZDvB/4HlXNdKQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYx89w2JzWUvzjcLJjznZZEYY/4YOPa8v8Q1qelVviRuTRpmun
+XNEDq2zIsM2tRDQUvBndYk/EvIZDxDIhXd0CHiAx69Iax3FQfzwjqL4fp6n
z8bY7fv9vr/P+/08z+sbn+mw2R8ymUz2yT/jP58eWnam+nqi7YJKP1wzYk3v
pvYXj//kO+hS5XHO4LryLtpgirKZ1l1WMa4XerNjumis+LUtwZ5ranvqdH/J
tk7650ieeX7U98rrMU6AHHZrw2Z3pXpCCwZo5ybL2b8tNcpQi3PepWT7jiXf
rapTk2KTih3UcGdap9njVisNudQOOnE6I/r0LY8qPG6cdppd+VTmmRKfGrUa
gm2Ulhx7Y8H8ZmXTBbbRofbMVzb/2qp0eS4/uX3152moTWm56X7aXpqy8drq
gMrS5w6Z1w4UXenrVobbwzWtZPl3X/SuX3qVthvXSusfmXJ7ZqRPvaMNt9D+
xws+qUi8r1iumQrXnOr4xvmbStKnmZbe+NqcOPK7+lQL3qa8wQfDH2b/ofoN
u8EmQvOxPRPTQmqNNtxEvfkfOOwbBlWpIVfioxW2VccKzg0p7oePsk0Jy1OH
/5L8Gyn0Z/ysj5aPKH37Ni8dyHdceckxqnQcVg8NhAceiz0ypn7WeTbQoR1R
c5NOPpD8fqQFr++e4skLS15ump1T5Y9ZH5F86mlrYGb3psGI5FFHc784712R
Ma60XHYthcD59KnCcfWs9vsDPfn8Zf+c4nHxV00Hyvpz6ibvZz9V5N0aY7l4
LyL1V1Lw2xb7OWtE6kX6vDztbIk1rAp0fRXUN29RTdG9MfWwruc6vWnfGLiU
Mapy9PuvknPWzeeeKR6W95VR+6O7puYXDYm+iy52T+3PeiMkehfImZLwlXco
qPbq50upLiF+0Vvu++qSvv8kWcLvTVS82qty9fWjtDd8Ys6WdL/8fp9Wx1e/
O7G/Xv2/IbH9n6WUrVy7TK6DXEd5Hnbz81jF+mBlfbleCl5+P37J9cHHXJ/c
7wIX148h9gcB9odc/1XIZf8o+YDkg5IfSH4o+YLki5I/SP4o/YFb3B+U/oH0
Dxdzf2Eh9xc5/1qQ/mMtzwfIfOAMnh+Q+cGXeb5A5guLef7AwvOHPTyfIPMp
9XpA5hdlviGX51vqbwSZf5T9ANkP8eODZN4flP2CPt4v8dcEsn8o+wmyn+K3
GZJ4f7GN9xsKeL/Ffwvs4/1HC/MB0pgPKPwA4QcKX0D4gsIfEP6g8AmETyj8
AuEXCt9A+IbCPxD+ofARhI/I+94B9cxPPMh8hSXMV1zI/IW3mb/YyHyGLOaz
5N0J0Uc1v1H4DsJ3yb8LhP8o3wfw8/dB+tED8v3A/wDu5VZn
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQ9M1GUYxw+8W2lUM6mtsjPcorPUVUBavj+esJXUpuuYmhnU1OEJzdS1
NgZJzaK1YsqwMRRnMlAxx2lxFa339ZE/HQR3N47Tgzs9upOs3fibDUqLiHuf
p3e73X5739/ze57v83w/b9r2PXmFySaTqXDul/inFcVY8HjORKpL5B9qn7Ll
/4x+W13NO1mtotVaMWJvHcIqIzTuSlEi1bkuVpo6hOkt044XXmsT+4wFAw17
I3g4NDS79ESn8HoS6yraxrLiT+/qFst0wKtodo89m4EekYhmrbiCZzJLKt8P
9Ym5YHMRw5jmWG9ubQqI7EQ4I4y5lec7bgWC4uiRxArhg6Gdu+u2hcW0LRFw
EMMq0mV/dUjk6QQHcXNGzuhMfkzo9JwDGGp+bkuze1jocAsG0NuyqvJ60a9i
p15BjP3r88+8GBeJag+1X8a1ORW32QtGhS7Xehn7PyledP/ZCVGmC76E+Q8M
rjxV87ugcAHMjk68jnv+EBl6BbB4+eqa4YIpUaUD9uOid93WzQV/itFEuSN+
7F9bckdl0U2Rqwv24/x9fy18fP/fojERrqEP763YfvbO6hlB/ehDz5d3L15f
P8v6+3B/b+1wk99k6ON7vbjyQId5qivJ0HLYPJju3ODPOJdsXNN69uASvEfF
DswzSL+fcPVvBU07ss0G6dWNlrhrkzViNkifLlxePmiu2moxSI8f8aXTU8fe
+tpi6HClnbhqTeo3rqjFeErX24F5jfUtV2IWg+prwx5fy4rQ3Hmq5yKqsdKT
6+wWg/K/gEVvPOMu/cHM+Up0uGufPzw5z6jV+X2P448erD44mWzcrvP5Dl9O
mt9rl0nGe/r7Ltwx6116bpOJv/cVxtWazN7yGdbHiSue+DQn69ZNQfHOYHtZ
8Za69GlRot9vxA3L2oKf3XVDnNfnj+PCC2//Ei8bER/o/c+xIeXN8uCH1/j5
IzRdb3Z8Ud8v/ndIz27HPzc6It/yPvC+5PeB35cXKT4sofi83wgb6fvyBOUH
3ZQfn3fCk5S/nKT6YJzqk5S/C7ZR/Yr1AdZHsX7A+inWFwpJX8X6A+uvuD/A
/VHcP+D+qUzqL7xC/VWkfydw/1UnzQfk0nyoFJof4PlRG2m+gOdLHaP5gyya
PxWl+YQ0mk/O1wOP0Pwqnm/g+eb8fcDzr9gf4CV/SPYP3Ef+kewvYH9J9h+w
/yT7E9ifkuoNwC7yrxwkf4Mgf0uq/xJsJf/Lh4kP0E18kMwPYH5I5gtEiS+S
+QPMH8l8AuaTZH4B80sy34D5Jpl/8BDxTzIfgfkoye9hWEz8lB8TX+Ek8VU+
RvyFJOKv9BGfIY34LEnvCBwhfkvmOzDfJfMfqon/ku8H4PtB8v0BfH/I/wA6
rEe+
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lX9M1HUYx5FEDkPn1lU26SrLdUCIWlKrz9enSYPmbOqpkwgRDWQrTfmn
Mc+YqBxtVKeNNaW8KT80qa4cLGh+vj2XnqPouKFwcJ3HdYLm4keRXhesiO4+
z9NnY+z2+Xze3+d5P8/z+jy2a5+lLDEhIaEs9hf/TyuMKzsi5QOvdogi+6U/
zUU/Y9Prh70Zy6ToNNWMbeoMYXBNYHz9sEsYnfk3DhhDuDf53dW30t2iQps/
2LR/CO+v3ZOTOtUlejzxFcT3c8Kdjxd5RLoSDGJDZULrvLZeEVcz1VzH6tx/
Ju9+2CdiYjHFALa0fX0l5BsQa+JyWgDHMvPvHDsSEA0n4+sntCxvNZQ0hUTU
HBf045aNhcXRUzeERQXox+zdFfa96TeFCs85iBtme7atjf4ilNz8QSze+VT/
taRRsVutAVyfGz19pGBCxLO1X/Kh8y+xrvvtSaHSNfmwzlWfZd15R1hVwv04
/Ejas8ffiAiS60Pj0PJqqz0qnlarD78M2Td7PFPimBK8hu21U19kmf4W4/F0
x65i9uAHbxVWzYiXVcJX8bXnikfTbs+K5rhcUy/aJmqD581zNKpHL25bNNFa
VZiokf9eXHt81tZy9B5NHd/fg++ZRlzbG+dqyg6zBxcEt5c4nEnasPKzG0vD
5SMZzfM08u8H1HJG3/zsnWSN/PoeFy7Wol2rDRr504WbdixdkNdl0MiPKxhw
L3vFnJWiKbkDbjyXlT7q3ZWirVL5XsbayEMbF5emaJTfd/jR+K83D8XOUz4u
9Ltfuv2iNHD83+LsxSdLyxcaOF6JF7auyPtjabJ2QsX3De6o3FN/fTpJM6h4
OvBcQfV9K+rnagfV99uxY19F472RRP7eBZzJmwmcSpvD+k40LvmtLPeJfwXp
nceGdf5MR9u0qFT3m/Fg5vTWursR8ZU670C3pSroHvldHFL79fjjC/YHz1hv
8e+jiN2NF7MdPvH/hHz8gLHk8tSnq3gfeF/yfeD70kX64CN93m+Gw/R9eZri
gzMUH593wsMUv5yk/CAhX+WnU/zt0E756+wPnCV/dPYPisk/nf0F9ldn/4H9
17k+wPXRuX7A9dOfofqCjeqrk/9uaKH6627qj9h91R96KvUPWKh/9C3UX8D9
pX9C/QfPU//pYepP4P7keD2QSv2rc39DHfU3x+8F7n+d5wMKaD44n17g+dF5
voDnS/L8wUqaP8nzCTyfkvLtg89pfqWf5hsW0XxLyr8fwjT/8lHiA9iID5L5
AcwPyXwB5otk/gDzRzKfgPkkmV/A/JLMN9hMfJPMP2D+SeYjMB8lzXsAHMRP
aSO+gpX4KjOIv3CC+Cu9xGeoIT5L8nsIlhC/JfMdmO+S+Q/Mf8nvA/D7IPn9
AH4/5H8QSDz+
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYx48jKjD/kNlWy5jmZHggOGPN1efrsxADhYlA/kKbonH/ZAgX
JJlr2dKYayErgqyRDaZI200cFOjz9UE6JodAXIccHnJy+GM0WKf9YFI24j7P
02e73W7f7/e553k/7/fru2zfwbwiq8ViKZr/hL/5jJP74dY9jtEWtbuq66+E
3bfo+7P5x6s+alPtccemctsDtKS3tvNSb4da7MwIHl4coOCuuYI7PZdVqRHj
aygZo/TkI23fbuxS/X3hc5OWbL51ovJ0t1qpC96kvIM/7Egud6twtbhjo7Tj
k82PyNuv5ovNV/TToYvN5qo3PWpduJzhp3P29NnClCF16qvwuUFz185fjMr1
qZmEcMERKlxoaXhmwK/ydIMjtL1u2xl/c0Dp9pw+Gt60oTqzPKh0uRgfLZrM
Tmq8elvZ9RmmPfZ3triz76nwtFVd12n/lQVHlz/2q9Ljxl2n2LtvVC2dnlLv
64GHqKZ4/c5Ya0hxOS/V9q9wRS97oF7Ux0uRTfE5Fd7f1Uld8BeqTIzNX1Dz
p5oOjzvloaYKR7GrcEZl6oE9VJbVkRVKfagaw+UaBqnaXp6+IvpvxfsYpOkD
n6VsG/lH9B8gv6Olbfjrf5W+vaSfFta8vLcse05pORL6aNje3ppRajEmtJ69
9NadmEXPJ0YYrJ+bJoMBl/PnCIP16qHXbJ/CgwKrwfpcpZM5PQWhHqvBenTT
6tLy1ImnIw1d7rCLVo7Z+jauizTW6Hl/oqKSM21REGnwfFfogidi+dvz9/M8
neRJLD1aRFaD+79MG25nTLz7itXgfpGSHCdKxiojjDrdXweFcpterT1rMZ7U
/fxIocTgtdHVc+qI/v9Wit53o2ym45Ho2UIvJOWk5YVmRR8nrbHV+7f7ZhTX
O0dp8fGzv733h6rQzzdS1oXuz7EzpM7r++upxf9BynrbpPpQX/+Cyu6m1Rdn
jMvvj6nyu7V1pwoH1f8JcR/6cueqKMtauQ5yHeV5kOexk+sDcn253gj5/P94
mvuDTO5P7nfCS9w/3uf5IJ7nQ+6/FR7n+VH0gfusD4p+IPqZoi+IvqboD6K/
KfsB2Y8p+wPZn5nK+wXZr8n6u0D2b7rYH5DM/jCfYv9ANfvHfJ39BeIv8xv2
H9xj/5nj7E84wP6UfvtA/GuKv0H8jeJ/EP+j5AMkHyj5AckPSr5A8oWSP2jm
/KHkEySfyPN6wcr5xRHON9RwvpHnH4Jqzj8uZT7AE8wHFH6A8AOFLyB8QeEP
CH9Q+ATCJxR+wVbmFwrfQPiGwj8Q/qHwEYSPyHn3g4P5iceZr7CF+Yo25i/k
Mn9xgPkMzzKfkfUeg03MbxS+g/Bd9A/Ac8x/lPcDyPtB9jEO8v7A/wBvxjrC

          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw9lQ9MlHUYx4nGJIdmDshRkP0/rbUpZLr96MkBE5qtdNdajXRh5latwKUT
JcPy1FIHAyeZzn8QyR8PSIS79tiDx0UQeN5x53Eed690hn+yf5biwqnx/p5n
/TbGbu/7ft/n+32e5/M+XPTh0pXxcXFxKyf+zP98Rij1sctrc1MrVWGF67ql
8Bwlpf66oXR+tXJk2K4scRhUHn5uzmvGbpVsX/Tz+mSDln+3On3GjL2qJHvy
UG1xlI5nuS6Gxw6oUwPmidC2y+P3Lug5rGZpwQiVdyZ8UHX9a2WqZdiGKfSo
/aOWqgY1ITahGKYVa5/wfVN/VD1vymWHCY0+Z3p6m/pqj3nO0oXCQ9N6G4+p
MYspGKKCiGPBP590qKW6wBC9u/39stoDTqXLsw/R2LZ5LyUnnVBabvIQrd64
Z03uii71jj5Bal5+rWPnKpcy3Va4ztDnefe58qrcStvNOEMP1YSfmRTrURu0
4QDln3d1VFr7FMv56cntsd9bL/SrTH38VN296uVnd3lUpRYcJGtvkvePJq/6
zbR7xUdH3r7L2pgyqPK1YR/ZHk/bV/OZX9WZcrVeagreerr0akBxP7yUeay9
tfKNoOTvoTlf9MxrdA4pfXvxKfLHbg0+dc9ZpeOwDJB1JO3grJywiuk8f6Ip
wdSEjW8NS359tPXP21dH34xIXr30bXzR/plzo5LPj0QpFZbpoajk8QM1p1gX
XyowlJZb76Z1i7bmvPCpoeZqv920cOoy9+IyQ/ydpBt52TfHMw3x00V/x355
JaU+KvV/T2Ml5/qLvBGpF2nhMu/oybZh9aWuz0nHm665sl8Mq0RdTyc5cx3D
D+4NqTL9/nY6Pf+89VJ9UN7XRtV355S+VxIQfTvdeHU8oemOT/QaaNrO22VH
WjxqnX6+jvyPZCXmx/epVn3/ftpdMPXijkndqlxf30XdsyOKDjvl92Y6aqkL
fNzfoP7fkMTXbeO+O51yHZr5Osrz4ObnsYv14RDry/U6CPH78SDXBw9wfXK/
HW5y/fgX+4Ma9odcfzv0s3+UfMDB+aDkB5IfSr6Qw/mi5A+SP0p/QPqD0j/4
l/uHWdxfkP4i5++GNdx/dPN8gMwHJvH8gIvnB608X9DC84X7eP5gC88fjvB8
gsyn1DsAMr8o8w0y31K/B2T+UfYDZD/Ejxdkf1D2Czbzfok/H8j+oewnyH6K
Xz/s4P3FEO83yH6L/wDk8f7jTOYDpDEfUPgBwg8UvoDwBYU/UMz8QeETCJ9Q
+AXCLxS+QT7zDYV/MMr8Q+EjnGA+Iu97GAqZn7iF+Qqnma84m/kLm5i/6GE+
g435LHlHwcn8RuE7FDHfJX8DNjH/Ub4PMIW/D9KPEbifvx/4H6FSV3o=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lX1MlXUUxwmb3ZCwP2hWbKDBRUSleVNXeuzQbOWGrsHQkdHmKAqwELq4
qUWzEvujF0nthTfXxs3XK8oisHXWuQiREt7x6r1c4PJWaqCFRlCkt7i/c/pt
jN09z/N9zvd7zvk8i7J2pGWHhoSEZM/+Bf/LGWKOGWyJm3eSMg+c/zMhc5Bt
qz8v+/jQGToXXTKees7Pm8l618bwrymy5tnhPZF+vrG7KjbOX0+F68I81QUD
/M6VwjlvpH5Hl9qCp5+Lsk8XO8BFS4xgP1tDV5U2rGyioFp0SR/H/Fu+dW5F
C82KzSr6ePsp3wLH7lZ6Mii3zscf7i0Nf9XnpvKy4OnlqiMRiamjHTSVEBT0
ciClfjyvupvSTIFe3jSdfjCx1kOmvBoPJz+cvNQ+v4+MXJiHI50LXlzu8tMr
5lzmxqgcnyVrmIJuD5zv4f2vxVqf+GiUjN3oHh6YmXC+O/QLvWkMd7PNk7S5
9/lrJHJdvISaR2xTY/SYOV183LLtM3vtDSo1gp18Yth59tH1E3Q9aHe8g5cv
XZSzoeEmbTCGOzj+pfTMtSv+IEdQrrqde7x+t9M5SdKPdr5Wt7qtLm5K83dz
/sXm02OHpsncXnCJ7U8v3rJz8i8ycSS0cf6nSUkLk2doxOTZyk21UVxU8I/m
d5ETVh0s8759W/O6wP6jtrAzL9/RfH7kzIyffiuOCmgeP/D9733QFVkVICO3
p5k7y10Z34wGyGb8NnFlXlHj2rGA+mvkU1W19mecAfXj4nuyJqwvxAe0/u85
50qJ3bLljtZL3L2iqTJ0zW36wtT3Le9Li3huTecMWUw9DbxxbPvO6zF/01vm
/XXsdbQ9ddI6re+rZct9n/RmXJ1U/Rr2FD6UlpB3S/VOcNfVzp/n5P5Ou8zz
DnaNLJ7sq/iVzpr7j3DFvbtujhSP0l5z/TC3HEuxHl7v09/7eG5EeNKy/Fb6
f0O25R67lVs//3G9jnfLddDnUZ8Hl+jjV6Kv1x3YIu+HL6U+7Jf69P4a7Jf6
YUL84TzxB1J/HXrEP2g+mCL5gOaHmh9ovqj5guaPmj9of1D7A9o/1P7BSukv
Vkh/QfJvxg7pPzTLfKDOB4TL/OBWmR9Il/nCQZkvqJT5w1iZPxiS+cQLMp9a
bxvq/ILONxbKfGv9bnxd5h90P1D3Q/20Y7fsD+h+oe6X+uvAZbJ/oPuJup/q
twt1f8Er+43xst/qvxt1/2Gh8AEvCx9A+YHKD1C+IAtfQPmDDwh/QPmEyidQ
fqHyC5RvqHwD5R9WCv9A+YjKR5B992GW8BP2C1/xQeErJAp/8RHhL7iFz7hD
+Kx5D+D7wm9QvuO48F3z96PyH/T7gPp90H4MoX4/4D8EhU2H
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1GUcxwn0QjjgLCnmChRbXbBhox9/5PP4MVo/qDGU2VimTmkUGg1q
yRrVShPm3MJa2AQZWdwqat1Q0YN6vnwuuiY0jrgA77xOuhQ0xuGvwwuEIO75
fHo2xm7P9/v+ft7v5/N5PatLKopKY2NiYkoX/6L/aQVx9LeMc6tnf1RbD3Xf
tG79E9MGTm1JDTtVR3rNxKaOEVTWz2ehwqVW2J/5q3rFCC69eqLLur9HvSET
vC2V5zG5e9KU9pRbufuiK4DzbX2Z2S971INaMIAnMsqvvFU3pKJq6TV/4Gjo
imfVWp9aFFtU9KN9/GjJWGFArY/KST/GPeB9vum9oGpsiK5z2JpT0bTv3osq
Yo0K+tB3K3k8y3xJFekCfZh/oCpSXTCudHl2L648+MSrNaMhpeUSvDiJuKN1
1zX1il5nMSctY83mj26oqNtD3cM4ZoqYLgemlLabPow5+a9bsov/Ue9ow0P4
+EOVG8IzM4rkBjGy3Hr/ku459bBeg9gw1rxm4dsF9bEW/B3DO1ueay2+zQhF
7U548L6deUvTRmONZ7VhD/7bc9Lrqlpi2KJyLQOYezArkphoMug8BvD6zKeJ
7UdvNyj/fgxtmy+/lbnM0I9XurHySVexrTHB0HFY+zB07KW81LlE44LO81es
d5xduXtDkkH59WLnN7HpDTuSDcqrB10/bHcefiHFoHzO4MWUPdPrzBaD8vgF
pycOXy7aZDG0XLULhXt5yUKVxcjVfn/Gjrbm0g+rLezvJ9y17P3CAy9a2I8T
T8Vtd+TeYeH6u/DvUuUsezqF61Vori1f67g72Tii6+vExuG9veuPmI14XY8D
d09tjNvYm2C8q7/fjp3uri1ffR/P3zuOe0fyksryTaxvR+sXZbX3fBnHeq2Y
9Nqe6oauGONt/b4N8/2fXHAXzKo2/Xwz3ngz+N2jPVPqA71fj7Cu4PjJmBD/
3o914XpbZk5A/T8hSSV18Xed2ebgfeB9we8Dvy+cpA9zpM/7Niik74tjVB/c
SfVJet4O2VS/vEb+YB/5k1R/O7B/yfkA5yM5P+D8JOcLnK/k/OES5S/5fIDP
R/L5AZ+ffITOF07T+UrK3wWSzl+6qD/gJvWHNFP/APeP3Ez9Bdxfson6D05T
/8kg9Sdwf3K9fTBJ/Su5v4H7m+vvB+5/yfMBV2k+2M8A8PxIni+Yp/lifx7g
+ZM8n3Cd5pP9DsJnNL/CR/MNYZpvQf6H4DGaf7GK+ABW4oNgfgDzQzBfgPki
mD/A/BHMJ2A+CeYXML8E8w38xDfB/APmn2A+AvNR0Lz74Wvip6glvkKQ+Cqy
iL9gJ/6KfuIzTBOfBeV9HlKJ34L5Dsx3wfwH5r/g+wH4fhB8fwDfH+I/zIAv
tQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYxy+wIYc64Y4DsjC77TrO5h+G+M/344O0K/thxdFsa6xmk1tm
LEot01bYuHbaD7KZIEkwfrQ5NxbTDazPx+eAwwqBjg44ONAQilCMVYRSYIv7
PE+f7Xb77vP9vj/P836e5/VZ9+KrnqI4k8lUtPSL/dMaw/ll+0Lj0+2ysLx9
zln4E3YNlxXvn70oWzN90/mtVzCpvLHs9NlL0tr0yNWD1iv4etbejLa6kHxN
mCP1JZfRfz7v68jVsOzpjq1RrM/JznE0RmSWFhzFah98kLcwImNqmb4RdEy3
POR/a0wuiS0pRvHDyq1euX1CbonJiSgG9zeX+A9PyqqTsTWMufONadE11+VN
Z0xwCBct6c4E+4z06ACH8NNLu264n/xD6vCaIujNvlW+8+Ks1HLmCP77c759
+6Gb0qvXIKbPdJ6pLf5bxrItbx/APfPxm347tSh1uplLz7mTR7viTeqQTrgf
7+m4lVYwcIciuTD60hIHRwLx6kG9wjj50lyRt+NO9YkW/BF3Xzsh1g4nqBux
dKf70GP7pW7H7US1TSfch/11tfXvuFaohphcfQjdH58JbHhulaJ6hHBqeWj2
RN5qRf734lP2Nyva8pOVfr2kB9ek1nQ/vCNFaTuc3WgJ+N449rhFjWs/u/DL
tQdaog9YFfn3PSYlzizLnbMq8us73BdXmjpak6rIn2/x+fWOrPH7bYr86ESL
+UjSN36b0nIHg7jYej3FfsGmNup8O9C5csy9LWjj/NrQ3OgK/Fph43wC6G/u
2rU7x8bxX8C7Nvddm69O5XglHv5rq+fzHquq1PGdx/R/mheg06KW63hasAXT
S7t9Keptff45XD01+sN9ycl8XjO6PBOOvP5VrN+Ex91BV05WEuudRvcT65+t
ciWoA/r7Biw8erL62ESc+kq//wUueDIyi9sWZaneP44VUxmb5Auz/FyGprxX
NrrfnZD/T0j47J8v2/cObOZ94H2Dv4fP6HsjQPpgLtD6vN8AO+l8UUvxwWMU
n6D3m6CK4he/U36wgfITFP85WEn5C/YH2B/B/gH7J9hfYH8F+w/sv+D6wBGq
j+D6AddPZFN9wUH1FeR/EG5T/UWQ+gO4P8QK6h/g/hHPUH8B95c4Rf0HCdR/
Yoz6E7g/Od5u4P4V3N/A/c3x98LT1P+C5wN4PjifEDxK8yN4vmCQ5ovz64MC
mj/B8wl7aD453zDw/Iohmm94j+ab8++Hu2n+xb3EB/ASHwTzA5gfBvMFmC8G
8weYPwbzCZhPBvMLmF8G8w2YbwbzD7YQ/wzmIzAfDZr3KPiIn8b7xFdYR3w1
XMRfqCT+Gr3EZ6ghPhvk92X4iPhtMN+B+W4w/4H5b/D9AHw/GHx/AN8fxn8n
uCQW
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQ9M1GUYx0/CYBRTvEPgcqQphm79EUikfq9P5IZE6w9OMO2W41JnsRZh
WUMra6EbGoi6lcrQJdfFdCw3Im3vy3PJMf50nocncF54ECOoyKCpVxSxuPd5
ejfGbu/v9/093+/7PJ93if2NDdujTCbT9tm/yH9aQ3i0Om8secwtbTWX7qTb
BrE8dqTt4Ktd8kJq5XjhhRAW359bskp5paVp/Y8VlhA6H30wZP/gqnxTxPWf
KbuBUYvuW7FveZ+87ImsAdzqMNvStgXlCi04gDddx7c99PSgjKilVv6AZ3cX
7izdNSxnxWYVgxi1JfTMGudPcm1ETgQxaAvLivxf5InjkXUdq2ecgwVbb8pw
ekQwgDv2JE8enJqUG3SBAcxYUpb4cOUtqctr6sequbfy0orCUsvF9ePQ4Zd6
Hy+dkjv06sOuGkdnTue0jLitudSLxb9m3xl8zKS03dRefDLY0hKzMkrt0Yav
4c8xbfY/1kYrkvPj2YlT2Q+U360y9fJj/10FT612xarDWvAqvrjGFONfdo/6
LWJ3vAcv+iZn6k/Eq3xtuAdTqzylp+Lnq4aI3BkfjtV95Dj3fIKi8/DhJ+uc
SwtrFijK34tFVvVnuMOs9ONll7FyoGTEcduidBzpHux7Nt+cOH+hGtZ5dmOt
yrvisiQpyq8Lv34i3hT9b5KivDrRA1XTWW3JivLpQE+tXNxekqIoj3bcDO+8
bvenKC1X4cbl4wXFVrNVZWi/bfj3y5ntexdZ2d93OHF0f17reAr7ceHb3WXr
Au+lcP2tuGAm65EvfMlcr0Tj05xjM8NJ6jNd30U8VD0xp6N5oYrV9XyD5SfP
/TNnfaLaq7/fjJm5o6v6Tpr5e+dxXmvdh9UtCazfhAeKfg8ty57Heo0YGgml
NZ2OU+/q9xuw/q/wc7Utc9VX+vl6tFtLdm85YFL79P4x/Nb2uTs6Lyzp98c4
3Xg7563XRuX/E2J5wWHP/f791bwPvG/w+yDpfcNF+rCT9AXtN0ADfV+cpvpg
mOoT9HwTVFH9YpL8QQL5E1R/M2SQf8H5AOcjOD/g/ATnC5yv4PyB8xd8PsDn
I/j8gM9PZNH5QpjOV1D+blhK5y/c1B+wifpD3Ev9A17qH7GR+guuUH+JOuo/
OE/9J4aoP+EI9SfX6wHuX8H9DdzfXL8XuP8FzwccovlgPz4YpfkRPF/A88X+
eoDnT/B8As8n+/VDgOZXBGi+wUnzzf6vAc+/WEx8AIP4IJgfwPwQzBfoJr4Y
zB9g/hjMJ2A+GcwvyCR+Gcw3eIX4ZjD/gPlnMB/hOvHRoHkPwtRmzU9jP/EV
viS+GiuJvzBG/DW8xGfYSHw2KO8bEEv8Npjv0Eh8N5j/sIn4b/D9ALvofjD4
/gC+P4z/AHPLJes=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYx4nsUsBfdCQediKmQRP/KEcbfT89hXNijKm3W790hc67rGYn
FdOhm4x1Oig6frQ8xOoc5xpM4cwb4Px+egDPpQEnx28PQbSMGmQli6K04j7P
42e73b77fL/P53m/n+d5fVbsdFhs0VFRUbbZX+Sf1hie3JxWsaI8oG93tf+R
uv06bvkntaMk/rLeYnZObG0ZxYmFL9lz3grqxoaNNwqNo+iK+ck159UePV/E
DNbuHUHry4b5LxgG9K7OyLqGizMkPJ4b1tNUwGvYnya2psN1PRLN7BzGZQ95
x1fvu6nPBpuNGMassNjwYtMt/blIOBFGn7U66Xvbz/qx6si6iutONl7M/+QX
fTo1EnAIS/N8ueNJv+sWleAQzsvY4d/jn9JVeg2DGCviTn9WNa2rcDGDuH/P
67ZXzs/odrUGENb/4PCuuadH1Lra+7HrirTWvB8llVxzP55v22X5+oNoeUAJ
7sOc6mjPn0fnSArXi+c21CZNhg3yabV68d0T/l5z5jxZrgL2YPaRhID5TKyc
jMidCGHZUHplfuYCma0Eh/DtUyXJl95cJL2RcLXdeKXekVfgXyypHt04dvbZ
spl/4yX5H8Q74QqbO8so1et7u/DL9L+sawsTpLIjtRMLxmqasjyPypvKz+/w
4LAl19y4RJJ/l3Fnxt1TtzyJkvy6hJNVI6ubHUsl+fMtTl3d7OlIMEny4yK2
/TpcWV1mkipcYQAfibqwZSZkkk8pvRcw+7320k2jJtbXhqU1h+5VNphYTyse
qLu7vB5MnP83uG2ZoT7XtZTz1bF5R3HP88cTpVvldw77zDmZefYlcq7Kpxmd
jUfcvtsJ8qA6349PDJzYbX/GyOedweSiqgU/rr/vTwMWLf8qRU9cxPHq0Fi8
qjFpX6zcr773YnHBf7setBukT73/BVbUOVOy5j8gi9T+p7jmI9tU59/TOj1/
iGtXHYt3J4/r9ydk5e7C1wZ9C1t4H3hf4++Bv9daKT64Kb6gfS+U0vnCQ/nB
Y5SfoPcbwEn5i99IH6SQPkH5+2El6RfsDxwmfwT7B+yfYH+B/RXsP7D/gusD
XB/B9YMSqp9YR/WFjVRfQf4HwEj1FwHqD2il/hBx1D9wh/pHWKm/gPtLHKf+
gzeo/8QY9Sccov7kfDuB+1dwf8Pn1N+cfxC4/wXPB9yg+WA93RCi+RE8X/AO
zRfrC8HHNH+C5xN4PllvLzhofsUQzTecpflm/X2wieZfJBMfoIn4IJgfECR+
COYLMF805g8wfzTmE8QRnzTmFzxM/NKYb8B805h/wPzTmI9wmvio0byHQSN+
aoeJr5BIfNWeJP5CB/FXCxKfYS7xWSO/R2Ab8VtjvkM58V1j/sNt4r/G9wNY
6H7Q+P4Avj+0/wHapRpy
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYxy8K+XEmInfI3c4DlJRjCzISanw/Prpix8oo0TbaqD9ql86t
xNzUSW5sQD9sdjJtISWyxE0nkDY0qO+HBxU6pLuLE5CfoiaagGxswjWxIu7z
PH02xm6f7/f9fd7vz/O8Psnv7SxwhRkMBtfCX+g/rVuYYDltixu9ohe5L8+m
Ft3Eub27Yi9u6NSb7RWTm5tHcb2pxT31sU83NTpv7zeNojNtxaXxzoC+S0T3
nyy+gas6js299m6f7vOG1ghGlJ9osB0c1B1KcAQ9c4N33O+M6iE1e8UwJs9k
GFfP3tYXxBYUh9C2eeQNY/JdfX1ITgxh4TMWW/Yv9/XqY6E1iB+99MO3Ud4H
ejA1JDiAEzFlB040TOsFqsABXFMQtASyH+qqvMZ+fLu8dV1RRFBXctH9+KS/
KSXT/kj/QK3r+EVZ19G8A3/rIbfuy314sbi2NmOZQSq79j7MPZVomooMkyXK
cC9eFSuKnclPSZLrwZj0/klf4SKZqVYPZufsW7eyPlIeVoLXcO2WqG0T8Ub5
IGR3MoA1e3aPeY48LfOU4QAu9pwxpi1ZKutCcie70fXb+MPKrbGSzqMbjTFr
C8erlknK34+b9pbUHLweJ9XjxT5Md5i/2RFpliqOVC/2VM/sSHPEyz9Unl3o
8myvfzZzuaT8ruKXR7Y4m5ISJOXViVnPucb+mkyQlI8HX0/PdWxyWyTl0YE/
+pMSNoZbpZLb346LLhxv+DXPKp9Xfq9g1faq1jffsrK/Szifs+qJudVW9tOG
a4b3JJ762cL1t2LuiOO8dYmF69Xxz5qb8ysX6qlS9bVg4s7wyurpeBmp6vkJ
u+pnD5WWmuUn6vtNeNaclf9vII6/dx6dd14s2XY/lvUb8ffvKw2uwzGsdwaH
v2rbfW0qWu5T79dhUZU9KyUYLs+p52swbOPjipRmgyxV+0exQz87k/J5UKff
5RjfErE0p+Ge/v+E5N87/spYhq2Z98FE+xq/D/y+1kb6EEX6gvbr4H36vqil
+uAu1Sfo+UbopfrFNPmDPPInqP4mOE3+BecDXspHcH7A+QnOFyYoX8H5A+cv
+HyAz0fw+cE/dH7iBTpf+JrOV1D+7RBO5y/aqT/gHPWHWEz9A69S/4it1F/A
/SW+o/6Dz6j/xC3qT+D+5Hq9wP0ruL+B+5vr90M+9b/g+QCeD/bTDTw/gucL
jDRf7C8APH+C5xMyaT7Zbw8Iml8xQPMNUTTf7L8XeP5FEvEBXiY+COYHXCB+
COYLHCK+aMwfmPcp/mjMJ2A+acwvcBC/NOYbMN805h98SPzTmI/AfNRo3ofA
TPzUPiW+gp34qqURf6Gd+Kv5ic/wuEzxWaO8b0Aa8VtjvgPzXWP+wwbiv8b3
Azyi+0Hj+wOW0/2h/QfLNw3A
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1lX9M1GUcxzEhhFiRHaBngRCtOzdjpaS15+mjjJQtxvRmazCI2aZghmj9
QeGv2iBp0kwjAlfaFKGUXcLOOLfv4wcRy+y4OA84QDgRGC4PjDYFE6Zxz+fT
szF2e77f9/fzfj+fz+tJfK/YtuWxkJCQLXN/wf+0hvDttYM7qvN/NXIPtd2z
5N7A1MSJOr/lD8MZXx7Y6PRj/Uj+3+NbOw2Tff3NUpMfLeHepoRfvMYuGek7
uXMQzx93nvUf9hkdruAawPI9b33fFTlgWLXgAB7Y39CQXDtkBNXiy69jTabP
PlE5YsyJzSn244c3vLlVf40ZbwTlZD8udxX2NLfcNo7WBlcfJr2/LnrXozvG
lCUo2IsVay4VJYz+Y9h0gb24siDzYVrlXUOXZ/fh4Ym0M6dLpw0tF+nDxneK
bPObHhhb9erB5OyfsydTHhpBt4faujE56fpzO2ZClLYb342O7Irp0Xnz1W5t
uAv31zdurrKGKZLzYv5LDtFTHK5W6OXFZ2u2GzGeCPWVFryGy58/90VbRpQa
D9oNePDL8OabGZ4nVYY27EGZt88d3hyt6oJyJzvxSnreJxdmn1Z0Hp0odh/c
9Fn6M4ryd2Oh5diS2jKT0o/v7MDxqJwj4y0xSsdhcWHhU9C7sC9WDes8r+KG
sJLWbcNxivL7HQ/MFN1KcS9SlNcVtFSMxZ6oXqwon9+wIytn85JXzYryuIyx
qY2rVjWYlZYrbcc090dH746a1Sva7yWMm03/oO+2mf1dxOqm6W7TOTP7aUXr
cOWJ42vMXP8FXB06ryT74GKu18CUO2PexKpFqkbXdx5PZ2WNBHLi1AJdTwu+
GwhLdQ3FqD36+w5c9/qs49GLJv5eE7bej80JrFjI+nYsfbn2TVNENOv9hKfu
jX29NOcJ9bF+vw5nXPlJ/szH1Vn9/DF0PbjmXP1viPpU71fhN6/Vb5j0Txn0
uwx7IrZ7F4TeMv6fkKKpP4tt65OdvA+8L/h94PdFK+lDD+lL2q+D0A79ffkD
1Qd2qk/S83bYS/XLSfIH7eRPUv0OWEv+JecDeZSP5PzgR8pPcr7A+UrOHzh/
yecDfD6Szw/4/ORKOl+IpfOVlH87AJ2/bKf+ABP1h4yi/oGr1D9yE/UXWKm/
5HfUf1BG/SeHqD9hI/Un1+uCAupfyf0N3N9cvxsKqP8lzwfwfLCfTrhM8yN5
vkDQfLE/D1TS/EmeT+D5ZL9eSKD5lb0038Dzzf67YB/Nv1xKfIBG4oNkfsAL
xA/JfAHmi2D+wBnij2A+wRHik2B+AfNLMN+A+SaYf5BA/BPMR1hGfBQ07/2w
jfgpPie+wrfEV7GM+AtlxF/hJj5DCfFZUN6DcJH4LZjvYCW+C+Y/nCL+C74f
gO8HwfcH2Oj+EP8BkAAtWA==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw90w0slGEcAPAjH+0m6XzbWhjlI1+jzW6PPV2haXGho9ZYzJlqaNFI1nG1
qEmE+SpirbpdcZ0Tl3h8HY67EjcxKnJddDcuhIpW3vc5/+3du2fP8//9n0+H
+NQItj6FQgn4/239yVhHCuU4w+MLH/gSsYb8pVZ0S/YLkEjEKip0FuTcMmgE
VZVb8RMJPfIdL8UJgFy2FSuI6xhylRX+EpDeCnIap3w9HinE3jKiWimMxElN
2FtCHGFUsmWJCHs/UNjdrqCp0WbsadGd03N2eQdbsKdFHOuJbk5NK85fQLvs
rqWZur8GxHCZBplRjykYo224nhrFRopG3pW3A4KvnEes0DDaQibC3hySs24X
m7V1Yk+F2NF+nnr9XdhTouyNmva/n7qxN4sml/cUGOj1Ym8G2X7/oPJyk2Bv
GnmnRDbWRfXh/ClU1O16+WJuP6ggxk+gh/4O1KLHAyCBqDeGYoxkh+3FUuBN
+KMoJvdQSFbLIPaG0W7z4vqG8iGcL0UdTQZqwwgZHt+DKkprn1Z9loEiol+M
Eups8pbocpBDtHnI/PcTF845OdCdMDvHaVMbJgePyH54z53pxjTWtcVQvi+g
d6RABvxJH9Z5tt4oVA7hfinczzfPWLYY0s0P+mU82whyHgR+5PzhyZvOPpZ7
pSCJXB+MqqW59OwYAA/I9UP6nNLmwHQfGCb3Bzb5X2GGtm7vH/TK2jQ9VdyL
x89AXx/uibjUHuzPQp4Zg81ndevOB579tlhWGNyF66kgO1ZSwjvaqTtfWC+B
lb+qO7A3DwfSzwOa7A321FBtLzIet27D89HAhcDAGO11MfYWYDCjL7qU0qq7
f/C+IjFeWP0KvCXvJ1S5Lsp3Mpt19xfOa9wj6bYinL8Ei2lc7sd1Ia63DE0M
JRb5mu33AS+YHFkbWxJgbwUmJ3nL06gC3fuC4frWej4JDdhbhWWa8HbH98+x
twZTGieDss/wsbcOR+npmU5/eOAf9ynG1g==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw903tIU1EYAHDJDMselpVFUU7TIqFcOo049omKNkVKI4mxMm3qMEvzAeYj
cmaFglqh5QuyLCsISyXQjKP4RynTRCnzvanbnJu6p3s4R3nvmR9cLodzvt93
noyEtJjETXZ2doH/v/U/HUZ8oof5V8aZRL5UGDDH+93DSfUUSqJiBasvusr4
l0Wopno99Jg3cyeecV6M+oXrocMqboYy9dwMoj0dHq/nd7SxZ4mnxaFbhrWZ
t+eIp8FveX25vk0S4qlxprsnp8goJZ4KJ8fUM9QJ88RTYQ+pU5hZJif5S/gS
NzbD9ESBqOFCJeYavz7dEb5I6inw/szkCJP7MqL4ajl+MVI5ml+mIt48jpw9
9oVdoyaeFI+ZXEZOtmmIN4fN8saGvjEt8WYxL8hS77xdTzwxPjM+F28JXSGe
CLfwirKLCw0kfwJXfvZ0fdxpRC+p8aP4Desms2vZhHhUvT+4XFAZrXJZRT6U
P4yjpi1DBxgW4g1iccnVbZKdayS/F3P6jPas32tkfA8WLLNqv6daUQXV346r
nodI3v+yogdU+wNeusI/dcRsRbYTFgqiAmoXrOgV3Q9ejNFvzq9t7XbIibsg
xx5WdJb2ISU4rkSctUb6e8Ep+tqt43Ub84P+T6Y274ZV5EfPH7Kv1/iLS82I
T68PygrUJheeCdXR6wdJlzBiM9OIBun9gUcc408308b+wWluLGO6W0/Gi+F+
ekNic7mO+LMgLb6htU/S2s4Hhg5pYpLDNaSeFHIdxxxrWGrb+cKzgcDCVqaK
eHKoOiwMKM5ZIp4C9h1lR4x8VJL5KCE3K83NwbxAvCXoDGraFZwot90/6HZs
HEhXyNAAfT+hqm9hGUqltvsLYWUtIgiRkHwNsDr88rS750g9LWzVevlM6Dfe
BzjESZsFi2Li6eBgSuRYvmHjfUF+v6L67h4R8VZAlvcjzj93ingGKOja21qh
nCCeEVxT2aHt98bRP/y65oI=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw9k3tI01EUxzed84Gba+mczrRlltgfOXQW9btenVpa5B8m/lFKKWbZP1Zm
SXMi9hBLRNDRTHuRWAtKnM3wgVfb8lHTHKLhA8tcko9kuaXTtKW/3/31hR8/
Lueczzn3nnPEGTlJ5xwYDAbY/Lb+lGyo/fq9EtHgGhFGagVd2qVSR8esE1mk
llEVU1LaatwgHlRv6Tdyeliz96PCTvQbtmRFGiYhMNeR2E1ZUcNT03hcLRNQ
PAuKk3dfi6p3ABRvCQ3ojJIjekdA8X6hwrB3+/UrLEDxzCi3Y3d3kIyNeWY0
aDfIeuuccfwiCkpTBs7tdAWku2EB+XvcfV711g3nm0c2jqCiMNsdkPjqWZTT
IF6dieBi3g/kfPt8e5MHD/NmUOKxgVeTvG2YZ0JjUaPy9zv4mDeNTJfTzaXh
2zFvCjU6adUFSZ6Y9xXd8LVq7LleOH4CsQzm4twqAVCR/qOollE5LH3tDTLJ
fCMo2KCIb20VglCSP4TK4wISdBofzBtEN3uknI5yXxzfh3jZUhs4KsL+OnSy
OtmtbFgEKkh7C8puU6wdCPcDReRZjU7kHxYpz/gBusOnpRF/uSl+4Allh5Kz
RkO8kD63wJFDPBlLLQIHKT7MtBdYRtxF2N4HKxVpL9oSfOn6YElf+1RFlg8I
p+qHH6bbXiovCsEF6n5QVuMdYEn1BrXU/eGb/s7O1FgBGKTeB6qFMU2GPV70
+8Hv7DSY6uqJ/afgesdshtTMx/xpuO/nBEc1+b8/0HTKtrYwwsP5ZmCxTG7p
1HrQ/YVjIiOf+ZmDebMwRx9h1PLdMW8eNuclf5Nku+F6FqBGExgcOuaCeYuw
i+PK3sh0pucPcstcA1QubDBAzSdM7W30/6Rj0fMLtSHiK0lKRxy/BI+L78zr
5Q44nwV29T+L7slj0vsBE2/VxDKKGZhnhVGPNKy4SDu9XzBkqHjuy/0NguIt
w5Tm5Kv53HWC4q3ASIE8ffzxGoH3F7YXmev/JKwS/wAFOLTZ
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1k20sm1EUx5uNZskiQ18wolWCkTZtCY25uRML6bZ4HbJo2MykYVML9oHK
iMU+LMSIhW4zi+lSIojaCNsli21Ml84ES7zrpLST0qraO89zn39yc3Nzzvmd
c+851y9HkXLjGI1GA4fraCflQDXmVI/2AjcQRmgfLU2WO8XJ3EEeITuq4Bnn
mrMYQNVypD2UK1cqGSVMoJs6kg0tCBqex7eyAMmzodrusOvLS2zMs6JlpqJS
FemJebvocrbukbTTC/N2kIkZoX0v8cY8C+JXN+VuGXwwz4L6fF2Eyl5fHL+N
YptU6roELiDcp8woeSzBlZ3uh/OZUMykpCZRwQMEvmUTabuMDfkqf8wzovAd
4zJ/LgDzNtAWXRc7ExCIeQZUljLYbagKwrx1lNxT8YJuDsa8VeQ4LtbMZodg
3gpSW8zTaD4Uxy+gfpYLfy2JD5oJ/29IIQs6e2pMAHKJfLOIc7CTXuwqBEKC
/xWtRN1are0XYp4e5cVfabSeF+H4CXQQljagRyLs/w7xOOfACEcM6gn7EPKw
Z80yr4lBJXHWoLelieqUKjGgOrzWHMWMuSsGbaQd6rbG5z0yqfMQpGd8qi5i
i4GE5MM+R9Izb60I2yfgb3m8aDFSRNUHRzsTdk+rhSCcrB8aL37g3D8uBHLy
frDvhPOldo0APCHvD6skvBldNB/oyfeBhgcdjys/hlLvB9Xl8s661BDsvwoX
nQS3G9eDMX8d5r8p8bArg6j+wO+v6w7+8QJxvg141Xqm5+9hP3F/YUvuyeiC
p/6Ytwk19JxBtxIe5plgK3c4O0Lmh+sxwxHxVvKrNC7mbcNxffHLuFFfav4g
y2BkDOz5gM/kfEKu9AuHf8Gbml8YV6T49XPYC8fvwkGpiZ4h9cT5rPBH73Zx
qYVN/Q+o6q0ofdjDwjwbzCy847DdY1L/Cy5ZdrR/ChmYZ4d2uSCGe9Md8/Zh
fdt012aZG+Y5oKxjw5mmcgX/AQOdt3I=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtIU1EYAODVICMxKxdYbcKm0+mmbs75Pp65kaiJhJKBkaGULc1aaZih
0xKpBHVY4KOREkiIZFJUao9frCTfkikWlan5nKjTbT5KLe8994fL5XDO//3n
yU++HHtuJ4vFQv+/7T8dq+CdIPhskyRAcipWoHGvRBqZ6IxSqLDChqfF5HTJ
BVVVbocF2O3x4FAmRD3d22GGXH3plZ4uV0R7Ztit/wK2PBHxlkHyQ6atve1O
vCXI8x7IK7ATE88ER09NlVQ2Soi3COWzfxu+XfUi3iLk6FStHLGU5M/Dobxb
Er6XDFHDu+fg50bhVozah9QzwhofNwnT5IjiK2dAHy4yjNT6Em8aWu2fVxxb
VhBvEoypWu+6WH/i/QbukbpVXVsA8cYhOpablq4MIt4oFBo0ih0dwcT7BQG5
7gVFJxHJ/w5N7JRPrMlQVEGN/wp9G/YxOj8lOkvVG4ITBRGr0yYlklL+AAwf
fNV+oSaMeP0gLzZyx0JUJL8DZEUZssA2FRn/HqKTWpuaxGqkp/qbIY49lZ9+
TY3yqXYdTNj05+gMasSc8MMXZ7zTq9Wohu7HLaYIk0LHtJvxuuPjfdFBahRA
+/ij0FCbMaQi/R3YA9iDefEqZn44mONxcetdGPKl549Z2SLOOCcMaej14eHj
oiG300pkoNePjaXKXbxAjPrp/cF3Mh0edTYgZv/wy9ADo52CEDJ+FPdu/qkK
fxBE/HFsHZtWcnmBzPngPmE4z1LvT+pNYrs9TkpNlB9zvnhSKJ13Xvcl3gzu
er3m6/hGTjwjvj6YyqnW+5D5zOEPyXH+NVky4s3jCa0i4alWytw/rFGElkRZ
vVAvfT9xst/A3fMST+b+4iTLM4/Zm2KSv4TLy26kLJjdSb1lHJjtullcIGLe
B25vWDeNid2IZ8ZT97MEh+eEzPvCC81cdmabC/GsWPv2nmPkE2firWDzSOOg
bb2AeKt4Zn9iVGQLH/0DN4+x4Q==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1030s1GEcAPBLiq2slMg/NRNrS3Pcdc7L40F36LzdXWe9rFOLO6+hhGtk
8kemzCS9UEkb5hoWop3Ks3bKDl3kpRmp63RObrdzDldo5fd7ft/tt9+ePc/3
831e3S5mCSU2NBoN/P82/2RYUdlNmshbRAcMIlZRb5mwoZbpA6RErKAx3uiR
qx6+oLZmM5YRZyxNvv8wA3wc2gwLalD/ttkATEB6FmSnf+PVmnIMe0vo7SFX
lUrOwp4Z+Thbt9tuZWNvEaky6O4uef7YM6FT8UcHem0DsWdC78CldPmLIJxv
RN9uqBMlBcGAGD5kQNvKGTPujBBcbwHZPS2p8vAPBQRfM48s/AajOS4Me3pk
mJ1TpuUfx54OxbvouaY2DvZmUaFGbQxf5mJPi2aqOq1pkRHY06A9lU5eqY2R
2PuObOu7SgLseTh/GnWxgMPz9CjwkBg/iQLUBwNjVNEgiag3gc5tnJc+cI0F
dMIfRYqyXQW7RXHYG0ZFi0nFk358nK9CSBvf/6qdj8cr0eUteZOSvQJQSfQr
UPKfXwLuGQEoJtpy5K4bqGsoFgDqhDNVfOlaqQDUk/1w7lFW9c4sqq2Ask9X
KudZAsAmfWg3INFOaPi4XwXXlSyDcw6fmh8MvjZlz/0aB5jk/KGuW9rc0R4L
Usj1wbBbhbeTM2LAY3L9UO7Z4vh3XzQYJvcHWlsV9wXdPGr/YHlHrMlfdAKP
18CgPtnd1OUI7GvhsJNCmVIXTp0PPJm24tYk5OJ6OuhwB36oduJQ5wuXxOMH
Rn6GYW8eRpeqMyP6Q7G3ANmNn3NPK0LwfAyw27mzwJIPsWeEXqrWqOYngLp/
cOy6kdbyIxCoyfsJV8UMz3vcAOr+QrFL+PpgHxvnm6E8O1H8LMEP11uCGzU8
c4Iji3ofsIY/NS2cYmLPAkd6ZONfehjU+4IVRe8rzrb5Ym8FNpW07BC/9MHe
KuRcyM2WDdKxZ4X6tdyc17Pe4B+tHb+E
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAPChExOfhY/SyoToD7WXSml6duZ8v3Ju18duPnLM0JQKA4eE
o4fC0iyVyCelqaHYQ1OXj/KUKSpMHZpLKaJhmMslU5dO0CzvPfeDy+Vwzvf7
ztNNfFWQYcJiscD/b/dPhxGVymWZ34Z8gTcVG8ivwDo7e/85cImKdVRVvrVv
pNAf1FTvxh+kCHuUvGMJwLhyNwzIi7z1KbSdA2jPgOTvGwo3/bjYW0M5qu57
bz0DsbeKHCpOznSe5mFvBWmt2R0nIoOwp0cR9kPpBdJg7OlRch7H/GdfCM5f
RhbHTVCtQxighit1iCXQsp/Kw3G9JeT2OIAYsI8EFF+tRSV/D9oRfVHYW0RT
IoWOkx+DvQU0WWxZ0sSPxd4PdGDRPjvtCR978+hXtV7Or4/DngYVIMXgdosA
e9/RSsOyc65CiPO/orIwwZZ6iABV1Pg5ZNN0W50zGQ8kVD01Ch0+S1SqEsAp
yp9GtsE3bEwHE7GnQh12L70X65Jw/hjqf1HMzSJFePxHtOdYCjA3iEAZ1d+L
+ltgvKuEBDepdisaPkyq05+RgDlhpVHo5NVDgnq6HzY9vN6oqWLavZB4LpQP
RJDAl/ahsKaItzYuwv1j0FyfKgTuImZ+sG213aVIkgR86PlDK+lOWsadRJBJ
rw++mUlxfF2aAOro9cPWSEmuVXE8UNH7A6XOcsv7MoLZP3ih4nPXg2tCPF4D
P2T+biiRCLA/D9/t3VQ7psYx5wNbPVVmujQ+rrcA1RNOpOnseeZ8YWWm2CXa
PAZ7WqiMm6/0i43C3hKsOTQymtcegeejg6zRi+VmHuHYW4bbj2TdlwdCmfsH
2Tx3n6msEDBB309o26i54ukZzNxf+MqCtxTMDsL5q9Ch70zztD4Q11uDX2bF
2rt6LvM+IDd/stbFhIs9A1yW9YhLwjnM+4Kd3FR2c1sA9tbhkegFo6+HP/Y2
IDHHC3Ud9sOeEXatHyUJqS/4B+MftZo=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtIU1EYAODVfCCF5oRqWEJZqSESTEzTw9l0jvloTV1u6HKb+SgstDJT
KlwZNleIlsWmIRoamBarLDSzA/YQm5qmbYqPtrTZ0nxNnQhKee+5P1wuh3P+
7z/PfanZ8elbaTQa+P9t/slYRfeGjZzsS2zAIsKOljVzV7NEHJBBxAoaKuRf
6I0MB5XazVhGzKIsoY0fAXq6N2MJ2Xg1OcdlXEB6S2js87goUx2JPRvy8bDl
mvQ87C0iT9dtkrMH+dhbQK+bdFntmijszaOLmopRrU8M9uZRSX3zXd1ALM6f
Rbog8a6H1QJADO+eQWHF+YZBrhDXm0ZN0t53a9FxgOC1VuQ7J/Glp8Zj7zey
GJr1oyUJ2LMg9zYHJa1DhL1JxHQ+JhO4JGJvAvlZhSemTomxZ0ZlNM9cx3YJ
9kwowfSg0rg/CeePokHVG2W6OhloiPHDaKifpbz1VwrSiHoGJGAsbExyU8AR
wh9ApSEPJWyVDHt9yGlV7ZQoluP8LsSBYwaVUY7Hf0CMXyFrCrYClBH9rWhS
GXrIvVQBlES7AZXXGa9VtSsAdcJPRzXivT0KUEP2Q2bteuVyG9VuhabDdZcH
1QoQTPrw3BdpbmMo1d8FNT88vW/0y6n5Qcuz7rwAoRwEkvOH37nvy73yZeAM
uT740cJwV7BSwCNy/dAhkOGyfUQK+sj9gT6P571TriRT+wev33+eU+WWhMeb
ITeM52xukGB/Aj5BOvvuGDF1PnCoOuyFk/0krmeBX7ui807rRNT5wowRpZRe
kIA9K/T6aXZcj4vH3jS06qfc+0Lj8HxmoKrfZL4dJMTeLNQUbni8KhJQ9w/6
u/KiCt7Ggl7yfkKlU+adDbcY6v7Cxvpxv8abUTh/EfaU1Wbqd/BxPRt0bKnw
r23hUe8DHqAHf8vJj8TeEtzZ+YmpFnCp9wU96NoAQUgE9lbgyz0d51lHw7Fn
h8Fq/+JOHgd7q3DLH12aLoMN/gFUGrrQ
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw103tIU1EYAPCZFKI5fBRCpGaFmkoE6nLB8Rimk6lTt6lszaZuC0UtIyvJ
UNO29ZI0JMwici3M9RD1D9HIoxaC4WNqCdYs13Q6N225TZeFlPee+8Hlcjjn
+33nGZR/nivbQaPRwP9v+0+GEzFcIvaML8eDSCI2EO/CVlPz5ilwloh1dO2Q
e2lYQCJofrgdDvTB8HslMJsFRke2w46+TnGEzNYkQHp2pN6pQelebOzZUEqc
MUHQmIy9NaRoyLwjjE7F3i/0MqQwpdDBwZ4V1fjyYzlF6dizIn4aS19ZkoHz
V9FCuMr9RA0XEMNHLCjqoquSp+HhemYUXDbdUWzkA4J/aEKLXKdSx8jC3hIK
5YfaGx5lY8+IVLkqH6uvAHvzqEXhP6J+IsSeAbkN2SIqmCLs6VGjcoMboc/B
3hzidYe9jmwQ43wdsnwv6JxuyQVNxPgZFCS+P/OsPA9IiXrTaEHRX/4iKR8c
I/wpFDh7rs+xW4I9LSpKcKoZ/RKcP4w4JxU3HCIpHv8emffdE9hmpaCe6O9B
h99w7t6MlYFqot2GxFKzzbVCBqgTbg+u7vtTLwNPyX44X1wTJK+i2j1wa+/P
b2yWDMSQPtSM6fZXLUtx/zBsmbsdoimWUvOD3rfitKJJCYgi5w9TSh4kThyQ
gAJyfVD0ilOqzMkHj8n1Q42wi2GqywNacn9gQF7jcVp3LrV/cEUy0V7bK8bj
9fDzD5l83u0M9g2QvXDayRCLqPOB8Zf9WkMGhbieEQ4MjdL9owXU+cLgdz7L
kt5s7Jlg3aRMKOZlYc8MN3RMbTctE8/HApca9Wr5IA97q1CaJV+81MSl7h8U
MTfXlq5ngDHyfsKB55/oHpXp1P2Fi3SPK+N+aTh/DU56981Z+am4ng1avJRH
xR3J1PuAaQfHdrmEs7Fnh2+/ePp8REnU+4L8spjawRIW9tbhEa5J5xGZiL0N
SFcx2wyeCdhzQtvVrk7133jwD/hhwAw=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAHCb0UTRKB8Ds3SYupaS5XxknI6s1CmbbqYzc07d3FwWaIkP
ikQIC6WyyD8ySqUIy0LBAvPV+UMtX9NB4Gsqzpkps6nb0umolfee+8Hlcjjn
+33nyZQVpihoDg4O4P+39yfDiiLGWv5emIkDYURso0eMr76lh3hAScQWmqYz
2dHZCeB5/V78RjyXxvaCgUSgHt0LC1LYqo20OD4gPQvqLW1MOKoXYM+MrtkU
oo2GZOyZEDe16sNSrxB7m2jSJ4pO+yLC3gYadB92tGtSsLeBMiLFD2jWSzjf
iKS7n6t8OWmAGD66hibcrtZevCfG9QzIaeT1aOB6OiD4+lVE52QtBhZmYG8F
tR32rjx1IBN7yyhEvhzy8KMEe0voOIupQSVS7OlRrTe9yz8gB3s61FMcNNLh
lYu9BZRULXQ/6CrD+bOo1HncOLFfDp4R46eRerxsyLgjB3lEvQmkVp5vL/yZ
B0IJ/ztyztbMDn5TYE+DXFLLxJY6Jc4fQl4WwVYfLx+P70NeDNk57lw+eEz0
d6Klpi7hMYEKVBLtd6hi3uTEqFMB6oTvxkr46W0q0ET2w+DbTpUdL6l2JxQF
FdXMZKtAFOlDdudaL9Oaj/uHYETz+pPygnxqflAQU0SzdysBh5w/3OxOvt9g
UgAVuT5YHl5R8sxDAV6Q64fap1qhDysPaMj9ge2e7xM2z8ip/YMcN6Pb2WgZ
Hq+Didq3v/jcXOzroe3mp9PtSTnU+cBFjrc5pl+K6y3D1skxP9YfCXW+UHrk
zZQ6MRN7qzCM6es/1ZqBPQO07xsc9mBfxvNZgy27otiWHjH2jJB5QubOVaZR
9w/eaTa4BgemgjHyfsIFFUN/y5ZC3V84tzJf7P1DhPNNMGDA07ygE+J6Zvhq
hy2J1CVT7wPSXWbbQv2SsGeBfdorJ9Mr+NT7gjl2zVTBTiL2tqC/YIXFq03A
3jZkNPSHGwAPe1ZYk3U9/oZjPPgHpSy3sQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAPBhLHpYJIKaqTW1hhlqWSbI2SFKyOfmmlt76Db30s0HqNNK
k0pTCg0fJZsU9oc5rFVqqYzEIwz/0HyloAmZiuZrIj7mM5Hy3nM/uFwO53y/
7zwZSRlclQONRgP/v4M/Gdvo1USCfLU0AgQTsYWgUvP5zHwkUBOxiYweqpwE
STSoMR7EBjp1c5thtcWAvt6DsKPgs1Ev8w1sQHp2lLEpb01r5mBvHXXt77SZ
GuKwt4bGcr9dDvrCxd4qol8/cYM7eAd7KyjX/jxM6BCPvRWk9vTvKY7k4/xl
ZK6KTqS/FwBieO8SUsirfEYYQlzPhhzaWgotzSJA8MYFJHtGEzslSLA3j8oF
soD2c4nYm0XawDe+C3tS7M0ggz7VtLYlw940euF+np75V469KbTeyTg0fViB
vUlU3xorzHRV4vxfyFz6m6n3UwEDMX4MuafXFslC1UBJ1BtBju92OEMsDQgi
/GGU4ZNa1xiSjL1BNK7XByhOp+D8bjTsUlhwYTIFj7ciw+3F8uwiLSgn+i0o
PO8j7z5NBx4R7QZU2S/nF7N1gDphnouSnZuuA2/Jfij1qGDviqm2BR7JMoY3
uelAKOnDvMqnAqZJi/u74TENktcc11Lzg/m+D3S1USngKjl/+KdL+eFTWjJI
JtcH6SLWFdM9DXhNrh/yHVdiRFlqMEjuD2z3g1H+ShW1f7Deuc/Sw1Hi8VNw
RjXw8iRLgf1pKFvnBs4EJlHnA285Mi/y/eS43iwUe0s3ai/JqPOFrm5zQxU5
idhbgK1SXl6RWYI9G7TGdjof3RPh+SzBEsFARbxKiL1lKCnzrXOeF1D3Dz50
V9tKCvmgn7yfsIw519IUEk/dX9jg9HhHQePh/DXYuPuz4O4EF9dbh/uuw2Gs
oTjqfcCp4urv1lEO9uxw9smUGYyzqfcFM8cWQrz9Y7G3CTuys8Sj1dHY24Ke
Pte+MryisLcNvYJ/eC92RIB/Va2zvQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw103tIU1EYAHB7aSEoJZZQSvbYsigTH2hyPEaRQlvTbfkWdc05dY/y2cM/
Fkose2gFuYWhMTFXiQb+kal90VAzbU3LSs10apZNzcd0owjLe8/94HI5nPP9
vvP0Fin56WsdHBzQ/2/1T4cd7ms4dYjDQf5U2KByQB/d1s1FEiqW4UXo4LMP
Eh66p12NJQj89rp7pCwKve1ZDSsMsSL1yqJoRHtW6LMHZCRd5BNvEep3trrb
SwXEWwA/fnJ/dYOQePPgVDeY3jJ1mnhzIGkJRo+PxBJvDjbV38zt1MWR/Fnw
+TT/9CQrAVHDe6ah1qkl5LghkdSzQJVlm0vepWRE8dopyPU9EB/ASyHeDyhq
9PBjVaUSbxK8ndVLo7o04k2Am/pCTG+TiHjjEHOupFhsOkM8M8TnP/nJs4qJ
Nwp/YnUj+Z4Skv8FlDwfWW9EBtJQ4wegROhoVCikSEzV+wgDQVJdwbVMdJjy
30O1azM7WpNFPBPYfbivJm5kk/wu8BS0nv8llpHxBtg1MbG9YKsclVP9zXBd
JYzClXKkotp66D3b4c2dlyPmhM2OQ+oTWxSomu7HseEdMYa/ctJuxjOHAleU
TXIUTPvYS3yMuy6E6e/COVe+WzeUy5j54YbFBzU5kI0C6PnjvkxWYagxC0np
9WHeXJO23ZCJKun148vslAjZQyky0fuDN2v0Jg9VBrN/uLNwfY1NICHjzdhf
a97L2ZdO/HGcN3wqPHWNmDkfPHBwd+PVMRGpN4lb9HP7w4xpzPlidU/pb9+O
VOJN4TtvkkaH7qYQz4KHp9O9HNuSyXymcc0eZSJ7JZF4s9iNvfHlTFICc/9w
+HTfrYr+OGSk7yd2HWW9c5fGMvcXP4egErZbDMlfwCUBZZ8V/UJSbxEbvSPH
VPUC5n1gS+0imtfyiWfF6rDb3ARtNPO+sFjT/lX0KIp4y9jm7FJfXMEjng1X
Nh41qOxc4tnx8rB2R0E+B/0DEoTEWg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtIU1EYAOA1JEiJNJgaiiU+8pHOUCGo0zEhCiZzDzUfS93m3FzqlkxS
C9TMUpDQJpGvKENLqAwzS6T+8oGJ5gRLtAc4H6v5WE7nlDAt7z33h8vlcM7/
/efpLdOIFGwWi4X+f7t/OjbBIoo0p8XEonAqNqDXr2JZXyhAmVTYwbQwXuMq
EaL6ut1YBziVV7rMF6FPI7thg6YBR7ZMLEa0ZwNLWFSdQR1HvDVwLrtY8PBu
PPFWIdjgJ+RPJhDPCrjYw0V0PJF4K9AQBDO+j5KItwKB8/rOUG4KybdAyE25
smtCgqjhI0vQMe30fLg+ldRbBE5mpJBzOh1RfJ0Zxoe1nCokJd4vKDvpwGvg
yYhngg73wfA2pZx4c6Db+u1fW51BvFlovs1P1vcriGeEbt6tLrc9SuJNg3E7
OeRFtIrkfwfP5SiR/UYWukeNn4LCPJedil41yqDqTUCrq8rPY/0SCqP8cSj3
iXRp5OQQbwyavBdtVz1zSf4QbMfIWpzYGjK+D1SNdXrrOw2qpvq7IbDc/W2c
vxaVUO02yAtXVLHEWsSc8P3piZ4Pci16QPfjK1uV72cuMO1urJN7TfdztegE
7WP7aK3q1ZSG9A/hnZijElcfDTM/rC41FLGic1EEPX/c7vjSPIpykIpeH/6c
Whyf7JWNGun1Y6nDk2/5i2o0Ru8P1lheHyh9msXsH463GvrdVCoy3oj5wDMZ
fZTEn8X15vaikjkFcz64sqXzY82zDFLPhPcnxhYPlMqZ88VBwp3QPzIZ8cz4
iNDQmiqSEm8R57MDBXpBOpnPEj72V+B/pyeVeBZcHzD4882ahLl/eF+zdWry
fAoape8nvmafD/zancTcX9zFzfmSfTaR5K/ic+nVtYcXEki9NfxY0Rp0uTWe
eR84gL836EdBHPFsmOcgOzSfJmbeFy7r4w66JouIZ8e+YqnOOVNIvA2sOxOc
VnZdQLxNXHmwJEItiUX/AMakuds=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1k21Ik1EUx1cQZehE+5Kl2NIvEliaSRZ3t1wYMxI2N5dDnZO95HSbQ9JE
Ez+ExijmTK1l5KKCUpbVB2Voncq3VjatMJOVaBNLHWZuzhdspM9znz9cLpdz
zu+ce8+5nAK9ULmdxWKhzbW101qFy86J5AqhAB2ltAIxEWsRVSeFSEXJDyaT
oyXoWCa6Y9nSMiSdq9DqT4nQx6Et+aBbWlcQKhMjmucDp67HmtuQRXheeFZp
r/jhkhDeEkwWh1ZFomzC+wtxVnZ8e5eU8Bahb/Bpf/j5HMJbBIk0NGwwkEvi
F6Azfe3RHqcMUe5DHpjrN9m2TeSTfPPQWMOus07LEYW3zMKr50rd6noB4f2G
tpu8ttcHFIQ3A7HV+xUnxErCm4YQeVhI+C0V4bnhbGmWlzutJrwpiJbYze6U
QsKbhPoYlTqxUUPivwOnJ1KTs1CEblP+46AsROGmVC1SUPm+QqrvUtQuow4d
ofhfoPXKnI/3Uk94IzB2QayN1ZSQeAcEvLOKWncJ8e+FgeVg40qaAdVTdjv8
u27mRpkNqIY6PwFzb1qQAAyI6fDe0jPq0WEDstJ2fKPN4Vl/w5ztOLsqLzqh
2YCO03xs6OvNY2Uwdgd+vP7hkWe+hKkPV4wke3mlJSiJrh+XjU7f6xnWo4v0
/bCprEXZ0aJDd+n743dydppFqEUj9Pvgz7XB/tMbRcz74abdlUHtrRriP4WV
ru5OV2oh4buxLE7U9X5OzfQHF4Y90Oa3qEi+GcwvqokzSpRMf3H6nwabhKMg
vFnc1LjGj9rsP82bx8L7G+rmn3JSjwfvg5TxHa58wlvAbFXw5MMBGTN/2BYQ
mbj+XOSk5xPHu8v1wMth5hcXN30zOm1SEr+Ey2UpBz2J2SSfF7vGqi1XP0mY
/4FfhIuuBeqyCM+HuR0Jv/pEYuZ/YX6K8nBGsojw/Fg6lMrhHMokvBXscAve
jiUICW8Vm22OnRy+AP0HlQzCVw==
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1k3lI1EEUx9ey8si0FtMUK/UPa8uU1otsenjQQeCCP491xWN1XUXNdVdK
StFUMFDBI480zSPMI8uoKNRsMu0wTDTtkMpbad3Fcz2SsvT3m98XhmF4733e
m3lvLMNk3hHbOBwO2lxbO6M1bGBgZxhlTSE+rVVc3bC/Kd3aB0lpreCyAP5s
taMvKivd0jLOUB6e4QX6oY89W9Lgw57cxeIif8TwNHjaJMNTPi0kvCWs+vrH
hRKICG8Rn+44KRvuDyS8BTzS/jzyqSyI8Obx+oXC3mheCOHN4wVpQF97WiiJ
n8XdcrAwTREj2r1HjV2VPTadWWEknwqrixUzO+vDEY0vVWIT0905I58lhPcL
G98IFU5ypYQ3jR3seKM8cSThTeJmlbmZzYsowpvAG48aIcsqmvDGsE1Rspt1
fgzhjWKjKeFq1/ZLJP4Hfnw3X+J8OQ7dov2HsCTH7vipERmS0Pm+YK/agr2C
inhkT/MHsFP5pG07yAmvD1+bo9QvP8lJfDeWOSULbL0VxL8TB7tp6Vu2KlAe
bW/BHblasfxdCeg6fW7A1JPzLm1OCYjtcJq9jsW/swmoirHDvY5BmdCZPbeA
2CM30V0nAbkwfMjgtm5QbQpi7wZNpPS7FaVg64Pe4WMPuANy5MDUD7/rjPXM
N+uPYu4Hc9qiN4m341E5c3/QVta9//lNhvqY9wHdQ0MVlrFx7PuBY/+5pANr
scR/DKae3Sw6khFD+BNQw00vK98XzfYHOPe77zQ1RpF80wBeSYIsr0i2v2BU
m5qSwpESnhLWsyvt9F9LCE8FhnxR557CcFKPGt7lfaCmroQR3iykXPUozIwW
s/MHfxN75ZVxoaiXmU/QLKjrvHaEsPML5vXuqeMXg0j8IpTULtcomgNJviU4
KjDjB58Qsf8DXCi9rvW3QsLTQGzVwqvKRH/2f0FBhCj94Rk/wluB8fClwRIz
X8JbBYMs1+wRXR/CWwNeembxQX0K/Qe6MLe5
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxFlQtQ1FUUxpF05LHkJDAJGIITRQshIZWayzFTqGZIXALMYAIcFFRiIXku
FikQMig5URMESPGaxmRESRB1D49lAWNBWHA3HkLEDCQMGAqaSMS59zrdmZ2d
nf/d8z/nu9/3u47hMfIIYyMjo4jlD33zNYJmiqyigfBpVXBu05xz8DAenPrU
4JRthHX2GZN76+7gyOOasWdXmaNVlc8fKVZ3sHRgZlB+zhJjZWb6UsUQwqOm
596us0VtB61BxLPbvOwTHPEVVnAQa+2OLlm7vYRUzT5jABcfDX8S+q0LLhdb
rtiPfW3JhZJhd/SicrJ+LHCVy1JCPLEgn9bvuL6nqCx9zxacd6aCBnxY6lDS
rtqOctagAbfnuBw/3L8DWXtVelT/+4VGWfQOsnJmeiz7KHpJcsEbD7J1G/3i
XA27Ld5Hmja3qQ9XTg3sHG/0RTaufR9O5NbbrBv3QyUbuBcdiwOGQm39kZfT
4URYY2ajMgA3s6VDt5rNFs3m+/BrVrAHJ1b9fT7h5n6conEnu/GBZE1DVG0I
vssG7sZReYVSGxmKZVSu9BZOL5zOqzMPR34et9CQ5v/8/uYDQv9OjG27/syu
MxHItiu02GwT5PPr4UPI5HDuQO+6dU/yA6NwlOl5E/ddK9hwes8RoV87ts4F
dg3Io4VebXjZN8ciOyRG6NOKkUvF6a5XFEKPFmxfeCt6/EYssnIpaqw+Fafd
oI5DDzZvM0rkFkOTms/EfI04czf9kr/6mJinAc/oTkQG1ceL/lXo4ZJQMFeR
IPq9jq8qXrfzyErE71l/V3HxL0nr+uAkNGH91OKm+pq9BodkTGXvr8FT6an3
SnqTxfuq8VxUWmNPfIqoX4Wh793tnjFWino/45LOorI8RYlJ7P9lWL8y071n
QIkX2f5iPFHhK8lySsU09jwPwxZXm64Nevo7Hcfm4fZcTCo+TcgPRlvZb/Ec
/Gzum/y/Pw/su6WsXgOvD4lbAtj7+PMyMJh2VVA/Jbw/yE4uYv3y/VVwJMeJ
zXOPzwfB31iyeXn/NVB8Ucb0EPrAtOYrDekl9IMVb/5kS3oKfWFsrDef9Bb6
Q3Ou7hCdhzgfmG1orabzEucHRWE7B+k8Pfn5Qu1CfgedN9dfDZ3GgUfJD2ru
DxjXnz9JfpFw/8AFtxxz8tOH3F9QUinTkt8Kuf9AOhv5AvlxhPsTDmzr+of8
KvwLH6vmd5Gfhb9hNN57Bfld+B800jYryoPIB9j+OH2W8iLyA6OP7ydRnkS+
4JfPM+spbyJ/kHTDu4LyKPIJ04ao1ZRXPq8ONDb9aZRnA883SE399ZR3Pn8v
OKuLLYkHDpwPcPJh/BvEC8EPcF9T+BvxRPAFAj64Mku8EfyBJ2PlV4lHgk/w
svY1BfFK8AtU3g8yiGeCb9DwnVc28U7wD3wrWzYSDwUfId+h5UviJc97P+w2
bJISTzM5X0HZcbydeCvl/IWiCWsT4nEn5zNsXWtXvmOZ11zvIaiRzMcQzwXf
Qb/R04x4L/gP1n8eW3xx+T4Q9wNc9jB2NyzfF+L+gLFLPiqPxGuy/wDdgUsS

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtQ1FUUxtfGkEESGgm0ktjBZkAyGbDBbaKDEmAMSCA4ymPaQHTDAoog
lDTjqUiAwxLikMrDB1ILhiiUcQBBIEWFXXksb5BHginI2gRF7bn3OtOd2dnZ
+d89/3O++32/Kw2N8gt/TiKRhOs/9M3XEDoV3r+5b7UlBmc16GyCB1H7aNBr
8CN7rLZMmfKtHsBA3WZ5XcPbaKbyGD5gNoCOVXEjrZGu+JmzUVdxdD9mb9K1
FMZ6YtstWn14ZeJVtczTF21ZwT4MubrGcEgXgFTNMqUXEz5O2Da2LQj1xfQV
tdj7sL88t1KO71I5Zy3uKg/IUtrsxpP5tHrQ5Nxmq14TBT61oYLdGBfqfnr8
80/QjzXYjdVG7Q+yf4xG1p6qC7/Diu0Dihhk5Yy60MfUrRyj4nAPW5046z3/
sveN/UjTZjXcwyiXgMlN0QeRjWt5Dzc4LQQHVh/GBDawBn2kLhK7sUTk5dSY
0FbleBBS0JEtNbYFbVF0NqdhNivYgSPjs9fdDqXjNI071Y5SzLTfGfotbmUD
t2P6/hf6UmXZWELliu/iqGmaq6LrOPLzuIvr1XeeXDmaI/S/jfLtbvWGPrnI
tke3YWXvbE7h63nI5LC5hdbmrmUxy/NxhOn5G6baGgdIF08K/VrRxm7pWslC
gdCrBS0tl5Su+feU0KcZS1eoNEVJZ4QeTdg9rRleeqQQWbkDjTj+yzdvjaUX
oQOb9zpaWHhlyNOLxXz1mBdb05SSXCLmqcPA03VPgr48K/qvRVmzEifl50S/
1zAqTLrMCc7jCdZfDcaPmuSGmF5AQ9bPVVR97a9J6biAX7H3X0aHcQv5bFKp
eN8lbE4M8n3e+qKor0Iv0/tvuKsuinqluEd3LWDv2jKMZ/8vQfOHTx94Jpdh
Bdt/Cld5GM8btJXhYfZciRExibOT/zz7nYx2rsOe8eY/4LOE5IRp2W/xHPaq
P/3ffiWYjf7+F9Wr4/UhHm+w9/HnJWD65yHWzxneH/jJTrB++X4VeN9cwuZ5
zOeD3R4VH9K8vP/L0Dk3oCY9hD5gvS9DSXoJ/SBTkm1Aegp9YUuirpb0FvpD
YNpKdh7ifEBauNhI5yXOD147m3SMznMjP1+I0JRtpPPm+jeCvH5miPzQyP0B
udpf1eQXY+4f2Llh2Xnykz/3Fyz3n5GS3wq4/yDilWE/8uMQ9ydEKiWl5Ffh
X0j9Of84+Vn4G+ZiO2vJ78L/MGHrNUN5EPmAd/IeuVBeRH6g2TGsh/Ik8gXq
CnM7ypvIH/jH7KqlPIp8wlDx0VDKK59XDS2PB9dTnrt5vgFlPvPr9Hnn82tg
wn9mB/HAivMBqo6t7CNeCH5AdUbmCuKJ4AtMLP5URLwR/AGXPxbciUeCT3Cn
5+9+4pXgFzQVhKcQzwTfIC7yTQPineAfKDJeiiUeCj6CbD42l3jJ864FB5fw
1cTTVM5XGO1p7RjU83Yd5y/Mrcr5nnh8m/MZ3qtJCiFec737IXG0Mo54LvgO
02b2R1DPe8F/aLwU8MWA/j4Q9wO4fmClUOjvC3F/gPT9HQ4v2k45/wcMl1X8

          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJxNlQtM01cUxhlRYoAwNhCEsYoTtMIYC8MNpnAIQ0TAAQ3IXAiETWAPhjKD
QVBAByVItECa8ZjKkIdCtNANBBfH4VUetTyLvFoQcDObxThCAJGJ632Y7CZN
0/xvz/+c737f7+744rgoztDAwCBO/yHfbM3iw8R9PeezPTBK0rEsjHqAe1MS
3k6qD8QWQY4urGUG05RvRM0rI9BSdnAuzXIGW1y2Jx2ujsFkL+PxyhPTWB2T
+13hhTjsV5GlxUi/XaIVx0TcQwtqcfmsoWPxg2Qk1QQ5GrzWbCXf8DiF+mL6
ilNot9hgJHNJR29SzmsKm/6wjQmOz8KyUrImMbTPqjyz6AdcEZKCE6iK9REK
duaiiDY4gTd2qNMU2/ORticbR4+lg8fmJRKk5YzH8UuvjFh/ryKMp2sMmxac
d76/JEUyraTjPoYHvBVVu1CMdFzBfcx7qvH2e/cnTKcDj6L4WbKZZeNVZOXU
GOH5XuI93wr8gC41Tsc6qwdDK7GAFhzBNU3phH12NS6QcXXDeC+5rzBaex0D
6MDDOPY4fOP2Z3VYRcpVDmGxKmhoZvUmsvMYQvdL/gMmLfVc/wG0PRojTg2S
I91+oh/DLpmUzfT+glQOoQo/qknKvChqxHmqpxK/ub1tS9mjJq5fH9aPVNhq
zjdzvXox0PTr/CcOd7g+PehTcUboqfyN66HAsfSUhZXjd5GWS+vCyZFJPw+L
VnSj83bi1gOKsKcNyOdrR7cPnV6uX2vj87Sh9NDjPwsS2nn/rWi9UvjmFYcO
3u9djLQzF+dPdGAJ7e8OJlj7Pxs614lbaD/NKHXxgUVBF56h729Ea1fH0mxZ
F3+fHJ0DfNv2uyp4fRmediqQ/12u4PVqMTg/6/WMlwpMpf+vwsmGdlOLw93Y
QPdfxcGQhypdbjdm0edSrKmKcE6tf/U7G1VaY+2Rzm58lRCj4M30N38OwYt+
/9svBe2pHlqvjdWHoltl9H3seRXURX5K+/mZ9QetKKL9sv0ykJavIZnnHzYf
1PoOl5B5Wf+NYLg260304PrA8xLNKtGL6wfzEWU5RE+uL8w/Mad6c/3B3SSa
ngc/H/hcXbRBzoufHyQlZIWS83Rn5wuzdpmfkPNm+neBfP9mHfFDF/MHWHus
7iJ+MWX+gZN/DeQRP4Uzf0HOyaVtxG+Xmf9AXXfEiPhxlvkTxvNLzxK/cv9C
urlDCfEz9zekuMZnE79z/4PnV25KkgeeD9j0rbWK5IXnB/yXXntO8sTzBWLp
0Yskbzx/YD5kNkryyPMJQXPiAZJXNq8a9r1ITiB5nmD5hhvf928ieWfzj8JM
k9lewgN7xgewKReKCC84P8D+hZUN4QnnC6ybB0YS3nD+wJWFmhDCI84n+FW3
EUd4xfkFaqG3BeEZ5xtEH9PlEd5x/kGnWnmI8JDzEbb2Dmpu6XnJ8j4Fcqd/
cwhPxYyv8I64ae1HPW+dGH/h493u68t6Hg8wPoPNuQArwmum9zQ8SrTDYD3P
Od9BEnL55pye95z/0JrR/Hui/j7g9wNc77xglKW/L/j9AQauAtvTZkbe/wEk
qFv+
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQlQ1GUYxoGBVISIxlKpVggSIpUQdISQd5w0jgkCAuwgHSCyA4hlJJBQ
KRDwmpUgAmw5gjgSdtABFpN4YV0PVljZe8FFSA4PkBoTiMmx9juc6ZvZ2dn5
f/v+3/f5nuf3uSR8GZVkZWFhkWT+kG+2xvGfynyv90ShGCeSzXvEjaFJPvTG
3HQcdgmOzER23US7AxFWNhX7cJUk6PfsVTexc4/s8FYXIQq32xrq0kbx9pa/
rVsjMnFwgCwTTtj1f16UcQhfpQVNqJsUdtjF5iGpJjhyAy2jX9yzdkURmouZ
K45gz0cy1VeJJzGQlNs+gon51nU//FqMlRVkDeOtjxVvhrt/jwsepKARNd2S
gTUWFRhFGzRiksPbTwnCxEjbkxiwUh3/ofvKWqTlbA1oGst5v/psHX5Clx5/
FiTvPShuQDKtSKbDfxeO3ruvakY6rkCHMYVbQ1oiW/FrOrAW2+TJn2aI2pCV
02AFTBSJxefQhy4Ndr4sDLmgacdTtKAa3a89E631luIsGXdGhU1T/o9zpOcx
mA6swumaPN/rid1YT8rVDeEXFZuMCVsQ2XkMYfj6ZTOuz/Vx/ZV4aFD/gmWN
DOn2tEGMdS31kfvJkcrhMYBLU+13a8cv4S2qpwKlFstWHvvuCtevH3fPPr/b
M6yf63UVT6o3//LA/hrX5wrqPfelOqkHuB6X8K8zS7say5RIy2XLMWhuXYr/
hiHcTOe9iAqx37DAVsXn60MH0eXMqAkVn6cXCwTbEpw71bz/HjyRl9qjztXw
frsx5MbjtK4dWiyn/Z1HFH426bmoxeW0HykGVHcrSqp1mEPf3445I46Y7qfn
7zuLuQ8MLQkX9by+BF/vvD8hCDDwes0YJlknK/zJgFn0//UY9Oi0qWHegG10
fxWCPLLsnK8Rc+nzUiz0nH7Wce+T3/nonzGe9cF+Iz5JSMzBEfqbP4fGHdr/
7S+Fh9M+tF4vqw9ur6TT97Hn9RCvv9tH+qlh/UGj7gztl+2XQILlMTrPn2w+
KFFJe8i8rP92sDkQS/Xg+kDKa4sTRC+uHygzcqmeXF8osZ78jejN9YeU4tp4
ch78fABt3Oh58fODLO/jRnKevux8wbE3KZmcN9NfDh2C1J3ED3LmD7BRyZOJ
X+yYf2DOJbuJ+Cma+QuWJwfHEL/9yPwHHcGuK4gfx5k/Iaiq+zbxK/cvDFsV
eRM/c39DSbl0LfE79z+4turukDzwfMCUuklD8sLzA98oTF4kTzxfUHZ9/xLJ
G88fhIZtfIfkkecThGvSd5K8snk1cCFPkUfybGT5hvKNAYkk72x+LYRCcyDh
gTPjAzx00o4RXnB+gG51cTThCecLKOcPhxPecP7A8Pq3IgiPOJ/gqtvoHy+Z
ecX5BUKDfSfhGecbHO17tIHwjvMPoq0cThAecj5CYtWpOsJLlvcREDu3eBGe
FjC+gtegooDw1pPxF+4MOdkTHisZn6Hy3YWGFjOvmd6jYFzMdCE853yHTd8G
7rI2857zH04rdb2z5vuA3w9wb1awLcZ8X/D7A7qeLro8L18d+B8+qmAF
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNVQ1M1GUcRm6VBzYyz8RZfGjESSGKDhWTX+iaRtnxWVNYXSLYZItDIkHR
xO7MTeggD4iGxFcgo7iDAQeI/hAOBeLr5OsODzgOgwBLpoEGLrv3w613++/2
3/+95/39nt/zPK/r4djgKFsbG5so60N+2TJj0XMf2e2MD8MIZfO8OGIMb4Qs
LvMMO4p1TorZoLpRbKjrzre1j0dRxb7xk6JRnE9v2t5YeArjdtsNFclGMNVL
saTuPIddnWSZMEGVValOvYAbKaAJp6YfvzvlrkSC5qS4g77O9TPPh19CK5gV
cRgb5M21s6XZ6Efgdg/jeheha8S3ufhjDllG9BIMVr0hKMAFMQE04OOrhzws
jsUYTAs04OY474Kgi6VIy6sYwp7KNZY6aTlSOLshzJLGfOrwkxqj6RrER/X5
0vtuVUi6VTYPYKiXtsGhthppu04DuPzBpnvCc1o8RRvuxw23tCEZFxuQwfWh
KS2g2dB3DbfS1Yc7/kxc2/RrE6ZTwNvYtnCs1j+jGe+Rdmf16PPipGC1Sof7
acN6PCp8vSS55iYWE7iiXtzrFuAd+ncbsnn04nnJ3lJ7yW+c/27sD9mTVNzS
hXS7rAvVX2s8De69SOkQd+LpMy7z4kQ9WiifHSh8KLnirL/N+WvHFc7jSROb
+zlf1nNyLaKYzAHOzy1MEQ88OvtkkPPRijnXw3RtkQakcCd1+Kqf3/HWNiN6
035bcKwyQWIW3+H93UDZkSyNLMXE+2nCr74Qe+t6Rnj91zFKnx7tvnKM19uI
3pl2USdczfgDra8es00wA5VmXE7r0WJNr+LpLz7jmEzPr8bw2J87lJpxfl4l
Bm0JFvW8ZuH4Ffh9x12IOW3heGWY+82y+yndFkyk/y/GspmKd4JemkAN3Z+H
d6f9LvvumcCz9LsKlyYVtq2Rz97lqMp3u5n35QQ+c0jApAt959/hZe2J/+1X
QaC/O8VrYviQo0uj57HvxWA0Dv5F6sln9cHTTA2tl+2vgO+OiWg/c6w/SHL4
hPbL6q+Gf/XbKB+cH4jc9fs04YvzB9rAkiOET84v1L9QE0X45vzD6PGdW8g8
+HxgbaBKTebF5weqMumHZJ7b2HzhvfhX4si8Gf86cJCtayF60DF9wFLhhQWi
lxVMPyDxla8iegpl+gL7gLhEordcpj/Y4dpTQvRoZvqEw1uVD4leuX5hLsDh
LaJnrm+QfjCeQPTO9Q/GB7oi4gfuD8juVG8ifuH+gbB1sYXET9xfELm4xob4
jfsPUn0UVcSP3J/gv5i8mviV9dsH/2zf2ED8bGD+hitzse8Tv7P++yHsTMsE
yQMXlg8QN+dRRfKC5we0xyx8TPKE5wuY/hg7QPKG5w8cjD7US/KI5xNIHfcr
SV7x/IKCwX2OJM94vkF6e14+yTuef7DSfPBJuDUPeT6C/Joxg+Ql8/swSFIu
t5I8Pc/yFTzf/nxp0pq3Hix/QXZJG03yuJvlM8xOfaYhec34HoEDckHBVWue
83wHZXC5kOQ9z39YJRf0vWm9D/j9AOtFu8p9rPcFvz+gMd4nbcRmg99/Ky5h
6A==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJxNlXtM01cUx4nTpYORbcaxhDFgG0EwnS4tLLiJZyIosD8QxgB5zIyHEQcR
tzmRuQ03HjGRV0VRpkgtLMqjA3ECG3AKLaM8WimUtmDlackmkpFBQVCW9T5M
dpOmaX6353fO936/n/tm4rGIlA12dnYptg/5ZmsSR6sfVga+FovxRV1Wr/gJ
zPNwq/w8Lg1bXHPnwlvG8VKkU2iN20ncIt8/lbVlHMvVX3hIlNl43N/eKMu4
j99tTl34vjcPNQNkmfFCgrK99rcC9KYFzagVDgl0JgmSaq6597DE+s6ie0oZ
2orZKo5h5lzQX4riK7iblPMfw4mDfldDfKVYfpmsUcz0SU4fy67CZS9S0IQV
0tebqkQ3MII2aML3BYmjbhF1SNuTG3E+Nd+w98sGpOXsjahQHnoc9+QWHqbL
gOGOr5b/oPoVybRFXSO4S2PqPKtrQTqu6wh+Uhs+NOLRht/QgfVY7aIx7lcg
snLDWLy2+vT8UCeK6RrGvBh9sOChEotpwSH8M2bBJ93zD3xExp3T4cXmpdig
fDUG04F1uK+3QiZ16McqUk42iFqnUJXzLQ2y8xjEgr3d2w/vGuT6a7G29Ojq
DbkO6fYMDX6dc8iauH0YqRxeA+jZVPjpVKsep6mefZgd+JGPOMzA9evF6M1b
XYWPjFwvNe48HZN1pHCU69ODUpG4MEJ8j+vRjT9V7uvzMpmRlstSofOBFxw3
ZY2jiM6rRMH1pOR/7Cf5fJ3oHGG3HKOf5PMo8ANNlPjnsinefwc67Tj7SujH
07zfNtROPydr3TSDl2h/rVi6fDzwq/oZFNB+mtHiG4CCkAd4mr7/Nspeqgt1
Nj7g72vEDW6ayJQoC68vxze6Jf8quy283k1s0UjfE3nMYib9fxXuqAn4TJcx
iw10fwVahSe+nauZxWz6vBQ7nKtbrbpnv3NwvfxpmsQyi88S0uWyQn/z51BQ
Ufq//aWQJD9I6ylYfRC+5ULfx55XgYM4g/ZTyfqDjY5RtF+2Xw5/++fSeRbY
fLB1LYbOy/q/DdKpmQ6iB9cH9sQJqF5cPwh6Unid6Mn1hdg1AdWb6w8ZYf0i
ch78fCD9QqqVnBc/PzjV3JlEztOHnS+ID/ziQM6b6a8Cyx2DmvhBxfwB6ob6
c8QvLzL/wKKqPZP4KZL5C1Ivn3QhfrvC/AcJhfki4sdJ5k8IjmyOJ37l/oU4
9xOLxM/c31BiTl8hfuf+h6WlO0KSB54PaDI7KEheeH7g9/MfXiN54vmCYt/M
KJI3nj8wBES/S/LI8wkhae6BJK9s3mE4tyJ8TPJsYvmGnUkbtSTvbH49rNYl
qAkP3BkfwGm2rZnwgvMDws7oiwhPOF/gSOv6POEN5w8sW54fIDzifIJr/d4q
wivOL0itaLxKeMb5Bt45mmjCO84/uNtxKp/wkPMReprOtBNesryPQe3Eth7C
0zzGV7hbX2YetPF2G+MvGN+eTyY81jI+Q+OcfxnhNdP7PkT3rfeV2HjO+Q7m
H+su3rTxnvMf8vyO+R213Qf8fgDJ5MuDe2z3Bb8/QK4MXZ0p9tz9H5TibdY=

          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtM01cUxpkQYYCAmxrHo+p0CYwtIEMbiXBGhEh4xIGAm0A2njJgTqED
oyzrRnUPDNTRAaIuQ8s2jGuUUYTiOFDZVIQiUGhpaW1R47YyZEsGw2FZ78Nk
N2ma5n97/ud89/t+d1PO+yn5K5ycnPIdH/LNlgW9bSv7fV7ah5m16r8DM+9i
pSjFRb3+XewUHLcld5pRZZuwlxWJcI1it/XoGjO+Xlt/ZdenH+LhSHfdhUMm
XNec6VznIsGhQbKm8PrOiqYizy8wiBacQm+hIC3xiBRJNcFxI96wTe7qzpWh
o5ijogGDU857PKttxChSLtKAtpk/hua157DpNFmT+PuWiH9f6WrG+UBSUI+J
ygd7/jHKMYU2qMdNj9uiG9/8Hml7Ch1OLWpKPwu/hLScuw63iAyuoojLWEDX
BKb1hBS8WtuGZNpa9Ti2jSiSRL5KpOMKxnFHWm7GrOkqHqMDa3FDdeneUYMK
WbkxjPngnWf0q3vwNbrGcKG6pUTW14tSWnAUy+5dswQ2qHGGjGsbwSafldv9
Pu/HODrwCO4X/plSVf8Lykm5C3dwpnVhybfnJrLzuINZOslyhH2A669B9ya/
ocnUIaTbDw1hXGpcZzUOI5UjcBBjxYoSdcAITlM9B/CvbVHpmpxRrt8tbElU
tgf9MMb1uonP+W0+MfNYy/W5gXUDbnb3+Amux8/4oMH79P5GHdJyR/vxQEuI
ueGeHsPovNcxbH5nR0mQgc/Xh9JvC6DigJHP04urrOLlN85M8f57MD5jRXq9
2sT7vYaSropVswYzNtL+unD1tmGbz/RddKP9XMVu0Tnpr0UWrKTvb8eyAWG3
j8HC33cF5z5K9qqJtPL6ClzefP9jiczK67WiUeU8vNVsxSP0/3L09fN/8uiF
abxM93+N5xOePyXcPY1i+lyG0eUx6c35T39LcGK7RfVQNI1PEzK3bKS/+XNo
Hhb+b78MToXYpaReL6sPmWL7Enkfey4H/69MGtLPN6w/yMtT0n7ZfgVo1vrS
eebYfBAgX1CReVn/7VAsTqV6cH1AXhNM9eL6QYBQ7Un05PpCxv2INKI31x9O
5n1nJ+fBzwe6/Y9FkfPi5wdBOaAk5xnOzhdq1200kfNm+veDW/BsA/FDP/MH
dF8cXyJ+8WT+gfWfmCXET6nMX/Be1ds/Er+dZf6DLJkulfjRwvwJ2hJhMfEr
9y/IwyKUxM/c39Annr1F/M79D8XWHUskDzwfUO0qXSR54fkBl+CDe0ieeL7A
aCsMI3nj+YMaZ1cTySPPJ1Sm6wtJXtm8Y+Ad3rSoc+RZz/INqoSqBJJ3Nr8W
KmeS9hIebGR8gBiP8ljCC84PEO6byCI84XyB22tzl8scvOH8gUeHW7MJjzif
AOoyQgmvOL/AJMiOIjzjfAPt4MnfCO84/+CsR/xFwkPOR3ji/NNDNwcvWd4N
EJqv2kB4eoLxFQb9b4cS3r7M+AuTXuXJhMcaxmdIqvNQfengNdPbBGdGCgWE
55zvEH0ppJjwnvMfBAe3TvU67gN+P0B9x1ulXo77gt8fkN2RHxvY8GLUf142
ZTw=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtQ1FUUxpFgeNWQA5KSLlgy4UpvNILgpPFyxuEVqRH4YMAkHoKzYhGh
IJDKjGwJBgw6FFiCsEI8RCHP8nKB3UV5Lq1AiAXMQMLACOLY1J57rzPdmZ2d
nf/d8z/nu9/3uxsjj4REGxsZGUUbPvTN1zhG/nB/T6X1LgzPbX3kHP4Hxk8M
RJlK92GjJGsmuHEMrUJsDuuCDqOtwu9+iu0Y+qTv7neOTcIkT0tdaeIoqiMj
32qIPI5aDa0RdD9rbZrokIabWcER3Go/lzQ3nIFUTZJ1D1/bu0HlteZbNBQz
VNTjAXer602aHPSicp569LZ88aWCU3IsKqT1O545aV2+En0el5yp4DDm7M92
GJdfwBDW4DD+FDt3ycesCFl7Ch0uydWbr6ovIitnqcOEtMbTq+ZL8BBbQ/id
ZNGq55VSpGlzWwfRq187nZ12Gdm4kkFM9YY4m+eu4Nds4AGcyhi49vBaBfJy
/SgzVu7ZmFmF77LVj81ng9MlUI1yVrAPa5Wdd1x6anCWxp3pxYlTVTGWCbXo
zwbuxVc/2dm+c0M9llG50rsYsfajezv0DcjP4y5ONCe/blfaKPTvwfUp+Z3V
x24i256oRQ/T4qDewGZkcjhr0OXx9ukX3ryFE0zPbsw+ty0u3lwp9OvCmYsH
p/xXlEKvTmyqS21rnm4R+qjwwM963aHBVqFHB0Z5Ho1/8FsbsnIp7Rj0wVan
3pJ2fIfN24Zrs2QNA6kdYr4WVBw/nVQcdFvMo0TpldXJD+xVov9b6G3yZ65M
rxL9NuNRj9Eal3OdWMD6u4ELI4GW/7h2oTnr5zoGJtvWzGq7MJW9vw7NRr5Z
XLe3W7yvBvvCnXyb+rpFfQWe6MubcvBUi3rl6PuF3fbqC2r8kv2/DBeS/Gwf
jqmxmu2/hE8nozJlazR4kj3PwwaryxaP33/2OxNPDO37zHeXBp8lZOhmGPst
nkORouB/+/PAXxrE6il5fXDZJGXv48/LoMNv/kPqp4T3ByvZ0axfvl8BAVmz
PjTPPJ8P1lt4sHl5/3VQ+4aqmvQQ+sC2kmUL0kvoB39nfsX0FPqCRYCM6S30
B4uE/GN0HuJ8wMH930Q6L3F+YKUZrafzdOXnC92F8k103lz/dvgrEOPID+3c
H/DEfh3zy/PcP6Dzr2wlP4Vyf0GjY8Yk+a2Y+w/MJvxiyY/j3J9QsMV3kvwq
/AsVuvQA8rPwN5x3irhNfhf+h+UfHbdQHkQ+oKr5zjDlReQHdhy80UJ5EvmC
auWqzylvIn+w29ZYS3kU+YT3HiWmUV75vP3w/dvaYMrzMM83yCJ+Lae88/kH
QOU2H008cOR8gNGo0AniheAHaMaCTYkngi+wbLKQTrwR/AHppysvE48En+CJ
9aiceCX4BTbTbquJZ4Jv4NGXU0S8E/wD/7Ewc+Kh4CNIFn0LiZc873qoaDIr
J55mc75Cmp/8Y+KtlPMXsmp7VEcMPO7hfIbgnMqFegOvud6jkK92yyeeC77D
cqjjzJCB94L/oFq6GmNiuA/E/QAxrmH7Kwz3hbg/wO6pKsDnF2uv/wAy2Vnl

          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJxNlQlMk2cYxxFHJICLMBQkk4xpIiiOCThDSH1w4VKY0W4cUgIIlpJNLZso
iqTAGOCEiJmkQw7HNbBIqlyCc/qU+5D7pkK1zGzMIyrjEMyO7z1M9iZN03xv
n+95/u///3vtIuViqaGBgYFU+JBvth7h/OEbCz+v3YWh2c0L9qEPcWH1ezFp
WV7YaJv29FCjDntLvn1+6uRBtFT76BMsddg9UBPu5xSIX4tMxktjpzG0w0xX
MCbB3h6ypnDrbzXxJj9FoAMtOIXmDvE9GusoJNVs0x7gvriNq0vcpCgUEypq
Ud9S89Vf09G4h5QTaVEpkRfOTckw7wpZk2glu64YM47BRXtScAJDXq3cmPtI
hmLa4ARe++HQ1CprKdL21OMYfPaf/rzzR5CWMxnHANGx+vLUYIymawx3G8sL
/Iw9kUyb3TyKIoU4pfKPvUDHtR1F8cX5zJlTEXCODjyC9XNtkipXObBywzix
9qjD4XNnwIWuYTx+02jZXJECl2jBIdS9eJmynJ8Bz8i4TwdRJXcZWF96EXzp
wIOou4CjkgOXoYyUKx3A/SWbtFUdPwI7jwEMyeq6ZY0FwPTvw4YOub+zTTHQ
7bG9aN0VdF1lUQZUDvsezN+gCtF4V8AM1bMb59ttPt5cWwlMvy584r1kHPi5
Gphenbh7U6PZ5LpqYPp04JWknQn1prXA9GjD7KjZA59tqAdaLqEViwv1R7c5
NoAznbcF558k5UX43ubzNaHHHpHsqvQOn0eDYa/0uR6Ku7z/e/gmelgXk4W8
31/RMXVHsGmbBnJpf7exNzvKsLixCYxpPw34r+J50ZvCZkik769D7f2TD9y+
aeHvq8bOxcnXRc6tvL4a/2zwyK+cauX1VFhnblNrfqINztD/l+F2fYpY97gN
btL9VzFIeXZdLLRDMn2egzKnkrr0xLe/v0Nlf9AL3/x2eJuQ9Zn+9Dd/DjOx
yf/bnwNFF/bSehpWH74fcqHvY8/LQCS7VUP6KWL9Qd58Rx7pl+1Xg6TRn87z
ks0HYV1DWjIv678OdmS4UT24PrAlo3AV0YvrB4NHAoOInlxf6DQymiZ6c/3B
vmRBSc6Dnw807NslJefFzw9CqsJyyXm6svOFpURVJDlvpn8rVPTn+xM/tDJ/
gN3sUDzxixnzD4w822dC/PQF8xdYxhm8Q/xWwPwHErt3txM/PmL+hCGLzADi
V+5fyKlwLCd+5v6G8Cx3H+J37n/4NDKwiuSB5wMk1eX9JC88P6D80O8+yRPP
F9SvkdwheeP5g42vnY+TPPJ8whrdl49JXtm8w2ClSDUgeZ5g+YbFEx0mJO9s
/hE4v7nHnfDgA8YHiBJ7eqoEXnB+QJiXZtRf4AnnC5iOORysEHjD+QNFO6Xv
5ws84nwC7yXNVkOBV5xfkFV1eoXwjPMNtpS5dRLecf6Ba7j174SHnI+gzkiu
JbxkedeCpY/VfsLTdMZX8AqotmgSeLuN8ReOhX5yl/C4j/EZ3Jc1skKB10zv
aciwc5olPOd8B+9f9HGnBd5z/kPfw+64dOE+4PcD2JrFm14T7gt+f4A8aUX5
92WDe/8BF+Uukw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQ9Q02UYxzmSqI08vEMEFBSVRK64tpUoRo+mQCTy39Qg5DAIJAKx7hDk
z3mMCCX0GhXEqQSlpMxpJoOAB9lAwI34M9gYDMnMKBD1OCDMjn7vH+9673a7
3e/d83ue7/v9fl73+LSIBGsrK6sE4UO+2RpHRfqTm/Z/vowxpW2znjG3cUNh
4NH6x1tR7SafDFeP4YEf7P2arXeggzLw1yyHMXzG8TN/6YQ/HvYTGavTLVh3
Mrrxnfv+qNeRNYriLx/FxUvexI204Ci+n6mxaoiXIanmJh/BPcEZXqfvrgWh
mFDRjK/rZ4uL970Nb5ByfmaMd70nz9sdAxXlZA3j/SSHf3btTII5T1LQhE7n
zLL8ugyIoA2a8OR4WrP7gyyg7SmN2FZop7ScPg60nMiIVZ9HX1nZXgSJdA3h
C8PykqtOp4BMW9o2iM+H2S58kq0AOq7bIG412m25VFEO2XRgA3q/K00ulp8F
Vm4A03Ve/ms9qkFG1wBKZEVf9D/+Hk7Rgv24NHMxKSzoIkyRcSf7cOqVsn+P
ilTwFh24DwteLEuPVV2FGlKuuhf/fi9Ot/Srn4CdRy9OZOTtT2hRA9O/B33r
S2sCPZqAbk/X45oki5eiC4HK4alDxS2b1SLDDbhD9ezGyOBvk7eMabh+XRiZ
kJNaadXB9erEqJDlvX/4dHJ9buJwt3X7zvxurkc7rns0o943qANaLkuLsluR
QWHSX0BK59Xg6BJtw1xnL5/vBi58E/JB8Hwfn6cVVdPb233dB3j/LZinapz6
eYeB99uEUetba1uiB+Fr2l8Dns/1SpYlDsFztJ96zLJPq3COM8Ix+v5r6GGj
8SkJMPH3XcHQOdM6g+Mwr6/EnJlKcUrPMK9XixKbnuxlKWbIpP+vwaaxDWOG
v8ygovvPYJnmtxUuwSOQT58rcM7l+InvSp7+LsCK8f6gKuUIPE3IdmMH/c2f
g0gc+7/9CojvO0/rtbL6IA8wWMj72PMaMLscpP2cY/2BaO1K2i/br4RtuI3O
85DNBxcWHei8rP9rkDJxsZzowfWBxJmIJKIX1w8+tB28QPTk+oLr3aZJojfX
HyYPSrXkPPj5wIMw70RyXvz8oNpaoSbn+So7X3A9NhRAzpvprwXnoujrxA9a
5g+4nh/eRvxix/wDfgd264mfopi/wCiuOkT8Vsn8B6VNPyYSP44zf0Kxt+0q
4lfuX9gToF1P/Mz9DSsaYs8Qv3P/Q9vHvpEkDzwf8NGz4g6SF54f0I9LD5E8
8XyBj+fGeZI3nj+YvuwcQ/LI8wk4X15I8srmHYDG/s2bSZ5NLN+wsCk0lOSd
zW8Av3rJasKDNYwPcCfS9zbhBecH6J11RwhPOF/gbKdjLuEN5w8s+/1JFuER
5xNcjtPuJbzi/AJ1WG1PnsAzzjeYLqmTEN5x/oHJcflsjsBDzkco6Q9I/VTg
Jcu7GVxDJJoCgaeFjK9Qs/feSyjw1ovxFx7GpR5JEHjcw/gMybOHu/YLvGZ6
W6A8Ny38NYHnnO8w2bvo3yrwnvMfLMmX5M3CfcDvB9iUj0OrhPuC3x/QULdE
tUvs1PIf/5MpDQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQ1M1HUYxw8TZ7xYE2woAzUkoFxz5wtYwQPDAMkgMJTBZbxM9EaExMsA
FU5MVk2GG5pAYOCdBjEIlALLeODgeAk5Xg7k7oDjbUrIq6REHaP+v5e2ftvt
dvv/7vk/z/f3/X5+O6Pig0+uE4lEJ4UP+WZrDE0+8r7x2PcISnKVz50lo9jW
ELPQ9rcE6+0vzQTVG3Dz+xXSP51i0LrKdzzd2oDV2QcPWS3EYYK72aD8zAje
9K44Gqn5DLsekDWMW1b0utOXU9CFFhzGaOW0fM0kHUk1+0tDWDW7IVJheR6F
YkJFPY6U5S8pszLRg5Rz1yP46DU+12VYWECWDqeMzimmszJcdiYFtRg2E+C4
q0SGwbRBLS59qjfHVzORtlc1iCWrybNz+88iLWc2iFk5p/a+sTsZY+h6iI9F
Wx2ipFIk0+YqB/C7fIWpn9oV6bj2A/jymM7uWJEUztKB+/FQt9ezTRkZwMpp
0MGwtf6rxS9hL10aFOv97r70QR5coQX7MHAyIfHdukKYJePO9GLu9afL88Wl
4EcH7sXB1Sav2KTboCDl5D3Yd2etWjNRAew8enCD19Js/PNqYPqr0buzKeoF
n1qg2890YcA3c4m3xuuAyuH8AOdGA7Z8ofoFJqiev6Fp3JoxYw6B6deBykz/
BqOLEphe7RhxMWTVmNoCTJ82PGFeVp032gpMDxXm7fa8Mh/aAbRcegs+Vd1r
LBrtBDGdtxmHA6fc5HFqPl8TJm7Os/TL6OHzNOJ2/bfhHcpe3n8DHjRRRXaK
NLzf+2gIku+o2dcP+bS/e3iqcvWuPmwANtJ+6vD70oaFH+Mfwjn6/lqsbR33
7I4f5O+rwfDgVenEcS2vX4WTXrqaJ7t0vF459vkbbcX9Okil/1dgoU2578fR
eqim+29ggFZXcKFHDzL6/CqKkgwRttuG+O/PsXLtVqULDMF/CWmL/Zr+5s/B
tPuH/+2/Cgckl2m9RlYfnJ3c6fvYcwWoYhNoPyWsP9DuFNN+2f4qkDS50XkW
2XyQ/NM6Oi/rvxZSHFTzRA+uD+DC9B2iF9cPmotTtxM9ub7gVncxgujN9Qeb
+MNh5Dz4+cBrFi4W5Lz4+UGZeGE/Oc997HxhpafkV3LeTP8WUMtfzCF+aGH+
AKsDxyuJXyyYfyBUMbdC/PQh8xeUdal/Jn4rYv4Du/JHz4gfx5g/Yb162ybi
V+5fyDVXfEL8zP0NrZ6nw4nfuf/h/lTOI5IHng9wNbrcJHnh+YEJ8ydikiee
L1iJtP+d5I3nD87ZTYaQPPJ8wm0nwzWSVzavBo6ulp4nedayfEPxzB4ZyTub
vx/GXatdQwQe7GB8gKC2ZsdAgRecH+B8YWB9tMATzhfIGXpFTnjD+QNW4sWw
eYFHnE+gMdqlEV5xfsFE0bFwwjPON4goLKggvOP8g9Cg+o2+Ag85HyHJ8u3w
ZoGXLO96eMesuJ3wNJvxFd6TZZn9I/D2dcZf+Ms/G6QCj9WMzyBqT6snvGZ6
j0Bxq4eFtcBzzneYv/bWnhWB95z/0PnHUFqHcB/w+wE8jkiqpoX7gt8f0Lrs
+KbtCZuGfwHTrkj4
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJxFlQtQlFUUx9EhR8EaHyRiyUg6ufkaFCYehcfRoRSFWEMXggRfgSYpiA4J
q6CshCwCyggRibJruBEbLGwsRh5iKUAWhmcLCMhDiYVIA1djSozz3et0Z3Z2
dr675zvnf///33XYd3TnwZkWFhYHpz/0zVYflmwstA7bvR+DUqvMoqB72GN1
qDcvJAp19rJRsa4XTV5Rc7Jt4tBG/X7/KZtefNm1W7Vcdh4jPKyMimM9eGe5
ZEXs2RRsMNDqxusFGyz9ZZfwLaFgN6ZcvJ9wUn4FqZq97C4+CMm/kdGSjdPF
pit2YcIC5UWTOBc3UjmPLlxcYNy0f0YeZn9JqxMrdeWnb4cr8YmICnagQSs7
s3L4G9wpNNiBnQrbfO0hFQrtqY0YL3EyxIwUoFDOyohjZYpHGXvV+ImwfsPZ
tguv5uwrQpo2taodl4JnY7isGIVx7dvR9WbRopuXNRgjDNyGjkvCr0kTS5CV
a8Vx93leloGl6CSsVtylt5vwm63FNKFgC7rvMJsKk7T4B4072ox3H45XZ3Zq
caswcDO238istZ7QopLKKZow/Vxod3azFtl5NGF4W9LjyxFarn8jrvvKrBc1
laKw/VgDpsXJ41NHS1CQQ2TA8E2a5GV6DQ4Iet5BycDaqs8kxVy/Olyt2mtd
4vc916sWJ/QWvetOv9CnBgMfRExGOOdzPX7BaOcrAZ7n8lAod6oa5w25tfz9
VzZuEObVo9Tl+NvJO9L4fD/jhfWOnt4Po/g8lWj3qpv7mqBoYP3fRiuNw2G7
uHRg/Vbg8dGk1NDmHMgS+ivHCNW7of+OKWC20E8ZpohfqQp2VUGs8P5S3Kxz
29zkqAb2vmIM8Rq893VIMa+vxt9PvOknO1zC66lwyCzdblijhWjh/0o01LhI
xbk/QJGw/yqubO4U7/qxDOKE5xkYlu9Ynhej478T8PXRl/rV3Tp4kRDvCzV9
9Js/h8+fn9D9vz8D3vBV+lK9SlYf5tcnxdD72HMliPQfbaN+rrH+IHb9JTH1
y/arYWJkoJvmecTmgxGXI+/QvKz/Ugg2xd0iPbg+MCvy2R7Si+sHYW6/SklP
ri/MH3aVkN5cf0icShxZPX0e/HzgW/mBLDovfn5wpv7ZdjpPZ3a+YAzeM0zn
zfSvBhvV4AHyQzXzB/gsNllGTvtlLvMP3P8uzUR+8mP+ghU9k4vIbznMf5D5
wZMa8mMf8yfsVh5NJ79y/4LE0jWR/Mz9DZH/fFFHfuf+B7sjzycpDzwfMPbh
rX7KC88P1AXqGyhPPF+wdWiijvLG8weK5No/KY88nzA0VfGU8srmbYXX6uN9
KM8dLN+w0FygpLyz+dvAyb9iCfFgGeMD6IxLW4gXnB+QJyq/TjzhfIHHBvlT
4g3nD5x1qGghHnE+wbh8SyHxivMLSjX+MuIZ5xvMXOuaQLzj/IMAn1nvEQ85
H2FOzqdZxEuW9y7wDhhUE0/PM76C2SM3hXi7ivEXtvmenEs8bmR8hhqppTPx
mundAzo3vY54zvkOU4Z8W+I95z8ETMon6T7g9wOsqtQA3Rf8/oAtmsKPfWdM
/vQf8TVaNA==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQlQlGUYxykdMAiYGBxAdCPFXNYDSqSYYh/MiszRFlAIh6BwwDMRUGLA
gzEOBXIRN1rkKGFnAKXlkOGI45FrEA9aQGDZhWU/JiKBgSZCKHSM93Cmd2Zn
Z+d79/me5//+/7/3jbBIv/CXTUxMwpc/5JstI2Yuaaw+EMVgsLx1Xhw8iqZ+
oc9MA5OwTpQ85VtnwGyrOf9n72SirdpHiLc14OP0GbeWxWyM8jIfLDo1ghs1
k6/NxhXgwwdkDWO0malnyFdF6EILDqOdbUesYrYYSTVRsh6/K8/x0E6W4XKx
5Yo6dGstcn0uqUQpKeelQyfrVW4RDtV4PYesIdyhCjA+9q7FJ2JSUItyWew3
4hu/oB9tUIvOmeN7zDybkbanHkTl16Ia/xUtSMuZD+Ll8iBBvaINI+gawKCM
gzcHHTuQTCtv7cf2xr2Wpbs7kY4r6scvbo0dzknrwgQ68COUVVx5ivr7yMr1
4Q5fj7Ujnt24na4+rM6uOlMl02AmLdiLWcNhso9Te3CajDvVgyU90pd+bu7F
T+jAPdhm7n5E93cfqki5Ig12jkUONW7qR3YeGpSHLNj7HBjg+nfjl4b1iviE
QaTbTz3EhqbcjCilFqkc4gdYOj/725GbQzhG9byH2ml7aVe5juvXhWY78+1c
i/Vcr7sYFiQrjZIPc3068a9tFh4lh0e4Hh04sai7sdXVgLRcfDseCqzZUDhu
wLfpvG0480rwv5Npo3y+FgwoSLRSWhv5PHdw2+kN/xz3NfL+m7F8zazCO93I
+23EqJWfxZxrMqKS9lePVoEnG/L/MOIq2k8tth68MCexFPAsfX81XpsbDavd
LPD3VWJNwnov7YcCr6/G1Lird18PEni9Unx64Pxtu6MCxtH/q7DlysV7750R
sILuL0Cpql86f07ARPpcgf4hNsXZ3774nYQfnYgwfJ4i4IuErE4/QX/z55Cm
cv7ffgWk/jpH691h9SH/rTL6PvZcBUFDVbSfn1h/MLVOQ/tl+9WwFHqMzvMn
mw8kNm6HyLys/2qIuDpA9eD6gHD0PtWL6weRhRVUT64vBI/5f0/05vpD/OJl
eh78fCDr+AQ9L35+cH3PpiVynu7sfMEh+KwzOW+mfzvETCsLiR/amT/AIaCZ
+uVV5h/wXvOE+mk/8xfckmy3J37LY/6D50151I9G5k9IKQwdJ37l/gX16Xnq
Z+5vUFiEU79z/8N5tZMDyQPPB+TuukDzwvMDeWVimieeL9BvtKd54/kD4zUn
mkeeTygr2E/zyubtg/dluxxJnrUs3/BDQPgSyTub/xFY2iRFEB44MT5Ah3+D
BeEF5wdEW2eXEJ5wvsAWx/BRwhvOH8iYW7pNeMT5BImXdvsQXnF+Qd3mS9GE
Z5xv8OlFRz3hHecf/PhmsoTwkPMRRPsMLoSXLO86cLdWSAhPUxhfYeH3fccI
byWMv7Byq8sWwuNuxmeobI5dmFnmNdN7BOo9e1cTnnO+Q2UuvEt4z/kP03sn
28l9wO8HmMwyzdu5fF/w+wPqJ04a9GvXSf8Dvjlmlw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtM01cUxgkTJGxGHYVkE6hAIB3qwkOGI8ohG4HpAgREcChkkxVDDQM0
MAfOGCeONGRFBzp5OCaFYJAqabWQGQ6vVct4lGcBSy0bMpTBgNJCGJvjPkx2
k6Zp/rfnf853v+93PU5kxoltbWxsxBsf8s2WCbftKrm2+cx5PC5rt4iOP8U4
1zCZ7sNibHIvmI1tMuL6tuxTy1vKUKCInMwTGHH+M80xX+ktzD7gqK/OmkDp
lFPI9qY67Okmy4BzC14vd1TexXdoQQNe290oq7+lRFLNveAJylznAt82qnGj
2EbFcXRyMTb7XH6IoaTcgXGc1KhnHve1YtkNssaw9GVeU/D1DrSKSMFRdC0K
93utXINxtMFR7M1PSTlq0CJtT6HHS2tnfJ4e60FazlGP3xVWp44U6TCNrhEM
9052rpAOIJlW1j6Mh2slQXW1Q0jHdR/G7+1kVkfTCObTgYdQPe+0Nz9oDFm5
QVy3mXFMqHmCgXQN4r+LemHVHiMW04ID2CeZiN6UZsI/ybiz/VgQql62tkzi
R3TgfvTZtPKP/87fUU7KVetw+GiJp3vhFLLz0KEwpCh3s+UZ178XU8PCbnqK
/0C6PasHt8YIc6+OzCCVQ9SNnycYHL6IfIG/UT270HlSekdzf5brp8V9kjw3
hXCO6/UY5/XKjP3fzHN9HuGOlRs/lRr/4nr8ggeD6yUr1xeQlsvrRPst9WJt
yCIG0Hk78EjQ31NLI4t8vjYMnH2QpDq1xOdpxWxxbEPy6hLvvwVj3zKao8+Z
eb8PMUPe+Ouq1Yw/0P6acfCrrijDyWV0oP2occJWoJD2LuM5+n4VJme1XZH7
Wvj7GrFfI909lm/h9RX4KCf9vWdtFl7vNsq35nRfWbfgWfp/OQ6b6mKUu6x4
j+6/icpvaw+LYqx4gT4vQUGDjWI07dXvSxjREKVSnbbiq4RcSIqhv/lzeF5j
97/9JTD0o4LWa2X1YX+fkr6PPZdDR+ZF2k8V6w/8tGdpv2y/AiK+LKfzLLD5
AAYG6LysfxWsJXpTPbg+cHJ5nOrF9YMMSSvVk+sL+sgXVG+uP4QJkuh58POB
ML+f6Xnx84NDojV6nnvZ+UJ9VzU9b6Z/J+BUBfVDJ/MHyK9mUL+8wfwD0f65
1E/xzF/QIfSlfqtg/oO0Bz7UjybmT+gMTqV+5f4F5/jiHOJn7m/QNJRVEr9z
/4PyYl8OyQPPB6BbqwfJC88PfCx4neaJ5wvCS5VmkjeeP3B5tz2K5JHnE2Rz
p91IXtm8g1CTeMSB5HmU5Rv02nh/knc2/xBIuuRmwoOdjA/gOZ8QQHjB+QF7
7nu8SXjC+QIpBz/4lPCG8wcqptOFhEecT/CJ7fZEwivOL4i1qEWEZ5xvoKtU
3iO84/yDxufNJsJDzkdYnP76NuEly/s4eGv9vAhPLzO+wmpb1XnCW1/GX5g+
ITEQHvcyPkNngs6F8JrpPQGJLfb7CM853yGy2cmL8J7zHwrt3CLIfcDvB0gc
OJRpv3Ff8PsDvNPbrO+XB4T+B/lddSY=
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxNlQtQlFUUx3ch4pFFpDmV0w5Q8bAMSlNQlgNZA+mII8EoQhkEhpXjUhYb
ULiKqIxK45KCksKwk49yg1HwAe759kEIwyLLrrDAQjxGHkEIixKCYdyHM92Z
nZ2d7+75zvnf//93vZJ2Rac4iESilPkP+WarB2Od5Xt3xuZgQr7uvl/CnyhX
eM2+p/8Jr0r2j2y62o3Ljrx6+Nn0UlykjujNWNSNr5/dKUsbOodpUre2MlkX
LriQ/ppcVY7GRrJseHBfvGksthL9aUEbfhZ89MrKY9eRVJPs78SNTcrE+LcE
nC82X7EDzSHmKGmqHkNJOWkHund633K0/4Eni8hqx+2zCt2Jlgac8iMFrXje
tXxA9vQtjKYNWvHuE9me2GJC2p66Dc9IzyYfiLIgLefWhoptc7u6ZlpxO12t
uC/TdNTX2o5k2nzdbQxUxuUmDNiQjiu5jVm1Uce/f64HM+nAFgwylGsU9b3I
yplRskx3SX6iH5fTZUZr4C+6hMw7+CMt2IJ688nJ/q8HcZSMO2LCAI1H7p7s
YYykA5sw+8XhQ0nFI6gi5cqacYejviDj5t/IzqMZ26+l1WpE41z/JpzON1Tu
9p5Aul1mxL5T1hynSDtSOfwacfDNex84yCaxj+rZgMcurEn+q/Ae168ev3U6
vDlAe5/rdRNN3RvagganuD51aG9sHk51neZ61GLziO0ZT58HSMtlGLBE7Byr
XTODb9N59Zhku7OuKnKWz6fFPPl31V+tf8jnEbBN2uArf/df3r8Gg8K67Vve
mOP91uBQ8TdB1c6PsJD2dw3P9Cavizc/QhfazxW0GNuHn4wQCVn0/ZexwqnT
9MkpkcDeV4HntI7KsAGRwOqr8WFsSF2wr1hg9c5jsZexZ+wjsSCn/1fh6JYb
Co88sVBO95/GzM0rq5N+FQt76PMC1LuUBl/SPv6dg5LJi4n9jWLhcUJ8fNT0
N38O1sL/7y+Aav9VtJ7A6oN7uIa+jz1XgaaP9VPC+oOLZaxftl8NYeFsnnE2
HwxsbKfzsv4vg0LWSvXg+oC5N47qxfWD0JgUqifXF34vraN6c/2haNVv9Dz4
+cC26Wh6Xvz8wN1SSc9zBTtfkHzRGEPOm+lvgPeNx6kfDMwfEB/yA/XLAuYf
2OA01kr8FMP8Bf7eEuq3YuY/cH0ePyV+7GH+BIe4VOpX7l8IWyilfub+Bsvc
C9Tv3P+wY7DSQPLA8wEvq5YqSV54fiBDFHiQ5InnC372DsoheeP5g92epRMk
jzyfcEN0RCB5ZfOaITAir4Lk2cryDeOL42tI3tn8FphItCkJDzwZH6CpRqog
vOD8APUrikOEJ5wvsGl11ueEN5w/sHzJ1MeER5xPoKorfYnwivMLHgSUdRCe
cb7BP0V+VYR3nH+w9vpeHeEh5yMscbGHE16yvHfAjHN6DOFpLuMrLPQdKia8
Xcr4C2KPD6sIj5sYn+Gd9MVuhNdM7y6I630qmPCc8x3qt66IIbzn/Iet2rV5
5D7g9wMY786e/nL+vuD3B6xumVw/WhIS+h99T2Dk
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcx4nCGvkjCqe5QMSanC1QzrJk8NHJOJsm/kAbdcbMEF0Qp+KP
A9xwqYfDiTmnZAlMGUG5Cx0VN9i9PcIwQuI8hPuJ+ItNgaVMS6egfJ/n8/zR
s91ut+9zn+/n837e79cz4/PcVZnBQUFBmWMf7VuuPnTMXdGWvKbPbixtfhBj
vIqitZf9sc8P2xsi9w2sbOhFiyXYEto1Yg+3Gq7lh/ci3tofVvMwBFsSQ3tO
mwK4Vf6er944EZfateXH7ndq7RveCodOFPTj020LXZbR16FVi9znQ1LqmhOe
7CiMFRur6EUg85DDmf0mkrRyiV7YCkvSbofpcOJbbXmQpWt8cZYpFv/GaAXd
aE+JaF23PB6rRINuLKs0VdzpfheiPWsPov5ZGKIPfABRLrQHb8xJ2jGUnYSN
YnVjpOTsa/cuLoI2bWnzFfzYb/jb91MyxLiRV/DY7R/y3TSgQAzcBcus64kG
81LIci5U5gYWB32VCr1YLrh/ndb0w42VOCwKXsYTp3nRuuQ0DGrjDjhxJpAe
neNdiyViYCdW2xwryqrTUaWVO92JuR/pjjytMUKeRydcPf91T7qWAal/B65a
+yMaqtdDbDddwrK81LhH2zdAyBHTjvnn5nmajZm4LvRsQ9fkkoQp6Vms359I
/sa9s2jTZtbrIspfLv75leIvWZ9W2ExLT35Rn8N6XMCTzmnDNbdzIcrltyAk
Ki7FGbYF8WLe3+G3/XHBH7uV53OgbvPqY19/uI3nOY/3t+6N1mfkcf92vOqN
nrA4Zzv32wRnwpmKp6YdKBP92TCw5HDIL1k78ZLo5zccMIyb3Lh8FwrF++vR
O31mxp6ZZn7fWRgHjyd8d8PM9a2IDD6+56+D+VyvFo/Mo+WTIgqwS/y/Cgs+
iXXUHilAndhfjrJhf6tusABF4vlR3DxV58iLKeTfe5E1dXZTW0ohVELUb35O
/99/lFS987I+qffJ51Wk+qmU/ZHqV+63kprnrpyP1Lyy/3pSerA+pPRi/Ujp
yfqS0pv1J3UefD6kzovPj9R5zpPnS+q8pf4tpPzQIv1Byi/jpX9I+SlN+ouU
376X/iPlxz7pT1J+Zf+S8jP7m5Tf2f+k8sD5ID3nhfNDaZwnzhdZOW+cPxrl
PHI+yct5lfO6qJrz7Jb5pkOcdzl/Fz3nkTyIknygc8wL5ge9cFDyhPlCbzNv
mD8UxzxiPpGRecX8Ih/zjPlGFuYd8488zEPmI40wL2XevfQZ83S/5CudZN7O
lvwlB/O4Q/KZciskr6XeAWpknjPfyVUsec/8p9KP5X3A9wMN6eV9wfcH9R5b
7zp1f07TM3P7SqM=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlXtMk1cYxitxU7DGGkkGcXYU4ixuM1Gn8QK8GrI5TTSKYjRDZlQkbCo4
FZSCwASRuAQtJVAmt3ARKTYziEBmfISx4ZSLyKWlUESzzj/ARMcl+8cp3znv
94cnaZrmO32/933O8/yO4VB8RIyXRqOJmfko33KN4oDriN1j0CEqt3XKGPUU
zViUeuGhAU36rLFdTSMwbpme/CzxC/jatzxL9h3B/m3fWs/Xr8HJUB9HRYIb
bn3t8cVvQtHZoaxhhBtr5r32hCNYFBzGee8Fa6vqtkKpps8aQvSywn/91u/E
TLGZii4EngtIO/X5HoQp5UJdWJHU6P136z4UWZU1iE2Inb9KF41po1LQieBs
L3uV7yFEiAadOGpaYdSaYyDaszvw//XDYeWX4yDK+ThwqdiTPq09gaNiDUCX
6clwXDkJZdrc1n5cDSnYXv39aYhx9f1ocS19mmxNgkkM3IfyuUGhRYEmyHK9
CLqWY3b4pGG1WL0oebt3Yq0tA1dEwScY+61u/IfZmRhXxh3rwYDB/dFu80V8
IwbuQVbCxEJbZA4qlXIVj/HnkkVfWXb8DHkej3F62JqampLL+nchrXx0oXf8
VYjtCZ2YpsGD+evyIOQwdiDIHEUH/fPxXOj5EF0B+f4/Lihg/f6CI6J0IMrP
yno9gGXKNrBx5S+sTzsCczSZd/YWsx5/4HjDPyUfZJVClEtuQ9J43M03Q2VY
Jeb9HaVh2cuyp8p5vhbQkea8em0Fz3MfPf31Z/7TV3L/92A7u6azIbiK+72L
Dp3z8Kbl1SgU/TWj+/Jsz/iS65gr+mmEe0N7xmKvGqSI99/GDq33UHhfDb/v
FjrP/fRCY77B9e2Y5xrK/nh9Lde7ge4RnamovRZnxf8rEec5Ftu60YZfxf4S
lN2JuGW02JAunltwovi70YZu9Xcm0md9cqDupQ1qQtTf/Jze328htd59WZ/U
98nnlaT2Uyb7I7Vfud9O6jyv5Hykziv7v02qHqwPqXqxfqTqyfqSqjfrT+p5
8PmQel58fqSe55fyfCmRz1vq30bH2A9t0h9kYL9opX8oj/20R/qL+tlv16T/
6BH7cVT6kwzsV/YvTbKf2d+Uyn5n/1M854HzQS2cF84PpXOeOF/0hPPG+aMX
nEfOJ1k5r3LeXvLnPDtlvqmA8y7n76NG5kGA5ANdYl4wP2gO84T5QonMG+YP
vWQeMZ8oknnF/CI/5hnzjfTMO+YfzWceMh9pFvNS5t1FxDy9KPlKm5m3yyV/
6UPmcZfkM8Uyr6Xebnq+VfKc+U7rvpa8Z/7Tg3vyPuD7gUxOeV/w/UHalqZP
B/2jQ94ByflCaQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJxVVX9MlHUcJit3Uhbxo2EWihvsolrr16ZO+lwtIx1OOUs5IPqF18bcpCxl
Z2394GelMBUUdwnGdZuzDiQKTeI5jgNB4aaddIh6QOpqUB3FlInV4n2/z/tH
3+3d7d37vef7+Tyf53m+ya9vsW6aExUVtWn20X7VGsWStYlpqSlpyKvyXTPn
jcBz1RSxDK7AsaTSiaxjYbw9fnPBzpEMxHsyxhzxYeTeYi/w1GThrfToUGPR
JeyILykMZGZjoF9bF5Fe6pysX/QqHtQBL6Iks2Jd30ABNLSk0gtwX9n82JbV
hZgFm0UcRigSY2nKLsLTGlz6MBYvzchcHfMODtRp6zy+feg26915xbhu1gCH
0Ho11j6V+T6seoFDKNjw7rpcx4fQy/OEEHu6OjTcUgIdLjqEI3bb2EZbBez6
+gnPRJetsGz/DFq3Vb5BzCt/xD71STX0dpMG8Yft82Vpi/bM9qUhnkOXa8xT
+XcNFFwQE8+1HZxJrcMT+gpi/TZv/fghJ6p1wB+x8fKj3yQsbcBvWrsTZxEe
eGPfr6u+wAt6w2ex3LzLYSp3waXBNZ5B5b6sr6sibqh5nMHm7FCt6ePD5D+A
B9YWrnnF8hX07UUDiNoduGMwpQk6HeZ++GrmzN2ReBQ/63yeQn3q3NRVTS3k
rw81tf9eyHuplXz1Yl7YEpdv+o78nMTJglJvbXcb+eiGZ+fLD09XHocO5/Bj
Jjmh7H7rCTyu99uFxN3nvbb7fmB/naiL237EF+5gP158+b2t2rnGy/o7EHFP
z+9I6WS97VgYuPGU81on9uv1HUd4ZcuG+Sd8MOn1tKH5zem4P7d24T39/FaM
207dtTzJz/OOYiTn08rpNj/xPci3XOnLl27iHcZ0zsobwZZuFOv/dyF3a+Pz
f8X0oFnffxBVr90bsye7Bx/o3/fCXRwZDVYY7yXovb05ceGhHhgOMd75Xf6/
f68YeF6FL8Z56rtLjHoaVH1i1Kv2e8ToZ1L1J0a/qv5WMfggP2LwRf7E4JP8
yiT5Jv/i5jw4HznAeXF+soDzfFLNV25y3op/vzRRD36lD+mlXu5U+pFo6ulF
pS+ppd6cSn/SQD2OKn2Kn3qlfuVW6pn6lmTqnfqXIvqB/pBd9Av9I0I/0V9y
mX6j/ySXfqQ/JYd+Vf0GZYp+HlL+ltP0u+r/nFxnHixW+SCxzAvmh1iZJ8wX
aWfeMH9kCfOI+STbmFfMLwkxz5hvMsS8Y/7Js8xD5qPMMC+V34fld+ZpmcpX
6Wfepqn8lXLmcUDls9yToPJa8X1JIsxz5rvUTai8Z/7LP7+o+4D3g3jXq/uC
94d0mPuXBRwftf8HNIpSLQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX1Mk1cUxokfCWJNNhUFNUyxTXAuxQ+MxuFOYha/EkksaDRjmWAqBsKG
YoiwBj9RwZCCGhSjiIIfsFhxVayKPtiVKEqR0kILKtYtGVmqmxFZom4w3nvP
/WM3aZrmvT3vOc99nt+dlf6DyTwqLCzMPPLRvuUK4tFQ3YyoTxORanUOxqW+
wI5jB1ouDyTBEVMUWufow87h6khr9SZMtq18WTC5D32lurUbg+nYvizCX5Pz
HEt9R0MXIzPhbtPWM3z2fX5DQ9J2zBEFn8Ee0dqPlDxo1WKKnuJf4/nDWUss
GCk2UrEX3qndNa4je/GVVm5ZL/7MTDDoi4twqlJbPQhdTJt4yFCCv+O0ggEU
RBbPnZlrhUk0GEDHaPu4QudRiPZsfuj+aLqbsbgColyEH2/ctqzU2FPYKlY3
DhvKywtKq6BNa3V2QR9I6U+7fw5i3JguzDMsNw4W1eJHMbAPXw5ZSFd5CbKc
F7NzVy3vGarHQrG8eFuYHx1xx4YyUbAT5tjfrpq2XcMrbdyQB2P26owD1Xas
EgN78CFBt1kX3oharVxNBza8iiq7fcYBeR4dyNZnVuxOu8P6t8MzLnnLQtM9
iO05bqRvyfv6Y2MzhBxxbYgr2f/TpE1O/Cr0fIToRV3jr0xwsX6tCCtP2lXf
2cJ6PcTgxp1/HbrwgPV5gM1TjBWp+1tZjxbYt5pNL7Y9hihX4EJxfiiQbXJj
gZj3F4RPvzBvSuITnu8+SmMi13rKOnieZoyZan+avNvD/d/DP/sOfrsmo5P7
bUJJ1Pr69BVenBT93YKzMaFwzTQfwkU/NxG06ytvBX2wiPdfh3XF6+mWE138
vmuYu8H00pLYzfVt0JsNZU/c3VyvDle/yIm9vdqPXeL/tUie9PvZuyO+aBD7
qxD/zdj2Mx/92COeH0fdz46qjPgA/z6AXMcVY97qAFRC1G9+Tv/ff5xUvWZZ
n9T75PNaUv1Uy/5I9Sv320jN80bOR2pe2f91UnqwPqT0Yv1I6cn6ktKb9Sd1
Hnw+pM6Lz4/UeSbI8yV13lJ/Fyk/uKQ/SPlFJ/1Dyk8p0l+k/HZa+o+UH4PS
n6T8yv4l5Wf2Nym/s/9J5YHzQSovnB9SeeJ8kcob549UHjmfpPIq5/WSnvMc
kPmmRM67nN9H85kHMyUfyMC8YH7QEeYJ84UGmDfMH/qEecR8Ih/zivlFe5hn
zDd6y7xj/tE75iHzkXqZlzLvvTQ+XvL0oOQrOZm3n0v+UjzzuF3ymb5jXku9
n9Mw85z5TjeZ98x/es/3Ad8P1DMs7wu+P+js0hs31vfnNP0HtIROLw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcx2+u1iXhSugPzF3Q6oaiplLIivPTlKGVYTLcdMNN7XA480cp
5DyN8tdyYCCiXETmD0orA4QzAY23HNwQxh2/4w7kgKPWSgy2lq1VI+553vdH
z3a73b7Pfb6fz/t5v19PzNbdaZkzDAZD5vQn+K3XCMJbNvoyV6Qgo8D5R2zG
MHqLE16bzNuAWtOxe+tq/Uh7ddMhpFkRWbFq9ECkH8ufPrhq0eROvGOZ2X9p
zxAM5q/PrqzcB3d7cN2FZ/NRa827NsxTBe/i/pfGBMP1DxGsZjo2iJeq7Flr
Nx/HdLHpigPI2WELH+/Ow/JgOcsAvNbMm3ERp1D6SXD58PYr9WO/1BfjQWyw
oBetBZYtcyfsSFMNenEqwVk32PAZVHsV/fjzi1meQNkFqHIz+xFTam386UY5
tqn1A7Z/vyzflngFwWkLnH2wZ337TJH5KtS4pj589+bfKePJVbCpgXuR1fdo
eKujGrpcDx7seL106bbriFerB+aHLOsjMmpRqAp2w598PrLLfhPjwXHvdaHg
14qPF5uA1WrgLjyfjtSynEaUB8td6sTChU+FhR1pgj6PTkzlPnzY4HBRfw+e
KIyLKDLegdq+x42Ty75pX5nbBiVHbDtyfgtrnXrSjYDSsw2Hfix75PG2DurX
ipj0OcXha7qo1x04Uj+Kn93QTX1akLD1vaKWxF7q4YLr2Q1Rp+v6oModaMbF
ny/nnrb0Y6matwklZyrXX2n0cr5GpMY79tpWDHCe2+hsql2Sf2uQ/Tdgd/La
l5MWDLHfW9hu9TUNnfTDrvqrQ3bJuS7n0DCMqp8bsMyZKDfnj+Cger8DnjPG
yqm5o3zfNexsqf7L9fko61egdLFzze+zA6z3FVKqS9LmZQewX/2/HP/6Fx1J
dAVQpfafQ018VJJ5xhg+UM+L0b7rsm9JXOj3Ucxvj73qlTGEEhL6zefy//3F
Eqp3W9eX0Pv083IJ9XNe9yehfvX+CgnNM6nnEzfn1f07JKQH9ZF91Iv6SRb1
pL6yi3pTf+ngefB85A2eF89PzvI8X9DnKxd43lr/ZmmmH5q1P+RF+uUx7R+p
oZ/Stb8kmn4r0/4TG/04ov0pe+lX+lfy6Gf6W2bR7/S//MM8MB8Sx7wwP7KA
eWK+5ATzxvyJj3lkPiWaedXz9sgk8+zV+Za3mHc9f69cIw+iNR+kkLwgP2QL
eUK+SBR5Q/7IBHlEPslh8or8knryjHyTTeQd+Set5CH5KBvJS533ATGRp8c1
X6WHvJ2v+SufkscezWfpeE7zWus9JD6T5jn5LvdXa96T/2LkfcD7QbJd+r7g
/SHj7qrh/e+fSPoP0JNXfg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1GUcxy9n1rgytwPSliQVhFA60lGu9ONaQ2jFJgVko6050Ba1JPvB
j0MJobVL4lq0qamdgRV23TjCcYbzffwwEYGQH3Ly4+SXV01pri3Ajevinud9
f/Rst9vt+9zn+/m8n/f79UTvfDc9d4nBYMhd/AS/9RrHsRjrI/dOpiK7qvWf
uOxrcKx/7aPnLNlwRVXc2O7yIuOzwhKbbTfCHdsmisK9ODGUVufalY/8zWFD
NXvGEP3Y79kmYwG6u4JrFE2vrzbO+PZjrSo4is9jIz5+sLocwWpRFSNImnvT
5DRYsFhsseIwZqpWpW2Pt2JLsNzmYbx0YJ2/7cqXOHI4uK6iOfNcQmnEIczG
BQt68Ma0pXzr3FGkqwY9GDl4fKot+QRUe44h3J9oL9n0QS1UubAhZJV9H7l1
xQ/YpdYVDJS9f/LRaDuC01a1DmKpuch98NV6qHGjBhEw+uYOTDegWA08AG/h
0kiH6zR0uX4srG3Z4PO4sEGtfjSZd3RXppyFVRXswzvz9tSkO924GRz3xmV4
T6XXblvRihQ18GXUnM94ypTcjtpguZpeBJrGuhu++xX6PHpRn+pLaki8SP17
cOtmzvI7fJegtu/pxrH3CrN9LT1QcsR1IWdfR0rxRC8mlZ6dWBmbkLhsbx/1
u4jfwmz7vjUNUK8OzCc7lhhaBqnPBVReyxzMLxiiHueRaY+x/p10FapcUTsM
P97VGX97GE+qeduw5u2OwcLmUc7XAldOx8+GIi/ncePxZpcla+U4+z+HBz7N
fahuZpz9nsUz9jJ33y8TOKT6O4PwyhcXnCWTuFv104QvOp1fPbFxCmb1/kbE
pnQZZXSK73Piz5SwqIW906zvQMDsX267Pc16dTi5v3B3dd51FKj/16LR/6G/
oOM66tX+47BGhC9LuM+HUvW8GhXmvwKdW0K/y5FXeumFlkwfQgkJ/eZz+f/+
agnVc+v6Enqffl4roX5suj/5l/3q/Q75g/Pc0vNJDOfV/TdKFfWgPmKiXtRP
NlFP6iurqDf1l3ieB89HTvO8eH6ymue5UZ+v+E/p89b6t8vL9EO79odY6Jd7
tH9kln56RftLuum3o9p/Ekk/jmt/yk76lf6Vw/Qz/S0z9Dv9Lz8xD8yHLDAv
zI/YmCfmS0aYN+ZP3mIemU9xMq963n6ZZZ49Ot/iYd71/AMyTx6s0XwQf7Hm
BfkhF8gT8kVSyRvyR8LII/JJesgr8kueJ8/IN/mGvCP/JJE8JB+ll7zUeR+W
wKzm6Sear7KDvI3X/JU08rhH81nOxGpea73H5GnynHyXcovmPfkvxnX6PuD9
IFkP6/uC94d4v87I61t/5Nn/AEeAYO0=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlW1M01cUxhETJypsTkzUDyC6kEqmIVN8GcODWxB0TmyRSAq4hPiGL4GR
aRrU0AgYsixKJhBlOJxUIlPRTRswMh4RnFZobS21pQKtaNQoy0SRxA+68b/3
3A+7SdM0/9vzP+e5z/O7MXkFhq2hISEhW8c/2rdcQdSfNCzUdX+FnKM33uhy
ArCHmd7muzLRGlX+Qt86CH3Cosy8iDxENqc+LI4cxIHfPvwkuWYnvkua4m0o
HEBmeMX0opwi2Hu01Y/hlAWrzxlNWCAK9iM3Fj807CiBVi2q/AFKRqeWrLlf
ivFi4xX9WBg7+/yksxVYqZVL8kN/5secUTqC2hPa6kPW+oOxE7N/wphOK+iD
wfttvm16DQyiQR+SXqcGjuhrIdpr9sKE53vDdPUQ5aZ4kZE6N/Cz/jS2iXUf
I88j0mp2nIE27dEbHvgOex3PAmchxo3yYMZY3LEN7eexXwzcC8tmu2tm+SXI
cm78NfPEP42P/8BisdzIiC7ZmG+2olIUvAdPkWPOPmMrhrVxX7hgWBZmzfr+
GtLEwC5s7gptfeNoh0Ur1+CE//aEGSsSOiDPw4n43Ji34fM7WX8Hvv40Izku
/ibE9kI7HpsPjq3MvgUhh64H3aVDr/aetmFI6HkHq/qMhbsn9rB+NlTXHYuP
3+9gvW4j9NCjtuhSJ+tzC+veP5212uliPW7i8qqT8zvmuSHKFXdhXWVLx2RT
Lz4T83ZiWnXBlly7h+frwLIvRwzOaC/Pcx3Pxlxl3+z2cf/tqE00P2m82Mf9
tmHF8k3uU0/8OC76uwrb39ayf8P7MVn004Jd7da46nkDOCDefwWOTdnGDTGD
/L7f8ar+7r61HwS4fjNGt1xo8bgCXK8JkU3vlqZQECbxfwuq135U01QexCWx
/xd8XHHoz8RrQZjF8ypcPN623RBQv8tgacxC8UgQKiHqNz+n/++vIlXvuqxP
6n3yuYVUP6dkf6T6lfubSc3zUs5Hal7Z/xVSerA+pPRi/UjpyfqS0pv1J3Ue
fD6kzovPj9R5LpHnS+q8pf5dpPzQJf1Byi/TpH9oAvtpo/QXVbHf6qT/KJn9
GJT+JBv7lf1LQ+xn9jetYb+z/2kR54HzQV7OC+eHjJwnzhelc944f3SP88j5
pHTOq5zXTZ2cZ5/MN/3KeZfz91IE82Cu5AP1Mi+YHzTMPGG+UDrzhvlDBcwj
5hMtZl4xvyiNecZ8o/XMO+YfJTEPmY80m3kp8+6nPczTw5KvlMi8jZP8pW7m
sUPymRKY11LvAVrOPGe+UzjznvlPKXwf8P1AlXXyvuD7g+o/t1ozn5q/+A9M
51X/
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcx5HZpoxNuGA1N0FyEQcMM+4fMPhoy2i1SI2yJkHWgA1dB8wV
kYgrQKgmuhFBIOC4+DV3A8I84OINxzmo4ML4TRwKJH+AMdZWW1kU9zxv/ujZ
brfb97nP9/N5P+/36wl523w8zdvLyytt8+P51usuLrhPhE+OhyC5zPF7WPId
1J9MijRfiYYtqGj1mG0ev6zneXsHH0KANWEhL2Aeiff+Xt91LQHZcT5TDVlu
1DsCz78UfxQjw541h7dMe0tDc16FURWcw+JCZ+r6xZPwVAsq+hkP/1s96fPy
KWwW26w4i7qMPf4DmWmI95SLm0XOi0bDj2GZ+LLKs2aw/y+7z0a1GX+EeQpO
YzC/yeR3PwfHVYPTaLHOJa7lvgfVnnUKldszug4W5EGV85lC1EhMw+DOAqSr
NYmOd0+d6fD/CJ5pyxwTOHgifTF5tRBq3KAJNH81v7T9kRJ8qAYex2cXfR8/
V/UpdLkxNB9+4dF975chWq0x7Ps4o2lx5gouq4I/oeqfDd9YYznue8ZdvY1p
02uBba0VeF4NfBsV6+7imZQqWDzlGkbRb97h6DxSA30eo3jjzNTyFyl11N+F
Y0s9z/olXYPanjWCpUtnhwx+DVByhA0jp/nGrxMLFiwqPb/H0O7lYPNgI/X7
DobYUHthbzP1GkJdnD0m0dlKfQaxP7LYVjFxnXrcgvcrn+x2rFmhyuU58YGr
IWWlqA1PqXkH4DKeXokvb+d8/XgmOz3CUN/BefowGr0W+qDxa/bfi6ydDyLz
GzvZrx29/cZi/5obqFT9dcH55pL7QNE32KH6uQnHvdKod1Jv4px6fydOt99a
OxRm4/vaMZwVEVvitrG+FQUm2/XH8rtYrwWBZml+8qFu5Kr/W9Ca+qfdcLYb
bWp/Lfp6l3/LHurGBfW8HNaSWttz23r4uxC7VoKPzO/pwVZCtn7zufx/f7ls
1evT9aWF79PPLRLAfup1f3Ke/er9VvmB86zr+SST8+r+O6WfelAfGaBe1E++
pZ7UV8zUm/qLi+fB85HDPC+en4zwPE36fCWX5631d8o2+sGp/SFR9Iuv9o/U
0k9J2l/iT7/VaP/JIP14V/tTsulX+lcW6Wf6W47S7/S/vM48MB/Sx7wwP/I5
88R8yRTzxvxJJfPIfEoI86rnHRML8zyt8y2lzLuef1ws5MFezQeJIS/ID2kj
T8gXCSdvyB+pII/IJ2kir8gvcZJn5JtEkHfkn5jJQ/JRqslLnfdZ8SdPizVf
5Q55G675K8nksUvzWa6S11pvtySQ5+S7zJH35L+U8T7g/SApvC94f8iljbzL
T9gPPP0fGP9S0g==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1GUcxxmTZpQ0CoQA+VGjDsVyiZFOfNf6gcacoWGKsKkMkrGUrAWj
bNTgcslC7KZIihCsRsZBjAQu4kPHBUhAHL8OTkGwsD+gMBrmdFTc87z5o2e7
3W7f5z7fz+f9vN+vJ+zgkZ2p7m5ubqmLH9e3XhPy/lxbesD4ZiQVWucNSdfE
0/7ljYDZHWgMzp+ObxwXv4m3LvgaE+Fjjp3M8RmXo5G7V8aeTcGbMZ6Oiswx
+ak964ONazLQ0+1aV6XIfbr0bd+jiFAFr8oFn5nAmdez4KoWnH9Fyo2PGwov
HsNiscWKTmkIiYp25n6ILa5yMU7ZkVcc/XSHESVnXWtUArf4mZ5oPoFbBlfB
EenelvNLmOUkdqoGR2TqRITPMXcTVHtmh9i9Xjkcbz0DVc7TIYbcomfu8ziH
NLWGZd2Ky+H+GWVwTVtoHZKm/bL+TGgF1LjBQ7K2p8W7yPAF3lUDD8qDQ6Fv
xB2vgi43IJ+nHw4pe6Ea69UakNn6/ZXTtbU4qQr2S+2NS2b5sw4zrnGn7QLj
d7fD0r7FVjWwXZKfG/G/7tWISle5ij75LNvHa8OMBfo8+qQs4ff+8oXvqX+v
hJQ/afu7rBVqe2aPzE2k3fx4nxVKDkO3TGbXbPRfa8N1pWeXmCctPZaH2qnf
ZSk5lNbiv6KTenVKQE3B6MGVXdSnQwq/8vZ6LbKbevwo8/mlxhfjeqHK5dik
yePQ1oLoPjyl5m2TzbHDVTXb7JzvB1m1Z1d59d5+ztMqXZa73stTB9h/iyTf
fXbDmvRB9tsslvie9qyUIRSr/prk04SMO9vjh7Fc9dMg9zyw+h//dQ68p95f
Lx6P2toSFxx83zcSV/dIR8OlEdY3y617/8pzTxxlvSpJXvh110tTo8hW/6+U
VQ8fSLDvdqJW7S+V54P2RsdUO5GrnptkqjD8+Du/Lf3Ok8i+22nWZVewlJCl
33yO/+83Yaleq66PIL5PP6/EPvZTpvvDPPvV+814mfPc1PNhGefV/dfDg3pQ
H5yiXtQPTdST+iKJelN/dPI8eD4I4nnx/LCJ5xmlzxcNPG+tvw1z9INN+wMF
9Mv92j/wo59e1f7CafrtnPYfvqYfJ7Q/MUa/0r/4g36mvxFEv9P/KGEemA+c
Zl6YH+xhnpgvbGLemD9cZB6ZT0wzr3reAZQwzyM63/Bk3vX8gwgnD0I1H1BH
XpAfiCBPyBcEkjfkD6zkEfkEB3lFfqGFPCPf8G+M5h35hyjykHzEefJS592J
I+SpUfMVmeTtas1fpJDHvZrPyCSvtd5j8CXPyXckX9O8J/9h+lnfB7wfcGpW
3xe8P1D82B3DJwc+av4PwJcb4g==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcx8+yaU5sppmtuEFiAf2RU2Zr83jP0tkgUn6MfjGduMNaluh0
BSpaAtv1Q8gfpRguO1wR43YsFpSXH71OibyDg5P4jUCJyl1WIygHzO6e5/39
o2e7se++D5/v5/N+3u/XE5u7PcN6l8lksoZ/kb96DUqFd+X41bvXI6fMPR6f
c1UWPePa6lm6GY3mkmB644DMXxW/+p6CbVjoWDdUuHBA3o7xtTtn7cYOy5xO
e36/dEzlPbs4bh983sjqkyeC2Wfe3XIQCapgn1xP2TTU9IANkWrmkl4pGOud
sjaXIVwsXLFHMotch373H0FypJylR05NXsSl3OOoOBFZ3bLYE7uz1VGJifhI
wS55MMb+8FvXTiNDNdglQ74l943mnYFqz9EpKdWzXnZtrYYqNyf8nNLQH/V3
LfLU+kUm/Q+9Mf/DOkSmLXN3yIaaFaYF+fVQ45o75EDINjFe04A9auArMuDq
fv3FtWehywXk4JpP/JtXC1aoFRBz9Fh6RvsFlKuC7ZKVdnl019MehCLjBtsk
PfjpeHHnJTynBm6TuH77wKbaZlRFytn94st4bH/yWS/0efglt+vk8g0mP/Vv
kUOONXmPnGuD2p7vk9jbr07fOhaAkiPeK4+uPdJtKe3AsNLzZyl3nmic+VEn
9WuWrxNGStxfdlOvn8Ts2phQEOilPk1y46uUec65A9TjopgPz2hyPT4IVa7Q
I/tL99b8kDqE5WreH+UPW93Nqe3DnO+ClGf/ZRn7+FfOc17+CSXt/tfxG/s/
J3eS3Ulpnmvs1yXvR1vbl7aO4Ljq7zt5YUvLzG+91zFb9dMgy3YsS7R8fwN7
1ffr5c17C3vvP3aT36uTp6Jm7PvmlVHWd8gXOVmF3tlB1qsW2wdFPesqg3hH
/X+VLBjc2Je9KASn2n9K5lUMr9+zM4QD6v1RCaY2vFbmNJ6LJS3u+bbLrSEY
CTGe+R7/338URr3zuj6M7+n3VTD6+Vz3h9PsV+93YCXn+VPPh22cV/dfjyep
B/VBGvWifrBRT+qLaepN/THB8+D5oIznxfPDLZ5nkj5fFPG8tf4eRNMPHu0P
jNAvc7V/EE0/ZWl/oZp++0z7D4YfB7U/YfiV/oXhZ/obht/pfxh5YD5g5IX5
gZEn5gtG3pg/GHlkPmHkVc8bQDHz3KXzjUHmXc9/Be+RBzGaD8giL8gP3CFP
yBdkkjfkDzLJI/IJo+QV+YUY8ox8QyJ5R/7BSR6Sj7CSlzrvPagkT0s1XxGV
qnmbqPkb1kPzuEXzGUumNa+13v1wk+fkO6rJe/IftbwPeD/gdou+L3h/YFeV
/aXcycOr/gNqhDoN
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX1Mk1cUxgksC2MlmU43zRYyZToky8y0ZGwMH2MW2JJlKHSiBIcwRf/Q
DaYwJy6goG46gQkGQTRoa7Qxq7JBccx4akWpUlAorNBaBn4RP8ZXtdipKO+9
5/1jN2ma5r097znPfZ7fnZHxbeLqwICAgNUTH+Vbrj460J+eFe7XIbXE+jAi
9R8ydlXaXdo1OB22/d6S0730SmJhQkX8BkwxxfdvntJLObUPDb35W5AdG+LU
Z3kof8cc3UprIVrtyrpGiwY7oq0JuzBHFLxGFQttR9KDf4VSLWy7m9Le/fyF
6ZX7MFFsoqKLztk6k/NHq7BAKRfrInPm7ICfK2pQVamsHsrT7B2pjjLAF6EU
7KappmnHSzOOI1E02E1GZ6g75r3fINozOWngjfqvftLVQpQLcVKaSW98kF2H
TLH+Jvd/u/pujjVAmbbE2kWRJ183twz+BTFuWBf5WqLisudakCcG7qSU5aVv
Pz1mhSznoNyewTr9qguYL5aDamb4X9y31oZSUbCDSnRvfveDuQX3lXHvtdOC
jKJXkxZfwadi4HZKtIxvPXmgHQalnP4qlU4a3/m43gF5HlcpSte4ttHXxfq3
0fvRhj0vr+iG2J7VSkvDLyfnDLgg5Iiw0wb344PuMg+uCz0vU871oFVn5vax
fpdo2Wu/PFmn72e9bBT3QUTy0MwbrE8z1RcUT+49cZP1uEB7voj5elvMbYhy
m5tIE6jx9LQNYJ6Y9zwNFxcmHcq4w/OdI3NY6vkE712ex0JBQ3HvLPzxPvd/
lhr/8AQffvIv93uGHtk3Fu9dP4T9or8/KbzT5J6eOYxg0U8DPXBm1y8PGcEW
8f46Gpts8Z86PMLvq6XQEn9MeuQo1zfR7BDbs9Yjo1zPSH6jtrnoJS82if8b
6GyufuMnK7w4JfYfoqqxWHvQQS8KxPNyCv/s4i1fs/q7iKq1Q5llHi/UhKi/
+Tn+v78caj2LrA/1ffK5AY+4nxrZH2Zxv3K/CRqeZ1jOB3Ve2X8dVD1YH6h6
sX5Q9WR9oerN+kM9Dz4fqOfF5wf1PLXyfBHK5y31b0Ix+6FJ+gNm9otG+gfx
7Ced9BdS2G/V0n/4nv3YJ/2JXPYr+xcp7Gf2N7Tsd/Y/PuQ8cD5Qxnnh/OBL
zhPnC4s4b5w/lHMeOZ84ynmV8zqQx3nulvnGSs67nL8TT5kHb0k+IJp5wfzA
HeYJ8wXfMG+YP/Axj5hPuMi8Yn5hHvOM+YYK5h3zDx3MQ+Yj/MxLmXcXKpmn
OyRf4WDeRkr+opF53Cb5DD/zWurtwZrfJc+Z7whMkrxn/mO3U94HfD8g7Za8
L/j+wO7xgo8aZpo+fg5ly0cX
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1GUcx5FrwsBRhpppYni6oazmQFzT9C1uBTbLJM66uiVRNFBb5GA6
7Ic1j0JWYoKiA6fBMqNdZ5wiBPfBC0WKnwFycPIj+jUHOU7garlh3PO8+aNn
u91u3+c+38/n/bzfrycy9e2ktMCAgIC06Y//W68hmVuVdtgc/SIsR1yTUZZB
8XZesa6qyMDlCOvI9ssDMuDcuyzu5WzMsyX8kjNvQHbnzx8tP/UB3tkQ0lOW
2S92wx/PVIxZ0dLsXzflVavjomfTp1ipCt6UjnPvBxt9n8NfLcLqkURTpSEk
vBjTxaYr9knknlkFS8JPY6O/3IY+2Rw7ZTYf/gKnTvpXr7wFj+nxki/hi/IX
dMvB9AWhO5+vQJJq0C0H4uyJRy12qPZsPZKw1RDjyKqEKhfSIxNtSy3b/r2E
N9W6IZn3GQ1r/66Bf9ojrm7ZG3qs8bFsgRo3olta4y9sHtzowgE1cJesDUqZ
PTXnKnS5Tmm3RC5fsfI6YtXqlO8WR24LO/ETClTBn2Xpuv42t7kNo/5xRzok
Gr8uGK/uQKIauEOC555Z/8p4J8r95cra5fuUe5+kmm9An0e7zBZrfuWIm/q3
itWbEbXjvAdqe2aLlG4pnjpbMAAlR1Sz7PdNlJ5sG8Kw0vNHGTZ8uM6bPkz9
miT+9Y8DUx78jXpdlzvNoxfzmn6nPo3SXjQ/99v8P6nHVQmL3bXFYboFVS6n
QWxdjyw0Lh9BjJr3B8kpu2V6YnyU812RoF2DD//lvM156uXamv70j+LH2L9T
whaZsz9b4mW/tVKYkbB4p9eLYtVftbiCF/ZW1dxBsOqnSoIyTkSm7RvHu+r9
Dvl6fUvO0ysm+L4L0nS3u+Ql1wTr2+Sf3Pufk62TrHdeUj151a2uSexX/y+X
1U/lT4UbfbCr/aflm65FtZY9PhxUzwulNLnrtbrSmd+HZNO+ooeOX/JhJiEz
v/kc/99fiJl69bo+Zt6nn5cjhf2c0f1hkv3q/TY0cp4xPR/OcV7dvwMG6kF9
4KRe1A9HqSf1RSj1pv5w8Tx4PgjgefH8kMXzXKPPF1/xvLX+DQimHxq0P9BM
v8zR/sFt+ilZ+wtP0m8l2n8YoB+HtD+RRb/Svyiin+lvvEe/0/+459R5YD7g
YF6YH8xinpgvGJk35g8PMI/MJ8qZVz1vJ1zMs1vnG1HMu56/C/XkwaOaD9hB
XpAfMJEn5Avc5A35g2jyiHxCCnlFfiGRPCPfEEfekX8IIQ/JR9h3a17qvPeh
N1nzNFfzFW+Qt6s0f2E9pHncqvmMvkDNa613P+ryNM/Jd6yu07wn/3GsXd8H
vB+QZNf3Be8PPLvshZhrd2tq/wOhvyWI
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlXlMVFcUxidg0kprjIg2mAAujUFj0Fi1pu3wdXOPGA1CUFxCFDUSxVaU
aBugZWm0SKsk7GoAxwUdB8EwCukBBNkEBQaZQWSx1ihDEYQZaOJS3r3n/uFN
JpPJe3PeOd/5vt+bFXZw024XnU63e/yjfcvTQ17Zhkkj9UEITal0+IZ206zt
0z+ltftg9k6wbzR3Ub0jqYjco+BhXNV7zKOLngZ71dv1MTikd2vPi3xM6Rdn
z9txKwGN97TTSa0hA4aFrsmYJwp20q7Ezev62k5Dq+ad8IgsLZGTOobTMF5s
vGIHXajzNM4Yy4G/Vk7fQY0T3r7ri81FZoZ2bBTj6nVkdYYBTl+toJW+NVkO
vQ0qwCbRoJXOJX3+d0S4CaI9YzvFOUYuLEsqgijn1k6NTTvj7J+UIFych2Ro
WTNQOrsU2rQplW0UeqpgpKmQIMb1bqOTiWe++21PJY6LgS1kmzbV/Pqbashy
rTQl+YPrlyJq8Zk4rZQSmzUYZW/AH6JgC+3KnFxqqriPfm1cezNt+CczZmis
GavFwM3kelSX2u5vQb5WLu8Bbbm9wNR24yHkPh7QL1+kLT4XaGP9m2gsw/1X
zOmEuD2ykcx/9lR85NUNIYfvPTo8vowGn148EXrW083iq9WWO09Yvzr6uln/
Jif6KetVSysmFvmUfvmM9amhq739xhC356xHNZXPmfDf970vIModq6KvdqZ3
95fZsVjMe4dqgqxzD2b8y/NVkC1slT7vh5c8TzkFvotY4JE7yP3/RVd+LrHe
jh/ifsso/sWWlc7tr5Au+rtFvqcSu6L8hvGh6KeEdtjXu78aHMZP4vnFdODH
gJ5l+SP8vELavzRtq99KB9c3Um0uBvosDq53mfbGG6YUBjgRLf6fTwGj/st1
N5wwifvPUvASn8uZb5yIFddTqfbADI/fF43y73gaCrJd81s7CpUQ9Zuv4/37
U6Hqlcv6UM+T1/Oh+jkv+4PqV95vhJpnUM4HNa/svxhKD9YHSi/WD0pP1hdK
b9Yfah+8H6h98f6g9rlE7hdq31L/Kig/VEl/QPnlY+kfKD8FSn9B+S1b+g/K
jz3Sn1B+Zf+ihP3M/sYo+539jzjOA+cDIZwXzg9cOE+cLwRw3jh/COM8cj6R
zHmV87ZiMufZKvMNK+ddzm/BCebBTMkHbGVeMD+QxzxhvqCBecP8QQzziPmE
bOYV8wt65hnzDdHMO+YfapiHzEdkMS9l3jvQwDxNlHzFNubtfMlf3GUeN0k+
I5l5LfV+jDrmOfMd15n3zH/0bZPvA34/4FqWfF/w+wNmT5fIgdfHy/4H6WxJ
Vg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcxy/UUrLWltNZdmFxg4NaJUhjKO8xXWTCMtZaMgZ0Zr/mgOh0
QCUMONYaDJYMpKnTSbncAJ1Cgu4+cFyiKSAcyHHACWYzBitQOHKBxT3Pmz96
ttvt9n3u8/183s/7/Xo2WjKT9gYYDIa9ix//t16j8nRic3fViveQUu6YDU25
JRuaTTsvf/EJLhhtE+9c8MofIc88+dBixZr6+LG8NV7ZV2quTog9iM+3Bg6c
zBqRhrdWNSx/3IbO6/41LMULUdeuGkthVgWHZe0HC93W7d/BX81oG5L7cbXB
qbHVWCy2WNEjva9PvLFt/VHE+stt9cj8nnWHBh+cwPc1/jUovgNlGfFzP8AX
6i/olt5h9/MZVaeRpBp0S3J+emHbeANUe/UDErDSe2xLwDmocoEDYvnx02/C
v27CR2rdlN3Fzy40ZLbAP225o1+iOgP/bf/NDjWusV/inHnhldNt+FIN3Cdn
RkIcVRed0OVcYp2JzI7p60CEWi7p2TKYmYJrqFAFeyUtMK0m2tCNSf+4Ez0y
ZR8KP13agzfVwD2yvKbGZrrsQq2/3MkbYjCfzfW8dBP6PG5IWERTZ36rm/p3
ScmjRmtIwRDU9qxOuXUnMPfVz7xQcoRel9CCssbn7KO4rfT8VRy+jPGK3bep
31W58r75RM6KO9TrirRv2xOzX36nPh2Sd2pXrqP4LvX4RXyTkXUxSeNQ5fKc
0ttSnm4JnsAmNW+7PHSkHfh4bpLztUlMkb0lquNPztMqLxaWpDrip9i/XYJz
PKl/mabZ7yVZNmjd5P1nGodVf81ivejK3tFxDytVPz/Ly0fXV8zY7uMr9f7z
EtRrNjVtnuH7zkq/ISCxsG+G9etldc6yRmv6LOv9JIkbMkI8A7PIUf+vFcsr
ETujo304o/Yfk7r8guTkIh8K1PNKKSsaqk5sXPpdLLllpqSsLh+WErL0m8/x
//2VWKrXqutj6X36eS0S2M9x3R9WsV+9vx4uzjOl54OR8+r+zyOcelAfZFMv
6odHqCf1xUbqTf0RxPPg+SCK58Xzw988z0h9vujieWv9nbhHPzi1P7Cfflmt
/QM7/fSu9hec9NsR7T/Y6cdR7U8E06/0LwboZ/obB+l3+h8vMA/MBx6E6rww
P5g/rPPEfOEu88b84W3mkflEK/Oq53XBwjy7db5xnHnX8/fhNfIgSPMBa8kL
8gPR5An5gjjyhvzB2GOaR+QT1pFX5BcqyDPyDefIO/IPzeQh+YgE8lLn3YNM
8rRE8xWH0jVvwzR/kT+vedyl+Yy6HZrXWu8RfPit5jn5jjGT5j35jyca9X3A
+wFz2/V9wfsD9fueCpvf3HrpPxQGLtc=
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1GUcx5ko5A/YRO0HONLWH2SgZVa6qW+0ReUvPGzkgszRIKJV/Git
YVN2JbDahAVtoA40KBflicYSFfvwqzoM2HkcHpxwJ0oFB0MBOXIuinue9/eP
nu12u32f+3w/n/fzfr+elSkfJKTOCQgISJ39+L/1uiHh59J317TvRXJR81RU
skfKvdtWXM55F/WRh0dM9W7JONeR9o/tIyy1vDSQu9QtsRvXb7e785C1aYGz
KrNfisvfMfelFaCj3b/65Pf8U4+tji7CE6pgn9z8Ys9o8ZpS+KtFHr4u6Y57
kblHyzFbbLaiS4at5u6ByUps9pfb5JKNi4Ibjp+uwtFy/+qVecOLPw2/dwq+
KH/BHkkMnAzeMfYDElSDPTITviTufvxZqPYsTql6eN8bbcV1UOUWOKXgwJaF
hS/UI02ta/J6TV/di9kN8E9b1NwtU4FDgQdLGqHGjeyWxp6IZWeebcEBNbBD
eo98mbb78V+hy3XJvq1dSRVvteEZtbpk2XiFKXG6HcWqoF0irP0Dr2TZMOof
d+SqLL//bcy1EjteVgNfldNNJ6/PG3Sg2l+uyiaXQuxjwSlO6POwieNypSUn
xEX9OyWx9+LyDX/0QW3P7JDPT6xJKfnLAyVHVLuYmrfcmikcwE2l5xUpnPje
89VTt6hfm6x8++Qu89Ag9bJKMkq+MVn+pD6/yb+3V8fGHBqiHr/I+cKJbvdr
Xqhyua3yfuXgm851o1ir5m2ReE995vqwMc7XJNGmwTHPyG3O0yihq7YFXXLf
Yf8/y4/zvV9vbhpnvw2yJOqhkLXHJlCm+rsgHndr2I6MSTyg+jkvcWHxD+6M
votP1PvrpPTvrIT5nrt831mJfT47IidvivUtYu3McFWH+ljvO5mL1EPeAh8+
Vv+vFnOZPeqK14datb9CuoOebln43DTy1PNS2X8mOEPSjd+fydzaC0lbzdMw
EmL85nP8f38pjHqNuj6M9+nn1TD6OaH7g9Gv3m+BMc8dPR+MeXX/dTD0oD4w
9KJ+MPSkvjD0pv4wzoPngyd5Xjw/7OJ5rtPni/d43lr/VvxEP7Rqf2CGflmk
/YMk+ulV7S88Sr8d1/5DPv14Q/sT8fQr/YsC+pn+xh76nf6HjXlgPlDPvDA/
qGGemC+EM2/MHx5hHplPLGZe9bxd2Ms89+h8w8G86/kduEgerNB8wDh5QX4g
gTwhX3CQvCF/cIw8Ip/gI6/IL8SRZ+QbfEOad+QfYshD8hHt5KXOuws7ydN8
zVdYydtVmr8oI487NZ+xn7zWevcjlDwn3xFE3pP/cAzr+4D3A4pr9X3B+wNz
yjccyf6wrOE/Y3E6oA==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103lIk2EYAPAxj1ykppYEkppkVqKJZ0H5EFEIGuUV/aHmkeaKULDCkOYJ
kX+4kefMsnKmQ5OhYt6vlqbzmHOXSZbHxCPPdLlpt9/3fA98fLy87/N73vNI
bFJIPJvFYp37/+3+6TCQwS5jJ6fgOPCiQk9UV0/9OTaWAglUbJF4k56zokIe
lAp34wfxUnMGovQ5MDy0Gzoys7TjaazPBdrTkcaGIjN2tQC9TWKeLsnOMy5A
b4NkX2vN6ysoRu87UeQ3mPAjnqG3Th7d/+piFl2O3jpJqpUkDYy+wvxV4i7y
0s8fFAE1fGiZRCaXpXXz3mC9JcKpOcEftBADxQsXyWS7Nze9vwa9BbLhWSEI
rKtDb44ErdV2wrQEvVnSXMjpKMmuR09LzFjOJy2hEb1pAqGd984faEJviizz
W/xSjZoxf4Kwqyzb8va1Qgk1fpyEOI9nfXZvh5tUPQ1ZsPp13Y7bCR6UryTb
l8yXJBFd6MmJ257M0Cd53ZgvJccdErxT+t/j+A/EWrL/Ds+sBwRUfwu5m8Q5
zAvqhQyqLSaV0Vpj+6cfgTnhx7q28J+aPnhJ9wNrIquq85AU2y3Q/Lw80Dt8
AE7TPpC4HVl07iD2S8Hxm6+zoGmImR9IIw2yqE/D4E3PHyovRNp2rMogkV4f
VLnK7FYMI1BGrx/2/k3k+qfJQU7vDwjWb5W92JQz+welmstGZfGjOH4a9ufa
pIaMjqKvBYfx2NdrvgrmfMDfR+JfV6TAenNgmFQYKdYVzPlCW8yIj+iiEr1F
EHp8mUkuVKK3BLoHJe05U0qczzIo2VkPXV1U6K2Crf1GdR1Xxdw/SK13mg2r
VoGMvp+QwdIGxGhVzP2FireObjZ2aszfgHdsv9+VV9RYbxMUfOGZ4Ew18z7A
NHYwN0CiRk8HLvPFs20TauZ9ge9tt4YxUw16W+Ceb2XR665BTw9Htw0r4jAN
egaQWd+IE6dq4B+qwtL5
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10nlIk2EYAPDNuc3oIi3FP7KyaX+IZSimeTwfHqTmARJiRVJqbqlLJFRy
BVmQCbUMDK9FCWZ2UGbeLV91Wioz5lEetDxW3rrp5rYOtfy+xwc+Pl7e5/k9
73UgPi36ogWLxfL7/238mTCT8oiYWYeYAnCnw0SK6w5xbTXlkESHkYiH7Zt8
7KugpHgjVshjS3bwces66FFuhIHUBou2P4qXA+MZyBaNX4/kTit6eiI7LEt0
s+5Ab5kUZnz46NPXid4SqfdMqatWKtHTEZXwqch0U4WejoR1TE0Et/Zh/SIx
NSdUVB38AnS6cp6ER+8XyV8NYr85ojQHNazFjQDNF8+Qu2W+6dZ+avSmid1A
+3eFYAy9SWLdfEUsVIyj94M4zYaLpRINehryIjl/WRD5E71x0ptVf3vAZwq9
MXJhuClsIWgG67+Rgr2K2IhLc1BE5w8TvXZVEFK5AIl0v68kOTHALYSlAzfa
7ydCpaTFxmsJPRXRrtY4u2QvY30X8TyTWz/Ursd8BSnfl6HdY7sC+fR8I1H7
T5SWphjhBj1+ToYkwilTmwk2b5hHRQVW2v+CJ8w8KEaD73mIf+O4Ecrs3OtC
3v8BL8aHt8ck+d3sVZzvgpxrasdZ/7XN9UGhiN/gkr4OHsz6gZMqG6k9yaJE
zP5gbQUyLw+xKBmzf3AQaE7kxLEpFXM+oBLGSfvVbArPD7Y9qO0WxVhg/jgE
3ve2PddpQTG+BibaMspH3TkU3g84ep9qdi3mYL9JiNhxK15q5qA3DWGZ4bLI
aEv0ZqCIUkmbKyzRmwO5/rTzEaMlrmce3gXanNVRXPQWoVq+vhCVy0VPB+yt
D/OKurjUZ+Z9gpfR7+guKx6F7xdW+b0LfwN4WL8MeVb6ZyXZPOynhywPV4HT
Gx56BohN5dj1j/HQM4DYfD10cCcfvRWI3p3Qed6Xj54R0kJ77EuT+OiZIPml
NuO1lI+eGT5dlbNaavjUPzZDxs0=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw10glI02EUAPB51DSNeSXlke6ykmaWVibI+6SsSAnS0swwsWViiLVMTCXL
LsMwRcNcA6UoD6ZkBqYJn2VpEy3zgoG3MZ3Hcurm0e3//3zw58/H997vfRc/
Nin0gimHwwn4/63+2ViiyedzTA8VvAYfJhZpgolS3m3fDHFMGKm5gldtFd8B
8uLVMNDaqzNeQdt7oKN9NRbow4/pUp9pNbDeAg3NjzYZNx1Gb55mhdmJPgWM
oTdHQ+RRrTsrNejpaav6Um9v8CR6s9RhqFlc56FDb5Y+WMrnZrnpsV5Hh+W1
2QUh88Ckt0/Ts8Exx/sVBuw3Rc+ke0jf2i0BwxdraU1yaciDVyvoTdCVAa6y
LPU3ehpqiI5yKt/HIaz3naaYuRUEfTYhrDdGO241GdfLzAjrjVBbs9BrOb7r
COsN04akEp7Ahov1/fQpb+VorbklecLkq2m4xS1aaWtFpEy/Phok5GpG924k
3ozfTaemLJSPk3jodVJpbGCu56AN1quoQrUt/L61HeY3U6VOkLYx0J7kMfP1
9O79dX+U1x3ITWZcQSXfujwlbzaRtRv+/aOm5aDOkZSy85C54VR5lXgzjuvB
2MbZe/j0FuLH+nBif/wz5ztOOK+CTJ0+8UaZ89r64N47rZ/Vexfiy64fPsgK
jdVfXUk8uz9InLReftG1lSjY/UPJ5UZ1isqNdLLnAx65Jw8YIt3Xzg9yZVa2
Jip3zB+BhJ+8OuNuPvpjQDK89H8L+Wv3A/72/kNhc3zsp4FHknbNnmMC9CYg
4vZA0JhCgJ4WtKPLwdWTAvSmwL1aLRn0EeJ6piEiuyqmMVWIng7OVcxczKsX
ojcLRFbJKTEKyRf2fYKFs2PRDm8RwfcLuwTphsQ4EdbPwa+m7K0vi0XYbx4s
RRlHLNpE6C1AjAtX27IoQm8Bnl9RD9kIxegZwCiLLrINEaNnhLRxub9eJkZv
ESJdPSd6isToLUFTn9f4YIOY/AOH0rjB
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10glI01EYAHAP8Ih5tYZpBM5psUqdzs3Nzb4nUgSSWGJppaaYrjSP7LDM
FMPEozzDAw1FywNMy7uMh4igMA8sTM1SWYpXOnUeKdPy/3/74M+fx/u+3/cu
dkj05Vs6Wlpabv+/gz8d23jH+2+gPqcX+FRsYc+WMV5n3yiEUbGJU9oZ3AeW
CigpPogNrMgxq+byFqBffhAq3KhbXVswogTaU+EGh9nuErmKeOvYhSG+7ru3
Tbw13OQTZeURoybeKo7g+UWXMLUR7Slx1pRv6YkCXUR7SswB1o9nUj1E1y/j
udO5pskmhohKly/hxPi0x7amDET3W8Ti3raaJHcTRPHF81jYHNjq42NGvDks
Z+8P+7KZxJvF97tK06QMFvF+40epqRkBLHPiKXAb52LeuJsF8aaxWuAuzHhx
jHhTWF3dk/Bz5Tipn8BVa59fT0utUBGVP4ZtD6VH9uSyUSjVbwRPlo3yZzas
EY/yv+LoO3q9NjIb4g1he2Zdxe6sLanvw6bBli4PY06S/G68Ge8tBh0uyqHm
O7CghjfZWHwKJVPjWry/nnnuD/8M0tywddn+4G6/HSqn52Fl5m7LXKgDGXfA
kOHR4dUnPCSifWji6vvZgSOZ74OKAHWT/p6jZn3wwetaRF6rE3Km1w/+R16a
MWV8JKP3B/XPw+x1DzujUnr/MGhQeMmo2RkN0ecD4XXfzQ28BJrzg8psN+XK
pIDkT8NC0JWAqdtC4isg0qfggtGSUHM/8K4mZLgzzIX0mwWPuP5f7uMumvsF
VvmNhK3zIuLNw0d1u5VbvYh4i5DU0NQVZyQm61kClue37N1wMfGWISC21d/p
i1jz/kCSHhx+z8gVDdDvE+xqJj+Z+bsi8n6hqvDVm+ByV1K/Bsx8UdR7hSvp
tw4pY4mZwJEQTwUWorOxV4MkxFPBcmX4BL9IQrwNeLszqGM8ICHeJjBu5g9b
akuJtwWipwpBpqOUeNsgM/b1ywqSon95wLOh
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wsslVEcAPB7iSlLMmld0vV+zCuXurPsf9B1ue5FSVpU87rIWihSei2x
FarJ65JYCZFKDVOrE6l5jyl2Wy3ySl43LteoxPed+9++fTs7///vf853zmcU
dvpgpAqDwXBde9bfdCzhkX+agRrnpMChQoHfTs8apJj/AjEVi7jBRqEYMpdD
oWQ9FnCtu1l2RckKdHWuhxxn2EYcz2xmItqT4yBZRFLNrBqivXmsxY47VBS8
CdHeHC6JF09paW5BtPcb+70z/ZbB1EG0J8Nd2i2fssp0ibc2vsgwPBm/ndTP
YDcVfblJLAtR6Z1TeHyzwvF7zk7SbxILA5n5k8lsRPGSCdwbZlJZ6W5MvJ84
/kC6O8/KlHhj+G97koOfnTnxRvClyKosToAl8YZxTOMNqbXEmnhDePlp4jYj
pi3xBnGtrmFIYYY9qf+KyxpaUwUGu1EBlS/F091pFXWpjiiC6tePy9mqucEr
HORA+X14T3OemuE1Z+L14IEaVadTentJfRtOM84/5lXPJfnv8YPQAm/PEy7o
DjXfiCveRNmVa+1DV6nxY3w3xYMd3eSKlCdclcfWjT0LqJSeh+Ku5X7PbETG
jVBcdjMkKsoNcWkfUnTsrZy57mS+DdQW058nq3oo1wf+4oRJm1YP5ESvHwan
PuSkpu1H0fT+4Mn5pBejLjx0j94/jFazlmXjPNRDfx/wleZ9Scj0VH4/kGr7
a4RZ8kn+ECRyeo8OvOYTfxieScofqfO9lOcDZ3asqnPbvUi/Mbj9Uqpo4nkr
zxfCaz+7bXjlTbwJcKr/MxhuISDeJOSOmrTwbwnIeqZgF4sXoDcrIN4MFE8E
3ucIfJT3D8xKc/UYpT6om76fkHLkcP2AzEd5f6FD++Hlra5CUj8HMc7LzqvX
haTfPJRE6gdNtwqV/wcEcYKMTTaKiCcHX1brxx88EfEWwLgvsCjmioh4i6CW
LA6V1YmIp4C4C42Z1RMi4i2BxM8iq4Pli/4DuYyzEw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw103swVFEYAHDVH5nk0awQUSGyplrP1hi+I4+MMF7L7hbFqPRgk0dEMsYf
TKYwGFto6UUPNam0yZyilxCVHqqJ9Vh21mizyzLVKPee+83cuXPmnO/3neem
BFHEgeU6Ojpe/7+lPx3zeLKpoPvjJTm4UKHFxbovTod6auEgFXO4aEV77Ev5
MnRBvBSzOMtmc1VusS7q7VkKDS5pOTOYXmKIaE+DLbkcSWoOC9GeGgtF28wD
kkwR7c1gi6KOteOlFsT7hfOtf5e9XthAPBXeGS659y3SmngqbJvhnC3rsyX5
0zi5OrRXkmaPqOE9U7iiQXZoxIdN6inxgANqLfTaiiherMB1yytdHrlyiDeJ
1cYsZ78xJ+LJsWUa3+NNswvxxvCid1tHeaUb8UaxSFpcKxXvIJ4MF70adl73
xIN4w7hiIu6y819Pkv8d/+A4NrBivVE1NX4QL5SlvK9NRiiRqvcJC+oECT5t
PohD+R/w52sttwtMfInXj9eX80f08vxIfhfewtY+tVb5k/Gd2H4fMrpzZBcq
pfqlODtzKjZQGYjyqXYTdh3pzw8SBSHmhGUBg7yf6t1IQvdD+qJCdDQzhLSl
0KivMNDThCIu7UNnsOdeO7cw0t8FJi5l4hxlGDM/aDg+1GRcE45c6fnDsWde
J5wCIlASvT5Q3R1K9FVEoBp6/RAPU/XKwkjUT+8PRCR8HZgzi2L2D8J0Lati
rkaR8TL483z7mo1sHvFH4Vz4zPmc6zzmfCBVvyu+0TKa1JPDfrfSwzMl0cz5
gpV24mTzbDTxFHCj9cspd34M8ZTg31ybJb8fQ+YzBe48L2S+mk+8aRiLOfvA
MY7P3D9QckNqU2/y0Vv6foLMQNbnreEz9xfK69rbZFwByZ+Bi4ti2yvZAlJP
DeJbeYbdDwXM+4C4TnZflUpAPA04jM/a+doLmfcFWRn1uSv3CIk3B6vSk1im
JULiacHIyiy4/rGQePOQUmYz8U4uRP8A5Hi9OQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtIU1EYAOBVUuGLslQ0TSXzsVE5rTVNOWf4yBeoa+l8VHObMbUyISt8
VIiF9DAlrE1NLaSwSEJnoWRHMV9ppjZDUXRmvpi4zc1n5sp7z/3hcjmc///+
c+4510mYxk3aTqPR/P4/W28yVlFVuaSxw00LvIhYQUZ7UhKSyrfBi0QsI+5A
dkCZiwkskW3FEooe3QxilFrAbz1boUeHTjTfG1BZQ9LTo+dGmq66+/aQ9HRI
q/RfGfzshL1FZJ6skuVNOWNPi7yHDIZ2XzfsadA4J0LG7mRgT4OMY3Nz3j04
husXkH52/eSzNiYk0nvmUVq6VnFzygv3UyF+GO3Da1cWJHjZHPJ+0/OUX8DG
3ixq6YgxbzpwCnvTiLNa+VXX74e930jVWL4vMxZibxIxzF7wfJQc7E2gq30K
x+kcf+wp0QaTJZrxDMT1o+jTdWcN1xAEpUT+MDpTdYuv+BUMxUS/n0jXeqO7
ZDQUehD+DxRQcNQ3RBWOvT5kd3csfN40Atd3IceINVZ2RSTOb0XuTX92uqMo
WEjMN6CmpjHe+0kuvEOMq9GVI6GWViY8SJ2wdxgrhON1FlaS8+CVfFy0Ny4a
jxuAjdXpiGs5MZBN+uCxratZVikfz3cBZo0bPbU2llofEC7W1XQ3x8Hj5PpB
aV7g0KW2eCgh9wcmhoRPUlACLCP3D3bXLQfTa87BPvL7gH413cArOk99P6Be
l9O+Sy7g/AnAXJPZxdgKsD8JtPUSZ2mmgDof0Bnmks8fFOB+02Ct1s6mn55I
nS+oGNs/xclKxN4cuJ3iwFK3J2JPBdghlh4O5kK8nnng2mq8YR0lxN4CyPcp
vnywUEjdP/Cos9c0o1sIe8n7CYT2h9Ljd4io+ws2FYwRM7YI1y+CssiHm1+S
RbifDuilqep6qYj6P0C4/KW7RZsIe3pgMzNSvUtNeUvg49+3Fi1WYuwtA0/5
4eEkXzH2VkDmcFGGrUCMvVXg6KcspuWK4T8q/78K
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1030s1GEcAPC7tBntWNlZ3ou87Kwmd2SanicvSVlxhA6r4xx33Nws1dpl
LrNdpYWmYZ0MZZG3P6IrPDOVyMsNI7mScNFJ5+28Lcrv9/y+22+/PXue7+f7
vB5OSOcm7aHRaH7/v90/GevoV8aimeMnA2ATsYbKvuQ67wiNoZAIAzKXHnk4
ZHwAlpbsxip6FgDtdK8Owr7e3VhBDdsWdyTvHCDprSB99WJkkNIJkt4yqurx
96Lnu2JvCeVlW3kXtbtjbxHd0xjJWi09sKdH/ITO0tdST+zpkbrA7eeHPxyc
v4BYhpe8wscnIDG8dx6xHLxippN9cT0dAqqYi0qhHyT4kjkkH+nTD5+D2JtF
oeYNnze2TmNPiwKlsTKXjwHYm0bnJ3JNaxuDsDeFhPQBTn1zMPYmkTHfhWM1
HoK974i+6VORbR+K8zXI1xA/byq/AIuJ8WMoq7pyhiUPgwKi3giqNAnLqFeH
Qw/CH0ItklNsz2MR2FOjRa44NbM4Eud3I5qwp2KQEYXHd6KdxgV2YF40zCf6
VchGErKQvv8yzCbaLxDXX16gKuVB6oRHYyO3eM5xsJzsBx17V5nZ9fG4rQID
22EMAfsK9CF9YBvXVNAccxX3dwMFXxLlaMGn5gdsawarVrr4kEPOHwzUhNvF
X0+AKeT6gFvPrLrNLhE+IdcP6hTlrJq2RKgm9wcw7Y4HT10SUPsH6C3WCq5W
gMdPggftMx5G6UnYnwJcQU6HjT6JOh+w53Za0ahIiOtpwbib9JBcI6TOF/y1
frSedjYZe3Pg9xizdbUuGXs6YOuq6L3JSMHzmQdzw/d7IpJTsLcA3N8rWn68
TaHuH8gxWyvP2ieC/eT9BJxt3zeyKBF1f4EmdLP3qFKE85cAwztB93VChOst
g6dOmRHD9mLqfYCyEHVmBE+MvRWwcesMs6RQTL0vcM3E8ca3LjH2DKBJO6GM
2RRjbw10Pu+/68NKxd46sGw4KauNToX/AJYavp0=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw103lIVEEYAPBFRbr8I1MUMdvNTAU1a1Vcs2YWFSkqTdeDPPI+Wtd9lWci
iEabIiqi5gUZ5YVp5YFZ6QelxZa2iqREiW2a7bqe64mWlu/N++DxGGa+3zcn
L0rqF6vD4XDO/f/2/kxsglV9bvCjym3Ep2MDNj6F8OZEh3AcHeuQv2aq+3bU
GFdX7cUa3LIvL05VH8VDg3uxCm0VBkEfBZaY8VahkG8+EN1rjRlvBdS7+jWn
79oRTwvHrrg41sodibcMTtwCai6dT7wlcJOWeqt8XIi3BCNmXdU1IgHJX4BW
Pbjjnu+O6eGDczCm4TZaLSNSTwMpsleqmQ9CTPNVasi3OBIe1ulBPBXM882q
u8GLeDOQEOApadZ4E28avEq3IuSCi8Sbgq0n0YbZLZeIpwStz9NMpdCHeD8g
4FtHx/iOL8n/Dl24obBI6ocr6fFf4eavWc9JrT+OoeuNwZfJ0Sz+/QDsSPuj
YNNblypzCCLeMHTzB4SR08EkXw4Owem/hxqvkfHvwDRcnxeXFopL6P4esJ1v
zgi5HI5z6HYznPBQKN4bRWD2hO2eJUWP6kbiOqYf9TtaxVpo2XYPGoxps96a
iMKujI+4kUOikYFo0i9HgZ3jvc5NMez8kCjttUKTF4udmPmjvuJA1XJQHE5g
1ofSDtiF5FnG41pm/Uhs/DzbZCYeDzP7g0a4s1lhDxPY/UNmKbnzzj6JZLwS
2Z+5atuylkj8KVR6b9dZXXqDPR9U4mSi42ItJvVm0AOqQDTbLmbPF7kqj3eI
XZKIp0YcwYS/dXsS8TQoM/usYdFJCZnPHEpUvfA9XCYh3gLaf3tfA3dbwt4/
xB8472QTmow/M/cTDe0syoq7k9n7i8pzm3++NJCSfC36c3B9jHNdSuqtoLI6
b15fi5R9H6i/Sa9VuCol3ioyWrwQKjan2PeFlv5aypTuFPHW0ak3wvrHIRTx
NhDl1l6myKCIt4kqltWanDIK/wM3tcJE
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103ss1VEcAHCUKY/eZdIWbV3MmF0lWXyP8ohGtyhSHlf3etyL+7Drsewm
S6aUmHuHIjSW/MGUySOnrcdGyF2T2tS8dr2u6/0Id8rvd37f7bffzs75fr7n
aR0tuso30NPTc///bf/pWMO+D4abe2u3wJmKVSxrTS9rRPtQDBUr+FCaPfuJ
sQUqLdmOZXxuU2nhYWuNerq3YwmnhlubqsxYiPaWsJm4SzPrZo9obxG/qy0S
poQ5EW8BW/lsbWDkTLx5bFih2skPciHeHH7p6Rf8WnGWeHPYa47XbWTiTvK1
+J5LuazwJkLU8G4N1qgEnpOB50m9aRwqYkdncr0QxZdM4o4848uhCh/iTeC8
pOwakeYi8dTYLr88oynuEvHG8GzriapVk0DijWKt4r6HWsgh3jCe71+3aVdf
Id4Q3lE9Zj2eEkTyB3FfgKV5zrFrqJga/wt/5qUmRw1cRzyq3g9cdzd8pasm
FDlR/nf8Ns9dV5UbRrw+vNsmKwLkt0h+J+6vP65NzIog4z9ilUMnu90vCj2l
+lvwAdaZIIsQLsqk2rVYtxZglRsbjZgTHhpQbbLSb6MKuh8yqrVy/Yc80m4B
s0cyf8diPnKlfbjwzZb/uzKG9HdC5J4iX0F1LDM/aJz45BpfGYdO0fMHXWKZ
UUNRPIqj1we1ge9/3pAL0HN6/XA42pD7JVyI+uj9gWUVm6tgJzD7B8qZsDsv
NhPI+GFQNvVkz7QlEn8URgWs8HpxEnM+MF4t32Rbikg9NTyuM+UOtomY8wUk
53nm24mJNwn++4M7WsVi4k2Do/DgbMMbMZmPBlpdl7IbF8TE00LBpNJ7y0HC
3D/QpaTv6udLUC99P2EmNdVcVCph7i+8ivTqMOyWkPwFeJYTsrd3XULqLcIR
c++vf1lS5n2A258BbjNHSrwl4HE4huw0KfO+4KT+VGdBmZR4KzACp3s2PkiJ
twpTxcvcwhHGW4Mh+VEPmUEy+gceocHk
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wss1HEcAPDDlVfaTV6LSkStJuZ5KX4/xskx6fSkls7hihx3x1Ijy2LI
1gN5VcrYTq8tF+nUL9I8kkcX1rydjCNxnq105f///b/bf//99vt9P9/fcydX
wInUpNFoHv+/9T8Zq+ilxPUrt1oDOhGxgsyg7En5PkMYRcQyUleWfsz8aw6L
i9ZjCWVJpfZjdtbwc/t6LKKNPk46DZV7IOktIuba48wwwX7sLaA+QTe/neWI
PRXaWmW/bTLdBXvz6PvgJ0Wkiom9OeTH0rcazz+EvTnU4iVOtjgAcf4s0lpq
ZtT6ekNiePsMGtaUaQwKfXC9aaTvl2f5ppEFCb5oCk1bbZJdd/PH3iR6bfuI
yZcHYG8CNXkqlVmFQdgbR2m5bfXxTcHYU6CgvVJP4xAO9kaR7z2TgrHVEOyN
IN2fJQfZNcdx/gCqe+ofGptzEhYS478hNr2TT798GvKIer1oQ4M048TVMOhA
+HIU0067syPvLPa60KyXyjn7/Tmc34pGH/7JM1aH4/EfEHetlqVlw4W3iP46
RB/zKD8SHAHTiLYEuSkZ7jrXeJA64SlGd7Ppi0hYRvaDgFR2dOhQFG7XAYWl
s2u1Hh8ySR/k9Pek73S8gPtbAZ2eUy7nXKTmB96xbra4xMRAZ3L+QDd618Dv
5FjIJ9cHiu3r521SL8FScv0gg8F5rk6Kg13k/gCtAZsb5jwBtX8gRc87pcIq
Ho8fBY1nrhSwc+OxrwBDYofzJqp46nyAxLFC3+loAq43AX7EWVj3VSVQ5wsm
ExufeakTsDcFegPLlDVBQuxNg+xYs1cpRUI8nxnwa7dR6uCwEHuzoEQ7oNnC
SkTdP6BT466fFi6CHeT9BJJjm9cOl4io+wuMkMyg5osI56tAVyCw1dQW43oL
wLDzfhaPKabeB5Bvn5IzosXYWwT5p9oM3O6KqfcFTBs0OrTeirG3DJJuj0SU
jVPeCtjSQ9d20kvE3iro93ygO2yXCP8Bspi2mg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw10wlIVEEYAGAtkBVFq/VAE03zwINS3NK8ZjLdCskzS0HFI1dN89hTqFBa
zehAs6B1MzWD0qCi3IjV8jfFKzfRysoDN1PERbHNaxWv8r15Pzwew8z//XPa
p+ZFp+/S09ML/P/t/OlYhZ47WZXV8t3YmwodWAwBV2BnhnlUrMDVZpePm9u2
WF61E8sw9CEq9HGAE/6s2oklsI5q7OSEuWPaWwKzqVPS8Z+exFsEL01CWrw/
h3gL0MVxNCgZ8CHeX1BPGPqaV/sTTwuZXxSx+vWIeFpQhoyyAxaPk/x5uHbF
eq/2aAimhqvmQC25ZZlRwyX1ZsGmLbxow/00pvgqDXxzPhzP/h1GvBn41FSi
MuwIJ940vPS67XZ/JpJ4U+DKC3XklkUTbxIc8pOqrwedJd4ETAeHVJiYniPe
L3Ax2dZErZ0n+WPwPmWwMHszHsuo8cMwKuCdYO1PwBeoet+hwKppMCYqCXtS
/lcordJvF0QkE28AEoxznquLU0h+L3RaDns8bEkl4zugNT2Qb7CVhiuofiVY
1HGeBnDTcTHVbgRDlnGtfSUPMyecP8q3FKozcB3dj9JG33hNumeRthLZyeRl
TqKL2Jf2Uc1GRI+pMpv096Lu7tqphuUcZn5I1qpj+7nmYg49fzSUOHczPjoP
Z9LrQwqDxBadTz6uptePKt2k3fK2fDxA7w+Sqh6wh4MLmP1DtkUxerLWAjJ+
AnUNzlmNePOJP4nAr+C1sp7PnA/68a7oXpqRgNSbRnsULw7tyxUw54te+RbG
GfYJiKdBFpdPdlQ6CIk3i+QeiwfXhUIynzl0g/V2tbxdSLx5JBBtjD0yEjH3
D+knp8bkRYpwP30/0ZZW+ifsroi5v+jIlrxP0i8i+QvINviSrzdLTOotogMq
86rmIDHzPlDmyHwSly8m3hISx8XaGD0RM+8LKTTsZ8cGxcRbQZnrayHbG4yn
Q8IV6Xips4R4q6hhqJyzdEaC/wEp47zp
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wlIk1EcAPDlAWVKUqCSlPNiaHhNrUzde2qYJVZzm1jq8L7ynnObkogx
GkUgq0mmpRleWEOpME14NXEe6BQmmSHemBfjS6cuESy/731/+Ph4vPf//d/p
nFoYm2HGYDBC/3/HfypM6B0zgPimtoT+ZOyjjJAUhn+YHcwkYw81Cl4/Nbk6
w1d1x7GLCJE0SVzBguNjx2FE55zOmnt6eUPKMyKe8Lx4qpGNvR2kYyaxTiRd
xt42ahWEOK5wr2HvD1IddDAV1RzsEahvaaO2QRaGPQKlKruH4FQEzjcgvbnI
XsmLhOTwsS10qPWpPnUQhettoqBLczG+o9GQ5OvW0cO5hR6V9jb21tBzYWTR
guku9laRva/e9UxbLPZWkFDp4Gws4GNvGSmm3S3k3DjsLSK/gyp15Z147C0g
7ZbuMzfnPs6fRdNWPDebxkT4khw/g9r0HzRRhBCmk/V+oCwbG8FJdTL0JX09
av9Z65FLpGBvEimTHUe9OGk4fwQFL24bF1XpePwAsr2lIgZ2M2AN2d+LmCWa
oeGELFhFtjtQFid0q3MwG9InLEirqDTzy4VNVD+QNaWscusf4HYv0BmCTCyz
fHiV8gE78XQTO60A948ATh/fStBfSM8PPJbnR8zKi2AANX9Q05u3v8kqhtnU
+sCwIvCJZqAYNlDrB3+/iMON8SVwktofcMhyv875XULvH7j39S2vukCExy+C
tYWNZ98NIuwvA7ZzU49ddil9PqDC29Tc9asU11sFhol8y/FIMX2+wPeKlvj4
Xoy9dfDG5cjik3UZ9jZBSPjFBKesMjyfLSA5DHS82V+GPQOYt+hqf2Qtoe8f
6BiHMU7xEqij7icYNPpF5zRK6PsL1qa7wjqXJDh/G9gy6yc9XaS43g6Qd9/I
8xBK6fcB+N1q/kqtFHtGkNCy3vJiTEq/L6C/EFxeeCTF3h5wiGu2b/WRYW8f
7LLL3TKTZNgzAU3yxPyMQgb/AXJcv00=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAPCRjSIqH5VpmfgAY9JjsIH2WOegKZEhKmVammhzaEna1Lnt
GqagM9N8ZA9HhYWWKdnUJHywk65/VtMG2vIZPuZIna9Nt4VTynvP/eByOZzz
/b7z9E5Kj0rexmAweP+/rT8VNuSexhxjMXZCDhlWJPHyi3v62g0KyLCgx/XN
a3arD5TXbMUaMtalcPvXWbBPsxWrqIrvv5zZwoaUt4q+JejmT8m52DOjBZ2j
s3N3IPZM6MPX6HOuh3nYW0EVqdyhn+MQe8uo0G/j95nIYOwto6mZyEr2XAjO
X0R1GVqH800XIDlcY0SxZeWCI8/CcL15FF9W2C5UhEOSr5lFus6Gok17BPb+
oEsrrhJuVxT2DIjVKVvwqr6MPT06pp8OMBZHY28ajTuYqivlMdibRIPXg7s1
6mvYm0Cbwa5uzIPxOH8MJe7YJw4oSIDPyfHDKEx5Q5POTIR8sp4OCfMJxcrV
JMgm/QHU4bTXpefzTexpUa8ijlPvm4zz1UjVPnx6t1yAx6uQwajsdXRPgRVk
fwcSD/3YlfcqFd4n2+/RyRhj5eLR25A+YeLigyBNaxqspfoByw50orN3cLsD
aPmrzdG96TCQ8kGzOHf/em0G7leD2F+3Wh/G3aXnB3xPjExNuQghl5o/yB9B
JrZKCFOo9YGeJ0TXQFomfEGtH1iOWxuiHbOgltofwMyRhWQ0ZtH7B0pDdUsb
vGw8fhKIXkakb6qzsT8N6gv+7ikNF9HnA7hSX6XuuwjXM4ADInOjZ1AOfb5g
2JCX9rElB3uzIPSTyTZ6SIy9eVBS6nVl/Z4Yz8cIiGK2LXlUjL1F0Nam7Mvk
SOj7BxKcq5TSIgnsp+4nCM3Vv+sblND3F7D0zKYuTynON4ERwURPOV+K65nB
G8WCrOKtlH4fQObk58+YkWJvFZgjfDI9vAj6fQGth33OM4bAngVYOKnbeWUE
9qygROUd1YAI7NnAdJX+y6MlAv4DRw/MnQ==
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1030s1GEcAPCrafMS5yXVSlrlboWWVJdCz5OdXMTV4ZxOs4xzURzi7txL
pzTabGkr8zo0ISfhqDQ8fxi6haSxGgtd3uYlHEf+Kr/f8/tuv/327Hm+n+/z
eiQmmRe3k0aj+f7/tv9kbCJRryQ2MtsSniFiA6XpJ6K7zx2EIiJMiHGB1/PS
6AKLi7ZjHRmrXG1sm91hf992rKG/lQy+LskTkt4aSrk6PtLaycKeEVX5rK95
BXtjbxWVW/h6RdAh9laQucMl99kSP+wto44p8OBLiD/2ltEoL8exwZWD85eQ
6tmY4LJnECSG9y2gBYO/NkocguvNI5aEbvwzcx0SfNEces+ydxpu5WFvFp0P
/8Vnl4dhbxodNRSOPX3Fx95vVM5uLJ7RC7BnQHGSqXCOtRB7k+gn65OdWHIL
exPI4E33qTBG4/wxdDG0lpMYdBsWEuN/oJZAWyddfQyMJeqNoP2+uU92HYqF
HoT/DfGtuMPikjjsDaL1JhfHHGY8ztejzcraGw3tYjy+C5lruJYjwgSYT/S3
IVvuFUHdjrtQQ7Rfo4BTen6p9h6kTvhjhGbOxE+GFWQ/kG3V+Ck0EtxuA8mH
acyU0BToRfoAlTVdsz+Wivv1YLTsTZ7HUio1PyA4YC7o0qXBs+T8QceKbnMx
9T4Uk+sDJ+jxvTvd0mEpuX7Q1R8geTSaDgfJ/QHvuj9onbMzqP0DGQlOFvUu
Ujx+EthYS9TMDin2DUAXeVpUHSyjzgfsYYZJhSMyXG8ayKuznHIi5NT5gvmy
/DvSr3LszYHHiy39D9mZ2JsHb5UFuWZNmXg+C0DB436P3KfA3hLQOm/1jUsV
1P0DWSxO3cqQAg6Q9xM8T5zsnDmupO4vyCtqL96bqcT5q+CklVv+QI8S1zOC
WnVQkpCuot4HcLhZIDILU2FvDdQITXa7X6io9wUYpsC8xiEV9kzAi+Fd7mat
xt4G+Oy8YGpmq7G3CXguuVEyuRr+AwORuOA=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -1.0318564776459377`*^-16}, {
          20., -8.15008637088953*^-16}, {30., -2.6401321248138606`*^-15}, {
          40., -5.6659962287610475`*^-15}, {50., -8.996491065652698*^-15}, {
          60.00000000000001, -1.0539822521550379`*^-14}, {
          69.99999999999999, -8.391481148018261*^-15}, {
          80., -3.016107666909874*^-15}, {90., 3.3882119722927397`*^-15}, {
          99.99999999999999, 7.607417894949906*^-15}, {110., 
          8.199763779873245*^-15}, {120., 4.571507799385681*^-15}, {
          130., -7.797578266480001*^-15}, {140., -1.8501621938798055`*^-14}, {
          150.00000000000003`, -2.973852796422895*^-14}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -1.11525165071677*^-16}, {
          20., -8.812214737307166*^-16}, {30., -2.8560916173450006`*^-15}, {
          40., -6.1305867695872655`*^-15}, {50., -9.717674945473613*^-15}, {
          60.00000000000001, -1.127586734444119*^-14}, {
          69.99999999999999, -8.54702125569512*^-15}, {
          80., -1.6935782269638287`*^-15}, {90., 6.8645032545680975`*^-15}, {
          99.99999999999999, 1.463590800410965*^-14}, {110., 
          2.022091631710322*^-14}, {120., 2.3191474379941734`*^-14}, {130., 
          2.3863852815889094`*^-14}, {140., 2.338863619532539*^-14}, {
          150.00000000000003`, 2.3907436129091366`*^-14}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 8.153738875547617*^-17}, {20., 
          6.878280840400669*^-16}, {30., 2.5200613980251545`*^-15}, {40., 
          6.57435612921193*^-15}, {50., 1.3942809418459638`*^-14}, {
          60.00000000000001, 2.491330491883745*^-14}, {69.99999999999999, 
          3.797071362031258*^-14}, {80., 5.0594135746217315`*^-14}, {90., 
          6.129522862117569*^-14}, {99.99999999999999, 
          7.015877888558488*^-14}, {110., 7.796503504087226*^-14}, {120., 
          8.546802738596351*^-14}, {130., 9.316451549004615*^-14}, {140., 
          1.0124864517869063`*^-13}, {150.00000000000003`, 
          1.0957893563075001`*^-13}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(Prx) [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: Prz/10, Blue: Prx, Red: Pry\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.006942711162594285}, {20., -0.05485893167241964}, {
          30., -0.1778362821883947}, {40., -0.38210164835068855`}, {
          50., -0.6079858655641115}, {
          60.00000000000001, -0.7155239227512527}, {
          69.99999999999999, -0.5767706536862516}, {
          80., -0.2210777231279823}, {90., 0.17661391911050175`}, {
          99.99999999999999, 0.43253357128866204`}, {110., 
          0.425730151671527}, {120., 0.09711735713748589}, {
          130., -0.5476497978419014}, {140., -1.4030043643339525`}, {
          150.00000000000003`, -2.22504307091437}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -0.006903449948941632}, {
          20., -0.054547678344081696`}, {30., -0.17679156022499698`}, {
          40., -0.37948374327141393`}, {50., -0.6015437471854785}, {
          60.00000000000001, -0.6980902157629435}, {
          69.99999999999999, -0.5294774758560448}, {
          80., -0.10592450320829293`}, {90., 0.42216548972942536`}, {
          99.99999999999999, 0.9003657424774559}, {110., 
          1.2415956517100204`}, {120., 1.4195767327541517`}, {130., 
          1.455610922906484}, {140., 1.4254000862937046`}, {
          150.00000000000003`, 1.4693015654584096`}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 0.0018624822317352516`}, {20., 0.01568763983657847}, {
          30., 0.05732680420504036}, {40., 0.14902311801865442`}, {50., 
          0.3145475889011019}, {60.00000000000001, 0.5590574143513891}, {
          69.99999999999999, 0.848008597402776}, {80., 1.1258367808569107`}, {
          90., 1.361195542452564}, {99.99999999999999, 1.557860092257024}, {
          110., 1.7347165289719786`}, {120., 1.9098292133744281`}, {130., 
          2.0953155445193503`}, {140., 2.2958743407072677`}, {
          150.00000000000003`, 2.5071764063898976`}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kbT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox[
          "\"Black: Ur/10/kbT, Blue: Ux/kbT, Red: Uy/kBT\"", 
           TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.16999999999999998`}, {
          20., -0.16999999999999998`}, {30., -0.16999999999999998`}, {
          40., -0.16999999999999998`}, {50., -0.16999999999999998`}, {
          60.00000000000001, -0.18}, {69.99999999999999, -0.18}, {
          80., -0.21000000000000002`}, {90., 0.14}, {99.99999999999999, 
          0.15000000000000002`}, {110., 0.14}, {120., 0.12}, {130., -0.28}, {
          140., -0.22999999999999998`}, {
          150.00000000000003`, -0.21000000000000002`}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -0.14999999999999997`}, {
          20., -0.14999999999999997`}, {30., -0.14999999999999997`}, {
          40., -0.14999999999999997`}, {50., -0.14999999999999997`}, {
          60.00000000000001, -0.14999999999999997`}, {
          69.99999999999999, -0.14999999999999997`}, {
          80., -0.15999999999999998`}, {90., 0.15000000000000002`}, {
          99.99999999999999, 0.15000000000000002`}, {110., 
          0.15000000000000002`}, {120., 0.15000000000000002`}, {130., 
          0.15000000000000002`}, {140., 0.15000000000000002`}, {
          150.00000000000003`, 0.15000000000000002`}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., -0.04999999999999982}, {20., -0.04999999999999982}, {
          30., -0.04999999999999982}, {40., -0.04999999999999982}, {50., 
          0.}, {60.00000000000001, 0.}, {69.99999999999999, 0.}, {80., 0.}, {
          90., 0.}, {99.99999999999999, 0.}, {110., 0.}, {120., 0.}, {130., 
          0.}, {140., 0.}, {150.00000000000003`, 0.}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(F): Pos\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: z, Blue: x, Red: y\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.4990798818477507`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"30", "nm"}]}], ",", 
  RowBox[{"w0", "=", 
   RowBox[{"260", "nm"}]}]}]], "Input",
 CellChangeTimes->{{3.50971437681612*^9, 3.509714383487936*^9}, {
  3.515730236050334*^9, 3.5157302400812387`*^9}},
 EmphasizeSyntaxErrors->True],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "P0", ",", "c", ",", "w0G", ",", "\[Lambda]", ",", "s", ",", "w0", ",", 
   "l"}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
           RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", 
           "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{"0", ",", 
           RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", "\[Lambda]", 
           ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "0", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.05"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";", 
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";", 
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dz", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4976782458944407`*^9, 3.497678282602376*^9}, {
   3.497678734617697*^9, 3.497678758681884*^9}, {3.4976787946572323`*^9, 
   3.497678869126648*^9}, {3.497678901374044*^9, 3.497678907614408*^9}, {
   3.4976795504702673`*^9, 3.497679632492855*^9}, {3.4977243494285603`*^9, 
   3.497724356772558*^9}, {3.49772439263517*^9, 3.497724432754241*^9}, {
   3.497724489838925*^9, 3.4977245072242403`*^9}, {3.4977685884705315`*^9, 
   3.4977686069519763`*^9}, {3.497768879199047*^9, 3.4977688887088127`*^9}, 
   3.497777426185375*^9, {3.4977774791316643`*^9, 3.4977774819343987`*^9}, {
   3.4977799158992424`*^9, 3.497779952931469*^9}, {3.4977825548726683`*^9, 
   3.497782556559885*^9}, 3.497784955902258*^9, {3.497790154819166*^9, 
   3.497790160226446*^9}, {3.4978101781630983`*^9, 3.497810186066362*^9}, {
   3.498207486396933*^9, 3.4982076550483007`*^9}, {3.498207703749872*^9, 
   3.498207713672394*^9}, {3.4982077795522623`*^9, 3.498207782905387*^9}, {
   3.49820793118533*^9, 3.498207934749765*^9}, {3.498207971635404*^9, 
   3.498208051532353*^9}, {3.4982081135471153`*^9, 3.498208113803018*^9}, 
   3.498208554851375*^9, {3.498208585402851*^9, 3.498208588504603*^9}, {
   3.498209092330097*^9, 3.498209096512031*^9}, {3.4982091526299067`*^9, 
   3.498209177682274*^9}, 3.498283080241593*^9, {3.4982866906827583`*^9, 
   3.498286692966523*^9}, {3.498908871863228*^9, 3.4989088907116632`*^9}, {
   3.498917820335005*^9, 3.498917891964542*^9}, {3.4989184779140873`*^9, 
   3.498918503722228*^9}, {3.498918654447453*^9, 3.4989186549023533`*^9}, {
   3.4990642567188463`*^9, 3.499064259992449*^9}, {3.499161475909781*^9, 
   3.499161476888074*^9}, 3.509713334865253*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "1000"], ",", "299792458", ",", "2.6`*^-7", ",", "0.532`",
    ",", "0.2448537586029159`", ",", "0.26`", ",", "1.0618583169133502`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.498908892291409*^9, 3.4989185875442343`*^9, 3.498924521835683*^9, 
   3.499062538336133*^9, 3.4990630771875143`*^9, 3.499064265492174*^9, 
   3.499160594487793*^9, {3.499161463882716*^9, 3.499161477702039*^9}, 
   3.509713338320138*^9, 3.5097137821923923`*^9, 3.5157302431757917`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CPrTzA", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Pf", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"CprG", "[", 
         RowBox[{
         "0", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "0", ",", 
          "0", ",", "R"}], "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["z0", "2"], "/", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"l", "/", "1.75"}], ")"}], "2"]}]}], ")"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z0", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", 
       RowBox[{"Show", "[", 
        RowBox[{"CPrTz", ",", "CPrTzA"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4982091006985703`*^9, 3.49820911910146*^9}, {
  3.4989184925961447`*^9, 3.498918497962447*^9}, {3.4989186568296347`*^9, 
  3.4989187078778543`*^9}, {3.49906434690629*^9, 3.499064347192109*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1lQtQVVUUhgElRBEuZY1NyqAOysMRvGCm7uMymXg4CsrUjCblaII1arw0
CzQdU+kBkcmU8mhESOUSKI8QdR8XXEBAHooIl6fPLBNRBLlkirTu2bs9wzB3
9jn/Wf+/1/r2tA1RYRE2VlZWEfRn+S/WTWxKvBE9zlDKwlOMQ+7hN3Cdg+Gw
bhJnZS77e1eVXUfv4fuBby+rYJMKAm/FT7qOP2XGDXV7VrMYZbwpO7oHb/04
O+O4sY41NlhWNx7S7wi46HGZeWiC3bjcaMgt4leZRc1lfxfGHHMaTYtoYyRG
ip1YN/3unE8zOtlii5zSiXE7RhZmbL3B0o5YVgeezpp6aGPsbWZ2twi2oyk5
LsvzwF0WphXYjraP6h9vMd9jWnkFJpy9uuR8yMUHTJMbb8JTepeK8oR+Fqmt
Nqy9NmPbi6oBZnGbYmxF/2JzYbcyxDS7Lq1YYwyOeeuPYZagGb6Gqa/uW1FS
8i8Tci1Ys/fsyWzDCPPVVgsm/xVc/2KdlfKDJngVk0xlCb+ZrZUHFru9zVj7
StL2p6ljlCDNcDMW+C548+Y8WyXHIpd9BX0jP8HqlpcUcR5XsMM6/2Hyx+MU
kX8Txn7lF/J7n72iPR7diNt6prVGhU9QtDjcG3CkK/5yfb6DclvL8xIePjXS
Z+qcqIj86nCMsXFlfbejIvKqxewla5fMyXdSRD41eD538RTrGTpF5FGNCxY9
HhpcqVM0ufgqdPZ//tz1Q52i1/xWYp9uSnpukE76q8BbG76p83LSST/luM8z
wPrn9U6y/gtozGrtiHnfUdbL0T/p5OlI+4nKYa2+s2i1tq/IOXqCMk6r5wy+
4b5swO2gvbJT+34Jbtqd67M+2k5+rxDdCj3uxr9sK/UL0K7yXKDTLhupl4vD
F1y3OG4dZZ9r7+fg5mem7c++e8pOa8//giM19a2BkYNsj7afikq1V/73k+/L
3/tw6bS2HEfWyf6fkJnDW17PyFt4Xu7DugB9Ee1z+T60+N4ppvd5udCHvQ7e
HaQv93OgIvSdL+j7/KioD9Z4pEVRffL5Aji38Mtgql/tF/6gcvmTP8mfKuov
AWf/BD35V2U+EHBm+hPKR5X5weZ/6ksoP1XmC4VTk4ooX1XmD+ZS3kX5q/J8
YJGd9xg6H1WeH7x2ZtclOj/VT5wvfOvnlEHnq4r8q2DAsW+Ezl+tEv0B1buv
m6k/VAfRP+A1f9ZU6h/1XdFfsDzTdSn1l5oh+g/+nrM/jPpPvSn6EwZm/vqI
+lPW2wD2Kbpm6l9V9jecUHLaqL9l/U2gDz4WSv2vyvmAMh/bfpoP6ecK1Ibk
ldP8qHK+wC1u43yaL+mvGVYcPPoZzZ8q5xOeYulOmk/ptwW+PjG3geZXbRfz
DVnPPzDQfHPh/xqY5o2G0PxzV8EHsEvMjCU+cMkPeLbarZj4wSVfYE+t93bi
C5f8gTuj9kbiD5d8gtTulSrxiUt+waoj+kHiF5d8g7GJuceIb1zyD+p6Z6US
/7jkI6QtrWLERy7mvRN2zN3kQ/zkBwRfwTnyPav0iDbuKfgL6WO5gfjLmwSf
YbB3cRDxmYu8e2DymuOZxG8u+Q4fPTSYie9c8h9Cbe4HEf+5vB+gf2dwGt0P
XN4fkHfPO5buD/4ftMs3fw==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1lQ9M1GUYx8+SiH/BmdUEdxmrhixGJYXS+/JsuaZmtsUyF+EqNo1chEWL
BlK0gC5sHs1SbP4HSrc8ZZ6J9r48eFCmcRd0HH8ORGFpY8D0xsGwiMW9z9O7
MXZ7f7/v7/l+3+f5vA/lF+VsucNisWyZ/wv/p3UN/555euj1woMiz+GeSsm7
igVRyfazX9SLZlvV2EvNQ7h5a1zDqeAxsdi5Zrh08RBuKi9L2XPspHhPRvfW
b7+Cw5Uv3GyaOS08HeE1iL998+YbG2PPieVGcBBXHnCdKM1CEVazVQ2gfe96
+/lX28S82LxiAP/6yTX2XM9FkR2WkwGMXPTvNn+6R3y7L7z6sfiD0C6Xu0tM
p4QF+7Dmq4IOb5lf5JgC+7B2YNWfUd39wpTn7MX8mpb0jYNDwshF92L5qMt+
JGdEbDWrB72ZFZFZh66LsFuH24+7YopbQrmjwti1+XH50XW+wzsnRJkx3I0b
8ioymxODguR8mL3uhm31iUmxwiwfxo8nHIXyaVFrBP9AR+umA3P222I8bHes
CzH+rowkz6xYawx34ZexWY88nGyRDWG5+k70vzi4fvfkAknn0Ym13tXP3Ntz
p6T8vZj3oXxetUVI8/h2D47/c+Yp+5lIaeJI6cDOQKh6c32UHDF5XsYldW/b
Hq2MkZTfJZwYTSwPboiTlNevOBf88Vby9D2S8rmI5+01h/wrEyTl8TM+nnSk
8LtAgjRype2YsaBkZyjXKp80fttwae8PD2xzWSX5u4DX0f3L/SNW9tOKny7a
59h/1cr1t2Ba48Rjrx23cr0Ko+fcDXXCKutMfeewcKBoYePeBHm3qecsPrHk
ldSbxfFyh/m+C7932ic/XxvH32tC67IJX0xTNOs70VIykx7himS94xias73z
ce5C+ZF5vwGzE3bH9p+0yFPm+YNY9K614MHPbosKs/81Tr1/+ZNLMsi/K9GT
NrvHkj8s/p+Q09XBkoGkqUzeB95X/D7w+6qV9GEH6fN+AzxL39eHqT6Yofo0
Pe+ECKpf3yJ/cB/501S/CxrJv+Z8gPPRnB9wfprzBc5Xc/7A+Ws+H6ig89F8
fnCDzk9n0PlCIp2vpvzbYQWdv26n/oA06g8dS/0D3D/6ZeovmKX+0vup/4D7
T1+j/oSl1J9cbwdw/2rub+D+5vq9wP2veT6A54P9dALPj+b5Ap4v9tcFF2j+
FM8n8Hwq8uuDKJpf1UfzDatovhX574Y1NP9qGfEBbMQHxfwA5odivsDvxBfF
/AHmj2I+AfNJMb/AQfxSzDdgvinmHzD/FPMRmI+K5j0AAeKnqia+QhXxVaUS
fyGV+Ku8xGdoIT4ryvsKjBK/FfMdmO+K+Q/Mf8X3A7xF94Pi+wP4/lD/AQd2
NqQ=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {GrayLevel[0], LineBox[CompressedData["
1:eJw103lI01EcAHArKWZmhUXY5ZEHTJdzTjePt7epTTPX3FWKhOUxjESzPwxz
VEJWODNBLY8Q/UdoxhQzhkE8JdTMa5Ys5mRetWme6TywleXv935f+PHj8d73
832nZ1quNHOvg4MD+P/t/snYQtf71VzrAh0EE7GJ1NGGL8riAKAkYgPdopud
NPzzoLZmN9ZRWVRCVeBRJhgc2A0b4rL2+ktOBAHSsyHNn5EsxxAW9tZQadkR
N0N2MPZWkf89l+TaLjb2fqFsJz90OzQUeyuo+FDoi54hDvZWUOFPsUlRFobz
l9DkjtHVvSACEMMHFpDwSlVsSgXA9eZRkTUgPW0KAoKvmUNKY2FRZ7AAe7Oo
9UFFjakyCnsW1G3PP/fmeAz2viOZSaUS6C5gbwZNj651tBfEYm8K+d5wdWlL
uYi9SRR3WkybS76E88dRuscpS3aOCFQT442IPdLid7JcDDKIegaUc9MlzNWY
CJiE/xW5lVi9DkxLsKdHw02lT5yNUpzfhyLUJqnorQyP/4i2zfOJ65lyUE70
d6CR0UZDulUOHhLt10jzPqRdxlQA6oR1jG8TukgFaCD7YTXNt87HmWp3QE5z
vs+nRjngkj5kqJY9l/fJcX8fTC18miqKkFHzg3+76+P2SKWATc4f1i9/NpVI
JSCLXB+Un50zjQkTwSty/ZDBEfD5uZeBntwfmOzYP9F7NYHaP7jSItRPSuLx
+Cmo2T+uMmXEYX8Geqp2nvOqhNT5wHe8gPWkHzG4ngUeG/rQqVdEU+cL4xu8
6B4WAfbm4I520bpdycfePMz7Pd3L6eLh+SzA2RgLx/4sEntLMPUuz41WGk7d
P+g1tkmj67hgiLyfUDvoXSI9yKHuL1xs5onaHoXg/FVoETeakDsb11uD99Uv
NZFGFvU+4B3ztVW2Ngh7NngmXmS21zGp9wVnWmOzkviB2NuA9gxvJSuPgb1N
aNMeljX1+GNvC2YOP/YJB3TwDy5iuOE=
          "]]}, {{}, {}, 
         {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwBUQSu+yFib1JlAgAAAEQAAAACAAAAY6+Q7///978m6HuUPuQnPX4l2sBm
h/e/oVa6fZ+3KD2amyOSzQ73vyeCVc58lSk9n9+Ib1EJ9r+/nHuNvZ0rPRbQ
U08pFfW/ddVBN2m5LT3IUFNEyyX0v9J23zP0ATA9SCkldCMi878MqcDOoGQx
PTquXKbPL/K/2lau0rrWMj36imYTMinxv2FMdDyTmDQ99feklV4n8L/+dOyg
oIo2PcQikjS+be6/CwJerLGUOD07BX+zK2Tsv1TJPOUbEjs9lEA3N0F96r9f
FCuWubA9PWOcWOXqn+i/IhWbl65IQD3Ppx4JAZrmvwsQUwhJCUI9HgywMb+2
5L+UYy1JqN1DPQog5s/pquK/JnVsZIoSRj1sVIWYqKjgvz9jbeIrd0g9YMPf
yx6S3b/GwH66neJKPSI9/lHFgdm/sBpOAESsTT2paLPhu7bVv8qsrtzLLVA9
avOxXIua0b8OhKdM951RPS5+BVkGI8u/xdd/ETjtUj3nPLlFKkHJv4o7rbba
NFM9oPtsMk5fx78FaJ2fQ3lTPVq6IB9yfcW/eAKkjha6Uz0TedQLlpvDvyAt
+Ev49lM9aecsbiaRwb9/E8rMHjRUPX6rCqFtDb+/QC1VGs1rVD0qiLtljvi6
v/hkizucnVQ912RsKq/jtr91VpQrLclUPXUD940hia6/wfLWe7IIVT13eiqO
yZWev/yhzJ6TL1U90Kwe31RSRr+yRMYetjxVPaqPOECkMJ0/8A9X374wVT14
jY/mic6uPzVFUkLHB1U9jmmB1mCCtz+/dyq3+cJUPTGJh76eSrs/ylo7auuZ
VD3UqI2m3BK/P5xRIseGa1Q9PORJR41twT8soJq6FzhUPQ30TDusUcM/TAJd
DfD/Uz1CVKu5Xl7FP3112RwjvlM9drQJOBFrxz+HJSq0ondTPeB0xjR2hMs/
3ORErl/eUj3uuU3Cd8jRP2jNEdFFjlE9poehYGSJ1T85I3nq4j1QPSX2qxN4
m9k/VxDjnkCaTT3esh+9O2jdP/RLF1ub/ko9VZfgiOuQ4D+KYSa3ypRIPZ6l
jL1MluI/kO+hdQAqRj0EW23tBXnkP1n14WAXHUQ9zmCpp1KE5j+26pFQPh1C
PbUNGl33bOg/4bDVFXtyQD0mmiHoB0zqP8vVtP/r+D09+naE/atT7D8xHkFs
lic7Pev6Gw6oOO4/G8MZYwfSOD2gZ4fUGyPwPyjUtztfkzY9kEHMjBkl8T+f
uGSmB6A0PQ5vq0LDFfI/7Twz5vkAMz2+RLi9thrzP9hIYnthbzE9/W1fNlYO
9D/zpBIHXCAwPQEH0pkr/fQ/uU/18YLxLT02SHLCSgD2P0bD5s64sCs9+tys
6BXy9j/jvkyD78spPZTRZWqQNfc/cczmDv9MKT0uxh7sCnn3PzwgNPZ50Sg9
yLrXbYW89z8UNDwiQ1koPWOvkO////c/Juh7lD7kJz3s7hGe
           "]]}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxNlQ1M1HUYx3lpKu8FRAnzAK8GQcZEb53l3ROJCAo2T2ysYJKBrFKEso2g
OUooatGhEhAwtEACBIQJgUA8BxyKx4twx3F4HAjK+13aiFLcrP6/F7d+2+12
+//u+T/P9/f9fn6+R04oEm2srKwShQ/5ZmsaV43S+Ve8IzBW2f2Xf+xtrPda
McV4x2KrKNt8oHUKf1KqO/oqktC9fs9MuvsUWnpznW0aUjFVZm8oT5nE44d3
rPtYl4aDA2SZUBdXeMi9PRNfogVNWHlWXRthyUZSTZQ9gdWukf7evt+hUEyo
aMTutMWtJ1VnUE7KyYxYctetUuJVgMU/knUL1zas9OteLcG//UnBcZzx3L77
cOEFVNAGx3GxoyCh37ECaXv1Bszc5GKTbFeFtJy9AbOsgi3dxbV4lK4xnMn+
NGHzQgOSaZXdevzN/LTvufErSMcV6fFfmyyJtX8LZtCBR7Fmn37kzYk2ZOV0
WOPx/Ds5DzpxG1063DNo7Vqg6sI8WlCLD9+X6FUyNVrIuOYRvOrSrFWsXsNw
OvAIzhWfi6iavYEVpFz5MEYFtl9823kQ2XkMo/fpyign6TDXfwjjpWPLs7Za
pNtTBrEgoOLkC0s6pHL4D6BteJdTz5we71A9NVgrU7TufGDg+t1AudxJ/IOn
kevVh0flueFxkSauz3WMCBsebc+Z4nr0YttbKR4didNIy6Wr8dJl+/u2OTMY
TOftwZB//NxuVt3h83Uh2LuWlPXe5fOoMObgrfjZiVnefyd+uN/wq+PSHO+3
A9eatQdyluexiPZ3FT1V324Zm1zADbSfFizM0UhyVYv4OX1/E359KfR0Yt4S
f18jihQT1iH7lnn9ejxW/lzctvvLvF41fp962+ObdDOm0f9XYM+p5CuDZjM2
0P1l+Eb0oHk4xIKZ9Hk+5u14cbIm48nvLOxrgSAssuCThGgOSulv/hyU61z+
tz8fMmRVtJ6K1QfVkdfo+9jzCmgUl9J+LrD+QHRPHUv6ZfvrIXktjc7zB5sP
xCnaL8m8rP8msAsMp3pwfUD81MOXiV5cP5hLDKJ6cn0hSi6menP9YX2COz0P
fj6wErizmJwXPz/QBIe4kvPczs4XNju63SPnzfRXQ93jpGeJH9TMHxDVXaYl
fnFk/gHNF6+HET9FM3/B7o2lPsRvpcx/cOqX7mbix2nmT6h9192B+JX7F7aI
J1KJn7m/ofjYygLxO/c/vBdfvZfkgecDqiRnzpO88PxAgINsF8kTzxdctpMM
kLzx/IHOWTlE8sjzCXZ7pQ4kr2xeHZgMoZEkz+Ms31Ckud5D8s7mH4WYRyF+
hAc+jA+Qf/O8K+EF5wfo042HCE84X+D36sYhwhvOHwg8ETV7XOAR5xOUzpeE
EV5xfkHn2fV+hGecbyB126UkvOP8g/1irw8IDzkf4c+mhtVPBF6yvBshMC+1
TiTw9CvGV/hMo9xKeBvA+At1Jg+jm8DjIcZn2Oje5pwq8JrpPQmK/ose1gLP
Od/B9pnwgWsC7zn/IemjqUfRwn3A7weIfRzq4yfcF/z+gNKmkemfNwXJ/wNv
7l1+
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxVlXtMk1cYxplucxKFJfCHYYrOy8AZ3UDBxMS94rKIkcklk4jDZKNU4qYU
s0GwdMqUy1RUIgibLgppE2HZOhorRdv4MAQvAyuUSxHKxYrCWk3mrUuWmY3v
nPf7YydpmuY7fb/3fc7z/M7bWbo07YygoCDt9Ef5lmscB5ueL5w58j4yT7a9
iM4cQ9GlM1srNn6IlshSf2rLKIyxO/KdR1MQbt50Tx8+ioPV2iWNKRnYtz7Y
bcwbwSu51S0RMVm43aUsD77Mmr3gtcW7sVwU9OCdfwayzRN5UKpFlg4jfuX2
opyEAkwXm644hIQI+9pdHgM+UMqtH0LFe3PtX+8/hDM/KOsuHFuiz2m05QhE
KwUH4c0ePazLOI400eAgmgu+MwxuOAXRntkN62cvnhWW10CUC3bj46oDvs1n
z2KXWAOw+bPjq7rqoEx7sq0f1lXfLHucbIIYN7IfR65dsD3MaUCRGLgPmqW5
zYnLfoEs14uM1Mm+qiQLVovVi7piXcxHX1hRKQq64DJ45gc9t+GRMq6/B8G7
r4xXPbEjUQzcg/CSGWOz41phUsoZu+HcPmm/bmmDPI9uzIwyunfu62D9nUhy
b3jz0/ybENvzbsOVU/JW6tVOCDmiu3AstEx7ccsdeIWev6PfoSu/e7yH9buF
5PnF2ypP97JeN7H01wWxP13pZ31uYMnrlpDQv92sRwcep6UfHksegiinb0eT
Pv1pgc2DWDHvNQwf2njgqxVjPN9vuKOpDfG6xnmeVtjXJeSOhnq5/6uoMwVO
z9t8n/t14Oe4gPeWfgLfi/4uo2HrVMfc+gd4Q/RjQ2btQHzA9hAG8X4r9rvr
z9fbJ/l9Fhw1ltekNkxxfTNevbzX8q3+D67XiPQ9YZaXq3woFP83IXxPZ0Kg
zYcmsf8c8ts/rwlb40exeF6NxWWJMaXF6u8SbHt0YlPIBT/UhKi/+Tn9f381
qfVaZX1S3yefm0jtp072R2q/cr+Z1Hn+lPOROq/s30qqHqwPqXqxfqTqyfqS
qjfrT+p58PlQN58Xnx95+DzXyPOli3zeUv92esJ+aJf+oCj2yxzpH4piP30i
/UVp7Lcfpf/IzX4cl/6kSvYr+5cG2M/sb0phv7P/aRbngfNBLs4L54fmcZ44
XxTGeeP80TDnkfNJjZxXOW8vaTjPgzLfVMh5l/P30XnmwSLJB+piXjA/yMk8
Yb6QgXnD/KH7zCPmE00wr5hfRFrJM+YbRSRJ3jH/yMc8ZD7SS+alzPsQ/cU8
LZN8pSnm7buSv/RMI3nslHymCp3ktdR7hE7VSp4z36k5TvKe+U/1dnkf8P1A
nQ55X/D9Qf+e2DHiq21w/Acj12Nl
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw10wsslVEcAHBrbVK3jRW2GneE0Qgj5LE/zSPUuF6Xe7HYJWsSZdUqzUUl
tMzUvJJ5PzZKYgz/s3tL3VxNWdrF5P1+5XKvtbXK95373759Ozv//+9/znfO
ZxJ/PSThgJaWlsf/Z//Nxh5a+d9YcWqYQQcm1Ohyb/pOp6MSE5lQoYFLBgrb
/mBZ6X7sYn7QbfuUpINkSL4fOziePKD+HXqYsN4OGnO9DYCnS1hPiZKgcaW4
9RhhvW1U2OrkyXwNCev9QruAH7Ia7knqbWEbx/m5E3Cpt4VjYkm2xagJrd/A
U0txo/bOZoRJl69h3/s8c8WABe23iiYiz8qSJ1aE4UuXsSClsTcwx5p6Syhq
6m226LWl3gLqRVbVhZbbU28OOaUBnn33Hag3i7uvXkosH56l3jQWZ3+P5nU5
U28Ke+rSBhr1XWn9BPJsj8YaVbuTEiZfgQrn4ZVvMUBETL9RDDCUjiSZeRE7
xh/BiMuxE4rX56k3jHUXPXXaQrxpvQxtVPVlV7V9ab4U210rSeWgHylk5rsx
+G2t+6Fyf5LJjJvwmpthrSQ1kGhOuOeTuP+Z3yVSxc5DUbqevuWJIDruBs7d
apcPacHEhfUh90qFpCqIR+dlELHknSw3C9GsD9xyc0wnN0OII7t+OL2odpxq
CyVJ7P4g0dffNFAURirY/YMydrFBzQknw+z3AbnogpjTHK75flA2F31k1S2C
5k+DTUeMtZE0gvqzMPiRM+XjydecD7yzsFw/3sGn/RagxvZnuwc3UnO+0PBg
vTk1K5J6yyDuvGXEn4yk3iqkbz7OLnSIoutZgzybEbM3WVHU24AU8/oiL3mU
5v6BsuppV7+ugHxh7yf4JIz5lAULNPcX8l/cjHUrEND6bVgsNg7/KxXQfkoI
M+Bmuu4JNP8H+MzHa5+zElJvBx4tzLQAX0i9XZhv3csqyBJSTwVxQxk1/BYh
9dRQ93lZOvJVSL09UMXnyM6ohOQf4yTavg==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.498209225787011*^9, 3.498283125010838*^9, 3.498286643054047*^9, 
   3.498286712511994*^9, {3.498902785944817*^9, 3.498902802218039*^9}, 
   3.4989074125413713`*^9, 3.498907513923221*^9, 3.498908309266608*^9, 
   3.498909046952826*^9, 3.4989186337603817`*^9, {3.498918669442256*^9, 
   3.4989187145846148`*^9}, 3.498924567336952*^9, 3.499063027781906*^9, 
   3.499063123897957*^9, 3.499064356360448*^9, 3.499160700243602*^9, 
   3.499161538314967*^9, 3.509714055752459*^9, 3.515731588579616*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wx", "=", 
   RowBox[{"0.26", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "x"}], " ", "*", 
    FractionBox[
     RowBox[{"3", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "13"}]]}], 
     RowBox[{"1.5", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}]], 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SuperscriptBox["x", "2"], "/", 
       SuperscriptBox["wx", "2"]}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "0.5"}], "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}], ",", 
     RowBox[{"0.5", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "6"}]]}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.517735242355441*^9, 3.517735265185398*^9}, {
  3.5177353211036882`*^9, 3.5177353510783253`*^9}, {3.517735424150754*^9, 
  3.517735507475101*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtlmk4lGsDgAcjss7EJypLRKePSlps7/tUJ5qkVISylEhIGiTZUrYINWaY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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.517735332431965*^9, 3.517735351367743*^9}, {
  3.517735424444744*^9, 3.5177355079978027`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["635 nm, w0 = 300 nm", "Subsubtitle",
 CellChangeTimes->{{3.498306046654065*^9, 3.4983060766740932`*^9}},
 Background->RGBColor[1, 0.85, 0.85]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"RRT", ",", "PT", ",", "Ri", ",", "LR"}], "]"}], ";", 
  RowBox[{"RRT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"R", ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "0.005", ",", "0.075", ",", "0.005"}], "}"}]}], 
    "]"}]}], ";", 
  RowBox[{"LR", "=", 
   RowBox[{"Length", "[", "RRT", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RRT", "[", 
        RowBox[{"[", "Ri", "]"}], "]"}], ",", 
       RowBox[{"PlotFU", "[", 
        RowBox[{
         RowBox[{"RRT", "[", 
          RowBox[{"[", "Ri", "]"}], "]"}], ",", "\[Lambda]", ",", 
         RowBox[{"Ri", "/", "LR"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ri", ",", "1", ",", "LR"}], "}"}]}], "]"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.4990657414254837`*^9, 3.499065773922699*^9}, {
   3.499065817477016*^9, 3.499065822517425*^9}, {3.4990663608275337`*^9, 
   3.4990663773893003`*^9}, {3.499066879366581*^9, 3.499066914857232*^9}, {
   3.499069974953237*^9, 3.4990700629519157`*^9}, {3.49907097271624*^9, 
   3.499070991527178*^9}, {3.4990716920544367`*^9, 3.499071717100708*^9}, {
   3.499072316055421*^9, 3.499072327391192*^9}, 3.499074027861108*^9, {
   3.499074233454485*^9, 3.499074233590016*^9}, {3.499079840994349*^9, 
   3.4990798779877872`*^9}, 3.499080153434732*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "13", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prx) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Prz/10, Blue: Prx, Red: Pry\>\""}], "}"}]}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "14", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Pry) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "15", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "9", "]"}], "]"}], "/", "10"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prz) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "13", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Ux/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Ur/10/kbT, Blue: Ux/kbT, Red: Uy/kBT\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "14", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Uy/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "15", "]"}], "]"}], "/", "100"}]}], "}"}], ",", 
             
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Uz/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(F): Pos\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", "\"\<Black: z, Blue: x, Red: y\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "11", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fy): y-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "12", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fz): z-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQVGUUxxlzAEEgC3VyEMExQEedAnWwPjw6FEEzRaAp4kIOAVopLUYs
D3kkuwkOsIDsQGa8HzYlqKzDwy8PgY4ouC3xRqCNiV5giqApNtDZez+/GYbZ
uff+7/n/zzm/6xrxaXDUIgsLiyj6M/+Xjwk93Z3cRvsOMIW27aGH4hfctTN8
xsH7IGty1kwGNY1hDLNThRkjmGPdW78mOY7h1/rg+debo1isj81ApXIUuyL/
9Lv072F2u8t8RtCwMJ0JeUfYeklwBF3C25T7fJXMrOasuYN72fCm2ZhjjMRI
cRiV9u+/a+qMYzvMcj7D+LDRdktkqIqd+cp8htCxeqLOflUSe+RhFhzEcNUb
LSVLUliwVOAg/vCUN6heTGdSeXUDGJJ/JfKzxi+YJGczgBW5lqH6mAwWLZ1+
dLodY1u7TcPMbrVtfTiy6kTvK0tPMsmucx8O1/rCxclMliwZ7kVN9POplt2n
mCzXg2X1v3nrGrOZl3R6cOLY06bdZ3JZniT4MyZ3Ob06tT2PTZntTnbj3b6c
mq1r8pm/ZLgbuxTaA3Zz+azKLFdpxJenlz84fKOAyf0wol2E4om3+rTI34DF
/31nFb+pkEm3K2/jyQc+nptbC5kUh0cXLp/KzS7YrmPjUp63sL2Q711cpBP5
3UTtZS+1a79O5NWB6qMOAcZZncjnBv7kfScyYFon8riOXlXaKZdbOibJJV3D
um3LPnwnVcc8Jb/tWFGvnt9opxP+fsTTqvPWWfGFwk8rFq2PDSlqeVb/VWw/
rJ9+MlQg6uU4/kLg77wvnxVL9TWjqcqjJLg+j1lL9TTiQkngx6u7c9lx6f16
3B8S7gdW2eJ9F3HiuZyb9pZZQr8OQ6I69G49GqH3La4JaXCtjTvBEqTnq/Af
/n2q33gKuyDdX4Jlf43arC6NZ+nS9UIs/cYqokYRI36rMWtiaEdCcjh7tiEv
KcoT3S3aWsR1uJlqeo+uc/E8rFE5fkLP81ZZH2pXHXEgfXG9CgyH3syg9/My
uT4IdLRcR/WJ++vg0udrG6l+fl/2B+0O9zrJH5fr10Nac4c/+eciH/hI0XaE
8uEiPwiyiS6l/LjIF85uzPuD8uUif9jV8vgB5c9Ff0Bp37Sf+sNF/6DB7dES
6h/fIvcXjoJhgfrL5fyvgW1FaCT1n1+T5wNWGgfu0nzwpfL8QNicSzTND98j
zxcE5gW9TfPFz8rzBy6LYjU0f9wkzyd09s/so/kU9XaB9vHVHJpfLuYbAs9H
edF8i/oNcDzsljXNPxf7AZsTlXO0H8KPEcr/dp6h/eFiv6AsI1tB+yX8dcOU
LrWW9o+L/YSMBgtP2k/htwdq7p1rof3lg/J+Q0+a6jXab+G/F8aUmWm0/9xF
5gOcW1a+k/jABT/gsu/1PuIHF3yBlIDipcQXLvgDi9euPED84YJPMO2ujyI+
ccEv6Kws0RO/uOAbXPAZuUJ844J/UBO+5wLxjws+gmF+91biI5f3fRhu5CQG
Ej/5lzJfobR6dDPxlW+Q+QsbPqiNJf5yg8xnCI5TnyI+i7xH4eAhf3/iNxd8
h/sbNQvEd5H/GFzuXZFA/Ofi+wDpYb6z9H0Q/TDBivJqd/p+8P8B2iMyYg==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1VXtQVHUYRR7yCJssxomHIFmJhNkoaurPPgIGzCIUAbXIEMRJoJAKQSgF
hpeUYEXxyBjUVWRHVkAEVn74rbAsyGtAnvFYtrAckj9UDKzJoW/v/fmb2dnZ
uXfP/c75zjnXNSIuKMrUxMQkij7Gb/kYMEqv/njS51sWlt/8t1vYJMZ/035K
mXiaNThn3tvVoMeig0s/KLD/gdmp/H9LttPjyuO97SuW/MTit9kMnz8ygV6F
M6mRe4pZd5fxjONhbun+539n2GoJcBwnDzmcbUotY0Y058wxZN/N+1vWnmME
Roij2Hg33WmL/QX2lhFu2yiuLvIa/7mqnJUUG8+veNfpim3dMSWbczMCjuD8
bNcJ+KKSBUkDjuCPvvFWGQFVTBpPNYxnT65tmJ2rZhKczTAOTrdND1+9yg5J
ZwjNBzZWfJ92jRnZ5jcPYtiIU8iTsHom0XUexNj9pxYOe6tZikR4AHOr71hd
WtPIZLh+LErnL9o6NLH10unHlKCEEymmyE5LgLex8nJcYtMRDZsx0r3Xh+WR
dWvK9t5k2yXCfWg45jwxtaGZKYxw53uxvc7PIcGihcn76MVJV/NLW7UtQv8e
PA4vNa6K0zLp9iPdOPeHoQTMWpkkh1sXLpsM9Kv8upX9LunZgdcePdZ2jrUK
/W7hkwfLOtc76oRe7Rg+MLG/bbNO6NOGbf9MevINOqFHK85aL8pULNExCS5Z
ix/ZOq46qmll6yS+LWiR0zmYH9Aq+N3EVD/zLF6rFXw0GK1zue0593T+G2i5
PCer9PkWMS/HrM01MTbPNLMiaT415r7yy5f3DRpmJc1Tj4qx3WYhHsi+kp5f
i+97BI+O7ePiedVov1SxLidQLfBVOFUyEmv+Qp3Aq8C5i89NpyprWJL0fwVO
RVds8tmsYlXS/aXY7ZIEQ4aLLFW6XoARBS3zTbWl4ncGlu+rqR7qz2NPE/KZ
ab1G/ebD6+I6WCgetNB1Lv4Pmx7NmNyoLeUaGR8+Vdv5Er64rgD36p2Mns/L
5PlgU2/0PZpP3K8CFdsSR/Pz+zI/0Awt2UD8uDx/Lez4XDdO/LnQBw4oeyxI
Hy70g4cV+gTSjwt9QZ89H0v6cqE/JNf3ZpP+XOwHihfH9NN+uNgfaMN3ZdP+
uKe8XyjNtx+m/XJZfy3kP/7EjfbPtbI/oK4xIIv8wW1l/8DY2+4byT88WPYX
dBx7OZz8xc/I/oNTDXu7yH/cIPsTws976sifYt4ueNUvw5/8y4W/4cod2zPk
bzF/D0Te8uXkfy7yAYt9nCooH4JPL1wo3O1I+eEiX+Aa4aKnfAl+fRDMla9T
/rjIJ/gv2pNE+RR8+yFp5+o0yi8fkfMNhxNDHCjfgv8AuKdH2FD++Qq5HyBu
7X2TaG81F/0BR62jQqk/uOgXUP17UEn9wkX/wM7O8b+of7joJyiw81BTP3HR
X/Bebqg19RcX/QaHAmPSqN+46D/w7175LPUfF/0Irl55E9SPXM77KORvvbyc
+pNnyf0K199d2E79yt3l/oUQMDtH/ct75H6GNxbKXqN+FnpPgHdJUDr1Nxf9
DqFbrTqo34X+eugqdPmQ+p+L9wNkK6vz6P0g9mGA0nd2HKD3B/8f0ho/sA==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQtQVGUUxwlNQVYxpTQslJoK0EYUJhO+9UiJYuUDlGwaQYV4DJNBFoO7
IhmCRYNZE+U7ERZCSNIRYZVvPIi81uW5PBbXZdldmgIFbASaHMg6e+/nN8Mw
O/fe/z3//znnd71jkiPinJ2cnOLoz/FfPlZcPdWbdjy1hO08Vjvhs7MfH5w0
zNVm/Mq0Xtn3w7UW7FpgUGmyLzGP8g02tYcFexQBw9vmXWGfKmcZC1P68Haz
7UD90FXW0uw4Zhxfa4k0u19jvpKgGaelrm8yf8WZQ80r+y4GWU8WefvVMBIj
RRNmX80P2BRcy9Y45JQmVCy9uK4krY6dOuk4d/AXW3p6o6WB/e3jEOzFlKSg
gpxkHYuQCuzFvTkjoTN8mplUXrkRj+asnPPF021MkptlxDLDmZV+zh0sXjo9
uKxm5/P/HTMwh9tjtd2Y8XnluSzfLibZ9erG5TGj9lx9NzsgGe5C56OTOtU+
I5PlOjHiI5d/3/a8wwKk04nnFun1WTdM7DtJ0IAJNVUPMz80s2GH3fsd2Kga
fvatoT4WJhnuwNjSot/y4vqZxiFX2I7TjfMVC+OsTO5HO66prF1kc7GJ/Fux
8oR+edZpG5NuT2lBw9aEXZ952pkUh08zvqqcfw8O25ldyvM2Tltn1xR12kV+
Ohx7prDtR9cBkVcT7s6c6Rby8oDIpxFV1Wn+SxYPiDzqcUWjf8/kpJ1Jcuo6
XHxT+f5DrZ2tlPzewswWX5YeaRf+bqLqbphbcodN+KnBkvUfRz1e9qT+G9j6
05yE6kSrqJfju+rjY6+49bMTUn3XsNCSuyXPtY+5SPVU4alzI7FjbSaWLr2/
AseKZ1jnxvSK913G+FWBdRvruoV+OXrs52+mTxqE3gWcfnFzyj+KdrZfel6D
LrP/aLRN6dgl6f6fMeSRMryr7BY7JF3Pw+dcUVkaf138zsLwp5y/3/RlKXuy
IUFtpRPBe9yrxXUwb9fm03UungfFhYJQep7XyPrAyt6IJH1xXQMql0E9vZ/n
y/XB0g8i91F94v5yeE+jC6L6+V+yP2hShzWQPy7XXwHR216yk38u8gHfG3Pj
KR8u8oPZr1eFU35c5AupSU0TlC8X+UPVmG8i5c9FfyD4UU409YeL/sGKwEQF
9Y8Hyv2F15zeUVJ/uZx/HQQMRe2g/vM6eT5AN7zFSPPBFfL8QG5v3gqaH75d
ni+I+tpbQfPFz8jzB7EPtO00f9wqzye43ntYRPMp6m0Go+bF+zS/XMw3eB9K
2k3zLepvhdHiBn+afy72A0xtFS/Qfgg/7TC+dsqxP1zsF+Rb9lym/RL+OuDs
zB8W0P5xsZ+gMW8Yp/0Ufjth76p1LbS/vFfebyhYlvSY9lv474L8wVA97T9f
IvMBBj7x/p34wAU/YPNhQz7xgwu+wNmtMZ7EFy74A9qjuQHEHy74BOdH/3Qn
PnHBL4i+ot5A/OKCb3B91/lC4hsX/IP6FjxI/OOCj6De1hpKfOTyvptAmVwQ
SPzkR2S+gs+RjGLiK/eT+QvnN5p0xF/eKvMZWleH7CA+i7z7QBO78CDxmwu+
Q863ISPEd5G/BQZPczXxn4vvA3wTlTCPvg+iH1bIvhSoou8H/x/aD08M
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQVGUUxxE1bceCMURiFHlI4VLZgzLwo5M5pkWTgmJgxIIESTiCMoyo
RGhC0ExKY8hjSFFBcMoFxh1A+YaDsPkgoOW1KwgLoiACIiAsCpqdvffzm2GY
nXvv/57//5zzu07bo/3CLS0sLMLpz/xfPj3YYPgq4OU5VSzoaM2kW1A3Jgc4
Zuv3X2YVDslDvhVGTOpcFjy1Vsts1Otv7bcxYn3HQIx92FW221thOBPThfPK
js1O66pjDfXm04nqMoXPo/JGtkIS7MRDq9dMv3GgiZnVHJJv4sisaNu2hhZG
YqTYgaF//rPCuEXPPjLLeXdgpbVDy0/W7Swn23zaMT0qpdjLopOZ3MyCNxCf
To9nOXczP6nAG+gf+eKFPK9bTCpPbcDlzv5tO6Z7mSSnMKDtpYWbv2+8wyKk
o8fJWtfxzgv9zOz2aE0bFqatDogsHGCSXYc2vFJmVaMsGGQHJMOt+GakhZOm
aJjJci04PHS+xu78CHtPOi0YHJa5LmHrKEuXBJvReVWUfr3vGBs22x1qQmX4
YOudteNsg2S4Cb9eUnzW3f0hyzfLndFhrCLx+O3ZE0zuhw7z+z6x0dVNiPwb
sfyiJr8qYZJJt8c04KMBrVuGrYlJcbjVY1mcpWNIhon1SnnWoesi9c8hJpPI
7zq+pDk0bbdqSuR1DePqXq8M9J8S+VzFuHWng3w2Tok8/saNhXuv7XWZYpLc
fi3m5kzHNOlM7F3Jby068lNHKraahL/LaPVXUsB/mknhpxozXZZ49g89r78K
d3772Nr1yUNRL8dz9wrOGvvHWZZU30Ucs2uOPnV+jM2X6inHke0P7ob4jbIE
6f0a/LE9NqhLfV+8rxQTla992Zc4KPTVGKv5rkxrf1foncMzaRUZD1Jvs3jp
+Xz0fOD228m8blYi3X8Ci0JTrMNGDSxJuv47PlaoYlXWOvH7MIbuVGiTHKvZ
8w2JX/nLhMLJpVJch/XxJxroOhfPQ+rnb8XT87xa1oc8p+BFpC+u58OvbguO
0/t5nlwfaJTvZFF94n41pIUMVFD9fFT2B6W5xZvIH5fr18DKfS+oyD8X+cCR
Td73KB8u8gP7H5bvpvy4yBeO7XpSSPlykT8YUjYvpPy56A9Yvb/Pi/rDRf9g
h747kPrHPeT+QuNcy3TqL5fz14L78LY91H+ulecDfJv012k++AJ5fmDOvGff
0PzwLfJ8wSNDEqf54rny/MHbVfoZmj/eI88nZP87k0rzKeqth8o/NjjR/HIx
3xDqY6mk+Rb1N0LshwMFNP9c7AfsSohaRPsh/OjgZnNOJu0PF/sFxk1YSPsl
/DWBKux+G+0fF/sJ9gdDDLSfwm8LLMtL/JT2l9+Q9xs8elVa2m/hvxUiLmU4
0/5zR5kPkHI4tZb4wAU/IMIjK5D4wQVfYFtfxEPiCxf8gWIHzy3EHy74BBdq
QvXEJy74BSVhT8384oJvcHKpZoL4xgX/YHHQK6XEPy74CEWZB1uJj1ze9w4Y
PTXfnfjJU2S+gs1nqYuJr1wp8xfWlHrOEH95o8xnKDmNXxCfRd5d4L104Vzi
Nxd8h8xZH+whvov8jRB95WMV8Z+L7wM8w1dz6Psg+tED2vg52+j7wf8HZo9b
ng==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQVVUUhq/yuKIpVIqvpBCGl2OMIg7YPix1UB4hA0oOI0hZoibZVQc1
QfOJlRniaF5fYAmmjs5NxUh0H5cKTInAcL0gyEvUxERI5BkQ2rpnb/cMw9zZ
56yz/n//69uunxrmJw7W6XSJ9Gf9L1Yjrl/U2OB9rIzF773Z5RV/Hzs/qlKd
75jZZZe0Z9GXGzA4NsLt6KkKNtIU8iBlZAPmx7l3JlRUsTXK0Krs1fU4M8lp
+KXFtay0xLrqMLApdm1M6H3mrRWswzXFax3Hljxg1mouabV4Ify4/0SvvxgV
o4o1GLeqe5RPfhMLspZTajB6clDrZ1uesiOHreseNo8ccjIgpYV1e1kLVmNQ
zu65vqefs/lag9U4wfJje9KOF0xrz1SFueM3tceHdTCt3NAqNGbaQrZbF1um
rbvYF53ntcKxh1nV7r1ZiR8mOy8PduhlmlyXSszsuTp49vB+lqoJrsC2tjEX
HzgPMFHOglGP8m67ub5iftqyYNy2dSvD9+uUDK3gHZxX9LLYlDFIabHKfWZG
O8OtoLNpg5VQTbAZd3s6vxphsFFyrOWyy3F9alb+oTBbRZxHOY42bdPZvmWn
CP/LMGHRB8tGF9kp2uOrSzGdebdc/Nhe0ezwKsH0WZGJDQ32ykPNz2IMm3Nr
VRXoFeHfLVw3x/aIy1a9Ivz6E7Mdnu7akalXhD9/4MkB7699D+oV4UcR3ktf
/6VphV7RyqUU4vf2J+y739YrUzW9BXh/7kHLSqO91HcDc2fsmP+o3U7quY7J
S9/vO+3xuv9r6LDhXOQGP1vZL8f8eQtcN46zUQ5p/eWjISHLJ7h+kDJE6+d3
DG7/Zppls07ZpH3/Ek6IjZr48r8BJr53Abszw6e3FvTJfJqw37ivJ2lhDxP1
zqBX1ubavisd7Cvt/Ry8GVV83uXFc3Zeez4La/Z9btFN/ptt1fYPYGj0jceP
Axrl750YcSPGOCasnL2ekFln2zyNcX5X5T6cmGT/M+1z+T7MXnq8md7n10V9
2P9JVDXVl/s5UPmU/0bf5z+J/iDJ9WU99SefN4HnknF91D9vE/qAGeoCSB8X
/V+CuKxn7qSfS3+gILbGn/xRpX/Qu6RrEvmnSn9h8yHTRPJXlf6DeeewKPJf
lecDj3Zm9NP5qPL8wHzgyQI6P3WaOF/YVd9fQeerCv8LoVnVD6HzVwtFPmD7
1FoD5UN9Q+QHPEL2bKH8qDEiX7DhVMi3lC/1mMgf6B8uPkr5UxtFPqHmh3cM
lE/Zbwk8aTm8jPKrynzDqDe/aKV8y/7LoNgveTnlX5XzAYHbfx1E8yH1lENk
wvUrND+qnC9IjZykczTYSH1mGO9nBpo/Vc4nHM/59zbNp9RrgfR3lyTR/KrV
Yr4hwHdNKc03F/orIM4jL5fmn78n+ACh/syW+MAlP8BpbMoK4geXfIFhPQPe
xBcu+QNTnabMJP5wySeIWJjeQXzikl/g2Z3eQfzikm9wLnBeKPGNS/7B8lOZ
vxD/uOQj6Pec+Yf4yMW818Dt1BmjiZ98l+Ar3Om8Np34yn0Ef+Fy72on4i8v
E3yGSocxycRnLvyuhylNxhHEby75DpXfbewivnPJf3COSXYn/nN5P4Bf291r
dD9weX9AWqmxke4P/j8wuSi5
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQ1MVEcQx4ECIRarwJ0gUIORBk6v2iqCsW8dP0C0NoooahtoQhM0sW04
CrWtoqV+JkYjCRA+w2k92xJaxEAV27cMgigiIALyLeJVG6scyileUKmde7vd
5O5y2bfz5v+fmd/O/iw1PsXNxcUlhT7OX7GGMbtpOM9+bUBJPFE/Hp54B0uL
rvSsNQ4rNbMOPdpYM4RKdldIBLcquorYu7t1Q5gQdL9rsOS+ksam9Jw23cb8
iaRUz/YHSmuLcw1i37lfqh98MqIYtICDuKPqcen+kCeKM9qsQwN4qSvnaeZK
u0LBKGI/mk/e8TXkPlOWOcOxfvxmtED5Ve9Qigqdqw91uomyjCsTyvNwZ8Be
1NW5Z4aeeaXEawn2osk90Lbv7GtFS6+iB1MPHl9rTHPVsqMvLNwxp7Yx+A22
XVvd+PnCIrujx5051Z6ov4Xm9dNm/mb2ZJrcWbewpTE5cYPJi+3RBHfhjeSs
u60xU5gI14kxtS/dzgR5s0Xa6sSCVaeu/zMylWVrATtwTXBN4bbqaWzEKffR
TewLnpe46Px0tkYTfBNt1gVx5Ud8mMUZ7nQ7Xn03Qvl5nS8T9WhH1TvHsOS1
LxP+t+FowpaW78x+THvc1IpjEJZpNuiYZkd4C8aMbA52LdYxq+ZnM043dpSE
jemY8O8abqnOq+s16JnwqwkDQysHZq/SS3+u4qf+X0cnf6CXfjTi3Ie3lq33
0TMt3O7LWDNuj3zdoGMLNb0NGL0SFozG66S+S1iZnr3lJfeTeupw++Lo5i89
/GT+tbhpZ3q+3eAr81Vx1/OooCKjDyvQ8ruI34eeHel8azrz0vK5gDH+sZ6d
lqksU3t/NQ6tqyp9bJ8i33cOj0YdcWn39pLxK/BekdemGw53Ga8M0w+8fFF3
0ZV9q5234GRx4ww890qp1J4vxfCL2aO7LowrWdp+Lp7Wbej9KdQm/x/Ej/MD
m3JW3Fb+nxCeG+a55osVf8p92LrveB/tq/I8jG/zvUvn1ToRH0zbXtgpvty3
gNFjaRC9Xz0p8oMf45VJyo+L5ytg5r9xCZQ/fyL0QYq1x430cZF/NRyzeJ8i
/Vz6A3Hvl3mRP1z6BzPS7tnIPy79hZTItGDyl0v/ISKssoD857I+UNV+4DrV
h8v6wd+Gjq1UPx4h6gsv5u9/j+rLhf+XISsgcgnVn18W/QF6Y8By6g/uLfoH
JuJ+j6H+4ZtFf4Fljm2Q+ouXiP6DxdFtl6j/+LDoT7AHeJRSf8p8WyDmzR/e
pv7lsr/hnYx1e6m/Zf5tsCcvrZX6n8v5gOUplrk0H1JPO/g3LWU0P1zOFzg8
5m2k+ZL6bgJfEJhE88flfIJt4d5imk+ptxNiT37USvPLe8V8w4mJY+4031J/
F/yR4LDS/PMQwQeoOlqbRHzgkh8wLSo+kPjBJV/A0djwlPjCJX/AmBSBxB8u
+QQh6uEPiU9c8gvyJodGiV+q5Bt0Z5XuJb6pkn9Q7rGznPinSj7C44K/GPFR
FfPeD35mTx3xUz0s+Ap7mgufEV/VuYK/MLaix0z8VdsEn6F6/vLzxGdV+H0b
KobrTcRvVfIdclYHdxPfVcl/CDdbZxP/VXk/QMbDs710P6jy/gA3/Vf5dH+o
/wFyQCdm
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQlFUUxxEHQUQJXURRcXcYjXjICAxS7vWMJAZCGQiUgNYsUrLlQJZo
xjYiIsJANImGGkUjNlnKhBKQfJfjA1+8BoJVEJSVhgHCUSQfiGmd/e71zuzu
7Nzvnu/8/+ec39UZ0mJSbG1sbFLoY/0Vy4JzWYC3MXhQn1R0/qFXUh/abtoF
ubYj+lqPnJHo2lvo+vSheSD8nl5T8cbtnZpb2LFvToDN1DH9J8zx+tH0m7jV
z7vBfOqBvqXZunoxyk9jSD32WP+KGrAXg4ovB5f8NaG3RvPI6cGXcn5yz0p7
rqdgFPEGVhomP1+yaBJbYQ3HbuAZl93VS16bzA4fsq5urDTqlBUZduyRlzVg
Fy73T8oM6rJnMWqCXehUP/G+70ZHpqZXcR0X529+lGk3Xc2OvnBtlXPkyUZn
9oG6ruHhoYhvamJdmFVt0XkzemZHNb3VOpOpcj3MaPoxZJl2rYZ9oQruRG/N
RHJjhysT4Tpw055EU+G7bixQXR2439k0Fts9h32tBvwTX/04pPpCtDu7Y5U7
0o5DsX73Qvk8Fq4KbscCu3nmmW4LWLk13NE2vORsTN6Q4MFEPdqwMy9t25rd
C5nwvxW3nMza7BimZerj6S3o0Ly0uahay1Q7vJrxP9/+xpxZOtav+tmIqROD
QwPrddK/q2hZ+vm23lyd9OsKZvjy+PYjOunPZcyf/YynFeukHxfREvHtgRPp
OqaG29mA0TEOe5v8dSxA1XsBs7TLMg3tWqnvHGa3FP6cGKeVes7i1Y2LH49s
f5F/PT6ttTfsm+Yh81Vwyrxkx7gP57MSNb8/cPayhK3Vhe7MQc2nBlv7NLry
rDksU31/FcaXvX23dPVs+b5KNAyb/v3BMkvGr8CgkgTFleop4h3HyZ7vHSqJ
nM52qOfL0Sdmx5Mrv9uz39Tnv8e8yoUxefcnsV3qfjFGZBenemvG9eL/HnwE
w3dHfIb0Lyak6OKDdUZzVJ3ch5W565/RviLPQ9pwZzqdV86K+PB36aU4is/F
fjmMrvN6Ru/nZSI/GFjlXkr5cfF8BWwoWFFP+fNRoQ9Od29+Tvq4yL8KNAOh
o6SfS39gdcEMT/KHS/9gklviZ+Qfl/7CjFNGJ/KXS/8hbJXrJvKfy/qAsSvk
CdWHy/rBgb6S41Q/HiTqC2+ued1E9eXC/wYw12tyqf68QfQHvOxy9CD1B3cS
/QMnQu2R+ofHiv6Cc/UN71B/8e9E/0GQlymD+o9bRH/CxtjBYepPmW8z2Nzv
aaL+5bK/YWTaohbqb5l/K1zN35JK/c/lfIBxOHg7zYfU0wb+vy5Mofnhcr6g
4hi/RvMl9bWD23jdKM0fl/MJn4afqqH5lHo7IH7/7X9ofnmXmG+Ijv/lS5pv
qb8T0lwCU2j+uVbwAaAnMYT4wCU/wHN5QjPxg0u+wGBB6H7iC5f8gV6briji
D5d8AsfIqePEJy75BZbSbQbiF5d8gykOp03ENy75B3OXx3PiH5d8hCNjB2uI
j1zM+w0INU1Y+cn3Cr5C7Vcb5hNfFW/BX8hujwwh/iqtgs/Qeyc1mfisCL9v
wlhZ3EXityL5DmFnFgQS3xXJf+gvrLtO/Ffk/QAfbXFYSfeDIu8PgMJsH7o/
lP8B+GMPcQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQlFUUxxEcLUEq2JBZjZcssEszYTg0yF6PQKgwo4g4yBiQMJImKSQq
tUiSARLi4KAmWqTCZpBJEA6+9nqIhwECgUiwK6ApWQj4YEQF7HH2+653Zndn
5373fOf/P+f8rmtC8upESwsLi0T6mH/ldQvzpsLqDtqPaWMK6sa9Ym5i7kSb
zVczxrXnnbKHI84PoFGpzn8n+plWUbHsD51iAH/4KKd30va59mM2q6c0pR8T
gk9bpzhasLZW8+rDBY8N6UXxlkwtBezDbe5Hstz/nM7M0Zyyb+CGDGPdGf1M
RsEoogkrAxpH5p6cxRabwzETBs5Kgb2m2ezYUfMyYu2EenJ22avsiZc5YC8+
7Gsz/rfbjq2WEuzF90eXWhanKpiUXkUPjsQ9W9+R6SBlR184fkfXPKh3ZB9I
63fM+6nkx8w+JTOrLajrxouDfQu/m/8Gk+Q6daPersS5aoczS5cEX8d/Q2qb
q++6MDlcF7773oW8DDs35iutLuwu7Q+3DZjPDkgBr+HGHQ0xM2Pd2YhZ7nAn
+h0JVQ1sV7HlkuBOnKrxiB/6zIPpzeFKO7DKa0tWcponk+vRgYVz3EJr1nkx
2f92dF6qvGenUjPp8ZQ2THRMOjV5Tc0kO7xacdXoX8728Rp2W/KzBQ88yPUI
atUI/5rR17Qpx/Cat/CrCU/5e++0f8tb+PMrGrtqw5e4eQs/GjHW+PqKiiEN
k8LpGlA3rFMEZWnY25LeeqwuLXkc90gt9P2Ck6kdDUM+aqGnFivfXLwtNPhF
/pdxe9XFqES1p8jXgPOs52WfHFSxIim/CxibnBFi3OnOXpLyOYea8Kbp0bfd
2C7p/WfxFf+1Fp1qV/G+KnwaO/3B6RNOIn4FPq/Ojzz2s1LEK8fN84bq2g44
sE+k83rU1XnvUQXbsUrp+W9RUVT8tKvUmmVK+4fQ6nLTwa37LMX/LHQp2HTj
ePGY9sWEFH99dc1yv6hLYh/m2OXepX2DOA+Zk3FH6TyvleODNmHxPxSfy/t6
mBtqlU3v5yfk/MB9fXMj5Seer4AQy7Qoyp8/lPVBY/nEI9LH5fzPwn19zzTS
z4U/cLhw5Qzyhwv/wHfDy8vIPy78BffIMznkLxf+w6Fzq6LJfy7qAxmevalU
Hy7qB/UfbrlC9eML5frC8eTAJ1RfLvvfAOPBSgeqP2+Q+wOUa8+upP7gNnL/
wOcTMRHUP3yN3F8wnl6fRv3Fv5H7DzRlU3up//gtuT+h8KLCi/pT5NsKYz5J
rtS/XPQ3lMcPfk/9LfJvB49FucPU/1zMB0R8+kUYzYfQ0wHt/bXZND9czBeU
XU1KoPkS+jrh8ZLdHjR/XMwnNCnuxdJ8Cr1dsKhxbBXNL++V5xvyavg+mm+h
/zok8OoWmn/uIvMBbq7c6Ep84IIfAL9l+hE/uOALaO+rKogvXPAHdOsGWog/
XPAJBjxYAvGJC37B3yu2WhG/uOAbpAUZTcQ3LvgHe0aVU8Q/LvgIYWEugcRH
Ls+7CYo1y+4TP3mOzFdozfBpIL5yjcxfCCi6kk385e0yn8F/QdMu4rPwux8u
fXnYhvjNBd/hTrizifhuEPwHdXj+fuK/QdwPoFdNs6X7wSDuD5jaHFlP94fh
f98CFtA=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQtQlFUUx8FgakhEY3WIAtaAhmfBbmQElyNNjg9M04AGQwxI1BlMG5x4
2hAFk6ADMjwEMQ0ZELUdIAgYuByEJRF5I7A8lpekJOZQI0xCWme/73pndnd2
7nfPd/7/c87vbow4tvfgKiMjo4P0MfzKawqHX1P6gueyb2hmy6JT6CTWztne
H4t55ltnmzq/p24CZ/WJtbsuGjOFZut0gmICU0M7M6M+MmFfMbPhy8f1WO8Y
rU3Y9iLr6jSscXTM23w3IMeMOUsBx7H6XuDAn+o1zBDNNnUMnZujLXoU6xgF
o4ijOO2/pXqnjyXzM4Rjo1iyKSI37sx6VlhgWCOYErr/20ozK7bkZAioQ4+c
D2MKKq3ZXilBHZqGx4yZJNswKT3NMOr0ePhrb6WUHX2h8bBLjKp1I4uS1hCW
xM9d6thnzwxqM1sGUX+hqi/0qQOT5NoOYn/3zFR22ZssURJ8BxV/eFeWBTkx
OdwA6t0C3I694MLU0hrAA0f0XuHXXVmWFLAffRPjE8oC3NlDg9z5PvTemXbP
ffwttk0S3IdpIQuN+9w8WIkh3OVefG/aKP2x3oPJ9ejF2QDdpHeyJ5P978ai
CdPljLUqJj1+vAtXljwLI0+rmGSHUye6jIzUhf6lYjOSnx34n3rlpj9TC/9u
oblDnc+GL9XCr3ZcZffsFWWKWvhzEwtdrewXYtXCjzZsCj70+PAuNZPCJWjx
QcivL2tN1Ewl6W3Fqb8t03MLVULfDeyLsny920Il9DRj+/Z/oeGL5/k3YbLO
/B/TQg+RbyOanyy1/Dz8bXZOyq8eX71r9sAu0J29JOVTiztCPi3Nt3BlSdL7
q7HTraS8NN9JvK8SvbKO2lctOIr4Gsz/uJ7n2dmLeOX4KBYrCpyVLE46X4Ke
Y+0bfnGyZhXS8z9i1sU53cnblixZ2s/B+Mie4JpMM/H/e4zNTYn7qXzZ9/mE
hCW/n+nADzSIfTidfugH2m8U5yEh+HYYnefNcnyo2f1onOJzeb8EFE901vR+
fknOD67Pd1VRfuJ5DVy17UHKny/I+qAlOsOR9HE5/2rY813HNdLPhT9QvTXt
CvnDhX/Q/O4HD8k/LvwFm6rf15O/XPgP65Y9npD/XNQHuiPe8Kf6cFE/0Gh9
bKh+/B25vlDQyjKovlz2Xwu/VUytpvpzrdwfsMPz7CL1B18t9w94xW52oP7h
gXJ/wc9N9grqL14k9x9ELo34Uv/xKbk/4amV1S3qT5FvJwzVLtRT/3LR33C1
xf889bfIvxtaz5uvUP9zMR/gqRieovkQenrB6/6iYX64mC/YPT/Kab6Evj6Y
C9syR/PHxXxCYvbGJJpPoXcAzo0c3UTzy3XyfIPqVKs7zbfQfweajAuraP65
UuYDfKZxmSE+cMEPSEqd6Sd+cMEXyB43Kia+cMEf8A9yO0H84YJPUOZ37Qjx
iQt+QXGdnZ74xQXfwPJU+wniGxf8g0+UDSnEPy74CIPWRXnERy7P+yhcuLK/
hvjJ02S+gptV1FriK3eR+Qt+QWsGib+8W+YzKDPbZonPwm89rATfaCN+c8F3
OLN9KYv4LvyfgMChb+qI/1zcD3DWanKO7odGcX+A1qOY0f3R+D/ZzBg3
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lXtQ1FUUx5FHES0YsZI4hpAtD5VpYXnsCtcDowzoH4jANEJqkyJGiihM
E5LTSLxUBoExjKfigChlK84gUHA9gPgAkUBAcAFFonIiBwwQyVE7+/vd7szu
zs793XPP93vO+fycdyZG7DY1MTHZTR/jr7zG0PkT/+isPYvYtry2ObdtD1FT
nfp6rc6cNTpmTm5pfICXc81OFMS+yZT6kEepyge4TzG899SUFTvIrAYrD4zi
yamY1fce2rA7XcY1gl9WNoJ9uS1zlwKOYOLjt2ZCFimZMZpj5jBuMn+R/aTc
nlEwimjA294LlZ3JDmydMRwzYI9NZM3ot8tZSbFx3ces/Abf4M4V7JmbMeAQ
KpKsu+2qnFmElOAQNo9blXYfXsmk9PSDiFdtIjYnqKTs6Att8k0nXiS5sjhp
3cPEr875Vhx3Z0a1eW0DmBug0SfUrmaSXMcB3HhtJODVQw/2tSS4H4/NxxZ5
WKmZHK4Pn/W+MWX2oSfTSKsPXaarbY+u9WL5UsC7qAlKi8zdpGF/G+VO9uKS
wroNGO7NQiXBvdjputhOv9GHVRnDVfZgfUeFesTTl8n16MHnEdHTXRZ+wv9u
hKYxbtfmx6THD9zBcvgnd9cuLZPscOvC3pEop9N/aNm45Gcn1j3ddXE8VCf8
60A322WFpdk64dcttMso6zheoRP+3MSYYUV6f4FO+HEdP0vbvsIyRsekcKnt
eHdN1F8uz7XMS9J7DZN2Pm68sFcr9LWiV1dH2Dd1fkJPC96wVhTb9vmK/K9i
tH+TYf0tH5FvM+4PPD4fX+jNiqT8fkaX+veXhARomKWUTwOmDdr3W6AnOyzd
X4eDnuVxaie1uO8yLg8NK9x8fY2Ir8dHYVcGvO3cRbwa9Npq2T6rVrEU6XwV
3kv51+VPlTOrlZ4/jXrNqpdZMw7siLT/HaaU3KxdFm8r/megxdmci2api9j/
E9KkVFkHVcc2iX34VPFbPe1zcR4U+oUrdJ63yPEh/HycafaMg9ivgsCGM+50
P6+Q84ODmvoblJ94Xg9nlAlDlD+flvVBytQ7RaSPy/nXQU+Q+eeknwt/YKIp
fYD84cI/+HFLvj35x4W/8ApMF8hfLvwH2/e0I+Q/F/WB7W/nllB9uKgftJiG
hVP9uLdcX/DG/b9QfbnsfzsEHhqepPrzdrk/gMdPOFF/cIXcP/ByriCD+odH
yf0FDtGOt6m/eJncfxD0wfenqP/4mNyfMNBq+In6U+TbBRfmrzlT/3LR35AT
uDWP+lvk3w2XIwOQ+p+L+YC5zTVPaT6Enh44uXTCk+aHi/mC2fsblDRfQl8v
dI0PB9P8cTGf8HFOcRTNp9DbB+atl96l+eVD8nyDavS1cb6F/n54sjSsmOaf
O8l8gD1+eeuID1zwAzZ9dOMS8YMLvkByioOW+MIFf6Dki62/E3+44BPsTAqJ
JD5xwS9ILXUtI35xwTc4dGTxr8Q3LvgH6zXHtMQ/LvgI5gFzPxAfuTzvBjiq
SDxH/ORZMl+hoS7kGPGVr5L5CzvOqmeJv7xb5jPsy2kOJD4Lv0chNnilB/Gb
C76DjyE+gfgu/H8A1uk78oj/XLwfYFx13sRfZy7qMQaZyeti6P3B/wM8dAiP

          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1VXtQ1FUUXoUcEHoBDuToxjMWSl7C8pDLSWZSKEsejY0K6ZAiFcSKTKAG
EQEOj5BGSOzN4w+0BEwKgW5HnkYDyMrThd0gTKilYhKFYYTp7O93uzO7Ozv3
/r57vu985/s5JaTGHF2vUCiO0sf0K68pvPRZavTeSXMWd7bjviruV+y1Pv12
X6AFu6bMN0ZfM6BbZfIffqtWzK5+9/QpOwOuZP7b0P3UE+w42zhWo9Fj32qE
vkpjw/r7TGsS1SkXb648sol5SICTuPp4a6HdpD0zoSnzJzDzi3svFy1uZgRG
iDqMzj3h6RWlZGEmOKbDFx4svJO+5Mg+vWBat9FZ21HQP+vMHqhMgONollye
rFh2ZTFSgeNojNxwYs8z7kwqr34MW9yr13ZrPKTq6AutXTd53L71LEuU1ijG
MbcW3xe9mInt2Y4RrJz21swm+TCJrnIE7bXzJWHf+bLTEuFhXE6wDfBZ82My
3BA+dieqLCfSn22X1hCy1aeL68sCWJkEeAs3WM59tXZTzeZNdI1a1H7gUHXG
LIhFSIS16BQYHrHTPZjVmuBqBnFiNiDULjCEyf0YxLvsmI/Ra4fQfwC35Npe
7doYyqTjmn7MX2hQd/eEMkkOVR9uS8s2RBxi7DdJz1/wao36k8VBJvTrxdrR
inU9DmFCr5+xdDZc5+QfJvS5gWOvHDo85Rgm9OhGB+e2c6/pGZPgTnXhm2a2
ijeSGPOT+HbiyaHVh0ntoYJfO4YH2O+Pn9sh+FzH771jstv1IaL+nzBjzNKv
ujpY1PsjRmzd43YuKIhVSvW14JEG+8q6KjWzkOppxuHz3nGpU/7sPen+Jixk
BwtnlvzEfVfwb7fYgESjj8Cvx9YM48qRrG0C7yJGxidG1RpVLFN6vha9FlN8
XT1dWaN0/ku8bOjYMPGhkuVI++Vorsge6ci0E//z0Dx91qa4xJz9PyH2ecM5
tYZjbWIfws0mlbTPxfPw+qM5E/Q8vy7jQ1ql1prwxX4ttP2e5U/386/l+mCX
LieW6hPn62Gn0maN6ucLMj8o9fhLTfy4XH8T6GIfFhF/LvQB87tj8aQPF/rB
vc03LpB+XOgLiS+tdyd9udAfgr16tpP+XPQHRsZtc6g/XPQP4p31B6h/3F/u
L4x29qxRf7msfxfMFenXUf95l+wPWG7MryB/cGvZPxAXokog//BXZX/BSprF
JPmLfy77D7JC95mR//iU7E+YUC6cJ3+KevugY5f3FPmXC3+DR/q+IPK3qH8A
ylzqm8j/XMwHfFO86EvzIfgMwnxFE6P54WK+4H2XK5E0X4KfFuab362m+eNi
PmGx07+K5lPwHYKRugMlNL98XJ5vMG45+THNt+A/DCn3VWqaf+4o5wNA8z8f
UT5wkR9Q97zjccoPLvIFlgqmWylfuMgfOKy77En5w0U+wfJbDooIjQcX+QUu
moPplF9c5BvMLvWmUL5xkX/QnKQ7Q/nHRT7CzP75VMpHLs+7DqrzA56j/OQF
cr5CfHneXspX7innL5T+sLWY8pcPyPkMqoyZQcpnobceLK3iDZTfXOQ7DFjd
aaR8F/ob4NvcJ42U/1y8H0ClnEum94PoxxT8OXwpht4f/D/YVxeZ
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQtQlFUUxwEHQzALIymg5c3wGEjYJRS4e2zUzCHUTFAXMNJBEUhJhhlC
SWoCYcoxCQuYeLUmgw4r6CoQXY/xWh4r8RREQESNJnLQccCy2aaz33e9M7s7
O/d+557//5zz+9z3Ht6eZGVhYZFEH/OvvKbxaUbzeEfxUhZ/qnXBN/4Ono92
CwwMtGVNiry595umMMRkDP4idAVz0G26m+0whdEGn925Gnv2CbMd1aZPorZ2
IPuNW6+wG0bzmsCoDdlth0pXMT8p4ATmBip+aix/nZmjKfJu40v3V545MevC
KBhFHMdSa4wwRrgxtTkcG8fC6Y/abvp4sLJS87qFNvcKJ9aqvNiirzngGBpU
YQmX9vqw7VKCY7giVtcXW+/LpPR0ozi6J1p50ilAyo6+MMIxxbCkIpDtl9ZN
PLjOpSrWeTUzqz3VOoIhVTk504eDmSRXMYJFs09b7nSHsKOS4GG83PPsIvNR
MTncEP5ZEF367eehTCmtISyKP9mjHHuLfSMFHMSXTZXLQn3WsL/McucG0G/H
PtPxA2vZu5LgAdyw6Htw6vtwdtYcTtuP6g1h9+0uRzC5Hv0Y/mH+BYM+Uvjf
h01KR9fZEsak4+k30H3xg4zkODWT7PA14uXfMp3y/lazGcnPHjQ1bE1pSwPh
XzceKVhj88IVEH51oeN7z3SVfSD8MeDSC+rHMY0g/OjALr/1dZkfA5PCZbfj
8ZW9/47Mq1mIpLcNk1PZ0SmmFvp+RRenjPnCnUzouY6XgvQb97Pn+V/DbT+e
di96FC7y/QUj4or9mo6sZSVSfs2YHBq+26YzjNlI+TTitbTWmjcfhrJj0v16
vJL46a4tc0pxXwPWnsvc/LAtWMTXYYFVmceDhSARrxb3pWcdCPDzZ1nS82dx
o03H9hp/b1Yvna/A2B7XgY4lbixX2i9G7aPqsIpjr4r/X+I70SYtO23Nnk9I
/RNrZ++w5BaxD/ZXFfW0z8XzELG1hdHz/LocH+59pRym+GL/LPyeOBND9/Mq
OT/IKKlOofzEeR3cGer3pvz5I1kfzJS+FkX6uJy/Ht7e6aUh/Vz4A7fLM2vJ
Hy78g+XFCxryjwt/Yf2ZnQHkLxf+w9fu8Z7kPxf1AZ1z3iaqDxf1g7zEzY+p
flwl1xem0TGH6stl/9vhj39qTFR/3i73ByRZul+k/uDL5f6B3AbnJ9Q/fIfc
X/Dw/HA99Rf/Qe4/GExYYUv9x6fl/gSNk2sa9afI1wiR85Eu1L9c9DdUWNpn
Un+L/PvgalaXG/U/F/MBkVH+dTQfQk8/WKYaH9D8cDFf0LRKl0LzJfQNQFz8
6H80f1zMJzQtt7Kj+RR6h+BE50QvzS8fk+cbkocKy2i+hf5hOKrzbKD5524y
H8Bzy4uc+MAFP8Cr+vhnxA8u+AJWCrtq4gsX/IG6BI9u4g8XfIJ1m+6qiE9c
8AtSQ1z7iV9c8A0MBfl7iG9c8A80muZJ4h8XfIRtGzPaiY9cnvdxiAnTRxI/
eb7MV/D+ues74iv3l/kLvbu054i/vE/mMzhoB9uJz8LvSahcZnmM+M0F36Fz
fLWG+C78n4JDNeVK4j8X7wfoWqcPoveDqMc0qBwcJ+j9wf8H6N4LOg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtMVFcQhqkiCCg+AKVVeRVlRcGyPBXODgrBtrGJkA2kqBUQqE0RQbAB
q9aCoKk2K4S2CBZRUUspoARBg6ezReRhEFh5v5eStiiaUokipI2dvfd4kt3N
5pw7Z/5/Zr7rGHMwLG6ekZFRHH0Mv/LSY+Rs7DajSRO2W1P/QrF7FG1PJr31
xwlzdtsuazL09giOZkZdm820ZNYV28eOWI/gmbLyqKPHlrFkZt57JWkYn+tX
jLx8YcUethrWEFZOOP74X/kKtl4KOISflzus1Vx/mxmi2WUNouUnH/TMjK9m
FIwiDqB9dcDGfg8HpjKEYwP44Jc9HztbObGC84bVj3kq3xOrbJzZS4UhYB+W
plnF7fdZx8KkBPvQTd+x0OawgknpVfTi9fkW5zLaXKXs6AvXe3Ut3gduLF5a
PXj137OlNfc2MYNaTX03WqYlBsVv8GCSXLtuDE3fo7+SrmRfSoK7UL/3Unhe
iyeTw3VisVNw4LOV3sxTWp1o2jhY7BTtw85JAR/hjkfJU8mXfNlTg9xJHZoF
+1n83eXH3pcE6zBhpbo5d2YzKzGEu9KBpjXw+MMF/kyuRwdGXtAaW8z5C//b
8Du7J8YjugAmHU96iE3K7qaZ04xJdiha0WSJ9cHGVSr2u+TnA/T6ounJvFMq
4V8L3t92I0zbpBJ+NWN8S3pp+qBK+NOEdVEx1Wu0KuHHffze/dZl21QVk8Id
aUDTuHj1rpeMKSW993CjZ55zVAgT+n7DRxWFSrfYAKFHi4477mxW73yT/694
vLH2nSmLLSLfu+h4wGhHcb4fy5fyu4P2ppeSM175sIVSPrU45jv9qau7Nzsq
3V+Nqd6KpecDPMV9N/G9QGN3pYuHiF+BtWkFQfvG3US8Umx7XpsRGLiepUnP
l6DZYMjSnAPO7IZ0vghjbgW9Wz5hx05I+3mYkzA+rauzFv9PYm5upVlGuzF7
MyH2oaF3j83F1Yl9cHldZU37XDwPmp2Js/Q818rxYXnBsILii/0SyH29xoru
58VyftBbWZhF+YnzFTDVczaE8udTsj6o/zZrE+njcv7VUKisWkb6ufAHMr2y
PyN/uPAPXlmyFPKPC3+hOuTqR+QvF/7D0HTsavKfi/pA6OJEf6oPF/WDgQUR
XlQ/7iXXFzSP1euovlz2vwHyl28Ip/rzBrk/IHzr0RLqD75I7h+IXutaQ/3D
1XJ/wcXUwDLqL35B7j8om0tRU/9xvdyf0Lkr+yn1p8i3FX7Y3ppE/ctFf8OZ
qZMt1N8i/zYwK9WYUP9zMR+QFhFpQvMh9HRAnaL1Cc0PF/MF3VO6FpovoU8H
RXuvLaL542I+oX9L+z80n0JvJ3xV63KZ5pf3yfMNjebHt9J8C/1d8OdwcwTN
P3eQ+QApuw+NER+44Acc4knBxA8u+AL6woQy4gsX/IHQbM0S4g8XfALds8s5
xCcu+AWOWSHmxC8u+Abtm/bHE9+44B/8/E3C18Q/LvgIlcrDkcRHLs/7AEx4
+LkRP3m2zFdw/8uij/jKXWX+ws2UqnXEX94m8xk8L2YXEZ+F38Og9QgbJX5z
wXeI2ngvmvgu/B8Bm56Qn4j/XLwf4G6r7Xx6P4h66KH7VHcQvT/4/zYtDJw=

          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQtQlFUUxwkaIwqUIBVNlBjjEeDGQijs9ciMpWWUCFhsoMUjILKwqYYA
B4dAJ6cCVgSURZ3x/WDD1BEGr2d5aK4iD5EAgeUZmjwthOGVnf2+253Z3dm5
33fu+f/POb/rFPXVllhzMzOzWPqYfuXVjdMx66LG4DkWkV31xDWiCy23JQW7
1VqxMsesweAyIw69pA4d1tswe92GnhR7I+5wTjvgoLFlO5lVy7GkToyPcKov
nrNjd2pNqwPXP7tj1vPEQuYmBexATdS0ZfQ+B2aK5pjVjk+nAnJcdK8wCkYR
76NmOLE0yHIFW2sKx+6jMkbzT2qrEzt00LTa8Ff/PasqbjizCVdTwFbcO6uK
1DauZFukBFsxJGTXoqWTLkxKT9eC0+GLPfN93KXs6AsTkl3Gbu3xYJ9J6w80
L7l+uukvL2ZSm13VjDk+dfq88womyXVsxjJsX9T84A2WKgm+h31vj15rcFYy
OVwT5pl/HZ0Y6cOU0mrCTJtvVn6Q68typIB38WzalpcnK95kQya5g404GBof
XtHmxzZKghsxP25CbxxYzY6bwh1rwKnymZTirjVMrkcD5obFFan0/sL/OtzV
njl/SVYAkx5PuoPTvaHaq+4qJtnhWoujBbbpfSUq1iv5eQtbl5x758ALTPhn
wKGH+Yc8A5nw6ybah17+KOE9Jvz5HQvjh113vs6EH9dxn4Wxt6dDxaRwKTWY
ntPbfne7inlLeqtx/qzh77aLAUJfJW7c8Lzaus1f6NHj3meGFRYNa0T+19Da
Mtq6/uBqke9V/LT755Nzfn6sUMqvHIuMZe2/nPdlllI+V7Driwn1yJSSpUnn
X8IfDQleg696i/Mu4PuqJ9/p3BUivg7HHo16Rrt5iHhncOqnlgXxBheWLL1/
HPcPJC2PYs6sVHr+MI6nrqsOW7qM7Zb28zBl+fp/72XZif+ZGOhQizaFFuz/
Cdlcst1eeSOqQuzDQ4Ovgfa5eB/W1ZhbNGfZcb0cH2w85t+k+GL/OBzx7HOi
8/lROT84E/WhHeUnntdB8f50BeXPx2R98HTgrWTSx+X8L0H3TPUq0s+FP/C4
QB1B/nDhHzgpXDrJPy78BXXgvNPkLxf+w7xlf9qQ/1zUBw57JHtTfbioHxSd
035M9eM+cn3haEbMONWXy/7XQPpIRifVn9fI/QE/VGb0U3/wF+X+gbRHee7U
PzxU7i940BOppv7iWrn/oOXKWi31H++W+xNUWzdvov4U+dbCt5//tpv6l4v+
hlXpo8XU3yL/OliQuciW+p+L+YDimDEtzYfQ0wBnTn2fRvPDxXwBr4+rovkS
+hohfea2muaPi/mEoOBTC2k+hd4muOlV/hrNL2+V5xuCK07G0HwL/fcg1t5O
T/PPV8h8AKugkcXEBy74AYPh9ZXEDy74Apc9T5wlvnDBHziS2f+Y+MMFn6As
+6IX8YkLfkFQ7uRi4hcXfIPq8IJtxDcu+Acjc5UK4h8XfAS3mdJx4iOX5/0+
JPV/eYH4yffIfIWwIWsN8ZW7y/wFr4oiK+Ivr5P5DJuUPXPEZ+F3JxQ0JTYQ
v7ngO3zy7tF84rvw3wiauIitxH8u7geoclGG0P0g6tENGbcN0XR/8P8AK4wj
3w==
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1lQlQVWUUxxlAckwHJczGiEFBIDbBh8TyPo4LYiPMWECDk2yaOmIm4lQi
UIIIM0CKMsomoygvi2peoIwi+HFYlQoevEBAZFNRKZxEZHkhS+fd+/XNAMPc
e//3/P/nnN9dtTsmaK+hgYHBXvrR/5XPIJ5I8Syd/2chC8uqm7APG8B7NUat
Gy8vZhWWqSMfV/RjQebdVtOIpcxcvfVhvHk/zmj/ioy/YsZi2aKu4sN9mA21
fg5Wy1lLs/70op27bcBI9wr2viTYizVG/q2jLSuZXs0y9QH63T4xXjn/HiMx
UuzBiBid49wNK+arl2M9GD31aXJN5mpWkK8/9zGUj9988xsbNmmvF+zGA5t1
G3zTbVmQVGA3Fm/feGWN2p5J5am78M6j/h91ww5SdfQLowqKPwrxcGb7pNOJ
Zbq3K3yy1zK926y6e7jmiOb6khlXJtm1vIdDbgtM97utYwmS4Q4cMA65uGOf
gsly7fhlzJ39rbnuTCGddhxPXHk2vW49OyMJ/on56xz5u4892HO93REtXsip
Gpud+IB9KBnWYk7AtDpvypOp9HLFbXiSl7wMGvJicj/aMME8/e+iCm+RvwYP
Pnn1wizWh0m3H27BuF6bXXsWKZkUh30zOg4cWJ6RrGSPpDx/x7Il78xgu1Lk
9xvmTulyzs8pRV5NGJ6eYvjvvFLkcxcb1VsCNnQqRR6NmGLY3++apGSSXHwD
Rhv4TRnP+rB1kt96jI08NXoo0Ef4q0W7uO6MgkPewk8Nuvldc3Da4yXqr8ax
zAgvXxdPUe9tDH1g2R6m8WB5Un23cHx6x+vj/uvZQqmemziZ+OSccb6CJUrv
L0eXM6pIVZObeF8Zdp+NP9pTulboqzHeorIvJtdR6JVgxPT1jSzQjsVJz6vQ
OL/+6NPO1axUuv8iKjKS/bu+tWBJ0vVzmDv+9RdOFm+J/0/ii+2auTxnI/b/
hqiePQxX2ERVietQqnlmku9sxMXzMF9+Opae5zWyPhiH/ryN9MV1Ffh2DB2j
9/MiuT6YOzW0meoT96uhUT0zQPXzUdkfjO7UHiN/XK6/HJJGe6LIPxf5wLWv
7HIoHy7yg9jHV2coPy7yhaD6uA7Kl4v8IdinwZvy56I/kK60dqL+cNE/qJ0K
/o76x93l/sKve83GqL9czr8BfgnW6qj/vEGeD5j1ODJI88EXy/MDm1wGAml+
eIg8X9B8wcqY5osXyvMH03/k5tH88UF5PmFL/Y1Zmk9RbzMUnn5jBc0vF/MN
1UV8N823qF8DkUNpL2n+udgPKEkzf077Ify0QfiE4yvaHy72C3KqYktpv4Q/
LVzqtB2n/eNiP2HCKL2a9lP4bYcfWqKzaX95t7zf4BhmcoD2W/jvgKf3Uy7R
/nMrmQ9g/7nNUuIDF/yA4MrecuIHF3wB3SfLKokvXPAHCpsSgog/XPAJuPv5
n4hPXPALvo/sLCZ+ccE3yBo5uIn4xgX/YJXptlvEPy74CB6K7BPERy7vew+0
vzZzJn7yNJmvkH08eZL4yh1k/sKyq8u0xF+ukfkMn5nUBRKfRd59sOCyqz/x
mwu+w05r113Ed5F/P4xZD7cR/7n4PkCqiYGWvg+iH4Mw7DxZRt8P/h9w7Sy7

          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQ9MlHUYx2+31Ri1ZQ5JnZG6WuAtHQiu2Q+eNTyxmTUYXbshmg1hShd/
RpYIoiF205RD7uCUcpG4BW1nTkaUTz1GZ6I7zzsBuSPupNqkIQtDZbaFxv2e
p9/G2O193+/7fL/P83zeZe+W5W03GgyG7XN/sf98xqjcfPrIvBdeU5sb++4n
b75JxbPerqdWvKF6kxpu5/ZGaY89YAoa81SCJ+e36oQoPe2dXZe64y1VkRk/
fKo8QrbnulKSLVZ11Rc7o/Swdm1nVqhQpWjBUUpfW9D3Yt02FVNLaviVrE0b
nO2lRWpObE5xhM63z3iivSUqKyaXOUKJpv4tUVupOnE8dsL0jPPy/MSmMjWT
HBMM0aOCGlqUUKnydIEhomGzbbKtSunyPMMUGsxY3rXtQ6Xl4ofpL8wIpxRX
q2J9btBMnd+1sbNWxdw29g2R/850+E/nPqXtJg1Rw5XcwOeVH6s92vAgbT1u
/zpYekCx3ABN1u8/fK32oFqtzwA5MLUs4bRdObTgder233KvjxxSkzG7t4OU
veaHgtRlR9QGbThISyJfPv7LzkbVEZM7FaCKHjQ3hR2K+xGgs6uWpr75T5Pk
76fsnPcNZfOalb69/CpNv/yOfddip9JxJPto0wLqOjPfpX7XeV6he9Mjs6/c
c0l+l6m+Z2eR6fsWyauf8tc/luba2ir5XKKxV5+1nrvZKnlcpE9KzMZHGW6l
5aq9VLFu6vqmLW6Vpv3+TJXLVy6YyneLv5/o2o6jf1xKdIufC/TV3zeqbO2t
Uv+PVPGgsEPdbZF6kc60PRy1PdGi3Lq+72jCFzz5/IRTxel6vqX+qbendzua
VY1+fzfVnF+Utd9wTN53lmBgfElOpkP0PTT0ks/odH0qep1ktDRvDBfY1Uf6
+Q46Nl583xuqV9/o+0+S45Zpypq2V+3T15102GSOS7dUye8DZHnv34vxu4rU
/xuyODL+gWuhdY1cB7mO8jwc4ufxAutDG+vL9Q44we/HL7g+iOP65H4PjHL9
eIf9QTb7Q66/G3azf5R8QPJByQ8kP5R8QfJFyR8kf5T+gPQHpX8g/cN07i+U
c3+R8/eC9B+9PB9g5/nAJ3l+QOYH83m+IJfnCz/j+YM6nj8c4/mEGZ5PqdcH
r/P8osw3yHxL/X6Q+UfZD5D9ED8BkP1B2S+Q/RJ/QZD9Q9lP6OH9FL8DcJT3
F0O83zDB+y3+B6GQ9x+XMh+glvmAwg8QfqDwBYQvKPwB4Q8Kn0D4hMIvEH6h
8A2Ebyj8A+EfCh9B+Ii87yPQzfzEg8xXsDBfcQXzF1Yzf9HPfIa7zGfJOwKV
zG8UvoPwXfKPgvAf5fsAJfx9kH6MgXw/8D9k6zla
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYx5kx5pSlLfohKzpWObDkCKgVfeBJyzAjKiNswzQrBHMZLKPA
zIYdK90y7RYiii2ulHAX0EWn9+SDx+EdDm533inngcfhsj+6NtORf0iO+H6e
p8/G2O37/b6/z/v9PM/rm/nme6ur5iQlJVXN/hn/+cQpe/cNl2tzg1q7x/1P
1toJ+jr6WsPWHZ8oZ4Yl8bIzRsUNK4NLHmtSafaSyca0GIUdS185+oNF1RXN
G+2ovUjpo/GyDYe/UCPDxhmnokbzxgXmL1W2FhynFZenEut79ypDLcMyRu1b
pvO9R6xqVmxWMUqvw2BK9kyLKjbkiqLkf3em5RC1qQOtxrlAJlfbhZ4rh9X1
LEMwQst2rqmxrvpOrdYFRmjm3+MfVkZtSpdnH6XM2yeeGj96RGm5eaPU/uyG
Vdf6flQb9TlP77z4wMIdyXZluN3jPkfNk/vezvR1K2034xwll7aXjnX1qm3a
cJjO3pni3drlUCwXosJNtVdzPX0qX58QOeosqU3XnOorLXiWHp7ucCXludRf
ht1EkCb8m7B6+29qpTYcpOdii0asflI2Q64jQJdubu4pWXBKcT8C9LQ9EDmT
55b8/TQ/Mjd3/wsDSt9eO0J3X23+fHGlR+k4soYp+dbCsZ8qBtUlnecZ+r3E
/ciKJ09LfkO0LufPXZdv8UpePgo5y15t6fJKPl5a9+hb0zuX+iSPQQrevyWW
ZvEpLdfooTsOPJh8m92n8rTfAapoav3+hM0n/k7Rz3urKFHlEz/9dGz3kCv3
ilfqP0n12+96KV7slXqRPlhU3W0uP6326/qOU6k5ULbcPKjm6np+pTZXeX1B
cEB9rN/voLon6gtMyi3v66GHli3Ouef9ftG308mO+JqaKRS9TpoOVTj7jjnV
R/p5GwWuW252pztUt76/nVxvbNvV841dfaqvWymjKVE40mqT359R9S8pUwtP
WNX/GzK/k8Km9M4+uQ41fB3lebiXn8d+1och1pfrNjjP78dvuT6YE9b1yf12
8HL9+Df7gxz2h1y/A2rZP0o+IPmg5AeSH0q+IPmi5A+SP0p/QPqD0j+Q/mEB
9xekv8j5e0D6jx6eDwjxfGAqzw+s5/nBcp4vCPJ84UGeP6jk+cM4zyf8wfMp
9Q6DzC/KfIPMt9Tvh1Sef5T9ANkP8RMA2R+U/QLZL/EXhEneP5T9BNlP8RuC
Xt5fjPB+w+O83+I/DH7efzQxH+DG85oPKPwA4QcKX0D4gsIfEP6g8AnuYz6h
8AuEXyh8g+XMNxT+gfAPhY8gfETe9yhUMD+xmfkKbcxXXML8hWeYv+hnPkM+
81nyvggm5jcK30H4LvnHQPiP8n0A+T5IP+Ig3w/8DwhBRvc=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lX9M1HUYx0m3AtJljj8aKUU/JkSLDdDMPuezpVunlSjaFh5zTbzW1Alu
zQWIRYUtWtEoTOlAyluTVbeoK2n32MOPq/h1dNdx3PHr+HFHlMDU9C5qlvH9
PE+fjbHb9/t9f5/3+3me1zd9f0mBdVlCQoJ16c/4z2eS9sbNpypD9aqotjOW
UTRBy71dFtjQoNrSqud2tYVpNvPPF+d3nFUpjienylPCtD32YW3Y9ok6akoO
nisdJzceMdfd9qny9BtnjBYu1VVtud6iMrXgGP2eWwULJQ5lqKVVj9KjZzct
9nW1qiWxJcURahg+P5Rod6rNhpxphJ7KeewWT/iCajhjnGGaLatytZe5VDzD
EAzRlpWVHeEyUgW6wBBVbjO/bbvaoXR5jiC99tea7qIit9JyyUG6mV3fcvmf
H9UL+gzRxcPLraahHmW4re0MUE3qYCwv2q+03bQAvZkw7wqs9qoKbXiQjlVH
rjX1+RTL+elOf9B8d4Nf5erjp9pUc+fjFQH1nhb8hQrGnv96/aGgmjfszvnI
/0f2zRPWYWXWhn3U/FFSYODAqLIbcue8tHZ0Z+n9xeOK++Glut2rnvYUTkj+
AxRv2rSivXlS6dtLPXTDcqQv760ppePI6KdGWyhj3f5pNa3z7KX8WP3is+si
kl8Pbdhx1FI6GJG8uumB49fasqxRyecnsr6b87olEJU8fqCDrds3JqfPKC1X
7qaa4sV/67bOqBztt4uKN57PdKkZ8ddBBwvqw723zoifdlpz9eG19uao1P89
Vfx8pjCYGJV6keKmk5edmyPqtK7vOyrPuoJ7n5hWibqeC3Tsxj3PXEyZUsf1
+51kM7lznyuZkPe10vXPtqV+bBkTfQfte/CrrPxYSPRaKDtptnFua0C9rJ+3
0xcL8Z7De3zqS31/E3V905ifsq9Xvaqvf0C3py9LuqOzQ36/Qb+d/vyRyHir
+n9DVjfetbMmbfhbuQ6X+DrK87CSn8d21gcP68t1Ozj5/djM9cF6rk/ud8AB
rh+vsD/4m/0h1++EU+wfJR+QfFDyA8kPJV+QfFHyB8kfpT8g/UHpH0j/MI/7
C9Jf5PzdIP1HN88HHOL5wBU8PyDzg3t4vuA+ni+08fxBLs8fTvJ8wi6eT6m3
H5p4flHmG2S+pf4BkPlH2Q+Q/RA/XpD9QdkvkP0Sfz7w8v6h7Cfs5v0Uv354
h/cXQ7zfsIr3W/wPwku8/3gv8wFeYT6g8AOEHyh8ARfzBYU/IPxB4RMIn1D4
BSeYXyh8A+EbCv9A+IfCRxA+Iu/7CLzP/MSTzFfIY77iQ8xfiDJ/cYD5DL8y
nyXvcehmfqPwHYTvkn8YhP8o3weQ74P0YxIK+fuB/wHMLFlr
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYx29Wy0nLucidtS7hD7tyLE+N1vaRZ83wyOEsurQfSKbSRsmC
5pbZ4RTC8pYagoelSxbovLZOTtHQHnsIQcTB7fA4IeDwhDHLYwTjuB+5LO7z
PH02xm7f7/f9fd7v53le37QtH+cVzjEYDIWzf8n/fEKUVbFok7PqR5V/qHXG
nH+LbHk3jmaPnFHNpsrw683DZMkpe3hzyjmV6rbe3pU6TI7yVpf75AVVumpe
X31JkDaa6yrueS+p7q7kGaKv4/9c6HCSelYLDtFHc/9e9+m+VpVUM1UO0riy
Nrjr2tWs2KziAL17+S9HMK1TZSXlVg1QcdPST/Yu6FbffZs8v1PwrOGt1b/4
VNScFOynNzJL1lQs9as8XWA/PW2rtv87GFC6PHcfWTb3lJd7+5WWm9dHVk+0
K/HAkPpAn5tUs+h+eq79lkq6PdQaoIUpzzxpPHZbabumABkf272xvHZUfa4N
95IquFz1pmdMsZyfdjzkaT83dket0MdPLqj9Y2TZXfWNFrxB9162OFcfHFfj
SbvhHro6Wl+aG59QOdpwDxUvjpVlN02qhqRcvY/Op6/NDoSnFPfDR5bCFyMt
pmnJ30vXzqwz1ORElL69pJsGV34W+nLbjNJxmLso5f7Z6iPFUTWi87xOM69N
OB0FMcmvkw74c+ekLY9LXtfIlLFm6xOjccmngzyvBjvytyckj3YaesWzfkFn
Qmm5XW2UeinTfiWSUMu13ytk+cG8dU84If5+oyVFJ25GXAnx00Iu93sH92ck
pP5f6fqR5gL7jrjUi7Q7Pat6piymjur6LtLYVNRpXBtVc3U9P5N/4fTz8wci
yq7f30QfZjx48dFl0/I+Dx1+/53JDeunRN9Np+PZVtvOCdFz0d2OzJKy2J9q
p36+gbozT+y3mcdUo77/e3LEi94+YAypPfp6DbnPh7db3QH5/QUd/im/0epr
V/9vyOkR15JK47EX5DrIdZTnQZ7HFtaHKtaX6w3Qy+/HOq4PJrk+ud8NjVw/
TrI/qGV/yPU3QRH7R8kHJB+U/EDyQ8kXJF+U/EHyR+kPSH9Q+gfSP1zJ/QXp
L3L+bfA49x/beD5gmOcDH+H5AZkftPF8wVM8X3ic5w8cPH8Y4vmEGM+n1NsF
Mr8o8w0y31K/F2T+UfYDZD/Ejw9kf1D2C2S/xF8PyP6h7CfIfopfP5zi/cV+
3m8o5f0W/73wEu8/LmY+wHzmAwo/QPiBwhcQvqDwB4Q/KHwC4RMKv0D4hcI3
EL6h8A+Efyh8BOEj8r4PwAbmJ+5jvsId5is+x/yFIuYvepnPsJf5LHkHYRPz
G4Xv8BXzXfIfBuE/yvcB5Psg/QiBfD/wP23/Wk4=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1GUcxy8Q4U7+YCqzRI/8sUJ0biT+YT2PnzINNlsFZUYakY4fK0LZ
wAzIhRdsVJusWD+w1AWuHHbhJLX2fPscP0QhPO44DvDy4LAgGCSmXStgGPd8
Pj0bY7fn+31/P+/38/m8nlX7DqRnh5lMpuz5v9B/WgFsuZObud31o9h7rCWY
sHcI35x5aF3xMoe4ZK2YSLs0iL6nZkZnt7SKpfaU4ZKlg7hi0Zrk2MF2USgt
/XUH/Xh4RXrF4OKfxbWu0LqB939a640Z6xbrtOAN/H1B5qHAhR4RUrNW/IIJ
tryqRT6vmBebV/Rh0Uztk6XZ18XWkJz04RLbZdWZ5Re1n4fWdZyuCS8sHw+I
vxNCggNYtWRH9/rXfhXpusABjNs3njL1wKjQ5dn7EbdmJJ2KHRdaztKP7v74
DZt2TYocvfpwfdTGiY8GpkTI7bEWLy4rTlv8WPefQtu1evGirfGduJ67olQb
7sWC8rqzfXeCguQ8aHk8b6xy4z9ik14etDdvfym3fFpUa8Ee3P3N02Wdo7Ni
MmR3wo2VtifyYzPuiVRt2I07qjzPBsZMsj4kV+fCwMk9h75bGybpPFw43rT/
tHdPuKT8nXgrGON3Vi2Q+vGD1/DRvDBH65kIqeNI6MLk+NRdxy8slDd1np3Y
uMGVEtMQKSm/Dtw/VPpyR3mUpLyuYmn7mtNFm82S8rmCH9rs0SMOs6Q8LuPb
cVWpSfEWqeVK2tAFPQ2enRb5iPbbin9l/+bu2GaR5K8ZPzbPyvMmC/tx4In2
huAfR81c/0/4TPMH1sYrUVyvwuKjX51b6YyUn+n6fsDMnTWvZ3yyUEbpei7i
l30HNlevipBl+vtNeGT1NttcYTh/7xzeLdq9fOr9+1jfjq9O5j6fMzwnSO8M
vlIQIR5OmxaH9fv1mJXV5X+rMCga9fMncMvVW1/L526Ld/V+DSbOrV7+4r8j
/Ps9NN/MT/LE9Yn/J6S4915i98mh73kfeF/x+8DvKwfpA5A+79dDHn1fnaL6
IIfq4+ftkEP1q9vkD4Lkz6D6m6CM/BucDxynfAzODzg/g/OFIsrX4PyB8zf4
fIDPx+Dzg2o6PyOZzhf4fA3Kvw34/I026g8oof4woql/gPvHeIH6C7i/jC+o
/yCL+s8IUH/CeepPrrcLuH8N7m/g/ub6ncD9b/B8AM8H+3HBMM2PwfMFPF/s
zw08f4rnE3g+Ffn1wLc0v2qA5hsiab4V+e+FN2j+1YPEBzhLfFDMD2B+KOYL
MF8U8weYP4r5BC3EJ8X8gpXEL8V8A+abYv4B808xH4H5qGjefVBA/FSVxFdY
S3xVicRfGCH+KifxGaKJz4ry9sMR4rdivoOV+K6Y/8D8V3w/QD7dD4rvD+D7
Q/0HCHM04A==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lX9M1HUYx4lLiR8VynFXy6HkWkisFGzrx/fT06bD+8M/hMB1w3I7ky5T
4yid0xZUwFxtHf2YZ4mAgm4nC3NB0vb59Jwc5GHHDQTiguOHkpriLyI1tq7F
fZ6nz3a7fff5ft+f53k/z/P6ZDreKdwaHxcXt3X+F/unNYnbXnFevpYaMDa5
O+9kbZrAnPzxmfjfg0ZHRvV0Qcc4urasCqxc02+YW9dd2Gsexzc2J56d3T9o
uETScFPZGEbLMx+8sSFs9AZjK4KJlZ9FbN6IsUILRvDP7g9z1vZNGjG1jOpR
TM4vCjYcnTLmxeYVRzBQfGzu4vnLxksxOTGCtV96Vlx/85rxzdex9Rs+mv/y
hMV507ibFRMM44vu+3+o2D5jFOoAw3j4kXtvN07MGjq81mE8NHvlb4v7rqHl
koZxyuEq8++bM0r1+hXPRd7adeDYP0YsW3fnEEp7W337gjih082Yf65NKHcN
3Sf26YQH8fPHjqzM9JkEyQ3gascvtmz/ApGn1wA+/lrK1azRBFGrBc9jVXRh
yRVTkrgeS3e6H0frnzphfy5F2HTC/Wh//mNbfflDojkm19SHqV+UPhm/MVVQ
PfrwW/ROf7pzkSD/Q9jtMEpHPlgs9OtlvbjbFs6u/ShNaDuyguhqydtu3mUW
F7Wf5/DI61eXHy9IF+RfD+YmFy8rT7MI8iuAoSWFnpZ2iyB/zmK6/aY6nmcV
5Ec3+jYXB/7abxVabm8X7ui5dKjylFXk6nz9uGr9uLPFa+X8zuDuyoZC504r
5+PD6js5+RujFo7/J6z65Nmlw0UWjlfihbF7a5e/ly4O6vh+RPPM3NyrJWbx
gI7nNEZO1Hxfk5wm3tfnt2FXj+fWyZpFfN4p/OOFPRsONjzM+q1Y8vMBR8VQ
Mut50XOyIFrXkSD26O+bsbRxSeLiIpP4Tr9fj5Zta+whZ9So1PtfoXfqtKMp
NMvPVeg5XLzOd2PK+H9CLvlN47bU6XbeB96X/D3w99JH+vAE6fN+M+yg81Uj
xQd1FJ+i91thC8WvblN+cJvyUxR/G/gpf8X+APuj2D9g/xT7C+yvYv+B/Vdc
H+D6KK4fcP3UaqovcH0V+d8FXH/VRf0BndQfKoX6B7h/VBH1F/RSf6k66j94
hvpPTVJ/wlHqT443CNy/ivsbuL85/hBw/yueD+D54Hz6gOdH8XwBzxfn1w88
f4rnE3g+Od8BWErzq8I035BL8835D4Kb5l8tIz5AO/FBMT+A+aGYL8B8kcwf
YP5I5hMwnyTzC+qIX5L5Bsw3yfwD5p9kPgLzUdK8j8AZ4qesIb7CQuKrzCb+
wi3irwwRn+HfCs1nSX6PgeldzW/JfAfmu2T+A/Nf8v0AT9P9IPn+AL4/5H+N
fS1R
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lXtMVFcQxrcYwyPWoigUKcvjJgZsbbS1IdZ7nH+KmGpspVUepbRqQGqx
apo01BpKmtKH5WGbxoAVo9mVxEcX1qyi4R4HdQWqC+yWx65bFqmCbQNaQoGU
9JFyz0xPsrvZnHvmzvfNzO+k7NyXXRRmsViK5j7mL61h9LcWFk0Fe/WC2uvT
aQV3sW955tk/B/z6ZWvl2NbLQ9jjai0pLB/Ulziyfj64ZAgfpB6LePmPYf2A
iPLb9ofwV4+98MmYEb3LY65B1F7ZY889+4uergIO4sWVj6qib47pZjRr5U/4
YPydDecyJvS5YHMRgxhbcn7m8+Ckvt4MJ4L4fsXkSZ93Wj9Wb647WOeMudST
NKvPpJkBA3i/qmH0ac/ferZKMICWnfvOh0otQqXn8GOT/avJU6fDVHZzX6iV
JaQnLZovitUaQJFfVLupKVyYamuv92PgRceVjI+jhJJr7ce2/IXWifLHxUdK
cB9u2RUobt4WLShcL9aMHs20WhaL59XqxeE7A+unWmPEERXwRxx/5ui9S5VL
xbgpd8yHcONA7Nq8OLFRCfZh3D+J3xxfHS/sZjibF53bRx7LiUwQVA8vlg6s
WasHnxLkfzdmVR/G6garUI/v78L4v4yH4cuThbIjzYPhL3kjF/+eLO4pP29h
6bObPpg6nSLIvx8w/2r7uqYNqYL86sRlb+39Iqsrlf3pwCMbV8rQCxr7cRPb
M+83ug9pQoU76MbZ+rLN9Sc08ZzSewNftQ2dya/TWN81dM+/bavYrbGeNnx3
7+yHi6I0zv8q7ple9a+rPJXzNfDLJ9pDbneKqFP5XcFY8SgvbzBZRKh8WnC2
o+aarSpJHFLvd2Hum/70CxGJ/D4n7jg8NtqxehnHd+A837m+nIVxHO8MOl+7
1ZPVGCPK1Hk7bol7Y8YbFi2a1fMn8OutnY3fF0SICrX/Ld6trWkqLbHw/0+x
oX/HqYxPJvT/J+TtXdlO/29aC+8D7xt8Hvi8bKP48B3Fl7Rvh230fnmS8oMW
yo+fd0Ak5S8nSB8Ukz5J+bsgh/RL9gfYH8n+Afsn2V9gfyX7D+y/5PoA10dy
/YDrJ9dQfYHrK8l/N3D9pZv6AzqpP+QC6h/g/pGvU39BPPWXPE79B7nUf3KY
+hPeo/7kfD3A/Su5vyGB+pvz7wbuf8nzATwfrMcLPD+S5wt4vlifD3j+JM8n
PKT5ZL29METzKwM031BN8836+2Azzb9MJj5AM/FBMj+gn/ghmS+wjvgimT/A
/JHMJ2A+SeYXhBG/JPMNmG8G8w+YfwbzEZiPBs17EKKJn8ZnxFcYIb4aK4i/
4CL+Gt3EZ0gkPhvkdwjGid8G8x1Gie8G8x+Y/wbfD8D3g8H3B/D9YfwHNb8t
0Q==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lXtM01cUx3EOZ6cxS1cdzqyTidICrYnUOMjv7szsgS4ig8wYk2IQh38Y
o13m8AFz7iFzhihmhnUMlxFwER8NZkwe+V0PgxKnFiwCFhA6IGpg4OIjEGGw
jd89Zzdpm+b+7vmd7/ec87nR2Xsycp6JiIjImfkYv7T6sbnsRtbqvLDmPtE4
ZnP/gaF3y8c3pA5qtdYjI+m1YXxzwe77wf57msWXMnDQEsZdh6Zunp37p/aR
eD5U7unDevOO09rtv7SWgLF6sSBtfVK747FmVwF70f2gpa1m05hmRLMeuYN7
H1zbZR19qs0Em4nYg4lFX6e6Jqe0N4xwoge/Kz81ke2PECXfG6sbJ/6pTJlO
my3GbUbALkx1jh//ctkckaES7ELT4tDfo2tNQqXnC2FU3WfmrIvzVXYzXxh5
b8GxzxNfEDvUuo2ln9SV5KwxC0PticZOfOXfhskz2yxCybV24sb3puf5qxaJ
PCW4AyM9ZZPZry0WFK4dYwti81y/LBGJarXjuBy0DG+1iiIV8Bb2pnceMBct
FaOG3JE2nE5ufFk8jRbrlOA2jDNdCLg+XCYqjHDlQbyzPTfh15sxguoRxPBV
5/DU6hWC/G/Fy+cs9d0nY4V63NOC2ZmDJ2v7bELZYQvgp9XCVP9inBhUfl7H
DXsvd1x3xLN/1/Ab0/RjXJ7Afv2OH2fkv5Q7lsD+XMXMowMXnxQ72I9mTMt9
1Vf4rFOocAf9mG8f3vxcklOsUnqbcL9IvtWw0sn6fsORtQPe4F0H62nAOXcP
e+2bHJz/FcwM2HtqDiVwvjp2F648fyArXnhVfnU4lZb19reTdjFX5VOD6+dF
LnRvtIl89f5qPB6fNCtn6wp+3yX0vvNo0T5nDMf3YXFZ1b5jTdEcrxIrC84M
7Uyxiv3qfAW2Rs922S5EiSr1/I+4vP7nbenNZnFY7Z/CqM6a86F1Jv7/FSY3
7wyf9kxo/0/IUEeJs6n4/hreh9dpX+fzwOdlA8UHB8WXtF8BXfR++RPlB5co
P37eByWUv3xI+qCU9EnKvxoKSb9kf4D9kewfsH+S/QX2V7L/4Cb/JdcHuD6S
6wdDVD/povoC11eS/37g+ks/9Qe8T/0h51P/APeP/ID6CzzUX7KU+g+OUv/J
fupPSKf+5HwDwP0rub+B+5vzbwXuf8nzATwfrCcIPD+S5wt4vlhfG/D8SZ5P
4Plkve3A8yu7aL4hhuab9XfALJp/uZT4AG8RHyTzA5gfkvkCPxBfJPMHmD+S
+QTMJ8n8AuaXZL4B800y/4D5J5mP4CU+Spr3HrATP/UC4ivsJr7qccRf2EL8
1VuJz/AF8Vknv/ugkfitM9+B+a4z/4H5r/P9AHw/6Hx/AN8f+n9fyCY/
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lQ1M1HUYx4mpMa1AxxRxMNAYd2qD4+6s6P/zsa0mLYu4BaZQbeq5Xqbh
elHUWlCwNmxiI3c5X2KcYZ1cnFGA/n89iiBHwHUnb8drZL4safPtsKjN4v97
nn7b3e32+/+e//P9Ps/z+aVuesvhjI6KinLOfIxfWhPYftmzr77uila0v3XK
VPQL5j94uccRfV1rTi6fzGsex3X9W4a+SbihxXvX/ro7fhyf/Nn+bkrpbW2H
mDtYWzyGuevjjkUmp7SebmON4onKHbP1oWnNrAKO4pq/Kx/yrb+nGdGSy0ew
MTmh6EDLfWIm2EzEYWxxrDUdPDxLrDbCiWF8bUVJRubI/eLQF8Yawth2/zvW
PfPEXZMRMIzZJfUTHaWxwqESDGOpD8oOTs8XKj3vIIbnVPq01+NVdjNfmL3O
+4QnbpHYqtYAJvzuLBu7sVgYave39uMz16o7Ls5OEkpucj/udDXlrDKliD1K
cB++5NvwQ/rVVEHherHr+Gbv5tPLhFWtXpw6Z64P16SJKhXwIr6511r7vStd
/GHInQzh8khG2HnILHKU4BAmxq8sPFCzQriNcLVB1FqDVUtPPCKoHkH05Dyf
n1eXIcj/AFY0PRc93JUp1OPFPVgXacjxNFuEssPUjZGP0kOTn2eJS8rPnzBy
5M6Zp1+1sn+dmFa8aIEjzsZ++XHI77d867axPx04uuzSwsUJdvajHQsLHrtZ
ttUuVLjdbfj2K9sKLfvsIkvpPY+rd936tK/czvrO4fsNn7hrXrCznrN478+B
Z9+4buP8f8TY7qsRX56N89XxtzmBIJZbhUvl14LmjcfHT1ZkiRiVTxP+8+j5
7dvyLWKven8jJh3593HPtQx+nw+/c1aFMjtXcnwv+gecO8sKzBzva1xy0tKS
60oTu9R5N1bf2viXdKWKBvX8UTS1PjXy3oVE8aHar8bphZ25n8Us4P8f44b5
2cemHo4W/09IYtepmJKkK6t4H3hf8nng8/IsxQcLxed9N7jo/fJLyg9SKD9+
3gsByl/eJH3QTPok5d8IS0i/ZH+A/ZHsH7B/kv0F9ley/8D+S64PcH0k1w8+
oPpJG9UXuL6S/G8Drr9so/6Al6k/5APUP8D9I1+k/oJB6i95mPoPllL/yQnq
T7hL/cn5dsMd6l/J/Q1fUX9z/gHg/pc8H8DzwXqCwPMjeb6A54v1hYDnT/J8
As8n6+2F2zS/MkzzDZ0036y/Dwpo/mUK8QG2Ex8k8wOYH5L5AswXyfwB5o9k
PgHzSTK/gPklmW/AfJPMP2D+SeYjMB8lzfswnCJ+ygriK/iIr3I58Rc04q8e
ID7DUeKzTn6PgYP4rTPfYQ3xXWf+A/Nf5/sB+H7Q+f4Avj/0/wAlcSbH
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYxy9YoE5pODYGNxnXWhzqHMKF4d3Tk2Nh/uEE9Iw/DlYmtrEx
cWkpullNbKMlZTCJEdlApQxQh3qM+/BcCv7gl/wQDi4hoDXzsAl0AaW07j7P
02e7u90+38/zfd7v53leH9Oe/dn5IQaDIT/wCf7ymiDPVNOe45PTNkfZjb/M
jl/I/rxvE9KMzRlXMp3lHKf3j5RE+8L8tqjGrZPFUePUmjQc+nR4wXYAVnhq
i8bodFbOvU/wma2nO7ge0JF/ipqq6w2QqAM+oHrP35FnT4VCMFpcyc8E36Se
KPCGQSBYIKKX9la8cLK4fAW8FgwHXsobGjUttEdA1dfBNUpZ9WaHsyUS5s3B
gCPks30esn1nFGTrBEcoIiU3cmljNOj0Gj10PX2Ho/utWJ1d4Iua55v+HOhY
A/v0GqZO98Cz8LZ4CKotuzFElxPcb9S4XgQtN26I8mourc4cewmOasH36TNT
zzL/mgTgcIN04Xx518dHEyFFr0FalbkrJ3RuHXyhAw6QoSzxVOmxDfA4KHe6
n3q/mp+qKE2CN7XgfjJHfZBw3LsR6oLhavvoj1z7rci1KcD16KNb2wsu+A5a
gP3vJf+WMw/h2iugHy/qoYuxGR2//Z4K2g5zNyWb3j50KPxVmNJ+dtJ3rz91
7liZJv7dpbndxofu2TTx6w4VWDIXjVc2iz+3yZixfml0q1X86KDWqg0ZrQ1W
0OGK2wN+7M9/NG6FZK33JvUfuBsT47GKvp/Int5nunjaKnrc5F8d8rgzwir5
t5ERYmJLt22WfF30pHDJs7AlDSp1fi20+EOVMWVxEyzT+Vwnz7b65z4sTIVj
+v3N9M7cu7XxdRZ532W6M5g+2/BtssRvpAoKt1/dmyTxvqcvf21L+nF2HRzW
5+toctW58vSOl+GSfr6GataXWv7NNsFHer+crHmF+cbd0fL/BMWEHoaJ4nD4
f0KcZTM5/uowp+yj7Cs5j3JeuTk+nuP4sl+HPn6/Osv5YSXnJ8834hnOX82w
PuxifYrzb0bRr8QfFH+U+IfinxJ/UfxV4j+K/0rqg1IfJfXDnVw/ZeH6otRX
sf/t6OD6q3buD2zj/lAruX9Q+kft4v7C97i/VDX3Hz7h/lMT3J9Yy/0p+Xaj
9K+S/sYG7m/Jvxel/5XMB8p8iJ4+lPlRMl8o8yX6+vEez5+S+USZT9E7iMt5
ftUIzzfKfIv++/gpz7+KZz6gnfmghB94hfmhhC/YxXxRwh8U/ijhE7Ywn5Tw
C4VfSviGj5hvSviHwj8lfMRc5qPiefeig/mpTjJfMY35qtYyf1H4q3qZz3iQ
+Sx+j2El89slfMcW5rtL+I/Cf5fcDyj3g0vuD5T7w/UfdYMiJw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQ9M1GUYx/FcdSKaNsLtsIt2NUCaF6hD4R6eG2vTLWKDoAljCDXPtfXH
2uyP0YAZkTg5Y1Ji9G9cDt265WBJcY+PGSxLwKPjn4CIkK2GIUHQpolx7/P0
bne32/t7n9/z/T7P83kfee6V3N2WiIiI3Uuf8K+scW74qjI+p/amq8h7fj6h
6CoPJDXX2RdmXW32qqmctjH2O30ll/0Lrmj/9mv7o8e4qepmfJvltutViBxs
2nuFfU/eU2i1REB3V3iN8iloWXNnwgKJJuAor3/p78rlG++FcDR71Qi7vYFr
CzdWwFKwpYjDXJbTEu9NXA0Z4XAwzPXFt5I/eH0tHG8Ir8v82bL1z26Mi4aF
hHDAIZ6dcBx+48F1kGsSHOJnsgqLPy6wgUnPP8i1c6We6emHTHZLXxyV6Xmn
aCoOPGYNcERxNFVaHRBW6z3fz1mLdXnJ2Y+BkWvv5ycK1o1MfBcPbxvBfbzK
kTnoyNoAEi7Eocj6pAOLj8Mms0J8qfxsWkW3E46YgL/w1tnle7ggGW6E5U71
cnZ+Sel4XwrsMIJ7+XTXkW2b8jaDLxyuKcgNzkMF6aEtIPUIckztqff/yUoF
8b+HZ+ZbXpxu3wrm8b3dnHk8uwZtaWDsSOhiS36I20rTYcL4+TNbrdWrZg65
1L+f2NIZk1daB+rXBf41f2219+UM9edHznVePZFgQ/Wjk2t2oT/Ji2DC7e/g
xebysvsvIKQYvT/wWGHRyT8YVd/3nDqyJ/boa6h6znFgoMIZHM3Q/M9yU9RO
t+df0HwD/Pz2+15wB11wzOT3LT/w21v7ynemg9Xkc4bvflQfc/DDbVBm3t/K
1ysGPll9OFXfd5ovzUW1r3Rv0fh+nnzKPR9oTdF4J3nu4R3fxE464U1z3sf5
jdcLF28nwtfm+U95V3tKzMpOB1SY/aNcnWY/UfWFTf+/y7Y1JXdrLkbC/xNi
O/Dn/NNxB8/oPuo+6XnU83RO4qNH4uu+D4vl/fS55Ie3JD993o+/S/40I/qw
X/SR5N+Kk6Kf1B9cdsz4Q+ofqn+k/qL6S+o/qv+k9UGtD2n9UOtHm6W+OCr1
JfG/A7X+1CH9gdofFCX9g9o/lCf9hZPSX9Qo/Yd3Okz/0bj0J66Q/tR8u1D7
l7S/Uftb8+9B7X/S+UCdD9UTRJ0f0vlCnS/V14s6f6TziTqfqjeEF2V+aUjm
G4My36q/DyNl/ilO+ICPCh9I+YHKD1K+oPKFlD+o/CHlEyqfSPmFyi9SvuFf
wjdS/qHyj5SPqHwkmfdh3Cf8pPeEr+gSvtIG4S/GCn+pR/iMXwqf1e8r2Cz8
JuU7Kt8Dyn9U/gf0fkC9HwJ6f2Cj3B+B/wAqPQ8y
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw1lW1Mk1cUx4nJHBI0WXyZb6uFkVGcAiIbVno4smTpFvkgTs1e3HQjaGJg
rXOAWpYsBnAzU4xxbBB8ISVhzAXcxqBI7w5zmKEUUixI7YSi2QciKmSJSqiB
8dxzdpO2ae5zz3P+/3PO78Z94tiePy8qKip/7mP88hql5eaPF/laHtl2V159
bNkdpra6nqdfF/9r85jKx3M9I+RYH703tOKJbUmT/e7RJSMU9h3/x7Vz2nYQ
YobczmEqqr7iOZE5a+v1GesO+W/GbTvkmAdJOuAdcnrOv13S+BwY0Uzlf9PF
c6f2frtzAcwFm4sYotJnt+d/9sVCyDLCQYhiDiy2rF36AtRUG+s2pe+rLnT8
shieWIyAQQr/lDi2p2YZbNcJBun+Vs/+df4VoNNrGqLxQHds6q6XdHZzX1T2
TV5yuMoM+/S6RZsyp6ZLLsWDobby6iCdTD92IWMsAbRc0yA5r8+8496aCC4t
eIAO5jjj3gskAYcL0K+vNORGXOtgo14BurKwt2JNdgqc1gFvUkHDvey6RRvg
gSF3vJ9Cib8NjJalwVtacD89qsw7VTi7EeqNcG4/qR3OttCR14Dr4aeBM2c6
MiZeB/a/j2q6Ux2r398E+nFnLzXYn/naW6yg7bD4KNLcmjgxtRnuaT9v0KuF
VfV5Zpv4d51SP2z9wZ0A4lc3eR/GtGfPgvjzF63xW+OnG7PEj2tUG2WvCpoQ
dLijXXTNldnz0bsIaVrvn7R/2dkFl3JR9P1BT583l5+bj6Knk8bfLN4WOZQl
+f9OvSWOjpPfgeTrpeicwSmb0wbf6/za6au7kzMJM5shWufTRvctZe3uN6xQ
qt/fQsHO5P49WzLkfT9TJGXsmD2SLvGbqKsZthw/nCbxGmlw2GqZLE2Bw/p8
PRWNxa+KbUyCy/r583TA+sGnpoqX4Uu9f5ZqVy8/PZGzUv6X0coHL3acKI6B
/yfk8i6r/caPla2yj6t4X8l5lPOqk+Pj5xxf9uuxlN+vLnJ+GOb85Pkm7Ob8
1STrwxnWpzj/Fhxi/Ur8QfFHiX8o/inxF8VfJf6j+K+kPij1UVI/lPqpdK4v
5nN9FfvfhVJ/1cX9gXXcHyqW+welf9QO7i+U/lK13H+4nvtPjXJ/YjL3p+Tr
Q+lfJf2N0t+Sfx9K/yuZD5T5ED1+lPlRMl/4kOdL9PWjzJ+S+USZT9EbwDae
XxXk+cZmnm/RP4AFPP/KzHzAfOaDEn6g8EMJX1D4ooQ/KPxRwicUPinhFwq/
lPANR5hvSviHwj8lfETho+J5D2ER81NVMF+xhvmq1jJ/sYD5q/qYz9jDfBa/
h9HF/PYK33GU+e4V/qPw3yv3A8r94JX7A5fy/eH9D4ESJFE=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lQ9M1GUYx08SxWSsFXc7m14ixQ4cYwfYnde9PMVKWQ42qbZqrj8a9I8p
FGd6scEMLclNMdeSZYAelpMuYzCOeY+PEYwz4ISAuA6Vk2qRMHTNtNKNuPd5
ere72+39vc/v+X6f5/m8KVt3FJfEGQyGkoVP7JdXlG6vbKw4HPjDteVg91/W
LZMERTePz92dc/kte2c2+6/Q1mjFU776P13Jvo1XPclXqKUsVHc67ZarQt07
fqL8Mt3fsTi4tPBf1+BAbF2is1m/JS03zrvSdcBLVOle4unaGKdi0Sx7J+id
57POHCmNVwvBFiJG6GNLX4v7eoLKi4VTEbLdbKvacS1RNRyNrZ+pZs2ke983
96lb1ljAMJ1sef3r+IwHVLFOMEx9SZ6KD383Kp2eb5yGl375iPWaWWe38EVr
q9/OT81ZqUr1+okS4sounOx+SMXUHuweo2WZ5qKR/hSl5VrGqOOj/v3h8VT1
vhY8Ssces9m23ZOmONwIGaY2Oxo2WVWOXiO06RXyBFoz1CEd8Ed67sCii8Y1
mWo2JndmmHa2mhb/05KlCrTgYWpe3nxx0mxT3li4E0NUn+pOnH4pW3E9hqhw
XWvDWFOOYv9DlH/jdqUhkqv04+WD5HtxoLY0/lGl7bAOUE7NmxFcZVdT2s8f
KLWs6njdKof4d4Eenio75Jh3iF9BSin8pciO68WfPtpQatu2otgpfvRSfbRt
sN3vVDqcp4cK7I2Hn5x1qmyt93syV/aqummn6PuOOpuCr86dcoqe85RsvbOs
MdMp+Z+j1/ZPG09XrJd8AxR64Wj1CrdDfabz66LZvInmO3a7StD5dNJOo7Ft
99l1qkq/v53G8zuC4UW58r5vafvfv8Z5krIlvo8mBvfc9fZnSbxT9F5d9Bn/
g2vVLn3eS8fy3nh63pSmzujnv6Bzvbsfvx5arWr0/hFK/yCvs8trkv+19FbN
gYKO4BL1/4TEp7+8y/+pyS/7IPso50HO43mOD70cX/a94OX3YxPnB9Wcnzzv
gynOH2+wPihnfcj5t8Mo60fxB8QfFP9ghv1D8RfEXxT/oYT9R6kPGLk+KPUD
qR/mcn3BxPVF9r8HNnD9sYf7Az7h/sBE7h+Q/sFnub/Awv2Fn3P/QQr3H0a5
PyGN+1PyHQDpX5T+BulvyT8ET3D/o8wHyHyIniGQ+UGZL5D5En3DIPOHMp8g
8yl6R6CA5xfDPN8wf1XPt+gfhQaef1zNfIBW5gMKP0D4gcIXEL6g8AcymT8o
fALhEwq/QPiFwjf4ivmGwj/Yw/xD4SMIH5HnPQK1zE/cx3yF7cxXzGD+wrvM
Xwwxn6Gd+Rxgvy+DmfkdEL6D8D0g/Afhf0DuB5D7ISD3B8j9EfgP1gcXKA==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lX9M1HUYxy/GNWBsFqABDhIlvCMVjrupf9zHJ2cDxx8VzLU26TKMRq4W
P1Y5LKfilU0NnUl60g/krNEPisU8qXt89Dgz5Ph5KHQCgVYDicVUcEvcuvs8
T5/t7rvvPt/v833e7+d5Xp+M0jeLy6IMBkNZ+Be58hon1fPOhDLetJfU+eZM
Jb9Twr+OpqS7f9nPpTuni86N0ctV0Tlnjk7bk1oKJmqSxqg85ZW0kppZe6WK
G2qqGKU/VU2313XH3h2IrBFK+6Nh76m19+xmHXCEVuwwbYveet8eiZbuvE7+
cd/pE3EGFQ4WjhiiU99V+Je3R6kNkXAqRDO9qx27yahcJyPrN9r/9vF1X66I
VfOmSMBhOp4V275wK14V6wSH6efaxh0xhx9ROr2WIco23384J5Sgswv/0YE9
qS9GOxarV/W6Rm+U1hoDyckqorbOd5WuBwZ7h2KXKi03/SqtvecpK8tJV7u0
4EHa3dH6YEPHMsXhgpTf6fv+dedyZdUrSEvQMlm6NVMd0QEHqGvm+aiDG7PU
3xG50/10G2+XH7Sa1GYtuJ++TS68mb8qW7kj4Zr6aPFExdz4E6sU16OPvqkO
DlxOWaPY/x4q3tf3eKkhV+nHK7rp4vwvnR9M5SpthylAMcGz/6zzW9QN7ecV
ch9zGFYfyhP/OqnoQIIrXlnFr1+pemXu+fcGrOLPZeoqTlt4arNN/LhEn3/9
kbHQZVM6XI2f6qrzjSG/TeVpvR2U6nzhwcnwPeu7SI2fvrW9rd4mei5Q5cCI
eWa9TfI/T+sLMrd7mq2Sr5cS5z85WzCZp07o/Nppqst96/Rdi4rR+Xgo+OzO
G1/15qp39ffbqPaSZYl5fo18r5VaNzb+GHfnSYnfQh7D0qKxBpPEa6bnJvdd
y1rIVDv1+26yOxcFR1Mz1A/6+c9oZeFPLx2OSVV79P7HtMk1W1754aNyv5/q
q/IXOc88pP6fkN6jR7Y5Upo9sg+yj/I+PM3v4wWODxaOL/tu2MTfxy84P9jC
+cnzLYCcP86yPmhjfcj5t8Fe1o/iD4g/KP6B+IfiL4i/KP6D+I9SH6ji+qDU
D6R+aOP6gtQX2X8/HOL6o5/7Axq5PzCe+wekf3AL9xdUcn9hA/cfPMP9h+Pc
nyD9KfkGQPoXpb/Bx/0t+feA9D/KfIDMh+jpg8d4flDmC2S+RF8/zPH8ocwn
XOH5FL1BSOT5xWGeb5D5Fv2DsIvnH5cxH8DMfEDhBwg/UPgCwhcU/oDwB4VP
YGY+ofALhF8ofINjzDcU/oHwD4WPIHxEnvcQ1DM/8X3mK3QwXzGb+QsZzF9v
D/MZUpjPXvZ7FKaY317hO7zGfPcK/0H475XzARL5fPDK+QFyfnj/A/heHEI=

          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1lX9M1HUYx6/mskwrUCANLyii48dhw1hC349PK5caznkYsZLVlgPHQITY
IsSNWnFsTnYyrTAZYx3+4ZBDNiXcvp8eJERjd7c7+Q2HP2DyQ7pZFgr5g/h+
nqfPdne7fb6f5/u838/zvD7Rnx/IyHnSZDLlLH2MX1o3sOCT6vjh5mEt29E5
Z8m+jsdnHl46GnldazdXztrar+HMu7vWh14c19a4tt48uOYallRdveOvmNSK
xYpBZ9EYpjyyaa8Gbmset7EC+M7uvNGq6TtanAoYwKyXmmrDAnc1I5q5chTH
tk15tm+4py0FW4o4gmUf5x9uuL+gbTbCiRHcZFqeVLf5sfbTCWMNoyMiwllv
f0LcsxgBh/C+6ez+kZRlIkMlOITeI+X/2t9YLlR6rkFsKdkj95WtUNktfWHh
cPDZHaHPiVy1BtCelVITfPSCMNQ6OvvxzJHDl1vWrRZKrrkfd4bX9Wz/NEyU
K8F9mPx6mKW9O0JQuF488MHubpNtndioVi96ROtbUQuR4qgKeBUL6gerHlx4
WfxhyJ31o6X/vZ6m96PFNiXYj13FYeWz518RjUY4pw9TN9a0VsTGCKqHDxNL
ik47j70myH8v7glvSQ2fjxXq8SIP/r1Y/XPcTotQdljcmHWq+p9BR5wYV372
4I+Fe4OjbfGC/PsdJ/t3PfToCezXFfRtsN3dcjKR/bmMx6Yi2xbSrezHJZyb
XIwLXrEKFe5gFz6f/zjdsTJJJCu9v+E3yR1lkyFJrO8iZs+HNJ3vs7KeDgwm
rM9rsFk5/1/R7DJtTbcncr46lny2qqm0OEHUqvwu4M2BMe/a1fHiaZXPL9g8
UbO4r8AiDqn3n8OZXF/meEUsv68Vv58uzMywxXB8F+495Y/pvBXN8U5jSGmH
c8BuFl+p8404uiqqO23iRXFWPV+PD76MLk39K1R8rfaP41xb2qHblc/w/+8w
LyLhqbdbFrT/J8Sd05zR/UNsO+8D7+t8Hvi87KD4sKxUxZe03wgT9H7ZQPnB
WsqPn3dBLuUv/yR9UEv6JOV/DqZIv2R/gP2R7B+wf5L9BfZXsv/A/kuuD3B9
JNcPuH7yTaovfEv1leR/F4RQ/WUX9QfMU3/IldQ/wP0jP6T+Ajf1l6yj/oNb
1H/yBvUnnKT+5HzdkEn9K7m/gfub8/dCNvW/5PkAng/W4wOeH8nzBTxfrM8P
PH+S5xN4PllvL/TQ/Mohmm/Ip/lm/X1gpfmXUcQH2EJ8kMwPaCZ+SOYLMF8k
8weYP5L5BMwnyfwC5pdkvgHzTTL/gPknmY/AfNRp3kfgC+Knbie+QoD4qscT
f+Ej4q/uJT7DJuKzTn6PQRrxW2e+A/NdZ/7DNPFf5/sBauh+0Pn+gP10f+j/
Aaq+Kw8=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wss1HEcAPBTVFuEOdKLXd7WcDvh8rOfGcldeRyhrTDEDSu142YmDoe7
LHnUzjOpZYxJQ6zjR2yNHbujhTJ5zetMnPPcovz/v/tu//332+/7+3x/T1r0
Y87DExQKxeP/d/wnYw9Vel5WULbjAIOIXdRKF551EHBBHBE7qFqvKR/SE0BF
+XFso2BBY7TyTBIYlh2HGrlRv9z21H0ESE+NemtG342aJ2NvCxX26XBWg59g
T4XA/ailpfdPsbeJbC9IbsYa87C3gfqOBMK/9SnY20CbuSxvZiQfj19H+nPf
fcM90gCRLltD4Ttshol3Oq6nREXThpYBvAxA8OUriCavN8sdzsTeMnLfn5BU
Wguwt4hondp/dPnZ2FtARonKwryxHOzNozA/2blDZyH2ZlExp8YutDgPezMo
Poqd/OtnPh4/hRStJ720KCIgIfInkZ+dzLpKKQKxRL0fqHctv2VWKAZOhD+G
rJz6XiR1iLEnR3VBA+Zh8WI8fhBN5afN24hEOL8faVmkdEyaFICXRH8Xsup+
7rtqmgeyiHYD0u6vyGV/yAGaEy4tGqgWzGWBWrIf5tru3zJWpeN2F6wWflRZ
OqQCN9KHnAjFkN5QMu4fhAelFhLeKa5mflC6rja8exAJnMn5Q5u24ovjV4MB
l1wfFBboSDvlXqCKXD+cvpZAbW2yAHJyfyBP3eR+5EmT4v2DmdWRn1jNDCmZ
PwvHI0qe9ZgxpaQ/D/WNTCzm825I8fnA7JFEOtOBKSXrLcKY9nZ+INUFe8uQ
T2so+7ZLx94KbI7qpLZ8tceeEro6FB5wI2hScj5rcObNXkRghgH21uGlB/eC
tA773fH9g59HY66c9zEAI+T9hFR/q1cTLDPN/YX8yavlghArvH4V/L1bMt7Y
bo/3ZwuOhUy+loU4at4HvMPaWBDX0rGnhtPa/o5lPgzN+4KK0NMs1Vtn7O3A
VEpf3Fj3deztwroeCnu11gV7e3DRlNYWwHEF/wDUWb+X
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1k1lMk0EQx0tNikrkklM5xChYfagKQYUli01QUBDCiwG0CBVbTmMBNZAg
Kg+mUhHDbcFKRcoRjtIIpU2WQ8Qq1SoGQWuFVBBSIAilQISgfN92ks1mMzO/
+e/OrFfi9egkKoVCCfq/tnbSVhFFlsHutKkAvoStoIaiN5r65kpwjTAT2nS9
ma/LeAqqKrdsGZm0hy38YquBemjLjKhObdei5T0DJM+I9rTFMmU6EeYtoe8u
B2ziPWsxbxH9fZTkY5knxrw/iN/OzmFtvMC8BXTruOM+d9FLzFtAB5fydum5
Epw/jzi0AdnO2EZAhA/NojVK/QVOdjOuZ0AD1oOp04oWQOArZ9CPcbpKUNaG
edPIkr8SxdS3Y94UYlIiZezTHZj3Cxku3RuNapZhnh45FXsIfrq9wrwJ5KCv
7ut50Il540iscuhdm+jC+VqUEGcqqHHqBhVE/BjaGOuSWNkpwFWi3ggK+u15
fqZLAY4S/GHUrjHo/ZcVmKdBafyy17xWBc5XodEA4Vz5124c34/2pluHnOLK
wWPCL0f+MbVZouROkE+cG5A2vP3520UZMHfYr/msNNdHCkSkH5aiNBaL04LP
cvgu0345nC8BJ0k+ZKnWpZM7xNivgrxinYswTGjWB7ODusVW1BLgR+qHoaXr
XIc2PuCS94O2brac/tx8ICTvD/nqc7p4Hx7QkO8Dp3rEWSWuV8zvB9WhcXm7
gwNx/AR0FufI/YVASfL1UJvp2zrZFKbE/YH23+7c/VQdpiTrTUFq4WdpgjdT
ifsL3b02hIWOdCXJm4H3N/cLym8wsF4D3P5whGXfcwbrmYUaWlGTtiMa65+H
RUc+HvOoijHPH/Sp87W1mYwHH8j5hBaZFwsYKNE8vzD6xOVhBSMJ5y/CgRo3
W2MIB9dbgoORI4fktGTz/4Bf6NSI+tspmGeE2xpT/OniVPP/gkY6u0orSMM8
EwxMXFcygtMxbwXOvac98e5Nx7xVGBEn6QtwzgD/AJx9yLI=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1kw0s1HEYx08vtBqz0rq8DL24cGLV5u2Xn4bQtOZlRpvX0VKTttpKEbrN
tHDHXeW8DJFG0ryEQz3yfuEQLteYbkzs7HbOdUJb8f///s/233+/Pc/z+T6/
3/M8tvEpIYl7WCzWxZ1v90/bHzj98t54x+1WdJ6yDXj6tnhY9asN3aBMD9PJ
nvNnsiWoWLxrvyFbs9dmLbATjY7smg4eRXpyjrl+QjRPByKd66kvwUB468Dz
5oecG+smPC00BEjW5kx7CG8NrNIseiPu9hKeBiztC8KtNX2EpwFb8xR5ceEA
yVcDt0xtthk5hKjwkVWYjV+v0vp/JXoq2IpyC0uNGkEUXrwC1mx+W0CxjPCW
QXe/19z+yTjhLYE8XTGbAROEtwilikkbO+NJwluAlv5bDnOxU4SnBNN/NbPl
jdOE9xOia0czHNblJH8WTkjaDDqPzqAiKl4Bj6v/engbKlACpSeH0P78VLcP
CuRC8Sfh8n5t0oMtBeGNQ0FDq/vipILkS6E9ItJDx2Xie+Gj7N3nS6wZJKD8
EjCosmq7EiZHmdS5Fhqdcp3C0RRiOmznn3lnXj6BKmg/PjlYHeollJGzBPPC
6qM5D6XIjebjus1Kr7GqPuKXYnd9ThDnajdTH+6IHPRJ5krQBbp+7MxxN+Sy
m9FN+n5Y5cvaaqmtR6X0/XHZj65GU94bNE6/D/atyfM7ElvBvB/+NvK+53m7
mMQrMSvPPKvO+QXhL2CX6pyZ+vRCpj9YowqMS2EXEL0lHGpmOF0pFDD9xa9C
F/VNZQLCW8EcKIG4bQHhqbBSfPC4Ja+A1LOKSyMSHKXsQsJT4+HtTKV3XSEz
f/isUbNxGleIZPR84vLvuSbJYiEzv/g1a2gmUS0k+Vqc1M/PUjuIiN46XrLo
OqS9JmL2A6PBffmOMSLC0+Hl4PzgnusiZr+wybMDJUZ+IsLTY35MkUuQDcPb
wDVan4iBHT2yvzi5uv4wr0mI/gOKitCI
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103ss1VEcAPDrFU13hTzKrsSalVaULc25O2Xl0YOm4R9tpZLScuWRrfWg
h+l6ZW0RSc2UKZFcrtdXV3e67RLydsXNIxdxH9xHReX3O7/v9ttvZ+ecz/d7
XlsjY0POG7NYLO7/b/VPhx7iDWNZ9n5f0F4qdHDxxD7DkZedKIoKLUTt4UOm
qAs9yV+NJXD0MhTs1HWjdulqLEKm/rpHnX8Por1FeOr694FB0Es8DYRZLtcu
+PcTTw2cEGsvyfIA8VTwIqY0oH94iHhK4FRalCVPyoinBL+M4CYdZ5TMn4fI
cYXW/eMYooZL5yDczod13+Y7yTcLv2WC7W03xhHF5ysA8l+dVRhPEm8aHG2v
rBU/nyLeFKxAulle+DTxJqBfJh2O2zJDvHHo75xOTVfNEk8Oh5MSM/iin8Qb
A2eL04Ll1AUyXwblReZ2CdlKlEeNHwRNqVWsKVahc1S+PvCNDh7iiVTIg/K/
Qpjw5sEESzXxOkEjN0vXrVOT+RI4xuNyuU3M+Fa4p841cnFQoRyqXwi5Vzti
hpyV6DbVLgNfkWCDk5ipj8UKLe+Lnvg2g4rpflzszDnT0PiDtIUYcb1XjLIn
kDft44rEXXNzKXLSL8Fl7AOJR3kjTH1YapmWNpo9gLzo+vFn9+BHa5J6UDS9
Pjyy8nr3+q1dqJBePw4srPKuZrWjTnp/cH1QkdPbpU/M/mH2Idc4E4WYjJfj
y2zJaERJK/HHcQI/aSVP94E5H/zLvt2qor6F5JvC8S6b2MICYM4Xj1m8q+ry
bCaeAis3Sy502zQRbxbb7rjV/cetkdQzh5+5OWiDIhqIN4+t/fxb0krqmfuH
eW13Tj3UC1EHfT/xftfG0MCTQub+YkNwb9PjqjoyX42Tr1XfFVvVkXwanOvD
4ZrE1zLvA/PZnq4bewXEW8QB2oViG28B876weeXQ8PHCGuJp8aA8UbjNuIZ4
OtyckuVneuk98fQ4vOtNTlBPNfoHwrfZVw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wlIU2EcAPB5zW4qRTRTKjCwrKbJPHrPvwpqAyW1hHCKYt7HJAsVFc9K
HJWaoFmKR1KYYCIZ6qoPM8LhwTzymNfW89h0qNM5L8zyvW9/eDw+vu//+3/n
xYjkwCh9FotF/v8O/0xso6K6O4q2GxRxk44tdD0+wawtZo6IpkOLeEIXH2nn
PPGm8jA2UVcg7xh1dZHo7zsMDUqf0W8Z+KYgGE+DoNjryOyjJextoPMae055
gAp768gpLHThU/AK9tSo3JZzSchbw94asn3amxGeo8beGvKoPlkwJFnH+StI
uldm3gYagh7ep0LJcRlvX/Vv4nrL6CVZ15ySuUXQfKUSfbHpMnnB28GeAhls
J5hR3D3sLSD+fVuFyH0fe3Nok33awiDiAHsUGogZP+sjZpGMJ0f8HxVWdpQe
yXgyJC1TxsVp9Ukmfwo1F5aaw7YB+ZoeP4HGRF2WRZOGZCRdbxT1EVqJd6kR
yaH9YeTMyZ8SHWVjT4LSCmVXnLhsnC9G2uKsEP5xNh7fjaylWan5BUZkCd3f
gXo/+jbW1BqSuXS7EVUjB9hJNCB1J/zErf1xwK4eWcv0w2KkTZUwjIXbHSCQ
75vUx+8TzowPpyJEf71sdgmmXwx27eLL5qZbeP8kQApY/Fv+GsKRmT942z9n
ZS+oiVhmfRCc2UDZt64SVcz6YUTYdM3OS0VImP2BVr/OstGHSuzJ4JzfWrrH
hUU8Xg4fKKtYgfM89imQPwsfqWigdOcDJNVyzz3wD663ADV3Z92SHOS684UU
O1+IdpFhTwmSHu1u2tcZ7C3Dg42VphzHaTwfFVhb/MwzHpzE3gqcGD+InhBK
dfcPeixKQj+HTBADzP2E1aVcQbfnuO7+wndJUBHXdQznr8P7NM93WvdRXG8D
bnuvTwmCfuveB/RxfyVGpY5gTwM9rruWsvph3fuCg+ws6zPSIexpwU2eOc2z
HMLeFihMk9TqqEHsbcOkvzE7r0NC/AO7KtD/
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1030s1GEcAPC7I5NDXM5bc7qLqahJFO739IwlyRoRI1krJy/ZbA3tlOlc
U2zZZTMvI20m6Z+w5WXWHktdnbdOpp0Q8tKJk+PceQnl9zz33X777dnzfT7f
55V/KzMqmcVgMMD/b++PYx315Fs6urD11Gk6DCiAEZaym2qgbtOhR3nuvp19
M+tUVeVerKFDT3n7CySbVH/fXuhQbz1bKAr+S2FPh1q3j0mYnjvEW0VXuQ/G
y10ZAHsrKCQ7+Kw0iAmwp0Xi4CFuWh4LYG8Z5UQN+ucPmwDsLaPZhFDHjfB9
ZPwS8k6RzS7+NAN0et8iapClWXtVmwNcbwElH2iJYIstAM1XzqOy5KZhbq4l
8dSo7fJIz8vn1sSbQ7/eeSt87toQbwZ5DZxTXKmzJd40kvrwWcofHOJNIVbz
a9NJnh3xJtHJ5kBBRgKXjB9Dgtjo+2NF9qCCzh9BDTc5EfwaByCi631D80cn
Qj0LHYE37Q+h4UrbIIOvE/GUyDmr7Z6wyomMV6CMlO8hZY1OJL8bFZxPeqxK
cAIyur8D9bfwYjRNjuAh3W5ET8Tt8tomB2A84bKaYel2mj14gfthdNdWb5jW
jrQ7YGTclzjTxIPAH/uw/HB88cf3tqRfAUNH5eZvfG2M84M85YVWVb4V8MXz
h/Fm6olOlQVIxeuDryYkuym55qAarx9qXa+1HxGZASXeHwjcKE69zNS4f7Bc
mlkYvs4i+VOwIljhIS9lEn8aWrpktfDiGMbzgdnsw71FBTsUrjcH3T3ksRKZ
8f6p4eYZkUmicpPC3jy0YljlBgVuUNhbgJJ05rjmk4HC81mE3EgbcXqWnnhL
UODn97lLuEa8ZdjNvGPa5ayjBvD9hHU5W8IB61XyHrSweGM3/gN3hYxfgaPt
HN7QCS2ptwp3x66zM2OWje8DXnK7GCC1/0M8HeSW8hFVrTG+L3ijRPV1LWCR
eHp4qqS2dVDzm3gG+MjSrVvQOk+8dXic87Yw6Zma+geb9rS/
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAPDpNnJOS2XqWEs2385VsnSJdTxkhf5R+ZiEkCaaRZKhiNhT
8EG5Enr4yDQrFbZl//hM0sovMZaiqcyQFEunZQ2nbTofvai899wPLpfDOd/v
O09penbCaXsWi4X+f5t/OjaAnWztTgx3QHuoWIdLeUiS3MJDZ6hYgyb+ZD87
ho9qazZjFUoC08VZ9s7o3dBm2OAn567Ibm4roj0b5Bye9u7JdyHeCiRGq0zW
clfiLcPgwxlDVL8b8axwn3fKcU0oIJ4FsDHWkFHqTjwLSLOCuWZ3T5K/BDLv
yLcGvRBRw4fMkM8XxfnViUi9BdCWuXAKq8WI4mtM4LEaW6rv8iLeN1Dt1Pun
FUmINw8Tv0pyE55LifcZokOURzv/ehNvDrRPZ295JvoSzwit46kpwS1+xJsB
08FXoflOASR/CgwBgeXOqYHoPjV+AmQf2nbfexCEMqh649D7aSNM0y5DIZQ/
Bpaesiu66mDijYI+QX0yJVxO8gdAl1R7ZFQtJ+P7IOaNTp9dKEd3qP4uiPdr
uPleLEeFVLsJwsLCNY/TGY/Fiq9yO7c9RYbq6X6cNAUxjeIg0u7CfYpiJ0VH
AAqnfeyac+PakNKf9A9grmFXfdQzX2Z+2IcnsI7s90Gh9PzxH2UGp35cis7S
68Nij+ZugVqC6uj1Y5HyYw1b54VG6f3BlUWNvpJcMbN/eFmLAiTZIjLeiM8H
F0gja4XEn8MXCgSXQ757MOeDr09rc9oy3Um9eRxRFZE2yBUw54tHZ49XLIAb
8Ux40rzUbKl0Jd4CXvR+vcOr2IXMx4xVipZ4qeM24i3hiIrY2fS9zsz9w5qW
A6sqNR8N0/cTn+jk8Tt+8Jj7iyEvIe+R2oHkL+MnbK3xqmILqbeCb2suVv22
cZn3gb+0ftVxhznEs+HMfYvG9hds5n3hAWHrSNxLe+Kt4Zluce+xYTvireN4
1VLxIQuLeBu4YUzcZJKw0D8gH6jd
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtIU1EYAGDTjBVI6TSdmnNOnWbW1M338c9MV0kPJlKiEQwfQfRgGivS
tYQiCi0zMZeoaPmAkNIydNHxHaIrTbAHqanhA5ebOufEV3nvuT9cLodz/u8/
T57sqjTN0sLCAv3/tv50mLHAMlnSJOegICqWcXKKu6rC5IzSqTDh0PEKyTu1
K1KXbMUSDjbnZrvI3JC2byuMuDojCPg+7oj2jFgxxDmZLeIRbxFbpSTd5p3z
IN4CZkkq9YeL+MSbx4POHLnvnCfxDHgaEl9Fp3kTz4Cl+d0JK2sCkj+HB8zf
Exre+yJqeJ8Oxz6SbpYV+5F6s5iXd0RbUOaPKL5kBjfWuJS0aA8RbxqHCNyK
q+0CiDeJrU9PfNwhDSTeHxwd3Tl/oSqIeBM4phK4rVZi4o3hD+wW8d0rwcT7
jYdVwhTr4RCS/wtfqllRnIoLQ8+o8T+w8v7gqlN5OEql6g3hZkPW+u6fEUhI
+YO4114hyZ+OJF4/3tMW7zCqQSS/B29+VXLm4qLI+A6cEzJ0gq+KQo+p/mbM
VRYlbsiikIpq1+Gnn3KMawaEmBN+kzderwxAqILuh9ct92JeCiNJuxl25bJy
VevhKJT2wanKpnBbbRjp7wGzvkXjD6HM/KCxcHN15EswEtHzhxda85Jvqhhd
pNcHGxr7h1IrESql1w/sDJcqbkMg6qf3ByZtv8mTMwOY/QPvzMuOSceEZPwY
pI4JKwdkB4k/AVmK3rbUlAPM+cBU6wJfd2s/qTcJieLzHnLsw5wv2F5Xu3d5
Cog3A36Cm39L67yINwsqkzi5Id6TzEcHtctNOi2LT7w50Bf4t/eP8Jj7ByJ1
RXdzrzv6TN9PyLeL7TrznMvcX6jpPMvSdO0j+QuwODW8U8F2JfUWoTyfo35w
x5l5H+Bmp58Os+EQzwhHl/q8tr91ZN4XhHHr28sz9xLPBNcC4vNMxx2ItwxP
GpI6eGJ74pmBdWM0Ij2Ijf4BYSuzFg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw10w0slGEcAPBLPtZlVvPR0myMlm+Hc8549seRw7mFrFo+miEbGzNbtEny
0VxLplFkdtwmWtFWxp3LQzYfTVz04aPkptE5hDuOmJX3fd7/9u7ds+f5//7P
p0NqTly6EYvFQv+/oz8du3j6T29em58L8qXCgG++X9gueu2KMqjYwVm27NrU
KHfUUH8U29h+oHDiuqkn+jh2FHr8oNujt2fZC9GeHudOOCWz9zjE0+HZ/hTz
l1Y+xNvCFvY2z2aFvsTbxDV+FdmqJ1zibeATw03V6uM84m3gjVN8u5xH/iR/
HVstfU6dCgpA1PCxVayt0uSHWQSSelpcUsldaTdBiOLrNdiNrw5MdQLi/cZa
05P7hV3BxFvC15IMHfGrIcT7heFFXlapn4B4izgJNezJqsKIp8Y/ImcmJnXh
xFvAt0rgMDklguR/x0m994wlo0L0lBo/g9McDFZ5zlEojar3FS/eVjaH5kYj
DuVPYa1c0TP0WEQ8FV6RaCKzymNI/ij2D2zykvHFZPwghl2UUSATo2qqX44T
Y6wS9ViM7lLtdtxgOSc89lCMmBN2HeTLyizESEr3Q/4dbWiHKIa05dD/6b7j
2zgR4tM+jLYVl8Z7RJP+Uag7U+yarYlk5gd1PZcVazVCxKXnD5OD1nNu3AiU
Sa8P6screDVfwlEjvX4oO7tf3VwUhlT0/sBAXyf7nLeA2T8omblkFKoLIePV
sMkL/uk4FEz8Rag0KxzuTgDmfMAjflrRKECk3hL42D2XvkkIZM4XwnGO5kAS
QDwNvAtyvPhX7U88LYwljJjNX+WR+axCaAu7tWONS7x1MJEfjtxo8mXuH9jW
Gs9rMn3QOH0/Ib3TbkUU7c3cX1DKJActAg7J34KFWI4yWOpJ6unAWxSn8Jx3
Z94H2BQmjGwhN+Lpofw0q++V0oV5XzBRZdmqvOJMvB2I67Je7jK/QDwDSAuQ
Kn3mPPF2IUUV++1DrxP6BwaOuuY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw90wlIk1EcAPCpiRKrSAlUTBEH2uk15zSfz3NzZtPNvCeWeZQpE5NQo4Og
zLSaZtTSSqEiS1lKQSPrCR7kMZ0Z01IqmyxtU9cON7Oy/L43//Dx8Xjv//u/
0yNHyM+zplAo4P+3/ifDjLLmf//i6hgggAgTahHG2FeymSCfiGVk4EgV2a+C
wV3xehhRlIa2U8I+AGTD62FAKVt4jmnmUEB6BuSu8fW4IQvDnh4dHlv4np8X
jj0dcm+POj9XEYG9n4jVd/Ms53Ek9rRojNk/8kAThT0tokuo2m0JMTh/EaW+
8fvQNcoCxPBhDXLgNfVKSmJxPTVaq5c8eRkQBwhePI/Gyj079rvEY28O7ZY5
+MtoXOypUMGCPKd5VyL2ZtFQneNmFY+HPSWyolBDjlXzsTeDehPaP9nJkrD3
FflljwdFOiXj/Gk00Z33ty83Bdwhxn9Ee2zOtZQ+TQW5RD0Fau+u8S/5kgZ8
CX8cNQpYLmJzOvbkSDp1PQz8yMD5A0gk5rwNbM3E43uQWl9r67lXAEREvxSt
uXqvNRQJwAWi3YpqqpaiFQUCYDnhleKyd97uAtBM9sP+QVRQfDsTt6Vw2uvQ
lYzJDMAkfVh/yVh3Rp2O+wdgcoWw2mcqzTI/aC2vog51pAI6OX+Y9Cfabqk8
BRwn1wezG/g2TsHJoIlcP9znVjF6dCUJyMn9gbdCOXWnEd+yfzDWg+t0/wYP
j5+BXLXI+VtRIvaVMEL/ubOyk2s5H5hTSNve9Cwe11NBfqtpB7U/znK+0Csp
zbXNioO9eehsUtg9zGJjTw0ZPO7Fe5MxeD4a2NPGLtSVRGNvET7PX3WQ0zbu
HyybHWTwdBFghLyfUJpef0o0EW65v7A8rmbpxCOI83WQVdt9zdgDcD099IGB
pUK7jfcB+Y2bQrqKQrBngPXKq+mrWqblfcH39K2vL9cFYW8ZRhpHJ7UHGdgz
QWt/ldLKLRB7Zuh00v7IC1s6+Adt6LoG
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw903lI01EcAPApZjApLKRMMw9mUVoY+kcHr+ecR7nacmJ5tMydeZUmnRDO
pMMMGaPETZOFRaWVUplH6qtVniss89iRZYZuU5bz2JRRlr/fc1/48ePx3vfz
fac/7zRH6EyhUMD/b+lPxjxyvZLFKbsbAUKJsCFRalLHnjoGEBFhRUNtVUNU
TSRQyJdiDsHqc+Igr2jwUb0UsyhPyiydORsDSG8WXUnq9LCY92NvBpmirL7G
67HYm0Ytmbzzg4yD2LMgluUoMAWysDeF7Kp7NS2eh7E3heQewy/sYXE434wW
vFZMZ6VzADFcPYkU91OKmxvicb0JZMuUrhX4JwCClxuRtp7NUDw8gj0Dkm0a
dF7NTMTeGKoO2C6oc0vG3i/UyAyP4xlSsDeKvv5hSG4Pc7E3gla+fb9Kb0zF
3g/0UzP/W+WUhvP1yLNVmuGzhgfKiPEaRIu3fRjfyAcCot4A4lMHntT5CEAI
4feh46ku+imqEHu9yPtMsrtMJ8T5XSgjECU+vybC49+htIxDopsuYiAl+pvQ
FlqBG5MtBhKi/RiJdCrVG74YLJ9wFb1ih4IuBkqyH76U9fbHTohwuwmaenT1
lUIR2EX6MLy2g+bXIMT9XVCzr7Lo1LhgeX5QXVjQqvjLB2Hk/GExPSO01IUP
TpLrgxfT9evaKDxQQa4fatWXb91YOAF6yf2BnyP32msMjv2DHu1+ne0mLh4/
AmuNHObTxRTsj0LpN3NVY5DjfGCz77ORitxEXG8MxgQrL73+4jhf6JSTVpLL
TsCeEbblsfuPjcdjbwKOdau878g5eD6TkKunbdUK4rBnhq6yB+sbYhz3D+oD
eli7C1jgE3k/4aNtITmGcsf9hdT8q3NJ+licPw0lSkluETyA683A7PZypULl
eB8wuHtn2XdeNPZmYaHzcInOJ2r5fcG+fCqTYWFgzwrdX3EX7doI7NngBWvL
5g0aOvbmYXYUr1NjDAf/AKFqxkQ=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw903tIU1EYAPClQqkoGfloaCaJYSZZThDycArB1Gm6mXNTho9tOp1zd6Ch
f+h8QGozszB0vogy8QFRKcaMOoUJLjW0tUR8a5hLWe6hjvmH5b1nfnC5HM75
ft95BuTI2CIHGo0G/n9HfyqsaKklJc4mjQfhZOyj6Ryp73sjE+SSsYcGhs0h
Pc2JoE11FLtoARiFal4SmJo8CguKaNRb/Z4nA8qzIMnFPxMrAyzsmdHciirU
a5KNPRP6Is8f0jndxZ4Refaa/6ZzU7G3g6LoB5rDcQ72dtDVrv6O6zwuzjeg
mYlUVq5rOiCHT24jSzlbaFvNwPW2kODeeIjPMh+QvEqPgltLgm45ZGFvEyXX
8u/3BWdjbwO9vmG7phXlYO8XYtQUGLyGBdhbR83sQumsjwh7q6i++x03UpmL
vRVUqwhTa0+Jcf4CilPIE8qU+aCVHD+HdO4N/s6uEiAk6/1EHm+eshTlhSCM
9LWoLe3EYcysFHvTqHOzJGrNVYbzNejDYgxTfpLA40eRYWJ/tr6AAE1kvxqp
ux/5zfQToJJs96Eul6TAqjEC2E94qSoLDKkJ8Izqh7v00x2iOntbDTlujVdu
MggQSflQ7hsepKqW4X4NzCwWQnp+kX1+MCiikhF4SQoY1PzhD0kpcX5cAsTU
+qDLgO7FPqcAdFDrhx/7vcMbF8Vgmtof+DZ7+WWCMM++f9BfVzx3YBTh8avQ
3dEgGFUKsb8Oe9aio5gRAvv5wIdPosd2drJxvQ2o7zJLHD8dny+cydB8p8Vk
Yk8Pbc3i0MfhfOxtwamvnfr22xl4PtuwpkI2RlTysGeAfbHOl50W0uz3D/o/
8NOe43LAN+p+wmSPkBGB6fj+wsDexZGW3hScb4I1M1P0ilI2rmeGg+3Vn22Z
LPv7gOUXjE1n+MnYs0CFZ5B1fv6O/X3BMtvvvMGAROztweKiNe+GOib29iGP
aTqrdIvHnhX2EOsWz1ex4B+HkcFC
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw90wtIU1EYAGBRSigytGZgD3v4IqxWaZTs9KuZhilz85VmS8c2xlipc6YE
mahjLiuW+X6hZoFKDUoEiTw9tJxTWT4GhmWmqEszc/NBSpb3ntsPl8vhnP/7
z/OAMJkvtrWxsUH/vo0/HSu4M3doKkobgU5SsYwbBnUx4hweklCxhPXx427D
aj6qKN+IRbzVIr9TUB+Jens2woq3yI3eqsEoRHtWbHnUE/jHNYZ4FuzzsFh3
VR1LvAVcdl9yM3BbHPF+4Ym6XQZ5Szzx5nH8QfN5w+0E4s1j0/oCR6wQkPw5
/AXKhhtCEhE1vGcWBx3lcNvkSaTeDK6/kVvT2yhEFF9uxqXvwyZsbUTEm8ab
L5YHOKeIiTeJnf1rvI/8lhBvAsd+to8oqpYSbxwPKAIh9ZKMeGPYmHdiu8xT
TryvuMkuICR003WSP4JFazuqn39PRmXU+GFcyR36ZJlMQSKqngmPsI16+cdU
xKb8Aawo9hhtf6ognhGzVZqSYGUaydfjw8JCFm+vkox/hyOzHXO765RIS/W3
4Qy2evDHqhJlU+1GrJI2GAY809H/I3Yxdn84lI5q6X4Yuas7fnleSdptYP/M
L8Bfq0SnaR8ey97Wr9oz/XpAK1PWzCtpzPyA88BVUVCqQD70/MFtMTpE/CoV
Sen1gddUcPROUwqqotcPLv3cYi9jMjLS+wPRT7QSu4VrzP5Bu8VRNe4iJ+PH
YDS7/5iJJyP+OGRpBJy5SilzPlCqy+zLW5OQepPgzHJ3V6eLmfOFHNZrj057
EfHM0BHAZ515ISTeDISdam0Jykgi85mFl4FLI9/4icSbgzfNXfurNALm/kF+
lnDJrzQB9dH3E3LOFTq2GOKZ+wsGJ1uJi1scyV+Ae85N68XVsaSeBX46NOtT
fGOY9wGi8DqnfeYo4llhUbKHd7Y1knlf0JF2Iby2gk+8JcgS3NL4F/GItwzT
viX5IXURxFuB0LHdXQ7ZXPQXPhC/gg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw90wlIk1EcAHAPnEdhCoVmFyIKapG2BSN9/rPIEtG8zWvMszG85nTeTKJS
K0tDSGuZiJVHppWEU/OVR2OmIppih+mcmMdQU9OFFuX3va8/fHw83vv//u+0
jk72j9PT0dFB/76dPx1a7I4NFTDvj9hUbGIfR6VGtR2A4qnYwDG6o3FFdkHo
fsVO/MTzLN5LX0EwGujfiXV8u9lTfq0nBNHeOrYKWuA+Q6HEW8OF/Vnm0rEw
4q1iOethx3JpBPF+4E5Ftp6NmEe8FWyEtodb3PjEW8GRzpV1+8OiSP4SXnba
15dbHI2o4f0aXPkmR3vncwypt4jX49kT02fiEMVXzOOLMvMXXYp44s3h5MWr
GaZCAfFm8fSvu02/7YXEm8GFU4GW46wE4qmx0sCvr/JPIvFU2KbqwsZHVgrx
pjC3bKLA2kJE8r9ixWPLCNujqaicGv8JB70Py5OeFqNYqt4YHjFuypV6pyEn
yh/Bt4p5gwFe6cQbwjVsF5ckZwnJV+I6086Jg5sSMr4bL7z7IvMoy0AlVL8c
t0pnthz1MlE+1a7DHtzDiUaumej/CfO/C7MgE1XR/eAtcxis3s205cC/rtto
8SQDcWkfFJrnB8rMMki/Ehrb2tZK/CXM/CC2oKunVZyOOPT8obnIttIzNw0J
6PWBSbdOnSRNjGT0+oFfY+E0GZOKhuj9geAZKHX0EzH7B1Fbxnlj7ilkvArK
ot9qUVoS8dVQ63pv+kR2AnM+YHL2RufTCiGpNwuiQwOmrFEBc76gVu5yjzp2
mXjzMGnZ2/6hOo54izDQoOl4xIkl89GApDyyok0VTbwleCU+uVZfG8XcP/im
Xr0yUsBHg/T9hD05BuNGWzzm/sJ0zMIRK7NIkr8KJvqOp0q8wkm9NeCwi8s9
6kOZ9wH6IoeV8/aXiLcO7eUtc8O9wcz7ggd2hQ3heUHE24AhH8OQm96BxNuE
gNe+e904AcTTgvhcY0j+cX/0F/cSv5o=
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw103tIU1EYAPAZpFhSlmA+0lmU9tbMP7Q6fiBiGhWYr+WrOZ1NGcv5mG4z
FRH9o4IyFZURYtA7y1yBmn06na/U1EIzLbSFj7Sp8wnRy3vP/eByOZzz/b7z
3CO6elG8icfjkf/fxp+NdWyQd7+xiw0lJ5hYQ+upxpfywjCSyMQqSs2CbKTt
4aSyYiNWUB+jzgh0EZDeno1YxkqTZ3BO2SXCesu4k/++5O3hKOot4fzgU97K
t2jqmTDAY8ftMxhLvUW0HAnMthQJqbeAcvMHErkqjnoL2CHMH619LKL5RrRw
NijuL8cTZnjPHDrpTEH8SDGtN4vXmw3hnWOJhOErZtCo1sRY5EioN40FZR/L
en2TqTeJmqwCjyi+lHrfcWvCeYclZxn1DDil1mjRKYV6EygQXBgv8ZZTbxw9
ZXzr9ehUmj+G8QG25dWFaaScGT+CzQ6qqJnn6SSBqTeEtq3XspsGMogH43/A
AK3IddSgoF4/Jm5O8vf4kknzu/Du4tc2pTaLjm/FlpL5c+ZxSnKL6a/HF206
q9xRJclj2o+w5mSBrthZRbgT7t8XZC1xU5Eqth/shM27+laUtF0P/CM6t+M3
lMSb9eF3XcOBmPks2t8F6nDfIRvXLG5+0JR66I/aO5N4sfOHqgl7M4W7gkjY
9YGkO/rmrE0G0bDrh1xID/EyppF+dn/gbLUM7+lTuf0DlUWPVWCVnI6fgOAS
beJwfgr1DTDkZ6rNm5Bx5wPDZMuPqk9SWm8SGrvcXnf/TObOFzQ9bR2+e5Oo
NwPvep+MuyiuUG8WarT2Pp3TYjqfOdDL/Fd4ygTqGaFSJwDYH8/dP+gtOKrX
z8aRPvZ+woDasa2lW8jdX8getrvTlHeZ5ptAP2h0fVgaQ+stQXZxUcTn/iju
fcBpn1fbnd0jqbcMfl6OgoxnAu59QVnHtoO7gyKotwo5p3ymiv6GUW8NLIZH
osV9odRbB+mvY+2ldSHkH0JowvY=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtM1VUcxylnIiFFgKDUjUtSgGLsooS4y8/wFiCbDKgY7c54BFY2AeE2
EmxQPCrGRAQHrvFGuA55CyjIT3kKIV0e8kYew4hHBCSOWdPu75zj1tnu7u7+
5/7+v9/3fL+fIw0K8wl5UUdHJ0T7oW++ptElvrAmbWylWXm+ZcNaOYVev35j
2F2jgw2SxCXvhge4KLluYS59GY3L3WbOGj/A0QoDg9xMI4yQ6w0Xhk+iafFs
ZF/cbrzXQ2sCIysKx1MPStGGFZzAxWzZoyP1VkjVJInjuF86Y7nUb4vaYtqK
Y+iTPets7mmPLlROPobvuE4lhCc74OVsWqO4GG/4m8LqPXxsTQVHMF1R/NR5
72H0YQ2OYOzOvYvqXEDWXvkwFmwOOcgVrsjK6Q1j1eFPW+I3FBjK1hAq4zXt
6w/dkKY933IfrYtjPc6YeiIbV3Ifa0tsagNTjmMMG3gQh9dkK25Sb+TlBtDs
epNZhsQXHdgawPwEjwZv+ceYxgr2o4us3G4y1g+XadylPpy+EBZmN+GP7mzg
Pmy/VbVN46/EIipXqEHXi6slv/99Avl5aDD8SZKz0WCA0L8Xe922pS8fCkK2
PfweHg11e/KXOhiZHNY96LH1X4XSMgRnmZ7d2Oz0Zs/7+aFCvy5M7lJdSdrz
hdDrLi5FbpQuqb8U+nTinqRqyWvvnhJ6tKPJZtnr31d9jazc2Tb8+SWVb9X+
0yhj87biqsUxF72iMDHfHbxTs6Pz2+RwMc9tdC33Gz7lGCH6b8Y4zwuWlyYj
RL9NKO0IbmuKOYNZrL8bOHtc71rlK5Goy/qpx5N5imc+WZEYy95fi/6luo5Z
xlHifVV4ZJ/59pQfokT9ciy4mbnday5K1FOjp9RizdJRhdHs/0Xofss+Lyha
hZVsfw7mp67f/fGqCuPY8wwMqIv4wL7n+e8ErLsSYmYyqcLnCUF1APstnsNy
Y9D/9mfArpRRVu82rw9R+TvY+/jzIlgbXF+lfvJ4fxAoPcH65fvLIctqVJfm
WeXzwfyrTQdpXt5/LTj5/vmU9BD6wMO3S8tIL6EfFOQ+biU9hb5QvHUX01vo
Dwn7BofoPMT5gPvUdx10XuL8oKvaRE7neYCfL+S02vjQeXP922Bh9pg5+aGN
+wPGaw+9QX7R5/4BpWFoCfnpI+4vmDPRFJHffuH+g76fgrvJj9Pcn3Cgw/Yo
+VX4F2Z2Bm6Sn4W/4WqMfhr5XfgfAv2inSgPIh/grH+tkPIi8gPmcR5bKE8i
X7ByZO4rypvIH8wnvmBDeRT5hMuKczWUVz7vAEhq+40ozyM83/CPrt0C5Z3P
PwgjjQtq4oEF5wPkeekD8ULwAz4LcWgkngi+wNz8xXrijeAPXJpetCYeCT5B
2haDQeKV4Bdkqz3+IJ4JvoHs5LkG4p3gH9T5mZ0mHgo+wrJs5S3iJc/7GBR8
WPJoUcvTJM5XaJmobCfe2nL+QmvsbBnxuJfzGTJvrJoQr7nek9Dp1FiRo+W5
4DuMffJ58G4t7wX/oVqT7tulvQ/E/QC6ZaY3U7X3hbg/IKB7offZaL38P5HO
P5c=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlXtM01cUxxtZQRHJYPzBQHAqmE63qJsTEcqhEJXNKb4CMytQQGYCYgsG
Lc/AoDo7BB2PCKJ20jLNWDciQ3TA4TkegqM81oJQHhtIwnzAhonI5nofS3aT
pml+t+d3zvd+v5+7Nkp+KGaZQCCIsXzIN1vjuGnM+qfMI2tQmt+8IJKOYfFv
u7ecXdiCte6q2YO1ZhSWukzFfumDTvo9EylOZhw8s3jUejIQE8S2xnLFKBqW
Xmyof/QR9nSTNYI7YTrXQXkQ36YFR1CgkH/cYRuCpJq76iFeXWnWFHt/ipZi
lorDOKt1vCI6L0M/Uk48jFPf3BcqDNFYWkLWEAbIBj1VacfxuYgUNGFyafxf
bpfi8BBt0IRrPtlz3GCrQNqe3ogalfcK6y8SkZazNeKK1JPz5oAk/IyuX1Ed
6xBVJVYimTa/eRC/zRINRKWkIh3XfRAzZs4FhCxmYCodeAC1yy689m5EFrJy
/Vi5SZm4Nzob36erH7dXZgX6n1fhRVqwD0eC8pyP9Z7DP8i4swZ06ldO3/RS
YxAd2ICHt6bPFdXnopaUK+9F392ux3bJ8pGdRy/eC3Tsq7K/xPV/gH5SD3BO
/grpdkUPpunSXZoeFyCVQ9SNMYLvvadii3CS6tmFhWE7c/OeFHP9OlFlCo8s
O32Z69WBLffj0zoEpVyfdkxwGB+vVF/herShi+cqny6Hq0jLpbRiXrhVe17B
NXyPztuCoYMhXXprDZ+vCY1Hr1vtbdDweRrRTjNRs0/+Ne+/ARvkDz886XyD
91uHA2u3FsXX3sDLtL+72N7jf+bN/eW4nPZzB5+2Ze44YCrHNPr+apTO3qqx
CtHy91XhapeRfb4/a3l9Pb44YVC6inS83i1sCX+5zpyiQyX9vxZnJM9vmut1
+APdfw0XvFapip/pMJM+L8SmE+qK644V/HcO/p4TeOrH9RX4X0IkSj/6mz+H
bYGp/9tfCDXTf+aQeo2sPsTd6aPvY8+1IMvuof1oWH/QvL6E9sv262FeUkLn
ecbmA0+ZlM7L+q+GpUgR1YPrA5K40dNEL64f+Jc1FxI9ub6Qo4ukenP94ekp
KT0Pfj4QVm1Pz4ufHzhV3Osk57mNnS8IR263kfNm+rdCUmaFN/FDK/MHJMui
xohf7Jh/QOI9lEL8dIT5C+a1tyOI38qY/+DwmFJN/DjO/Ak55UYv4lfuX3Ce
vehM/Mz9DYlD68TE79z/4KNZ+oXkgecDXt/cGUHywvMDK4eEj0meeL4geHJ0
guSN5w880g1vkDzyfML2fq0fySubtx/C3NPjSZ5NLN+QqUl69Y4l72z+AfAX
e+wgPHiL8QFcvyvoJLzg/AAbt+BQwhPOF/A98PkjwhvOH5j4e8M/QguPOJ+g
qs9BSnjF+QX2Ni2jhGecb1AWPWdPeMf5By9tqp/ILTzkfARxV3c24SXL+zCM
zb1KIDw9y/gKUZIgN8LbjYy/UKDOCCM8fsD4DIUb77bXWXjN9B6FXYqQRaGF
55zvENvm6Ul4z/kPdsF1cpXlPuD3A7g2GmvSLfcFvz/AZ/UH+tDNM+J/AYA6
Rfk=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJxNlQlQlGUYx1ck4yoYMQvETSR0axoVgWgK9lEnokMcWQmLgBltSGqQw6xg
gRLlKNDYCYSVFLnGwBIEWQ45nr2EpVFCzpUW5FBqBAMcEETIvvdopndmZ2fn
e/f5nuf//v+/1/lgtCzcTCQShQsf8s3WMFbsyRVnO72JIVnaOUnIbVyeVdls
/sgf68WpEwH1Q7iipF9e37Mf11T4jcjXDGGk9C/JbvcDGOtj1V8SM4gNCuNg
p+8hvHGdLBMaZ53lKq8ofJkWNOFzT2Uc7rP9Akk1ceofOKxKF5/K+BqFYkLF
AbyrCHjhz7xElJJyPgOY6L40f985GfPPkHULrVd6Nm/0T8GHElLQiC+NK68E
daejjDZoRIOr/Srrq5lI26voR29VUdvWlQqk5az6MfD4tq74sB/xU7r6cLbY
dmp0OgfJtFnaXpyZitNaNuUhHVfci456yatOmnxMoAP3YO4uz8Y2UQGyct34
iXvyydPNhehOVzeeUF767E5eMSpowS50S1fPNf9QipNk3Imb+PHiZl+vogv4
Dh34JgYbPZSWHWVYSsqVdGLz0zFBCvtfkJ1HJz76qTLDEH2J69+BHU9iZgOG
K5Fuj7mBW7LTTa+7VSGVQ3Idpz2PBmfGV+Mo1fM3/Obne5ej265w/dqxf9/9
AjsHFdfLgE4mZXtcZC3Xpw27RcvC9HVcj2u4Qb/ziJ9dA9Jycj0ed63aIQu5
itvpvDq8Pfne+viiRj6fBss/OGUtH2zi86ixJtaxeO2zLbz/FmyNaU9zdEPe
bxOOVavGtm1Uo5L214BuhXEJU8VqtKD91GHsBX1ip4MGE+n7azBXrX1tMlXD
31eFSxfXBUSNa3j9ChzrO2uhfEPL65Xj0UWjRJusxTj6/1K00IxgWKMWL9P9
BSgzBGYsjmvxGH2eg7Vhv6+Vmuv47xR8FBpb+PdqHf6XkCnzw/Q3fw5Re7X/
258Dnz+W0npqVh+km3T0fex5KWxPqqL9FLL+YCk0kvbL9lfAGYfRvWSeaTYf
+M1/S+dl/ddASEoc1YPrA/vMXaheXD8ISwqienJ94XzefCrRm+sP4nmPInIe
/HzAxy7HipwXPz8IQx8ncp4e7HyhS6QAct5Mfz0sl9nEEj/omT/AdUVNI/GL
DfMPPFjnbSB+CmT+gn8sk84Rv51l/oP69YcqiR+HmT8BDYMfEr9y/8LuqqEB
4mfub7gmezxN/M79D2abnk8neeD5gGOramUkLzw/EFESnEPyxPMFXz7ZspPk
jecP/N++OEPyyPMJv55PCCd5ZfN2w/eOnt+RPBtZvsHbJrKa5J3N3wMLbW4u
hAcbGB+gNWJ/A+EF5wf4qlvvEp5wvsDCAZ2B8IbzB0pC7VsIjzifwNPU8MBK
4BXnF2w9bVFIeMb5Bqa5I+WEd5x/sCvimTuEh5yPkH/LZXpc4CXL+wBkZa9+
eFLgaRrjKySk9b5FePsK4y/M2L4rITzuYHwG5z3nMgmvmd6DUHYvqO99geec
72Bh92JvncB7zn8YM+1Quwr3Ab8fQPfVxAmFcF/w+wO8RAtmB0fMpf8CCnda
Ww==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtM01cUxhGcPIbgQjMlcY3OqbycvFJJJhwVJ8gWUMCNAIGJQCKO18Yc
k4fDCU6BMbEykFoNbZaxAaOMWZHJKe8CBYFCW1sEhglTGMRsglOSsd6HyW7S
NM3/9vzP+e73/e7WhPTwJEsLC4sk84d8szWNu/rqyuQ1RzC2rGPJJXYKjynE
5TFrEvC2sHD+6O1JNI34RN3Ym4qChqDfzwgmMeSLvw8mOn+Gmf52elnGA3Qd
WGfjV5yLgxqyJlDkcULhfeEcutKCE/hTd8GhsPgLSKoJC01Y6Fmi8p0oQXMx
c0UjbnXxSvcpuowBpJy/EVscPP7auyrGa1Vk3UdDe3Rr6nQlLruQggbcffJp
Tr/ndQynDRpw5uHGV86t3ETaXoMe76UIq2olMqTl7PToVKQIr83/HpPp0mF+
3YBpXlaLZNqyjnEUve8Uk+RQj3Rc4ThWp65bxPhGzKEDj+E2TbxobWwTsnJa
3OzlrnTIbUYfurT4Xdyd98rwFn5LC45iZoF1+b3tLfgnGXd+BPMsf42or2/F
YDrwCEriMKviWBvKSTnZMB6wTwzpLFUhO49h3PTWrsCv/m3n+g9hSA0YK3I6
kW7PGETfxuT2cKtupHK4aDBlWhqhv9KDM1TPfpxKtvITuKu5fn0Yb5G3oOnp
43qpcfb5irs0cYDr04s7Nigt11oOcj26celSVsVHkiGk5c50YZv/nZ8LNg2j
N523E09ptiVUTg7z+drxiuPMsuDGCJ9HhYNTu6OuRY3y/tswc8G3ecRWy/v9
DaMcUyLTFFqspP214B/Z0jCv0DG0of0ocf83atuFyTHMpe9vxtWLQ6e/Thjn
71Pgw6CijZaGcV6/AZWF3j9+EqDj9WrRe738ouNVHWbT/8txoFyt9DDpsJHu
l6J8sfdywAY9fkmfi1EnHPUw+bz8fR7bAz+OaX1Xjy8Tcnc5mf7mz2HGp+N/
+8XgHl1P66lYfXi6X0bfx57LoXT2U9rPTdYf7Ex5Vkv6ZfsbQOW0j87zhM0H
x1/Po/Oy/pvh86ZTVA+uD1jZi6heXD/oebwUQfTk+sLVueZfiN5cf6ickn1I
zoOfD1j9c5ieFz8/mL109jg5T192vnBEbUvPm+nfBXf3rIiJH7qYP8Du5PY1
xC/2zD8gcQ13I36KZP4CcXDrPPGbhPkPcre4iYgfp5k/ITan4SjxK/cvdDfF
I/Ez9zfY//Cmgfid+x/SJ17sI3ng+YAqvzeCSV54fmD9AbsMkieeL9C+bQwl
eeP5g9ABm1KSR55PeK2u6hDJK5tXC9VZcwqSZwPLN0SuWniRvLP5x6CgpPgR
4cEWxgfQRD4OI7zg/IDppMxhwhPOF3ihcgsivOH8gWpTWinhEecT5G4OfF5g
5hXnF1wPsE4kPON8g+psTxnhHecfOPT03yc85HyERYn0A8JLlncjqA86lhGe
FjG+gvOjWwLCWzfGX5jLijhLeDzE+Axxh9Nke8y8Zno/AOPqk6kTZp5zvkP+
O6dLpWbec/7DwoqoN9p8H/D7Ac7PTzyrMd8X/P4A66JXlbpi54D/AD5HWRc=

          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlX0s3Hccx8+yrqLSZqup0pqbUbfoqqhKhw/rk9HqUC2rNCah21Rmteh0
k6qhZudhJoYd2jnNTlZh68yt48M59XR3jvNUdephXKTq5qnrHzq770OTfZOL
/PL7+vw+n/f3/X59hbGfhMW9IBAI4kw/8petSdxqtiBeehKD0QWKNZfoh9gU
nijSn7uETfZZj0KbJrB4xVEdpUlDq7rjU1esJvBZUH6D9FoWfuprMVKdpEd/
V039unUeqlVkjeMRwdOUV6eKUEQLjuNMoY+ssu97JNXssx7g02OLO3PjKtBU
zFRxDGU72qvaR2+iHynnO4ZD236cEn1Qg+VlZN1HSY2wKSBchk9cSMFR/PeX
ebVD420Mow2OonlFzt7DgQ1I26sbQfnNGJ9zq78iLWcxgkHLb/eKphsxnq5h
tN4XFWtn9QeSaQsUQ3h1rqTfUdyMdFx703Ny84Ghmlb8gg48iHcdDl69K1Mg
K6dDy8c1m7T9SvSgS4eh7j9HN+/uxEJacAC3WB/NuCfuxgUy7qN+rP1QcbJt
twoD6cD9KN6flPBKnwalpFy1Fnsi9TkRfVpk56HFZPfUd188OsD112CUrWLJ
tlOHdHuSGoW7thQawoeQyuGiwiTjSs5X88M4TfXswWBdcOhI1ijXrxudfDpf
rnIe43p1oVnHLYek7gdcn06sCdjpjQl6rkcHnlqtDzZYPERa7ooSVfXGRJuw
SXSn87ajOstm4KLtFJ+vDZe3C/y36qf4PK14I0RZLymd5v234DvDIZKW4Bne
7584UnZi8I21GSyl/cnRWe7onf/dX2hO+/kdG1JcD/Q6zeKX9Pt3UPxZpnlb
7Sz/XgPmeq3JLwrneP06vBaf2j2bM8fryfCw/2BuzOQcfk7/X4oVaRGubnsM
WE/3V+L8nkMXuqINmE7fF2Pg6R33W9KfP2fi5eDzL6mKDPg8IYcWI+kzfw9i
783/218MPQGv0XqtrD6gfB/9HnsvhYzMatrPDdYfTBf50n7Z/jo471xH5/mb
zQedG/vpvKz/O3AhWeNJ9OD6gM0z+UGiF9cPdq0P64ieXF9YcFP/QPTm+kNY
uhc9D34+kGgWD+S8+PnBGbtL/eQ8Pdn5QsKMDz1vpr8SUr51DyJ+UDJ/QJ8o
w4v4xZL5B2aF/9gTP51m/oLxkI1txG8S5j8oXU04Rfw4yfwJeQXr2cSv3L9g
q1jPI37m/gZjbIWR+J37H2Qav+MkDzwfsN0yP5vkhecHJhJl8SRPPF/wsd9Q
IMkbzx9sjvFII3nk+YSz+stnSV7ZvDpoXH5PQPI8yvINxzLaU0ne2fyDoPLc
60Z44MD4ADauAfcILzg/YNNbA2cITzhf4PY315HwhvMHfMsz3AiPOJ+gtiRT
SHjF+QXpEslvhGecb7DkUFJFeMf5B9ejJroIDzkfQWquzia8ZHkfg7jonwxf
m3iazfgKHxlvpRDevsn4CyuLdkcIjzWMzyARlgcRXjO99dChfBxEeM75DkVa
p41IE+85/6HMuff9cdN9wO8HeD1CvGg03Rf8/oC2yuV8jzWR33/Etmia
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJxNlQtQ1FUUxgkzCqnAYcgMcZskFzKKMChjOUNAysCEICoBFUjoDDDyaFIe
RoviAgnBKDMCGlCALBTLokwrIBzFJQRlRVhZ3vHaQFmI1zLZA9v7cKY7s7Oz
8797/ud89/t+99VDsQGRxkZGRpGGD/lmawxHglRBIV1HMTS3VS8M/Q3nPpC6
r1aJ8arN6Vn/q6MYYpwjl5qdQUvZ7vFky1E06dDaZp06h/EiU01Z3Ajqs+28
miOKsOsOWcOIi+bqkq0/oB0tOIwRu5zWfjpfgaSazekh3NQna19XWY2GYoaK
gziv2uAf+6Yc3Ug50SCus28UQtgVLCokawBXjztvTl36BVeFpGA/VtTMBmc+
bMQA2mA/KucslFEfI9L2ZBrc8un68TGLVqTlTDV4Za+Z322FEg/T1Ycm0raJ
LRfakUyb23of0y5Kvshv7kQ6rs19/MrHLj5aoMIUOrAaXzBxVmyf6EZWrhdX
BdX+l9Q96ERXL1qUDX8ZNq3GPFqwB8d14prKlzWoI+PO3sPO+u+8oqMGcA8d
+B4WnFyq39k/hOWkXFk3ep/0ktuGjyI7j26M8Wn5IyVtjOuvwtpfBTu+GRlH
uj2uCz1WnBMsPSaRyiG8g8XS7Vnp8imcoHp24l2Ji1j32u9cvw58VCLWul+Y
5nrdws87HZoOWj7g+rTj8Q/ftpzKfsj1aMOpQ5+IJMY6pOWSlfj9X48DuxLm
8B06700MOyd0hKF5Pt8NjJPfaqi1XuDzXMdOh4L9IW0LvP8WXPNYfznm8CLv
9xqqnnFPV6wtYgHtrwGTZ61E1jlL+CztR4EHMrS2Z8yX8QR9fz1q7dWeJpnL
/H11+MbWGaOqpWVeX4albaniUr8VXq8KE8eiWlyKVzCR/r8ca84f3aceWUE5
3V+Mmc/9vfTn83oU0+f5ePP2o6KPHJ78Tkfhft2xr930+CQhO9Km6W/+HGx9
Z/+3Px8ieydoveusPvgV+tL3sefloH8KaD+lrD+QP9hD+2X7ZfDuNimdZ4HN
B066LDov678eYkbzqB5cH8ioU7gSvbh+8LqV5hTRk+sLhUl5dURvrj80Rm+i
58HPBzyHRPS8+PlBSsk/b5Hz3MnOF6SVzfvIeTP9lSCoMXIlflAyf0Di+zc2
Er+YMf+A49mqBuKnQOYv6IvXThK/XWT+g8g6SSrx4xjzJ0zmhmcQv3L/gtY8
NI74mfsbrCoc7Ynfuf8h5tumOZIHng9oFGz+meSF5wckLT/KSZ54vmBmm7U7
yRvPH7wompOSPPJ8QlOuXSzJK5u3Fz5LGPAlee5n+YbSbO/LJO9sfjWYRlgf
ITwQMD6AZ7h3MOEF5we414b0E55wvsC0dZIn4Q3nDxw76NtHeMT5BP/2BMsI
rzi/YP6u3pPwjPMNAtQmTxPecf7BypGgjYSHnI9g73piF+Ely/sgKBZFRYSn
EsZXKGhJ6ia8tWf8hQM+L10iPFYxPsPjwLaZawZeM71HIKbapiPTwHPOd8jZ
G7BaaeA95z/4jmokesN9wO8HCK3KiA4y3Bf8/oD3NmjXXkl0cfsPNj5tjg==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQlQ1GUYxnchhdkhRUNMrA1kOKRIE7CxYl8bLRiKTDGGnMUaCSrjzEYQ
YcaJKznEFoYAmR1GiAiZlau4Ft7lEOKU3ZX7hg2SzQkFCUWh/Q5n+mZ2dnb+
377/932+5/l9NmfCTgQaCQSCQMOHfLM1hW028bKOugsoTW9+6CidRM3pazOp
/SlYI07QH6+ZwMx6n9WXsrLQQuExHW0xgeYyiXWUVz5GuIsGC8LHsT1k3US7
uQh7uskaQ5/6jssemaW4lxYcw9uWoRk64wok1cQJo3joM/1c+Nu/o6GYoeII
rim63GrX6lBCyrmPoNLX2W3EQYW5OWQN49HRK0NWNi244kgKDqF0dkk5EdqG
J2iDQ5gWGrXL1rITaXuKQTTzd6pL3N2LtJxoEO1M7POz3lVjEF0DqMuWdX5c
rEUybXpzPx5LCtghPTKAdFxxP96+tH205oVhvEgHvoNu59tT/9k1hqycFr+e
k8mNfSfRhS4tWq7M6yoDpvEqLajBisciYfTBWfybjKtXY4z8x9rQPX+iJx1Y
jQrlxbN+9vNYSMoV9GFyyNUbvxy+i+w8+rB7qNQpMkzP9e9FoUiyllp2D+n2
8B5U/rW5XCFYRCqHYze+H+uflrTvPs5QPTtx77hjwuGAB1y/DkzPO1fomLvE
9foDX52Ul3+rWeb6tGOqU//AIdEK1+MWnhfHNyTCv0jLRbdiL4wZfRK+igfo
vC3osa5ZyM59xOdrwjefSzv4nvIxn0eFUu+zxse1a7z/Rjw1b5XTMP6E96vE
nZNbt+YNP8Vs2l8timJtq7bfWkdT2k81zjp/YH9GvoEx9P1VGOit2PTwDYGK
va8cXdW5Ny2TBSpWX4Gl10876AcEKlbvV3z5HdOesZ1CVRT9fyGqSo41BH8o
VJXR/XJcbV3Z5PqdUHWJPs9E7+m4a7orz37H44Ks3dwrT6h6lpB9mS30N38O
JjOR/9ufCRv1M7SeitWH1y670Pex54XQdW+2m/STz/qD+1sO0H7ZfgWoRgPp
PItsPpAMhtN5Wf9VsH+j0Y7owfUBz86ESqIX1w+Cv/p8C9GT6wtvRXyaTfTm
+sOT61lG5Dz4+cDooyI3cl78/CDk3Mhdcp6u7Hxhh41aSM6b6d8K8GWQkvih
lfkDvOYK+4lfzJh/4JSTtIz46STzF3z0s7iA+C2P+Q9iZpviiB+nmD/hgUaX
QvzK/QuaxZibxM/c32AdZLpK/M79D72Jvg4kDzwf8H26VTHJC88PVKTNB5E8
8XzB/rCp30jeeP5A5ix5esGQR55PkK8Jpkle2bxaWEjJyCJ5HmL5hpLqnHiS
dzb/HUj+olZDeGDN+ACe22bMCC84P2C5Rd9EeML5ArpG6U+EN5w/UJDhV0x4
xPkEC3PBJoRXnF+wbbyyhPCM8w3cTr7SRnjH+QfPb87YQ3jI+QhTPl7mhJcs
7yOQk2zXRHiayPgKP4R8E0J468T4Cy9q/dwJj3sZn2FJ/Xq9xsBrpvc4uKzt
1kYaeM75Dn1dsf6E95z/4C9evpFiuA/4/QBFFnG27Yb7gt8f0B3RnFQdd0Ty
H8atYF0=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxFlQtQlFUUx1kVWBbQSQgZUIoiRCsTJCwQjqaTNkiDgJBmozQDgkw8plgN
aaDhlSGwo8vbQJRRSNsweabj+cBVFtoFNsAl4hnyUhhRQZDXtPfRdGd2dna+
u+c753///9+1/zLKL2SFgYFBiP5DvtkawNyJjLqjJsl4JKthxulIPzpNWe5p
u5aNtXYpjw/U9mGQh5PFuLwELRV7B+Ms+zD7pMHq4M/LMcZTorsc3Yu5LlKj
xDdvoEZNVg86Vm6XSz2qcRMt2IO/+ib5NBjeRlLNLuVv3H21Kuz7T+pRX0xf
sRufPfOdN51Xohcp59mNojs/20+vb8KCfLL+QofQ9zRZv2vwhRMp2IV3r23J
//YrLfrRBruwbClU/vCjDqTtKXSYFbl43DJYh7ScRIf7znXmuf7RjaF0PcDT
2l3dL5P6kEyb1dCJ1kUPzt/7eBDpuHad+M74byVV3wzhaTpwB9oGTJ53Vg8j
K9eOZzbcX3bzGcNtdLWj2t5G7j/7CGW04J949aks/qemSZwg4z7Woryk9VJg
8BTuowNr0Wq/onX/1FMsJeUut6GtV2tGnOw5svNow84qa8nxnTNc/xZs2Ho0
7LPlF0i3R2swV/X+wkHVHFI5nNSoajErevvCPP5D9WxGP7PIjZEnF7l+TVgZ
oRpMDFrmeqmwq2n7S816A4Hp04gJRqAKNxcJTI976JyybXrNokig5eKUuFx7
s8FldIXgQue9iyPqYVPQrBTYfPVYXWBTc/H6KoHNI+CCNHBHY5KhwPq/gyee
bFi3+YCRwPq9jUm20dY+FsZCHu2vDjdt6U5TqowFMe2nBlXxI4YfRouFePr+
ShS1KRwixCb8fTewLHDsFzeZCa+vwEapiyzbSMLrleOetLKoSyckwin6/1LU
zOboCm5JhAq6vwi7PrhuNjgnERLpczn6xK1MXLI35b+TUeu+MFTsZir8lxBr
ixn6mz8H7+WphP/3y2Hr4QxaT2D1waY4gr6PPS+FUXk07eci6w9Eysks0i/b
r4Dp6hw6zxSbD66s9aXzsv4r4VxkHNWD6wPehceoXlw/SNSOrSN6cn3BDH+w
Inpz/cHV7aYHOQ9+PhDjGF5NzoufH1RLHOl5urLzhYK84Xpy3kx/JdwSBT0n
flAyf8CZjQGNxC9mzD/wbqnXHPFTAPMXjOjq+onfLjD/QZNs91vEjwPMn9A3
er+Q+JX7FzLNO+eIn7m/IdPvYQjxO/c/xH6XbEzywPMByT++kU7ywvMDzWse
qUmeeL5goX+6mOSN5w9qUiukJI88n/Cq+JVMklc2bzsYFuXMkTx3sXxDfX1+
Bsk7m78DrAo9CwkPXmd8gKHxXRmEF5wfUO7epyY84XyBYf8d6YQ3nD8w8cT5
MOER5xOYJ0SlEl5xfoHDztXphGecb9AWW1pBeMf5B2fFvasIDzkfIf/Q3l7C
S5b3bhiQS70JT1MZXyHstStrCW83M/7CUoTRIcLjFsZnkPXMNyfoec307oWy
6bScY3qec77DbLhX4Zie95z/YBkT79+qvw/4/QABX4t1X+jvC35/wKmU2IPl
7p96/Qse/1Kw
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJxNlQlQ1GUYxhexIAQGdglkahbDRo4OyoCxQN9MjgixIJahwA6Ho0KKoyEH
IdFEzImwQIRAQI4ajllOg2WI90OWkDMEkUOBFQlJmAg5DNqc9juc6ZvZ2dn5
f/v+3/f5nuf3PXXos4DwTRKJJFz3od98aRDfiM8LMkzH0IzLq/ahU9jjbxv/
a1ghNslT5/2bJnH66MvtxQnlaKH0vpVoMYknrR8/czakDmN3G42UxEzgH/EX
4j1+a8K+XrpuYmZmcWCEJUEHVvAmRu1YSK31VCOtJk+9gf3PpLjE6HWhrpiu
4jg2uu+taFb04x5abvc43qo63qOwG8Qfcukaw0jfnuNbk4ZxzZ4WHMWFOyrt
/PNjGMAaHEWf8Dc7fTwnkLWnHEFpsJ/BtmkNsnJGI6jeteuuffBtjGDrOn44
d8m+8tFZpNNmXB5Gtyc6rZ9dnEM2rnwY3/1e0tIsXcCjbOBraBIZqdDELiIv
N4THspOtfE4t4UtsDeGPdxWfSGOX8SwrOIhbpamFRUdWcYGOO38Vg5a/tP0z
7z6+zga+ioEJFwNzxtaxlJYrGcAr1d2bJ520yM9jADW3g+MK8x8I/fvxUpvP
WvW3EsK2x/RhxcG0M6UjeoTJYd+LkBmiOW+nT6aZnt3493Vb576kzYTr14X/
fOeYFjb8COF6XUG9sQG3950MCNenE3OK2jzKThsSrkcHWgTf6TOaeoywcolq
dPnlyX1BL2whO9m87Xhg+47zXonGhM/Xhpb6G1W5zSaEz0OweP9sh3TRlPD+
W1H+ue9hYmQm+m3Bw3FlIdPnzEgO60+F9hVuX8xbmRND1k8jRhVC6WyGOUli
72/A6YKPlhe15uJ9tfjcmus91/ekor4Sm8dqWiT1UlGvHGumVnrLN6TkCPt/
KXaoAtN+cpaRGra/ALdnN5z4+gMZSWHPs1BWdzF9I/nh75Nomrga0/aNjDxM
iLfFEvstnoNLctb/9mdBdVoBq0d4fSgmLux9/HkptM70sn6KeH9QRI6xfvl+
JfgXaJfoPH/x+SB95mk2L++/AQwO3iuhegh9IE81k0D1EvpBstKD6Sn0hQmV
JorqLfSH+Sqtmp6HOB9I19dW0vMS5weNebJsep7O/HxhMnN1Lz1vrr8a6r+q
7KV+UHN/QJdD7D7qF2PuH/j4RtQr1E+B3F+w7l6bSv2Wz/0H2uhzO6kfNdyf
UBHdPEn9KvwLitnB09TPwt9gmXBihfpd+B+G28o+pXkQ+YALr65IaF5EfuBF
i/K3aJ5EvsDQPEJO8ybyB2uufnk0jyKf4KWURNC88nmHIDTfWEbzPMrzDd5+
/vtp3vn816ClWlVHebCN8wHudweYUV4IfkBhkpUN5YngCzQux2kobwR/gISH
/Wuj45HgEyx6uddTXgl+gW9M1BzlmeAbrEu9oynvBP/gwIPenykPBR8haiYl
hfKS530cJmzitlCenuJ8BeNNuSGUt46cv1DiKXWkPO7nfIZ3TM3llNdc7wno
sXN0pjwXfIf2xFZLynvBf3B6zcS6Q3cfiPsBHA4F//627r4Q9wdkm1iNurYq
9vwH4RNMOQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtQlFUUx5FHCSIFLrlrtQOatKAUSFmRcEwkDXUa0ICNDSKGdJiawClk
kFEqAddEDCgwkgoWRZJXGlBi5xN2BVdYwOWxvAkKkAVnoxAhH+19ONOd2dnZ
+e6e75z//f9/1/W9j0JiLS0sLGLNH/LN1giuz5jcUBaUg4qshjmZYhgjj/ae
L+lTYZ00zRhcN4T2bbrotskqFFVs+z1ZNIT6YJem4qg6TPCz6ymOH0Svs7eK
biUK2NpC1gC+e+nCSHy4Bt1pwQF8OTFTmj+mRVJNmtaPR072Z1rntqO5mLli
HybeDtzbtqoT/Uk5vz5sN0QPShwM+M0psnrRo7ljvvqTAbwtIwUN+NnYVofs
8yMYQhs04P3VoZ3aqDGk7VX0oI3cV6kLG0dazq4H729clB7Pu4nv09WNPzWe
Hk91nUEybVZDF4YfmMnpOGhCOq60C9dNlGafyZzFg3TgTvzxTydl7tV/kJXT
o99jxs1ZbvPoQ5cebyymzbiUL+BJWvAGegaUy2Lkd3GajGvswMrrW+IX3B/g
djpwB9bmJZWnOywRVKRccTtu35Qe7pZvKbDzaEfTS4Oaj72sBaa/Dk+sn92m
67IR6Pb4VpwOijmzJ/1Rgcoha8GE/YaIWbAVRqmeWjyqcDVEWiwTmH7XcHn3
2z+v0dgLTK9mVNp/3Vz0hYPA9GnClKnDSSdkjwtMDw2GO9o2KGwdBVouWY2i
c8slTeOOwgY6byNaaTYV7kYngc13BWuS1xkzvlzB5xEwLODS1pkIEe//N4xI
e/Oy6Gln3m89vrbMdWOB3lnIp/39gpcD//byPPSEsJT2U4tT3VWxx55cKaTQ
91/ESfmwo7JsJX9fNTbueGNR7CHm9SvQR50pef2UmNc7h5Ul8ju+82Ihif5f
hdV7W8q3BEiEKrq/EIMOj2ZoUyRCKn2ei/E+pYqY4oe/j2DRdEJaQ41EeJgQ
tc8H9Dd/DiLrvP/tz4WQ6xpaT2D14Smxir6PPVdBVMFa2s/3rD9YNOyi/bL9
FVC2+94CmcfE5oPKZzLovKz/i1DrvZPqwfWBgbufUr24fmAzXfQi0ZPrC3NR
6nqiN9cfqqZX0/Pg5wPP6tKmyHnx84N/S5SnyXm+wM4XjljvEpPzZvqrYXbI
9wrxg5r5A2o9VQeIX+yZf8C/sPEq8dMe5i9YWv7hBeK3b5n/YGerpJv4cYT5
E24aa+TEr9y/oH1LpiJ+5v4Gv7jCQOJ37n94JDqhkeSB5wO+k1qFkrzw/IC3
aLiM5InnC+r7/4gjeeP5A/0+tzUkjzyfUBBkmCB5ZfPqwapC/CrJs4HlG4Yt
pZ+TvLP5OwFqc44THrgwPkDsc79mEl5wfsDmdx70Ep5wvsBXgTInwhvOH1hh
90oK4RHnEyhT3ZsIrzi/4F6ryYLwjPMNflg1OkB4x/kHPme9GwgPOR9hbWf/
DsJLlvc+sCry2094ms74CoH75sbzzLz1YPyFniXaUsJjHeMzmCbq4wivmd6D
8FekfyjhOec7OMgPmXRm3nP+w2Jw0jWV+T7g9wPcse6NKzXfF/z+AOcw/fPG
bIX/f/5tSpY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQ1M1GUcx/FgQrymvB8vyTAhMCtQNmnwK1BhXi0ltJkkLwM0yXVaIW8T
KHCBI8SOGQiN6QnpChFvAQn8HuAQjrd4lQNBUAQKxMFQYCHWPS9uPdvtdvs/
9/v/ft/n+/08LlFfhsRI9PT0YnQf+s3XOE7NT6RGv3YRw3Ibn7mHjeEJadil
2tVfsNo5c3Z/9X2Mta2aOgYqtCoPepBkdR9zo1R+zZ51eNLPePCKfBTfkYaP
6Vc2YWcHXSPY2hVt/nmmBt9gBUfQ8k3l2LoN3UirOWfew37PV+sdOvtQV0xX
cRiPBLhJ9utp0Z+W8xvGyJS6kLlbI1hYQNcQzjhKA7NXxnHJnRbU4iNFhNmH
4xMYwhrUYtZqbdFx62lk7ZUPoseOnYvVl2aQlTMexE3xwZYl8U8wlq276Pr9
UHpa6ALSaXMbB7Bg2T3mh8JFZOM6D2D+muGKn/kSJrOB+7E0rlkxe2MFebk+
bEi2eJiWuorebPXh33Uh78alvMDzrGAvHnrW367p1SOP6bizPRhmudPh1xQJ
CWYD96B9qau72teAKGm5K934VPqW3k2T9YSfRzfOawr3aOYMCde/C7U2xxWO
Y68Qtl3eiSVFMXbxoyaEyeHegXk+LacipszIQ6ZnG74fZEQ8li0I10+Di4lu
4afXbyBcr1bce7BvRbZxI+H6tOD1+Ljeb5wsCdejGZ8bNP8ZvMWKsHJJavxC
GX7L3NOaeLF5m/BjteeciYeNmK8Bp2b+SctwsRXzEDxq6/WEWNiJ/uuxwCRL
33LRTvRbi2rVqXPDGnvyE+uvBnPzpSTrgpQYsX6qMOhydsI1mQNJYe9XYYsq
Sn900UG87yZGSqNLJ7McRf1yHD/UWnvV1EnUu4ZuX92RuyY7kQT2fyWW9VWY
n+t3IhVs/88476NceNvOmaSx5wqUzLQZ/7j75e8MnIQGg0/DnMnLhORf/oP9
Fs8hwLTqf/sVcNbwO1aP8PqQ6PMtex9/roStAdmsnxLeHxyIPcP65fvL4fA2
UzbPPJ8PlhTPJXRe3r8KFixsmB5CH1Dtu4hUL6EfyM6MZ1M9hb6QVzYtoXoL
/cH7o/Q5eh7ifOBgri87L3F+oLhx+DE9z+38fKH5dmolPW+uvxpCfQe6qB/U
3B9ANHE91C+m3D9wdaBpmfoplPsL0gKNjlC/FXH/gWHb9Trqx3HuTyh3lcmp
X4V/IT2n3Zr6Wfgb5I2VedTvwv+wTr8lkOZB5AO0nbBWocuLyA943rV/neZJ
5AvMtdZ2NG8if2B2uqCV5lHkE6LLfttO88rn7YPJdv97NM9anm/oqmjPoXnn
8/fDrs7pecqDTZwPsPmvR59RXgh+QI3H10mUJ4IvIN/6ngHljeAPJO5dmaA8
EnwC9Y7gHMorwS+4kF279oGOZ4Jv8GKbzJvyTvAPZFt6vSgPBR+hIWDpwT4d
L3neh2FPb0kx5elZzlc4sHutnvLWg/MXEk6qOo7peNzF+Qz//v5JMeU113sU
1opNa9Q6ngu+Q5w8K5LyXvAfnmbYnr+tuw/E/QAnnO8cjdLdF+L+AJfNmp6h
9gj//wDGy0BI
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJxNVQlMVFcUZXFktRpBLduAUlogphWUpVa4ksiiJSjE1GCIhhHFJVqoscLY
OshSjVGwLAmUFkmEIEWnkCIwLXpfAZVtWGQbkGWgVNExIlsbKGjnLSR9yc/k
5785795zzzlvo+zLiKNGBgYGR/UP/eVLiw1DKucCkzyMyqibc40aQeXmi5oa
SRnWSNN04TXDuOUn1eDY6D20VgaPyq3171GNngZJiPF+5n234obQNFA1L9n5
ENWtdA2imcMVK9+UFnRjgIO4JifmrVdYJ1I0adpT9MpTvP1qbw/qwfSIA7jX
PGbyvfZ+9KdwfgO44KDec793GH/Io6sfX+TEhBj6juHfrhRQgyXV6wZWRPyF
EaxADU4tFhr9fn8CWXnKPhy+luJso3iFDM68D11mM+LaQ9/gMbZ6Me3i91bS
K9NIu82o68Hjyaq8/OlZZO1Ke1CiMS40u/4PXmANd2NXq8y79sACcrgu1JXt
fpwesYRb2erC22fnNp72NyA3GOATlIe/i696aUhe0XZ1neip02kD7hqTENZw
J2bNRO/+M1VCiijcrQ5csepjzaY4E8Ln0YHuvVOhfqfNCOe/De8W1ya7yC0I
2x6nRtLtuuty9irC6HBtRQ8zw2MtqtVkjPHZjIc+jbuePrOGcP6asPQXE68a
y7WE89WIo25behs+tCKcn8e4Nr1szminNeF8PETHyt7Fii/WEQYnb0CP9YGW
JifWE0/Wbz1eWwpd8ji3QfT3B7q90Mhlie+LfggW7I+yVZ+1EfU/wIMBqw+X
y2xFvbXYfvBCVuQuO5LL6lOhXa461m2DPTFl9VSjV4BTUG6/PfmGnV+JO7Zp
922/6iDOq8DOy9FG9R9JBb4SX1ZdijWtkAq8Usxr+XVK4uJIEtj/i3By88Tw
cLIjKWf7C1CTE+mjbXIkSex7NtrJI2XJ88vvqVgq07rdM3Uiyw55YDLE3sV3
cIwI/N/+bEia8GF4hOPD6EANO49/L4J9P3/N6ink9YFZpjerl+9XwqNNpqyf
N7w/cA1NYP3y+ivBPKM0kPIh+IHRJ8GML8EfGG5/lkn5FPxCmOLkIcq34B8G
ykts6DzEfOCOuzWbl5gfPJ89v0jnuY3PF87cPGxB5835b4BTNdp/qR4auD7A
XlI8S/ViyfUDz21teqie9nN9gZendivV249cf3DnnO81qkct1ycExcYfoXoV
+oXPyhIDqJ6FviG05LWC6l3oH+q6JHuoH4Q/IGzmgx7qF+EfSGncEUT9JPwF
881lQ9Rvwn8QfKr4DPWj8Cd4rEyRUr/yfrtg5IA3oX7WcH/DTLHzJ9TvvP9u
SEzPz6V54MTzARKb3DNpXoj8AO+VIxY0T0S+QMiR2uM0b0T+QN7Jm1Y0j0Q+
gfV46vRv+rwS+QXhKY+aaJ6JfAOF7pkPzTuRfxBa8a0bzUORj2D3tFFN85L7
fQCmzhcO0jz9jucr1DeFDNK8def5Cx3K8TYffR638XwG7xNVlTSvOd9DUH/J
9vY7BS7nO7z+PCGc5r3If8gyXiDV+vtA3A8w2Tw1na+/L8T9AfmZV8ejMqP9
/wPY5TwM
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQtM21UUxkEzx1MQcBMYLZiFxxjyUBJgwiERMhhmOARFBtLI2HSjyoJT
YAMaXI1TxiNDBVzUSd0gaEXDcwLn8hzIQ7B0LTAYMHFsIKnLGAj46H2YeJOm
af6353/Od7/vd91eeysu/SETE5N044d+8zWL1s8eDgw4VonJJV2rnsk3sVNX
NbCYVoctEuXSoZYZfLfwCrS6N6GDev9crsMMboVX+4ToEU+GWuiqM6dRcXBF
6fZ2Lw4P0XUDfRTzpo+0D6IXK3gD/X91tcrNGENaTaKcwmjnupYguRaNxYwV
JzF36PkJu7sTGEbLhU6it3vUYszyDFZV0jWBFe61o9lh8/jAkxbUY95521Ov
xC1gHGtQj1/NvN430biIrD21DgO7TjepM5aRlbPQoXLZ1tQq1IBH2bqOERuB
vWmZ95BOW9KlxTLv9aNHxu4jG1eixdTLsnMNsjU8zQYex7mDhRmlkg3k5TQ4
GPRZBVr8hU+zpcEcE/2tSDsTUsoK/oK+tcfrkhtNyTIdd2kMU7q8Oon8YRLF
Bh7D0uJLL+4P2UZUtFz1KBZk+aXkOW4n/DxGcZ8i17LG3Jxw/UdQIduR0mdm
Sdj2zGH8LWJq7YKDNWFyeA5hYv5TAef32JB5pudPeMtpynWj2pZw/QbQxVLa
vtTwGOF69WN0a2J4UZ8d4fpcw6hFa88QnT3hevTiVqHhfuSCA2HlcnvQI7Gg
+8HK4ySAzduNx/VP2pTc2yHm60SDWfG5Qys7xTwER7NaDcrZJ0T/HdjRY/Zz
3jVH0W8b/v3jpl3lJSdSwfprRe1l2zcPyJ2JGeunGW/+4CB39tpFzrD3N2DA
gemwes0u8b7vMXVwt9vgCRdRX40Wkhl5rMFF1KtF+wBVZIRMQrLZ/1UoLZjQ
Xr8qIfVs/+e4+ztlSPI/EqJgz8tRt7i5FecjFb/PYuO0xu9IhJT8l5CSvmH2
WzyHDy/e+d/+cnjZ8RirR3h9KMtXs/fx5yoorsxg/XzJ+4OmxkrWL9+vhpQ4
jSudx8Dng7PZ+Wxe3n8DKPbVZFA9hD6wGfyJnOol9IN3zLOYnkJfiM8/OUL1
FvrDt7H27DzE+cB8t/4Del7i/MAq6NVH6Xk+w88XxvfWddHz5vr3QFGtFfND
D/cHnIlx8qB+seL+gfW4BKB+iuf+gu0Llm3Ubxe5/8A/tkVK/TjL/Qnwx4Av
9avwL+QHJa5SPwt/g/eJU0nU78L/MPdSmxnNg8gHlN9OSKJ5EfkB1Ud1L9A8
iXzB4RjHDpo3kT+I0IbX0DyKfMLI2sezNK98Xg1ked0po3nW83xDZKcqnead
zz8OtR5JhZQHrpwPoI4dTKW8EPwAZcJCO+WJ4AvUW3/xp6WRN4I/sP5p0hXK
I8EnUPvaNFNeCX5BmuN76ZRngm8Qn7dMKO8E/0AqyemnPBR8hJ2xfq2Ulzzv
kyD9PaqC8vR9zlcoilYs5Rh5u4fzFyxW/ck2I49HOJ/B5+7kc5TXXO9peKN5
uCbYyHPBd+jfG3S1xch7wX8I/lrdftt4H4j7AWRF3zj7Ge8LcX/AZFVUbfCk
LOxfhDw/sw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxNlQ1M1GUcx5GRGALxchwBHi/linclKGyoP6ECJjaCkmVYJAKbggFjSwYp
uEDURMC5IVC8DEJEuw6kxIL7PSKICThevTs4QHlJ2rE0wCsTpXte2Hq22+32
f+73//2+z/f7edziU6MTjY2MjBINH/rN1z3ctdzs+3FXGe4t6njsvncSn7Z6
VTW3XcJW53xdVOsElu57VWqc8DNK5GH3syQTODdWNXHYimD6NjNVbdo4/hQ/
tbGivAv7eunS4gdmvWct7/egByuoRZXWrDQjawBpNef8Max8U5nTnjGChmKG
iqPYuGidJpnV4HZabtsohoJdlLlqAsvL6NLgfu0Fk2fuU6h3pwXVuBLtl/i7
7yxGswbVuKhMj1nInUPWnlyFpZEVlRmvzCMrZ6ZCZzudfOP6R5jE1l1svVkT
lLBpAem0RR0jGKl2qRo8uoRsXOcRdDBx0f/5RI/ZbOBh9MwrDRiqfoK83BB+
5/jvP54Zy+jP1hCq7vaf9UpbwWJWcBAVmnZlaMQaMk/H1Q3gF3/MdL6zYEzC
2cADqFTmLc1eMiF1tFxtP5Y8Naq58eVaws+jH2WbA/Wbo9YRrv8dlGT6NQW/
bUbY9rQ+vBl4dKnH25wwOdx7MWfxsl+KhyWZYnrexnf7fSzek1oRrt9vWKoL
DfnRwZpwvW6hi/Vz2yMyG8L16caS6PRTr7naEq5HF+aE7P/c3lVCWLmsTsze
kxx8xcmOvMHmvYGp36z1/sRaKua7jtPzx6dTVqRiHoLLLRmfRc3Yi/6VSDQS
l8PKl0W/bRgwXpwYe9qBnGf9XcOdfbY+hbscyTrWz1VUufU8UDxzJF+x97dg
QvffD7+udBLva8LQ7tv1kz4bRH05jnpbbW1r3CDqXcSA9mtO/hIZyWT/r0NN
sZXRsQMyomD7K1E3VNNg2igjuez5OUzKUb8VObL6O8/gs+/9THUyspoQ58dV
7Ld4DiXaW//bfw7iLheweoTXB9PrupXcA6vP66BGcor1U837g4OpI0G0X75f
DgPyPDbPIz4fnHqhns3L+28B+/hDTA+hD2y5etGb6iX0g36pI9NT6AuDL5Y4
U72F/pCdP/UpPQ9xPhBkMTdFz0ucH1xp3uNFzzOAny8cDFfsoOfN9e+E97vK
4qgfOrk/ID2k7CT1izn3DxTutmd++oj7C3ZmRwVTv33L/QejTR7m1I/3uD/B
7UTBJupX4V+wnQ9aoH4W/obAXwbl1O/C/yArbFukeRD5gB9kyZU0LyI/EJs8
/BfNk8gXVD137KB5E/mDlIixX2keRT7B8pj2NM0rn3cIqlrVCzTPap5vGImN
8KV55/MPw4lDjQ8pD1w5HyAhMP885YXgB2jypgMoTwRfIKxifQPljeAPSJsr
iymPBJ9A/frWcMorwS9o+LA7hvJM8A0KJi30ywbeCf5BXNdJf8pDwUeQvRQY
TXnJ8z4KHmcq9lGeHud8hbD6C5mUt56cvyDXl+ymPL7D+QxJ3sEPyg285nqP
Q6JNbTXlueA72MwUlK0x8F7wH/oUqromw30g7gc4ssN+S4zhvhD3B+QUmSuW
8+K2/wf2Pj7O
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxNlQtQlFUUxwlTYSEs4mHArg+iWAbDQTQi4ARNASpToNKk5pS0sUUKUjZA
TQkCY4PCJhALvnBYEEh5JSzMgOdjWcAH72WBeIng8E6JksQS2/twpjuzs7Pz
3T3fOf/7///uhoNRoTJjIyMjmeFDvtkaxZM/BqY75Z/B/emaB877byN8LErJ
LLuCNZLk2ZCaEezYp098Mq1Gq9KAO/FWIyj9PmbNH5IGPOIj6suPHkaLZBd9
9lIztrWSNYQVlaHvhma1oZQWHMKwu5/c+TyhG0k1SfIgZg2/8XNccS8aihkq
DuC8pmXJc8cg+pJyPgNoVLjLPOr1UczNIes3bHrHPcfZYhwXnUnBfuwqPy4/
vmkCQ2mD/Sht9uucVU4jba+0D+WSt/dE7vodaTlRH75l/cuVG2Xz+Bldvbgv
tH/619sLSKZN1+jxz7EuNyevB0jHlehxndzH/Sv8G7+lA/eg992EwPSoR8jK
6VA2ecplOegxbqFLh4EOg0emXjESFLRgN7aMBJ/pqHtGmCPjznZh5Ksz3Q2y
FUIgHbgLz7bFFp5cv1JQkXL5nTj6XI++fnaVwM6jE6tyrnurmkwEpn87RpeF
NYdcFgl0e3Qb+lrPRJw/Zy5QOZxbUZGgcHDNthDGqJ43Mc1zemrrjucFpt8N
/GBsThmy8wWB6XUde3MuKOOCLQWmTwve27j5olvwiwLTowkfLoalzARZCbRc
vBbDA8z87fytBXc6byMGtN8Uu3rY8PkacLuHyWSaxJbPI+Br0YsO6ie2vP9r
eLRyzWrH3rW83zps2v1ewYG8lwQl7a8WbzWuPLT6IzvBhPajxtTCPS0dInvh
O/r+qzj3V0lgYpE9f18FKi6rc5/d6sDrl+KJPqXV3jIHXq8Ya5cvLBfYiIVY
+n8VltZrj236QiyU0/3nMTVp5s0Pi8XCMfo8E/0uTadV657+TkJpRMmJh1Ni
4WlCbO8V0N/8OfRvGfrf/kyIWNbRegKrD7f+VdH3secqiGz9hvaTx/qD5vsy
2i/bXwo/YTydZ57NB2bF4XRe1v9VkOeuoHpwfSBDUfQl0YvrB3mKCRXRk+sL
jxdyVxG9uf6wsPMoPQ9+PuAZFD9BzoufHxhfc6Pn6cHOF76uP+hHzpvprwVN
cV4y8YOW+QOi9JF5xC/mzD+wTtyWTfy0m/kLqm3Mqd/OMv/BIYtHk8SPo8yf
EBOTZUf8yv0L0qhuGfEz9zeMqTdqid+5/8FUHetF8sDzAUtNch3JC88POGoX
8kmeeL7gtP32TpI3nj+oLMpUkjzyfMLmEtMoklc2rw6Up+peJnnuZ/mGmm1J
/iTvbP4eKL9o7Up4sJ7xAareT5QSXnB+gFdw+DjhCecLNP5jeYnwhvMHPH7o
CiA84nwCTWSGhvCK8wuGt53bS3jG+QYV0rWphHecfxAGouXDBh5yPkJt9cgQ
4SXL+wB8mmwcR3iawvgK8pbxRsJbF8ZfOGzXJyI8bmd8Bu927xzCa6b3MIQv
SXTzBp5zvkNYbJwp4T3nPxRVWZ7OMNwH/H4Ary6nAkfDfcHvD9iweD/crOGA
739G8EhQ
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlXtMk1cYxgni1A4vGxiXFJkQMtvVoFjYLF5eFhm4ZUNgCDMgOkzBgQ13
5oAsylqS6Zwa67yG6WxkS5aKCRNnTB/UsonjXpCLijB1gCgjKm6Lm5HvnPf7
w5M0TfOdvt/7Pud5ficoIzfR7O3l5WWe/Cjfcg2gSpcV43fruittz6UJXdot
hLbmbFhVPeY6F2gbTTjXj5EHVa9PXfuvy98ZO1jq349Zmz+8bf7WG/krNd0n
825i6OnLcQ1HZ6C5SVk3EJCmbf18fA70ouANWD6rqK1pnAulWqDtOiqMpuz4
Ai0mi01W7MPpx1aH3TsIq5RyK/tQV/LGS1+0huDIYWX1wi9gqEW/WI8nOqVg
D354v6T/VFgoEkWDPcgzuN/ufBQG0Z6zG6GulHJDWAREOU03kifs7+zqXYZM
sa6hOvOb+ScmVkCZds+lLmQ+bU34+9coiHEDu7Bx35SP4tatRpkYuBN3Ck91
O/QxkOU8iB0/H5Id+x6MYnlwsOz4X3vPfIC9omAHlvznbFkWEY/7yrij7XhX
a3vSZUrEGjFwO/wDMz7xyUqCQyl3sg0aT2Ku80Iy5Hm0wW/Bp863ItdD6t+C
edOnFeX0p0Jsz2vG3IT/Y8qr0yHk0DXhn2D7lW2Nm/CH0PMqvjLMs3niMli/
RvhGtZ24M7iZ9bqCB7OKPs7ZbmZ9fsOhV743dSzMYj0aMM34cLexawtEuVI3
0o+YXBtt2Vgq5r2MUe1g/d3wrTzfReRbe0vnD1h4nnoEW0YfGr/M5f5dcEcu
2R+wO4/7vYCUiOLvDsbn45Do7xdE6+5ZZmoKMF30UwfL6dWanXUFKBfvr0VU
deawIaWQ33cG0T6mykVDhVzfidSYRU3D5iKu9yMazu6YGG4vwjbxfwfWvub7
+5C+GDVifxWCj9Y/69lajO3iuR0FJT+VjR1Wf1sx/OfP1mM1xVATov7m5/Ti
fjup9eplfVLfJ587SO3nuOyP1H7lfiep84zL+UidV/ZfS6oerA+perF+lMx6
sr50mfVm/SmIz4PPh3L5vPj8aITPM1yeL6XxeUv93TSV/eCW/iA7+8VX+ofu
sZ+SpL9oBvvtmPQfVbIfB6Q/6TH7lf1Lc9jP7G96lf3O/qeZnAfOB/lwXjg/
NJvzxPki4rxx/sjAeeR80i7Oq5zXQ5Gc5x6Zb+rlvMv5OymJebBA8oE2MC+Y
H3SAecJ8oWjmDfOHAphHzCdKZ14xv8jKPGO+0ZhW8o75R/uZh8xH2sm8lHnv
o+XM00rJV1rIvH1T8peupUoet0g+UzrzWup9kyoyJM+Z7+S5L3nP/CfvZnkf
8P1A0SHyvuD7g9ad/bpzJCtsxXOsPDda
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcxxmOHxljbkJtrjEczg5cmoT9WMmnRiNJccJy00ZkuEOw5Mcs
8ggcMygg11GBCTJR7o7A6vK2a0Ix3nDgTAImHL9ThJTKwZIQcIa6uOd580fP
drvdvs99vp/P+3m/X8/alMxEo7eXl5dx6eP51mscH3zRtjntqQAkmV3zhqTr
OFjTkNv8IASNIUVTCY1j8L28s7npRDiC7K9N5AaNwd8/rGjbr5HI3rpyyJJ1
DfuqJlNmb76A7i7Puoqj/Y+ef3ztKwhXBa+iuycsuMA/Fp5qIUW/oXb8XnVn
23YsFVuqOIpyh2kmMCoB0Z5yW0fR8sTAxPaA3aiq9KwR2Gf8Dq027cWCwVNw
GP7BmS82lCYjUTU4jJg6v+lFQwpUe/YhPHhrR8HTWUaociuHsDh429IWlo5U
tQbhvD9nzN1xCJ5pza4BvB0R3553Lwtq3JABzPV6r3aZD+MjNXA/Powt7rr1
Xg50OTeyEufzM8tNeEYtN9JHv6/f9Ug+ylTBPmycio+/m1qAac+4U71o72sZ
upt9DNvUwL34bNeqvavqCmH1lLNcQdB3gxUbVnwKfR5XcOLVitZzxSXUvwc5
UVOTe7Ych9qe1Y37R42b9vmZoeQwdOGv1LqfQh+W4XelZye2pO2JO1D8JfW7
jLjNTbNfhZZTr1/QvcL32+SOCupzCabS50+GZ39NPS4i3CejwGddJVS53A44
p22xjSNViFTztiPh3IXDFz+v5nxt2Hh7pOmInOY8rYh1BCbM/lnD/ltQfyM1
f43rDPttRrJr8cc1xWdxUvXXBHep74H5mFr4q34uwPJH9MMf7tQiT73fibSB
kuMpFRa+z4EGn/6il5+0sr4dC+8PRp/9xsp6DRi54/WPX7ANR9T/rfj4HXPg
hgwbzqv9pxH3d5rzX4cNBep5ObwnWgLqri//LoQj8PW8mgUblhOy/JvP5f/7
y2W5XquuL8f4Pv3cKsPs54zuT+bYr95vl3rOM6Pnk1TOq/t3Si31oD7SR72o
nyRRT+orddSb+ksMz4PnIxE8L56f7OR5RunzFQfPW+vfIevphw7tD8mhXwK0
f6STfnpD+0ti6bdq7T+JpB/HtT/lJv1K/8oc/Ux/Swb9Tv+LmXlgPiSAeWF+
pJB5Yr7kZ+aN+ZP1zCPzKW8yr3pet6Qwz8M635LOvOv5+2WSPAjVfJBE8oL8
kCryhHyRCfKG/JEb5BH5JAbyivwSd5DmGfkmJvKO/JMS8pB8lGTyUud9VJ4j
Tz/RfJX95G2E5q88Rh73aD5LWaXmtdb7mjzrp3lOvsv+S5r35L+sq9b3Ae8H
uVWq7wveHzJ2ave7fZsOvvQf8NlTUQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJxVlXtMk1cYxgle4tiYLvrHdEmnE7EYjQOrmVN4VVBhMwRRcSpkGRuwDJlF
0WFRmUaM13gZl64zipYZq1kRhQGD8ZSKjkkRELAMoeqyeVmJV8Do4oXvnPf8
4UmapvlO3+99n/M8vzMucU1skq+Pj0/SwEf7lusG+tqjPvLO0CN+v7NPH38d
kwLyv0g+/jEqdDnexRUe6Dy3pkx/MR+j7AtvmkZ54H28cfCWiTFID/VzW43d
sJ+oq4qYF4dGl7a6sOpOz6yMdQkIEgW7EB0Xk7bsYSK0arqca/jn7bbfD3an
YKDYQMVOTLYknLuSl4YwrVxoJyxhF4MLRq+F5Udt/QXL/a73Au+sR79eK9iB
5Y+/SrVEmBArGuwAuZ617gzNhmjP7kbJ7f7ifuM2iHJ+bszOby7YVJiDZLGu
4oM+d5LXsAvatPud7TjWkrr77PR9EOPq2hEw5GnUs7YDyBIDt+G4f++TKYt+
gCzXim9m1r9YPygf08RqxVpr4KGU52YcEAWvoMH4KOWd2YfRo43rbUHcv73B
Nx1HESkGbsH4u+3miIvHUKSVszYj903fReuarJDn0YyJ7pDKjP9/Zv0v49se
ayZFnYTYbmyE0+ZaTeWnIOTQuxCbnpQZHf4L/hZ6XkJIbFRe8X/FrN+fKDDV
Lxm6rIT1qsfdq+/aq2rOsj5/YMW2BbYZH5ayHhcwYozJc/9EGUQ5Ux3ShzYt
eH9sOULEvOfx9al5+efNFTxfLco8PZ+e9v+N53Fg777sldlZVdx/DQxPKazJ
U839VmPq9fRInaEGZtFfJfy3+HU9/A4YJvopR2nW5kDjEgc2ifeXouyNzCHN
Hge/rwS/hs9M2BNfy/XtGDx39L1pDbVcz4bqvWMWbw1yIlP8vwifj3R/snyD
E2fE/iOISYlY1XDGie/F81zcPpL6ZVCH+r0drkv6OU+8TqiEqN/8nF7fn0uq
nkPWJ/U++byIVD+Fsj9S/cr9dlLzPJDzkZpX9l9KSg/Wh5RerB8pPVlfUnqz
/qTOg8+H1Hnx+ZE6T4M8X1LnLfWvI+WHOukPUn55S/qHlJ+WSn+Rmf12WPqP
DOzHG9KftJT9yv6lC+xn9jetYb+z/ymI88D5oDzOC+eHAjhPnC/6jPPG+aNG
ziPnkzI4r3LeVlrNee6Q+aYizrucv40CmQdjJR/oJPOC+UF65gnzhcKZN8wf
qmQeMZ8omnnF/KJk5hnzjWzMO+Yf2ZiHzEeKZF7KvHeS73DJ0x2Sr5TGvJ0k
+Us/MY8vSz7TA+a11LubJvdKnjPfqZB5z/ynqRPkfcD3A710y/uC7w86nRi8
MWOFsfoVU09c/Q==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1GUcx1HZInUY7dK1OoRaQNZaIrFE4DOjyPVHS1cRpX8kgTOkYEAh
1ipKRraF1MkEFUkuGDKvVFinCe8Djp9yCHfHgeiR6dQOWrOajaQ07nne3z96
ttvt9n3u8/183s/7/Xqit767KXthSEhI9vwn+K3XJSTdU/pgVGEKNld23Yzb
/BMOrgi9Vhf/EuyRu2c22qdgvjf0BavjdZhsz/9cappCkTltXaAxCwUpi8cb
8v244TpxuNWUC9dQcF3E7I+mZSPTBXhUFbyIhvBF8beXvo9gtcjdF1AUkXNz
/ZIPMV9svuIk3N8lBSIWlCE1WC5lEpdTm4dWhpWjtia4zsO8s8Mc3rIHf8UF
C06g6Td/0+ytSmxSDU5gx/m8h32hX0O1ZxtHlX174emiaqhyi8eRe9eWqPxX
a5Gjlg95xVKRdLIOwWkru8bQ/Xla64rBb6DGjRxDdG9NzaJPrNilBvbiUHZs
dFFZE3Q5D9JztzuXu49ijVoenNgR5jIV2rBXFXTj9mig9+81x/FrcNyZUQQy
r8+tzTyJDWrgUQwk7oo51dwGa7Bcwwg6MhZmZz1ihz6PEWyJHbrfcvY09R/G
TMza+rAD7VDb810YvPNkyfQGB5QccUN47sv41475OnFZ6TmIa+3V1dHF3dRv
AMlb019JfaiHevWjreVK26ELvdSnDy0FsW9+VNdPPXrg9Gc87to2CFWu1InG
xuXT0QlDiFfzdqO68b233HdcnK8TVaarebO95ziPA5Hezj/QNcL+OzA3kdFe
e2CU/Z7B24764plcN/ar/k4hvbA24avVHoSpfn7AFyudWTunPfhAvb8V536/
suCwxcv3HUfZ2af95ifGWN+GxH3PVCS2jbFeM1YvSR3OiPOhRP3fir4jG9+J
Kffhe7W/DlXep3751OXDx+q5BUf+dK6y/Gv8/gwvZjz2T+d94zASYvzmc/n/
fosY9Ry6vhjv08+tYvRTr/sTo1+93ybGPDf0fGLMq/tvFUMP6iOGXtRPDD2p
r9yi3tRfjPPg+chenhfPT/bxPBP0+cq3PG+tv1O66Aen9occpV+Wav9IK/30
svaXrKPfDmr/yVX68ZL2pzxLv9K/MkA/098SoN/pf3mDeWA+5AzzwvxIH/PE
fMl15o35kznmkfmUY8yrntcj65nnCZ1v2c+86/m9YiYPojQfBOQF+SE55An5
ItnkDfkje8gj8klyyCvyS2rIM/JNlpF35J94yUPyUZzkpc77pGSSp+War1JB
3q7S/JUp8nhY81kc5LXW2y9p5Dn5Lu0RmvfkvyTzPuD9IPZwfV/w/pC747f1
9zxQkvwfTnJb+A==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1HUYx8+fIwOrCXGuhlmrjltqwzZKoydapVtz5a00g6GDgGVTIFwp
UDB+HLBGGJnyQxSFgdF2eBvJiT/eCocc4SlwnIcIFyI/siMHWwmE/eA+z3N/
9Nlut9v3c8/3ed6f9/v1WR2bZIhfqNFo4uc/3m9eQ4i7szuo3LIF0cUtf+qi
f0FkQvv+DTt2wRKS59lqceP8rPXtoAWfItC06XZaoBuFWQeutNxIRUrEMld1
8iDcS0P9Y7anw37VuwYQXj06nRicjVBVcAC/FcRGazblw1stJO8WFhbPJod+
UIT5YvMV+/FQh/afuHUleM1bLqIfXfojoXsjD6O8zLtuInHwvYkXpspxX+ct
2IcPDTl///V8FQyqwT7ci4wy3w2vhmrP5ILWqc04Za6FKrfMheDC5WuOH6tH
glo3kBa4qCrMrwHeaYtbnEjMTvGzz5mhxg1xIuCj8URXcyPS1cC9qDCMxUS1
NYHLOUDrY1cGrTqH9Wo5oM+JCNzYeREHVcEeVJq+nlybcBkT3nE93Tgx3Vz1
TEkrNquBu9E93GuauNuGGm+56i6sfsRz4Is9NvB5dGHnhuymkCc7Rf9reHnG
PXX0DzvU9mQ7ynfmf5mV1gUlh+4qKoPGdxsCejCs9PwZlZaHbSvMDtGvAw03
ja//FOcUvWxITTU+1/G0S/RpR92qzH/zPH2iRxvaV2rCO5v7ocqlWTF1hZbo
igYQpuZtxfCi+PyRGLfMdxkFGz9PX/r4kMxzCWct+r00MyT9X4SlImDxA8dt
6fc8lpveMq6oG0ap6u8snG/MpMQk3YGf6qcJp7RNp6EfQYZ6fyMyK8I0a10j
8j4zvmtIePfCZ6NS34QJY46zbm5U6v2AN/dZa7clj2G/+n8N3qnfUvTJ9TGc
VvuPIc6+ePJC8Diy1PNDKH3i0SP7Nvt+5+LFiseevb9rHL6E+H7Lc/r//kPk
q3eJ65Pvffy8hnz9VHF/5JF+eb+JvpV5Jnk+ypB5uf9GqhU9RB/qEb1EP/IX
PUVfOiN6i/50Rs5DzoeMcl5yfjQo5/kSny/9LufN+lupVfxgZX/QSfGLP/uH
ksRP77O/qF78dpT9R2XixyH2J5WJX8W/dFj8LP6mdeJ38T9tkzxIPkgreZH8
kE3yJPmiUsmb5I++lzxKPkkreeV5HbRG8tzH+aZCyTvP30sPdjAPnmI+0Hbh
hfCDooQnwheaKWDeCH9otpd5JHyi68Ir4Re9IjwTvpFOeCf8o4PCQ+EjddiY
l5z3fsr9hnlqZL7SHuGtnvlL504yj68xn+nXJcxr1nuQSjKZ58J3sk8z74X/
tPVjvg/kfqC6W3xfyP1Bc7lfLfjxnunV/wD/SF4R
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1GUcx4nhxlECgf7VJIqtQWWbKfaLuw/9MFnLEBQzomYFrpUFzFUM
E2WKsWKBdJWAGA22IPUSOjsQ1/v4lVLHL48TQk4xDaqTBniAi43inud9f/Rs
t9vt+9zn+/m8n/f79dzzenZqVmBAQEDW0sf3rdcYQueyryycSEdGaftsbMYV
JLcMdRe89A6ao4o8Kc2X8XVmU9a0MQ8rLBuv5q+4DNuBmtzmvkLkGkOGanPc
GE1oiLOWFKPH4VujSDxx55PzpjLEqYKjyN627GPbhBm+alFFl2D3Rrtqt1di
qdhSxRG8mXPXpbG0Gph85Ywj+HR8LmjfYi0qK3zrVzR9ZdoWFF+PuVhfwWEU
T69BmOEkUlWDw1j86+6fcjc0QrVnGYLXuzBblWWFKhcyhMzs3PLCSRt2qnUR
hsq+6qrfW+GbtrTdhb7byp5Z9YAdatwoF95KKXjxZG079qiBB/HUjuLbH9/R
BV3OifCGNENM5nmsVcsJb3Hk2eSmX1CmCl7AyyGHEiI29eGGb1zPAAw9nv6g
qgEkqYEHsGbh2LpAmxN1vnK1/bj3iwZ37j8u6PPoR2zg4Fp75jD170Xh+tPG
bu8I1PacHiTtmnmot94NJUesA+Zxw5frZQy/KT1/xsbEibFNLVepXzcGypPu
u5B4jXqdR0fmxQ8+c16nPucQ/YI7NCx7nHp0Iaw18qPd4X9AlcvvxLvPP7fy
G+ufeFjN24GixbSW5O0ezteGVw/mp7vnb3AeO/adCbd8Xvo3+/8Rp39IHe1f
PsV+z6Ki6/20UMcUjqj+WuB6JGbi8P5pBKt+bDjzXbJ5d9wMPlTvt+L7xogn
3J0zfF8jqtvigiNTbrK+BaNO0/E9jpus14CY1vGV9fFe5Kn/16FjNuRw+ide
nFL7j2HzhGe+xOHFfvXcjLzUiMn3bvl/H0Si+9HrJaGz8CfE/5vP5f/7zeKv
Z9f1xf8+/bxO/P3U6P7E36/eb5GjnGdKzydNnFf3b5UW6kF9ZJB6UT85Qj2p
r1ipN/WXvTwPno9k8Lx4fnKA57lOn6/s4nlr/TtlOf3Qqf0hUfTLHdo/0kY/
bdX+kl767aj2n2ygH8e0P6WcfqV/5Wn6mf6WvfQ7/S8xzAPzIauYF+ZHHmSe
mC9Zxrwxf5LKPDKf4mFe9bxOCWaeh3W+5THmXc8/KK+RB9GaD3KOvCA/5FaF
5gn5IlvIG/JHrpFH5JNMklfkl+wkz8g3KSPvyD95mzwkH+VZ8lLnfUQKyNND
mq+ymry9X/NX/j2uedyr+SyvkNdab7fEk+fku1S/oXlP/kuSTd8HvB9kcVrf
F7w/ZPW3w8YR06mE/wByU2+H
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVVX1M1WUYvZc2asxKwf5oFlP+MCQwVxRFyjNtiFHNCTldYmUEactChSKE
TIKyGmGGHzHGYECSMcRAobpxLngFAUGvfF++Lk4JEXcFhEAy477vuX/0br/d
/fZ773mf5zznnHfJOx9FxLgZDIaYucf5q5cddWVvJC9xi0VUZu2kb9QA7tvr
H7YrKBFV3uk3NlT1I/qt+d88ZEzDwtKwwaSF/UiZyV06HZOBXas8Ogvi+uBe
cnee10tZaL7gXL2wHg/LvWbNxjIF2Iv37Rn3j63OhxPNO70HMUXXvbabizAH
NodoQ3jrd+cHZ04gxAm3ygY/S1NAdWoZsn90rm54uy9aPXS3HFO+TsAu7HY0
9G6erUSEKrALUUUBpzIOmKDKK+1EeWDAuye7zVBwHp1oCo5dcdNyFrFqdSAt
/Hs39wfr4ew2s7Ydu09X7+mvaoRq17sd6Qu2DT1ysQV7VcNtOPNk8jrHCSs0
XCsMXt967FjWhmfUasXFP/wKtl3rwEEFeBlvrx+errN3Y9TZ7g0rHEfWWscf
68M61bAVkfGP+rz8mh2FTriCS9i4v3m8zv8K9Dwuodi6peRT/6vkvwXBOfHp
ca8MQW2Pa0ZvdsoHwQeGoejwvYCc2JAVA/YRXFF8NuLr0M96bBE3yV8DGhzT
xxb1OMjXeXhFTAUaXxwjP/VIPLgjoTxznHycw2DlyBPrr09AwSVZUGRv6VgT
OomnVb9nMbnx1rn6vCn2V4M3Q4yRI9N/sx8zJmxBl38In2H91fgitQaHD91h
vSZMmh72PNM8i2Oqvt9weo1pp2n6Hzyg6qnE2uXDY/vm/4tkdX4Fap7yfHVy
wT2edwoJEw2mlXfuEb8UPvu7uzdFG8wa72fk/3mk7ePfDeZE9f9CHKrd7thj
NJrL1P5cjFs6bQlBRvPn6nsWXtg0Wty+xfWehoGxv5b6fGg0uxzieud3+f/+
LHHhmTW+uM7T3wslj/Xk6frEVa/eXyrx7OeW7k/M7FfXXyGh5IP8SAX5In9y
m3ySX0kl3+RfxjkPzke2cl6cn9zmPAP1fKWQ89b8W8ROPVi0PuQT6mWe1o94
Uk+va31JPfWWo/UnX1GPdq1PyaZeqV+xUc/UtzxPvVP/8hP9QH9IJP1C/8gG
+on+klH6jf6TrfQj/SlN9Kvut1VmPbWfu7S/5Vf6XfffJinMg8U6H2Qn84L5
IfuYJ8wXqWfeMH+klHnEfJJI5hXzS95jnjHfxIt5x/yTxcxD5qM8y7zUfrfN
4ek8/VLnq2xm3vrp/JUS5nGLzme5+ovOa813nzzHPGe+y+PMe+a/JCbp+4D3
g5Sd1PcF7w85fLS4MSk6f+V/VRJ2IQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX1Mk1cUxgtThGYsc2kFTWAYp+JYoplGkMhONpfM/bGgZFGyMJkfSGKE
1flddOl0RccSEUKsAwWczSYECyQsrR/4vFaIosAKVIt8KCDqOvxgMJmbyzbe
e8/9Yzdpmua9Pe85z32e35294fO0rFCDwZA1+dG/5RrAGVvb8NlhCzIKvc/i
M+7Csi+3dIrjADyx9pHVnjsonxHcGuU+ApPrg0Gr6Q6Snn1v3lB8DNtSjIHT
ln6sq6ouGoupQFurvvrw4lZeiuO4EwtEwT44PSWR5gPV0KvF2nuR4/t3esRP
dZgsNlmxB++Ov7Krz9OAd/RyKT1IeHHSkLbuHEq/09dtzDKHLEr3XMJEvF6w
G257WHFujhdposFuZFbMca163AzRniuAb0/dH/vyQQtEOWMA6dGRNe0b27FZ
rFuoWkpdEZ4O6NMWem+icV6U448CP8S4sTdhaY1+v7U2gDwxsB8P08tqUxN6
Ict1Ibk+uNUfcheLxerC7vMnzAVlgzgqCnbCV2lfMfXhPTzSxx3pwILBxsPZ
mx5gpRi4A/euD7sTTUE49XKnffDW1azMmhiBPA8fEg9Vhican7L+7RjqNJ+P
mf8bxHZLG7zNcT/GDIxByBHfim0V5nyH63cMCT2vw1Zt7Sw7OsH6teBJcKmz
7eBz1usa8jYtT9po/4v1uQrzqlx/fPHfrEczPLWj8/J/+AeinLUJyct2Rq/I
NGhvi3mv4MOkrP7RLSGanO8y1r+XGxu2I1ST82h4vvjwN7P3vKTJ/i/hxkJr
5s87pmiy34tomRkcL86eqh0X/Z1D4Zqa3tGPwrRw0Y8bBSdDi/bOnabtE+9v
QJTpjVT/yDR+Xz3W2j4daikP5/ouRMY55qcuj+B6Vcg49trEEW+Etkf834n8
4U8WjS80anVifzl8df7Gtw4aNZt4XoLXS/9cknxB/f4ag7P6w3ICRk0lRP3m
5/T//SWk6mmyPqn3yedOUv1Uyv5I9Sv3u0jNMyrnIzWv7L+BlB6sDym9WD9S
erK+pPRm/UmdB58PqfPi8yN1nkvk+ZI6b6l/E7nZD03SH2Riv7ws/UNW9tPH
0l/0mP12QvqPlB8HpD9J+ZX9S8rP7G9Sfmf/k8oD54NUXjg/pPLE+SKVN84f
qTxyPknlVc7bRSrP3TLf9AvnXc7vpy+YB3GSD3SZecH8oLPME+YLfca8Yf5Q
CfOI+UTZzCvmF2nMM+YbJTDvmH+UwjxkPlIa81LmvYdszNN8yVe6wbx9U/KX
5gQkj9sln6meeS317qdDzHPmO1GU5D3zn17dL+8Dvh/o16/kfcH3B/UVbb8f
Gtdw8T9vb1HL
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJxVVX9M1GUcPm5Rivw6dLBZknINj7AZxWyB8ElakZRiSGRgc/3AnNOAjV0m
2rKFXRpCEzdEUjaQgAarxgYl+LzAkUhgwB1w/AxPajlIbQS5Zi3u/Xzuj97t
dvve973n/Xyez/M877o3c9KyjQaDIXvp4/nmNY2W8FuWfsMh7C7uWLDs/hlF
UWemP99/Yun3wtmXW6bw9CtmnyTHGaxqTL5+eNUUbpk/2pPuV4m8BL+RqtxJ
5DjO+eavqUFfr2dNIDVi34mtyQ2I0oATsF1Zb50Z+RYetPDCcSxcb4p4sb0Z
S2BLiGPYUZrXWvBeGxI9cAljmOs1np5d3oHys541iuMNX441uLqwaPEAuhA6
E90et6kHabpAFy5QsXFPzE/Q5TWOYGPmg3n1Bwah4fxG4E68+GP3+SHs1WsY
tSX1NvumUXi6Le4YQrI5JSB28yR0u+FDiC8uTIkZn0aBbtiJ5sJsc0jGDTCc
A1t+893sMP2KJ/VyIPKrf/eFm26iRAMOYtj3i/DQjDnMedqdHcBTNJYe576N
F3TDA8jbntMWOf4Hqj1wVf2wn7satubmPHge/VgR/WnS0dWLwv81xHU91P/M
u3eht+f2ocWn4jmn+29oOiy9iBrcawuy/gO35rMHBvOrWWUhBsX8XUXqtgsz
B6w+ivnqRkLuzlrbjFExP1egulzJVZn3KeajCwkDNSUbhn2VhjtsR8f8kbVp
6Q+oJ3S/nciNOzl6/+Ayxf21IzLraJj/S36K+1HYdXC17d7lFYrrv4zbB/8q
2LU+QHG9rSjaGmY9fSxQlen6vsOlzt6miJ4gtUzX04yy4tqYHz4IVkf0+U3I
d79RFO9vkvO+QeXrn9VNnDQJfiOq3il/PPaeSfDq8PYndanzWSHqkP5/Ncqs
ixvv1oWor/X+85ivmKjd+UuI+lC/L8XyP98ybg9YKc8fw/rwsZr961Yqr0O8
z/Ke/r+/lLx4ivHJex6/ryZvPZVcH3nr5f2N5O3nDvdH3n65/iY6K3wIP9Qq
fAl/dEr4FH7pjvAt/NNrMg+ZD1lkXjI/ypN5xvJ8qVPmzfzbiUQPdtYHtYte
/Fk/lCh6Smd90Q7RWwXrj4yix2nWJ0WLXkW/1Cp6Fn1Tguhd9E+B4gfxB3WL
X8Q/lC9+En8Rid/EfzQlfhR/0mPiV+7XQSniZxf7m5T4nft30rOSB2s5HyhT
8kLyg76XPJF8oQXJG8kfSpI8knyiTskryS+KlzyTfKN6yTvJPwru4zyUfKRy
yUv2+xhtcXOeHud8pSHJ20c5f+l3yeNrnM8U7OS8Zr4n6dQjnOeS7/R+Bue9
5D8FbeD7QO4HumTm+0LuD5oKvdH2fKCz9T9VCjn8
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX1M1VUYx6/hC5cAEcELESxrGZRurWDVjB5GGQ6hEjJ7Uedw0KgQ3cR8
6+WPLoyRYA0VCFzpDWjTazBLQuJ75IJvAwZe7F4vIMiNSUGAzmI5hPid85w/
Otvd3d3v3Of3PN/z/X7O8ozctMwHTCZT5tzH+FZrEHXn/b15tz7FppKWv6M3
DSDC/PVbE/O+QkOUdXR9ww0UWWNDN0dUIsSedHNfyA1Uj7TnDdTasDPez3Vi
Rz/cGytWXzlwEh3txurDruwFG6L76hEjC/Zhe1XQrcKkBhjVoqy9iHA4Rn+t
bMZcsbmKHrzjGMqPud+Cl4xy8R783hf+xMGEi6goN9Z1FNSmH5+Jacc/0UZB
NxY9OLFycrgLabJBN3YXv7315MM9kO3ZXbjnQ1WBDhdkOT8XrE3p28K8vciS
6ze4P2srzHx5EMa0JS3XUOeNzLjfOwQ5btQ1bHz+aWuAGMZ+OXAPnDWmYJ+7
I1DlnDiXEXxkYP8YnpXLicWNs4u/XDWJQ7LgVWyo35L7QvIdjBnjjnbD+0qx
6U7pXayVA3fDWZWUHhc4BZtR7kQX1n+wKmvqp3+hzqMLwxEXvjlUNM36d2LY
8knc6YOzkNt3dGCNZSb38c3zhJQjuh17X2vOSV3kI4aknlew9Pbh4wWO+ULp
dxnVbyyZqS5ZKJRel7BgTcqF8GxfofS5CPQXrh5L8RNKjzaUB3QXdDznL2S5
fa1oS7aZLSsCxTNyXgcSsh6d/tMcJNR853H1Mf+aD2eChJpHIH665o93x5cI
1X8z8j5K8M1zBXO/TSj/vnQi5+xSUSb7+wUPDY4fu1cUInxlP2dhf90z60kL
FQfk+89grPHIba95Gb+vDh/Hbks2n17G9e1ISTxa/H6Chev9gPGF2ZGpTRax
R/7fhnW9iYcTl4eJH+X+Y3A31sYFbw8Tn8vnpQhI7fDr/E7//gKXp0Z+7jkX
JnRC9G9+Tv/fX0q6nlD1KZnfp57b6C/u51vVH63jftV+O+3meSbVfDTK86r+
z9Ap1oP1oXDWi/WjMtaT9aVdrDfrTy/yefD5UDefF58f6fOMVedLrXzeSv9W
KmM/tCp/UDP7xV/5h+azn95U/iLtt0rlP9J+HFT+JO1X9i+9yn5mf5P2O/uf
dB44H6TzwvkhnSfOF+m8cf5I55HzSTqval4n6Ty7Vb5J513N30OaB48oPlA9
84L5QdeZJ8wXymfeMH9I84j5RJpXzC/SPGO+keYd8480D5mPpHmp8u6hSOZp
vuIr7WTePqn4S3uYx52Kz3STea307qdTzHPmO1Uw75n/9BTfB3w/0CTfF3x/
UE7oe3tXHC1p+g9NSksI
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX1QlFUUxqHGSQUbCMRgjcyo1o20zMacWA9mYcoUiUvlCoyhYBrN+jEl
kUGlsFY0AoJEk+LHTuQw0EJUMJLPBSGVgJDlY0UEk2wsnABDyz7G2HsOf3Rn
dph33st5z3nu8/zuPUm22ORbvLy8ksd/nr+8LmDy/krz/W+/i/g9DdeM8QNY
YRutb4/ci5rQrKGVNf2g+MGsAFcJAiuW/Zge2I+svrCEsuRSbDFP7Tmy+Tzm
VK5vtM12orXFs/qwrci0ZUniV5ijC44/fxQc+cXOY/BUC806h8NBIWmpq+sx
Xmy8Yi/y8150L7M3YbGnnLkX31W1Zt6V2IxPij3rLIo3dJ3sHP0B142egm7s
yj77W9WDLsTqBt04mFsSG9fRDd1eRQ8y7rtm8v+zF7rc1B78ZNibt+rzAaTo
1Y3+Nfb1T2+/CM+0exq68GVe0Nobmy5BjxvahVmHDJby6st4Sw/ciapXH/fd
uvoKuJwLuQ+n3T08dwSP6uVC4brvt48lXUWuLtiB58Pt/i83j+GKZ9yhMygY
nm2NS/kDz+iBz2B54QFDysK/4PCUO9KOjqjyv3eb/wWfRzu87fnTvCO8FOvf
BsuiN2uOXvVWevvmVuTf9I0sqr9VaTmMLbCGt+1cUDpJXdR6NmNhQOrh9EO3
KdbvNL79Os00XD5FsV6nYDvWV+Q47aNYn5Mw/h4XYx6dpliPJiTVPbs/zc9P
6XLpjZjbZPGJNvmr+XreEziealnUtfQOxfPV44XMWkelNUDxPAqXZ0RNSkwN
lP6PI6EkbONTb0yXfutwY1XU4qbXg9THur9a9D5km/7kKzPUZN3PN6hKeGzQ
GH2n2qG/X41HBqt33DQEy/cq8et7wVNs7mCpX4GIobLQmIwQqXcUhQ8ML3H6
GFSa/n8Hoj8rzbyUYVBOvf8ATsRaB3K6Deod/b4A927r3LrPf6Y878L7IRva
l8+bqSYSMvEs7+n/+wtoop7i+rRCvsfvHVQg/Rzk/ugJ6Zf3V9AvMs8Iz0fz
ZF7uv5qcoofoQ27RS/Sj66Kn6EtrRG/Rn36W85DzIYucl5wf1cl5LuDzpXA5
b9a/kdaKHxrZHxQmfvFl/9Am8ZOF/UW14rdP2X80X/x4gf1JceJX8S/liJ/F
3/Sc+F38T/9kcx4kH3RK8iL5IZI8Sb7oA8mb5I+iJI+ST/pQ8srzusgueXZz
vqlE8s7zd9LtwoNZzAdyCC+EH9QmPBG+UIPwRvhDCcIj4RNlCK+EX7ROeCZ8
o5eEd8I/yhIeCh9ppfCS895LScLTbOYrjeUwb03MXxrbxzxuYz5TmZN5zXqf
J/s55rnwnZZamffCf4p5je8DuR/Ir5jvC7k/aGO274i1ZSDiP9LEOYs=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1GUcx0lS4tAJCZ5wjcj+6HSroTGmFnwGZeJmMk83caNiINrEhiIb
RaYZwj/UFGJxMTQXh46Qs+axkCHvB8QUBbw7OKHj5x3m2i6VMRSxzPg+z+f7
R892u92+z32+n8/7eb9fzyvZ+ZbcBUFBQbnzH+1brQn8m1X4jfX5Y8g80fnQ
nDmOvY5O58DlSrTElga2tYzhwk+LDMefnkakfZOvOHIMu81rtvlvnMXBJMNg
3YFRNE+WZ5UWXEBvj7ZGsPGaOzrc48AqWXAEs86Zvzs9rdCqxZYOI33r+Mjh
ewLzxeYrevFdWdeHR4OvIlkrl+RFRnnzlp3oRs332vodxs92bqhPuIVHZq3g
EI5Y9y1b0uaGRTY4hMqpOYct/TZke/ZBvPzGD+2JWV7IcoZB+N66V7R0bgx7
5LqNPVZPGl70Q5v2RKcHjoKIBMvjO5DjxnqQ/8eh+Nq1f+JzOfAAuht2fWL7
LQBVrh/DidT8pOUB3pSrH+mNm2O6F03jpCzoxs1S66benBn8pY0bcCH7emHI
+ZlHSJMDu1BtbAo8vTQHm1auzokfe+qr2i/+A3UeTvjuxu/f4HvG+vehKdwT
evTMc0JuP9CLlY33I3Z/HCykHOYeLMjOuN/+3kLhl3reQMprqfaK9SFC6deN
CkfTw7zkUKH0uo7gHYv35VnChNLnGi6KxOrkgiVC6XEVKXEl+atrlgpZrrgL
me/mvB06GS7WynmvYGhdhbvjcYRQ83XA9STKNxG2TKh5BM6FzDYEoiOF6r8d
ZVFxfdvjorjfNni/3ZV07KXlwir7u4Tq2Y/GR8KM4gXZz6+oThluHQ4YxWH5
fgcKTIcyDK0r+H2/IL78lGlFYTTXt+Mr1/tpfmMM12tAVUPJ/iN1MeJT+X8b
YgzP7r4TZRI/y/2nMf56yOaBPJP4Uj6vQo55VcbKs/rv46idGv2i6IpJ6AnR
f/Nz+v/+KtLrCVWf9Pep5zbS+zmj+iO9X7XfTvo8U2o+0udV/TtI14P1IV0v
1o90PVlf0vVm/Uk/Dz4f0s+Lz4/080xQ50sf8Hkr/bsolf3QpfxBDvbLYuUf
Wsh+2qH8RZXst1rlP0plP04of1Iw+5X9S6+yn9nfZGe/s/9pkvPA+aB6zgvn
h2o4T5wvyuW8cf7oFueR80kWzquat5/8nOchlW9yct7V/ANUxDyIU3ygy8wL
5gflM0+YLzTNvGH+UDzziPlEdcwr5hedZJ4x32g98475R8XMQ+YjtTAvVd69
dJB5Wqb4SkkuxdvVir/0NfO4T/GZNt5RvFZ6j9I085z5TjcbFe+Z/1TSrO4D
vh8oMUfdF3x/0Bbrgw6L29X2HwbWT9g=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlX9M1HUYxxGmpaAzO2BUY8Eo7lprK2yLBJ8lFRgGokQW2JISsqaAv1C5
zVoculhSEw1NwA2MhYVAQMhuvj8eHAQhCYjQdeBRZg6IcIizLOvu8zz3R5/t
xr77fni+z/P+vN+vT1hmzrrNvj4+PpvdP89fXi6cXGKe8z1gRkaJbc6YcQU7
kvcWG3JL0BpqmUxpHcN0vvNMue9xGOrix/cZxvDp5IuN30RUIS920XBV7ihe
SS1dY95Wiwu9nuXEn2/NC2+zNMCkCzqxKnjF25ajLfBUC7X8hCxVuf1MoRXu
Yu6KDmTPW9He23IeKz3lYh3wf+/zodxWO44f86wf8c+YZU/ohh7cMnoKjiC6
Iuz5ypofsE43OIKDe9N22JwD0O3VDSOuxJ5VsPYydLlFw2i39Vw/+4wDWXpd
xsa40/a4yjF4pi2xDeG1VNXv7ByHHjd0CM9WPGdtLLqKAj3wJfiXpdd/cPg3
cLlBpB/ua111YwJRermfa79u2lI1jU90wQF8sd06tCntBqY84072w2/Xgkdr
D8wiQQ/cD0d2VEPItTlUe8pVXUR+ZuqR5rzb4PO4iJi17SunTHdE/z405/8+
U7T4LvT23AtIWTpwKuljH6XlMPbiYPT60y9E+qqftZ49GA9fuGZuwE+xft0w
VURuiD80X7Fe3+GBKxmztrR7FOvTBWf9zbuHTAsV62GH/fqJzt1+/kqX29fh
7vPXf2dcAeopPW87HmwOe8h0boni+c6jtzN5qyVxqeJ5FNr8su/URN2nuP9z
aLjaPRofuEz6teKPo80hxullqkz3dxYf9iQmBVjvV/fqfr5FzLGkjTazQZn1
95tgrElf/fgTgfK9BuTN3xnwUl+g1K+D86OtkXHpQVLvS0zOqtqcwSC1R/9/
NZJvhhS8+XSwqtf7K5BZHFJ2bX+wel+/L4VvbNeTIY3e50KEv7F40+vfBytv
QrzP8p7+v7+UvPUU1yfv9/h9NU1IPye5P3JIv7y/jnJknhmejx6Rebn/JooW
PUQf2i96iX40JXqKvlQneov+1CLnIedD3XJecn5kkPNczudLlXLerH8HKfFD
B/uDhsUvAewfChI/pbK/KEL8doL9R07xo4v9SYXiV/EvvSx+Fn/TV+J38T8t
lzxIPmib5EXyQ/2SJ8kX/bWT8yb5o3LJo+STEiSvPO8gJUieRzjfdPszzjvP
f4mMwoOHmQ+0Wngh/KBY4YnwhaqEN8IfChceCZ8oW3gl/KJb5cwz4Ru1Ce+E
f9T1LvNQ+EgRwkvOu4N+AfO0iPlKCGLePsb8pd3C4z7mM6WsZ16z3qNUPME8
F76TaxfzXvhPrybyfSD3A72zgO8LuT9oy9+naitzXDH/ATWZS4A=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxVlW1M01cUxsswyBCnZdXGuJEx9wGNyxZkzRICR4eLjA+KqJFEHbFE5l6c
IKKmuo0w2DSagZMQZUiYQAKaVBDxDcZzgRpkKy8tYLFiQacxUVE0SCQmOv73
nvthN2ma5n97/uc893l+N8q+M3XbGyaTadv0x/hWaxRjHR+nJ8zLxeai9ufR
m0fwZGtr3vLEX3EpsvDh2ksBBA+8HbTl82OwOFfddlgCyL+X8eGKr8qRHR/m
q8q6hYR732duOVWFbrexhvH68Ma975pPY7EsOIwBuyPnprceRrXIwpsoe4o3
B1c2YbrYdEU/ZlZ/cHZ27hUkGOXi/ThcdKxsLF6g7ISxbqBpYl3vycsdmIw2
Cg5hl3V9zobmTqTKBofg2O9ctnutG7I9pw8l4vif31ztgywX5sNEzfv31zT3
I1Ou62jfvioQEuGDMW1R+yA6m9PTLB4/5LiRg7B0pba1vg5gvxx4AB8dTWrI
9t6GKtcP3wmPJyPjLpbJ1Y9yYF/OJ/dRLAt6cS421TKS/ACPjHEfelC4Ouxa
cs0YkuTAHjxdWV/rPTWOaqNcVR/a3rnREVL6DOo8+pBrz68YPjPB+vcgKT90
8c5/JyG3Z3Xjr6qfv10TNwUpR7Qb5cNphw40vMQdqeff2BSzKOrLxFesXxcq
Hbam0T0mofS6hg07shq/ux4klD6deNyzyRaVECyUHldxcN2nFQVnZghZzuHC
kDsj4F8YImLkvB1Y3vbCufTITKHma0OQqCxImQoVah6BJSF1Mc/Tw4TqvxVx
1pFwZ8ssofptgXf8YoopfLY4Lvu7DNuKtOLs5LdEqOznIhwz3D2lu+eIA/L9
57G6t3vqaOJcfl8D8rY3lv2AuVzfOe2j3lkVS81crw51r4r/qT1kFvvk/6vx
9cG4338aNIt6ub8Cny3YGmqbEyHy5PMSWF8G/zbfpn8XwLr3zpOaLyKEToj+
zc/p//tLSNcTqj7p96nn1aT7qVT9ke5X7XeSnmdczUd6XtX/edJ6sD6k9WL9
SOvJ+pLWm/UnfR58PqTPi8+P9HnGqvMlfd5KfxdpP7iUP0j7JVz5h7Sf1it/
kfZbufIfaT+OKn+S9iv7l7Sf2d+k/c7+J50HzgfpvHB+aJzzxPkinTfOHzVw
Hjmf9AfnVc3bTzrPQyrfpPOu5h8gzYP3FB+oi3nB/CAX84T5QpPMG+YPlTKP
mE/0I/OK+UV7mGfMN7rCvGP+UTHzkPlIZualyrufapinvyi+0gjzdoniL1mP
KB73KD7TRua10vsWNTLPme8Uy7xn/lOKXd0HfD9QvUvdF3x/UHBkXeYFe23L
fwPiSxE=
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJxVlX9M1HUYx8HQ4GZuCTI3BKJNutA1Fs6ZCU9TtEsIJ9HGHy4Fs5waghgo
wkoGVOQNZsyEjKkwTUjGkUOK0/c3fgwPDgMB7zx+eGCL5aERJxqpFfd5Hv7o
s91ut+/nnu/zvD/v9+sTlro/cdc8Ly+vXbMfzzcvJ5KMxgf1WfuwraRlWr/t
NiyjhouZhz9BU0iha2vTCI5sqpwsDStGQN2bozkBI4h/O/Xb0fivkBGts1Wl
D2O81vR64tUKdFs9awi55veNU51n8LIqOIRjMf4HHD7n4akWUjiI1Z9lf382
4iJmi81WdKCifcXOHa80IMZTLtqB7J139odvb0RFuWfdQpS925G2thkP9Z6C
duye9r7mv0dDomrQjuDY3PBTp1uh2quzoVTv3HcurgOqnM6G1a5akyGrCx+o
dRPjDSeD7Et64Jm2pGUAi4L/Mh5qvgE1bsgAUguCDnxoGsARNXA/zI1xoXhi
B5frQ9dl/buRZ4cQpVYfEp5Gm+8nOlGqCt7A5zFrJsoLxzDhGdfVC/+ONGfK
3V9hUAP34ofOyLCF+eOo9pSr6sHmj61DHfF3wefRg1C3T3DQ5nui/3U8Ttvb
vnvdJNT29G4Mv7bHlOX6E0oOvRUlW09Udte7Mab07MTRzK6qsuJp0c+CP+ZH
rz+a9Uj0uoYRd4vBljEj+nTAJzs5cu/hx6JHOw62Ni09/8VTqHI5bci03s45
XvkvXlXztsJiffDW/VteGs/3MzYWP/zp4Ji3xvNoCHwnuSv9t3ka938VKZtC
f0m584zG/ZrRvzzsefNNH+2k6u9HuI9bMt1X5mu+qp/LaPNbVl50YoGWq95/
CSUB+i26956V95kQrn9pZtViX6lfh5X2xprf632l3gUs0htq1q/x0w6p/1fj
yj8LFn9zzk+rV/srcS8hIu7rv/20T9XzMgTmNYSvjNLJ7wKYz4xur96i0+YS
MvdbntP/95fRXD2N69Pc+/h5NT0n/Zzm/miF9Mv762i5zDPJ85FR5uX+L1Gr
6CH60JToJfpRn+gp+tIO0Vv0pyVyHnI+FCvnJedHHXKeq/h8KV3Om/Vvowzx
Qxv7g7zFLwvZPzQofkpif5FL/HaK/Ud54kcn+5O+FL+Kf8kufhZ/0yPxu/if
AiUPkg96Q/Ii+aELkifJF/lK3iR/lCd5lHzSBskrz9tHjZJnO+ebvpO88/z9
lCA8eIH5QE+WMS+EH9QvPBG+kL/wRvhDHwmPhE80s4F5JfyijcIz4RtN2Jh3
wj+KFB4KHylJeMl5d1BtEfO0iPlK3sLbCOYvTTUzj68zn8lWw7xmvYdpbTzz
XPhOybHMe+E/5Q/zfSD3A1kK+L6Q+4MGj+W/GLS0d91/t2tYIw==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1k30s1HEcxy89LP0TxZCHxuGPUs55qFb2KbexSSuiByfa0Z0euAw1yUNO
fj9M02ZCJP6hGG0eRta+1nWL5uEwEgmd3dhxw11352rE7/f9frbvvvvu8/68
Pg/f79dVJI24Y8HhcAK3187OmgmN8m9QU0NHwZcxI+KPh/AaH/JAzJgBWev3
CQWyM1BVuWN/kO5bjqG2+gIMDuyYHvnRNz/9UgYDy9Oj7NaVfx/EYZinQ73r
3g01vuGYt46oKZPT+eRIzFtDQa+DL7YvXse8VdRzJKnpd6MQ81aRn4cHze2I
w/FapO+7TDscEAEjH1hGnRK1e4k4AefTIE6R6Xi+TgwMvnIJCWrf8Irb72Le
InK/V0oZmx9gnhpFFYnmG2elmLeAOC2amOiGFMxToS37Jp+nWamYN48iKpSx
fSnpmDeHupJtKmvyHuP4n0hiH1043pwBFYz+B8qNGylM02RCApNvAgVF5hdL
T2UDj+GPIWd+ybVhQS7mKVGZuf7yk8RnOL4fSWba8gpkeVgvR8PGHKeiFzIo
ZfzdqLflvSRDlg+5zPkdWlZU7A659RzIDe+V952T2hfAW9YPLtby9Ctt5NwN
AXNB8sCTFJxm+TDt/zU6tJjC/n5Qb9aNzgxSpD5o2AwQepkp8GPrh1qFXNNq
Q0Mi2x8YpeHKLlcaqtn+YetRrJurBw1Kdj6gmtniurvRZH5QN9EaetWR6OdB
aMlV1B6iMV8Ftl+0OVJLmtwPyG0/13RySD41SOzie6w2SH2LEJ52P/n7OoV5
S2DtVb7qpyX1aoA/7zzF11C4nmUY7toIUyxRmKeFS5PlnmNLhLcK4aqI8bPb
+iH2fQLXP+b29ApF3i/ETwocStZI/Dp4HzNHnTCQfDrYM9aTWfWX8PTgOGso
7dhFY54eXh4uzhLtp8n/gqSFMlv6IOnPADqfVxZWdmQeRtga+VihdiHzM0H9
QGqd2ZOG/x9xzRU=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10ntIk1EUAPD5SCxE0UAtM7TE0cNHZiA5O1FKplQ6EktiLh8lIWiLkpSZ
KGGl+cqVs1LzEWkOw0z35eMk5sTyhdZklaGuieJ7Tt0fGuX33Xvg8nG55/zO
vd+9rjFJwnhTHo8X8H9sfbkwYpNTdkzw2zA4ysY6NnmgMvz4VbjGxhr6hpzW
LX+8AaXyrVjF9LCi7AmJBPr7tsKAd31O+Ah0KcB5BuS5JYwcbpcSbwW79Z0h
jqaZxNNjJW8xNiLmPvGWkQ/DP9bMHxJvCV85WsTtXcol3hKO/M7YcURWQOoX
MGzUzkM8VgRset8clqeUBQVelJF+s5jwebJDvvkMWF4+gwIv9a6dY6XEm8bk
TmHnobWXxJtC+1Zvd0NNBfH+YGyQyvJkciXxtLjxyUp0J6qaeBP4zcTqllfc
a+KNY7jIQ9Gf84bU/8JW15v73QfqoITN12BsodTf010BcWw/NQ6b8xsxtwG8
WX8EHaVhvKCNd8Qbwhaze6NuXo2kvhfnXJpt6y+9J/ldKO1GQaikCQrYdQb9
ryi6Bm5/gAx2Xote1ml9JqJmoDfcFrnsKeC3QAW3Dn4NDtvaB+mcAd31jLqO
SCX4cT4sCisbTnUqyXovtGkTR2tsGLo/iNM4pzucYcCX2z9Ef5mssU1kIIE7
H5R8dRFOZzLwgjs/pE7ydGn5DAxx/wfUVbWPbWTUG4ekHLPnAU9p/gSIsnpS
eTLqawGCj4l7ihh6P5Bpj9L8AtpvCmIb410386g3DQcfmO6R5FFvBhqWz4ld
8qk3C4HnHykdC+l+5iBxyFkfUUy9BWhXG+26S6i3BMrE776hZQwMcO8TqqKd
inurGfp+YVrkfNalntbrYZ/m73bvJtpvBS5YZgT8bKOeAfhZ2cUWKuoZwNpT
ES4fpN4qSHdro6Qa6q2B+InFgXIt9dZhVmVVNT9PPSMYVE4Ll40M/AM7mcln

          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw103lIk2EYAPAlDiXnjUeQmSmEijYrS5f5RIdkZUTUP2EHNWXqwMzIxDNF
tDRsYelMUXRkyTAPFA/0beaxNY955DZbMnGYY/PcPKjQ9Pve94GPj5f3eX7P
e3yf18PEmzEWDAbj7O6z96ZjCxX37DTVOSTCCSo2kTbYOoLJyoZYKjbQ4Zgn
x+7OFUC5cC/W0XI7N0HoL4Dhob0wo9y/lUGLnPdAe2aUE/faXFj3AXsmNBbJ
6LTrrsbeGuJEMvNsZ2qxt4oONLtaGc/UYW8Fladl+J/X1GNvd6yxkTj1N+D6
JVTNTBU+yGwCKn3IiH5G2Vdu97XgfgaUtJAeoghtA4oX6lFJ+NrVMG079haQ
T6vYI72rC3vzKN/N4fKjkR7s6VDVs+SRl7YS7M0hfagjM2qsF3uzaPJrrzS0
uQ97WmS1o23bbhjA9RrUEyBwXeyTQhmVr0b7zZaZX5a/A5fqN4VqL7G7nX2H
gU35E8hzzNPtH28UewpU1HpPNDCuwPUy5CQwKif1Yzj/G7JkelnMmMbhDTXf
gVar+E/vGyYgmxp/RhUpjECxfBLIDacGilhxgh9QTc9Dfdht1i/OFB53gC4t
wWApnYIQ2odSPx7icZR4XgZ2uqxDkhIlWR/Ihdzg3GklnKTXDzkt/AG+vQp4
9P5AnmjK8j6tggp6/3BcXSNbvaUCBX0+MKw0udckqMj5QbK8vzE5g+TPwvS0
zM6rSIX9OVAOOSWslKnI/cAn+99XpCLSbx5aHvv6XWwk3gJsNsgsBruIpweb
t1a9rwaJZ4B4j9IC8QRZjxEKff0Zp7TEW4JEt9hwn0XircAFtnsr/48KRujv
E7Zc8kUMazX5fkH8sTlp1EWN69fgTlJ+oNRbjfuZ4DlbUjwdpCb/Bxy94Zix
CWrsmWG51jna8Trx1iFmHzfgYDTxNkD3LqLINp54m3COda1Ck0K8LUg70ml8
kaeG/6Lv1HY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10ntIU2EUAHBNSntoZeQfpQuxmpjOtEbrMU4JSkVZClnmq5ZJSeIjxKh/
lmZiPugpLsTX8p2W7g9bUacavsrUHJrLgc73mu1xt+k0sfLe7x64XD6+c37n
e3mKksOvrrKzsxP+/1b+TNhw2XVPa0J9NuyjYx4jZVkpzbFFkEDHHC7wq8f4
ERXwXLISVhwWOVEL0zXwrXslLBgSeoYTpm8CxrNgaIUs1HBQRjwz3vspaeAG
tRKPwvycjT78onfEM2GHAANzOB+JZ0SHL2XNO8o+E8+Ilu2JjuazbaRej3H2
y3Phgk6g07tnsdO4lNsR+ZX006F1ta1gQd4DNC/RYrNq9HIn7zvxZvCp2EUt
3qkk3hRKGnURXkcHiDeBKr3qJmT9IN44im57C9/oVcTTYPtUem16ppp4o+hb
4VvgJBwh9WqMHlzMkzproJjOV2Fim//QXN4YxNP9BnGtlF/ZsHUC9tK+Elt7
2p1kVZPE68PGGwO2Yf40qe/CBI9XaR44Q/IV+KnVIHc99Ase0vNyFFPZnqVl
OhDT4zp05V2/KNHOAnvDA5X5d1K36KGcmYddMUl+hdsMZCwH7qQoKHnZAALG
B/dTScFwyUjmu6ApMHONstnIrg+Uz+JOjluNsJ9ZPxT/Pn+uiGeCa8z+YHfv
67fOsSYoYfYPUbNVS0fum6CPOR+ot6p5/bUm9vxAuiFP7tfB5mvg9HATxo+Z
iD8OqRx72Yk/JvZ+oNBRkZfhSpF+U8ANdwuO8abY+wW3x+qQ40KKeFrIt7px
k8Io4ukg4DC3Wh9PkfXMwq1HinXjGaynB6+AKM6FB6xnhP7NaZsiSijoYd4n
HIvV3dU0Uuz7BUXLesPSB7aegsUgnbSul+1nhvf+huiZEdazQIv2yku5gfUs
4KB4coDzl/WskFKaO+TmYibeHPBqlI0v3M3Em4fp8nZOl4+ZeDb46yAfyhaY
4R/RfONd
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10gtIU1EYAOA5ndtKopIUixGRiqXlI8ksxn9DSSsfVFKpC8lnJCYNepha
gmYkEmVUzmZKPihfaCSySo6mJc7XZCppG21q6k2n080pFlne+++Hw+Vw/v/7
z7nn7IlPP5vE5XA44v9j48vGKmk+KK5OelYCh5hYIbIhXkBBWi0kM2Ehhodh
GTXiZiiRbcQy6W30pROCW6GvdyPMZOFMZt/+2c/AembCCwgN5eZ0oWcidLqD
9HlKL3pLJM5QmN48pEJvkTh2DXp9q1ajZyT8JGFkZcMIekay11dC642jWD9P
poOOB9VItcCk984RddHk7Xq5DvvNksG2LBlUjQPDy2hi8r5jGR6eRG+GlNJS
s6vvNHpTxCOqvrxSQaM3SQo6U1Il1+fQmyDi7dpPr6IX0NMTfp3t1+jARfR0
RNJeNq7QLmG9hlgWFzVpxWYoZvJHSXeOvlCVbIFEpt8IiXC55G8MXgUfxleT
EUOn+O6BNfRUJGzy8OUplz9Y302+cxRJxdy/mN9BTCLlWP6PdXjMrCuIcsHt
S8oQh8ph5m+JU7g790OtDWW94Zi0R53rUi5Vzq5Df0ZIVJaHLc4VkH+/5UZe
jy11hPVB2VqhTJXY4Xo3jMrUeec0duipwHGfwXUmjEf5s/uHYZ6Dm6iRR11h
zwdB8t+RS3x7Ss6eH+LiN3mdPG9Pqdj/A3U7I172yO3R08H7o02eeo01Xw9D
vwYMDc589CdAc+tmqSiCT+H9QMjqR8V4Dh/7TYHn01woaOSjNwOBQblN97R8
9Gjws6wP7BAI0JuFrS70SKGPAPczB95P1i46XxCgNw8nRLtmtZkC9Iyw+VjV
mE2ZgOpn3yeY3nS5lbUJKHy/cErO/dmns9YvwYstuacr1q39THCVzo71EwnR
M8NUR0JiYaAQPTPw0i0x7VFC9JahqUjtpLsmRM8C4e7vsi0PhOitQEzU7tfb
yq3eKkhiO0fFLULqH46xyaE=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw10gss1VEYAPArI895FLm496YlieRSm8fuvsOk7ZLWtamsbMmj2dDN1hrS
VemqRTEtlHlmTLTZsmk4xvIal400r7ryyNvFvS5KK///59vO/js73/f7zjn/
4xCZKIk+wOFwRP/H3peNLSoMWdXpeV4HnkxoqUxBJk4/oBDDxCaVh5udN4ro
gsKCvdDQkG2Zr3fHAPT17oWaysQpdS41X4H11NTvo4Nxy/QoehuU9ylBKxIp
0VunRXr9wlCfKfTW6HZrg5yfMIueiroN6nalT8yjp6JSg/CrrVnLWL9C/Waz
LERtKmDSe5doe0TQt/6pdey3SCO3Avzr3DTA8AXztKq4/PjOey16c1SRG2PU
GbyD3ixVeDenqh130Zum98zr7Xe5HMJ6U9Q70sxM0qRDWG+SznU7R0Yk6xLW
U1KTzLSTQ6F6hK0fp9yizqLkCwdJPpM/Qv19OYlaiSGJYvoNU0NxcHzZXWPi
zviD1MrDSHqn1BS9AapqeBirO2KG9d30fsb1MI2BBea309K+5YvGxyzJK2a9
kY7+tqSfPQ8RGTOvpjcyhnwv+xwm+3/4aGemsN3DipSw61DdMlY5Y2uN80YY
XrimJ1+zJl6sDxm+llbRDUdwvRticybf6MfZ7O8Pkjp+iJ+YcslZdv8gTOX4
hJRxyW32fND7RdaldbYl79jzwyNeSJh5pS0ZYO8HcoKiNgxt7PbvD1Zd0+Jc
0+0wfxLG46SJOT/t0J+CvP6K1ydE9ni/01AcOCSuz7HHfrMQ/7T/14jSHr05
kA9fqnVy4aE3D8qlJGtzKQ+9Rci7eU68Wc/D/SzB96XsmjNrPPRWIPeUY5m+
Kx89FagC/VuabvGJgn2f8Me9N/xFPp/g+4W0vy/Hqnv4WL8OkscVJQE7fOy3
AW+3hG1yJwF6asie8SovlAjQU0OVl3NMaYoAPQ1c2XULai4ToLcJjQELuyZd
AvS00OxaO/xhcd/bgjAr7rMx/aPkHxZuuTg=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10n0s1GEcAHCHUgp564pueWmUdO5+XnaO6/t0YVpmS//ZmXDpvGU0u4U/
1BS1VmeIQ9hstVJTmXWm9SDU6RRrGWYhdbrhOtx5uZHy+z333X777dnz/X6+
z5t3am7CZWsrKyvR/2/nz8Q6jsmfvZT1oRuC6VjDbjLU3npuBNLpWMUFUS/k
o28noE65EyZsLU8bbZL+gCHNThjx1n2J4MC7OWA8I950Y7n/zVsk3gq2P+oz
wO1bIt4yDqKUgwZbE/GWcM8TrdCmZJ14BmzDl0juCTeJZ8CxreY6B44VYur1
+M7gmPaC2BrR6ZoFHC5hFQoVtojpN4+r1NP5LvZ2iOaVOqy2lT0WtO9FjPcb
hyZH8+we7CeeFttnJnq9bHYi3k+sZO1JvF3gTLxZ3BnflMMVuBJvBlMpZX/M
h9yJN40dGjUtBjab1E9i8YK+UBByGNXS+ePYVd8u12V5IindbxRn5rVsT3Rx
EI/2v+Liga3aficv4g3jUvTGuTLWm9SrcdwIO2qy1Ifkv8dNCk39x25fpKDn
O7Eov29aun4MldDjpzjZ/VrAkr8fstxwzs2+joA4f9TMzINXdpFNaepxMu4E
vSbpoDjjBBIwPpRXVTcVJweQeTX0hzR37Io+aVkfjEf5HRF7BKIQZv1QIZqJ
2JwKRDJmf1AjuOonrDmFGpj9g6m5UeV5houGmfOB87+Mlb3fuZbzg54wYdjZ
vCCSPwMry5FhjzaCiD8L804TwZJInuV+IK3Asei1nEf6aaH+YswtbhvPcr+g
KH1Y7jvLI54OzHdV+yZd+cSbh7YvG9t1Z/hkPQsQMWdUNWTziacHc5JbN7ua
TzwDFKewykRdfPSZeZ/wLVe/JZziI/J+ISFjyCWcRZH6ZZCtaTlJ3hTptwLP
a66DGijiGUEqOP2qQUIRzwicld2ORjlFPBMoTX4VugqLtwoeqsX46mcWbw0o
n9ArDr0Wbx1umD5R6WMU+genELQ+
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10n8slGEcAPBzkaRbwjVljdLdJc2uzm/xfc696UaTmtr8RT8UZrjSsNm4
RVlLQxGXhVWKLVEa2urZ6JejEGOiO1zTyZEcTjqU933e7/bu3bPn+/18n1+7
z6acjONyOJyg/9/6n4klnFsbo/ap7gUJHSb8p2mDc4loHC7QsYideGvp2+wM
oCpfjwV8SP1NJAw3wqeu9ZjHFRmprUO6JWC8eVz50cxVDq0Sz4iHpfyF7Sou
Yrw5XBe2tS961Qox3m/86n3/5uj7NojxZrHA9elaRDYPMd4srk+T8RR9dqR+
Bks5xyRFPAdEp3cZcEZDfi1S8BHTbwrrk5U3Ry2cEM2XT+L4Qo3c0LaTeHrc
1pj9Qde8i3gTmK+P6uBfciXed/ygKJVKFewhng7vO/MsPcLkRrwxnKnY0lOq
FxBvFJepbLkVf0SkfgQfppSKn+77URmdP4THVVNpjhkH0Hm63wBe/dI9kDvm
icS034clltSwuFFMvB7s+qPu7rvlg6S+A3soFE0xYRKS34771vqnL1d4oUJ6
vhX/zZE5H5n2Rjn0uBZnBMXdE/r7IvaG3alf115n+aEqZh4Sr6tTvF/6k3Er
8ESOw7GjAciP8UGrNHLbzYFkvgN2HJ2uzLMJYtcHD73tNbEbg5EXs37oErvU
ZBmDUTyzP7hluBh/ohdQBbN/cBGKqdBIhHqY8wHNY47HSgNizw/Me+30AbZS
kj8Glk4FzckxUuLrwFFbbLCql7L3Aw6Wb18kmKSk3wS8CX/UuRIYwt4v8HlX
NC5ZIcSbhAJJmUzUEkK8KZALE7hxsyFkPQa4Efl8xU0gI94MpJfqfGtPy9j3
B0nLVQKvPBn6zLxPqJN3Wq81yNj3C56Gc3L4ytbPQWil+6DAgiL9jDAx3n1V
K6CINw+l2sSoEjlFvHm4s8lzMCmBIt4CZKrNyfn5FPEWIe3UbZV1DeuZoPgJ
8rFuY70lMNsfb6keodA/x964iA==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw103tIU1EYAPClJUqhJCpJ5WOaUiGs1Jo99p10m7NQ5x5qmTFCJU2xiAxN
lxW5WfSkpPlIRcsM/cMsX2CHNETN5XISFanznc/maxMVK+8994PL5XC+7/ed
c8+57udTJfEWLBbr+P9n403HMmbPo4HJtEHwpcKMaxUqo8fKHCRQYcKBkPVG
27YK+ZqNWMKPuerTJU6WSNu1EYt4Zl0l4BZZI9pbxGV/rwhFSltEews4dkZd
9llhj2hvHqtqHT309Y6I9uawWFY62SdyJp4Rr9/SKk07dhPPiO+OtFxqz3Mj
9bPYYB59y29jIyq9axonKm/42bnsIf2msL7vWuzlUm9E8ZoJHCkI+tMj3Ue8
37ikyUFSwfUh3hj+aVBZVO7lEG8E72roZWXrDxBvGI8GZVkdKfAl3iB26E+J
HLrpTzwDnktj21ipD5P6X1jo+CQ3pzoAPafyf2BzHYeTNHcUxVH9vmGdD9++
JoKHOJSvx7b+E7yCeEQ8HY7pzkvsrTpB6jtwf2m5s241kOS3YmtPgeliOB89
ouYbsVVM8f2gcgHKpsaV+La7LmHMJETMCUeF+AbY8UWohJ6H5gHudb06hIwb
YacPb/xTy0nEpX1odEtNtjCeIvMd0Ff1rDrALpRZH3gOHSoodA1DfvT6gfXO
qajbLRxdoPcHWR8fcpNsxKiQ3j94BdteXckQIx39fSC/ebEtalTMfD/gHDPl
6EURJH8Q1FMVKZ0vI4g/DEJLpbx4LYI5H/Cb6OHXh0pIvzHIVKeo0zQS5nxB
mz72mmeQEG8ChO3JW1PYUuJNAav4q+MZhZSsZxqsu7e8j86XEm8WOG0f9tfp
pMz9gxfBGocmSxn6Qt9PMHa2ql75ypj7Cwcrt0c3KGSkfh5aY5LPed+TkX4L
sGLcrPWqlTH/B4hdc++Mfme8RYiusU19sMZ4SxDGzuwQuciJZ4Lxsk1ZXJ6c
eGZY0nTGKc/KibcM2ywznnLT5egfY0W7FQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1030s1GEcAPDDijqt1cytWFOHmnejFzaeh7rsmEiR68S9EBMiF9WlWi1q
mfPS8rIsa1N3ZagmL+Gb6WXXEaVIJKaJ6HDHefmD8vs9v+/222/Pnuf7+T6v
OyVnw+KMWSyWz/9v7U/HIlRLVU07NNPIg4oFyLI4n9gsZOHTVBigTlxtffHQ
BlxWuhbzMMu5cLhduAV3dqzFHBRY9pp5iSwx7c2BvDGmWFdnhWlPD94Pf4qn
n9kQTwefs1LN1Q1c4s3CzSNCUOrtiTcDwdLQ+E3xDsSbAee8sukvHBeSr4VV
h/GV8nXumBreMQVGxqavk7gepN4kbI8esgpM2IspvnQCzPpbdQF9+4k3Du//
8u/lpHsTbwwaCrrEXOxDvF+gfLGkMLXBxBuFisFoMDT5EW8E/NStNVNpB4k3
DJ2qP9kFPB7JH4Rmu2yN0b4AXEKN7wd51ub+Sn8+jqXq9YL5o8gedmIQdqP8
HtimfNX2QRVMvG54npmVn7ESQvLVMKBKXvrqfpSMb4egq2jcKjEM51P9jVDC
LnZyqjyGr1FtFfi7yb6ZDh/HzAnrtCJtCycCV9D9SK7vuFHEP0HajWhAZuHI
TY/EB2gfVXs5+qcVCki/Gk14e1rPV55k5odidZ55JVVC7EnPHyWw+btrK6Nw
Ar0+lLTckqPNP4Xv0+tHgky+VXhKNO6m9wflPr3LsfWNYfYPhbaFFcaxRGT8
CBpUnNMkC0XEH0WfFAbBlVoRcz4o/I566+yqiNQbQw0uG/13BYqZ80ULM5ND
yQox8SbQO97b287dYuJNInZ8gEu9uYTMZwq1S0T2UTwJ8bQo8LKmNeGShLl/
qEZ2y8S2SoI/0vcTZVzPha7vEub+omx10QPleinJ16EF1cCZMVcpqadHj33r
Q5ojpMz7QKXpKXsEcinx5lBb35ve3+VS5n0hu/wlhaKV8QzI1cTeSfaD8RZQ
qu+T1JfLjLeIcMpYuMwyFv8DlzC/wQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wlIk1EcAHCPsii1DIu8qI08ltS8Sul6z5wHLrJ0aVqmqZvHpvu0IgNb
kUkHEt3MEPGYWkLNJktF8SVLZOIxnUmmkbZyXqjTpW5YlN/3vj98fDze+//+
72SkiKP5VhYWFsf/f+t/KlZRXtXfu4tdJuBPxgqKd9g7GfBgCxSQsYyqakxu
ETcd4auS9fiNNjZaNvi6u8Ke7vUwopHa+nQ1kwkpz4hkwzltnKsekPKWUIcv
0fTc1ht7iyiTse16p4GNPQPyKmbaH3vhh70FxF5zt565dAh7C8i37FnTYHwQ
zp9DXJbexHp4FJLDu2dRfUx/Mt94AtebQfP7B80Vp4MhyZdMoVbBrGqEE4K9
ScStXuJkJIVibwJx7SJFveXh2PuJop3N3IKtkdjToVKlR2BtxSnsjaMdbOlT
Jj8Ke2PIyhWVvfQ+i/NH0dK7+EKX1mgoJccPIxvGfbMmlQfTyHpDSKHXb1Yx
YqEP6WuR3fxiJTTGYU+DPm/6Htn3JR7nq5Hf9ltSdvcFPF6FroTqFNe6EuFj
sr8ZsaRhqwF9SfA22X6DDpY80Y9OJ0P6hE/ydqtls5dhOdUPBpx6TfLpFNxu
BtLgMInhRyoMonywdsfmq0ybhvvVoOx1hX1CC5+eHxit9CkySwUwgJo/WJNF
KDqF6TCDWh/w7RHU8fwzYCm1ftAf4MkomM+AGmp/wBGvrhReeSa9fyDum1bJ
DMvC48dBC6c6NGo8C/s6IIJtsQl5Qvp8QDDHg6U1CXG9CVA4NlR1Jl9Eny/Y
sPPXe+GcCHtTQFv5wa3lYjb2ZsCfPnWdRpWN5zMLPvbqDgTuy8HeHDCy92Tm
SnLo+wd2WY7dMA3kwF7qfgJll0EOmWL6/oKe2o63cpEY5y8CQ8O55hqFGNdb
Ag7thLfEKKbfB2iUOOaHOBHYMwJlTMG9osME/b6A/JGts2c0gb1lkGY+7xIu
IrC3AjSfirstiwjsrYJE63aL3FIC/gOnAMTn
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw102tIU1EcAPC1Hh/sgUVftEyGRq185SMq0XNmlMtE3RIZ5pwsNRVNp3sI
ZZi2nJq6VGQzX4xlm+UHEXxlHTVIDZVpqCSBE910bsmc0/khqLz33D9cLodz
/r//eTKE+dwMOo1Gi/j/HfzJ2Ec31wt62fF0GEKEC1k+XutWzZ+BmUTsodqe
zgrdWS/YrD6IXWTXpQgT933g9NRBOJHG9kzK/sSEpOdEni+ylmOWArG3g7hu
kWfeBIRgz4HqDjGYlzqvY28bmQ8HDVTxbmHPjujFCvp4TCT27KjRnl7FZLFw
/hZS81ujK8tuQ2L4lA31CYCv3nYH17OinJY06XIZGxK82oI4Tk6znn0fexuI
n+/gt7LisGdGmqGWEv1AAvbWUGzXxJImj4u9VdRVPtyayErE3gryfvs52CMs
CXtG9GVh6aXlHg/n/0LdQYy4sNJkqCLG/0RJ5dNXBhZTYDpRbwH55QX3xMcL
YBDh/0CC/s2HuY407BmQ6dhgQ02MEOdPol2RQ2fqfoTHf0XfFBX1cx4ZUEn0
D6Lt6KfihOpMWEq09chDMuzy+vsYUiccN1K4YhJlww6yH7gplP1ZxhzcHgSb
lhofTXQuvEH6QP4qPHxdm4f7J4Gf9zvvP7tPqPmBCAPTV3m+AIaS8wejVt53
RV8BzCLXBwJifyvK2SLYQq4fpC74q7hzImgg9wdMaf3m9x4UUvsHQo7T+pum
C/H4FWC8wLgrAUXYXwUKBnfGoi+izge4G0v6eCfFuJ4Z1M291vnniKnzBYLn
2UcWR8TYs4Crl3klY6cl2LOCpEVtbzJfgudjAyncCfVRrQR7W+CcjiPzMUuo
+wcYHLrwlK8UzpD3E0CoOuGZKqXuL3DMK2cbGqU43wHkTYHmsXEprrcDYj+4
v99wSan3AULbq3fgRRn2nKA9OEpJT5BR7wvIh2qrBcUy7O2BdlNUh7xNhj0X
qJzNbWwbk2FvH1irRusNazL4D1rGwdY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw102lIVFEUAOCxZawULXIUhbT8kVuRoJLlcm4uQ2hJLuGSWrklKY7jOqMz
WlI62h/zhzWTgiVqapgKWoZ4DBGynJoQl8k9lzRNHMcc/0Tle/cdeDwu957v
3PVUgigseR+Px/P5/+392djF5xfaRl30fOLGhAEX8yxmplVWJIWJHTRzSnCp
97QnKuVe/MZ6L92DgYNORD28F9voZeVrlWnrSlhvGwOfVVje0btRT4+ls7Y2
NXxP6m1h85nE5sg4b+rp0CzatqGtiFBvEz3MugXSHT/qbWLFqzfzmcpAmr+B
58r6qyDtMmGGD6+jZOFEm0YUTOutIWKm8EprCGF45Sp2L4gI/1go9VYw3+iQ
vXA9jHrL6LCiljauRlBvEWVKgzjKJJJ6CxhfEmOXFB5NvXnskowHlw3coN4c
drWejDeNi6f5UzjjbeJwtfIWecqM12KJutuZZ5xAkph6Y8jbr7A3qkokrow/
gr5BighL12TqaVAhFL+OnU2h+UO4FNueJ6xNpeMHsDfqunFzyl1SyfT3oIcu
bEx7Pp3cY9rNKHz8UjNumkG4E/7RYmchmxeROrYfAh/WOY9NZNJ2D7wtvWY8
2CsmnqwPj3ICstSqLNo/BE7mIdPZ4mxufuDn73hbATnEnZ0/SOYWtc4Hckkq
uz6YrK6OGOrLJTXs+kF6c/SdtSiPaNj9gRc1aU5HBfnc/gHvT2j5SHs+HT8P
pT73Jzr8JNRfgE5NqJvgk4Q7H8iVKwIKgqS03jJEa6uSUt9LufOFznTL9DTX
AuqtgvrX0nHzpwXUW4M41VTT5G4Bnc86RMzkDoeHF1JvA747go2+qZC7f1Bc
z4s5aygkn9n7CX3m6JFxScbdXxAc+eplXSaj+VugGgy3rvggo/X0UFxjvGvB
l3PvA6Q2Rjo+kVNvG540fSxvzJNz7ws6TNDdvUVOvR3wDer/8vObnHoGGKg9
bcs7XES9XfC/+Nerwb2I/AOunLPJ
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtIU1EYAGDL5SMJ07RckGn5ALOU5swpcY5pJjkYpZWo1BQ1H5VTm2mb
c1ugMcFMzMeMHlsPJPAJ8xF5sHQmmGiZZGk6lTlTdM7NOaSX9577w+VyOP//
/efcc65nSs7FtJ1WVlan/z/bbzI2kUnB3NHP2A0ZRJiRzZZ9WafhIEwnYgO5
Cma6NUNeUF6/HSZ0M5Y+PfnAH34a2g4j8s1kPO1OOwlJz4hq1nit3/qCsbeO
1Natpr6sMOwZEO1H5CF0AmJvDVVvRcYPjJ7Bnh7J1C599oqz2NOj8Qhfn2Rl
NK5fQVLn6RjTRAwk0oeWEW2i7QjrPAf3W0Ja0fr1POEFSPD1i6gjWHCAz4/F
ng6FMeRTLVWXsKdFgifhatX4FezNo9KYTp1tZAL25lD/ruPulskk7GmQISiC
WaG8hr0Z5PPcx/8VOxnXT6KtaCeOdDoF1hH5E2g27uooW5YKU4l+48jPtlqV
wk6HgYT/BZUNSJryvTKwN4JYL5p6cvdm4fpB1CyNP1ax5wbO/4CyG4bbotxu
wUpivgvZtNS9C9/Pg2Ji3IjUX8OFmiO5kDrhWntv7uuAPPiMnAfBE0m9rNB8
PO4CRn2lJBHehiGkD8qV939bQz6eHwSaTD9O3qkCan1AfZQuC/W+A4PI9QPd
nMKdbVcIM8j9AV67nrs2XQgfk/sHYxF/PQffFMER8vuATXPDn7fZd6nvB1K6
SjirhwU4XwPOvS8SdXwUYH8O1OxzditPF1LnA+SWyzlmixD304KAhSZm7b1i
6nyBsNHi7EATYW8R5Bc6uRoFIuwtgWqub/vqkgivZxmgTCH9UVwJ9lZAgSqE
n68qoe4faGeWiu3sxXCYvJ/gYRWdY2KIqfsLlGoPHStJjOsN4FfrbLGDVIz7
rYPEZu2C/KWY+j/Acg9v3mWA8oygNlbAVWgpzwR+On7vzaBJsLcBPivrA2Ue
EuyZwXBC55R3mAR7m2BqzDEqPk4C/wHQhcOd
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw103tIU1EYAPCpqKUlmGjQi0YUmamFZRPUc3z08DENbUaRpjJnK5/5ypZu
u5oV/rGRUM6WG0o+icTAWoWHoTMt3y6dYTibzMypU+eTgvLecz+4XA7n+37f
Ofecy0zOjEmxZjAYAf+f7TcVG0if2vw9nrUL+pCxjvSLEbbNtgchj4w15HGI
XcHnHYNVsu1YRdmpDkNf1F6wr3c7LIjRppWkDPhAyrOgkCfzhGspC3sryKWm
3G6sNAB7yyhDmPjRMS0Ie0to1pSoTAsOxZ4ZRbgHWyWEXcSeGbURrkyrh+G4
fgEpp8/X9myyIZnea0JaPUsTMHoZ95tDW+42RXuGYiDJy2ZRi+Sp7U7zFez9
QtxPDtETZ69iz4jAcJwu8tU17E2j2ccuaoegG9gzoOMDz0zPHW9ibwpxwuEz
qU0S9vToMyffub4qGddPoNg6cXppBBdWkvnjyBDVYHfYjQe5ZL9RZJ8VqtZu
psJTpD+CFqNuX7qwysfeIJqvfnE62i4N1/cgX01X+x/3DJzfgb7pwtrZXllQ
Ss6rkM7Mq/kdmQ1F5LgReXat2mdm3IX0CT8qU8ZxpDlQSc0DfTFX59qSi8cq
MDO41hryNQ+yKB+8nFb41k/m4/kewB+rrYydK6DXB7RHPfhtpnvwDLV+kC9h
yRU/C+Etan+A2d9tDuq9D+XU/sFujaz6ZKMADlLfB3S+CXWGhQ/o7wfe2atG
FP5FOH8KKJhEU+1KEfYNgGEM5/ZUF9PnA/ilH+IaAoW4nxEoc8a3jCNC+nzB
pLwkXuYtwt4scGqaMcizRNibA3esT3BiX4vwekyg20utdDKKsLcANGWB6Qf2
i+n7B/zcPCWaSDHsp+4nSBI39LEFYvr+gpK9LT9W6sS4fhl055YTSwNi3G8F
SE07ugRrtGcBfukLgR37COxZgOCvKsHiT9D/F/B+P6M+F09gbw0UdoqFrQIC
e+sgRDqVV1ZJYG8DFBy5XjH8loD/AIz1yCo=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -7.617622941414896*^-17}, {
          20., -6.168870547596518*^-16}, {30., -2.1247127717618755`*^-15}, {
          40., -5.181055699554299*^-15}, {50., -1.0487294710107414`*^-14}, {
          60.00000000000001, -1.888465868862194*^-14}, {
          69.99999999999999, -3.1279269074116296`*^-14}, {
          80., -4.8288290353787796`*^-14}, {90., -6.930741130043354*^-14}, {
          99.99999999999999, -9.104581202627837*^-14}, {
          110., -1.0730489085740703`*^-13}, {
          120., -1.1300160518386083`*^-13}, {
          130., -1.0962724158104481`*^-13}, {
          140., -1.0408911975591301`*^-13}, {
          150.00000000000003`, -1.0302831808846029`*^-13}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -8.454478436587665*^-17}, {
          20., -6.850061392168347*^-16}, {30., -2.361207671676738*^-15}, {
          40., -5.76341371684946*^-15}, {50., -1.167785805648643*^-14}, {
          60.00000000000001, -2.1043938740225124`*^-14}, {
          69.99999999999999, -3.485128035542445*^-14}, {
          80., -5.3686421177827275`*^-14}, {90., -7.655255320369455*^-14}, {
          99.99999999999999, -9.901679065616847*^-14}, {
          110., -1.1291052111962713`*^-13}, {
          120., -1.1136050815623953`*^-13}, {130., -9.56494309072466*^-14}, {
          140., -7.378613890708896*^-14}, {
          150.00000000000003`, -5.341491343173*^-14}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 4.633896384328014*^-18}, {20., 
          3.879933709006848*^-17}, {30., 1.4420900368703444`*^-16}, {40., 
          4.008049911542339*^-16}, {50., 9.864011513847432*^-16}, {
          60.00000000000001, 2.279282005192402*^-15}, {69.99999999999999, 
          5.0687327036084456`*^-15}, {80., 1.083596804045226*^-14}, {90., 
          2.1849062920072655`*^-14}, {99.99999999999999, 
          4.0393144486906276`*^-14}, {110., 6.647741215081673*^-14}, {120., 
          9.533495016262095*^-14}, {130., 1.2025552389624387`*^-13}, {140., 
          1.3783361757442085`*^-13}, {150.00000000000003`, 
          1.4866788907719942`*^-13}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(Prx) [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: Prz/10, Blue: Prx, Red: Pry\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.005337793734762674}, {20., -0.04324118644511588}, {
          30., -0.14901526292127396`}, {40., -0.3636310951804765}, {
          50., -0.7366695522281994}, {
          60.00000000000001, -1.327756370992641}, {
          69.99999999999999, -2.201313143700211}, {80., -3.401672154347022}, {
          90., -4.887456669534976}, {
          99.99999999999999, -6.4284764144221676`}, {
          110., -7.590187143222143}, {120., -8.017007168036681}, {
          130., -7.816788446960017}, {140., -7.479519629848509}, {
          150.00000000000003`, -7.477510581138197}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -0.0052953828811668005`}, {
          20., -0.04289720909312445}, {30., -0.14782610543041697`}, {
          40., -0.36070298791797917`}, {50., -0.7305861209868905}, {
          60.00000000000001, -1.3160523333479688`}, {
          69.99999999999999, -2.1787760772260607`}, {
          80., -3.3551884208894625`}, {90., -4.782633401518856}, {
          99.99999999999999, -6.183428628892167}, {
          110., -7.046180015843341}, {120., -6.94088551203836}, {
          130., -5.948586956444645}, {140., -4.571922062108363}, {
          150.00000000000003`, -3.288887738297687}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 0.0001078879265068756}, {20., 
          0.0009044242998183355}, {30., 0.003370001433802155}, {40., 
          0.009398734486649924}, {50., 0.0230615190086034}, {
          60.00000000000001, 0.05299572729085213}, {69.99999999999999, 
          0.1164876335166738}, {80., 0.2448726695386373}, {90., 
          0.4853171458248351}, {99.99999999999999, 0.8837096747842932}, {110.,
           1.4339511542083534`}, {120., 2.0355931160366385`}, {130., 
          2.5504639631447863`}, {140., 2.9097836317508468`}, {
          150.00000000000003`, 3.130208345671203}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kbT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox[
          "\"Black: Ur/10/kbT, Blue: Ux/kbT, Red: Uy/kBT\"", 
           TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{{}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -0.15999999999999998`}, {
          20., -0.15999999999999998`}, {30., -0.15999999999999998`}, {
          40., -0.15999999999999998`}, {50., -0.15999999999999998`}, {
          60.00000000000001, -0.15999999999999998`}, {
          69.99999999999999, -0.15999999999999998`}, {
          80., -0.15999999999999998`}, {90., -0.15999999999999998`}, {
          99.99999999999999, -0.15999999999999998`}, {
          110., -0.15999999999999998`}, {120., -0.15999999999999998`}, {
          130., -0.15999999999999998`}, {140., -0.15999999999999998`}, {
          150.00000000000003`, -0.14999999999999997`}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., -0.2999999999999998}, {20., -0.2999999999999998}, {
          30., -0.2999999999999998}, {40., -0.25}, {50., -0.25}, {
          60.00000000000001, -0.19999999999999996`}, {
          69.99999999999999, -0.19999999999999996`}, {
          80., -0.1499999999999999}, {90., -0.09999999999999987}, {
          99.99999999999999, -0.09999999999999987}, {
          110., -0.04999999999999982}, {120., -0.04999999999999982}, {
          130., -0.04999999999999982}, {140., 0.}, {150.00000000000003`, 
          0.}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(F): Pos\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: z, Blue: x, Red: y\"", TraditionalForm]}},
       PlotRange->{{0., 0.}, {0., 0.}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {967.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.499083277519418*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P0", "=", 
   RowBox[{"1", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";", 
  RowBox[{"Pf", "=", 
   RowBox[{"2", 
    RowBox[{"P0", "/", 
     RowBox[{"(", 
      RowBox[{"c", " ", "\[Pi]", " ", 
       SuperscriptBox["w0G", "2"]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{
           RowBox[{"x0", "/", "w0"}], ",", "0", ",", "0", ",", "s", ",", 
           "\[Lambda]", ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "4", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", 
       RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPryT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"Pf", " ", 
        RowBox[{
         RowBox[{"CprG", "[", 
          RowBox[{"0", ",", 
           RowBox[{"y0", "/", "w0"}], ",", "0", ",", "s", ",", "\[Lambda]", 
           ",", "1", ",", "0", ",", "R"}], "]"}], "[", 
         RowBox[{"[", "5", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y0", ",", 
       RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.01"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrzT", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"Pf", " ", 
         RowBox[{
          RowBox[{"CprG", "[", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{"z0", "/", "l"}], ",", "s", ",", "\[Lambda]", ",", "0", 
            ",", "0", ",", "R"}], "]"}], "[", 
          RowBox[{"[", "6", "]"}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z0", ",", 
        RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.05"}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTx", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPrxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fx [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CPrTy", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"CPryT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Radiation Force, Fy [N]\>\"", ",", "\"\<\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPrTz", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"CPrzT", ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Radiation Force, Fz [N]\>\"", ",", "\"\<\>\""}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], 
        "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kB", "=", 
   RowBox[{"1.3806505", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "23"}]]}]}], ";", 
  RowBox[{"T", "=", 
   RowBox[{"273.15", "+", "24"}]}], ";", 
  RowBox[{"dx", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrxT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], ";", 
  RowBox[{"dz", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{"CPrzT", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "\[Mu]m"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrxT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrxT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrxT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPryT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPryT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dx", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPryT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"CPrzT", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"CPrzT", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "j"}], "}"}]}], "]"}]}], 
        RowBox[{"dz", "/", 
         RowBox[{"(", 
          RowBox[{"kB", " ", "T"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "CPrzT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UxP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UxT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Ux/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<x0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UyP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UyT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uy/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<y0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UzP", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"UzT", ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Uz/kBT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<z0 [\[Mu]m]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
     "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.499064453718556*^9, 3.499064456764189*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"CPrTx", ",", "CPrTy", ",", "CPrTz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"UxP", ",", "UyP", ",", "UzP"}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1lQtQlFUUxwEBySAUFiVYDZMZWCUtRTD6rkd85ANGkdCsgSmaMWbURjbp
ZWj4rkZHZlYHWBnAXEzSQBMfTN/lrDwMFZCXgoIKW6QoD1tUBh/R2e/e7szu
zs797vnO/3/O+d3Jn2yMX+vi5OS0lj6OX7E6cVtN50H7pXYlcX/F49DEO5hl
vti6NKxTOT9p14OV529jeGZLUDi3KbrixV2bdbdxWWB3S0dut2JkY1qPpN7C
vcNJG90b7il1tY7VgZdOHSu992GvYtACduBHpwfytgc9VBzRJu1qx7IW02D6
fLtCwSjiTTQV3PExHHikzHWEYzdxXX+2csJvSDHnONYNHK0bLkq7OKw8CXUE
bEM3q2t6cOFzJV5LsA2TXQP6tpaMKFp6xa2YsnPf0jCjs5YdfWFmypTyav0o
9qm2ruPHM832oVZX5lC7v+IampZ7v/prvjvT5E66htbq5MQVqR7sW01wC1Yk
Z3TVLRrDRLhmjCh/5lIY6MlmaasZf1hw+EpPrxfL1AI2YYT+fM6aUm/W65D7
oBGb9NMSZ50dy5Zoghvxb9uMuON7xjGLI9yRBuRvhCs/x/gwUY8G/M3TZJgz
4sOE//XYvWp17Tf5vkx7PLUO70JIer5BxzQ7QmsxqjdB73xIx2yan5dxdFhT
bsg/Oib8u4SxpQetbQY/JvyqQc/gk+2TF/hJf/7AhAlfLEx+x0/6UY1B96/N
XT7Oj2nhNldhyWN7xEiljs3U9FbinPkwoz9eJ/VdwKObMlc/475SjxWTZi+8
/Jmbr8y/HJeu25RlN/jIfFXc8CQy0Bw2jmVr+ZXhV8Elvc2vjGUeWj7ncPaE
xe7NFi+Wrr2/FK/GnM4bsI+R7zuFWyP3ODV4esj4xdhu9njv6pCrjFeE63c8
e2otc2Zfa+ct2H+oejyeeq6c1J7Pw4llmf1fnnusZGj7B9CkW9F2NLhP/t+J
sVkBNaboW8r/E1J6IMR9yYbo3+U+xGzdd4P2VXke7q7x6aLzqlXEh5Q1T+0U
X+5b4DW3qEB6v1og8gNzvPKC8uPi+WLw/jduFeXPHwp98IGt1YX0cZF/KXxn
8TxM+rn0B6LfKvIgf7j0D7yMf/WRf1z6C4kRRj35y6X/MDXkZDb5z2V94JeG
HVeoPlzWDzoMTe9T/Xi4qC8MTN/+JtWXC/+rIM0/Yg7Vn1eJ/gCvMP951B/c
U/QP9MedWUT9wxNEf0HOlL4O6i+eK/oPQhbWX6D+452iP6HH3y2P+lPmWwvK
y9smUv9y2d/gnxazhfpb5l8PqQeNddT/XM4HRK61TKX5kHoawLsmitH8cDlf
MOA2bSXNl9TXCGdmBCTR/HE5n9A+c8shmk+ptxneLoito/nlbWK+IWN4ryvN
t9TfAidWDdlo/nmQ4AMc+7E8ifjAJT9gVGR8APGDS77Ag+rKQeILl/yB15PC
kfjDJZ9gvLp7GfGJS37Bjhe3+4lfquQb1GTkbSG+qZJ/kOe27jjxT5V8BFv2
n4z4qIp5vwkv5bvriJ/qbsFXMF7OeUR8VacK/kJPdGs+8VetF3yGwunzzhKf
VeH3LfipsyKV+K1KvsP37+qvE99VyX+YmG+bTPxX5f0A6++XtNH9oMr7AwZ1
n2fR/aH+B30HI+0=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw1lX9M1GUcxwk05KBSOe5qOpRp80D/MKn1Y9+nTxuGt9aaXOC6abgdEy4z
A5aNtAWmMpYt0JqoKVCgG7JhTkDS5/GDggp23vh13YnHj6RkiJKMRNlkxT2f
T8/G2O35ft/fz/v9fD6vJ8H1qWNLeFhY2JbZv9B/WkOY+b77zt357cam0ssP
bZsGMT51YCL8T4/RHL9vLK15AHOyXmpfndJlmOvX/bHTPIDOzVHXJkt6jTxh
8lfn9uOD/IRn7q8PGDc8oRXEx4XfBe21QSNRCwZx9MruVWs7h4yQWvy+W/jv
2+meyp+HjVmxWcU+vJBxYvp29x3jzZCc6MM935cn3su5axw9Elo3MSb1rUGL
e9yYsoUEA7imdE5T4bYJw6ELDODB5x99XDU4aejy6v1YNjny2FI6ZWg5kx/9
rrzc1l3TRrZev+P54Ec7Dp14YoTcll72YaOzoaJxbpjQduN9eLYsMj/P95TY
pQ33Ysmin1YntEQIkuvBRNdv9qTWuSJZrx40fxgzarsVKcq0YDd+PvP0xpEI
k7gXsjvWhZ6Klaecr8UIuzbche+8vsdekf+sqAnJVXdi5MHsFeEb5gs6j06s
wdqx/dsXCMrfixdcRnbfVwuFfjz3Bn5iDySVfR0rdBw2D+bUJW8z7zCL2zrP
61ieObrsZFqcoPw60BadsTQ/1iIor3ZsXewor2u0CMrnGkY5x9XJZKugPK5g
w+aM9n9KrELL7WzDrI6/fiw6YxVrtN9WfPHdAXddrZX9XcKtRZUO93Yr+2nB
goerUjfMWLj+i/jFN68s8adbuF6Jvv5Ha5d9FicO6/p+xaiJ6ekPNprFPF3P
Oew+VXy2ODpWfKm/34Cyo/zv08UL+Htn8OYbBesPVz7H+vX43tVDrkJfNOvV
4v7TaTPHmiNFgX6/BjOrFkctTI8Qv+jnK3De1hSn1z1jFOn9H/D48DlXtXeS
f+/Fb49nrGu5P2z8PyFzxg+8kLJo+au8D7wv+X3g92UL6UMc6fN+DWTR91UV
1QcHqD5Fz9eDg+pXD8gfDJI/RfU3wHnyrzgf4HwU5wcmyk9xvsD5Ks4fOH/F
5wN8PorPD/j81Mt0vsDnqyj/NuDzV23UH9BE/aFiqH+A+0elU3/BJeovdYz6
D5ZT/6kh6k84Qv3J9XqA+1dxfwP3N9fvBe5/xfMBPB/spxN4fhTPF/B8sb8u
4PlTPJ/A88l+eyCW5lcFaL5hBc03+++FvTT/ainxAeqID4r5AcwPxXwBSXyR
zB9g/kjmEzCfJPMLmF+S+QbJxDfJ/AMT8U8yH2E38VHSvPdBE/FTFhNf4Qnx
VSYRf2GE+Cu9xGeYID5LyrsfpojfkvkOzHfJ/Afmv+T7AZbQ/SD5/gC+P+R/
8rMqng==
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw103tIU1EYAPBNTZYzH9Opi5xpipYFYlrq7vHksEwkJUXRzD9KbU4DIWah
FWuODKNs9qA0H0EY2D8tKR9YHMnSluYjH2i+00RT1zanm8+V95x9cLkcznd+
33l6XsyNz7RgMBjg/7fzx2FETVJbN3f2KnWUDgPyYUSLTFkG6hIdq0jsE9Tc
OWOkyst2YgVZ3+fvLpStU987d0KP3tWwBRnCTQp7evR866CM6b9NvGUUyb0x
9tSDAbCnQ6F5wuPyCCbAnhZlC/u44psWAHsaJIrvDZEOWALsaVB/apTbWswu
Ml6N3EWK34u/rAGd3rmIHivEdocrWADXW0Cx9nVx7HwbQPNl80iaqRzgFtgS
bw5VnRn+9qrKjnizaORjgCrwigPxZhC/K1x19qUj8aaRJNDTomecQ7wppFe+
tprkOxNvErm/DfO6nMol40eRfVLC9dFiF/CMzh9Gjy5w4jwrXUEGXW8Q9ftN
RPkXuYEA2u9DH8ocIwxBPOL1IEtJwzVBOY+MV6EE0c+TT2p5JL8ViSPT7wyl
8oCC7m9CDXX8xCWlG7hFt2tRXn5jW7XSFZhPWFY5IN8Su4AXuB+eaNnoiNY6
k3YTDE/uTrZKcwIh2Ie396fc/fLJkfSrYOhIG+tNkIN5ftDUfap+SLoHBOH5
Q8p6bqJ5yAZk4fXBexMyk6iABSrw+uGgx7nGAxnWoAfvDzzkTXFqFFbm/YMy
eW5RjNGC5E9BuVDl2/aQSfxpaNwnqeMnM8znA2PZ+zuKC7cpXG8WMnzbkmQK
8/2bg+PHMizTetYp7M1Dtcm2ICJsjcLeAkzPZo4ttRsoPJ9FuBnnkJ8tWSWe
GrKCg7+2CFaIp4FKZo5Vy1491YXvJ3xwdUPQZbdM3oMW5q2ZUj5zdWS8DrY3
cvh9R7Sk3jJUj55n5yZqzO8D+nmfDpW7/CWeHupKPRFVsWR+XxCUDP1YCV0k
3ip0Kqmu7136QzwDzLH1bvWqnyeeEXI474vSS+eof30PtmU=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxNlQtM01cUxhkbsjG2oGncpqwwJ6Ewx+Y0EBnlhAk+AhMBiQxYIgx0gY3X
FsfDYVUsoDiIkinFiA6kwEYtD0VUOMqKIAJDqC3PDlBAbNmgUKLTsPU+THaT
pmn+t+d/zne/73ffi04MjrW0sLCINX/IN1uj2BnWHRbRlYCR+S0mUeSfOPlp
hc9ipQSvCo/qg67qMNDyhLLC9jgKFFvH0gU6XGqfcMo9cgqTxTba0qQRnM5z
8Wv6SoZdnWQN45U5O3WJwwV0oQWHMcxzw9Kvpy8iqSY8OoQ2GkXby/IqNBcz
VxzEye7XgxI/VKI3KScexKcu10Swpw5lRWQNoP4H91WZxiu4KCIF+7GoWh+e
8/gaBtMG+/HyzHJV3A5E2p5Ci4IvrcZGl7cgLWejxcqdtoF3G1S4ly4NPpe3
jr9b3IZk2vyW+/j9WWlMYVMH0nGF9zHW3yU53rEbM+jAalxm7d7gPN6DrFwf
GhyrgsrVvbiBrj60Lh3+bs+UGgtowV7UGCTV8ne0aCDj6u9hU/1PfvFxA7iN
DnwPjx021m/sH8IyUq60Bz0P+ymdonTIzqMHY/yb/844NMr178by247rDo6M
Id2e1IWbFtxTBJsfIJVD1ImFFc65WcqHOE717ECV1ENieH+S63cHZ0okEz7F
U1yvdgzpcLu+WzDN9WnDuM8+FjzMe8z1aEVN9BdiqaUBabl0Feb/8++urpQZ
/ITO+zsGnRKth6G/+Hy38Gtle+Ml+1k+z01scTsTGtE6y/tvRtNmq9pv9s7x
fm/g7WU+WQ1Lc3iG9teIyfqVYvsTRnyV9tOAn2dPOB23m8cD9P31OOyq9rXO
mefvq8E1Do8sKo3zvL4Cf27NlJwPXOD1KjFhNK7Z49wCptL/l2Hp6YQQ9cgC
Kun+c5j52jPjkzdMKKHPC7Hx7lPZFrcXv7NQGGrY/6O3CV8kZM2hKfqbP4fV
Afr/7S+EiL5xWu8mqw9+RQH0fex5GehfAtrPedYfyKe30X7ZfgWsW1tB55ll
88EHhlw6L+u/HmJ0BVQPrg8crGnwInpx/cBhpfYI0ZPrCyfTCmqI3lx/qIt/
m54HPx8QD4npefHzg4SS5x+R89zIzheK5U0h5LyZ/ioQVFt4ET+omD/g2023
VhC/2DL/gPPJykbip13MX9CZPPGA+O0s8x9E1kgziR9HmT9hMD8qm/iV+xeG
7SKTiJ+5v+HNi+tdid+5/yH22PUZkgeeD6h2XPUbyQvPD6Q3/6IkeeL5gpG1
9j4kbzx/YCWeqSB55PmE2nyXRJJXNm8fhKYMBJA897N8Q1He9lqSdza/Gp5F
2+8jPHBkfAD3qO3hhBecH+B+KaKf8ITzBXT2ab6EN5w/kLQ7QEN4xPkExt5w
BeEV5xdM/mHyJTzjfIMAtfUrhHecfzC7L2wF4SHnI4i8DngSXrK8D8LlObGM
8FTK+Aqy5rQewltXxl8I93+rnPC4m/EZbENbH90w85rpPQIZVcI7OWaec75D
3c7gRbmZ95z/kKrTSk3m+4DfD+BQlR0fZr4v+P0B+8O3Plmd6uH9Hx26bQY=

         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJxVlX9M1GUcx4HOTajQQPot2dwKamsrFaiAj279cCUxWBgyt9AdzT8quFHJ
sJkWGis2fnj9EMzYQIGCK+jsuGC9kY6AOn4eCAGnZ+mRog3wgBbLxT3P+/7o
2W632/e5z/fzeT/v9+t5cG9uek5IUFBQzsrH/62XB8GLuReWG7Owu7RzIWb3
BWyzj/Ue3PUGWqOPzKS1nofZ2JIzl1SAdZbnLxauO4+mD6pNrQOHYUoKG6vJ
c2MgsSHWWlKMPqd/TSG+8Y5tS8lliFUFp2Dcueoj27QZ/mrRRybR4tswWpNZ
iZViKxUn8GrefZOejGok+8slTeB976LhvZs1qDzuX7/h1JfJOw1b6rEY4y84
joK5x7EmtAnpqsFx+K4+8LPp2Wao9ixjuOJbXqjKsUKVCxtDZq6p4vB1G15T
6xyWjw98UXW5Df5pSztH0R1c9sz6Rzugxo0exZ60g6801XTigBp4BAnZxbc+
ld0FXc6FVQ0ZoRuNPdiklgve4sj21JZfUaYKDmNH2NHEiJQBXPOPOzOE4L6Z
QUPVELargYcQs3xyc4jNhVp/uZpB3P1pg9v0zyj0eQxifcjIpg7jOPXvx1tx
Z5J6fRNQ2/P68OTr84/117uh5IhxosQb+lmcePC70vMXyNZpT4r9IvXrRU/F
9oeGt/5BvXpgN57bf8x1ifp0486X3OFrcr3UowuGtsgP89f+CVWu0IG9O16I
qrNewRNq3p9QcDPDnpo5w/nOIq2oMMu9dI3zdMD0w1rLJ6V/sf8f0fR9+tTg
7bPstx0VXe9khDtn8bnqz46++I3T5YfmsFr1Y8N336Sa82Pn8a56vxWNzRFP
ux3zfF8zzGdjV0em3WB9C1yu5K8POG+wXgPubfNG1W/xoUD9vxb2hbDyrI99
+FbtP4nnpmeWSpw+HFLPzXgzPeL6238Hfhchzp1wqSR8AYGEBH7zufx/v1kC
9Tp0fQm8Tz+vlXvYT7XuT4bZr95vkWOcZ1bPJ19xXt2/VZqpB/WRgF7UT8qp
J/WVgN7UX/J4HjwfSeV58fxkP89zsz5f2cPz1vo75Bb6waH9IVH0y23aP9JK
P72s/SXd9NsJ7T9Jph892p8S8Cv9Kwn0M/0t+fQ7/S/3Mw/Mh9zFvDA/8jDz
xHxJEPPG/MmLzCPzKZeZVz2vSwzM87jOt8Qz73r+EQnwYIPmg/SQF+SH/Eue
kC+yi7whf+QqeUQ+ySJ5RX5JIXlGvslp8o78kyLykHyUbPJS531CzpCnRzVf
ZR95+4jmrySSx/2azzJJXmu93WIjz8l3qSPvyX/Zx/uA94Ok8L7g/SGmSkfd
RHR++3/D0m64
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {GrayLevel[0], LineBox[CompressedData["
1:eJw10nlIlEEUAPA18c5WLc3VPTIyszXTLPBgmxIzPLJaQUxCyNRqIY+OP/JK
K9MiMwNLJckrQUwDwwVFfYOWruIFXphJ2nq7msfqmrVSft/zwfAxzHu/NzPf
2EXESqN2cTgcyf+x/WVjA3hBv3Q6nleDGxMaiO4+M3osGSCaiXW4F8Y9Zxyu
gIL87ViDs79TvTxae6GrczvUEOufWC2uHADWU4P4k51J08Q39FaBWxujkUjG
0FuBLL0e12BPJXrLME3lGcKYKfSWgNenq0gbnUVvCUINw0Jp1gLWL4LbVJa5
pHkJmPROFXwODxjqUa5gv3m4tOHjXe28BgyfPwu570sPbX7QoDcD9a+jjdsC
N9GbArlHY5LaXoveBNwyq+FreRzKekoQR3C50gYdynrjMNzuGBGeoEtZbwz+
ZqQc6Q/Wo2z9dzAobCtMOG9A85j8YXD24sRqpEY0kuk3CCt+gbdL7phQF8bv
gy1X4/i4YlP0emFA/vCG7jAX69tBln41ZM3QHPNb4HXXwgWTgxb0FbNeB+1/
LKDebS9NZeYVEJje73XZcx/d+cN72jJdW05Y0iJ2nbxpGimftLHCeR1pmbui
l7FsRd1Zn8R7WVhGyffjejuR5oy/1ZdZ7+yPhLf+8H9iyqMn2f0TfhLHM6iE
R2+y5yO1X1MVGkcb+o49P5EJgkLMym1oL3s/5EFA5KqRte3O/ZEhpxSZU5ot
5o+TL7L42JyftugrSVJPWe5hCR/vd4Jk+vb71+Twsd8UCXnaMz08xkdvhsQN
XqxyEAvQmyUK1V0rs3gBevMk+dop//UaAe5HRVpVLyuPLwvQWySJR+1L9J2E
6C2RIV/vpobrQtrNvk+idOkMe5EnpPh+SdRW9khFhxDrV4jH47Iin00h9lsl
jzZcmzMcROipyf1J99ICqQg9Ncl2d4wuThSht0ZOa50DGktE6K2TIp857W6F
CD0NKXWqGvw4v+NtED9L3rMR/QP0H6J61cI=
         "]]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.498306046055502*^9, 3.498909200037582*^9, 
  3.498909404574926*^9, 3.498924314880492*^9, 
  3.499161112194419*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1064 nm, w0 = 500 nm, 10mW", "Subsubtitle",
 CellChangeTimes->{{3.498306046654065*^9, 3.4983060503718853`*^9}, {
  3.500321849933041*^9, 3.500321853756118*^9}, {3.500356092599565*^9, 
  3.50035609383642*^9}},
 Background->RGBColor[1, 0.9, 0.8]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"RRT", ",", "PT", ",", "Ri", ",", "LR"}], "]"}], ";", 
  RowBox[{"RRT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"R", ",", 
     RowBox[{"{", 
      RowBox[{"R", ",", "0.005", ",", "0.075", ",", "0.005"}], "}"}]}], 
    "]"}]}], ";", 
  RowBox[{"LR", "=", 
   RowBox[{"Length", "[", "RRT", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RRT", "[", 
        RowBox[{"[", "Ri", "]"}], "]"}], ",", 
       RowBox[{"PlotFU", "[", 
        RowBox[{
         RowBox[{"RRT", "[", 
          RowBox[{"[", "Ri", "]"}], "]"}], ",", "\[Lambda]", ",", 
         RowBox[{"Ri", "/", "LR"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Ri", ",", "1", ",", "LR"}], "}"}]}], "]"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.4990657414254837`*^9, 3.499065773922699*^9}, {
   3.499065817477016*^9, 3.499065822517425*^9}, {3.4990663608275337`*^9, 
   3.4990663773893003`*^9}, {3.499066879366581*^9, 3.499066914857232*^9}, {
   3.499069974953237*^9, 3.4990700629519157`*^9}, {3.49907097271624*^9, 
   3.499070991527178*^9}, {3.4990716920544367`*^9, 3.499071717100708*^9}, {
   3.499072316055421*^9, 3.499072327391192*^9}, 3.499074027861108*^9, {
   3.499074233454485*^9, 3.499074233590016*^9}, {3.499079840994349*^9, 
   3.4990798779877872`*^9}, 3.499080153434732*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "13", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prx) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Prz/10, Blue: Prx, Red: Pry\>\""}], "}"}]}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "14", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Pry) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "15", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "9", "]"}], "]"}], "/", "10"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prz) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "19", "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
                    RowBox[{
                    RowBox[{"Nearest", "[", 
                    RowBox[{
                    RowBox[{"First", "/@", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "19", "]"}], "]"}]}], ",", "0"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Ux/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Uz*10/kbT, Blue: Ux/kbT, Red: Uy/kBT\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "20", "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
                    RowBox[{
                    RowBox[{"Nearest", "[", 
                    RowBox[{
                    RowBox[{"First", "/@", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "20", "]"}], "]"}]}], ",", "0"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Max", "[", 
                   RowBox[{"Last", "/@", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "21", "]"}], "]"}]}], "]"}], "-", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "21", "]"}], "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"Length", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "21", "]"}], "]"}], "]"}], "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "*", "10"}]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], "]"}], ",", 
       
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(F): Pos\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", "\"\<Black: z, Blue: x, Red: y\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "11", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fy): y-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "12", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "PT", "]"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fz): z-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]], "Input",
 CellChangeTimes->{3.500355939017991*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs0lFsbx6eTvuWScorkZCWUqM45onSZzXYORb7KpU4HoSS6fB25VUwt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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgtUjFsbx8f90AVJ8nGkg1LSPSfZeZwjEk6pI6pD6Cjx4SRCU0RXRCYU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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk4ldsax6Xx5N5UR3UobmlSuidK3dLS8uCkW1SodKQTpzToJEUT9kmm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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs41Nkbx0dtW+myT9HNRhdqlVaKTeqMo6tCNkqRktQk1FLpz7ItEqlV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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgdUVFcax6kylGE2SnBhPcSIFHExWAF9Lx9ZUYyuRrAsUhQIRUoQRVAR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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgdQVMkWhokSBCSn0RUXEzzEfaL7DPfa6IqIAcWECV0QEBUJuisIBnSB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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtYjNkfxytLoxtRiXRvEkotkXjPHmRF+fsrSUthUdmlUv48to0uSMV2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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgdUVEkWhhsJKsqSQUGSSGyhWxZxXF5RMONgXNOOrgmcATGtIMlZQWDE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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgtYjNsax1MqRiRlU0i33ZWkqZlj+9Ze0UnuVJSdZES0cZQOdqdoh8pp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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs4lNkfx3XdP+UWktWSMGQlt6K8x4+0sUoXbTYt7SZsd5fHtrls2aL0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          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk4ldsax4mrNCiHVDdtaUJdUVsafMsy7E0kUZ3SJE4pRzk0ZzcckaRr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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJwtlglYjdkfx7NUhExcFZlIi0SWQvp7T+e23Xvr3uavLJNqRE0ynpAtaQwp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          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs0VdkfxyWKYlKIFOklzITIK2e3PUNuufeO/2iUVjQljcpf1HiOSjW9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          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk0lVsbx0klw1WJIjLdFJqEJN59H0kdknsN55w0oUHDrRu5lZLvxv1M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          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwtlgdUVMcax4FQlGKjGgkksUCCvqhY4Y6DSLEgSlvKrggKKMZHER4gCqJB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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs4lGkbx2err02124axvg4qSbSdpG1lnrp1EOkksRSjzZIohbClbGql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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgdUU9kWhoNlEHniiMwoFhDH3hFhUA5s0AjqsyHDgEwQG2AfsCwReDNU
HbGAiqA+LBAB22BQFGIOnkhHCEmQqqKU0FtIwkMsOObc+85aLNZdSf6z///b
Z59rtvP3Ld7DOBxO2rc/7X9JqXZpyK1wl+ixxk02MTn9c3jRGjKFO+jtNLvd
ZkuWSWSns4ZE7rSLiwtV2vyQ5tQQaKQhOtIFg+vj+m2q+X62o6vVZBN3BrfL
7LPNtavapSZhzh47HLjDEC9aK6gmM3yO/2jN10Wm39SyTNTk0NOOUHmgAWoM
NPqmqCJDjVxPVex4dFsrx1eRJbUWyd6GxsjXR7tUZAUKipd+NkVzqaCKjJ96
OWit6wzU5awtsI+UPv9w3SRnLqLlpfWRm/4275QOS5C/Vs6vjzwcsC7SP7IM
LbPQrj6S4anP80tcjv43RyuoJMISD5ctOvaI2s1SkojQFar+jlUoSFteoJKc
cJPkVz1ag+y0crZKMiHZOuA/ERsRhy4l2WPi7bq+eAs6qbUX2UucRAssu/Xd
kD4NqJdU8XKEvfN5iMm3hxwevmOR7pwdiMmzh9wZ0Em2KN+NmPy6ycotanXA
wr1sXt2kRZ3mO+B6iM2niwgqSNgly8NoHs2ji3Du+D7SKTrG+u8kxx5MyInr
P8H67SSPbTiOIa/+QELqr4NMUSyI8kZhrJ8OcoQjebbwz0iUqy0vp53oiz7h
A3AardHKObUTs5iNBU5nziGmX9rI4e+Qe5n1BcT0RxtprRd4KDmxqIb2Qyu5
Eupf9nFmPPKk/FtJQArX5ePDayzvFiK6/Np5IOUGy7eF9F03sNlzOpHl2UwO
Jf1ZcOoLn+XXTDJm8v15j1NYXgoyor45c3TaXRRM+SiIq7J1OlI+QDqUh4IY
dl3kcOwELI8msk8xZY3r3EcsjyYymjcufuuKDJZHI+le+y+zYr+nLI9GUlOY
VCEtyWJ5NJAgk3OOg2tFLI8GovLaLDVrz2Z51JPdmSLBMhcxy6OeCOTVzkbk
BdpG/b8nVpU1BzWWuWgP9fuORKtMri1+kocOU391RBYTr3yyvID185YkPbMu
NRAXsvW/IX4HHzbyuMVsva/JbHjVuDvnJUqg9dWSSpfq9DjLUpRC66khVonb
nY2vSpCA9kM18Y7p96ltLUPPKP8qsilKd+YGAxnKo7wrSaVsMGPEVRkqo3wr
SPiukYq94+Qsz1ckJCk+/t1ROVJQfuXkQ1b6trdiOctLTlZ96TfTUcvRB8pH
RnwdAwYn65Wz50NGiseOqFuuU44m0nzLiPmxi+/Ta+WIfn1OKZEkVN9eckGO
7Gk/viRjpruKc2bJkTvtryIiDOIJ6r7Vx+RXQCY6VG4tq5CiEJpXHvnJ73ej
Y+ZlbD45ZKTVPJXbv0vRHZqHmBgZ6g0YznyJ6KNfNrmvP1KxNKcQ3aL5CYlh
dvG+hbPzkYz+/AnhuHeH/bI1Bympv3QS8dspo6js58ie1vuARIbk9icGZ7H7
3yYytxqHkqF0JKZ6V8kuYwtPYWoK+3kEOT71Vy+++UXEoc9HwbU3oMd8WRi2
p8+xsNj+YtaB2Um4nu6XCB3dK9+Ojn2IQ6jcXQiF3pXp7k/xLWpAAO3lB6Zf
f4ixH/19BpjWeEqKvV7gzcwAA1+3DacdbPPwNFovhtLAhNba9gLM8BDDH8ML
Z33yKsZtdL8XIFsRGq64VoJllHcufMzzCXoWJ8Fimkc+mGZvsonZLMV3aD8V
wtLLakOrXTJ8hdZXDPnPRor5n2Q4hPZrCZwt4WRF+Msxk7cEwqukpXb5cuxO
z4MUyoKFnvwBOWbOjwy2bd/X1KJXzurJQd92wde4L3J8lvIsh0WazVujK+Q4
guq/gl2d9290x8hxAPVfAZ5z1/WMsPz/fpXgeDNK1zlXhnfTfqmCieP8Ivfa
yTBzH1XD/EsRdR3OUjavGvAJh0w7/TLMpfOuFnxCE+VGaaUY0X58DYL5wk0x
UIKX0Hn6BvgL6nbczCvGTP++ha77zxs7HYrwFDof6sDr2NToMlEBpuUZvQON
bkcz1yofj6Lz5z342+x60J6Riz9/1a73sCrQQUe5IgfT4xVYD98v5L+ZViLG
GrpBPZxW15x9In3O+muA/cFX7WbPwriD8muAalMXi6wEIaZ2fRphUXtgWLFl
Jq6ngo2QnLvxwCh1Buu/CSynnckKrnyEqyjvJoicdPLIlToBm4cCYtaWjLvw
Yxqm46BUAdPLA6L08T3sSPNpBoefB1NL7qZi5rg1A78kVOhWd5vNqwVGVSQ1
ClyS8FPaji2g16Ka6K93Cy+l+bXCHrt+saT/v5i5r1pBNunoV96aK3gWLbAN
oj1bPsUMu4yTqOE22L8z9r7HlIuYypm0w1nHG/tPTI7GzHxuB/NTf52RXo/C
hlSwAzJTm+35gpP4PC2wA5L7DqacXx2OaXmjO0EoKxf3bwzBzHzthCR12AGL
kCA8RHl0gt7guNS1k46zPLqAtIiSt/96BDP3Txf0DDXfOz3NDx+iPLrhu59s
G7ZK9rE8uoFrPxTcv8SH5dEDO0Iyh/7euBMz918PwN+FY4Ybb8MelEcveDj+
VfQmxZ3l0Qu+jq4GB01+wcz7jhI29Da8cOZtxt5UTwmaTZUdYeHrMP06XwkB
9xbr/bxnNaZ4GpTw3KjIuNvaATP3VR+EWz9QVCXY4N/ofn2waF33tUsGVpgZ
V30w5rz7Qv/z5ph5n+sDXYnVda/a+Xg8zVMFQR/UISeGzcLUnrMKYlN0z9u5
mmEqF62CsLAgzthlkzHzfqCCM/Oyl55b/QPWo4JqiA74Gj/x0veY4nZSA/ft
TQsN1sO0vEg1yBNSY6Xtw/EL2k9qyFx/ib8vY0hEcXxVQ3lBEjc9bkBE47bV
wMrxd9tkBioR836mgd2PJzg1n+0UZdIG0UDP/SF/+z6F6B+/mMGt
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs41Fkfx8dK6arZRLJLeJNUUiqVo2N3vZRSuZWXxFYTJYzLvkWTa7Rq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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs0ldkbxs/RmCWmUi5RFllMoYZCTTX7eGWK0k13kuhChgoxQ1KpwWi6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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk0VV0bxxGFG7mZajWQfMIbXxkqvee0FV+GUpQGlTGaqJAG4kWGSgNp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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs8lFkfx0cXt0TjfhnjsvuKUrmki30eR1ahvEqtTSmXjVIJZXtLtbnk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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lWkbx5WUmIyQtFiO5ZxTTZt8ab55X4+vBS0yfJqUrWSdqcgySqZM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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs41Fkfx90q2S3R5K0MuQ5JjImt99n/cSRFJRu6qm1zTW+ble2yqd4Q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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs0lFsbx0d0hM7qpkS5JTIk4xJmvNtW+VCcBnVOF536KuIgZ9xKF+Ur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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lGsbxyepUFTSEZVQDfW1EVnO+3hmtEiLwglJSpa+tEnafGFaiChL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          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs8lFkfx0m5VPuWQhc1aVstba91L+s5HTLMhIR6297oqlpr25JUFpXC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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgk4ldkfx7Vn6V8h7Y0wDZOJLDXxHucW2S5uIjSkhBKTrmS0zd/eIpEZ
KaXJGtWQFsV4Twcp/6lLGFlT91pybXGXKRX17573Pc/j8bzPvfd7ft/v53d+
5125+8DWwKlKSkrFX/8U/+sEiiXHvYOhp//Nd6fOVf+r75Mix7Hn9Xz973tT
W8tWJAy5yvGNwRazgPjd1IJiO9FRTTnuAI2XV+QFUa25fKDSKsMLzkWonHHj
U5cyFEuG66uvn/Y/E0H5pCgEZdiTr5arveU49c1XtbIVMmy0OEumeTKW6j6q
+VVRirP9j/m7rzpF5SnkcqV4a/jO9BvbU6i9exRLis8ZZ9u52aRRBkRQijUn
pCG2iy9Rw66KAiXYytP0t0o6iyLlFUuw4Fdts5d++VSYQo4vwV3F6i3O5jcp
M1PFkuCRluJULavb1Dt9heAYDp7RtbGgppQidsvG8LC7uvXDnRXUMUV5R8dw
QalJ4ye9KspKIQfGcNSn9/6cgMeUElljOLJ3Rqh9+lPqhMJewihOCQc/wIgG
SpUENIrNbe3yx7nNbL5vcVH+pOaS0TY2z7f4Y5fgu5Vxr9j8RnCjZZRl+8Vu
Nq8RHPdzWcf082/YfIbxoqvZL29vGaK+J3kM42/uXzjdemiM9T+EzfKfyFMr
ZazfIazidEmr9cp7qpz4G8SWs5V/KNeeYP0M4lrf0zUnbimBR4ryqgdwn7hZ
bW3ZNGCvkLMbwPfkfb/I1s0CTL+IcVplkFhvgypg+kOMTy/v16oSzAVtpB/6
cfD7RKFOtDrYQfj3Y6+1ZebWYQsAw/sN9j1r9sWiahFg+L7Bl+tCBg5GLgMM
zz4cmDd+PNlZGzD8+nBOk871+AwdwPDqxcbhB7r/0vkWHCd8evHqjR3Ow0Pf
gSmERy/2aI9LdXv/PWB49GB9l/l+SbZrAMOjB4fWWQxsGDEGDI9uvDvxplp8
uwlgeHRjgfTy2rx+M8DwEOHOTLvmRK31gOEhwtZZkuLEgA2A4SHEHst/jOE+
twQMDyF2WOb77KGbFfAl/l/jIavOWNVIDggifl/hEG7RiFCwERwk/rpwVItU
fkffmvXzEuf/2W518KQNW38nHjcKb7/Vt5mttwPHSa4W5EA7kEnqa8dxwR12
Rqn24Bqppw1bbDwTJ33hAEpIP7RiPe3nNi7KXPAX4d+CIWfT58OrnEAN4f0C
H22Z9EnRdwb1hG8zlu1QVS5UcWF5/oMNlj/XG6h1Ab2EXxM+NmOKwVVvHsur
EU8EHbzuXsUD44RPAza82BA1KOcB5nw0YL8L0XW3pDywiORbj7s61oEjD3iA
fF1fgEOTL4jvc3iAQ/rxKb4Y6md7KskFeJH++h8+5XcjsS7Dmc3vCeYY5Q6b
BzmBaJJXDV6atMTdcdyRzacai4K50w9xHUAhyaMS/ydLPvbZ3w6QRz7Crg7X
ExZu3gyySH7lWL5XVvNIugk0kJ+X4up0n5rWMA4YI/5u48D1EduepVgCDqn3
T9xj6TS89Z05u38ePvB8T6dIzxhUEr0MvEZl46SSux77eTxuqolZdNVtHlAi
z4dggc7cnvFtSohDntMgP97D2dJRGwnJftnQezRfTexuiKKJ3HVo72SR6qNq
hrKIgRK4beZc3TnlGxCf/P4eFBmJXqZ9C9EWZoBBDat7B1R0NiFtUi8N94l4
O4/E2yCGRyW8owHrp5TaIjHZrwru2ply0vOWPWogvB/BmhUeGdP5jqiS5PEY
3l0a9ChMzkWFpJ9q4cPfZ1CDFs7oIqnvb6jnl9hxaZMLiib9+gwmz/mtJUmV
h5i86+C9eZLAzHQe8iLn4TlUrUzLDOnjIeb8NMCSguUzt37ksXqNUNP7pxiH
Nh5KIjyb4N6nnpK2WB6KJ/r/wKwH/r6Tky7oMPHfDN+H6uuqu7iw+72Ah2MM
cVmkMwog/dIC963rFFZGOSHmPmqFMq7DmvkhXDavNviZ/2RzqpUjsiHzrh0i
vxzfBV/sEUX6sQM+Oa4h5N62Q8ZknnbCg61XjIu22yKmf1/CHz8GD++fsEHL
yHzogiVuvlfCr1gjUp7mK1gfJJvgcjah2WT+vIZ+2n/cXyXmoIkvivUacnY1
6OYaQUSO11EhdC3ZQ+/PpZCcbCCEs24ZvqowsmD9iWB7RfHrjtb1aJDwE8Ew
aHjF9w9zROzu6YZzTu0fX51gioREsBt6BdcfSTi7lvXfA1WM6xaa8o1QC+Hd
Az2mLcvWVTFk8+iF71rvGtqK9REZB4JeGN02omSpvArZknz6oGdT/ufxYF3E
HLc++PhVQtKwyko2rzeQf+l4t4FgObpP2vENDLpT6gOli5EJya8fPjxfoj4t
Rgsx91U/9G6YprUkTAOtIgWKYVTQ3RtqFfNQDjEshmnH6YWNxWqIyK0YgB0p
yqUVv85GzHwegJVwan1R83SkTgQHoXfSR6B1bQpKJgUOwpL0Upn500malKcy
BK0+5CZ7q36gmfk6BG+eLwww/SCnPxMeQ9B7jt0OzSgJzfAYhu4Gd7mmmiM0
c/8MQxODpa4W6mI6lPAYgQ9tksO3tffQDI8RqMw9pNvpLKQZHm9hlVGRyp7i
Dpq5/97Ct8mr623wC/onwmMUusd6SAwKG2mGxyiciOdXJKcIaOZ9Zwx6XetN
3T+1lg4kemOw0DlxpnpkNU2+njsGWzUbuYEJiCZ4RGOw6ff4iIyYBzRzX0ng
4a7yB0/y7tDeZD8J1Dk738ksoohmxpUE+vil+FivKaCZ9zkJbHxRa+K4OofW
IHlKoYnFjJxffDNpYs9VCs3WnRMZzk2niVyKFPplF/x8fkEqzbwfSKEgZULb
zDuRViaCMlgsb9h3BMbTBLfd12ehBxj+9F+alJcgg16+tdunZkbSVaSfZJAy
iNI9PBhGExxfZFCgNfhMohFCk7iBHKoFRd6J3RVAM+9ncuiaIDkxK9GXfkAa
RA5jPcvnR/3tQf8fGPSViQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglYjdkfx1OGFobqIktJTKUxlhYM7+m0h0h3mSTVEFknItS0aC+mMV1m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          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgdUVEcbhsGGIFEElYgKPzHqWmJQAoeYOw5NulIXdhUVFbAgTYyFJEq3
RKP4I4oFUbCCCIgFveMsWBAEXER6KAtLkwW2iYAicefeOYfDuWd33/ne9/nm
m2u8NdQjYJyamlr2tz/V//Iy1VLiNY4e+bpmG6nTRR85vqeUOFMafN9NsI3y
eGwY3+uuxMF7w7Siz+6iZmbbiyJnKPHm5GxPk4pwqjY9DGjVKnDl4fnGx9F+
6kKKaimwJryjtSrmMOV7SiWowFddhBE5wjjK6JvaY0MFTrJ95vXjlr+ptsgZ
3xTl+Lp5bdORvkQqQyWXLsdtVv8InPzOUdsDVUuOP30pc9vFT6UWE0E5NtLL
rddNTack7qoCZXiuXOu8rtVtipSXLcPBalkn5D/nUOEquTAZ1hb9Oc7xTj71
i6lqyXBzM7jZseYJNchRCUpx6qGkSo1rAorYfSzFuiGXwrcNv6D+UJUXKcVd
k3QK/XxKqdUqOSDFE6p447cfFFJqZEmxIjeveGrCeypBZS9+AFdkteR776+n
ppCABnDD0dGz0w+2sPn2453dktaPm9rZPPvxxWcdA7qCLja/Phy8UB7GUe9j
8+rD8RYNl9UzZGw+Ehye3aJ9Y/NHagnJQ4LPurtkBL0ZZv33YucuelihPsb6
7cUuX21LeKfHgQLi7wPWHFrn8nn+JMD4+YCvTHTQ/GOtFniuKq+oB9O/Rvs2
GE0DDio5+x58RuaVUuCjC5h+6can1Vut+47OBEx/dOO3u9CpxuWzQR3phy78
1NJwzhruPLCR8O/CPUbPFhlMMAYM7048vDJC1H17PmD4duIHi3eM6F9bCBie
HThmfti8I/LFgOHXga1OVYaXpP0EGF5i3HzX1XyszgT8SfiI8ceHF7w9Z5oC
dcJDjB/VDmWtOmIGGB7teFPGeddpJhaA4dGOhShL54zOb4Dh0YZ9fftNhJzV
gOHRhjvK7RIn0JaA4SHCUcb745wOWQOGhwhf3E2t7+TbAoZHKwbrE5XDLnaA
4dGKw3OO+etxHcAm4r8FO46Opi0IdQI7iN9mXLrE9G7sORewh/hrwuaz61Oa
S9axfv7F8ru2W9Kj3Nj6G7H3o6p1319yZ+ttwE1zp+WtzvcAl0h99bgOaYqe
v/QEN0g9dbigusTLoNwL5JB+qMU2+RE/xL3igieEfw2OkCzba5TtDV4Q3tX4
8JBApDzsAyoI3/c4YN/rAxoWPJZnFea87DQNfMcDYsLvHfZ0XJG42pnP8qrE
wW/O9Qyk8sEQ4SPEnfdfGhqV8gFzPoR4Akd9aWkJH3xP8q3AgU3H9Tdc5APy
dU4Zfj/Jr6GA4gNL0o+l2BdzL/lm8QCP9NdrnDZ8XMLt8WHze4V3PLQI8VN4
gyiS1wv8k3Z3Slcpl82nCGvHVK36LtwL3CJ5CLCtFs8/s8sDkMcwhB3yfXI9
VriDNJJfAS5WeoUeu7YOCMnPH2CPTnFgdbITkBJ/uVjNZs70RAc7YEnqzcIu
MT9cryu0YvfPwK5TuZ5Bc1YBAdFLwQ0npGXiUBP28zj8aPYSbfvtBkCNPO+F
NsKcYv0gLWRJnpOg8m+Hi5q8JaiV7HcVTrKTTo/rNkdRRO42fHGzTiH7xRKl
EQM5UB3pe+qW2aIw8vt8aOb0+3Kv5Y7IjRlg0M96LNHefS36H6mXhuGD4c5F
Z90Qw0MAN3ReM9++3gN1k/0KoR93coO+whMJCe/n8ERSRIXGRi4SkDxeQqOp
U4uNkr3RLdJPxfB8dFGS2mUfdJ7UVwJXSmJ3jgvnoSjSr2+ghef9aBNdPmLy
Lod9wgdhVtF8xCPn4S3k/yzdcgLzEXN+hDCnxj7ncwWf1auEBzRO24zm8tEJ
wvMdRHvuLAsP4qM4ol8FR/mHviZ/5aEDxP97uOWW07aREB67XzWsl+4K2izw
Qf6kX2rglc8F2vcGvRFzH9VC86aHluKZ3mxedXCcs2z+iDEX2ZJ5Vw+tjZOC
Gg29EEX6sQE2lON9njqeyITM00ZoPrBlhfqIO2L691/46ll3n3OLG5pL5kMT
NDKyT85PcEWkvBnNsOXxTd4sj7VoMpk/LTDhytV9ogXO6MuYarVA62kTBRcm
OSJyvCJboZqv85wFQ3ZISTZohU3WwsiiUVvWnwgqys0r9A1s0AfCTwTPVXUd
MXW1QsRuYBt0naV7ZhmAqJUItsEuruxopC7F+m+HMW/fVm8w+hXVEN7tcNHI
5r4J/uZsHmIo0Ont6WsxRWQclInhcTfTDkniCmRH8umAZiedPl2RLkfMceuA
8UrzNonxUjavTjjeVPRdZd4i9JC0YydMyLTjNl7+Ea0k+XXBjHfO+6yajBFz
X3XBHo5ENLnGEC0kBXbD2OmDesYxBugaMdwNz+2b8jI3bxYicoY90OmBaFfT
Bj3EzOceOH3R3GLOHh2kSwQ/QH33aNOV1VPQP6TAD1Cc7KOT/LsGIuVp9cLS
w0GVE/PGI2a+9kLH+nK/kANq6Cvh0QttLvno+4R9phkeEri08WC/3otBmrl/
JDDPNPtprFBOhxAefbDsnmH7veF+muHRB0FiZmxxQA/N8OiH92VvbCRITDP3
Xz88+eiM06aWVno94TEAn+40lDj6NNIMjwF4ZdUK7606NTTzviOFqWa7Ncae
VtIBRE8K26O/pMr8y2jy9XQp5Dw+k5qd/oomeERSeCA+c4HnSCHN3FcyuPDr
UvGNUJreQPaTwZ06FjV5AQ9pZlzJ4P3L+tWRibk08z4ng7NmtOps3ZNJ65E8
5XD3J79AzL9OE3vucnjdd9G01mNpNJE7JYeHQo7IDsam0Mz7gRz+NQ+8Dzj/
f1qTCCrg4sHXn8yGTtIEt70CPm+eM3lrZQJNyotXwAUz76FC52i6kPSTApob
+A94G0TSBMeYArabuqyLvhhBk7iBEo6E3uSMuQfTzPuZEkblXb17uzKAfkQa
RAkfbJz15CbHj/4P/w+g6w==
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw1lg041Nkexyfda+1yY/OytrqWItS1rPQi/9OZRCiESXmfqxelbqgk79cW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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10ntQTFEYAPBrbe1u6zET8g55FUlIE12dQw+SpTSrkUpSGyOymiKqfVUa
9g8GQ1trGoqMZ6MJdTnH0Jg7k6YmjFBaURIjZJGd0L2fb+bOnTPn+37fOd+c
GUnpG1MkDMOs/vcN/cUYQd0OGwNCJZHsEiGU9K4p2FXnG8VqhHChd/06Jr7I
2chaiodCQS0qN29ZbzT7uGEo5PRVanBdoE7Nip6c8l93HwoNigFPRreu5C6X
LdgMnjOt6YoYczx6C3hOdFbBGsuKW/HgSenVLK+Rqb6J4Emp/4ntuP7KNvCG
07eLrz1yqLeDJ6H3+qZ6DC5KAW8Y7Z6g0O9dncoKXANDzfae0JvWneAx1Ha/
NLaZTYP6QWKYZ2mPW5AO+Q7ynPSXubJa6PebtEl+nG51zWAFvvgXmZEfZ65x
zwTvJ9FUb5runrQfPDux+tvHorZs8PrJh9q5DoM5h10seN9Iu4vSa69Gx54R
vC/EaLx0KsvbAF4fMfpwye/PGaH+I1kZkRRp/WOC/B6y4am1KMijgE0W+nWR
i41Yb+0oYH0Fv5O8Y/hes7wQvA6yPtzQrU4pgPpWsnn+54VFvAnyW8inNzUx
y6cY2GPCPk8ye7vLTzQcZPXC+g5RyrrWBVZr/8+PUdvO70koTGDLxH2k2xMb
P0EVwolrHjk/bPSMe5LKBYg+OuJ5riiKz4D9VvR2mTlzRV02B+dDnz35mjMV
uZDfiVrWXrTIqnTcDvF+KM4vsvbZeD0H90cLS62KNJOOaxLng27kRiyrdMkD
rw8F0pP52nE5XKk4X2R8MntTpS2b8xPnjwpHGzQlJfuhvh95zYq3NSVmQj87
qrKPV+4OzgDvJ8qvmFaXoNKC9wvJhu3L++aUDt5vVCsN63jN7wLPgfyMrW1Z
nTvAG0QNHsvf+Kg04DE4r2tOVjiTzDWK7xMv/fMivfz7Ng7eLy4p87EHzEmE
egkOqo7VP3KLh37DMf/lR+WYoFjwpLhxpuK96lYMeFIcZnIMlB5Qg+eEK54p
JodnR4PnjN1v10+6UBUFngy3+/QwA5MiwZPjYoP3y/oEFXhy3Hz9TvOhlrXg
KfBWbVOf+9E14Lngo8yVB69yw8BT4vqqkDRbeQh4I7Dr2VG+/gOruL9CXgAE

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10g1MzGEYAPBT13V9jOVklSIfM2eIijW9vK/zcb4W5bRhWBbJRsrnqDii
cU2XK4RddSdXd3JFH5p/3hcjtS6Zj9bCKAx96Oq0Il/9/49n+++/d+/z/J73
ffZO3JYQtd1JJBIp/33DfyE8mW/z6PiQRcdRCB8e7J4srogmqdEOPtxZxqpu
b+uDE+hy7nC4Md0JNLM6NA3ZGoZDyl7viqvzs51Cgidlqes2dxRr08FzZZ+l
3YGdaWfAk7An124Ygko14Lmw79ONXibfc+CJ2UD+l6qHsVrwxCzuUXOl7kMW
eM5Mf8d7RmaWDjwnZp68r9mamAPeCCZ+NincpLmIeK5BxIZeHpzz7lMueCI2
06xWJmmuQv1vGr4l8sAvdR7kD9HEjTO8SuMLoN9Peuh6WqLvEiPi+dxB2mC4
qepfVwjeACW5qryHV0zg9dODoXveV40zg+egZ9H8TYqmGyiY9/poilz+o8dq
RZd4z06njfRTqlRl4PXQoqa9uvGNt6C+k8ZFuH6MmVUO+V9oRn2YqUZVgWL5
fp/oHBQ9xjG2Es3m/Xa6ZtmKww8UleC9o2/jFV7Rxgqob6HP5Gss/h7lkP+c
znJ97CyJKUNafr+ObvDX12o2WdBxfl1Nk/Lq6kOUhv/zE+k/r1rbsFuL8oV9
LOtyL/u2IIET1nX4WmTXwhbLBS5M8HFba3730TAj7LfgXsUL5/SgYg7Oh8cG
vqndGlgC+e04eUJE65IQK7dTuB+2Lcwo7a22cnB/7OfZofjmbeWahPngNwHW
ivWFJeD14LK2wNo/VRbuqjBfbO9zOWfWFHOhwvxxen1mjna1CeodONZn7sog
n0Lo149vT1bPM4uM4A3gYsPISseoAvAGccSyV8deZOvB+4mXr7QPamKugDeE
d+tKxD4nL4H3G9fkRHU5OXLAExH51NCIghId1yi8T7J/12lbW1EWB++XjNpj
f1lQkwn1TkSSkrz1ZlYG9HMmjbfmdzy9fwY8McHZwTbvxengiUnqV/PAXY9T
4LmQmo/nUwJkJ8GTEMMF1q6PVIPnSu5F0RHT1cfAk5LR/qny6PJk8KRkeYJb
ti74CHhuxDN50P6n9xB47qRPppzS2nUAPA8S/mvp5Rj//eB5EplNEmA5nMT9
BYX9DOY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw10n1MU1cUAPAHtPKgbFEzF6XqVsVEdBgEYlSe3rs5PvYHGFBQg0OtSg0u
m4GBCtpihgHNukFEHF8FCwooWWGyKvLsvY6PUikIRZZoqOgQ4wdoCdiUgKC8
d3aSl5ebe87v3HtyFcqfYg+7MwwT8fGb+4vhQzUxprpt8aVcsBAy2lO8dSYw
ScclCeFNT97TWQPiKrjiornwoh5n7c68gstcl3UuWBrekhA6NKHnRI+lV749
b4rMqALPkwY7vrie6X8VvHk0U52if+pZA56U+uzRJVfKr4Enod5PVpxtP1oH
noRaV8a9jmAM4HnQJdt/QPKxevDc6Winceew9i/w3Gh2gE0TureREzgrQ2PK
MkrSlEbwGPrKclGjqb4F9TMksM+QdDuoGfKnCRsQvs8kM0G/KeIVuumrd6WU
E/iiSRK2YPX7Bwf+Ac9FluNjFdXxreA5yZ7r1ebazHbwJshI3Z9Vw10dXJDg
jZNfrNmSo2Gd3B+CN0YOyRbLJ2xd4DnIVlV0wpl1PVA/QnblpxbvT+yF/Jek
KWpyd8P3Nu6Q0O85aVJGRhjYPi5Q8IeIHw5XtYX0gfeEJKb+XLP6bxvUPyRq
12uj4mAv5PcRnNc9oont5vKEfQs5mFvStmxZB5clrJvIWNpA+a4M+v/8GFf/
mhNhswauQtxHS1j/waTfU3hxbUGGSl5tlzbwG0UfNZY/+/EbpQn2H6KB4+eK
NdtaeTgfyipfq3qlN0P+ECp0yhdWHrPwR8T7oRVa5Y63DgsP90d3SlrwqTQL
3yPOB20pq60KieoAz4HOOf5NWd7czpeK80W+/f7mz8db+RBx/khru7gh2rcF
6ifQfeaIrOi7u9DPiWKbg9LPf0nAc6FIt/G2M6PN4E2iwZob6b+5NYE3hfof
ud58kmgEbxqp/2Pr9UwjeDNIF5z6+MGzBvAYbLZEd62S1vPd4vvE0nsqor5Z
x8P7xW6zvrvvtNVCvTuWf20tVKyphn4eeOkp+2DloyrwJNjst/fX4G49eBKs
nZ87dWu6AjwpLrsWs36RSQfePOyTkO9ltJeA54lzTi/MiYwqAo/FCjYi18/j
Engsvnt5S9iAswA8L1xgf3FzkeICeN4Y7VtZqMrMB0+G2c7RTzczeeD54EvO
z5Lj47T8B+SHEu8=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10ntMU1cYAPC+eBRcjHMR3cSJaNAwN5RBNLnbOf6hU5HEZ4AJCSsgLBOQ
zVeMzoIMEh9Mq4m9iIgipOOlTFconnoOg8BKK1SkKgIdUKFBUahjCFJx497P
L7m5OTnf9/vO+XICVOnbk2QSieSb/7+ZvxizGF81UNVBqrlQIXxZ/PLaX/Jk
t7g9Qviwf3MeqlHKbS6fnwklu1x+902z6w/unmUmvNnPJwq0muIaTvS8GbU6
9bosA3hebGG76ZTpwh3wPJk8ZGBedq8RPA/WURb49LdwBp6CGfs15O+r9eAp
2Lk1QU4S3gCenJn1m0rYm0bwZCwjZ2vuorEm8KSs53jS9b9WmDiBs0jY2r6l
5RnFZvAkrD8w+Yz6+1aon6ZYnf3pwT+tkO+mxsHha4ePt0O/KapE8wM27Ovg
BJ6fpGVbUp/e0z4Eb4Jazjn2sanH4I3T85bIK9l8F3hjtPGlv6s6zc6tFrx/
6KGfFo6+ru3ltILnopWh7dmajf3gjdLZeVq39JED6oepCnv8GhQ5APlDdM4P
6h9jTg5yiUK/Qcq/i1nwLMHJhQi+g56OCo93lzrB66Uj9kuhk/5OqO+k3XU2
kpw/APkPaIiupOkrmYM7K+ybaIVu/VBqnZ1TC2sD9XmdZ00y2N7PT6LLzUm3
JzRzReI+OrorfHHsFi2sTehk0GcRzeWUrBF9ZHv7RWaCuY2I+52oIivMa+qt
jcD50F0u7v4ivyeQ70CvitPS/KO6SYp4P3Qjt8eV9UEPgfsj5bGI6GG+m1jF
+aAdewKGXNFd4I2ibYZkaRTfSQrE+SKzZqJ0qfYR+VKcPzqgqktdlWmD+jF0
YHvFSHvGA+g3jlgwP/750fvgTaA4yQJp5c428CZRXtfBFyVSC3hTaO/Xl4zB
UhN4bsQnx+83bG0Cbxr5fJuUGvG8ATwJbj12cWdxSz1pFd8nVh16t3illRJ4
v3h6udvld4RAvQz3lQYezs0xQD85vvWRsnJiSA+eAqf3eX4sz78NngLX+Nnn
xp75HTwPXKZK1LTcuQmeJ3boe9qWcVXgeeFNTetajLvLwfPGYR/KozebdeB5
Y8UnBdolmaXgKXFRGPbt2n8dPB+sp1HB/leugeeL2wp7vzsxWQTeLDxCRlJe
uQvJf79OKLI=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10n9MjGEcAPBXP3SlxaySs0bHZqXJdEh763nRUv6gWEMyk0p3yYXlRxv5
ERGRn9PtLIsS51c/Rtk7z5PLJY4Q+qlzzl13zo+Lu1y7E3rfr+/27t2z5/v9
fJ/nuyckXbYy042iqKX/vtE/H76k0RovyVM/oiO5GEfkylb1pqAWOosLH5Jt
SfkUfPwxLS8fDW9yQOncVSZqpZ9rRkNAhKXbIhbqn9C8JyCnldcS579+Cp4X
0aYtt6y3a8AbS/we2ePXrGoHz5MEPXAu6h9+CZ4HkUfspC7KXoPnQVTbpUdU
49+A50429Ilqf2jfgudGbs+3N+QaO8EbQyTyyusxYT00x2ko8t4U7RtR3wce
RbJoh5f6mBbqR3Bc2t6S0nU6yHfhwBteAwkiPfRz4tvW4ps3gg00x5cP4zMK
08GHyQPgOfCcCw2yNc1m8IbwrJR0g2/uF/BsuP5BTdyd5O/0XM77iZ2pGblT
Igfpi5w3iENjFdUFmh/gWXGtOL43IMsG9V8wW7IjZJbZDvlmfHbg/P2ieb/o
DK6fEW8NcYlc0xz0HM7X46Kfc+VojwO8D5hcF3uGejugvhunLonMz6wcgvwO
bJFGaY6G2egybr8N5/Wr986usdL7uXUTHj97ubT4vOn//KjVwiva1or39GV+
H6n94tZ3SlSwbkMi95YOXNfMRvE+KkwXL35Y2cXy+92ooGxFR9DmjyycD62a
0SfVnTJCvh6hc4Lie99MbDZ/P2R2xZ5c3G5m4f6oWr32UmipmX3JzwdFT5g4
Zd8BE3hWJOkpzxU7jKyCny8y+vknLAs3sGJ+/igcBcZFJ+ih3obkSSmDJdk6
6DeEFnQ9K/gVowXPgfp3KqIoSy94w8hn40x7lq4LPCfKX1aft2X6O/BcaHdF
WIvgTgd4I6gn50SgqvAVeBTjvWQk/83UdvYF/z6ZNP+AjMa6Zyy8X2ZpYY3t
j/IJ1LsxSbpm/0mUGvq5M4GZMYuSrqrA82CEsrRat1PN4HkwruO61GAZBs+T
keRc+l4VzoI3lvmcMfmkOLEJPC9msyY526fpHngC5uu3x6XGbQ3gCZieVMva
bmkdeN5MW2KsQai4C54Pk/RJe+jp71vgjWNyDKLDVUIleL6MuSIob39RDfsX
dt0d0g==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw10glME0EUANCltKUHnpFoaqJ4kKhEQTDGxC0z4oEheGE88IonmGhioCre
oFEBjRGVqxWJFPDCCEU80NUZb0GKFAxaqAQRrKJAK4e01Krsfn+y2Uzm//dn
fmbc5l2R20QMw4T9+wb+QnjTmLw6UfTwGjaYDyXVZU3xfbCklo3mQ0GTOzpK
NxS+Y3XagZDTRY0bWdukOtZYORAyuslZrTlV+Z4VPBmVp0T8qdeZwfOi/Rnj
T87UNoAnpfUtZzcUGz+CJ6FZpW1rdWObwBPT6mfr99Yc+ASemE5+6nnR6WoG
z5P2yWLG+BW2gCei2SMX9spPfwHPg2q019KG5n1lea6SoYr4uLuRzjbwGPot
1M9wPqsd6t3kddz8PYPn2iDfRQ4804iet9qhXz+xzrc8v3y/i+V5rYMMSn+Y
EU16wOsjOe3RaeWuX+D1klOzRt1PinWC1026XYdCfEb/ZoN4r4sYA4ddeGL/
w2bxnp009FW5fTUeasGzkfEh8/QrO0Vqof4HsdWnLtVFidVC/jfiKlidczNd
ot7K9/tCJoaFKo4ekaoDef8ziVoTzDyxSsFrIrnBxvideinUm8nUJM1mfEIC
+bVEOe3G8jH7PNWp/H45SQy/JElOYNSJ/LqMxO1J3+c+6fg/P6bxSnyQSWVn
Lwv7aPHLcOnjjiZYl6PinFyzMTSTnSX4SF8VoNi9rp4T9s1IVBLrnar4ysH5
UKF+04Kh+k5OyP+MdtxoPWf3+cltF+6HDA+SZluHd3Fwf5RXbMOOEV1ctTAf
5DU7WbU/5id4NpThOw81htu5bGG+6IMqIKmiuZObIcwfHR8yroRz/4D6bhQR
qzBoVW3QrxcltCQumLDCCl4f+v3WUG0hLeA50GHHMf/ALc3g9aPWO7qitDlN
4LmQ9uD5I1dvW8BzI0eYI3f6MjN4DD6tLXD1RNZxVcL7xCm3aPmioloO3i8u
k5iSz6wzQb0I+1vvvXHqq6CfJ/7kETFsuvINeGLc0+6Xv7T5FXhi3J44KOiC
6gV4EmzJVOKKq0/Bk+Ih8tqNoQkUPC98rgFF4IBH4Mlwdtzo63tNZeDJcGN/
jaun7i54chxYtvt7THApeAo8IyQ/ZYTFAJ4Sm3xLsledLQLPG6+Y+v3jFEsh
9xcaoiFJ
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10g1MjGEcAPBTV925VJcshESE+YwVeV/PW1hEJjazNCyJxZGofNyMKWnz
kc/uUmFkk9lyWRbv9jzM1fVxnEwf6pKuJE6u67qr7ip637//9u7ds/////s/
z7MnIP7otv1OAoEg8t839ufDnWSHys0PD7VRy7mQEOOs0Y3OGd+oRC7Gk7hQ
c7iqrJ3KU46FmBTe8Muocu2gtLVjISKtB5b+0KZ3UrwnIsWOmSFkQhd4biRy
/Zfhxdof4LmSa41xyqjXP8FzIaPVO6PteiN4QnJ9TcPawdV/wBOSecV7v6b0
mMBzJupEfaAqwQyeE9GGnDIoXCzgjSPPTAWGvPp+iuNqBeS3/9nV7/Q28ARk
If44RRUwBP0jOEiVdOv0EwfUO3BaVnzUKfkozLPjF0N+9oGt42iOVw7i0oFp
7au8nGmeG8ANJkVw8oiQ5j0rFnpVZJ+c5kbzngXL+yoCLx4U08Gc14f3pcs6
C1sktILzevHz26puxWEP8Ez4zrOwOR/Pe0G/EW/2rp6qIVKo78YJH0ylkS3e
dAI37zv295UpF5RNpJdyvgGvkrW/ohf4gNeGL+nUyb1SH+hvwttOeoT7bvpf
/wnXPe0xer2R0jlcvgoLrUl7go0e9DluXY49v+1u1kjF9P8Xczq8YHB+ohN9
n8+jQzWxmbZhK8Wvq9Dh7MzY7noDtZL3UXNGSm15VxnL55tQb4v/Lk1nBwv7
Qzvc7wSbe0wsX29AN8PizuSI+tmD/PnQlFtXQoJm2Fg4P+qPeZsiL7KxOv5+
kFyRYi30toFnQprz+ceTq/rZfP5+UYu28G7QZAu7gr9/JIu1pBaEmqHfgnKU
v9LObDHBPCuqGX6wM/enEbwBpJYdffj4RDd4g+jYC1Fj5sbv4NnRZWu0esMR
A3gOFNYhKQppbwNvBDkcrXRShB48ASP7krRbE9XEvuffJxNRafCL1n1m4f0y
5WtaqWx1HfQ7MUN7Kzxzp+tgnjNTd6w6S6CsAU/IDLvE3Gu4WgmekAlaXjp3
u/gdeC6MbtGTju02Ap4rs941Z3bxTRY8N2bdrzpHWtdL8ESM9EJ8X8SnUvBE
TFdj+rLItSXgiZlJ9iNZbzcXgzeeYT/EN6Y1PwJPwkiWpKY6Jt8Hz52ZWaJP
XdSay/4Fv/ciqw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10w1MU1cUAOBneZRSUSuoBAWBsZio2AAjmZvv7d4o/mzxhyxRxCgaVlGm
jAyGgqhQwjQpiUDQSZU5tSJEYgJqNOrDe7U4QgX5cW7jL3QpVDQMC7VSpcDG
u4eTvLzc3HO+k3vefeHJ6d/uV3Act/H/Z/rNwo/6/RrRf1oaEj6TYzbdtfbf
bo1xWEiRQ039Y25dfRDvEC4Yp8OXDumOa1PSRoSW5ulQ0StC5qMfKkcF5qlo
nD2uJdjjBM+Hft7wTBOZ5QJPSStRXXX3gjHwvOmm/T1KzuoGj6dns7KTFvV8
BI+nFpchJHHeBHhe9GZ/ZP4f+VPgKSi+fsYiBM8SmTeL9m3Nyf7lN4Uoc80c
bTtUHJ+yjRfhwLR7r3l1QLRSZPWT5NDhibHUb1SQ7yHRTwdWHbmiFlm/cVK4
xVX3pTBHlHnjB1J20pQVrNGA5yaW8pjNf1fPB+89KR80JoipAeC9I4u6TP7a
+IVijOw5iS9e+sWOxECxXPZGSPvvRYaLuUHgOchJH9+lMVVLoH6ImH/SGgrM
IZD/mjQm5YQm3AwVdXI/Oyk6sPP2wothYpTs20j/Xr1nxD8cPCtJOlZ9bVVY
ONR3kpr62FPNVTP5L8ialqPDLdGhYom830RiH3ScNrxaIubL6/tkqzZ5j74i
cGZ+3GKuz3Oi0l+8zPZRsqU1YtKmhnUTKlUbp/56w4mrmY9iH+qeZSKHwPY7
0aA5pXC5kcD3taKdaedrbJv+kVi+DR2t6dEWn3krHWTnQ2lm84E+h1OC86On
2dagtkaX1Mbmg8amigLWj7okmB/qKOH1Os4lVbD5oolPepWd3zmlWDZ/NEQW
Jw6kj0D9O/S81atD/3AY+r1H+0LqN5iuvQHPjY6sdVZvabSD9wH9vO4UP3eN
DbxxdLj2ydU/fa3geVDep2FRc7/vAm8S5W5/bW798SV4HC7LissZD2mXnrP7
iV9EPK5b9sgiwf3FyYOCvffrBqhXYM2O0XPb8+qhnxeepxoo3cffAY/Ht5MK
N77qqgKPx5cm7O7dK8+C542jaEm0uy5VYJ4Sb87I+CpRcV5gng92XTJZCnpM
M/8v1l+Yf7+4/4bAPBVuj2xylOlqZ/5/XHXD+2595y3w1Ljt5eUVubY74M3G
QQ0V5/jSu+D5YUWFITDt7T3hP1LrDAk=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw10wlMU0kYAOBHqbRQFg0RbUiDFgRBsXhA3NX3nKlHvOMJsZJ44IERxChk
u0QpiOuuRlCDRhBFUeMRiRCFKJriTIxSNEDEWuyLXFJFzArLIUq5VN78/ZOX
l8nM//0zf2a0cfvX75JxHLf01zf6Z+FNI//qrM819vNzpFDRuaWeA/+5DfC7
pfCizcaGjdaSQT7/wmh4UmX0zaqtx4b5murRUFIx2HRM9+8PnnlKen5drWJB
IycwT0Fb9BkpBb4ygXkeNOGGPH1CvLvAvDGUOnva0pvkAvPktCCuLzMqzUNg
npy+39GcGLpMCZ47tc742/D/Yi/wZJQr0bTYUr3Bc6Olov5qe4ePIHHVHK08
sdKU9mYceBytm96e88rgC/kjJKPkn5iTqvGwfoi89oioy+z0g3qDpNI+9ugp
hVqQ+AtOcv5eW58u1h+8ftJqm1E18kUD3jeyqKw9yv5kEnhfScH8jbEv47XC
bMnrJQGDYWU3vIOEPMnrJqnlXdfSLFPA6yKmWYHZb7JCIP8LabhZMS5/RSis
/0wOzevbUNkWJuyU6rURVTn1sSyYLsyUfAeZMP+0qjg0HLwWUigOYJ0xHPJF
kq2q6FK4hcN6K3HWHE/RF00TzkjzL0jFIf+Ll5NDhQxp/Ih4dthyoozBrv5x
IamlKtStFQrZPJqIyxo7tmtg/ALFOFbVPvX1E35nPtp2uLXwrOw3mBdRWE9W
Vdav+wD7Q0788cMdoZdn6x1o+9i1ljW5Dfwedj5kin8e/Wf9bTOcHw3fqvyu
Pm0zv2L9Qc9MibvqFjaZoX9oh8U3oTOwxXyJ9RepA30mn1A2mSNZ/1Hv2nsR
Uw0i5H9F60fW/TGUajWzet/Qk4fBxZdNL8HrR3l3ow0r7pvBc6LDyXFHcqrz
wBtEkVrj0UZbEc+8IbRMmW1QJxPY/wjae/x17rkoC7wPDmfH6RO0aTV8Lbuf
uDxkiU4dUwfvyw23zvXJ5w5YIV+GFdeDLEMBNp7Vc8fpzi2Pu5LqwZPjR4qD
k01Jb8GTY/3KA0G2MDt4Y/Cep/4zi4vs4HngZ7HXujcP28FT4OHwwtWOENH1
fvFn3YaUqREieEqMMjY5ZBrR9f4xve4nS+pxeV64ubkioOCBy1PhzH2fFmkS
7eB543dXlld98rPzPwH2qf00
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10n1MU1cUAPAntKUWsBY0ujTOlqGIjVgLFtR3uVeNwTgjRqhmK3FKKiBi
QLBGjTIdIc6PsU2oCrjZRPxjmRETtVoJ3kuAJQrqkPmBH3xIRDQ6KLR9IvjF
e6cneXm5uef8Tu65V5+Zv25LEMdxKV++8b8UYazUuO1E00YZihcjlFVeXDL9
0J9ylCWGig2XpB50vFegqsrxmMjKHuxx6HYp0e3W8VAyS0v7zOYpKiR5SuYO
O5RR/TgUvBBWZfPlrmwNB0/BrrlqezQDavDkLLUtumFPtAY8GbOHVmy3FkSA
J2OWCZ1zFV2R4AUzY2rDhns7p4IXxH4+dfRwjXkaeBPYFef+HCH2KyRyrRyr
T7J4utO14HHs/Q6Wpr4xA+o/0gMzX96zmnWQP0ZzX17tNV/WQ79R+sBjzc3L
+AaJfOUItQ8I0ytNs8B7R4tqUlLqFsWA56fWFu0PFUWx4HlpVITtGe0yIJPo
DdPIeRfubtsbh06Jnoe2fa1NXveHEbxB2na/5JNWaYL6NzS77MZ3FwviIf8V
1Z3x9m1oSkA2sV8ffZizqWTS64XIKPq9VJ+c7l3ZaAavm0YXJf3ljkuE+g76
5ohu8ZHwRMhvp5bC1f3Vq8zoN3H/Jr0W63PJnyegA+LaTc8Wtvzd/8IUmB9X
Gr5D/3S/ETmlfdzTrm2MZwZY38S1bZl3Lh+bjZIkH9frll+qatLDfgf+yfff
8rT1gfvoxtffLl6mqZ8C+b24Txg1fyhUoxzpfHhy++lO7SJl4Py42lavWbIi
GP0rzQd3P5/jilRxgfnhaefLG9SRY/xpab7Ybuh/ll03widI88dpZI3VW/SO
l+q9+NbvQnnLXYGX+vnx5ugF/YZSgYf7xWpdfHmWTQBvBEfVzutcsFYAbxSn
/xKc7U4UwBvDJS7V5FURAe/jl3n86vj2qR88jkTxB+cvdPj5O9L7JEPNy6LM
yX4e3i85/qrryfcdPqgPIifPxQjyrT7oF0w0ZQa7c8ALnoxkucJ+3J7vBU9G
ljote3e+HgZPTvKK8+p2Zw6DpyC1m5tNI4+GwAshxQVXihNSh8BTkozGSbPn
/+MBT0k2xbx1Xk/2gDeRZNlrtuxzD4KnIn0KzVGveRC8UMINLq0IyR8AL4ys
dsY5enb9z38GSRHx6A==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tQTFEYAPC1uz1U9Fj0UHqjJnb1kFWnc3Y9GhTZKZnMKCuNYaaG8ZhB
ZGhq1JAxhfSaVePVjtc/iDlHEelhSUNq8miQ7AqtHkpL9373m7lz58w53++7
57vn+GqzNNvEIpEo9v8z+ebDgUX6BP7VljuhMC7smef84j3yMmeUwYUd09c6
rvG76YJKz0/GVPbOaHG61SNDrS2TYcumXTZ3X5o3E/GeLeu3zhsPPjULPBv2
ZZ9B3ubmBp41i6PK4xVP3cGzYjr083nYxdngSVl22Ax9vd4LPClL/XC0VP7d
GzwJ03cvXnk6whc8MbMoY9odSvzAm8K+JGVn3/cMQBzXImLm/TLTqrZA8EQs
6VOBf8f1eZA/QWVhEwFfG4Ng/Tj9eEKzOc09BOqN0WDLizq5fiHi+POjVHH4
+VOrRwrwRii5579hR3IoeEN0a6wr2uQSDp6ZpitLok3mCBTKeYPU20g/NY1H
onOc95OWV1g6hvyXgveDNvRoxhJSoyHfSBdtrm7tKouB9V8p1kmXe24hKJ2r
95l+yzyZ8StJhRSc30sNT+aGuLmqwXtPEx1tBg4VqiG/ky74U78zs1IN69up
1FJdXoXVqIibb6JvSvtfZ25XoRxufJf+aTxbmxxAhP6J5nrkrK9wR6iKn8dd
6tV9pQVKGDfhFb3Lu58YI9AS3sfXRx4qfh0NhflOXFlfpPQaXih8Hz7c80Dy
oTcI1vfiq1YDqmhDINrO7w/X7I/c+qraT9g/zsrNLU+I8kEGvj9Yp+oLOdPu
KfQPL8tVJNyWeaAyvr847fWZlJphVxTO9x/HV5qa76ydBflmHBdvuJH+ewbU
G8InlmlP33kpE/4vVjQb8+s6XMAbxUce53cGDTqDN4Yj1pncbvo7gzeOk8te
jF7UOoE3gd+9qpH7pDgK/SN59h6/o8TTURt/Pklq4COX+DoH4fySqDTJ2q5j
9pAvJurLF0zfUuygnoQMe0zonuGpwv0gIxsMwX2LbMGTEk2ib1ujwka4X+TA
7q7igShr8KxJZOFng1FjBZ4Nad44rSF2r1S4v4SpBufk6yTg2ZJDF/buDn8r
Fu4/ydEeFLfPFoNnR3Z5XWnqz5gCnj05WJKXJa0TgedAlrys8rvmKkL/AOFo
5og=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw102lME0EUAOBSChSoWKWg4rGUyxbkrkHRYUYBsdCCaOIVfigq3qJGVDwx
gkECEUmUw/tGUBIT4hHBWUkqVyEgKuAFHpBgEGlqQAIWZfftSzabycz7Zuft
PGVy6sotYpFIFPP/mXjzIWMbZY9tHPPdUCgXjmzc7XPsWmYWSuHCga1ofzSn
tWU2KimeCHs2SB6cpyllUJNxIqRsTfa+4a437oj3/o9vyOXMTyV4dmzdu8bv
eYwneLasSU9bI1K9wLNhTQmlhQ+6vMGTsB+v936uPTAXPAm77uqiWzahavCs
WevSr/Z7GD/wxKwBnaouw/7gWbEKDRPvXBKIOM4oYg3Hzhe8dwsGT8SqhyKv
qPNCIN9CPxUZOvxUGlg/RrOipPFrBufDfqM0M3Q4N+JHGOL44hFatBElJrqF
g/eHTqocqE7LXAzeEE1Sbf2w3Q+D95uqww7U99stQSGcZ6bHyi+pcwqXoiLO
M9HwMx1J90kUeIO0LdY9sXY0GvL76ZYq07TcqhhY30dX7l/l+HCvFm3m9uul
vi6FL1eNx6Igzv9Gt286YqjQ6sDrpqrdI03b/PWQ30m1OnHaybN6WN9G083L
k5loPcrn5uvpaS/5i57VOpTBjZ/R7O61Pu31sUL9RHIfT93R6uXoOj+P+yI6
X0dtWAbjerxjsbNlsCcSLeB9bCYpv/THl8B8J7b6LF5/7XyE8H24Kn1P3eEn
4bD+G/YfLCvXHApD2/jz4YNtSteFdRrh/HinzjbLozAEtfD1wW8V18zDxiCh
fni20WMk614AuszXFwd0xWeXBM9DGr7+eCl67Znh5gv5v7EhLaD0ZZwK9hvC
4+abBd2VPsL/xXKVNsus9QZvBOvvxqXtFnuBN4qtZA4i7w4P8MawQ/sd6aVX
SvAs2EnaEHiwQegPEZnel5qhr2FQM38/SboxdCBhyhzh/pKunJan5SdmQb6Y
7FL9TbhpNxP2sya1u/6qOu/PEPqDSFa0fiGbpoMnIc3q/AuSkGlCf5G3BQ1n
TihcwbMlKpfvOMjeBTw74n4Om6qcFEL/kl6vX5E9ns7gSYklxcJkxkwV+p/8
eB+nyD08BTwHcmR83M/msRw8RyKrfKZ0tUwGT0aeu59svHjHCf0D8+Tb8g==

          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBwB2IQDQE8B/SFMg8Yn1WxNQYD7gN9p3SEdzKo2aaBAdeB
W8YqnMZ+6razZoIA54GdRVmyxTs0bM+eAQGOAxJvdpQud9KyhZjHcWAHy9Qb
6R+0oeaxH4gs/Bxx5Kgu1Dy2AykVUy6GHteHmsd6oMJqr7TGXwOoeSwH4jYu
DvE2MoKax3LgMGtzSUabMdQ85gO9Gs0nHf6aQM1jOsCx+cQr3tlmUPMYDzxo
7/DoTrGwBRt3huEAk2nJ3j9xVlDzGA40Psgr059gA9X/b3+jdadU4T87qPo/
+++HPOmyvuEAte/3fkY+ue5pYU62YONn/txfkXGQcf1fZ6h5P/avSnX8PemC
K9S8b/ur7NQ1ui+6Q837sr/+mqhIBaOXrRHYvM/7+5XOH38d52M7A2zex/1B
50RLvjzxg5r3YX9u3sOcM0cCoPrf7N/pXqEuKBcEVf9yf/z7OZUHCoNtU8D2
Pdu/bLHm2XXrQmwNwOY/3s87+ffFmP2hUPMe7F/58tH2/u4wqP6b+1tFzsq1
/w6Dqr+8/7D/3lcz/4TZTgDLn9y/W03ivUZbmG0DmL9z/3rGewbyc2HmMTDM
X+J+wiMkxHYBRN4++M+Usy9PBEH5J+3vfH68arFMoK0FxHz7tvUzNLbd9YPK
37Q3NFtgOWO9N8x99tW5e449P+MBVf/Y/hDnTT8fJzfbDIj/7DVyzvU187vA
/G+/9s7BmLk6TrYXIOFjn3HL5EVCnwMs/OznZkdEFQbZ2c6BhK99uNPqddVP
rW1NIOFvL2j54NWUI5ZQ/V/s9zcdZ/n10Bxq3zf7TTYPD30zMoPFr73H602t
7utNoOb9tG+pXl/fEmAMNe+3fZ3ykfDlgkZQ8/7Y7z2ysX/tOwOoef/sf6ov
urD8hD4s/BxuXX698NR9XdtzkPTpcCy5rMJATgeWfh24yvRi3tRrQfUzOeQ8
/nJsCqMm1D5mh7ny9zdoLVCH5Q+H92cCnNgj1aDmsTj8VygXOqepCstfDodO
pHUmCahAzWNzyMs3L73PpQw1j92BhX+/4QRxJVj+dXj/cv73VyaKUPM4HOLO
GHH1JCrA8r9DfIiHarKFPNQ8LodTcwW4C47LQs3jdijg+P5ZN08Gah6PQ9aq
U/v3aEnbAgB7Kuvs
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw102lME0EUAOAFajmNoFEUr6gV5KpQjhZ0mBFFQOSQ0ggI2KpQIkH7QyPg
BR6pEEHjjRcSMcFooqhcgpn1CApWxWDAGyJFUDEeIAJFVHbfvmSzmcy872Ve
5s1Ztzk21ZxhmND/39ifDzu2KvqYTGdciHy4sGVTjowLuvPaC6VxYcOenutR
Vt7qjU4Xj4U1a/+5Pc6+R4aeGMbCin1UfVYb5eCLeM+KVbs65dio/MCzZIes
W7TLqvzBE7NHI3UqtUIB3jjWc0eGo297AHgi9mfgbOPka4vAE7E+wSVOvVcR
eBasJKutHL3H4JmzXTOXzSiVLAHPjM10m5OQlROMOM7AsJf2xrfv618KHsPi
v5sjxp8MgfxRuq+/M6g2LRTOj9BRLyzPSw+HeibaOu1dTGFpBOL44iGqT25d
MDwlCrxBmjsh8ENdWgx4A7SmqSAmwbgKvH7aXa03BOxXIhnn9dGLxDhwPUyF
TnHeD9pcV5R/xX01eN+pk6uut9QlAfJ7adbxvk2p3mvg/Ce6fKTdMCxPRhu4
eh+p/9W43cZ5a5EX53fSsPKv92sz1OB10MSlf+y1UzWQ/4q+CDlvdNBr4HwL
3dqgdOi+rEGHuf1Gml8d+3NXtgblcutaaqpwWxz9W/AYpjZxRfoUqRpd4Pdx
ibLmRcXaFFg34mMb9VekkiSk4H0s7XlyYnFLAuy/wtf3lMnPFAn37cCxz3K1
8zNVcL4T60pTA+y2K1E6fz98dMjZQ1K/Srg/Pi9OfP5SGoOa+f7gleKQgwXn
IoX+4SS5wcLOMwKd5fuLM4o1HoVm4ciX7z/Oa/rWudMhFPL7sfLv87AbcSFQ
bwDf23K/V/VAeC+DWO9Yv6I+MRi8IZxZ1pTvNmkJeCa8/UCfJrIFgzeCo8Xz
fpVUIvBG8Z4Gm0W5D4X3zJDxQXG2PRaB6Cn/PsntFOfsLWnCPJiRxvUKs4gv
/pBvToaH86jokB/UsyATrSxN56KEeRMR003Ulu7iA56IPB2tiDd3lAnzRbSh
Eo/w6d7giYliRttjlcwLPEuiw2+yum9Jhfkl2Pp1klziCZ4VMapn3Xl7zV2Y
f7LtQfNCtcoNPBsSlN2Vlz/RFTxbUulbcze+ywU8O3Lmhut0xuCM/gHye+Cr

          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw10wtQTFEYAOBtLW0tCmE8pqaIaYrSaxXHOaWHbUt6kIrpobK2CdEgDE0P
o0melbZhNcwYbRiUSWHO8ayIGM/EikyUmkQ1Vmnp3v/+M3funDnn//57/nuO
beKW8GSxSCQK/P+MvvkYz172hPRP/SZHblzI2ECxk/wR8UIpXJizXv0Po+G6
NyrTjIYZG4jv7rsctBQ9aRoNKRvWIJvV4mWI96SsWBmka2jD4Jky6bJ6jesA
AW8cK1HYamSTfcEby057pp+tUSwHT8Jau05UxZ7xA0/CLAx/PudOCwBvDFN6
tircqwLBE7O8uNnvuzIV4Jkw+1oHt+otSsRxTSLW0H/p2sKyEPBEzFj2O/uw
MRTyR+i5zM13lRFhsH6Yri6MW+L3OBzqDdGRwdvqnamRiOM1BmpdMammUr4G
vN/0eWj9gWS3teANUqaNepCVEANeP63Wz1eU3luHXDnvF61WPrzjFB2HSjmv
j8ZuvnkPWySA94Pqss0nHs1LhPxuqrLKL7KVJsH6Tuo4v/zk8YJklMTV66DE
Z9uev8YU5ML57TTKPtFsdpgKvDZqV6TdVrBxE+S3UJP7uqocRzWsf0Gfyhb1
fjioRke5+UZqLbHqPrhdjbK4cS11Ti3VdXZtEvonwv5WQ5f+qFA5P49LtHbR
OTc2wrgRfzMecdmLU9Bi3sf6j41er3VJMN+CVb6HXzRP2iB8H677pJXsykuA
9e043/1863bLeKTi94cdL0ZU2m1dL+wfJ/Qt6qgaikHP+P5gf/Mi9cy7a4X+
4eDWpupMugad4vuLL/S0vx/bG4nc+f5jywXvgpuVEZDfj6cb2BX752FQbxAP
pEts6e5Vwv/F02Kcp2TnrwTPgFFtpf/OqGDwhvCDeXUzfaKDwBvGMpXi+9b8
FeCN4Db1lELX9gChf+TWmR23vRP90VP+fJKkwFxtjdhPOL8kwHPOhOV3fCFf
TGquehS+LvOBemPI8I43x9ghItwPosp49dXDAYMnIfsR6siNR8L9Irce2ii0
N5eAN468i1KnzZJ7g2dKnGIKun42LxbuL/liUvcrLUcOnpSsX5rRax3qKdx/
4rTv+twWFw/wzEnKDJP4innu4MlIcbg+o3mhG3jjif7+2+wbga7oHwy77eY=

          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtUjOsexofauxuhtMwJpb2jibYTdbBLvUkRuRU7kS4uhUJRlHKJ7hep
XRycIl3IVrkcSU77eyRRKqVQg66TblNjmglJu7Z55zvvWrNmfWvme97/8/z+
70Vvh6+j53gOh5P//SP7rq6SjUGsKzQfDtjszyQ+/sTbdnYQNlfNMhbMjGQc
H+hECB0GUb3KdXuIcjKjlb+yLXjqII4sGDS9sSSNacj0s1BtkMLcrClTmZvN
XLooG1KUvjFfm7Ehj9l2ViYoxQ9rOBmv+f9ldL+rPdCRoiDc3jF450OmPXjq
d0UJnPp5QQ72JUyWTC5Tglf2EW0D3k+Z3V6yIYHP+XXbJlVVMYZUUAJuiluQ
oksd0+cgK3AA9dtz9LmkgaHl5Q9At8BRqGTbxByUyfkNwHXIMfb4pnbG1EQ2
BrAxeKKjpLGT+cyTCYoxb9zknugtfQy1+0CMoV8dtgaGDTAhsvKCxXj7xbC6
Lf4TYymTsxCjcJOhV+XeYYZDhxjTmj3KRnQ5iJTZi/gIu6X3tNzSFKBGA/oI
vczPZShTgjxfEbgxR2KNCyZAnqcISVckRndsp0CeXz9GFmdKvxZMhTyvfkyL
Dkl2ARfyfPowReTs+zVwJubSPPpgHLvPyuCYHuT+hTh8c3JjRp4+5H6F4B8d
GpvtzkMR9deLhTp7fs9LN4LcTy/skjY8YUqMUSor73EPiho1ifoZE9jJ5Fb2
IO3Csv/oFy+CvF+6QQ6fLgrYYgZ5f3TDQW35wyFfSzTSfujC/bGwzsSIZXCl
/LuQWb++d/t0G8h5d6Lp46jLibEVkPPtRNJSg2tqS1ZDzvMDDOJ/E5lWroWc
3weo/Zk+Pb5lA+S8OhBqnoPGCRtxjPLpgO0Ve8Udfr9hHOXRgY69yQptE5xZ
HgIUXeec4ndsZXkIUMZTvRo/7MryaIe1tl7+p+seLI92PF53NMDGfwfLow3V
dTF5T913sTzaYPODvvur/V4sj1bwFAWBYWl7WB6tiPxlHckQecON+m9B9swi
n7se+7GH+m3GGlH9aIfEF4eovyYomlwLU3M8yPp5j+Ya4zu7iw6x9b/D8YCh
isvzA9h63wJWJoLU24eRSuvj42dNvbGfLANxjdbTiDP8zcvLXwfhNu2HBlif
0638djgYDyn/NzhgPUtDaeYxPKG8X8Ny5KB4csVxvKB8XyGr5R86ekEnWZ71
wI3LXI2UUHRQfnXQ+vpFIcjnFMvrJbam2qzQX3YaQ5RPLb7uGPaQaIZBvj5q
oVVlMf5hexi4NN8X+CfnTIFDbjjo33lVMPKsuJTkGwEr2o/P0bL6R22neZFw
pv1VDodS1bjTzZFsfk8xscmoXCE6CqE0ryfQ/V01u25ONJvPY4T+mGb9uSga
OTSPR/ACzzzSKgb00e9PTFA8dzW3KAbpNL8iPFe6W3tdPxa19PUC+GQ1K1WF
xkJM/d1BHce+Prw6Fla03lxcToSlk2ocO38WFCdvqmtaFIdHVO8ixne3ONc7
/v/3cER2zPFTcYsDhz4HkA2clvb9znGwos8pREMzr0rFOg6tdL6rRLV7TvS4
6d/fp3I3SO+qeq8UQSzSqYHbxHZwosmM1Fj40ffvkbPiWyETbGOxQb6BkR+v
7L8x0ByDWbTeYuL6TaXZ1zuG5fGIjI7WpC3rjkY3na+E+Gw2s1m0JRq1lHcp
MXBab2vMROERzaOMpKQOWfzMjUIO7adnxCzwxJspeyJxgdZXQcZSVoSo3YpA
KO3XSmI875vYUBTO5l1NLoesfJ4wJxzOdD3UkNTBTU89toSx66eWiBxnzKqI
Os3qvSSTft3VIL57CvGUZx3Ji2wZ+etdKMKpfj2RiojaFMVQBFH/r4iilk9+
uPMJdr7XJHGpjxW5eQy7aL+8IfeUxs5vHB8C+XnUQMxeuGVlux9l82okw2YJ
r748CYQN3e/4xMmou73L5AiW0n58S/LU1S378gJgTPfTd+S8/8Lxjqb+bP++
J2cuJiaYlx/EDLo/NBEz5YzCK95+oOVNbSb+38p4yUsOQJnuPy0kNSm99M7/
fDAyJhst5GbuzZ4I972gyyu4lRy3POyRo78bg3SCVqJ5P0GwU82T9ddGPn8a
qynS3Ileyq+NzPDOC91tsR3Urlc7mcbX9W+c5I5WKthOFJzs/tL54ML6F5Bb
ae+8aoac8YbyFpAZiyJKSuyc2Dw6yFHrfZyouo2g20FVB+F5/uF6JNkBK2g+
H8iAj+GtgCnrIV9uH0gIP2LeQzd7Nq9OwvFdpJ2jbIf7tB07yc3+R2FaKrZY
SPPrInv/MJjJ32LNnlddJOxTYVBBD8EcWmA3OTS6ytI2xxwZ1HA3eVYq/lYl
WAwqp9NDrI1c23hJpuz+3EPmulT6FGYvgAYV7CXRntnvq+fPRwItsJdcuKSc
f6LIELQ8VSFZaXpirJY/m91fheTfB1+Wbj35E0YpDyHRne8+W/IvXZZHH5kr
rEm+YKHNnj995KpVzRqPES0coDz6yWozU+52Fw2WRz856aiZK4pTZ3mIyM7W
94l2G1XY809E1GdpTGwQKmIr5fGRxKyNWuG6ZBzL4yNhYorLdS1H2PuOmKw+
ua02ReML40n1xEQ5od4h7qmEoX/PFJM9KQJ1a18RQ/G0icmsNdcOzU/sZu9b
A2SV9vR1mcUCxoXON0CisyqUApNaGPl2NUCEppa/qOnw2fvcAKm8PRa2r6We
0aR5Skg1r5h3n9Qw1J6DhDSneTcu3lXOULmzEuIUp+B1rvUxI78fSEjYi2d3
FwqLGRUqKCVHo7gx8U0FDMW9Ukr43Ht3fZbdZmh5EVJS/SKrq+DydaaE9pOU
SPdqR5y5mM5QHGNSIuDOdTtmcJ6hcVsMkgKNS7lmo7Hs/WyQHInepVkgDmYK
aYMMklvClOHlKZuZvwG678T5
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lWkfxlHUaJetSaQoohmmZdRXHskWlWUUylczCeVDSF+oRqWSaRpK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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs41NkfxlUbUamkh7QbW9uGVC5tWRtHRfVPdhGllS1tuVXrknqEdm2Z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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs41Okex3Vhlc7WabVZlY5ToRxJUeni1UmJEKonSdqKSlYRamvbpUKX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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs4lGkfxmk72A6+EpuVDj7WSvRVqL5teSqFvs7sFlEuCtthpdQW2RSR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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs4lGkbx5FT2kpSNFkdVJTI5tBWuLEqSqXa2nJYpIOKHCKabUtKB/lK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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglUzesaxncTtStqV0RUZLqXk5nca3s7iSKRg3NxDAelOoW0jGVoDmmw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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk01Wkfx2Upy2hxr2xZrkkxSR3LmFE86miuUqGV1IgQR9lK0+CVsqQ3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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs41FkfxyfZtlLupNwNRRdtZe27oSMVlafWJemC7YrWVnJ5S1hlKVR0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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lGsbx8dWWqQQWRoKMZQ6lM6X5dFykDY5FZEWRZuE03ZEqQhRlJSk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          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtYjGkbxyNaxZjdVEYnpcMWYaatdaXDXVtRLloloZJaHaykw7K20Uds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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgk4lWkbx9XEyFK2JiZL0oJicHBKuDWmJH0ZfTMSMaXNl6+JtFJTGhqM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          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs4ldkax1GhzJTkkkSIUlSiEm37dYpUZjQo4cQpoqtLaKaYyjkxUbl0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          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtYjNsax0dyjiREQhE57SRKN4Yu1jRDsWujbI6inKjYciuEqZxSKXLU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          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwtlgk0VdsfxyWPeN6rrpQpVE+heBSpxJa5VFIvIqql0PAv0YSXlGjQK5Xq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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglUU1cax9ERHUQqm5SODOjggiKKLLaKcEERbRERcUkFahFURkcIIqhI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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglYjWkfxouvqzKkFFPhyPiYNGQvWz1RlO3TZrR9SEp8aSEyjUraZFC2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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk4lWkfxo+tQgujomkZTbs0Eykf0pNJSTWFVEJpo0UhKiLyZZ0WS1Ok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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtYzFkfx9MKZV3SYN8o6rGWLAZZSjm5bGkTFetSiVJq5RJrUWTTBa9t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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk41Vkfx5EWTCJpWhCpqGTEEN50tEw0402UXuoOJUs1zVBUo7QZimqi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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs4lGkbx51GIbWVSluRWhWtiG07cis5pHY/dFwfwkaoRNL2iV3lUFol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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk4lGsbx+1bqRlR2mg/tDi2olM8+jiROt85okUnlWwlMlmOaBFRXY4W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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs4lGkbx4fkFKGcFdKX5FBJB2V1a9siu1+qtZXoZCtFRadtP7If69CJ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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk41Osex0lkPRwhJ5Ns2c9pIXUUrxa0XF2SklA5ouXQuGnVonukhSd5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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs01Gkfx6dki9ImI13QSG6zREmUeLqItEsr1bZE3kprU0J0pHuN9pVe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          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lGsbx6WdNktlKaHFEhlLfXVKT9L+cUKbTirJljbk+CT5fCWdUEqU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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk4lGsbx8XYKi3CsR/itHCSrKX0OBdRX9tBIeEraeOcE9o0qZwa6otP
WnTS4lMoqbRRStxPQ4sYjZ1CtrKOGTOT5VSc5p73e65rrrnea+b9P/f//7uf
xTR4l9dWRQUFhZzvH9k3r1w2pHAuKz4qwGKwKIn7eU7AKSksOTLv56n6LPDK
N47t85TCqfEQtXCYDto5Hm1sLSkYveM5Hf5mAPXp4c4T6yVwfLi5WPW1OVxM
kQ0JDOXdSj77bB4EnJIJSmDdoVeSO9QOfvyulm8sAYHD5rt2e5ZAO1vru6IY
qkJry74udYUMmVy6GHzn32ka5a6A7dtkQwwN2mmRpT94wlwUFMPRFyzXII4P
9HvKChyE0wVjNsEHAgHLyxmEPz3E7PVWWyBCJhc+CEr//lNdXLsD7GxlYxAC
QqevClAIh6E5MkERvFy4c+hE3B5Au/kiWJk6+fCwAxsOyspji+DC0VDfG7di
YKlMzlkEh/5ykr4xigUFHCK4Mj+M559xEuJk9mKFYCPdKKgqTIJJGJAQ9m2y
JI8+nwN5vgOgeWTNSy/zi0yeA2CYK8xrck5j8hOA9qwn/p4GGUxeAjg5tk6v
vDyLyacfdPTd/tZj54AF5tEPHhU3Ry9nPWD894H9m/D9x4sfMX77IEtZOGHy
7QJ4gv56YffjRayVXMr46YXePu4aDacSKJaVx+2Bn5ZJWE7er2G5TM6jB9iH
wjcEzOKBvF+6YWyv6eXg7ZVMf3RD5LGqYp+8GmjAfuiCp089/sr6bwMEIv8u
mH/8xz0xis0M709w/2CyzZsZbQzfTxDf/dZLU72T4fkRZrrdmRn1WxfD7yP0
rVu5Y9q/+hhenSBoeyNJzhFCNPLphI3OqRHZ3mKYgDw6YUKb0rCq6WeGRwfE
79bM2eU+wvDogM9Wtrmssi8Mj3ZwaRwZ6skbZ3i0Q366oHGGqiKV82iD7jGb
ZvffWVTOow1cUgI9S6epUjmPVggs8Jp5QapO5TxaIXhpUl+QgQYNQv8fwCnB
bOoD12l0B/ptgYULR92djDRpJPprhkfucZu69LWo3E8TbGodclR11qHy+t+D
MHOjd8IxXSqv9x0ENUiOsQb06WWsrxHKuNkbkg4a0etYTwNkx+vU/a5tQu9h
P9SDNHVz0aRDpvQp8q+DkTnj+WzJTFqCvGuhnDU92Wu/Oa1AvjVg6BPD61GZ
ReU8q0GvqNnHJ2027UR+VdCh9OuVXb/MpXJelTD6+GZRZZcFHUE+fFi3Razc
nvQzla8PPvzk4Hq9ZpEV1cV8K6ClfjT74Yf5FP8+pxwE7POxD8GaumA/voEb
I4YdLScXUD/sr9fwW1m+pGCtDZPfS+i0q0jPmmxLYzCvEtBTdP1Dhdoy+XDh
RPwla5cddjQL86DAKbw4ha9kT/ExvBBqlQw9lp22p2mY3xOQBFm9XzHVgfLx
9TxYnpPSfSPagYrQ331YXChMWdPgQF2w3tvgPU83ycfUkZk/AzJVWm8p+zpS
inopMHI6zLQq6v+/c6DkTEhxSJwjVcDnPeRYvGvUxSOO1AWfzxGu6jifE+JI
W3G+q0Tl7cXCnfbf30e5m0SJ77+ZK3agaWjgHrk+lKKx6IoDDcf3c8nanpW7
rts70F/lGxiRFr4f1yi0pyZY7zOyaI17RYqdPcODkvS7LfnJV+xoN873nPyn
Udk2dNSW8pF3McmNXJB7foUtpZjHC5Jb2Txw65QNzcJ+ekX8vcMHlvEW0AtY
XykZ98twUmEtoDHYr2XEJ6zbKNHemsmbR/gZbuvEL62oH66Ht0TRMnruPeN5
zPrhk5GqK+O+ey0ZvUpy3n6cU8KbSxOQZxXR8Nx9+KrFHMpB/Woi8H2bvjVx
Fo1C/zXkwAqvJ6u/mDPz1ZIDJzN6/Xab0RDslzpSUZUQ4j5iSuXnUT3pDY0w
OxdvwuTVQAwqOsu/BRhTN9zvGskz7miwSokBXYL9+I4ksmNOFK3Wo9a4n74n
Sf7DfMsvOkz/NpEy9c3CjnItaoj7QzOBdq5Aq1iTYnlaLURnsePqxOZpVA33
nw/Eha92IdlxCv06Lhvfn7OizD6PTqS4vNitpOd1wUQDBTUqxQlayVqW1ryD
HsqMvzYS3Z5zegFPkfYivzbizOLf0U5UoGh3WzspEPrNTtH4Bq0o2E4cfVOv
Pdw+ypzHHaTU6tHNQLMhqEPeHcSS0xQRsUgC8jw6yZ6QQX7DNRHgdlDeSdon
W3m73e8Hd8znI3G7bzTJPKsb5MvtIzHxNpEEG30EeV6fSJxRwsgDVjs8wnb8
RByuBZ8XZLSADebXRWYUVK+9NNzInFddJDQ7oN9OUAuzsMBukrnqWoLG7iq4
hoa7iWZjmIK6qAJQzriHzKhtW/q1oZQ5L3sIz2Lv9rucF6CJgr2kv8azLafx
OSRigb0krDAod+vRQsDyJvaRnrzMmp7V+cz50EfMjYcblMUPYQx59BH9Q/xc
k7X3QM6jn3Cmadobnc1mzp9+Ytnkt2zHmUz4A3kIiEms6WK/yKsg5yEg+qFW
f5cYXQY5jwGirRA4xebMeeb8GyCshP2tZhpnwB95CElG+L4HO4sTGB5Csj7s
QVFddRxz3xERnoHlp9RJR2Er6olI6xNRXVBoNODf00XklU6+dq7HPkA8bSJi
N8X6hylbI5j7wyBxU6y+5TwxDDbifINE67XiZlFvCMi3q0FyWvXlist6m5j7
3CDZH7w8rDHTD2ZgnmIS3bqLw6ZegPY8xWTj2ds1V9evApQ7JSZOG7ZtuL94
GXM/EJPlyzf8r/IoAXUUlJAA27TSJbqOgLg9JGRogp9vwQ1rwPJiJWTCL4rh
1kdmw3PsJwnR3cKp5k42AcQxLiF5qZFeFg1agHE7S0n94QN2uaDG3M+kZOxt
35bphiNFj7FBpETtkkuhbnZN0T+IM8Zn
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk4lGsbx2lBHC0iJWv5ZKZSMZVlxl05JW0OhUqLklAnEWXryHc+yzm+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          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs4lGkbx4mSQ5tNiXHKIapNiZTK9DClSX2tJZsKpYNqrXNqHfZjGtT3
bWWsImp3EVFaYqWizf1QqV3JOCSKzDg1GM1Rp09Z87zv91yXy/Ve877/5/7/
f/dzsNwf4RM8TU1NrWzqT/W/6YlqKGFDgv+jAfb72vT68UUBPCUEMJaZHOLp
gc8d89RRbyVYaWr0Jvkaw7wytjB+rhKylp11EevbwPOCSKbOcwVI7mqFW0ns
4WKOaijgp4+CLRPJzhDAUwkqwHywLmJsyXqwmFK7Y64A5em0kuUNG6Evfu6U
ohzCvCN0+9f8CwpVcgVyqM/YHXz9vQ8cPqQaU79fGSs4xN4Fi4ng1LOfT1j0
7SAQe6sKlME7R4OVRu+CgZRXJoO2uiSLzIpQiFLJRcqADaJOdmE0rHRSDRms
+fqXh1aMWHi7SCUohVDhZ3ddzSQgdu9IwTDMOUfRkwwJqvLipXAvO/BCpN9/
Yb1KjimFhbzS0bVG6aBGhhR2lurUOASch5Mqe6kSMIiqrzYrzgFdEpAEtM5y
GvhGeUDl+wY4bc6KKItCOs83UGh5Z9Bg9jU6vzFoiFYqWIY36LzGwP9g87ZK
50o6HzHEfm8yva/oNiwheYjhW2Z+5maNe7T/UejYbBORWlNH+x0Frb2o1jnr
IVQTfyPQXDl9p6PD37SfEbh2QAh5xc1wX1Ve/TB8/Kp17MnsNtiskmMPQ55T
SOmd3g6g+kUEAZWJ2Qm7XtL9IQLTkaMWv28RQCfph9eQUZrtqu7XD4GE/2uo
SG7d6ycYonkPwaqrsPrM2xGa7xBYO/Xk1JZIaJ6DMPzaUHL5lJzmNwgmVXYT
/EvjNK8BWO8nrVph+gF+JHwGwPb0C5tUg0+gTngMwAfz0VfHG9QwxaMfuBPX
ZSOeGpji0Q/y0PDpIuMZmOLRB+X8pCoXV21M8eiDE7EPLp67pYcpHkLwktjn
u7P1McVDCB4a5a1XDs7BFA8BhGsH3BiqmospHgJg4E1xTsz5eA/x3wspPjqe
IRPG+Ajx+wrqaq+Ha42b4mjirwd0zSq/1pm7AFN+umHxnrWmeo2WdP0vgcOU
8Li51nS9L+B5Q13FvJ8X4l9IfV0wI0VgPS/XDheRejohMPOpZvTjxbic9MNz
mBY9X1StuxTXEP4dMOzXxDA4vAw/ILyfQezZDkezUAf8lPBtBx6719W9bAWm
eLbBusTGrJD3jniA8GuF5NCffF9uXokpXi2QltXieeVXZ/ye8OFDCketuFS5
ClPrgw9RG1dfrNjqgo1Ivk8hYnuReGveGkxeX/QEtjzjnv2fZC12I/34N9QE
R40vcXHFO0l/PYaY6vZNLseZdH4NYBMbo51YvB5zSF4PoHs8a3fAX4jOpx4K
TPSd8kPd8FWSB4auvb0T/iNumDxG3oPvcg9yKgPccR7JrxryTtr6Z9S7Yz75
vAqOruDYf2KwsJT4qwC//GW5hsEs7Ebq/R1E7DNvrfJY9PyF0HTuD/vTjSyM
iV4O9POijvYO/f/3FBB4bNPukrGwGnmOQbphQUf9xVN65Pk8YlyfqYjpYGEB
mS8fqY8keO4pn/qeyF1Dnrm378fFs3AeMVCO9O1OZHo7s3Ak+f4mOvDn5rOZ
Qnf8DbWBoZ1y3jIjjjteQOr9Ex073L2h8Ut3mgdGu7TsJu5ecMMiMl8dkoTo
lnxh4Ib5hPd9xHr8bZxSG2FM8niIxBdiDE/1MPFV0k+PUNCwjnFUgSvOJvX9
hVJ+qLT127MOc0i/NqJ9OZlePfpr6bybUKFmoN1v91zwTrIemlHoj5ZhVodX
0+uHjyykRcFds1fRei1ox4Pz0+fUrMRnCM9WtJU7MW38sBNOIfptqGXfx1dJ
Jo44lvhvRzGfc2ScDgd6vmfossf2d4ucl+ODpF86UKr26A8erUsxdR49R8b/
3jF57+QSOq9O5NH0hTvPdxHeSPa7LpQcOKt2G9MWu5J+fIEMer6bsZhlgx3I
fvoSpes885MesKL7txvFvSo7aFSwAJuS/aEHqcUmMVImzTApb+4r1HbxfXGy
goFnkv2nF6mz7Uq9LI3wxKRq9CIJO3B5+ql5mCyveAHKajJvSbUxwEoygQCV
XBg8zXirT/sTooETk+oDill4hPATIsO6/jXy3TqY2D3Uh4rXeV8dNtHCAiLY
hzRSq7IsVmjS/vvR6lp+RtN5ddxBePejC/N7wry4n4HKYwBlFZnFCYI+AtkO
ngygd3mMQv2at7CJ5DOISkLOx05wFUAtt0HElQlvraiQApXXEPL8dK6De0wM
t0g7DqElf3g/vbhUBI4kv9dIW7JYy/r4AH1evUY1jt0ure5CsCUFilB7fHLv
RvUeuEwMi1B9BhflenYCkTMfRh0aVx5e3tBOn5fD6EOdeUp+Jx/mEMER9PJo
S9j3okZIIwWOoDn2iTkbZz4CUp7OKJomXs8IktbT5/Uo6oq5tc1qJsBnwmMU
FRUduOvmWw0UDzGqsG92+Zx9kz5/xGj7E53edzfKIZzwGEOGdxvQoKQEKB5j
yEAcm/jb1StA8XiDeGkn9+vtyqfPvzeIv5e3o6LsEuwmPCToUW5cnqZaFlA8
JIjxn+YqRsjP9H1HipipeurGx05DMNGTonK3Tq99aalAXi+QIhPNIyEvujhA
8Ain3tcG7fK18fT9QYb2iMJza71jwJ/MJ0ORXrdMnXwjgNquZChWz7S7fsYR
+j4nQ+va5dkxPvvBgOQpR1apITcmH/gDsectR0J3w3TLQV8gcjw5ysqYlR64
3Iu+H8iRh7Wt9zodNmgTQQUaT7jZXtnsBgQ3W4G2z8vo2m3tAqS8VAWKGDrB
H5Q7QB3pJwX6KtGkxkHPDgiOSQUKWsq8dqrRDEjcTCXa18Hl8i59Sd/PlCgn
wav8koE63CYNokRrogO80xb21P4Djm28vg==
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs4lGkbx4U0S6ESaeVQKmkVOZXwjBxGh6tQ61LbgRz223SgrGTTymHV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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtQTFEYAOBV2TZFRaPxaMpjmyEir3Zm8Z/xyCsMhpQwKyV2Bsu2S48t
uyX0JlGaGCWPRQybFM7BsDHlETY7GDvWM5rBklhC9/73n7lz58w5//ff899z
hqzZtDjeRSQSzfr/dL/58GKaw9E3l4X2h/FceLJTDbbttX+DIYGLXmyooUpB
3oVBWWl3eLCyIKs0tVkGzU3dIWFVXtq4F4EEeE/CdLES+frgGei5s5n69rdU
Pxs9MTMHvdAunTofvZ7MSyHNbQ9bhJ4bu1Qz/7bp7xL03Njxay9zVnlHoefK
HGerok8nxqDnwlyilrgq/Vah14NVt1qMEX0UwHFNIuZuvW8IjohDT8Tyg2aM
Hl4Xj/ld1LfF1hSpTMT1v+koeXrr5nVKrOekdvGCLwGmjcDxpT9pp5/tzY1Q
FXqd9LVcmjps4lb0OqjzltEnc0sSet+o7+S+MYkftTCO8xy0f8vy6frKZDjI
eV+oPXdv+NfyNPQ+09ZnUs8KZQbmf6IB1w2x34P1uP4DLVd9LtI6DbCWq/eW
GitWe2tsWTCW8+20c9+v5x8as9Gz0ZpGVYK8cjfmW2nFCbHZHp2D6x/R6qgC
y/gnuVDIzd+hvmPqHaQrDzK48WXaZr37NO1GvtA/0bGDG0L8/AvgCD8Pdy92
rnD8ysfxHSjdUer9SpMPMt6HUNOgKYWH8nDeCg3mAPtyXa7wffAHLL0bJubg
ejvsrFsbudWyGxL5/UHcD2VDjWqXsH/wXRiqV/hlwwO+P2C/VJ8SZ84S+gdr
PPL8BxRmQjnfX5AaZe/DVQaYwPcfYiLTFXuUesz/BpPElaZ9uh1YrwPci0aI
+pzMEP4vnEmoytrTko7eT0hrC/QxJuvQc8LeQo8F1RFp6P2GRxf2n7s9LhW9
Lngs6fAolqcI/SPnLUPabSuT4R5/Psk81tZ1r2S7cH7JgcEyc7N9G+a7kNjs
jYqSaduwnivJUWXul57XCveDhDjmLDKN1qLnRsJKLP61tRrhfpGBxSOvNs7V
oCcmI+sHHKp7n4SeO3FO+b5YU5Ak3F8iTnkV2G9qEnoScsr28OIVh1q4/+So
Tl5+uUaNXi+i9SnunaBSo+dJ4t/cDwmTqdHzIuHLDhwpc1XDPz7m92o=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tQTFEYAPCrd1uMPJrkuamRkSQaDfEdf1TjD61KIonZ8hqPGGWkx2TJ
o5BWTU+PWlvrsaSlh+yeO6xIKXklpMKUV0OP2Slqo3u/+83cuXPmnO/33fPd
c8TS6KCtJgzD+P9/Rt982LIXCmtcT6b4wSIubNhW7TDjtSEUtnEhYiXJXUML
3KSQlzsa1qyX3PZm77yd8Kx+NKxYF2sz36zwfcB7Vmxbztb52/bHoGfJ6ice
9Xv/4RB6FqxvuvOGeFUieuasrEc/53j0EfTM2OXPi/5s9juGnhkbKEuw02w+
gZ4pK/K/6xT0MBU9EzY6rfW1w+Gz6I1hM2el15n7ZwDH1TPskuqYt8tSzqPH
sAr7xDwrYxbmG2nDzC0BKZU5uH6IZhfU1affz8d6f2mAc1ySfsIl4PjcQRrS
cEPhKS1Eb4DGi+rcMvYo0DPQX42gDitVotdPg496d09boAJPzuuj53tXSzK7
r0EO5/XQrsauph/davR+U7tvNU/fZpdi/k/a2zHwxSe0DNd/o8HhTqdneNyB
KK5eJ82XhyibppSDB+d/pqe+kzaJZSV67bSWWfNppLMK81vo8Oyp9usU1bj+
JV2yvntlvrMWznHztVTm4+PQEqyDZG5cRRlZzfgDM6jQP0a8v39jchyFy/w8
2BlK8t9HCuNasI+ZVejVqQNv3oeFcvfFc+10ON8Cce1Rh42D94XvA03zibUu
FdW4/jOsMkrOSDbdgx38/mDSg6CeK8OVwv7B8Y1b4CRlBTzn+wORiTnSuPBy
oX8wpbXo4dK5d6GA7y+4plloJ4y7A4v5/kPNpaD1TTYazO+HSN803Yi4DOsZ
4NCIqShCclv4v/B411LrFfJS9AbhleprgqzpFnp/4Udms5NJ0U30hqD5o7Eq
QK5GzwjmPpqEgYs3hP6Rx9rb8hb9dWjgzyd5tVe8z3HMdeH8Ev9HthUegdcw
34R4azQD78quYj1TMv2pV5uj81XhfpDdfcfL3RUq9MxIWFjI91R3lXC/CI1v
bHipL0HPgkyfHNHRHFWCniUxzH+dmTq2RLi/pMNcrB7RFqNnRZImJrpsjy0W
7j+RHjmYbb2oGD0RCY14Yu9rUKJnQ16cTo5N1SnRsyUb1a5fwtKU8A/3MAA0

          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw10wtQTFEYAOCtTQ9t8pydaWLGoyFmRakM6T9ChWjaPFJmJKRRSNpZ72Km
wXgV04yMtDVhYpRXE5Fz2tpW25bajdrNY7NTowehUB6he//7z9y5c+ac//vP
/e85U+P2ynfYikSikP/PyJsPCTuU4rzkfP428OHCmV0zKNyTolIhnovRzCLP
C3MoSoMrOSPhxDznRL1P6cmAev1IODLxjxRZ0pGzwHuOzD8jNnu6Lgs9B7bO
ZecGqspGz55Flji4+Oly0BvFMotzT2jCr6Fnx2Lcbid8yc1Hz45lKTxU3msK
0RMza9EnU3TATfRsmc630s1m/y30bFiWNGtu+dAd4Di9iO2uTnZ1+3gXPRE7
J3Pvvun6APOHqeXUxtIru0px/W8auyW5tdjuEdb7RT2n5E1d3lEOHJ8zRLXy
9oehE5+hN0jlhsWBo+oZet/pD33T12SqRm+ALsojrvKOavDmvH7q7x7pZV2q
hcuc94Uu68+NkbTUoveZzvYJV6YX6jG/lwbJg45k33iB67to2bfXy/ftaoLt
XL1Oqh5XpYwfa4R5nG+l0pJCG1l5M3oWulPqcaYz6hXmm6jpQ+L+aHMLrjdS
hd+MhtTZJsjk5mvpfVlXW4WvGdK58WM6OT/n6LZes9A/UVHcycAxK9pAxc/D
5v6DSapAYVwL5ZVPokItZljI++AUEW+0+ptx3gT7WpRlIRtNwv7g8Ot3spUR
rbjeCvRdZGWYfwsk8N8H49tki9VSYf9dcDqmZ2zmn2Zo5PsDtOvv4PzPRqF/
4B7fywIGDHCV7y+sbu5eby8xwAK+/7BMVZAYurAJ8wegsST8WNGBRqz3HVpX
++nDLr8Q/i/Myy2bUBHXgN4Q9H9s+HBhTT16v+Dh2mBSsF6P3m/oTNwT3KOs
Q28YvnlnFF+6pxP6RwaH2ifYiHTQwJ9PUlnnUWWKrRXOL7nuldAhNjzHfFty
PibaqSDiOdYTkxW+xsgxb7XC/SDH+6bNfKnQomdHQnr6npVItcL9InpJt2Oa
ugY9e7Ju1iZLsKIGPQey9emkCk+vGuH+ksEBpWl7nwY9R1InJnVhpRrh/pOM
8cknV6Vr0BtNUtU+2tZwDXrOpN0poer4dA16EqI2XAx487Ma/gHq4AhG
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAPC5mc4XPbCHFWEZK8qknJpk8N2wMCuU7N0fFflIW6WGLwqp
zEx7qCW9ZWmxplamRoRanYOaWmpURmaWe7nm1OVkS10+KO/97geXy+Gc7/fd
891zFh+Oj4gWCgSCkP/P1JsLV5qqLCJZBWkgZcOF5icnevsk50AMG860r2hl
jW9rAdy9MxVO9EnlJ9WimHvQ1joVYmquz3kpaSkGzhPTyorelLUBj9BzpLeT
q9/MmyhDz4E6BXn4a90r0JtGF7i5O1FdFXr2dIZ3efmFoRfo2dP7+TuG4zZV
oyeieZarR28ZXqEnpJe7A94qEih6dvSB8mzPaXkdsFyrgJaNeyetEb1FT0Cd
QkbmRSmaMH+SuAU2StOuvMf14+TbTYtBTtuw3hgJF8aExio+AsvfsZHICYlo
/93P6I0Sm+xNqbThC3rDJCWybJXb8g70rCTXGjFU9b4TfFnPQs4vMS1bUvED
brPeEMl9Htfc+F2Fnpl4LEzICFBoMH+A0N6Osfh0Ha43kiNZScGLE/UQxdb7
RTIUteWlqQZYzfo6Eqb0nBBkGtFTk2zNM8OpzH7M7yS2ulpTVKQJ17eTWvnG
0BbxIOSz8+/I3L0+n6p8zHCWHVcTSXjzHA+lme+f4IafStRnMEMRNw/+vfLS
nWZ+/A6OznQZPdlghkDOhxNtD8f3HOPnO6Ho4vWg/p5B/vtgpmzXyer637he
Byd2tHveyjFBLLc/2P80a3peyAC/f3BI8Fqb7dwPH7n+QEpsvv+RLn6/Zljo
XilXkl4o5PoLfeF26Z41BvDj+g9BxerBupZfmG+FDc2XBtdZ9VhvGFYUPtgm
89Xz/xdeSU8FN2X2oGcD2TddY55Rh94YpF4r2Dl2QIfeOJSkaw+F6bToTcLs
kd0rjElavn9M5EhFTtgsLXzgzifjpR8NldRo+PPLvP7e3rRepsF8IfN3a7Tw
3FIN1hMxXQ2hKju9mr8fjMV0Y0H/YzV69oyPRC3NSFPz94uxFv897rVFjZ4D
M71EOx881eg5Mve3F/qXW/nzJ2Zyl/tttT1ToSdmll7vKCtMVPH3nzEeNP4c
CFSh58z8idtTHzFNhZ4Lszl61LL5azd6rox8mfuZfY+74R8geBj0
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10w1MU1cUAODXUv4bZIqMzRGjOBGlgbXFkEV3rkA0Zs5ENEajEkUGykY2
simJTGwsxcESoygGSBOZOkwFNUHEUH/uBSGkwPCHoFSzoevoBPnb3mv56QMn
7513kpeXm3vOd/LOu3dZ5nfpX6s5jtv0/pl/y6FlXb05/5T6lYFBilD2VYj6
gG20GrKlCGHZLc8iPhu9AtVV8xHMyppan9+cqIffu+cjiK0vdjd0dTSA7AWx
8vO31DPf3kEvkGXoVe1vv7+HXgB79Emt5c0YQ8+fjR9pT64YeIiehv2clefx
hXegp2HbFpVYj5Z1oufHnI2x6p07etBTs+WR2hZu3RP0VOxRkmjQmnpB4ro5
1tm61bVZ7EOPY7cbZ2N+uNOP9XM0scMwFtL8EvNF+vaakJEVPID9fLTVkTbc
s+s1SHzVNO3f6LC07XOhN0U/PzNTbq8cRM9Ll5y4fnww7A16Ao1xD6cb2odB
L3k8/SNj9QsHHYVKyfuX2jSN+ZdNE+hNUP9z2sMv0v7D+hE6lthhvrBawPwh
ajbZsj7WeSFL6uem2x+kp6rTpiBR8l20s8/69HTmDHqvaEx97ansAhHrnfTp
3lXu+Lw5zO+lhWUqZ3QkR85I+w6aYjSepz0cMUnrZhrt2f/ju50qopyYsCax
K9KmIjXyPtzdc/ae+FBZO+BXaNIV1KlIsuzDmutHLupzlH0n2Nd+NGBUKd4r
iA64NBhXzGG+C1q3WIsm+XdwSP4++PsD/bq/+uaU74fYvdaLNvssPJbnA8dC
M72BdaIyP6iO2PxbXr0PrPJ8gbcdTLzfMgNGef5wKKVtg3pkGusFKIpO2a5d
M439vPC4pPFT9/Ep5f/C0NowXbxrEr1puFsT1b1p9yR6PrC0xQ5V/OlFT4R9
NqGuKN+L3hwsS433N4d7lfNHGoyH81PtHuiRzyepNf+UezLPo5xfcsB5IWlF
nAfr1STuRI1ONyJgPz8SodmWRm8Lyv0g4sSNhA8tAnoaEtlc+kvpbkG5XyT8
iy1RJr2AXgCpWhmjK1igeIFEdfTLHN84r9xfcirKV3m1l0cviMy+DvYut/PK
/SeWjQnHll7m0Qshhopy867TPHqhJHThYuvZQsXTklsJz7+pyOXhf8PjCVE=

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw10g1IU1EUAOC5zbe3vZmWFWVZpmAlNbMWlpn30A9WaEQ/S0oDzUozC7JZ
lknk/EE0hpRoLEoEKaRf+tNa91VUilY2s7IfXJrGUsNS1mzLyvfOO3B5XM45
3+Hed2elHNi4Sy6TyWL/r7GvGFq+TB9QPklTRRYJwfGJaXfr+3oukd1CaPi/
daVFr6bdJGerxkLNd/ZmWt813iPPW8aC5Q0N0/0tikdE9Fj+Z3lY9aeDT9FT
8fuyNgfnRzWjx/A1Wz6qnBGt6HnzW2rj0to9NvSU/IbdayvfKt6gp+S9glb8
aYjvQE/B39XFdczo+oienJcF7PjzMtWOnhe/LCPR7C7sIgLXIuOticHfuU9f
0JPxceuvfA7N/Ir9o7QuZ/78sJhvWO+hzqGbv65vHcB5bppPp5zXJA8Sga8a
oXcstqY5K3+i56L+fQ/03w3D6Dlp9NIQbWi1E71hmhRr4naGjpCFgjdEi5fn
Gcu+uUml4P2gNsPW0qjBUfQGaU1EwGn7NC8Q+/tpS3GSTd4pB7HeQV3lB3/l
W5WQKszrpa6C7FrdNQYWCH43Tb5yrcJZx4Lo2SmknjVbqzXY30H7j4XX2PK0
WN9GcyZv1u3XjQOzkG+iubFnjs6z+MIJYV9P4yOvbjdv9wPpxdx6wp5KbPCD
C2KeRJWaTGsc0r6JbFjcr4vr84Mlok9ipmb0PHkq5TtIpKmbm22SPDv50px7
Om+eVN9N9EM3FhSYfSFNPB/JPjp+01TrOOn85Ny74ycrHD7QKt4P2aOveFMR
6IPeIPEvqXrtSNKCRbxfsl5nDFt4mQO9eP8kGu4oTmg57B8mc0/dbm87psF5
TrL3uOd8/m81ei5itB7YaCpSozdCJpR2L7PMUqPnJtsCg2WmZyx6HlLPZXl+
H2bRGyX3i1hFW4T0P2Rw37fW4BxSwQvxfUJjbqMr3aoCfL/gbX58O75Mhf1y
sHCRjvcpKpyngAT1RFPKchV6SmjODv2wbrrkKeFIZ0CCz18GPW+IPZS+Wt/D
oMeAcSTkYcILBj0VhBgN9qAGBj0W3AM7vWMuMuixYA6fmZZRKXlqSE1IbtlX
InkayOEGUnzyJI+DVRMCW2dkSZ4WCi/1bzqSzsA/HsDmtw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10gtQTFEYAOBV27bZIouxu3fvThkaGhqJHsT5e3pFthFGeWfDeL9i8qg1
pZioNDYynpVqZhsNJjTNORiNpWgGk6KRWY8aJdpCbQ+695x/5s6dM+f/v/+e
/x7PTbtjtjhIJJIF/5/htxiupKN6ZVIsKUZ+QihIbFfHgRxjJTIIMZJYtR/9
K4Mfo0sXh8OF2BTxadnTLKiudjjkpDx9uq9uWT0SPTl5odU/Co16Qz1n8u36
x1VfTO+oJyOBxlXbuKBm6jmRMIO3d4r2E/WkpKYzp6K93ko9KVk8FDL+Kv5K
PUeS11d9Y2JnG/UcSG1L3qkmQwf1RpBGlNCQZfqJBK5WQuIOPcu+WdJFPQnx
bwnP+/W9m9YP4r69nG514h+a34+9Ol0y1nj20X523GG6HMB7DiCBv9iLc4vw
gHeABETuL55cNmvnebkDiN5v/MccLm+XS0H0unEynJb5BstgpuDZcH50s66p
SA75gvcL20siN+oXKqj3Ezs9L1vuN2kUrW/HVefnlpUWuNP8Npwff/xwzTwl
JAj9vmKVojzzUddYmCH4Vpzcs+GtpWI89VpwSJTfkcpdE2h9Iw7KeP9qh0ZN
819jc5DGw7FQA9nCvgWvPjCOf9rHQYqwfoC5YMuUYnce2I35PGlEjOkDD9fE
fVT5+Nk2abyOri1oQdLSzMFcHQSKPoqYrdgx+gzbb0QBd17c9tLr2Pchm5f5
xlIbT/OtqHnft8Sq4zxsFc+HNl8K/VEwqGXnR0bu4PazyVqoF+eD6vj7TeV2
js0PpZsTzJ1GDi6L80VTY/c25IzlYJY4f7TwXPT8gnINre9Grak9qXNXaGi/
34jYxoRqpBr2f1GWfr9zdrWaer1ofvF2Y90JNfXsSBlk0PcsUlOvH/UPNCmn
cWrqDSLl04Yn17tUbH6Qy/uUXnilgpfi/YSjRd/j1laogN5fOLler4wzqWi9
A6wsjPgkS1XRfo5w62HJntadzJPCPav7ngtrmScFbVii/W4085xAYpmi6A5j
ngwUnhuH3OYwzxmuGI9F1fgyTw67h/yjWr2ZJ4ejTr2+kZOZ5wJL3Ewe9z2Y
NxJ82jes43jmKaCnYn2hXsM8VzBkZKaBSgX/AIUb4+E=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw90gtIk1EUAOBNp04XvvJJopZW25BeijnL7sHMCCnmo6y0ltMyU4qQNLOi
CMMka1DD5lKTskxHpm30wu6PRlT4ohE5c5VZpmWpJUNxrvL/7/XAz8/l3vOd
ew53sfJI0n47Ho+3+f839+diATNT1RuWPfwAhbMhYnhFWz4Ulj9HB9hwYc7l
/v0429eNKjVz4cyE+oQKzZa3qLNjLoRMr3ddvTyvH3GekNlnsjWv0w0Qz4np
T/UZvZ75lXiOTOTqzxqrcoR4DoxjXHHhQPNP4gkYd9t0tzJsgngCJim9/q72
/h/i2TOtDxW3bYcsxLNjRC38NTUZ08TjMxurEs3btVbEch08Rp631vrdjQek
YaZt9o10YIYPXL4N19lvKFT4CIA7b8VdGzwHW7Mcgas3g0VbPVpMo0Jgec00
1hnqIlwMIuJN4RXCxT8Fz12JZ8E9ZRmSFHcP4k3ieP0Lfc+wJ6xhvT+48ttQ
7eFfXnCN9Sbw1Kbwpt0hvsQbx26uHYcyS/1J/ig+ZrgiiwwIIOdHcE1jye/8
vkDIYusN4WeTKr80czCsYv1BrL8lV5hTlxDvE9Zl+NqVGENIvgm/v3nPiuOW
kvNGfC/Mr7Skehmo2P1XOHmdV7DRuBzOsOvHuPdRt7bMJKbz44U3v3skq5fA
DW4fVRzhu8bGSMn6FdKtfKoQaKUQxfmoSNFQ4fKS7ptQ7OmCq+c6pfR+KOis
f4vKQM8PomJ9+cl3F6RwkOsPSVSyPHWSlPaPEsq3pUb7SKGHmw8qaC3S5pgk
dH7oYvSykLU1ErjOzRf13HlhLs6RQAQ3f2RJf8uXyiQkfxL9PZ0TpXaVkHoW
tMrN90fDCO13Ctl0m5SLXouJN43SXvbGFTSJiTeDToQajsZoxMSzotqd1Z/G
z4uJZ0NRbvom7+Pz84OIU55TsjwxdHHvEz547bpkUYqBvF94ktJ+fCyN5ttB
wOqBWuMOWs8e2toXBqcnU08Aar5xS0Ii9QRQFBvzOFdOPQcYi5EnX5ZTzxHU
So+9lxKp5wQqh5WN8fOeELLcg0yV26knhBR1Y8PRndRzBlGwId8wfz8XyB7f
o0lWUE8EXzZWhKzPpN4CCMx12JuRLYZ/ZaDlVw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw10mlME0EUAOC1lFKwKjZVI2CgGC8gQjm6KMq8RBFJrIChISYKCoUQFeuF
aIxXvI2YeiF4RdF4x4InUnRGhR8VMCpeaBqMmFLDIUI5KliV3ZmXbDaTee+b
eW9XnWVckiPhOC7x/zP8FkNBPqWrHPE9BEUJMZIo1Ybe99veoFwhfIhXx1l1
n/ILOlM6HN7kR8+qJ8uvfkMN9cMhJztuFqTNDXAg0ZOT0x860273dFDPi/ht
cm0O9u+mnoxMn7erILewl3qe5O+CpWBWuagnJRNWQVSda4h6UrL1wZVvmtMc
iJ4Haeu4619kk4DoScjRhWGbGtM8QfRGkJrOqpXbJXIQuHqO2EMSPpS3+wBt
mCTfN3en+o2m9W681L7v+UGrL80fwu5lk3QWs5KeN4hTmu8XGGtUIPClLoyD
w1sfKSZQbwBXzqrU9BdNpF4fjou+3lepC6CeE4+qa9MbUwMhUvB68LprmQ+l
yWooEbxfePelIPkt/8nU68IkJTz5xJgptL4dlyz+VDsuZBrN/4HbjqWfSsqb
AQbhPDtu2btlZ2JNKEQIfgvW5ydX7Y+eSb2v2LUmNsCqj6D1TTgnNCZec0RD
8xuxznHbo+FeJJiEfSt+llRnf/c8CnYJ68f4rsFufVEezebHlYU0/7lSGAMX
xX3kXfxyXLdKS9dWNHrPxsbqQ1qIFX2ER104HPSZ7Teh77oodYyCZ/dD57Kz
bLapPM1vQWPWm8JqI3jIE/tD3OWxtopwnvWPBpruBM6ezsNrcT4oT5JveTqJ
eV0ou7rsp0nJwzlxvihLf9QyQ85DtDh/1Bpa+nvlXy2tdyJtUIu9bEBLz+tD
jsSPkQqnln1flNTWKzf90lLPhd5lykpk/9eiN4g4Y4U6rpt5Q8h2XJPmdDLP
jTLn3stwDTCPA7jZ3Khya+GV+H9Camp+4Hgpz/5fKD9/cvxbH9a/BMICzruD
lez+HpDyeE6CYyLrVwrG1p++smCeelKITx8khhDmeYJpUcLqrkjmyaC433dF
SRzzvKC6/8WjxfOZJ4cbG7a0e+mYJwe1xbyzSs88bziw+satjAzm+YCfYXNg
Zy7zRsLBP+aabCPzFLA2tqLIUsjDPz316aI=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 3], 0.6666666666666666], 0, 
          NCache[
           Rational[1, 3], 0.3333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103swVFEYAPCLtbusQmFMSWmqTS+JPBp1Pna3jDKixzQqUyhKUkmT6L29
RlPxRy+mPEqUR3phZc7VQ7aWPKeQMqMx2RbVboaEcu8538ydO2fO9/2+e745
1yk8LmSHMcMwq/4/428+LFjro82/V3trkBsXEjZueVZAg10H2smFOdtY1Ced
eLIb3bwxHmas+L1H5vw/fahWMx5i1tThFD5oZEC8J2aTD+TnxjYPEk/EIrcy
n+sjI8QTstjMalj1wgh4z5Tdf7KypkYlAN4TsLkV9mHBOhHwnoBNyzYRbd4q
Ad4zYT+dEJYW2FgC7xmz1SmMs/6iNfGM2LRt4g21qsnAcRqG1c4Dt6f2dsRj
2McPf7lYFtiT+lFcPef2sS9HppL8v3igbW1QY4oj6TeM6+OVzx31M4Djbwzh
RdrSZIl6JvEGcfpY70vdu1nEG8ALYyo/zmGkxDPggInKQNvdzrCE8/S4JVgt
wBMWwHXO+4n92w/siexbRLwfeOxC7qF+oSup1+HpSdGB3U+XkPwe/OiyZevK
U+4QyfXrxm+/pd6xi/aAxZzfhVVBqQ7PtnkRrxO/9tRE5oQvI/WtWOo5hSnZ
7kPym7DNh2KfjqAVcIXbV+OzmyZ1RFkCnODW5VgrqR3t7AQ6PyYQC28VXvOF
TH4fbXoyFnHE1Y+s1Sj1cNPr+CI/8OJ9FFbT9ltnJSP7rahwQrO+cIuMfh9K
8K1on31VRvK7kGnprM9lVTKI5s+HJjk11Ph3yej5kbQ8b2x4RAb1/HxQojZG
utRGTueHvPN8pXlSOWTw80UWSj9Vkrcc3Pn5o7NrPsXvCZCTegPSn/8Y/z1U
TvoNoHL1+iqPGOoNIhuNNjQmiXpDaFrgqCE1hXrDKNbFK/1eOvX+ou66sJCc
B9QbRV8bi7MSK6jHQOSz3BLHd3Ko4+8nZAR/SD7XJqf3F0xNZu+630PrjWHK
m4TTxwdpPxPY6+ykZEQK+n9AvqrsyVxbBfEE0N6bWW2YqaD/F8jienLCFyuI
J4S2aTq0f7mCeCIIeVW5e0YA9cRw+0x/3r6N1BNDb7OLVUQ49cxA01I7dyiW
eubwa1VLk3si9STwJmPdUnsl9Swg6o9/9t1LCvgH+d3wgw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[11, 15], 0.7333333333333333], 0, 
          NCache[
           Rational[4, 15], 0.26666666666666666`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10nlIVEEYAPD1tauru6CkmJJh2mGtlbIeVKbzqZlK6h5u2XpG2oWUqHRs
dirUH0IlVniUiWG3lrVJkjHTqdZuamFlUUpWFirmtSaale/NfPB4DPN9v+/N
98ZjS5Z2KycSiSL/PzNvIeSkIMgnO0zyDvnxISON4W8Hn9/rRdv4sCMZiqz6
DN0wKiudCVsyFlbxPTFwAplNMyElrmIPk0eECARPSgYSdX/1y8UgeDaEKwtz
wnopCJ41qd1xvHagTQ6CJyH5umsyL7MDCJ6YFI1xd+akOVJPTH5HZ1qGPZ2p
N4vs8zQUW+a5Uo8jZm5vqvVGN+pZkacON31JuzvwnElE4lGhKsrkQT0RKRt8
15jeuYDWT+PsoL9LO5wW0/wpzP0Z8nxUsIT2m8TOFatC27y9gedLJ3B743Tx
UscV1PuNx75s8vKt9KWeBfdNFo8uTlFSbxR3Vxc09Ib7g5L3RvDT+DzvmoRA
KOG9IWyf525YXr6Ser/weOGhfi+HIFrfj92x3NFcH0zzf2JNjiI7fx1ABt/v
Oz543c7+9fNQ8OX9HtyeejL/Y0I49brxrreZu+xH1tL6TrwndPX63lPraP4b
XJkTospdGAWn+f0WHPJ5w8Pky9FwlF83YPV7vyMB8vVsfiJdutOTJ3ExUCns
I0M9cuvbGUvXLSja5orfUHIcrBR8dMwzWOWsUNH9TiQyxrbe7VCx70NrjQlJ
JUo1ze9BNyIVTXZZatghnA/VWefcN1ap2fmRbluM4VarGtqE+SArY1pA5bia
zQ81rTlQ92iuBs4L80UVaP8PyxoN+AvzR7uHnNK6kjS0fhR97XuV8nO/hvaz
IEX1soubz2jY/0UXHlzVG2qZN4G6W32WbGpi3iSaCik5OqeLeVMoccCc8nKM
edOIW3G4ukCmZfODJInL7dj5Wngl3E/InfIODvDXsvsL5wyXbSIitbSeg5R5
j91O6LW03yzoX9Qml2QyTwz6BV/EzXnME0Ovz/CH94XMk4DryKnZUM48a/iz
7/EnyXXm2cDZ+So35X3mSSH54aVE0zPmSeFbg6z942vm2YJt0aH07V3Ms4M8
o0vVnj7myaDmZtwL+Tjz5PBLe6lZycXDP3jd418=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 5], 0.8], 0, 
          NCache[
           Rational[1, 5], 0.2]], Thickness[Large], LineBox[CompressedData["
1:eJw10w1MjGEcAPBzdXVX2aSUQnb6YivqLh8Rz99ol7STdOnqPmKcr0S6Ddsp
zPJZPsY4w86wSWHOR8I8z7IkQr5d1E5ttWQ++iId0fv+3//27t2z5/n//u/z
f59HvnxD2kqxSCRS/X+G3nz4sFuWwJgWUwtRcuHNwl8Gr1T86CImLrzYuMdZ
Z4IS/5CT1qGQsdFvlxwNC3GHp/VDIWX2Dzutl7tkwHtSdmpweFWY/wjgPU+W
Wrs/SLLCD3jPg+3d3TZJ9jUAeE/CIsxF6z5WBqPnzqILPXwdtSHoubOqkLvm
g0fk6LmxTkde3tvOUPTETNfSvmmOOQK9YSwjmga+iJkEHFcvYvr++OS4yCj0
RKzSFiW9o5+C+X+pdHV3buX6WFzvotRt8d6R6UqsN0AfrbnkTDBNBY639tPB
olnp7Reno/eL2qwVcUHymej1UcuvhtMBrxPQ66GF7XtKFbUEFJzXTY+NLlZU
F82FE5z3g16LLim+C/PQ+06Vkqmx/hMTMf8LXZZmtyyYpsL1HdSrsVUxb+0C
WMHVa6NtyQ+KqtlCiOH8Vurz3E/XpFSj56Se26+kZupTMd9BJ1xIuXb//GJc
/4rWWDZGTelIg0PcfB39+qrcf1FoOmznxlU0fpa6aXaKRuifSLtQuXmLIQNs
/DwJN2vLCzOW4riOOMG7ergyE2bwPpnf6HjR0ZOJ8w5yo73iTfoZrfB9ZIzE
lmtSZOH6VlJvb8svuJEFq/n9kdRzM0adjcwW9k+SKmy+ZaXZ0MD3h5guFzbU
dGYL/SMDDz+Kb4MOTvH9JeNd986/L9VBHN9/clzyzTz5nQ7ze0jzAWffjmA9
1usj1ddl/eu1euH/Eo2pQZV7VI9ePxE/P/yn+YkevQFSqTkuDxQZ0HORhJ9L
ErWxBvT+kt58o91pNAj9g/jXydZP+w3wjD+f8EZddmTfTYNwfkGzK6lc0iTk
i6HEb/eErWIj1nOD+NmfezwjjML9gH31MP+lyoieOyS6Ki72rjIK9wtSZL/z
S4qN6HmAfFDabD8neJ4Q9HSDahsVPCnUPlSrxY2CJ4WMUVdcmm7Bk8HOrWcL
aiQ56HlBWdLJcK1vDnreYDl8wT9vbA56PjCuYN1V78gc+AdAFeWM
          "]]}, 
        {RGBColor[
          NCache[
           Rational[13, 15], 0.8666666666666667], 0, 
          NCache[
           Rational[2, 15], 0.13333333333333333`]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1031ME0kUAPDS0lJBrecHUVRKo1GxyIeiVlDnSS5SMSBYjacVqaW028ZL
Tw2EQyEiGPHzbCTGGsAaNSqG8yunAf+YMQQSUFFbJOclIoiiRjyLRxAOrp7s
vn3JZjOZeb+383ZGY3ZuzJNKJJLU78/YW4jxzHjt+ucMbx9ZwkcYq4oM/L71
yn/Eykcoi96d8lnfq4Bz7rEYx25fGKrIKVDB40djoWST79jDS1OnguApWQcJ
KoHIGSB4IaxePS02bW0kCJ6CvTFOD7/Yo0FPzgzm+jPd7XPRC2aeFVxB7ch8
9IKZS9M4y5itRU/GjG+SnF+/xaInZaOeCIM6PwG9INZmD3/b5VoCPPdIwhRF
striv5aiJ2FlhU1Fdww6zA/QiNTOvofSZFw/SuXalxmXP63CeiP037PuOuMJ
AJ53D9PjX9viK/Qp6A1RX8WXH+bE/IjeIM0/2uCLXrkWvQEqUzFH3X49LOa9
f+h1d3XE+f40OMt7/bRDdfzIwZp09PzUO6lZ8y0lE/P76JdnExZcbM/C9R/o
44cFv90qM4CFr9dLIzo3fEzI2AzxvN9Dm9fvW7Uhfgt6XXTvkC135tytmP+C
xnHbb7o1RlzvoyfbE1vi1Nlwip9voTE6V3z55Bw4wI/r6WHD4PLnhSaxfxKZ
xZSr3bYTPMI8UU7fps5daMZxCwlSVt5VvTeDTvCJJ/nXn6NO5+L8C2Ktu7rA
FWMRv4/0/tTql9214PoeEmvI85sS8oAT9kcSvY2vT3ryxP2TS/2ucr3cCk+F
/pBApc8UutMq9o/ELYt6MukPK1QJ/SULDy0q3SG1QaLQfxIoPp/UvM6G+QNk
841fqgaO2bDeIFlxZXFNYYtN/L9E4evObJVy6A2T+V6nPFPHoTdCijS6KLOD
Q2+UBF5N/ZDu5tALkAfdm6q3NHFi/2C99v7w/b85aBPOJ2Q5d1luTbOL5xde
6dU+LsmO+VK41phcOjHbjvVk0GTiylqL7eL9gPLKhjUPquzoBcP+sD87pzSI
nhycceZTXc9FTwHeoXsfU/yiFwIl75KjN41ziPcX9mTdy9FqHOgpIeGpqv7l
cod4/2Fl8+oLJekO9EIhqiPNrzY70AuDeTVdKm++6I2H2iMTZ1+qcMD/0gzl
4Q==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[14, 15], 0.9333333333333333], 0, 
          NCache[
           Rational[1, 15], 0.06666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wlIVEEYAOBVV3fVTTIpLUsTQYnExLZWxWV+LStXqEgt6fIoN2019zIs
OrbM7NYivDPNDiqiSDq0cqZCutTuwxQP3OxWSxNlTcv3/vfD4zHM/N//5n8z
XkkZK5KtRSLR4v/P+JsPGbOXHd4w1W2QzOXCkXklTnzkX2MHai4c2Plqj/Wa
Q85QUjwe9swtdMPe/ilu0NgwHlJmE72rSOfgCbwnZaMJ91LsFd7AexI24Cfx
k/j4omfHkpW37cyrZqNnyxZ0hP2xvJqDnpiFukrL5y0LRE/MfMoLr7p0ytGz
YWne2VlHqxToWbPcRi/XM6Uh6FmxsetFTt+blMBxDSJWcrW6/V0loCdiXn2z
8raawjF/lAb4WIUpcxfi+hG6TS59tad2Edaz0LQzwdoJnpHA8cXDtGZxS+m0
2ij0hmiPxZNFHV+K3iBd8+D9WtXb5egNUE3Pvu3S/SsgkPP6qU2Zs3X7uhgo
4rxf1LTvVN6B+JXo9dHOn36j/kfjMP8Hza8oCBd/WY3rv9IueVzr/Yx1sJGr
103lkWsjZM4JEMD5XfRD826Ty85E9Dpoak7tA6ehJMxvpmVXFPGnd2zE9a9p
Wtlkf7lYDfnc/BNauFDfXpi7CUzcuIaaM//uvjGWIvRP1Br2RaVWb4YKfp78
aT32edItDY6fkMtzb18S9aZBEO+T5RVJVuETtuB8M3F3j06Pn5QhfB9RuSjr
28YycH0XyX6Ttadbo4UUfn8kMWT+04AmrbB/UjVRHdjpq4MXfH+IaUpE7O9t
OqF/5PAMbR/U66CM7y9R9hUojjjoQc73n7Q8Tm3LUukxf4A8tjT2n8zRY71B
8qOguHjNXb3wf0me4URQUK8evWHitGSmx0EPA3oWYh6qP1GpMqA3QkYuXNz7
zGBAb5Tsahe9XFJiEPoHN8qHN8fUGaCJP58gfm6e5d1hEM4vVF1W5JvHhHxr
KG+pS304w4j1bOB9nG1sd7BRuB8wsjIqRBtjRE8MPz9FVJvSjcL9gjtZrmp5
jhE9OzibrY49Vyp4Esg5NNn3+zXBk0JYanOSe73gSaEh6ObFyA+CZw9tkgWf
c78JngMkfzTu7LYIniPo8wo1RlkmejJofGmrI9Mz4R8+IevX
          "]]}, 
        {RGBColor[1, 0, 0], Thickness[Large], LineBox[CompressedData["
1:eJw102lME0EUAOBaoBSowSNowHiAohZJyuWFwjwvDiUKCAWsIIeCRqICVWuh
R5AE/aEo4FGCiKLiASh4oD9g1gMExAtisEbigQcQMZqKgi1E2X37ks1mMvO+
t/N2xjV5d+Q2oUAgCP7/jL25kDCVF01fOwsE4MuGAyOavTPX33YipLJhz4yE
KTY9D3aBEsNY2DFi2aeHofZu8LR9LMRMlXBK84vl84DzxMzdp2+mLnzgiZ4t
s3/FNY+hcG/0RIyxH/wWZPqhZ8NcWlxpjm1djJ41U71yOqlTLEPPmnmjzJXZ
yAh6Voyy/+/D3gsr0BMyzR0hcdeNq9Abx4Sc7PzctzQIWK5dwNi52uTPbwtB
T8Csbr35Ia9gHeaP0pqUgOKagvW43kIfRc0dUPeGYz0z7UoFmbQ6EljeMEyH
XEpO1Bqi0Buiz2c5l3nXydH7TT3U8fNF5lj0ftGgwKbK6yoF+LCeidqfDz1c
IUuA06z3k7pJu12EhYno/aBVFat1pZ7JmP+NduVuKrvRm4Lr++hf86GOiOZt
sJWt94XGdXtLfB+lgRfr91Anw4bHa97tQO89jY4ddtw7KR3zjTSxq6WxVL4L
13fSwOisP+kRe+AYO99KJzZWTTu7LwP07PgePZ5z8MOXE5l8/wQfe051PL6a
BeXcPIl5a3X/dq0Sx60kq8izMPzyXljC+SQi79aM1CP7cN5IFJKwnqbE/fz3
kQEqz7S4qXB9D1mnblBIXqlgO7c/ooDXZh/VAX7/pFd6527jeDW84PpD7Nrq
zw+eVPP9I1sW1aeInbKhlOsvqUgOnjD+cDb4cf0n8luDSaOmbMz/RYoz3js1
yHOw3m8Se3PznEl1Ofz/JTO+m6S1Ig16wyQsPbTeP1qDnpl4F5nSA8s06FlI
+7i+7uUfNeiNkgijYdkVVy3fPxj8tuFl/2YtPOPOJyQ5F0UlFGv58wvkzg3H
mBYt5gshz/9J/8xhLdazgq3Vi2Isc3X8/QD/M2mzpJE69KwB7GLcu9U6/n7B
98sDltBzOvREcK68Kb+0SYeeLRwtl2eMfOU9Mew6svBliLUePTGovYI2NkzW
8/cf/iw15e5006NnDw5KzdokLz16DqB0vxp/LUCPngQqVXPiotfq4R/zPfCC

          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., 1.1268448858300088`*^-16}, {20., 
          9.00766043536206*^-16}, {30., 3.036774585421376*^-15}, {40., 
          7.190504796334576*^-15}, {50., 1.4034297239023006`*^-14}, {
          60.00000000000001, 2.4254095448966154`*^-14}, {69.99999999999999, 
          3.856510343712825*^-14}, {80., 5.773893458285357*^-14}, {90., 
          8.260093298063532*^-14}, {99.99999999999999, 
          1.1404172240880819`*^-13}, {110., 1.5300727778243173`*^-13}, {120., 
          2.0045603903198448`*^-13}, {130., 2.572763264541799*^-13}, {140., 
          3.241484987709102*^-13}, {150.00000000000003`, 
          4.013428276695174*^-13}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., 1.2516259902386578`*^-16}, {20., 
          1.0013478561058627`*^-15}, {30., 3.3804237363093524`*^-15}, {40., 
          8.018618268428698*^-15}, {50., 1.5684553652654802`*^-14}, {
          60.00000000000001, 2.7172154710107046`*^-14}, {69.99999999999999, 
          4.331691998522543*^-14}, {80., 6.501197946977559*^-14}, {90., 
          9.321805169685063*^-14}, {99.99999999999999, 
          1.2895861111313199`*^-13}, {110., 1.7328801195559*^-13}, {120., 
          2.2721603503751164`*^-13}, {130., 2.915683131635691*^-13}, {140., 
          3.6676124129824076`*^-13}, {150.00000000000003`, 
          4.524782414883776*^-13}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 3.822185672887343*^-18}, {20., 
          3.089303795374987*^-17}, {30., 1.0661547831847365`*^-16}, {40., 
          2.6259315221757317`*^-16}, {50., 5.434236781607203*^-16}, {
          60.00000000000001, 1.0171991563832349`*^-15}, {69.99999999999999, 
          1.7910121763723023`*^-15}, {80., 3.0421348036029624`*^-15}, {90., 
          5.0564973590283085`*^-15}, {99.99999999999999, 
          8.236085755550265*^-15}, {110., 1.3232280082242585`*^-14}, {120., 
          2.098737261525899*^-14}, {130., 3.266609892632882*^-14}, {140., 
          5.020320390672691*^-14}, {150.00000000000003`, 
          7.541597270037628*^-14}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(Prx) [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: Prz/10, Blue: Prx, Red: Pry\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.013352259145790552`}, {
          20., -0.10678197779040813`}, {30., -0.3602598292005943}, {
          40., -0.85386682292628}, {50., -1.66856641830285}, {
          60.00000000000001, -2.887594882916289}, {
          69.99999999999999, -4.598332626625347}, {80., -6.894318242172558}, {
          90., -9.876872630266988}, {99.99999999999999, -13.65559453330161}, {
          110., -18.346741529591057`}, {120., -24.06821163039869}, {
          130., -30.929549027316163`}, {140., -39.015317659630846`}, {
          150.00000000000003`, -48.36075862641975}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -0.013128962901097638`}, {
          20., -0.10498254548440579`}, {30., -0.3541140389212944}, {
          40., -0.8390600983644279}, {50., -1.63904969055478}, {
          60.00000000000001, -2.835319438948343}, {
          69.99999999999999, -4.512871507131199}, {80., -6.762278320895155}, {
          90., -9.680888621530553}, {
          99.99999999999999, -13.372495893454097`}, {
          110., -17.944162289302664`}, {120., -23.498450771799536`}, {
          130., -30.118905885944425`}, {140., -37.846540853579505`}, {
          150.00000000000003`, -46.64595875231702}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 0.1029448848918581}, {20., 0.808688946709511}, {30., 
          2.621840538848983}, {40., 5.7946614120546105`}, {50., 
          10.071754950845254`}, {60.00000000000001, 14.282837653228286`}, {
          69.99999999999999, 16.198654735887608`}, {80., 11.99479771903107}, {
          90., 0.}, {99.99999999999999, 0.}, {110., 0.}, {120., 0.}, {130., 
          0.}, {140., 0.}, {150.00000000000003`, 0.}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kbT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox[
          "\"Black: Uz*10/kbT, Blue: Ux/kbT, Red: Uy/kBT\"", 
           TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.31000000000000005`}, {
          20., -0.31000000000000005`}, {30., -0.31000000000000005`}, {
          40., -0.31000000000000005`}, {50., -0.31000000000000005`}, {
          60.00000000000001, -0.31000000000000005`}, {
          69.99999999999999, -0.31000000000000005`}, {80., 
          0.31999999999999984`}, {90., 0.31999999999999984`}, {
          99.99999999999999, 0.31999999999999984`}, {110., 
          0.31999999999999984`}, {120., 0.31999999999999984`}, {130., 
          0.31999999999999984`}, {140., 0.31999999999999984`}, {
          150.00000000000003`, 0.31999999999999984`}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., 0.26}, {20., 0.26}, {30., 0.26}, {40., 0.26}, {50., 
          0.26}, {60.00000000000001, 0.26}, {69.99999999999999, 0.26}, {80., 
          0.26}, {90., 0.26}, {99.99999999999999, 0.26}, {110., 0.26}, {120., 
          0.26}, {130., 0.26}, {140., 0.26}, {150.00000000000003`, 0.26}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., -0.5999999999999996}, {20., -0.5999999999999996}, {
          30., -0.5999999999999996}, {40., -0.5999999999999996}, {
          50., -0.5999999999999996}, {
          60.00000000000001, -0.5999999999999996}, {
          69.99999999999999, -0.5999999999999996}, {80., -0.5}, {90., -0.5}, {
          99.99999999999999, -0.5}, {110., -0.3999999999999999}, {
          120., -0.3999999999999999}, {130., -0.2999999999999998}, {
          140., -0.2999999999999998}, {
          150.00000000000003`, -0.2999999999999998}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(F): Pos\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: z, Blue: x, Red: y\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.500332267843464*^9, 3.500355941031766*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "5", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"PT", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", "6", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "13", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "7", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Blue", ",", "Thick"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prx) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Prz/10, Blue: Prx, Red: Pry\>\""}], "}"}]}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "14", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{"PT", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "[", 
                 RowBox[{"[", "8", "]"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Pry) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "15", "]"}], "]"}], "]"}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "[", 
                  RowBox[{"[", "9", "]"}], "]"}], "/", "10"}]}]}], "}"}], ",",
              
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Prz) [N]\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "19", "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
                    RowBox[{
                    RowBox[{"Nearest", "[", 
                    RowBox[{
                    RowBox[{"First", "/@", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "19", "]"}], "]"}]}], ",", "0"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Ux/kbT\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", 
                "\"\<Black: Uz*10/kbT, Blue: Ux/kbT, Red: Uy/kBT\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "20", "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"First", "[", "#", "]"}], "\[Equal]", 
                    RowBox[{
                    RowBox[{"Nearest", "[", 
                    RowBox[{
                    RowBox[{"First", "/@", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "20", "]"}], "]"}]}], ",", "0"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Max", "[", 
                   RowBox[{"Last", "/@", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "21", "]"}], "]"}]}], "]"}], "-", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "21", "]"}], "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"Length", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"PT", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "[", 
                    RowBox[{"[", "21", "]"}], "]"}], "]"}], "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "*", "10"}]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], "]"}], ",", 
       
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "10", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(F): Pos\>\"", ",", "\"\<\>\""}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<d[nm]\>\"", ",", "\"\<Black: z, Blue: x, Red: y\>\""}], 
               "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "11", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fy): y-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "*", 
                SuperscriptBox["10", "3"], 
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"PT", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "12", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\"\<Max(Fz): z-Pos\>\"", ",", "\"\<\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\"\<d[nm]\>\"", ",", "\"\<\>\""}], "}"}]}], "}"}]}]}],
           "]"}]}], "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1100"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.500355939017991*^9, {3.500356189370006*^9, 3.500356287012588*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs0lFsbx6eTvuWScorkZCWUqM45onSZzXYORb7KpU4HoSS6fB25VUwt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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgtUjFsbx8f90AVJ8nGkg1LSPSfZeZwjEk6pI6pD6Cjx4SRCU0RXRCYU
+Xy6oj4ditLFrt1Ft+kyUzqVGJruNY2mmVy6LH1mz7vXarXeNTP//fz/v2c/
+9X2+MvJczKLxXry/U/+v7ZGvobJizxzrv+BGYhT8mnlnuvDxLxO3T5RXRU5
5S4JEzkOE9dJjq+TbOeh+U9shWz1YTL6s9iwI14TNSf7WM9qlhGNvev26O3S
Qnfj5EtGlNgmHg2CZWjPdbmgjJje2FiuslAPaX1Xy10iI2NRJgv33TZC7Wz1
74pSoqEX/aMzzwylyOWSpcTXRJI9VGSJDnnJl5Q4ur0LuVi/HulRQSkx9AwY
svtxIxpwlBc4RBzHn+zLi7dFtLwnQ6SeHWhgtOA3dEIu5zNEdI723jvd4ojM
zeRriGiFNZkE853R55VyQQmZ5hFXGRzthqjdXAmZNN2kLH3JfhQgL48tIXlH
3gStOvcnWi+Xs5aQsGnPI8v9DyEWXRLSm9NdeNXgKAqX2wsbJI1xz0wWtvgg
JRrQIBHH8xPU555i8v1IBm1unt9df4bJ8yORDKe8PKQfyOQnJrdmtprF3r7A
5CUmx6t8kwb9Q5h8BshCnSNuo+XhSJ/mMUA64gu8xy9fYfyLCO8l2GfURTF+
RaTpmE7MTX40yqP++smdCXWVhvBbjJ9+MnmLwNaScxuVyssr6SMzrjuXNUrv
oi1yOds+Mm/QrSc46z5S9Esv2RLX5+p5LJHpj16ipFFf7J6djFpoP/QQzZPr
J3ubP0R7Kf8e0u6wbZbrQCrDu5uYjZpzbrx/zPD9/hx9u6tX6SnDs4tsm6Tr
a2uVyfDrItN1rfNZys8ZXp0kpdBvEXs0CwVSPp3ETLBNFj81B02iPDrJmKgi
pG9lHsOjg7iHRmMnz5cMjw5yyjq3YHdOAcOjnQylhq8aUSlieLSTcsuIDzW2
xQwPIYnFLNefIkoYHkKi+2u0ak5VKcOjjSzmnbFQVSljeLSRkAOX8v3sy5E7
9f+BCK7aRShHViBv6vc9sbZzn8IllciX+hMQw1btvPC+KsbPO2JQfGJs2rRq
pv63JI3v4cGaXcPU20ry8/aLDafWonu0vjfky8WtN3cJa9FDWk8LWetUMXVn
ch3KoP3QTFZXhnro2vJQPuXfRLT9z6ROVPHQK8r7HxIBOyqT1PmojvJtJMEO
iW+cTPgMz9dkT5KgWdmKjzopvwayqEFD8+tqPsOrnsy9Yld/WJmPvlI+fGK+
AEXy0njM+eATjsEn952qPKRJ860jWfuPCtZurkP06ytriHFsxkfiWIs20H7k
kpbPG+dEmdQgF9pflUTzfqtXZjeXya+cbEtfER3nW4Uu0LxeEZZz1l715gom
nxJip11/eYtGOUqleRSRca91mU9NXyH66FNAuOU5sbONSlACzS+P5C+pEfmq
FiE+/Xk2eaF/029j6kskof4yiWtn2jKzGTloA603nQRB5BylX54x+6cQrvHJ
ipb8/6EiqhdHnk5/YuFVmcB8HkqWvUg6biS6glj0+RScNmaN/UfMxhvo8y2o
sXweGiS8i9vofolwNqkqUOn4I3yByqWBtruvLC8pAydQAxmQrsMK4JzMxj70
91kwc9dYWYN2Pt6hGGAwbgGC2Q8L8VJaL4anB5w2xAYWYwWPInD+YXbs2iul
uJfuVwzXNvUN1p8tw3zKuxTcdI0KL26qwEU0jzLw9vovyhZX4lTaTxWwnid0
0fuLi+/Q+qrAauvEt6GKanyB9ms15Bd/Sg76XIMVedfC3kxOd/JILXah54EH
J6/e1orh12HF+eGDt3JLgYTNY/TqodI+1gF/5eGrlGcDTN70hmO6go9Dqf5r
eNAfarrPko/PUv+NsCb8c9/5NXxmv3+Ac6Lu2B9L+fgg7Zcm2Guj7dIo5mHF
fdQMd8wWj3FO85i8WmBmx+eg44I6bEPn3RvoLbzRsmpFHUa0H1vhReOysPwd
tdiYztO3EOOS72D2Zw1W9O87eBijksrdV40X0/kggITNxu9f2XExLU/9PZy8
1cs+srwK/0DnzwdwPnNeOi6twOMT8vUBSkLmiB7nlmN6vNhtsDNMbWvkdx7D
dIM2UDpcanHF4hXjTwjP2X5G/5aW4H7KTwjnbKo8CjKLMbXr1Q66AXzU7FeE
26hgO6iWx6SlXCxk/HfAr6nb7efqYdxEeXfApUv1FjpdeUwenaA1IQy5kZuD
6Tio6QQdj4CA0AfZeDPNpwvMrVNc//77OVYcty6IaRWxbBsymby6ISp0xHCR
egZ+QduxG0YTuzsW9KRjU5pfD6hdq15uJUzDivuqB3b3yOzH5z/COrTAXvDU
fLtYPzQFJ1HDveBcbTF9rn4SpnJL+mCKwGhdzLQErJjPfbDakcu6uvIeVqOC
/RDF+7Ks/eEdHEUL7IfZ9x9cPnwhBtPyZong8vl0N+2nN7BivopgRaO/bZ8B
B3+jPESwtrDY1LInkuExANxHnGO/jUZgxf0zALNK11j9HBGKj1MeYrAXJteH
BV9keIjhscqDXfdKzjE8PgIa6cVsU3+suP8+wpSK3Q3bf/HDbpTHIDSNJLTP
F5xgeAzCrVSZ9/n+Y1jxviOB2Dz2GtNP3tiT6knAbxfa/rjwIKZfT5aAjlaM
8fjqA5jiEUrg4LVDytGue7DivhoCpy+aahvtd+M/6H5DkKgCdljjd6wYV0OA
qidkRboOWPE+NwQlr1UM23fa4Xk0TylsE7S3eYfZYGrPUQpT3/RHIc4GTOWu
S0GkbbNAnGyFFe8HUjhj4jo52MUCz6SCMhi5e88naJYJprhtZfB7lOo31cWr
MC0vTAbxBeEO+oErcDHtJxl4HXD4afmXpZjimJDB+vbrearP/oVp3NbDkDWx
UA2J1bHi/WwYIodd1ba4zME5tEGGISSaa3DZZyb+P8h3r5Q=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk4ldsax6Xx5N5UR3UobmlSuidK3dLS8uCkW1SodKQTpzToJEUT9kmm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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs41Nkbx0dtW+myT9HNRhdqlVaKTeqMo6tCNkqRktQk1FLpz7ItEqlV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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgdUVFcax6kylGE2SnBhPcSIFHExWAF9Lx9ZUYyuRrAsUhQIRUoQRVAR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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgdQVMkWhokSBCSn0RUXEzzEfaL7DPfa6IqIAcWECV0QEBUJuisIBnSB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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtYjNkfxytLoxtRiXRvEkotkXjPHmRF+fsrSUthUdmlUv48to0uSMV2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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgdUVEkWhhsJKsqSQUGSSGyhWxZxXF5RMONgXNOOrgmcATGtIMlZQWDE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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgtYjNsax1MqRiRlU0i33ZWkqZlj+9Ze0UnuVJSdZES0cZQOdqdoh8pp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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fx [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs4lGkbx2err02124axvg4qSbSdpG1lnrp1EOkksRSjzZIohbClbGql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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgdUU9kWhoNlEHniiMwoFhDH3hFhUA5s0AjqsyHDgEwQG2AfsCwReDNU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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs41Fkfx8dK6arZRLJLeJNUUiqVo2N3vZRSuZWXxFYTJYzLvkWTa7Rq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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs0ldkbxs/RmCWmUi5RFllMoYZCTTX7eGWK0k13kuhChgoxQ1KpwWi6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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk0VV0bxxGFG7mZajWQfMIbXxkqvee0FV+GUpQGlTGaqJAG4kWGSgNp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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs8lFkfx0cXt0TjfhnjsvuKUrmki30eR1ahvEqtTSmXjVIJZXtLtbnk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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lWkbx5WUmIyQtFiO5ZxTTZt8ab55X4+vBS0yfJqUrWSdqcgySqZM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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs41Fkfx90q2S3R5K0MuQ5JjImt99n/cSRFJRu6qm1zTW+ble2yqd4Q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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs0lFsbx0d0hM7qpkS5JTIk4xJmvNtW+VCcBnVOF536KuIgZ9xKF+Ur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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fy [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10ntQTFEYAPBrbe1u6zET8g55FUlIE12dQw+SpTSrkUpSGyOymiKqfVUa
9g8GQ1trGoqMZ6MJdTnH0Jg7k6YmjFBaURIjZJGd0L2fb+bOnTPn+37fOd+c
GUnpG1MkDMOs/vcN/cUYQd0OGwNCJZHsEiGU9K4p2FXnG8VqhHChd/06Jr7I
2chaiodCQS0qN29ZbzT7uGEo5PRVanBdoE7Nip6c8l93HwoNigFPRreu5C6X
LdgMnjOt6YoYczx6C3hOdFbBGsuKW/HgSenVLK+Rqb6J4Emp/4ntuP7KNvCG
07eLrz1yqLeDJ6H3+qZ6DC5KAW8Y7Z6g0O9dncoKXANDzfae0JvWneAx1Ha/
NLaZTYP6QWKYZ2mPW5AO+Q7ynPSXubJa6PebtEl+nG51zWAFvvgXmZEfZ65x
zwTvJ9FUb5runrQfPDux+tvHorZs8PrJh9q5DoM5h10seN9Iu4vSa69Gx54R
vC/EaLx0KsvbAF4fMfpwye/PGaH+I1kZkRRp/WOC/B6y4am1KMijgE0W+nWR
i41Yb+0oYH0Fv5O8Y/hes7wQvA6yPtzQrU4pgPpWsnn+54VFvAnyW8inNzUx
y6cY2GPCPk8ye7vLTzQcZPXC+g5RyrrWBVZr/8+PUdvO70koTGDLxH2k2xMb
P0EVwolrHjk/bPSMe5LKBYg+OuJ5riiKz4D9VvR2mTlzRV02B+dDnz35mjMV
uZDfiVrWXrTIqnTcDvF+KM4vsvbZeD0H90cLS62KNJOOaxLng27kRiyrdMkD
rw8F0pP52nE5XKk4X2R8MntTpS2b8xPnjwpHGzQlJfuhvh95zYq3NSVmQj87
qrKPV+4OzgDvJ8qvmFaXoNKC9wvJhu3L++aUDt5vVCsN63jN7wLPgfyMrW1Z
nTvAG0QNHsvf+Kg04DE4r2tOVjiTzDWK7xMv/fMivfz7Ng7eLy4p87EHzEmE
egkOqo7VP3KLh37DMf/lR+WYoFjwpLhxpuK96lYMeFIcZnIMlB5Qg+eEK54p
JodnR4PnjN1v10+6UBUFngy3+/QwA5MiwZPjYoP3y/oEFXhy3Hz9TvOhlrXg
KfBWbVOf+9E14Lngo8yVB69yw8BT4vqqkDRbeQh4I7Dr2VG+/gOruL9CXgAE

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10g1MzGEYAPBT13V9jOVklSIfM2eIijW9vK/zcb4W5bRhWBbJRsrnqDii
cU2XK4RddSdXd3JFH5p/3hcjtS6Zj9bCKAx96Oq0Il/9/49n+++/d+/z/J73
ffZO3JYQtd1JJBIp/33DfyE8mW/z6PiQRcdRCB8e7J4srogmqdEOPtxZxqpu
b+uDE+hy7nC4Md0JNLM6NA3ZGoZDyl7viqvzs51Cgidlqes2dxRr08FzZZ+l
3YGdaWfAk7An124Ygko14Lmw79ONXibfc+CJ2UD+l6qHsVrwxCzuUXOl7kMW
eM5Mf8d7RmaWDjwnZp68r9mamAPeCCZ+NincpLmIeK5BxIZeHpzz7lMueCI2
06xWJmmuQv1vGr4l8sAvdR7kD9HEjTO8SuMLoN9Peuh6WqLvEiPi+dxB2mC4
qepfVwjeACW5qryHV0zg9dODoXveV40zg+egZ9H8TYqmGyiY9/poilz+o8dq
RZd4z06njfRTqlRl4PXQoqa9uvGNt6C+k8ZFuH6MmVUO+V9oRn2YqUZVgWL5
fp/oHBQ9xjG2Es3m/Xa6ZtmKww8UleC9o2/jFV7Rxgqob6HP5Gss/h7lkP+c
znJ97CyJKUNafr+ObvDX12o2WdBxfl1Nk/Lq6kOUhv/zE+k/r1rbsFuL8oV9
LOtyL/u2IIET1nX4WmTXwhbLBS5M8HFba3730TAj7LfgXsUL5/SgYg7Oh8cG
vqndGlgC+e04eUJE65IQK7dTuB+2Lcwo7a22cnB/7OfZofjmbeWahPngNwHW
ivWFJeD14LK2wNo/VRbuqjBfbO9zOWfWFHOhwvxxen1mjna1CeodONZn7sog
n0Lo149vT1bPM4uM4A3gYsPISseoAvAGccSyV8deZOvB+4mXr7QPamKugDeE
d+tKxD4nL4H3G9fkRHU5OXLAExH51NCIghId1yi8T7J/12lbW1EWB++XjNpj
f1lQkwn1TkSSkrz1ZlYG9HMmjbfmdzy9fwY8McHZwTbvxengiUnqV/PAXY9T
4LmQmo/nUwJkJ8GTEMMF1q6PVIPnSu5F0RHT1cfAk5LR/qny6PJk8KRkeYJb
ti74CHhuxDN50P6n9xB47qRPppzS2nUAPA8S/mvp5Rj//eB5EplNEmA5nMT9
BYX9DOY=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw10n1MU1cUAPAHtPKgbFEzF6XqVsVEdBgEYlSe3rs5PvYHGFBQg0OtSg0u
m4GBCtpihgHNukFEHF8FCwooWWGyKvLsvY6PUikIRZZoqOgQ4wdoCdiUgKC8
d3aSl5ebe87v3HtyFcqfYg+7MwwT8fGb+4vhQzUxprpt8aVcsBAy2lO8dSYw
ScclCeFNT97TWQPiKrjiornwoh5n7c68gstcl3UuWBrekhA6NKHnRI+lV749
b4rMqALPkwY7vrie6X8VvHk0U52if+pZA56U+uzRJVfKr4Enod5PVpxtP1oH
noRaV8a9jmAM4HnQJdt/QPKxevDc6Winceew9i/w3Gh2gE0TureREzgrQ2PK
MkrSlEbwGPrKclGjqb4F9TMksM+QdDuoGfKnCRsQvs8kM0G/KeIVuumrd6WU
E/iiSRK2YPX7Bwf+Ac9FluNjFdXxreA5yZ7r1ebazHbwJshI3Z9Vw10dXJDg
jZNfrNmSo2Gd3B+CN0YOyRbLJ2xd4DnIVlV0wpl1PVA/QnblpxbvT+yF/Jek
KWpyd8P3Nu6Q0O85aVJGRhjYPi5Q8IeIHw5XtYX0gfeEJKb+XLP6bxvUPyRq
12uj4mAv5PcRnNc9oont5vKEfQs5mFvStmxZB5clrJvIWNpA+a4M+v/8GFf/
mhNhswauQtxHS1j/waTfU3hxbUGGSl5tlzbwG0UfNZY/+/EbpQn2H6KB4+eK
NdtaeTgfyipfq3qlN0P+ECp0yhdWHrPwR8T7oRVa5Y63DgsP90d3SlrwqTQL
3yPOB20pq60KieoAz4HOOf5NWd7czpeK80W+/f7mz8db+RBx/khru7gh2rcF
6ifQfeaIrOi7u9DPiWKbg9LPf0nAc6FIt/G2M6PN4E2iwZob6b+5NYE3hfof
ud58kmgEbxqp/2Pr9UwjeDNIF5z6+MGzBvAYbLZEd62S1vPd4vvE0nsqor5Z
x8P7xW6zvrvvtNVCvTuWf20tVKyphn4eeOkp+2DloyrwJNjst/fX4G49eBKs
nZ87dWu6AjwpLrsWs36RSQfePOyTkO9ltJeA54lzTi/MiYwqAo/FCjYi18/j
Engsvnt5S9iAswA8L1xgf3FzkeICeN4Y7VtZqMrMB0+G2c7RTzczeeD54EvO
z5Lj47T8B+SHEu8=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10ntMU1cYAPC+eBRcjHMR3cSJaNAwN5RBNLnbOf6hU5HEZ4AJCSsgLBOQ
zVeMzoIMEh9Mq4m9iIgipOOlTFconnoOg8BKK1SkKgIdUKFBUahjCFJx497P
L7m5OTnf9/vO+XICVOnbk2QSieSb/7+ZvxizGF81UNVBqrlQIXxZ/PLaX/Jk
t7g9Qviwf3MeqlHKbS6fnwklu1x+902z6w/unmUmvNnPJwq0muIaTvS8GbU6
9bosA3hebGG76ZTpwh3wPJk8ZGBedq8RPA/WURb49LdwBp6CGfs15O+r9eAp
2Lk1QU4S3gCenJn1m0rYm0bwZCwjZ2vuorEm8KSs53jS9b9WmDiBs0jY2r6l
5RnFZvAkrD8w+Yz6+1aon6ZYnf3pwT+tkO+mxsHha4ePt0O/KapE8wM27Ovg
BJ6fpGVbUp/e0z4Eb4Jazjn2sanH4I3T85bIK9l8F3hjtPGlv6s6zc6tFrx/
6KGfFo6+ru3ltILnopWh7dmajf3gjdLZeVq39JED6oepCnv8GhQ5APlDdM4P
6h9jTg5yiUK/Qcq/i1nwLMHJhQi+g56OCo93lzrB66Uj9kuhk/5OqO+k3XU2
kpw/APkPaIiupOkrmYM7K+ybaIVu/VBqnZ1TC2sD9XmdZ00y2N7PT6LLzUm3
JzRzReI+OrorfHHsFi2sTehk0GcRzeWUrBF9ZHv7RWaCuY2I+52oIivMa+qt
jcD50F0u7v4ivyeQ70CvitPS/KO6SYp4P3Qjt8eV9UEPgfsj5bGI6GG+m1jF
+aAdewKGXNFd4I2ibYZkaRTfSQrE+SKzZqJ0qfYR+VKcPzqgqktdlWmD+jF0
YHvFSHvGA+g3jlgwP/750fvgTaA4yQJp5c428CZRXtfBFyVSC3hTaO/Xl4zB
UhN4bsQnx+83bG0Cbxr5fJuUGvG8ATwJbj12cWdxSz1pFd8nVh16t3illRJ4
v3h6udvld4RAvQz3lQYezs0xQD85vvWRsnJiSA+eAqf3eX4sz78NngLX+Nnn
xp75HTwPXKZK1LTcuQmeJ3boe9qWcVXgeeFNTetajLvLwfPGYR/KozebdeB5
Y8UnBdolmaXgKXFRGPbt2n8dPB+sp1HB/leugeeL2wp7vzsxWQTeLDxCRlJe
uQvJf79OKLI=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10n9MjGEcAPBXP3SlxaySs0bHZqXJdEh763nRUv6gWEMyk0p3yYXlRxv5
ERGRn9PtLIsS51c/Rtk7z5PLJY4Q+qlzzl13zo+Lu1y7E3rfr+/27t2z5/v9
fJ/nuyckXbYy042iqKX/vtE/H76k0RovyVM/oiO5GEfkylb1pqAWOosLH5Jt
SfkUfPwxLS8fDW9yQOncVSZqpZ9rRkNAhKXbIhbqn9C8JyCnldcS579+Cp4X
0aYtt6y3a8AbS/we2ePXrGoHz5MEPXAu6h9+CZ4HkUfspC7KXoPnQVTbpUdU
49+A50429Ilqf2jfgudGbs+3N+QaO8EbQyTyyusxYT00x2ko8t4U7RtR3wce
RbJoh5f6mBbqR3Bc2t6S0nU6yHfhwBteAwkiPfRz4tvW4ps3gg00x5cP4zMK
08GHyQPgOfCcCw2yNc1m8IbwrJR0g2/uF/BsuP5BTdyd5O/0XM77iZ2pGblT
Igfpi5w3iENjFdUFmh/gWXGtOL43IMsG9V8wW7IjZJbZDvlmfHbg/P2ieb/o
DK6fEW8NcYlc0xz0HM7X46Kfc+VojwO8D5hcF3uGejugvhunLonMz6wcgvwO
bJFGaY6G2egybr8N5/Wr986usdL7uXUTHj97ubT4vOn//KjVwiva1or39GV+
H6n94tZ3SlSwbkMi95YOXNfMRvE+KkwXL35Y2cXy+92ooGxFR9DmjyycD62a
0SfVnTJCvh6hc4Lie99MbDZ/P2R2xZ5c3G5m4f6oWr32UmipmX3JzwdFT5g4
Zd8BE3hWJOkpzxU7jKyCny8y+vknLAs3sGJ+/igcBcZFJ+ih3obkSSmDJdk6
6DeEFnQ9K/gVowXPgfp3KqIoSy94w8hn40x7lq4LPCfKX1aft2X6O/BcaHdF
WIvgTgd4I6gn50SgqvAVeBTjvWQk/83UdvYF/z6ZNP+AjMa6Zyy8X2ZpYY3t
j/IJ1LsxSbpm/0mUGvq5M4GZMYuSrqrA82CEsrRat1PN4HkwruO61GAZBs+T
keRc+l4VzoI3lvmcMfmkOLEJPC9msyY526fpHngC5uu3x6XGbQ3gCZieVMva
bmkdeN5MW2KsQai4C54Pk/RJe+jp71vgjWNyDKLDVUIleL6MuSIob39RDfsX
dt0d0g==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw10glME0EUANCltKUHnpFoaqJ4kKhEQTDGxC0z4oEheGE88IonmGhioCre
oFEBjRGVqxWJFPDCCEU80NUZb0GKFAxaqAQRrKJAK4e01Krsfn+y2Uzm//dn
fmbc5l2R20QMw4T9+wb+QnjTmLw6UfTwGjaYDyXVZU3xfbCklo3mQ0GTOzpK
NxS+Y3XagZDTRY0bWdukOtZYORAyuslZrTlV+Z4VPBmVp0T8qdeZwfOi/Rnj
T87UNoAnpfUtZzcUGz+CJ6FZpW1rdWObwBPT6mfr99Yc+ASemE5+6nnR6WoG
z5P2yWLG+BW2gCei2SMX9spPfwHPg2q019KG5n1lea6SoYr4uLuRzjbwGPot
1M9wPqsd6t3kddz8PYPn2iDfRQ4804iet9qhXz+xzrc8v3y/i+V5rYMMSn+Y
EU16wOsjOe3RaeWuX+D1klOzRt1PinWC1026XYdCfEb/ZoN4r4sYA4ddeGL/
w2bxnp009FW5fTUeasGzkfEh8/QrO0Vqof4HsdWnLtVFidVC/jfiKlidczNd
ot7K9/tCJoaFKo4ekaoDef8ziVoTzDyxSsFrIrnBxvideinUm8nUJM1mfEIC
+bVEOe3G8jH7PNWp/H45SQy/JElOYNSJ/LqMxO1J3+c+6fg/P6bxSnyQSWVn
Lwv7aPHLcOnjjiZYl6PinFyzMTSTnSX4SF8VoNi9rp4T9s1IVBLrnar4ysH5
UKF+04Kh+k5OyP+MdtxoPWf3+cltF+6HDA+SZluHd3Fwf5RXbMOOEV1ctTAf
5DU7WbU/5id4NpThOw81htu5bGG+6IMqIKmiuZObIcwfHR8yroRz/4D6bhQR
qzBoVW3QrxcltCQumLDCCl4f+v3WUG0hLeA50GHHMf/ALc3g9aPWO7qitDlN
4LmQ9uD5I1dvW8BzI0eYI3f6MjN4DD6tLXD1RNZxVcL7xCm3aPmioloO3i8u
k5iSz6wzQb0I+1vvvXHqq6CfJ/7kETFsuvINeGLc0+6Xv7T5FXhi3J44KOiC
6gV4EmzJVOKKq0/Bk+Ih8tqNoQkUPC98rgFF4IBH4Mlwdtzo63tNZeDJcGN/
jaun7i54chxYtvt7THApeAo8IyQ/ZYTFAJ4Sm3xLsledLQLPG6+Y+v3jFEsh
9xcaoiFJ
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10g1MjGEcAPBTV925VJcshESE+YwVeV/PW1hEJjazNCyJxZGofNyMKWnz
kc/uUmFkk9lyWRbv9jzM1fVxnEwf6pKuJE6u67qr7ip637//9u7ds/////s/
z7MnIP7otv1OAoEg8t839ufDnWSHys0PD7VRy7mQEOOs0Y3OGd+oRC7Gk7hQ
c7iqrJ3KU46FmBTe8Muocu2gtLVjISKtB5b+0KZ3UrwnIsWOmSFkQhd4biRy
/Zfhxdof4LmSa41xyqjXP8FzIaPVO6PteiN4QnJ9TcPawdV/wBOSecV7v6b0
mMBzJupEfaAqwQyeE9GGnDIoXCzgjSPPTAWGvPp+iuNqBeS3/9nV7/Q28ARk
If44RRUwBP0jOEiVdOv0EwfUO3BaVnzUKfkozLPjF0N+9oGt42iOVw7i0oFp
7au8nGmeG8ANJkVw8oiQ5j0rFnpVZJ+c5kbzngXL+yoCLx4U08Gc14f3pcs6
C1sktILzevHz26puxWEP8Ez4zrOwOR/Pe0G/EW/2rp6qIVKo78YJH0ylkS3e
dAI37zv295UpF5RNpJdyvgGvkrW/ohf4gNeGL+nUyb1SH+hvwttOeoT7bvpf
/wnXPe0xer2R0jlcvgoLrUl7go0e9DluXY49v+1u1kjF9P8Xczq8YHB+ohN9
n8+jQzWxmbZhK8Wvq9Dh7MzY7noDtZL3UXNGSm15VxnL55tQb4v/Lk1nBwv7
Qzvc7wSbe0wsX29AN8PizuSI+tmD/PnQlFtXQoJm2Fg4P+qPeZsiL7KxOv5+
kFyRYi30toFnQprz+ceTq/rZfP5+UYu28G7QZAu7gr9/JIu1pBaEmqHfgnKU
v9LObDHBPCuqGX6wM/enEbwBpJYdffj4RDd4g+jYC1Fj5sbv4NnRZWu0esMR
A3gOFNYhKQppbwNvBDkcrXRShB48ASP7krRbE9XEvuffJxNRafCL1n1m4f0y
5WtaqWx1HfQ7MUN7Kzxzp+tgnjNTd6w6S6CsAU/IDLvE3Gu4WgmekAlaXjp3
u/gdeC6MbtGTju02Ap4rs941Z3bxTRY8N2bdrzpHWtdL8ESM9EJ8X8SnUvBE
TFdj+rLItSXgiZlJ9iNZbzcXgzeeYT/EN6Y1PwJPwkiWpKY6Jt8Hz52ZWaJP
XdSay/4Fv/ciqw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10w1MU1cUAOBneZRSUSuoBAWBsZio2AAjmZvv7d4o/mzxhyxRxCgaVlGm
jAyGgqhQwjQpiUDQSZU5tSJEYgJqNOrDe7U4QgX5cW7jL3QpVDQMC7VSpcDG
u4eTvLzc3HO+k3vefeHJ6d/uV3Act/H/Z/rNwo/6/RrRf1oaEj6TYzbdtfbf
bo1xWEiRQ039Y25dfRDvEC4Yp8OXDumOa1PSRoSW5ulQ0StC5qMfKkcF5qlo
nD2uJdjjBM+Hft7wTBOZ5QJPSStRXXX3gjHwvOmm/T1KzuoGj6dns7KTFvV8
BI+nFpchJHHeBHhe9GZ/ZP4f+VPgKSi+fsYiBM8SmTeL9m3Nyf7lN4Uoc80c
bTtUHJ+yjRfhwLR7r3l1QLRSZPWT5NDhibHUb1SQ7yHRTwdWHbmiFlm/cVK4
xVX3pTBHlHnjB1J20pQVrNGA5yaW8pjNf1fPB+89KR80JoipAeC9I4u6TP7a
+IVijOw5iS9e+sWOxECxXPZGSPvvRYaLuUHgOchJH9+lMVVLoH6ImH/SGgrM
IZD/mjQm5YQm3AwVdXI/Oyk6sPP2wothYpTs20j/Xr1nxD8cPCtJOlZ9bVVY
ONR3kpr62FPNVTP5L8ialqPDLdGhYom830RiH3ScNrxaIubL6/tkqzZ5j74i
cGZ+3GKuz3Oi0l+8zPZRsqU1YtKmhnUTKlUbp/56w4mrmY9iH+qeZSKHwPY7
0aA5pXC5kcD3taKdaedrbJv+kVi+DR2t6dEWn3krHWTnQ2lm84E+h1OC86On
2dagtkaX1Mbmg8amigLWj7okmB/qKOH1Os4lVbD5oolPepWd3zmlWDZ/NEQW
Jw6kj0D9O/S81atD/3AY+r1H+0LqN5iuvQHPjY6sdVZvabSD9wH9vO4UP3eN
DbxxdLj2ydU/fa3geVDep2FRc7/vAm8S5W5/bW798SV4HC7LissZD2mXnrP7
iV9EPK5b9sgiwf3FyYOCvffrBqhXYM2O0XPb8+qhnxeepxoo3cffAY/Ht5MK
N77qqgKPx5cm7O7dK8+C542jaEm0uy5VYJ4Sb87I+CpRcV5gng92XTJZCnpM
M/8v1l+Yf7+4/4bAPBVuj2xylOlqZ/5/XHXD+2595y3w1Ljt5eUVubY74M3G
QQ0V5/jSu+D5YUWFITDt7T3hP1LrDAk=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw10wlMU0kYAOBHqbRQFg0RbUiDFgRBsXhA3NX3nKlHvOMJsZJ44IERxChk
u0QpiOuuRlCDRhBFUeMRiRCFKJriTIxSNEDEWuyLXFJFzArLIUq5VN78/ZOX
l8nM//0zf2a0cfvX75JxHLf01zf6Z+FNI//qrM819vNzpFDRuaWeA/+5DfC7
pfCizcaGjdaSQT7/wmh4UmX0zaqtx4b5murRUFIx2HRM9+8PnnlKen5drWJB
IycwT0Fb9BkpBb4ygXkeNOGGPH1CvLvAvDGUOnva0pvkAvPktCCuLzMqzUNg
npy+39GcGLpMCZ47tc742/D/Yi/wZJQr0bTYUr3Bc6Olov5qe4ePIHHVHK08
sdKU9mYceBytm96e88rgC/kjJKPkn5iTqvGwfoi89oioy+z0g3qDpNI+9ugp
hVqQ+AtOcv5eW58u1h+8ftJqm1E18kUD3jeyqKw9yv5kEnhfScH8jbEv47XC
bMnrJQGDYWU3vIOEPMnrJqnlXdfSLFPA6yKmWYHZb7JCIP8LabhZMS5/RSis
/0wOzevbUNkWJuyU6rURVTn1sSyYLsyUfAeZMP+0qjg0HLwWUigOYJ0xHPJF
kq2q6FK4hcN6K3HWHE/RF00TzkjzL0jFIf+Ll5NDhQxp/Ih4dthyoozBrv5x
IamlKtStFQrZPJqIyxo7tmtg/ALFOFbVPvX1E35nPtp2uLXwrOw3mBdRWE9W
Vdav+wD7Q0788cMdoZdn6x1o+9i1ljW5Dfwedj5kin8e/Wf9bTOcHw3fqvyu
Pm0zv2L9Qc9MibvqFjaZoX9oh8U3oTOwxXyJ9RepA30mn1A2mSNZ/1Hv2nsR
Uw0i5H9F60fW/TGUajWzet/Qk4fBxZdNL8HrR3l3ow0r7pvBc6LDyXFHcqrz
wBtEkVrj0UZbEc+8IbRMmW1QJxPY/wjae/x17rkoC7wPDmfH6RO0aTV8Lbuf
uDxkiU4dUwfvyw23zvXJ5w5YIV+GFdeDLEMBNp7Vc8fpzi2Pu5LqwZPjR4qD
k01Jb8GTY/3KA0G2MDt4Y/Cep/4zi4vs4HngZ7HXujcP28FT4OHwwtWOENH1
fvFn3YaUqREieEqMMjY5ZBrR9f4xve4nS+pxeV64ubkioOCBy1PhzH2fFmkS
7eB543dXlld98rPzPwH2qf00
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Radiation Force, Fz [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtUjOsexofauxuhtMwJpb2jibYTdbBLvUkRuRU7kS4uhUJRlHKJ7hep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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk4lWkfxlHUaJetSaQoohmmZdRXHskWlWUUylczCeVDSF+oRqWSaRpK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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs41NkfxlUbUamkh7QbW9uGVC5tWRtHRfVPdhGllS1tuVXrknqEdm2Z
dFG2peRWQoqk2EQX8yKXaMhgBpX7NQYzTCUl/+Y453k8nt8zM+/5vu/ne77n
9+1eL7v9k+Xk5DK+/Mn+V/BkS4pOvVTL4dP53H8K32rvCpfi75/01413VXPt
chdy+myl0N24crWhRQt3Xsam1gBVKVY+jcpePdLDrUvyNlWqG0axgdtI2NQh
bky0bA3j3V7pHxylD9xd4TLBYcwM3panJ5WD5he13IXDWD7bwPrkaXm0Bah+
URwCv8vu2eXQmUiWySUN4ZsB+2m3F82Fm6tsDeGvZWevH4tQhw4VHEJiy+Qf
pXaaENnKCpQg9M51pYbaxaDlZUiw4tx6Y8X32vCRyXlL8L9vqx0MN6zEKiPZ
kmBZjpFdTYAR3mnLBMWQ2+JJYnSNQe3miuG+elGg1UtTBMrKCxBj+aiNwSTn
9TCTyZmKoaSv/ulB8EbI0SVGo/N04U5/K5yS2eMMwnZu3uYd920wnQY0iF8e
cSJqTO0xke8AwmqPanh7O2IizwH02bV4zHJzxkR+/XDi9c4cvubC8urHTwY7
FJ2U97N8RCjw0s8+MccDujQPEf596xq3lHuI+e/DLsOlk85d8mF++2B9UUMU
m+uHh9RfL65YC+IrHfyZn15Yuj1O4AYG4amsvMI3iDEKODw9PhibZXKb3sB/
npJNkc1JTPRLDzYk6Rs0uZzCRH/0YMxCL/xqwxnU037oRtruS4YZBefhTPl3
42ZBTs8UlYuMdxf4eoknfDgRjG8X5rnEFlubX2Y8O+GmnuZRvima8evE287Q
sRnX4xivDrR21UZf0E5AEOXTgcBmtRr3FYmYRHl04GrM1CTnfcmMRztmCl1f
hfJSGI92WDVG+Za5pzIebfBNV5ifb5LOeLRBY/fb8ocb7jIerXggsSu3X5/J
eLQicVDfRXk8i/FogWLRLSf1+vuMRwvWvbausah4gN+o/2ZMeXFk1ZKmXLhT
v004Yv2iWl7pMXypv0Z0mS1fJ/4lj/l5DT/txhPXMsDqf4X1y8MjLVQKWL0v
ESh/9AfRjkLE0foaIK4x1DK++RQptJ566Cn0F777XIR7tB/qUNLyp4rAuQSP
KH8h+PNTru4pLEUR5S2Ag8oVTaVlZaikfGsRv8LUT/tyOeNZg7iPivKfJvHQ
QflVYwPPi5N1sILx4oNcWyf2rK3ECOVTBbXor9/ELahi56MKBx05dZfLqqBO
861EgHxUoc5hPujXtXngZDmmO6tVw5z2Yzmu7JFzMsuuhiPtr2dQvlh0odGq
huVXgpx+oyUOL2sQTPMqgsch8eKy3bUsn0KoqHFueLyqxS2aRz504iVJflsF
oI/eeViQ7Bm/JkuABJrfQ7ikpsyeM0OIKvrzbPi7CSp9dgohpv4yceO76Yua
ooUwp/Wmg3P+SOkAT8j2T0Ykf36e7ZAQ+VQv+ovfxe3linXs8xAcj5F4r5pb
Bzn67EfCUhea/aVcB3P6HEkWtaU3Z30UooXud51o3fGO7n/5RZ/KpRKT/24v
3pcuRAI1cI8oO2VZuHgL4U1/f5+IYn83s1wqhM3EACNn55jN4vAF0KL1PiHV
/qOnUr0EjEc+KTSuWvHzZAF66H4FJGph91Sts7Wooryfkhn+oyqvFWqRT/Mo
Jjkba3jWQTW4RfuplJxUH3Oy7qnGFVpfGTmdKcrN21qNYNqvz0lV8720s2l8
lncFce7QvZ0ymQ9Heh5ekGDbtAfTtlex81NFyjm6C+ytXjA9PnHP7W9S6KxA
GOVZTS6nZmVoBPIQQvVryKXtu076zHoOf+q/loSX7J7WkVTG9hMQexWDYGOT
Z9hH+0VIVm4J6NesLcHEfVRHDoUY/GN4uJjlVU8eO+kUidSLYEHnXQO5lla/
Nb2kEGtpP74kbeOtahnHC6BP5+krcu77A8dnkHzWv68J399papAaF1/T+dBI
JNxqc52yx6DlqTaR/sMm6oGRDzGNzp9mskclWO5kQA4+jctWM2nwshlVCsoG
PV4BLUTgoy6Niv4PUrpBC9FZMuP9wZpM5q+VqP9ZIB+ucw+9lF8ruZ1YqR+x
5g6oXdc2ckBDoOi2LQ0tVLCNeFX33XO/cZP5byd3UtY+nat3A0LKu518FeFR
EtuZyPLoIJ6OajHvXySAjgNeB1m35W5oAz8eG2k+naTdJ6xi1a4YTBy3ThLy
LjZQwSSK5dVFzuv49hm5RuIBbccuord1z6Wzry7CkObXTVx/vmGdrRPO7qtu
MtZudHuSxjl8TwvsIXm9O570HA9FIjXcQ2IrtayTrUJA5Ra+IVtGQ1R5x/5m
8/kNERUG+pZ9Pg4VKthLHjmebhTePIYLtMBe0tdaWvSk6QhoeUp9JM7zuV9I
pC+br32kuF5QEHHUC58pjz7Ssj1727EwT8ZDREYlj3RNtrmy+0dEuoM09Q5k
78UflEc/CSn9d8SS7GY8+kmb77XCYrlfGY8BYj/L9OBIuAO7/wZIXaumoKvK
Fr9SHoPkh/opPI6DNeMxSNQO3H1kO2sze98Rk9H1fgX5tzZgP9UTk6WWH7vW
ypmDfj1JTCI+OXz4TvIjKJ5WMWlsEJz5IF7F7isJGYvkRfrU6sOJ7ichXuMj
BUEiXUyMKwlBaPvwvENLMPE+JyFlXVMPx0m1MJfmOUSEW5XPZKZpgNqzHSKT
G3PNEviqoHLhQ2TszBFJ6Dez2fvBEPk9KM1uTeY0KFLBYTJyPjR2e/pkUNyb
hkmyJXrliz9yaXmcYbJ3wcCp/OVSbgHtp2GSq2ZcofqbiEtxjA8TffdTSysH
2rg0blMpSTE/6LpTpY478X4mJeVfNa+4o1DKzaENIiUXuBXFg9rJ3P8D5STn
mg==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs41Okex3Vhlc7WabVZlY5ToRxJUeni1UmJEKonSdqKSlYRamvbpUKX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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgs4lGkfxmk72A6+EpuVDj7WSvRVqL5teSqFvs7sFlEuCtthpdQW2RSR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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJwtlgs4lGkbx5FT2kpSNFkdVJTI5tBWuLEqSqXa2nJYpIOKHCKabUtKB/lK
G0V93342KTo4lWIt9+uQlCGnQpIZZ2OGGaOiHNY88zzXNddc7zXv/J/7///d
z2HBXv/t+xXk5OTSJj7S7wqOdAziu5Gl3L714oKYok8GblcHMSyw9URL/iTc
nqMb2bttEO0qHcQK39RxVtoGHltz4v1cIevEVBbWJwVYqdVL8MKW6dULyhfi
rQTpkCCE8IR+c5ah21WpoASr+ZaMeuoPOG9CLUdXgprhC8LOhKzCVrbmhOIA
fvKyH47Ptca7UrmkAfRRiLD70vETHjwgHQO4qifJ83CUIy4lggO4w//PEld7
ZxRskxYoxo6tCxQ4cT8jKS9NjD98Sv4s7tiDgVK5ADEG2n+Zk2nmiWam0iHG
0Kqgf1RX7MPPBlJBEZp/1M3fqXwIid0cEZ4OXe+i2HEUf5OWxxbhT02XE0zG
gtBaKmclwlY7jec5dqEoR4YIN85oKuv1PInnpfYi+3H2VKd8EziDU0hA/Vjm
WInDredQlm8fjvtqpXxvdonm2YeWo7p8lS1XaH5CXL5phxaj/wfNS4ij9y+E
BT2Oo/kI8NrJZYxJeQIuI3kI0CsxImfajT+p/17M8o2tj9e4Q/324o9P+w37
HZIxl/jjY3vsqTH8lkL98DFhy8OW2tWPsVhaXlEPrm32SQ2fnIkOUrkNPTig
f9F5BucJyvqlG2vV/MURwme0P7qxa1uDm2Ho39hA+qELPcINk5igAnQn/LuQ
38cO1wsppLw7kacXf3VUUkz5dqLDu7lbdPJKKc8OvHM97Vjam1eUXwemfNN2
qLWooLzaUXFNn3MJuwpPEj7tmO34OWvTxRqUJzzaUXuFsieU1lEebXjRy3p5
ukU95dGG6sU6Av+mRsqjFeXqbL5Tf/aB8mjF9T0mKzkvWygPHg58yJ9WdJFH
efBwVXe6fINjG+XBxah1Ds6G+h2UBxcXFjjpRszvwl+J/xbslt/l62Xegz7E
70esNFjInby/F4OIv2a00rmwKyRNSP18wPQMiwfLVEW0/ibsttQxu2QvpvW+
x4NHTOwPXB7A/5L6GtHYN2htWpME75F6GvCPO9xZhmafMIP0Qz2y88IXnL/+
Gf8m/N9hhd3jlRuHvmAJ4f0WT6/129LpOYyVhG8dpjycVZhR/pXyrMXHORZx
fIsRbCf8ajBQInIrThylvKqxKXiHtbvKOA4RPlUoaTNK8DGTY2TrowrdRdVZ
CTw5RpvkW4lWfR/qNkXJM+R1Aw7OjLCTRBkpMDakH1+j65phq4OvFZjdpL/K
UH5Kmt0Xj0mMLL9SrDCrGdojnMSEk7xK8P3SvVk5gYqMLJ8ijF77XOAgUGRS
SB4MGpqnj252U2LIY0A+Sj763GIVKjGJJL9cDJHPMddgKTNV5O/ZqB5tZf7g
gDIjIv4ykR+TO3L4njJjQ+p9hH5M+htRgzKd/y4Gu1dfEowqMwzRS0C+d7Xx
olkq9PdzuPncju3HdFUYOfIcDKdfXttdPkeFsSHPsVDjsiTGVEWF4ZL5/oLu
r/qLX3VO6BO5VFC9dkZYkKPMJBIDGeCoZzjN/XdlJoD8/ylkb8gOkzNXZpxl
GxhMn822YXGVmPmk3n/gXmdpqfFpJcqDgZTW4/l1GkpMN5mvELzVi8ef3FZk
qgjvYrDWirA9x1JkGJLHC/ApTYubEjOJSSH99BK8jTgVOqMKTDyp7xWYzrv1
NG6vAhNO+rUceqNO6rsXytO8K+B0g0jDiyXP7Cbr4Q0YTPP+JfaoHCNbP1WQ
aLRmdePv4yjTq4bLXVnmjPYYRhOeNeBn5VJUmj6C54h+LTQ3i+0q7b9hGPFf
B0PPnmg+ahxG2XxvIcpolf/igCHcR/rlHRiXjUX0Tv5Cz6N6cOIHddxM+YSy
vBrg/rfnu1M3D6I92e8aIbJabST86wBakn58D6qphv0eGWI0IftpE2RGiwL2
B4hQ1r8fgD+VN8IK7UMdsj80g/czLt9jsQBJeZofYeyvymNywh5UJftPC+wp
d3vOetOFI+PS0QKrz8b7RXI6kCwvNhd2Pa7+rqajDQfJBFywHH7IbJ3bSv3x
gMVOZU334yKf8OPBoPLRYk52MxK7B1rBoDG+TFD2HrlEsBVOHtLz8NBooP7b
QM9p59yMmLf4jvBuAwWjSNf5drU0j3ZQ9bZ9krWoGsl2wGkH1sbgE76+lbie
5NMBJ9wSbJK6X6NsuXVAyWyDrXNzX9K8OsGlXc2/oKEEn5F27IQZt0Hfy64I
V5L8uuAX01Ob7vOQnldd8L5+Wj0vPw+XkAK74d5MW6fd03PwDjHcDdHOFa4/
cp4ikdPtgeUtsbvUJtalbH/ugf/8dizvzIs01CCCfOhqGLOJ2vkAr5AC+dB0
6mzeeMg9JOWp9ULODX5NgVYS3V97ITq7YiR7eSKOER69sJdfmly59TblIQDj
JexQztcb9PwRwN09G6Yk2V/Ho4SHEGz9iubFzYmhPIQQ69zgkfImivLoAyV/
2yaO9Xl6/vXBmfllazT3RaAL4dEPKQEeQjenU5RHP3AsP9aHN4fR+44I9Of9
P9/x52DcT/REYLRi42G3KwFIXk8SgZOBU8j9psNI8PBEoDfqHhufuZ+eV2Ko
PqG9QxDoha5kPjF4D82tzBa4omy7EsON+ZdMDlnuovc5Mczh39y59/Y2nEny
HACLIyz22uxNSOxtGwB1/Ucuk5LXIZG7OgC3qi5zMott6P1gAOpMK0LvP1mN
k4mgBKYo/e94UpApEtwbJp6BL9YWLUdSXqQE8ow9tVTUFmMh6ScJHKxLXl12
83skOMYlEK0SfP1F0UwkcVsNQvaiF+xMLVV6PxuEX23XGR+fPlTwnDTIICRz
NY+c1Xhb8C/9qtrz
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglUzesaxncTtStqV0RUZLqXk5nca3s7iSKRg3NxDAelOoW0jGVoDmmw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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgk01Wkfx2Upy2hxr2xZrkkxSR3LmFE86miuUqGV1IgQR9lK0+CVsqQ3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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs41FkfxyfZtlLupNwNRRdtZe27oSMVlafWJemC7YrWVnJ5S1hlKVR0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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"x0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {193.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglUU1cax9ERHUQqm5SODOjggiKKLLaKcEERbRERcUkFahFURkcIIqhI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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lglYjWkfxouvqzKkFFPhyPiYNGQvWz1RlO3TZrR9SEp8aSEyjUraZFC2
km1aaErhKK3y3kWjbDmVSkTLOe0nZzVoUuM85/2e6zrXud7rnPd+/vf9+z/L
9J0Bjt6jVFRUbn/7KL5fPFcMOaQ3Bp1ryyOYxIcfjT0S5PDPODW3atdZxrGY
E9PvIIfn2mOCl1qpzMTbtu2henI49wQ0CdSzmaaMQIsxTTLwdeU2ZR55zKUU
xZBBu0Zn1BF5CeORoBCUYY5jXmkbv4KZ9k2tmCODiiXf9NSyaqYjVO+bohQi
EzPDVFMec10hlyFFlH5/5NldDcxuH8WQwmNwZk7ImBZmNhWUIu5x2HMt0sEI
HRQFSgAtHItN6WZoebcliIiXTA53/8AEKeQCJQhcoeZSsU/GLF6kGBKMUdWz
86/4zPxlrBAUI35zEOJ9Rxhqt1iMY+dF5cNNo/GrorxQMUJrtUf0BjVgqZCz
EMOiNVuj0mE8VOgQw6DV8X++ibqIVdiLEWEzdyg9xU0f39GARFj1uc/q8BIO
lPl+gMXJlrz4nB+gzPMDdF80PHAcmQVlfgNYrOF4t3P5HCjzGkBZkktxsM0C
KPMRYpPo7gXbcUtgQvMQws/eOnvW+WVQ+u/HaS/rZ/ZfLKH02w/XzVteFHBX
o4T660Ov7XcnZaFrWT99MDCJ492RrscjRXkPe+ElWPlxWN8edgo5217YtAna
xSZOUPZLDzrMFhqtwM9Q9kcPdsd87xbb7YbXtB+6MV/TuWR60Xb8l/LvxrWI
qC3RaTuh5N0FS7+CETHPG0q+XYhdkXLt74N7oOTZiaHcr+Fnru6Dkl8njkx6
s+GWSRCUvASwezekUd9wAEcoHwFeFBpuy2o6BFXKQ4A3duPD68xDWR58cGpl
fxkMh7E8+Hj16qfW2QaRLI8OJKxa7zrDP4rl0YGOuF9ePlaNZXm0w7PZQF7a
dJzl0Q6OWXLiPtlvLI82xA+flIxsTWB5tGFdTYS+QfQZbKP+WzGQ9uTVrKhz
8KV+3+PAzVGH1G9ewH7q7x0KznXW2H5JZv20IKNMw00/6BJb/1t81dhfuVrn
KlvvG6zbSIyNmn/HFVpfMx7Y/8ap9kpDJq3nNY7qJ3YcHkgHl/ZDE5wmrLI8
ffw6Sin/RnA87XbfXpSJSsq7Ado2UVVLB/5ADeX7CqtyN35ak5/N8qzHV4cL
wqyoHAgovzqkmG0LlLjfYnnVYtCtpDNg2R18pnx4GL7MWXT1JJddHzw8NR51
0eDIXejTfGtgyT0x5/iePNC/Gz9H9+Va14VO+bCi/fgUo3UM+c7m9+BC+6sa
vnYurjP1Ctj8HuPOtQFRU3cBjtK8KrF9iVrKDW4hm89DtEyav6nOrwhZNI9y
9BUUbs83LAZ9DHyA9cf/QEFxMVJpfiXYvlpTbdeaEvDo6wXoPVcz2w8lEFN/
dzF/suXL6zNLYUXrzUXGhiCpTkgpO/91qOX852NPXinKqV4Ktrp1Cc69/v/v
0ShTtenL7y6FCn0OJpGpkU0/tH3To8/nia25ZrWsohRtdL40YlDuytt/6tv7
VC6bPBuZiRnWpUilBrjEduT7T+CXIJC+f4/4hlXsWxRYAnvlBkYeB05vv9hb
DCNabxn5YhjjusShmOVRTtRN1+kcyCpCD52vguTkjG59Ky4Ej/J+RDx+abTS
nVOIcprHnyTgR83ZPPcCZNF+qiJB3vG5jZH3cJHW94S8u5ycL/k9H0dpvz4j
C9NLngmL8ti8X5AfA4yWnn52Fy50PbwkFof03M+0cNn1wyOyvPRp1s13WL1a
4ly5WCdn8BZOUp51JKjlfuTPRrmIpvr1RK9gHkdz000cpv5fEQOdxvt2UVns
fA3E+fTRaa5/ZmIX7ZdG4uR3UH/ZxBtQnkdNRD59UVdqcAab12vSuimuWbUz
DTZ0v2smu7yTJ8ftTsVK2o9vSL+tqeq8wauYT/fTt0Rdi5PI3XiZ7d8WsrI6
ycmz6iKm0P3hHQmZlW5wZW8SaHl678lTq8F4B7Pz0KD7TyvZtHyH7wSTsxga
UYxW4jPls6vhmkTQ5RXaRv5VH/OmYOwpyOkEbST8arDjuOZ41l872SEUvzUX
xqKP8msnVXVC0fvV0aB2fTpI5fzRZX7NkWijgh3Eu9flhoVLBOufT9aZu5aa
+v+KRsqbT3zGp29pFoaweQgIt2FgrP/zYNDt4LmAHMtzSFimth9raT6dxOxT
ffj+aQFQLrdOYn5/ar7Lk71sXl2kPWLovPWgDwppO3YRN19PntoNLyyk+XWT
TvecM2YPdrDnVTfhzN0xEOLvgVm0wB7SEqiemabtgnRquId4hYYUj93kDCrH
6SUHaz0zo3Uc2P25lyyNjBP1XNqICVSwj0TtfFLG5dviNC2wj4SEiGZs7bAG
LW9MP5mU5J2dGW7F7q/9JOxEace0tSswTHn0k7mJY5Okh81YHkJitYCvbRi8
kD1/hCTkwn05Z7Ep/CmPAcIVXVkyNd2Y5TFAFkwRzvJX+zfL4wOxzOdneZkb
seffBzLVti/Tf64h3CgPEVlXVVHfMG4iy0NEnNRzHuxp1YbyviMm+mu05ALJ
GHhTPTHp9G9uWhGgBvr3DDHReCVwWzOkAoqnXUykjQGBvS8H2fuWhJzRGr2+
esJHxp3OJyExV6QnLMPEjHK7kpDXzmG69rd72fuchKz2VjO/JOAzujRPKVkV
G37POOM9Q+05SMl0XpbBQ/8mhsolSMnH5dk1u6tqGeX9QEp4Pi4/bSh6ymhS
QRkpm934Nrn+EUNx28rIAo2lX7zlZQwtL0ZG9v4976zfrXtMBe0nGWlIDVia
kJzLUBwjMlJX4lka/iSdoXFbyEnVts/CvoQkRnk/k5Nmh2u+Z5fGMkW0QeRE
aiq6f9jSi/kHKvTkQQ==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk4lWkfxo+tQgujomkZTbs0Eykf0pNJSTWFVEJpo0UhKiLyZZ0WS1Ok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          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw1lgtYzFkfx9MKZV3SYN8o6rGWLAZZSjm5bGkTFetSiVJq5RJrUWTTBa9t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          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk41Vkfx5EWTCJpWhCpqGTEEN50tEw0402UXuoOJUs1zVBUo7QZimqi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          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgs4lGkbx51GIbWVSluRWhWtiG07cis5pHY/dFwfwkaoRNL2iV3lUFol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          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgk4lGsbx+1bqRlR2mg/tDi2olM8+jiROt85okUnlWwlMlmOaBFRXY4W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          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJwtlgs4lGkbx4fkFKGcFdKX5FBJB2V1a9siu1+qtZXoZCtFRadtP7If69CJ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          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw1lgk41Osex0lkPRwhJ5Ns2c9pIXUUrxa0XF2SklA5ouXQuGnVonukhSd5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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uy/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"y0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {580.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{
        {RGBColor[
          NCache[
           Rational[1, 15], 0.06666666666666667], 0, 
          NCache[
           Rational[14, 15], 0.9333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10wtQTFEYAOBV2TZFRaPxaMpjmyEir3Zm8Z/xyCsMhpQwKyV2Bsu2S48t
uyX0JlGaGCWPRQybFM7BsDHlETY7GDvWM5rBklhC9/73n7lz58w5//ff899z
hqzZtDjeRSQSzfr/dL/58GKaw9E3l4X2h/FceLJTDbbttX+DIYGLXmyooUpB
3oVBWWl3eLCyIKs0tVkGzU3dIWFVXtq4F4EEeE/CdLES+frgGei5s5n69rdU
Pxs9MTMHvdAunTofvZ7MSyHNbQ9bhJ4bu1Qz/7bp7xL03Njxay9zVnlHoefK
HGerok8nxqDnwlyilrgq/Vah14NVt1qMEX0UwHFNIuZuvW8IjohDT8Tyg2aM
Hl4Xj/ld1LfF1hSpTMT1v+koeXrr5nVKrOekdvGCLwGmjcDxpT9pp5/tzY1Q
FXqd9LVcmjps4lb0OqjzltEnc0sSet+o7+S+MYkftTCO8xy0f8vy6frKZDjI
eV+oPXdv+NfyNPQ+09ZnUs8KZQbmf6IB1w2x34P1uP4DLVd9LtI6DbCWq/eW
GitWe2tsWTCW8+20c9+v5x8as9Gz0ZpGVYK8cjfmW2nFCbHZHp2D6x/R6qgC
y/gnuVDIzd+hvmPqHaQrDzK48WXaZr37NO1GvtA/0bGDG0L8/AvgCD8Pdy92
rnD8ysfxHSjdUer9SpMPMt6HUNOgKYWH8nDeCg3mAPtyXa7wffAHLL0bJubg
ejvsrFsbudWyGxL5/UHcD2VDjWqXsH/wXRiqV/hlwwO+P2C/VJ8SZ84S+gdr
PPL8BxRmQjnfX5AaZe/DVQaYwPcfYiLTFXuUesz/BpPElaZ9uh1YrwPci0aI
+pzMEP4vnEmoytrTko7eT0hrC/QxJuvQc8LeQo8F1RFp6P2GRxf2n7s9LhW9
Lngs6fAolqcI/SPnLUPabSuT4R5/Psk81tZ1r2S7cH7JgcEyc7N9G+a7kNjs
jYqSaduwnivJUWXul57XCveDhDjmLDKN1qLnRsJKLP61tRrhfpGBxSOvNs7V
oCcmI+sHHKp7n4SeO3FO+b5YU5Ak3F8iTnkV2G9qEnoScsr28OIVh1q4/+So
Tl5+uUaNXi+i9SnunaBSo+dJ4t/cDwmTqdHzIuHLDhwpc1XDPz7m92o=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 15], 0.13333333333333333`], 0, 
          NCache[
           Rational[13, 15], 0.8666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tQTFEYAPCrd1uMPJrkuamRkSQaDfEdf1TjD61KIonZ8hqPGGWkx2TJ
o5BWTU+PWlvrsaSlh+yeO6xIKXklpMKUV0OP2Slqo3u/+83cuXPmnO/33fPd
c8TS6KCtJgzD+P9/Rt982LIXCmtcT6b4wSIubNhW7TDjtSEUtnEhYiXJXUML
3KSQlzsa1qyX3PZm77yd8Kx+NKxYF2sz36zwfcB7Vmxbztb52/bHoGfJ6ice
9Xv/4RB6FqxvuvOGeFUieuasrEc/53j0EfTM2OXPi/5s9juGnhkbKEuw02w+
gZ4pK/K/6xT0MBU9EzY6rfW1w+Gz6I1hM2el15n7ZwDH1TPskuqYt8tSzqPH
sAr7xDwrYxbmG2nDzC0BKZU5uH6IZhfU1affz8d6f2mAc1ySfsIl4PjcQRrS
cEPhKS1Eb4DGi+rcMvYo0DPQX42gDitVotdPg496d09boAJPzuuj53tXSzK7
r0EO5/XQrsauph/davR+U7tvNU/fZpdi/k/a2zHwxSe0DNd/o8HhTqdneNyB
KK5eJ82XhyibppSDB+d/pqe+kzaJZSV67bSWWfNppLMK81vo8Oyp9usU1bj+
JV2yvntlvrMWznHztVTm4+PQEqyDZG5cRRlZzfgDM6jQP0a8v39jchyFy/w8
2BlK8t9HCuNasI+ZVejVqQNv3oeFcvfFc+10ON8Cce1Rh42D94XvA03zibUu
FdW4/jOsMkrOSDbdgx38/mDSg6CeK8OVwv7B8Y1b4CRlBTzn+wORiTnSuPBy
oX8wpbXo4dK5d6GA7y+4plloJ4y7A4v5/kPNpaD1TTYazO+HSN803Yi4DOsZ
4NCIqShCclv4v/B411LrFfJS9AbhleprgqzpFnp/4Udms5NJ0U30hqD5o7Eq
QK5GzwjmPpqEgYs3hP6Rx9rb8hb9dWjgzyd5tVe8z3HMdeH8Ev9HthUegdcw
34R4azQD78quYj1TMv2pV5uj81XhfpDdfcfL3RUq9MxIWFjI91R3lXC/CI1v
bHipL0HPgkyfHNHRHFWCniUxzH+dmTq2RLi/pMNcrB7RFqNnRZImJrpsjy0W
7j+RHjmYbb2oGD0RCY14Yu9rUKJnQ16cTo5N1SnRsyUb1a5fwtKU8A/3MAA0

          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 5], 0.2], 0, 
          NCache[
           Rational[4, 5], 0.8]], Thickness[Large], LineBox[CompressedData["
1:eJw10wtQTFEYAOCtTQ9t8pydaWLGoyFmRakM6T9ChWjaPFJmJKRRSNpZ72Km
wXgV04yMtDVhYpRXE5Fz2tpW25bajdrNY7NTowehUB6he//7z9y5c+ac//vP
/e85U+P2ynfYikSikP/PyJsPCTuU4rzkfP428OHCmV0zKNyTolIhnovRzCLP
C3MoSoMrOSPhxDznRL1P6cmAev1IODLxjxRZ0pGzwHuOzD8jNnu6Lgs9B7bO
ZecGqspGz55Flji4+Oly0BvFMotzT2jCr6Fnx2Lcbid8yc1Hz45lKTxU3msK
0RMza9EnU3TATfRsmc630s1m/y30bFiWNGtu+dAd4Di9iO2uTnZ1+3gXPRE7
J3Pvvun6APOHqeXUxtIru0px/W8auyW5tdjuEdb7RT2n5E1d3lEOHJ8zRLXy
9oehE5+hN0jlhsWBo+oZet/pD33T12SqRm+ALsojrvKOavDmvH7q7x7pZV2q
hcuc94Uu68+NkbTUoveZzvYJV6YX6jG/lwbJg45k33iB67to2bfXy/ftaoLt
XL1Oqh5XpYwfa4R5nG+l0pJCG1l5M3oWulPqcaYz6hXmm6jpQ+L+aHMLrjdS
hd+MhtTZJsjk5mvpfVlXW4WvGdK58WM6OT/n6LZes9A/UVHcycAxK9pAxc/D
5v6DSapAYVwL5ZVPokItZljI++AUEW+0+ptx3gT7WpRlIRtNwv7g8Ot3spUR
rbjeCvRdZGWYfwsk8N8H49tki9VSYf9dcDqmZ2zmn2Zo5PsDtOvv4PzPRqF/
4B7fywIGDHCV7y+sbu5eby8xwAK+/7BMVZAYurAJ8wegsST8WNGBRqz3HVpX
++nDLr8Q/i/Myy2bUBHXgN4Q9H9s+HBhTT16v+Dh2mBSsF6P3m/oTNwT3KOs
Q28YvnlnFF+6pxP6RwaH2ifYiHTQwJ9PUlnnUWWKrRXOL7nuldAhNjzHfFty
PibaqSDiOdYTkxW+xsgxb7XC/SDH+6bNfKnQomdHQnr6npVItcL9InpJt2Oa
ugY9e7Ju1iZLsKIGPQey9emkCk+vGuH+ksEBpWl7nwY9R1InJnVhpRrh/pOM
8cknV6Vr0BtNUtU+2tZwDXrOpN0poer4dA16EqI2XAx487Ma/gHq4AhG
          "]]}, 
        {RGBColor[
          NCache[
           Rational[4, 15], 0.26666666666666666`], 0, 
          NCache[
           Rational[11, 15], 0.7333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw103tIU1EYAPC5mc4XPbCHFWEZK8qknJpk8N2wMCuU7N0fFflIW6WGLwqp
zEx7qCW9ZWmxplamRoRanYOaWmpURmaWe7nm1OVkS10+KO/97geXy+Gc7/fd
891zFh+Oj4gWCgSCkP/P1JsLV5qqLCJZBWkgZcOF5icnevsk50AMG860r2hl
jW9rAdy9MxVO9EnlJ9WimHvQ1joVYmquz3kpaSkGzhPTyorelLUBj9BzpLeT
q9/MmyhDz4E6BXn4a90r0JtGF7i5O1FdFXr2dIZ3efmFoRfo2dP7+TuG4zZV
oyeieZarR28ZXqEnpJe7A94qEih6dvSB8mzPaXkdsFyrgJaNeyetEb1FT0Cd
QkbmRSmaMH+SuAU2StOuvMf14+TbTYtBTtuw3hgJF8aExio+AsvfsZHICYlo
/93P6I0Sm+xNqbThC3rDJCWybJXb8g70rCTXGjFU9b4TfFnPQs4vMS1bUvED
brPeEMl9Htfc+F2Fnpl4LEzICFBoMH+A0N6Osfh0Ha43kiNZScGLE/UQxdb7
RTIUteWlqQZYzfo6Eqb0nBBkGtFTk2zNM8OpzH7M7yS2ulpTVKQJ17eTWvnG
0BbxIOSz8+/I3L0+n6p8zHCWHVcTSXjzHA+lme+f4IafStRnMEMRNw/+vfLS
nWZ+/A6OznQZPdlghkDOhxNtD8f3HOPnO6Ho4vWg/p5B/vtgpmzXyer637he
Byd2tHveyjFBLLc/2P80a3peyAC/f3BI8Fqb7dwPH7n+QEpsvv+RLn6/Zljo
XilXkl4o5PoLfeF26Z41BvDj+g9BxerBupZfmG+FDc2XBtdZ9VhvGFYUPtgm
89Xz/xdeSU8FN2X2oGcD2TddY55Rh94YpF4r2Dl2QIfeOJSkaw+F6bToTcLs
kd0rjElavn9M5EhFTtgsLXzgzifjpR8NldRo+PPLvP7e3rRepsF8IfN3a7Tw
3FIN1hMxXQ2hKju9mr8fjMV0Y0H/YzV69oyPRC3NSFPz94uxFv897rVFjZ4D
M71EOx881eg5Mve3F/qXW/nzJ2Zyl/tttT1ToSdmll7vKCtMVPH3nzEeNP4c
CFSh58z8idtTHzFNhZ4Lszl61LL5azd6rox8mfuZfY+74R8geBj0
          "]]}, 
        {RGBColor[
          NCache[
           Rational[1, 3], 0.3333333333333333], 0, 
          NCache[
           Rational[2, 3], 0.6666666666666666]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10w1MU1cUAODXUv4bZIqMzRGjOBGlgbXFkEV3rkA0Zs5ENEajEkUGykY2
simJTGwsxcESoygGSBOZOkwFNUHEUH/uBSGkwPCHoFSzoevoBPnb3mv56QMn
7513kpeXm3vOd/LOu3dZ5nfpX6s5jtv0/pl/y6FlXb05/5T6lYFBilD2VYj6
gG20GrKlCGHZLc8iPhu9AtVV8xHMyppan9+cqIffu+cjiK0vdjd0dTSA7AWx
8vO31DPf3kEvkGXoVe1vv7+HXgB79Emt5c0YQ8+fjR9pT64YeIiehv2clefx
hXegp2HbFpVYj5Z1oufHnI2x6p07etBTs+WR2hZu3RP0VOxRkmjQmnpB4ro5
1tm61bVZ7EOPY7cbZ2N+uNOP9XM0scMwFtL8EvNF+vaakJEVPID9fLTVkTbc
s+s1SHzVNO3f6LC07XOhN0U/PzNTbq8cRM9Ll5y4fnww7A16Ao1xD6cb2odB
L3k8/SNj9QsHHYVKyfuX2jSN+ZdNE+hNUP9z2sMv0v7D+hE6lthhvrBawPwh
ajbZsj7WeSFL6uem2x+kp6rTpiBR8l20s8/69HTmDHqvaEx97ansAhHrnfTp
3lXu+Lw5zO+lhWUqZ3QkR85I+w6aYjSepz0cMUnrZhrt2f/ju50qopyYsCax
K9KmIjXyPtzdc/ae+FBZO+BXaNIV1KlIsuzDmutHLupzlH0n2Nd+NGBUKd4r
iA64NBhXzGG+C1q3WIsm+XdwSP4++PsD/bq/+uaU74fYvdaLNvssPJbnA8dC
M72BdaIyP6iO2PxbXr0PrPJ8gbcdTLzfMgNGef5wKKVtg3pkGusFKIpO2a5d
M439vPC4pPFT9/Ep5f/C0NowXbxrEr1puFsT1b1p9yR6PrC0xQ5V/OlFT4R9
NqGuKN+L3hwsS433N4d7lfNHGoyH81PtHuiRzyepNf+UezLPo5xfcsB5IWlF
nAfr1STuRI1ONyJgPz8SodmWRm8Lyv0g4sSNhA8tAnoaEtlc+kvpbkG5XyT8
iy1RJr2AXgCpWhmjK1igeIFEdfTLHN84r9xfcirKV3m1l0cviMy+DvYut/PK
/SeWjQnHll7m0Qshhopy867TPHqhJHThYuvZQsXTklsJz7+pyOXhf8PjCVE=

          "]]}, 
        {RGBColor[
          NCache[
           Rational[2, 5], 0.4], 0, 
          NCache[
           Rational[3, 5], 0.6]], Thickness[Large], LineBox[CompressedData["
1:eJw10g1IU1EUAOC5zbe3vZmWFWVZpmAlNbMWlpn30A9WaEQ/S0oDzUozC7JZ
lknk/EE0hpRoLEoEKaRf+tNa91VUilY2s7IfXJrGUsNS1mzLyvfOO3B5XM45
3+Hed2elHNi4Sy6TyWL/r7GvGFq+TB9QPklTRRYJwfGJaXfr+3oukd1CaPi/
daVFr6bdJGerxkLNd/ZmWt813iPPW8aC5Q0N0/0tikdE9Fj+Z3lY9aeDT9FT
8fuyNgfnRzWjx/A1Wz6qnBGt6HnzW2rj0to9NvSU/IbdayvfKt6gp+S9glb8
aYjvQE/B39XFdczo+oienJcF7PjzMtWOnhe/LCPR7C7sIgLXIuOticHfuU9f
0JPxceuvfA7N/Ir9o7QuZ/78sJhvWO+hzqGbv65vHcB5bppPp5zXJA8Sga8a
oXcstqY5K3+i56L+fQ/03w3D6Dlp9NIQbWi1E71hmhRr4naGjpCFgjdEi5fn
Gcu+uUml4P2gNsPW0qjBUfQGaU1EwGn7NC8Q+/tpS3GSTd4pB7HeQV3lB3/l
W5WQKszrpa6C7FrdNQYWCH43Tb5yrcJZx4Lo2SmknjVbqzXY30H7j4XX2PK0
WN9GcyZv1u3XjQOzkG+iubFnjs6z+MIJYV9P4yOvbjdv9wPpxdx6wp5KbPCD
C2KeRJWaTGsc0r6JbFjcr4vr84Mlok9ipmb0PHkq5TtIpKmbm22SPDv50px7
Om+eVN9N9EM3FhSYfSFNPB/JPjp+01TrOOn85Ny74ycrHD7QKt4P2aOveFMR
6IPeIPEvqXrtSNKCRbxfsl5nDFt4mQO9eP8kGu4oTmg57B8mc0/dbm87psF5
TrL3uOd8/m81ei5itB7YaCpSozdCJpR2L7PMUqPnJtsCg2WmZyx6HlLPZXl+
H2bRGyX3i1hFW4T0P2Rw37fW4BxSwQvxfUJjbqMr3aoCfL/gbX58O75Mhf1y
sHCRjvcpKpyngAT1RFPKchV6SmjODv2wbrrkKeFIZ0CCz18GPW+IPZS+Wt/D
oMeAcSTkYcILBj0VhBgN9qAGBj0W3AM7vWMuMuixYA6fmZZRKXlqSE1IbtlX
InkayOEGUnzyJI+DVRMCW2dkSZ4WCi/1bzqSzsA/HsDmtw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[7, 15], 0.4666666666666667], 0, 
          NCache[
           Rational[8, 15], 0.5333333333333333]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw10gtQTFEYAOBV27bZIouxu3fvThkaGhqJHsT5e3pFthFGeWfDeL9i8qg1
pZioNDYynpVqZhsNJjTNORiNpWgGk6KRWY8aJdpCbQ+695x/5s6dM+f/v/+e
/x7PTbtjtjhIJJIF/5/htxiupKN6ZVIsKUZ+QihIbFfHgRxjJTIIMZJYtR/9
K4Mfo0sXh8OF2BTxadnTLKiudjjkpDx9uq9uWT0SPTl5odU/Co16Qz1n8u36
x1VfTO+oJyOBxlXbuKBm6jmRMIO3d4r2E/WkpKYzp6K93ko9KVk8FDL+Kv5K
PUeS11d9Y2JnG/UcSG1L3qkmQwf1RpBGlNCQZfqJBK5WQuIOPcu+WdJFPQnx
bwnP+/W9m9YP4r69nG514h+a34+9Ol0y1nj20X523GG6HMB7DiCBv9iLc4vw
gHeABETuL55cNmvnebkDiN5v/MccLm+XS0H0unEynJb5BstgpuDZcH50s66p
SA75gvcL20siN+oXKqj3Ezs9L1vuN2kUrW/HVefnlpUWuNP8Npwff/xwzTwl
JAj9vmKVojzzUddYmCH4Vpzcs+GtpWI89VpwSJTfkcpdE2h9Iw7KeP9qh0ZN
819jc5DGw7FQA9nCvgWvPjCOf9rHQYqwfoC5YMuUYnce2I35PGlEjOkDD9fE
fVT5+Nk2abyOri1oQdLSzMFcHQSKPoqYrdgx+gzbb0QBd17c9tLr2Pchm5f5
xlIbT/OtqHnft8Sq4zxsFc+HNl8K/VEwqGXnR0bu4PazyVqoF+eD6vj7TeV2
js0PpZsTzJ1GDi6L80VTY/c25IzlYJY4f7TwXPT8gnINre9Grak9qXNXaGi/
34jYxoRqpBr2f1GWfr9zdrWaer1ofvF2Y90JNfXsSBlk0PcsUlOvH/UPNCmn
cWrqDSLl04Yn17tUbH6Qy/uUXnilgpfi/YSjRd/j1laogN5fOLler4wzqWi9
A6wsjPgkS1XRfo5w62HJntadzJPCPav7ngtrmScFbVii/W4085xAYpmi6A5j
ngwUnhuH3OYwzxmuGI9F1fgyTw67h/yjWr2ZJ4ejTr2+kZOZ5wJL3Ewe9z2Y
NxJ82jes43jmKaCnYn2hXsM8VzBkZKaBSgX/AIUb4+E=
          "]]}, 
        {RGBColor[
          NCache[
           Rational[8, 15], 0.5333333333333333], 0, 
          NCache[
           Rational[7, 15], 0.4666666666666667]], Thickness[Large], 
         LineBox[CompressedData["
1:eJw90gtIk1EUAOBNp04XvvJJopZW25BeijnL7sHMCCnmo6y0ltMyU4qQNLOi
CMMka1DD5lKTskxHpm30wu6PRlT4ohE5c5VZpmWpJUNxrvL/7/XAz8/l3vOd
ew53sfJI0n47Ho+3+f839+diATNT1RuWPfwAhbMhYnhFWz4Ulj9HB9hwYc7l
/v0429eNKjVz4cyE+oQKzZa3qLNjLoRMr3ddvTyvH3GekNlnsjWv0w0Qz4np
T/UZvZ75lXiOTOTqzxqrcoR4DoxjXHHhQPNP4gkYd9t0tzJsgngCJim9/q72
/h/i2TOtDxW3bYcsxLNjRC38NTUZ08TjMxurEs3btVbEch08Rp631vrdjQek
YaZt9o10YIYPXL4N19lvKFT4CIA7b8VdGzwHW7Mcgas3g0VbPVpMo0Jgec00
1hnqIlwMIuJN4RXCxT8Fz12JZ8E9ZRmSFHcP4k3ieP0Lfc+wJ6xhvT+48ttQ
7eFfXnCN9Sbw1Kbwpt0hvsQbx26uHYcyS/1J/ig+ZrgiiwwIIOdHcE1jye/8
vkDIYusN4WeTKr80czCsYv1BrL8lV5hTlxDvE9Zl+NqVGENIvgm/v3nPiuOW
kvNGfC/Mr7Skehmo2P1XOHmdV7DRuBzOsOvHuPdRt7bMJKbz44U3v3skq5fA
DW4fVRzhu8bGSMn6FdKtfKoQaKUQxfmoSNFQ4fKS7ptQ7OmCq+c6pfR+KOis
f4vKQM8PomJ9+cl3F6RwkOsPSVSyPHWSlPaPEsq3pUb7SKGHmw8qaC3S5pgk
dH7oYvSykLU1ErjOzRf13HlhLs6RQAQ3f2RJf8uXyiQkfxL9PZ0TpXaVkHoW
tMrN90fDCO13Ctl0m5SLXouJN43SXvbGFTSJiTeDToQajsZoxMSzotqd1Z/G
z4uJZ0NRbvom7+Pz84OIU55TsjwxdHHvEz547bpkUYqBvF94ktJ+fCyN5ttB
wOqBWuMOWs8e2toXBqcnU08Aar5xS0Ii9QRQFBvzOFdOPQcYi5EnX5ZTzxHU
So+9lxKp5wQqh5WN8fOeELLcg0yV26knhBR1Y8PRndRzBlGwId8wfz8XyB7f
o0lWUE8EXzZWhKzPpN4CCMx12JuRLYZ/ZaDlVw==
          "]]}, 
        {RGBColor[
          NCache[
           Rational[3, 5], 0.6], 0, 
          NCache[
           Rational[2, 5], 0.4]], Thickness[Large], LineBox[CompressedData["
1:eJw10mlME0EUAOC1lFKwKjZVI2CgGC8gQjm6KMq8RBFJrIChISYKCoUQFeuF
aIxXvI2YeiF4RdF4x4InUnRGhR8VMCpeaBqMmFLDIUI5KliV3ZmXbDaTee+b
eW9XnWVckiPhOC7x/zP8FkNBPqWrHPE9BEUJMZIo1Ybe99veoFwhfIhXx1l1
n/ILOlM6HN7kR8+qJ8uvfkMN9cMhJztuFqTNDXAg0ZOT0x860273dFDPi/ht
cm0O9u+mnoxMn7erILewl3qe5O+CpWBWuagnJRNWQVSda4h6UrL1wZVvmtMc
iJ4Haeu4619kk4DoScjRhWGbGtM8QfRGkJrOqpXbJXIQuHqO2EMSPpS3+wBt
mCTfN3en+o2m9W681L7v+UGrL80fwu5lk3QWs5KeN4hTmu8XGGtUIPClLoyD
w1sfKSZQbwBXzqrU9BdNpF4fjou+3lepC6CeE4+qa9MbUwMhUvB68LprmQ+l
yWooEbxfePelIPkt/8nU68IkJTz5xJgptL4dlyz+VDsuZBrN/4HbjqWfSsqb
AQbhPDtu2btlZ2JNKEQIfgvW5ydX7Y+eSb2v2LUmNsCqj6D1TTgnNCZec0RD
8xuxznHbo+FeJJiEfSt+llRnf/c8CnYJ68f4rsFufVEezebHlYU0/7lSGAMX
xX3kXfxyXLdKS9dWNHrPxsbqQ1qIFX2ER104HPSZ7Teh77oodYyCZ/dD57Kz
bLapPM1vQWPWm8JqI3jIE/tD3OWxtopwnvWPBpruBM6ezsNrcT4oT5JveTqJ
eV0ou7rsp0nJwzlxvihLf9QyQ85DtDh/1Bpa+nvlXy2tdyJtUIu9bEBLz+tD
jsSPkQqnln1flNTWKzf90lLPhd5lykpk/9eiN4g4Y4U6rpt5Q8h2XJPmdDLP
jTLn3stwDTCPA7jZ3Khya+GV+H9Camp+4Hgpz/5fKD9/cvxbH9a/BMICzruD
lez+HpDyeE6CYyLrVwrG1p++smCeelKITx8khhDmeYJpUcLqrkjmyaC433dF
SRzzvKC6/8WjxfOZJ4cbG7a0e+mYJwe1xbyzSs88bziw+satjAzm+YCfYXNg
Zy7zRsLBP+aabCPzFLA2tqLIUsjDPz316aI=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Uz/kBT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"z0 [\[Mu]m]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}},
       PlotRange->All,
       PlotRangeClipping->True], {967.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., 1.1268448858300088`*^-16}, {20., 
          9.00766043536206*^-16}, {30., 3.036774585421376*^-15}, {40., 
          7.190504796334576*^-15}, {50., 1.4034297239023006`*^-14}, {
          60.00000000000001, 2.4254095448966154`*^-14}, {69.99999999999999, 
          3.856510343712825*^-14}, {80., 5.773893458285357*^-14}, {90., 
          8.260093298063532*^-14}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., 1.2516259902386578`*^-16}, {20., 
          1.0013478561058627`*^-15}, {30., 3.3804237363093524`*^-15}, {40., 
          8.018618268428698*^-15}, {50., 1.5684553652654802`*^-14}, {
          60.00000000000001, 2.7172154710107046`*^-14}, {69.99999999999999, 
          4.331691998522543*^-14}, {80., 6.501197946977559*^-14}, {90., 
          9.321805169685063*^-14}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 3.822185672887343*^-18}, {20., 
          3.089303795374987*^-17}, {30., 1.0661547831847365`*^-16}, {40., 
          2.6259315221757317`*^-16}, {50., 5.434236781607203*^-16}, {
          60.00000000000001, 1.0171991563832349`*^-15}, {69.99999999999999, 
          1.7910121763723023`*^-15}, {80., 3.0421348036029624`*^-15}, {90., 
          5.0564973590283085`*^-15}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(Prx) [N]\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: Prz/10, Blue: Prx, Red: Pry\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {193.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.013352259145790552`}, {
          20., -0.10678197779040813`}, {30., -0.3602598292005943}, {
          40., -0.85386682292628}, {50., -1.66856641830285}, {
          60.00000000000001, -2.887594882916289}, {
          69.99999999999999, -4.598332626625347}, {80., -6.894318242172558}, {
          90., -9.876872630266988}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., -0.013128962901097638`}, {
          20., -0.10498254548440579`}, {30., -0.3541140389212944}, {
          40., -0.8390600983644279}, {50., -1.63904969055478}, {
          60.00000000000001, -2.835319438948343}, {
          69.99999999999999, -4.512871507131199}, {80., -6.762278320895155}, {
          90., -9.680888621530553}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., 0.1029448848918581}, {20., 0.808688946709511}, {30., 
          2.621840538848983}, {40., 5.7946614120546105`}, {50., 
          10.071754950845254`}, {60.00000000000001, 14.282837653228286`}, {
          69.99999999999999, 16.198654735887608`}, {80., 11.99479771903107}, {
          90., 0.}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Ux/kbT\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox[
          "\"Black: Uz*10/kbT, Blue: Ux/kbT, Red: Uy/kBT\"", 
           TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {580.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{
        {RGBColor[0, 0, 1], Thickness[Large], 
         LineBox[{{10., -0.31000000000000005`}, {
          20., -0.31000000000000005`}, {30., -0.31000000000000005`}, {
          40., -0.31000000000000005`}, {50., -0.31000000000000005`}, {
          60.00000000000001, -0.31000000000000005`}, {
          69.99999999999999, -0.31000000000000005`}, {80., 
          0.31999999999999984`}, {90., 0.31999999999999984`}}]}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         LineBox[{{10., 0.26}, {20., 0.26}, {30., 0.26}, {40., 0.26}, {50., 
          0.26}, {60.00000000000001, 0.26}, {69.99999999999999, 0.26}, {80., 
          0.26}, {90., 0.26}}]}, 
        {GrayLevel[0], Thickness[Large], 
         LineBox[{{10., -0.5999999999999996}, {20., -0.5999999999999996}, {
          30., -0.5999999999999996}, {40., -0.5999999999999996}, {
          50., -0.5999999999999996}, {
          60.00000000000001, -0.5999999999999996}, {
          69.99999999999999, -0.5999999999999996}, {80., -0.5}, {
          90., -0.5}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       Frame->True,
       FrameLabel->{{
          FormBox["\"Max(F): Pos\"", TraditionalForm], 
          FormBox["\"\"", TraditionalForm]}, {
          FormBox["\"d[nm]\"", TraditionalForm], 
          FormBox["\"Black: z, Blue: x, Red: y\"", TraditionalForm]}},
       PlotRange->Automatic,
       PlotRangeClipping->True], {967.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}]}}, {}},
  ContentSelectable->True,
  ImageSize->1100,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.500356240026969*^9, 3.5003562889566927`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some Performance Test", "Title",
 CellChangeTimes->{{3.497810125931468*^9, 3.4978101286205473`*^9}, {
  3.498209213105289*^9, 3.498209213544026*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CprG", "[", 
   RowBox[{
   "0.3", ",", "0", ",", "0", ",", "s", ",", "\[Lambda]", ",", "1", ",", 
    "0"}], "]"}], "*", 
  FractionBox[
   RowBox[{"2", "*", "2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], 
   RowBox[{"\[Pi]", " ", 
    SuperscriptBox["w0", "2"]}]]}]], "Input",
 CellChangeTimes->{{3.498201305120493*^9, 3.498201379888418*^9}, {
  3.4982014648222637`*^9, 3.498201465215968*^9}, {3.4982015061345367`*^9, 
  3.498201511307508*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "8.806346164546631`*^-16", ",", "5.078106007074451`*^-16", ",", 
   "3.728240157472179`*^-16", ",", "1.091732474468358`*^-17", ",", 
   "4.902203458709971`*^-33", ",", "0", ",", "0.001706251514211154`", ",", 
   "0.0017165965855121274`", ",", "0.0000669998100710465`"}], "}"}]], "Output",\

 CellChangeTimes->{
  3.4982013181941957`*^9, {3.498201362414877*^9, 3.498201380553994*^9}, 
   3.498201466571944*^9, 3.498201512048802*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Ctot", "=", 
     RowBox[{"CprG", "[", 
      RowBox[{
      "x0T", ",", "y0T", ",", "z0T", ",", "s", ",", "532", ",", "DoXY", ",", 
       "1"}], "]"}]}], ",", 
    RowBox[{"Pinc", "=", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"f", " ", "nm"}], ")"}], "2"]}]}], ",", 
    RowBox[{"Ctot", "/", "Pinc"}]}], "}"}], "\[IndentingNewLine]"}]], "Input",\

 CellChangeTimes->{{3.4978999437405167`*^9, 3.4978999999254303`*^9}, {
  3.49796157392388*^9, 3.497961596057579*^9}, {3.497963730526997*^9, 
  3.4979637606292562`*^9}, {3.4982011060527067`*^9, 3.498201108437367*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "4.840352382607715`*^-6", ",", "3.0773979858601558`*^-6", ",", 
     "1.7629543967475592`*^-6", ",", "0", ",", "0", ",", 
     "1.898912608802201`*^-6", ",", "5.775913`6.91213564085886", ",", 
     "0.005549`3.894729722646152", ",", "0.002989`3.6260409128712645"}], 
    "}"}], ",", "0.000010178760197630932`", ",", 
   RowBox[{"{", 
    RowBox[{
    "0.4755345728386733`", ",", "0.30233524772264586`", ",", 
     "0.1731993251160274`", ",", "0", ",", "0", ",", "0.18655637542617082`", 
     ",", "567447.5955671223`", ",", "545.1548019857574`", ",", 
     "293.65069438375`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.497899956428973*^9, 3.49790000705013*^9}, 
   3.49796160208817*^9, {3.497963740536858*^9, 3.497963766810964*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"CprG", "[", 
  RowBox[{
  "x00_", ",", "y00_", ",", "z00_", ",", "ss_", ",", "\[Lambda]\[Lambda]_", 
   ",", "DoXYY_", ",", "Exactt_"}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"x0T", "=", "0"}], ";", 
   RowBox[{"y0T", "=", "0"}], ";", 
   RowBox[{"z0T", "=", "0"}], ";", " ", 
   RowBox[{"DoXY", "=", "0"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"test", " ", "position", " ", 
    RowBox[{"in", " ", "[", "nm", "]"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"OG", "=", 
  RowBox[{
   RowBox[{"CprG", "[", 
    RowBox[{
    "x0T", ",", "y0T", ",", "z0T", ",", "s", ",", "532", ",", "DoXY", ",", 
     "1"}], "]"}], "/", 
   SuperscriptBox["w0E", "2"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OE", "=", 
   RowBox[{
    RowBox[{"CprG", "[", 
     RowBox[{
      RowBox[{"x0T", "/", 
       RowBox[{"(", 
        RowBox[{"1000", "w0"}], ")"}]}], ",", 
      RowBox[{"y0T", "/", 
       RowBox[{"(", 
        RowBox[{"1000", "w0"}], ")"}]}], ",", 
      RowBox[{"z0T", "/", 
       RowBox[{"(", 
        RowBox[{"1000", "l"}], ")"}]}], ",", "s", ",", "0.532", ",", "DoXY", 
      ",", "0"}], "]"}], "/", 
    SuperscriptBox["w0G", "2"]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OE", "[", 
    RowBox[{"[", "3", "]"}], "]"}], "/", 
   RowBox[{"OG", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"OG", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"OG", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"OG", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"OG", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"OE", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"OE", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"OE", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"OE", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwd0Fsow2EYBvCZqGXlHApzKGE3+1POCTlcjAgxJKyWUhjN+bTF0P5rUWtK
DiuMpiSFm21MxIVDQjlluZCzstwa3/NdPP0un/d9IqWtpTIuh8OJIoGyQb5S
5f2WXdRYRq37GlFDReA0NUPV1q8hhnBfBuCa69QADQHWKai4CFqGNiaUarQ7
3VhiisKHC9XNah7MGn/0gkbmyBf2HLv7wZdzV5OWOM7fk0NjqHMYSsUxY7Dw
6VcDLUEsC7/nPvUwYrvWAP+iWMk8+g7jq6D1QtwAk+Xl1KbePZGRyJ0VMjBz
w5C7iN7A+TwoeA4fgbtnJjXsF3axMI3RUXUJHgvQZXpYhLcVVjPsnmhfhZ4n
+euwo6OYqpT7Xi3hjz6eA74ebPJNxMEwG1Vf/VSzgrt+ZmqhvzZ2yEyMOxZR
O7X5o7Au2K6Bt6rUD7jruUJlSm6ut4jBXeI7mNjLd0BHvYBaudDyBiVJ9k9Y
bg6fOCc6/WKozQXe3ZfYQxTdAy2Tehsssn7sQN19zj70SX+n/gPA0gOR
  "]]
}, Open  ]]
},
WindowSize->{1431, 549},
WindowMargins->{{Automatic, 21}, {Automatic, 56}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 20, \
2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 1872, 59, 194, "Title"],
Cell[2442, 83, 23725, 395, 341, "Subtitle"],
Cell[26170, 480, 344, 6, 30, "Text"],
Cell[26517, 488, 4962, 124, 131, "Input"],
Cell[CellGroupData[{
Cell[31504, 616, 5255, 158, 152, "Input"],
Cell[36762, 776, 12935, 245, 462, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49746, 1027, 238, 4, 108, "Title"],
Cell[49987, 1033, 489, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[50501, 1051, 13323, 367, 377, "Input"],
Cell[63827, 1420, 370, 8, 35, "Output"],
Cell[64200, 1430, 19038, 346, 462, "Output"]
}, Open  ]],
Cell[83253, 1779, 467, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[83745, 1797, 11557, 303, 326, "Input"],
Cell[95305, 2102, 272, 6, 35, "Output"],
Cell[95580, 2110, 6254, 136, 462, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101871, 2251, 2702, 79, 103, "Input"],
Cell[104576, 2332, 537, 10, 28, "Output"]
}, Open  ]],
Cell[105128, 2345, 534, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[105687, 2364, 11557, 303, 326, "Input"],
Cell[117247, 2669, 299, 7, 35, "Output"],
Cell[117549, 2678, 6308, 138, 462, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123894, 2821, 2702, 79, 103, "Input"],
Cell[126599, 2902, 313, 6, 28, "Output"]
}, Open  ]],
Cell[126927, 2911, 757, 18, 46, "Text"],
Cell[CellGroupData[{
Cell[127709, 2933, 11610, 304, 326, "Input"],
Cell[139322, 3239, 293, 6, 35, "Output"],
Cell[139618, 3247, 66131, 1120, 462, 6217, 136, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205786, 4372, 2876, 82, 103, "Input"],
Cell[208665, 4456, 309, 6, 28, "Output"]
}, Open  ]],
Cell[208989, 4465, 660, 16, 46, "Text"],
Cell[CellGroupData[{
Cell[209674, 4485, 11662, 305, 326, "Input"],
Cell[221339, 4792, 320, 7, 35, "Output"],
Cell[221662, 4801, 6280, 136, 462, "Output"]
}, Open  ]],
Cell[227957, 4940, 2876, 82, 103, "Input"],
Cell[230836, 5024, 802, 18, 46, "Text"],
Cell[CellGroupData[{
Cell[231663, 5046, 11664, 305, 326, "Input"],
Cell[243330, 5353, 318, 7, 35, "Output"],
Cell[243651, 5362, 6291, 137, 462, "Output"]
}, Open  ]],
Cell[249957, 5502, 570, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[250552, 5521, 13478, 371, 377, "Input"],
Cell[264033, 5894, 341, 7, 35, "Output"],
Cell[264377, 5903, 29685, 520, 462, "Output"]
}, Open  ]],
Cell[294077, 6426, 684, 17, 46, "Text"],
Cell[CellGroupData[{
Cell[294786, 6447, 13679, 374, 377, "Input"],
Cell[308468, 6823, 419, 8, 35, "Output"],
Cell[308890, 6833, 30618, 534, 462, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[339557, 7373, 227, 4, 108, "Title"],
Cell[339787, 7379, 211, 3, 67, "Subtitle"],
Cell[CellGroupData[{
Cell[340023, 7386, 1097, 33, 69, "Input"],
Cell[341123, 7421, 605, 13, 35, "Output"],
Cell[341731, 7436, 238, 6, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[342006, 7447, 1089, 31, 69, "Input"],
Cell[343098, 7480, 650, 13, 35, "Output"],
Cell[343751, 7495, 288, 6, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344076, 7506, 127, 2, 28, "Input"],
Cell[344206, 7510, 251, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344494, 7521, 341, 7, 28, "Input"],
Cell[344838, 7530, 88, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344963, 7536, 148, 2, 45, "Subsubtitle"],
Cell[345114, 7540, 17442, 425, 623, "Input"],
Cell[362559, 7967, 1441, 35, 43, "Input"],
Cell[CellGroupData[{
Cell[364025, 8006, 17494, 444, 439, "Input"],
Cell[381522, 8452, 149950, 2807, 695, "Output"]
}, Open  ]],
Cell[531487, 11262, 285, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[531797, 11274, 10480, 289, 309, "Input"],
Cell[542280, 11565, 524, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542841, 11580, 1378, 38, 53, "Input"],
Cell[544222, 11620, 13801, 259, 462, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558060, 11884, 1087, 35, 74, "Input"],
Cell[559150, 11921, 3416, 61, 238, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[562615, 11988, 148, 2, 45, "Subsubtitle"],
Cell[562766, 11992, 1441, 35, 46, "Input"],
Cell[CellGroupData[{
Cell[564232, 12031, 17494, 444, 431, "Input"],
Cell[581729, 12477, 149765, 2810, 695, "Output"]
}, Open  ]],
Cell[731509, 15290, 8718, 263, 292, "Input"],
Cell[CellGroupData[{
Cell[740252, 15557, 322, 9, 28, "Input"],
Cell[740577, 15568, 60901, 1032, 462, 11673, 224, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[801527, 16606, 250, 4, 45, "Subsubtitle"],
Cell[801780, 16612, 1441, 35, 46, "Input"],
Cell[CellGroupData[{
Cell[803246, 16651, 19503, 489, 452, "Input"],
Cell[822752, 17142, 242895, 4331, 695, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1065684, 21478, 18873, 476, 431, "Input"],
Cell[1084560, 21956, 148106, 2663, 695, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1232727, 24626, 155, 2, 92, "Title"],
Cell[CellGroupData[{
Cell[1232907, 24632, 499, 14, 52, "Input"],
Cell[1233409, 24648, 473, 10, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1233919, 24663, 678, 18, 53, "Input"],
Cell[1234600, 24683, 815, 17, 56, "Output"]
}, Open  ]],
Cell[1235430, 24703, 177, 4, 28, "Input"],
Cell[1235610, 24709, 2491, 73, 140, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
